-- MySQL dump 10.13  Distrib 5.1.62, for unknown-linux-gnu (x86_64)
--
-- Host: localhost    Database: hermeshi_8
-- ------------------------------------------------------
-- Server version	5.1.61-community-log

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `hmsh_ebay_eastar_sku_item`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_sku_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_sku_item` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `sku` varchar(255) NOT NULL,
  `item_id` bigint(20) NOT NULL,
  `quantity` int(8) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=100726 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_sku_item`
--

LOCK TABLES `hmsh_ebay_eastar_sku_item` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_sku_item` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_sku_item` VALUES (1,'TRTS001',100001,1),(2,'TRTT002',100002,1),(3,'TRMX003',100003,1),(4,'CASS001',100004,1),(5,'CASS002',100005,1),(6,'CASS003',100006,1),(7,'CMLO001',100007,1),(8,'KBLO001',100008,1),(9,'SCLO001',100009,1),(10,'SCLO002',100010,1),(11,'RCLO001',100011,1),(12,'RCLO002',100012,1),(13,'RCLO003',100013,1),(14,'RCLO004',100014,1),(15,'RCLO005',100015,1),(16,'RCLO006',100016,1),(17,'POLO001',100017,1),(18,'CRLO002',100018,1),(19,'CRLO001',100019,1),(20,'BALO001',100020,1),(21,'BALO002',100021,1),(22,'BALO003',100022,1),(23,'BALO004',100023,1),(24,'BALO005',100024,1),(25,'BALO006',100025,1),(26,'BALO008',100026,1),(27,'RELE001',100027,1),(28,'RELO002',100028,1),(29,'MOLO001',100029,1),(30,'MOLO005',100030,1),(31,'BALO007',100031,1),(32,'HSLO001',100032,1),(33,'HSLO002',100033,1),(34,'RCMA001',100034,1),(35,'SHLO001',100035,1),(36,'MOLO002',100036,1),(37,'MOLO003',100037,1),(38,'SPAL001',100038,1),(39,'SPAL002',100039,1),(40,'ANYA001',100040,1),(41,'ANYA002',100041,1),(42,'ANWI001',100042,1),(43,'HSMO001',100043,1),(44,'HSMO002',100044,1),(45,'HSMO003',100045,1),(46,'HSMO004',100046,1),(47,'HSMO005',100047,1),(48,'HSMO006',100048,1),(49,'HSMO007',100049,1),(50,'HSMO008',100050,1),(51,'HSMO009',100051,1),(52,'HSMO010',100052,1),(53,'HSMO011',100053,1),(54,'HSMO012',100054,1),(55,'HSMO013',100055,1),(56,'HSMO014',100056,1),(57,'HSMO015',100057,1),(58,'HSMO016',100058,1),(59,'HSMO017',100059,1),(60,'HSMO018',100060,1),(61,'HSMO019',100061,1),(62,'HSMO020',100062,1),(63,'HSNO001',100063,1),(64,'HSNO002',100064,1),(65,'HSNO003',100065,1),(66,'HSNO004',100066,1),(67,'HSNO005',100067,1),(68,'HSNO006',100068,1),(69,'HSNO007',100069,1),(70,'HSNO008',100070,1),(71,'HSNO009',100071,1),(72,'HSNO010',100072,1),(73,'HSNO011',100073,1),(74,'HSNO013',100074,1),(75,'HSNO014',100075,1),(76,'HSNO015',100076,1),(77,'HSNO016',100077,1),(78,'HSNO017',100078,1),(79,'HSNO018',100079,1),(80,'HSNO019',100080,1),(81,'HSNO020',100081,1),(82,'HSNO021',100082,1),(83,'HSNO022',100083,1),(84,'HSNO023',100084,1),(85,'HSNO024',100085,1),(86,'HSNO025',100086,1),(87,'HSNO026',100087,1),(88,'HSNO027',100088,1),(89,'HSSA001',100089,1),(90,'HSSE001',100090,1),(91,'HSSE002',100091,1),(92,'HSSE007',100092,1),(93,'HSSE003',100093,1),(94,'HSSE004',100094,1),(95,'HSSE005',100095,1),(96,'HSSE006',100096,1),(97,'HSSE008',100097,1),(98,'HSPL001',100098,1),(99,'HSPL002',100099,1),(100,'HSPL003',100100,1),(101,'HSPL004',100101,1),(102,'HSPL005',100102,1),(103,'HSPL006',100103,1),(104,'HSPL007',100104,1),(105,'HSPL008',100105,1),(106,'HSPL009',100106,1),(107,'HSPL010',100107,1),(108,'HSPL011',100108,1),(109,'HSPL012',100109,1),(110,'HSPL013',100110,1),(111,'HSJA001',100111,1),(112,'HSJA002',100112,1),(113,'HSJA003',100113,1),(114,'HSUE001',100114,1),(115,'HSUE002',100115,1),(116,'HSUE003',100116,1),(117,'HSUE004',100117,1),(118,'HSSS001',100118,1),(119,'HSSS002',100119,1),(120,'HSSS003',100120,1),(121,'HSSS004',100121,1),(122,'HSSS005',100122,1),(123,'HSSS006',100123,1),(124,'HSSS007',100124,1),(125,'HSSS008',100125,1),(126,'HSSH001',100126,1),(127,'HSSH002',100127,1),(128,'OTHP001',100128,1),(129,'BAZA001',100129,1),(130,'CCZG001',100130,1),(131,'MOSA003',100131,1),(132,'MOSA002',100132,1),(133,'MOSA001',100133,1),(134,'OTSB001',100134,1),(135,'OTCR001',100135,1),(136,'OTRA001',100136,1),(137,'OTRA002',100137,1),(139,'OTGR001',100139,1),(140,'OTGR002',100140,1),(141,'OTHP003',100141,1),(142,'OTCN001',100142,1),(143,'OTCN002',100143,1),(144,'OTCN003',100144,1),(145,'OTCN004',100145,1),(146,'OTCA001',100146,1),(147,'TOIN001',100147,1),(148,'TOIN002',100148,1),(149,'BAIN001',100149,1),(150,'BAIN002',100150,1),(151,'OTJE001',100151,1),(152,'OTPH002',100152,1),(153,'OTKE001',100153,1),(154,'OTSO001',100154,1),(155,'OTSO002',100155,1),(156,'KBVI001',100156,1),(157,'KBVI002',100157,1),(158,'KBAP001',100158,1),(159,'KBAP002',100159,1),(160,'KBAP003',100160,1),(161,'MOMI001',100161,1),(162,'MOSU001',100162,1),(163,'MOSU002',100163,1),(164,'MOAJ001',100164,1),(165,'WWSI001',100165,1),(166,'WWSI002',100166,1),(167,'WWSI003',100167,1),(168,'WWSI004',100168,1),(169,'WWSI005',100169,1),(170,'WWSI006',100170,1),(171,'WWOT001',100171,1),(172,'WWOT002',100172,1),(173,'WWOP002',100173,1),(174,'WWOP003',100174,1),(175,'WWHU001',100175,1),(176,'WWHU002',100176,1),(177,'WWHU003',100177,1),(178,'WWOT003',100178,1),(179,'MOCN001',100179,1),(180,'ANCN001',100180,1),(181,'ANCN002',100181,1),(182,'ANCN003',100182,1),(183,'WLDL001',100183,1),(184,'WLAP001',100184,1),(185,'WLAP002',100185,1),(186,'WLAP003',100186,1),(187,'WLAP004',100187,1),(188,'WLAP005',100188,1),(189,'WLAP006',100189,1),(190,'WLAP007',100190,1),(191,'WLAP008',100191,1),(192,'WLAP009',100192,1),(193,'MOAP001',100193,1),(194,'MOAP002',100194,1),(195,'WLIN001',100195,1),(196,'WLIN002',100196,1),(197,'WLDE001',100197,1),(198,'WLDE002',100198,1),(199,'WLDE003',100199,1),(200,'WLHP001',100200,1),(201,'WLBR001',100201,1),(202,'WLHP002',100202,1),(203,'WLAT001',100203,1),(204,'WLAT002',100204,1),(205,'WLAT003',100205,1),(206,'WLAT004',100206,1),(207,'WLAT005',100207,1),(208,'WLAT006',100208,1),(209,'WLAT007',100209,1),(210,'WLAT008',100210,1),(211,'WLAT009',100211,1),(212,'WLAT010',100212,1),(213,'WLIN003  ',100213,1),(214,'WLIN004',100214,1),(215,'WLIN005',100215,1),(216,'WLIN006',100216,1),(217,'WLIN007',100217,1),(218,'WLIN008',100218,1),(219,'WLIN009',100219,1),(220,'WLIN010',100220,1),(221,'WLIN011',100221,1),(222,'WLIN012',100222,1),(223,'WLIN013',100223,1),(224,'WLPO001',100224,1),(225,'BTAC2000',100225,1),(226,'BTDE2001',100226,1),(227,'BTDE2002',100227,1),(228,'BTGA2001',100228,1),(229,'BTLE2001',100229,1),(230,'BTLE2002',100230,1),(231,'BTHU2001',100231,1),(232,'BTHU2002',100232,1),(233,'BTHU2003',100233,1),(234,'BTHU2004',100234,1),(235,'BTHU2005',100235,1),(236,'BTAC2001',100236,1),(237,'BTAC2002',100237,1),(238,'BTAC2003',100238,1),(239,'BTAC2004',100239,1),(240,'BTAC2005',100240,1),(241,'BTAC2006',100241,1),(242,'BTAC2007',100242,1),(243,'BTAC2008',100243,1),(244,'BTAC2009',100244,1),(245,'BTAC2010',100245,1),(246,'BTAC2011',100246,1),(247,'BTAC2012',100247,1),(248,'BTAC2013',100248,1),(249,'BTAC2014',100249,1),(250,'BTAC2015',100250,1),(251,'BTAC2016',100251,1),(252,'BTAC2017',100252,1),(253,'BTAC2018',100253,1),(254,'BTAC2019',100254,1),(255,'BTAC2020',100255,1),(256,'BTAC2021',100256,1),(257,'BTAC2022',100257,1),(258,'BTAC2023',100258,1),(259,'BTAC2024',100259,1),(260,'BTAC2025',100260,1),(261,'BTHP2001',100261,1),(262,'BTHP2002',100262,1),(263,'BTHP2003',100263,1),(264,'BTHP2004',100264,1),(265,'BTHP2005',100265,1),(266,'BTHP2006',100266,1),(267,'BTHP2007',100267,1),(268,'BTHP2008',100268,1),(269,'BTHP2009',100269,1),(270,'BTHP2010',100270,1),(271,'BTHP2011',100271,1),(272,'BTHP2012',100272,1),(273,'BTHP2013',100273,1),(274,'BTBE2001',100275,1),(275,'BTBE2002',100276,1),(276,'BTBE2003',100277,1),(277,'BTBE2004',100278,1),(278,'BTSA2001',100279,1),(279,'BTSA2002',100280,1),(280,'BTSA2003',100281,1),(281,'BTSA2004',100282,1),(282,'BTSA2005',100283,1),(283,'BTSA2006',100284,1),(284,'BTSA2007',100285,1),(285,'BTDE2100',100286,1),(286,'BTDE2101',100287,1),(287,'BTDE2102',100288,1),(288,'BTGA2101',100289,1),(289,'BTLE2101',100290,1),(290,'BTLE2102',100291,1),(291,'BTAC2101',100292,1),(292,'BTAC2102',100293,1),(293,'BTAC2103',100294,1),(294,'BTAC2104',100295,1),(295,'BTAC2105',100296,1),(296,'BTAC2106',100297,1),(297,'BTAC2107',100298,1),(298,'BTAC2108',100299,1),(299,'BTAC2109',100300,1),(300,'BTAC2110',100301,1),(301,'BTAC2111',100302,1),(302,'BTAC2112',100303,1),(303,'BTAC2113',100304,1),(304,'BTAC2114',100305,1),(305,'BTAC2115',100306,1),(306,'BTAC2116',100307,1),(307,'BTAC2117',100308,1),(308,'BTAC2118',100309,1),(309,'BTAC2119',100310,1),(310,'BTAC2120',100311,1),(311,'BTAC2121',100312,1),(312,'BTAC2122',100313,1),(313,'BTAC2123',100314,1),(314,'BTAC2124',100315,1),(315,'BTAC2125',100316,1),(316,'BTAC2126',100317,1),(317,'BTAC2127',100318,1),(318,'BTHP2101',100319,1),(319,'BTHP2102',100320,1),(320,'BTHP2103',100321,1),(321,'BTHP2104',100322,1),(322,'BTHP2105',100323,1),(323,'BTHP2106',100324,1),(324,'BTHP2107',100325,1),(325,'BTHP2108',100326,1),(326,'BTHP2109',100327,1),(327,'BTHP2110',100328,1),(328,'BTHP2111',100329,1),(329,'BTHP2112',100330,1),(330,'BTHP2113',100331,1),(331,'BTHP3000',100332,1),(332,'BTHP3001',100333,1),(333,'BTHP3002',100334,1),(334,'BTHP3003',100335,1),(335,'BTHP3004',100336,1),(336,'BTHP3005',100337,1),(337,'ADAK001',100338,1),(338,'ADAK002',100339,1),(339,'ADAK003',100340,1),(340,'CACN001',100341,1),(341,'CACN003',100342,1),(342,'CACN004',100343,1),(343,'OTAU001',100344,1),(344,'OTAP001',100345,1),(345,'OTAP002',100346,1),(346,'OTIN001',100347,1),(347,'OTIN002',100348,1),(348,'OTIN003',100349,1),(349,'OTIN004',100350,1),(350,'OTIN005',100351,1),(351,'OTIN006',100352,1),(352,'OMHJ001',100353,1),(353,'ANTY001',100354,1),(354,'ANTY002',100355,1),(356,'ANAP001',100357,1),(357,'CALO001',100358,1),(358,'CCPL001',100359,1),(359,'CCPL002',100360,1),(360,'CCMO001',100361,1),(361,'CCMO002',100362,1),(362,'CCNO001',100363,1),(363,'TRTS001*10',100001,10),(364,'TRTT002*10',100002,10),(365,'TRMX003*10',100003,10),(366,'CRLO001+POLO001',100019,1),(367,'CRLO001+POLO001',100017,1),(368,'BALO001+BAIN002',100020,1),(369,'BALO001+BAIN002',100150,1),(370,'BALO005+BALO006',100024,1),(371,'BALO005+BALO006',100025,1),(372,'HSMO001+CCMO001',100043,1),(373,'HSMO001+CCMO001',100361,1),(374,'HSMO002+CCMO001',100044,1),(375,'HSMO002+CCMO001',100361,1),(376,'HSMO011+CCMO001',100053,1),(377,'HSMO011+CCMO001',100361,1),(378,'HSMO012+CCMO001',100054,1),(379,'HSMO012+CCMO001',100361,1),(380,'HSNO005+CCNO001',100067,1),(381,'HSNO005+CCNO001',100363,1),(382,'HSNO006+CCNO001',100068,1),(383,'HSNO006+CCNO001',100363,1),(384,'HSNO016+CCNO001',100077,1),(385,'HSNO016+CCNO001',100363,1),(386,'HSNO019+CCNO001',100080,1),(387,'HSNO019+CCNO001',100363,1),(388,'HSPL001+CCPL001',100098,1),(389,'HSPL001+CCPL001',100359,1),(390,'HSPL009+CCPL001',100106,1),(391,'HSPL009+CCPL001',100359,1),(392,'HSPL013+CCPL001',100110,1),(393,'HSPL013+CCPL001',100359,1),(394,'OTGR001+OTGR002',100139,1),(395,'OTGR001+OTGR002',100140,1),(396,'OTCN004*10',100145,10),(397,'BAIN001+BAIN002+TOIN002',100149,1),(398,'BAIN001+BAIN002+TOIN002',100150,1),(399,'BAIN001+BAIN002+TOIN002',100148,1),(400,'WWSI001+ANCN001',100165,1),(401,'WWSI001+ANCN001',100180,1),(402,'WWSI002+ANCN001',100166,1),(403,'WWSI002+ANCN001',100180,1),(404,'WWSI003+ANCN001',100167,1),(405,'WWSI003+ANCN001',100180,1),(406,'WWSI004+ANCN001',100168,1),(407,'WWSI004+ANCN001',100180,1),(408,'WWSI005+ANCN001',100169,1),(409,'WWSI005+ANCN001',100180,1),(410,'WWSI006+ANCN001',100170,1),(411,'WWSI006+ANCN001',100180,1),(412,'WWOT001+ANCN001',100171,1),(413,'WWOT001+ANCN001',100180,1),(414,'WWOT002+ANCN001',100172,1),(415,'WWOT002+ANCN001',100180,1),(416,'WWOP002+ANCN001',100173,1),(417,'WWOP002+ANCN001',100180,1),(418,'WWOP003+ANCN001',100174,1),(419,'WWOP003+ANCN001',100180,1),(420,'WWOT003+ANCN001',100178,1),(421,'WWOT003+ANCN001',100180,1),(422,'WLAP001+WLAP004',100184,1),(423,'WLAP001+WLAP004',100187,1),(424,'WLAP004*10',100187,10),(425,'WLDE001+ANTY001',100197,1),(426,'WLDE001+ANTY001',100354,1),(427,'WLDE002+ANTY001',100198,1),(428,'WLDE002+ANTY001',100354,1),(429,'WLDE003+ANTY001',100199,1),(430,'WLDE003+ANTY001',100354,1),(431,'WLHP002+ANTY001',100202,1),(432,'WLHP002+ANTY001',100354,1),(433,'WLAT001+ANTY002',100203,1),(434,'WLAT001+ANTY002',100355,1),(435,'WLAT002+ANTY002',100204,1),(436,'WLAT002+ANTY002',100355,1),(437,'WLAT003+ANTY002',100205,1),(438,'WLAT003+ANTY002',100355,1),(439,'WLAT004+ANTY002',100206,1),(440,'WLAT004+ANTY002',100355,1),(441,'WLAT005+ANTY001',100207,1),(442,'WLAT005+ANTY001',100354,1),(443,'WLAT007+ANTY001',100209,1),(444,'WLAT007+ANTY001',100354,1),(445,'WLAT008+ANTY001',100210,1),(446,'WLAT008+ANTY001',100354,1),(447,'WLAT009+ANTY001',100211,1),(448,'WLAT009+ANTY001',100354,1),(449,'WLAT010+ANTY001',100212,1),(450,'WLAT010+ANTY001',100354,1),(451,'WLIN004+ANTY001',100214,1),(452,'WLIN004+ANTY001',100354,1),(453,'WLIN005+ANTY001',100215,1),(454,'WLIN005+ANTY001',100354,1),(455,'WLIN006+ANTY001',100216,1),(456,'WLIN006+ANTY001',100354,1),(457,'WLIN007+ANTY002',100217,1),(458,'WLIN007+ANTY002',100355,1),(459,'WLIN008+ANTY001',100218,1),(460,'WLIN008+ANTY001',100354,1),(461,'WLIN009+ANTY002',100219,1),(462,'WLIN009+ANTY002',100355,1),(463,'WLIN010+ANTY002',100220,1),(464,'WLIN010+ANTY002',100355,1),(465,'WLIN011+ANTY002',100221,1),(466,'WLIN011+ANTY002',100355,1),(467,'WLIN012+ANTY002',100222,1),(468,'WLIN012+ANTY002',100355,1),(469,'CACN001+CACN003',100341,1),(470,'CACN001+CACN003',100342,1),(471,'UDAP001',100364,1),(472,'UDAP002',100365,1),(473,'NTLO001',100366,1),(474,'HSPL014',100367,1),(475,'WLAP005+ANAP001',100188,1),(476,'WLAP005+ANAP001',100357,1),(477,'OT3M001',100368,1),(478,'OTFY001',100369,1),(479,'OT3M001*10',100368,10),(480,'HSNO028',100370,1),(481,'HSSE009',100371,1),(482,'RELO003',100372,1),(483,'MOVI001',100373,1),(484,'',0,0),(485,'MOVI002',100374,1),(486,'MOVI003',100375,1),(487,'MOVI004',100376,1),(488,'RCLO007',100377,1),(489,'OTCN005',100378,1),(490,'OTCN005*10',100378,10),(491,'EXLO001',100379,1),(492,'MOLO004',100380,1),(493,'OTMP001',100381,1),(494,'OTHP004',100382,1),(495,'RCLO008',100383,1),(496,'RCLO008*4',100383,4),(497,'RCLO007+POLO001+RCLO008*4',100377,1),(498,'RCLO007+POLO001+RCLO008*4',100017,1),(499,'RCLO007+POLO001+RCLO008*4',100383,4),(500,'WLIN014',100384,1),(501,'OTHP005',100385,1),(502,'MOMI002',100386,1),(509,'OTES001',100389,1),(508,'KBNO001',100388,1),(507,'OTTP001',100387,1),(510,'HSJA004',100390,1),(511,'REPL001',100391,1),(512,'NTLO002',100392,1),(513,'NTLO001+NTLO002',100366,1),(514,'NTLO001+NTLO002',100392,1),(515,'MOSA005',100393,1),(516,'GLSG001',100394,1),(517,'WLIN015',100395,1),(518,'GLSG001*2',100394,2),(519,'OTSO003',100396,1),(520,'RCDE001',100397,1),(521,'SHLO002',100398,1),(522,'SHLO003',100399,1),(523,'SHLO004',100400,1),(524,'SHLO005',100401,1),(525,'SHLO006',100402,1),(526,'TRMX004',100403,1),(527,'HSJA005',100404,1),(528,'GLSG002',100405,1),(530,'GLSG003',100406,1),(531,'KBFF001',100407,1),(532,'HSSA002',100408,1),(533,'BR3D001',100409,1),(534,'HSJA006',100410,1),(535,'HSJA007',100411,1),(536,'HSJA008',100412,1),(537,'HSJA009',100413,1),(538,'HSPL015',100414,1),(539,'OTPL001',100415,1),(540,'HSPH001',100416,1),(541,'MOAS001',100417,1),(542,'OTLK001',100418,1),(543,'HSSA003',100419,1),(544,'HSSA004',100420,1),(545,'HSNO029',100421,1),(546,'HSMO021',100422,1),(547,'OTSO004',100423,1),(548,'GLSG004',100424,1),(549,'OTGR003',100425,1),(550,'OTGR001+OTGR002+OTGR003',100139,1),(551,'OTGR001+OTGR002+OTGR003',100140,1),(552,'OTGR001+OTGR002+OTGR003',100425,1),(553,'RELO001',100426,1),(554,'MOLO006',100427,1),(555,'HSPL016',100428,1),(556,'OTSO004×2 ',100423,2),(557,'GLOT001',100429,1),(558,'GLOT002',100430,1),(559,'CCGR001',100431,1),(585,'GLOT002+GLOT003',100449,1),(584,'GLOT002+GLOT003',100430,1),(562,'GLOT001*2',100429,2),(563,'MOFP001',100432,1),(564,'HDSG001',100433,1),(565,'MOLO007',100434,1),(566,'MOLO008',100435,1),(567,'HSPL017',100436,1),(568,'MOMI003',100437,1),(569,'MOLO009',100438,1),(570,'WLAT011',100439,1),(571,'GLSG005',100441,1),(572,'GLSG005*2',100441,2),(573,'HSJB001',100442,1),(574,'OTAM001',100443,1),(575,'HSAK001',100444,1),(576,'MOOE001',100445,1),(577,'MOOE002',100446,1),(578,'HSNO030',100447,1),(579,'BR3D002',100448,1),(582,'GLOT003',100449,1),(583,'GLOT004',100450,1),(586,'GLOT004*2',100450,2),(587,'BR3D003',100451,1),(588,'GLSG001*4',100394,4),(589,'OTSO004*4',100423,4),(590,'OTSO004*2',100423,2),(591,'OTSO004*4',100423,4),(592,'OTRA003',100440,1),(593,'MOSA004',100452,1),(594,'MOSA006',100453,1),(595,'GLSG006',100454,1),(596,'SHLO007',100455,1),(597,'UM00001',100456,1),(598,'BR3D004',100457,1),(599,'BR3D005',100458,1),(600,'CAWA001',100459,1),(601,'OTSA001',100460,1),(602,'HDGE001',100461,1),(603,'BR3D006',100462,1),(604,'BR3D007',100463,1),(605,'UM00002',100464,1),(606,'UM00003',100465,1),(607,'UM00004',100466,1),(608,'UM00005',100467,1),(609,'UM00006',100468,1),(610,'UM00007',100469,1),(611,'UM00008',100470,1),(612,'UM00009',100471,1),(613,'UM00010',100472,1),(614,'UM00011',100473,1),(615,'UM00012',100474,1),(616,'UM00013',100475,1),(617,'UM00014',100476,1),(618,'HSJA010',100477,1),(619,'HSJA011',100478,1),(620,'HSSE010',100479,1),(621,'GLOT004*3',100450,3),(622,'GLOT001*3',100429,3),(623,'OTSO004*3',100423,3),(624,'GLSG001*3',100394,3),(625,'HBPH001',100480,1),(626,'HBPH002',100481,1),(627,'HBPH003',100482,1),(628,'HBPH004',100483,1),(629,'MOLO010',100484,1),(630,'BR3D008',100485,1),(631,'WLIN016',100486,1),(632,'HBPH001+HBPH003+HBPH004',100480,1),(633,'HBPH001+HBPH003+HBPH004',100482,1),(634,'HBPH001+HBPH003+HBPH004',100483,1),(635,'HBPH002+HBPH003+HBPH004',100481,1),(636,'HBPH002+HBPH003+HBPH004',100482,1),(637,'HBPH002+HBPH003+HBPH004',100483,1),(638,'SCLO003',100487,1),(639,'UM00015',100488,1),(640,'UM00016',100489,1),(641,'UM00017',100490,1),(642,'UM00018',100491,1),(643,'UM00019',100492,1),(644,'UM00020',100493,1),(645,'UM00021',100494,1),(646,'UM00022',100495,1),(647,'UM00023',100496,1),(648,'UM00024',100497,1),(649,'UM00025',100498,1),(650,'UM00026',100499,1),(651,'UM00027',100500,1),(652,'UM00028',100501,1),(653,'UM00029',100502,1),(654,'OTSO005',100503,1),(677,'OTSO005*2',100503,2),(656,'SCLO004',100505,1),(657,'HSIT001',100506,1),(658,'OTHP006',100507,1),(659,'OTGR004',100508,1),(660,'OTGR005',100509,1),(661,'OTGR006',100510,1),(662,'UM00030',100511,1),(663,'OTGR006+OTGR002',100510,1),(664,'OTGR006+OTGR002',100140,1),(665,'OTGR004+OTGR002',100508,1),(666,'OTGR004+OTGR002',100140,1),(667,'OTGR005+OTGR002',100509,1),(668,'OTGR005+OTGR002',100140,1),(669,'UM00031',100512,1),(670,'UM00032',100513,1),(671,'UM00033',100514,1),(672,'GLOT005',100515,1),(673,'GLOT005*2',100515,2),(674,'GLOT005*3',100515,3),(675,'GLOT005*4',100515,4),(676,'HBPH005',100516,1),(678,'BTAS3001',100517,1),(679,'BTAS3002',100518,1),(680,'BTLE3001',100519,1),(681,'BTLE3002',100520,1),(682,'RCDE002',100521,1),(683,'RCDE003',100522,1),(684,'HSIQ001',100523,1),(685,'MOHP001',100524,1),(686,'WLKO001',100525,1),(687,'HSBS001',100526,1),(688,'HSBS002',100527,1),(689,'OTTB001',100528,1),(690,'RCYA001',100529,1),(691,'GPS0001',100530,1),(692,'GPS0002',100531,1),(693,'UM00034',100532,1),(694,'GLSG007',100533,1),(695,'PHVE001',100534,1),(696,'PHVE002',100535,1),(697,'GLSG007*2',100533,2),(698,'HSAK002',100536,1),(699,'HSAK003',100537,1),(700,'OTPA001',100538,1),(701,'OTPH003',100539,1),(702,'KEOT001',100540,1),(703,'UDAP003',100541,1),(704,'GPS0003',100542,1),(705,'GLSG008',100543,1),(706,'HBPH006',100544,1),(707,'HBPH007',100545,1),(708,'HBPH002+HBPH003',100481,1),(709,'HBPH002+HBPH003',100482,1),(710,'UM00035',100546,1),(711,'UM00036',100547,1),(712,'UM00037',100548,1),(713,'UM00038',100549,1),(714,'UM00039',100550,1),(715,'GPS0004',100551,1),(716,'GPS0005',100552,1),(717,'OTNB001',100553,1),(718,'HSNO031',100554,1),(719,'GLOT001*4',100429,4),(720,'HSBS003',100555,1),(721,'UDAP004',100556,1),(722,'RMSN001',100557,1),(723,'RMSN002',100558,1),(724,'RMSN003',100559,1),(725,'HSPL018',100560,1),(726,'CC00001',100561,1),(727,'CC00002',100562,1),(728,'HSSE011',100563,1),(729,'HSSE012',100564,1),(730,'HSNO032',100565,1),(731,'HSIT002',100566,1),(732,'HSIT003',100567,1),(733,'HSIT004',100568,1),(734,'MOMI003',100569,1),(735,'HSJA012',100570,1),(736,'HSJA013',100571,1),(737,'FP00001',100572,1),(738,'GLOT006',100573,1),(739,'HBPH008',100574,1),(740,'HBPH009',100575,1),(741,'LGGL001',100576,1),(742,'LGAD001',100577,1),(743,'LGRM001',100578,1),(744,'LGGL002',100579,1),(745,'MOOE003',100580,1),(746,'GLSG001*2+BR3D001',100394,2),(747,'GLSG001*2+BR3D001',100409,1),(748,'GLSG001*2+BR3D005',100394,2),(749,'GLSG001*2+BR3D005',100458,1),(750,'GLSG001*2+BR3D004',100394,2),(751,'GLSG001*2+BR3D004',100457,1),(752,'GLSG001*2+BR3D006',100394,2),(753,'GLSG001*2+BR3D006',100462,1),(754,'GLSG001*2+BR3D007',100394,2),(755,'GLSG001*2+BR3D007',100463,1),(756,'GLSG001*2+BR3D008',100394,2),(757,'GLSG001*2+BR3D008',100485,1),(758,'GLSG001*2+BR3D002',100394,2),(759,'GLSG001*2+BR3D002',100448,1),(760,'GLOT006*2',100573,2),(761,'GLOT006*3',100573,3),(762,'GLOT006*4',100573,4),(763,'GPS0006',100581,1),(764,'GPS0007',100582,1),(765,'GPS0008',100583,1),(766,'GPS0009',100584,1),(767,'GRUG001',100585,1),(768,'MOLA001',100586,1),(769,'BR3D009',100587,1),(770,'BALO009',100588,1),(771,'CAWA002',100589,1),(772,'SHLO008',100592,1),(773,'SHLO009',100593,1),(774,'SHLO010',100594,1),(775,'LGGL003',100595,1),(776,'LGGL004',100596,1),(777,'HSPH002',100597,1),(778,'HSPH003',100598,1),(779,'HSPH004',100599,1),(780,'HSPH005',100600,1),(781,'HSPH006',100601,1),(782,'HSPH007',100602,1),(783,'HSMO022',100603,1),(784,'HSMO023',100604,1),(785,'SCLO005',100605,1),(786,'SPGL001',100606,1),(787,'LGFI001',100607,1),(788,'SAFI001',100608,1),(789,'SAFI002',100609,1),(790,'UM00040',100610,1),(791,'UM00041',100611,1),(792,'UM00042',100612,1),(794,'LGGL002*2',100579,2),(795,'LGGL002*3',100579,3),(796,'LGGL002*4',100579,4),(797,'GPS0010',100613,1),(798,'OT00001',100614,1),(799,'MOHP002',100615,1),(800,'RCLO009',100616,1),(801,'HSNO033',100617,1),(802,'HSIT005',100618,1),(803,'HSPH008',100619,1),(804,'OT00002',100620,1),(805,'GLSG009',100621,1),(806,'GLSG009*2',100621,2),(807,'GLSG009*3',100621,3),(808,'GLSG009*4',100621,4),(100638,'OT00004',100624,4),(100637,'OT00003',100623,1),(100636,'GLSG010*4',100622,4),(100635,'GLSG010*3',100622,3),(100634,'GLSG010*2',100622,2),(100633,'GLSG010',100622,1),(100639,'OT00005',100625,1),(100640,'OT00006',100626,1),(100641,'GPS0011',100627,1),(100642,'GPS0012',100628,1),(100643,'OT00007',100629,1),(100644,'UM00043',100630,1),(100645,'GLOT007',100631,1),(100646,'OT00008',100632,1),(100647,'LGFI001*2',100607,2),(100648,'LGFI001*3',100607,3),(100649,'SAFI001*2',100608,2),(100650,'SAFI001*3',100608,3),(100651,'SAFI002*2',100609,2),(100652,'SAFI002*3',100609,3),(100653,'UM00044',100633,1),(100654,'UM00045',100634,1),(100655,'UM00046',100635,1),(100656,'UM00047',100636,1),(100657,'UM00048',100637,1),(100658,'UM00049',100638,1),(100659,'UM00050',100639,1),(100660,'UM00051',100640,1),(100661,'UM00052',100641,1),(100662,'HSAL001',100642,1),(100663,'HSAL002',100643,1),(100664,'MOZA001',100644,1),(100665,'BR3D010',100645,1),(100666,'MOSA007',100646,1),(100667,'MOSA008',100647,1),(100668,'MOSA009',100648,1),(100669,'MOSA010',100649,1),(100670,'HSNO034',100650,1),(100671,'HSNO035',100651,1),(100672,'HSNO036',100652,1),(100673,'HSMO024',100653,1),(100674,'UM00053',100654,1),(100675,'BR3D011',100655,1),(100676,'TRSN001',100656,1),(100677,'LGGL005',100657,1),(100678,'RVM0001',100658,1),(100679,'RVM0002',100659,1),(100680,'PS00001',100660,1),(100681,'PS00002',100661,1),(100682,'PSGL001',100662,1),(100683,'PSGL001*2',100662,2),(100684,'PSGL001*3',100662,3),(100685,'PSGL001*4',100662,4),(100686,'CACN005',100663,1),(100687,'RCHP001',100664,1),(100688,'RCHP002',100665,1),(100689,'RCLO007+POLO001',100377,1),(100690,'RCLO007+POLO001',100017,1),(100691,'ADPT001',100666,1),(100692,'GPS0010+ADPT001',100613,1),(100693,'GPS0010+ADPT001',100666,1),(100694,'GLSG008*2',100543,2),(100695,'GLSG008*3',100543,3),(100696,'GLSG008*4',100543,4),(100697,'ADPT002',100667,1),(100698,'ADPT003',100668,1),(100699,'GPS0014',100669,1),(100700,'GPS0015',100670,1),(100701,'HSAL003',100671,1),(100702,'GPS0006+ADPT002',100581,1),(100703,'GPS0006+ADPT002',100667,1),(100725,'GLOT009',100675,1),(100724,'GLOT008',100674,1),(100723,'RVM0003',100673,1),(100722,'HBPH010',100672,1),(100708,'GPS0014+ADPT002',100669,1),(100709,'GPS0014+ADPT002',100667,1),(100710,'GPS0015+ADPT002',100670,1),(100711,'GPS0015+ADPT002',100667,1),(100712,'GPS0006+ADPT003',100581,1),(100713,'GPS0006+ADPT003',100668,1),(100718,'GPS0014+ADPT003',100669,1),(100719,'GPS0014+ADPT003',100668,1),(100720,'GPS0015+ADPT003',100670,1),(100721,'GPS0015+ADPT003',100668,1);
/*!40000 ALTER TABLE `hmsh_ebay_eastar_sku_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_eastar_stock`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_stock`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_stock` (
  `item_id` bigint(20) NOT NULL,
  `item_name` varchar(2048) NOT NULL,
  `item_condition` varchar(255) DEFAULT NULL,
  `item_type` varchar(255) DEFAULT NULL,
  `item_stock` int(8) NOT NULL,
  `item_price` double DEFAULT NULL,
  `update_time` datetime DEFAULT NULL,
  PRIMARY KEY (`item_id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_stock`
--

LOCK TABLES `hmsh_ebay_eastar_stock` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_stock` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_stock` VALUES (100001,'AUI Transceiver  210TS','used','Computer',-14,0,'2012-03-21 19:51:43'),(100002,'AUI Transceiver  210T','used','Computer',107,0,'2012-03-21 19:04:33'),(100003,'AUI Transceiver  MX20T','used','Computer',5,0,'2012-03-20 20:20:13'),(100004,'CAB-SS-2626','New','Computer',34,0,'2012-03-15 00:01:02'),(100005,'CAB-SS-2660','New','Computer',67,0,'2012-03-15 20:09:43'),(100006,'CAB-6060','New','Computer',15,0,'2012-03-19 19:54:52'),(100007,'罗技PRO4000 摄像头（原装）','New','Computer',0,0,'2011-11-13 18:11:01'),(100008,'罗技 diNovo Keyboard+ MediaPad+ dongle used','New','Computer',0,0,'2011-06-15 21:35:15'),(100009,'罗技 880 880pro 890 890pro screen','New','Computer',4,0,'2012-02-22 19:29:06'),(100010,'罗技 MX 鼠标 mat','New','Computer',161,0,'2012-03-25 04:11:34'),(100011,'罗技 880 遥控 新的','New','Computer',0,0,'0000-00-00 00:00:00'),(100012,'罗技 880 遥控  旧的','New','Computer',0,0,'2011-08-07 20:00:38'),(100013,'罗技 890 新的','New','Computer',0,0,'2011-12-28 18:48:55'),(100014,'罗技 515遥控','New','Computer',3,0,'2012-03-14 21:29:31'),(100015,'罗技 525遥控 旧','New','Computer',0,0,'2011-05-05 02:16:25'),(100016,'罗技 628遥控 新 ','New','Computer',23,0,'2012-02-26 18:41:52'),(100017,'罗技 remote adapter US','New','Computer',54,0,'2012-03-25 04:46:52'),(100018,'罗技 harmony 880 890 cradle 旧','New','Computer',6,0,'2012-02-14 20:27:20'),(100019,'罗技 harmony 880 890 cradle 新','New','Computer',-1,0,'2012-03-18 19:45:00'),(100020,'罗技遥控电池 蓝色 新 950mah','New','Computer',9,0,'2012-03-25 05:06:35'),(100021,'罗技遥控电池 白色 旧 930mah','New','Computer',0,0,'2011-11-27 01:16:04'),(100022,'罗技遥控电池 白色  1250mah','New','Computer',0,0,'0000-00-00 00:00:00'),(100023,'diNovo 880 890电池 黑色 930mah新','New','Computer',5,0,'2011-09-14 03:53:19'),(100024,'罗技G7 鼠标电池 ','New','Computer',0,0,'2011-11-22 00:35:39'),(100025,'罗技G7 充电器 旧的','New','Computer',0,0,'2011-05-10 20:38:14'),(100026,'罗技遥控电池 蓝色 旧 950mah','New','Computer',1,0,'2011-11-06 19:05:46'),(100027,'Lenovo标志的罗技接收器','New','Computer',0,0,'2011-05-14 23:20:12'),(100028,'罗技 unifying receiver 优联','New','Computer',45,0,'2012-03-25 04:51:17'),(100029,'罗技 MX1000 mouse 翻新','New','Computer',-5,0,'2012-03-25 05:16:19'),(100030,'罗技 MX1000 蓝牙版 used','New','Computer',4,0,'2012-03-05 18:47:22'),(100031,'罗技 MX1000 电池','New','Computer',3,0,'2012-02-26 23:51:38'),(100032,'罗技H555头戴式耳机','New','Computer',1,0,'2012-03-01 21:00:36'),(100033,'罗技H530盒装耳机','New','Computer',0,0,'2011-04-30 21:45:43'),(100034,'MarantzRC3001型智能摇控','New','Computer',1,0,'2012-03-12 21:08:59'),(100035,'罗技 AIR mouse shell','New','Computer',3,0,'2012-03-07 01:19:06'),(100036,'logitech MX518 鼠标 new','New','Computer',8,0,'2011-08-30 22:49:32'),(100037,'logitech MX518 鼠标 used','New','Computer',-1,0,'2012-03-25 04:06:47'),(100038,'Altec Lansing im602 白色 US标 电源 全套','New','Computer',1,0,'2011-08-02 20:00:35'),(100039,'Altec Lansing T612','New','Computer',0,0,'2011-04-01 00:48:59'),(100040,'yagi antenna 16dBi','New','Computer',0,0,'2011-07-02 23:55:12'),(100041,'yagi antenna 18dBi','New','Computer',0,0,'2011-09-27 20:04:54'),(100042,'wifly-city IDU-2850UG-U20 plus','New','Computer',2,0,'2012-03-09 02:40:27'),(100043,'motorola S9 单机 红色','New','Computer',0,0,'0000-00-00 00:00:00'),(100044,'motorola S9 单机 黑色','New','Computer',0,0,'2011-05-26 19:34:46'),(100045,'motorola H3单机','New','Computer',10,0,'2011-12-28 21:14:40'),(100046,'motorola H300单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100047,'motorola H350单机','New','Computer',6,0,'2012-01-25 15:43:45'),(100048,'motorola H500单机 ','New','Computer',9,0,'2011-11-22 19:03:48'),(100049,'motorola H550单机','New','Computer',2,0,'2011-12-25 18:42:11'),(100050,'motorola H555单机','New','Computer',48,0,'2011-11-05 23:34:10'),(100051,'motorola H605单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100052,'motorola H670单机 黑色','New','Computer',18,0,'2011-12-26 19:16:42'),(100053,'motorola H700单机','New','Computer',23,0,'2012-01-18 19:50:56'),(100054,'motorola H700 黄金版','New','Computer',0,0,'2011-05-04 21:10:23'),(100055,'motorola H700盒装','New','Computer',0,0,'2011-05-16 19:26:42'),(100056,'motorola H710单机 used','New','Computer',4,0,'2011-12-21 02:37:19'),(100057,'motorola H721单机 used','New','Computer',0,0,'0000-00-00 00:00:00'),(100058,'motorola H800 单机','New','Computer',20,0,'2011-12-07 03:45:02'),(100059,'motorola HS810 单机 电源不同 绿色','New','Computer',27,0,'2012-01-03 00:47:21'),(100060,'motorola HS820 单机 电源不同 黑色 绿色','New','Computer',4,0,'2012-01-01 06:44:45'),(100061,'motorola HS850','New','Computer',43,0,'2011-12-27 18:43:53'),(100062,'motorola S705 ','New','Computer',12,0,'2011-12-25 02:20:14'),(100063,'Nokia BH-102  单机','New','Computer',0,0,'2011-12-10 21:25:50'),(100064,'Nokia BH-102 盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100065,'Nokia BH-103','New','Computer',5,0,'2012-03-22 19:46:56'),(100066,'Nokia BH-106','New','Computer',8,0,'2012-02-29 18:55:13'),(100067,'Nokia BH-200','New','Computer',33,0,'2012-03-25 04:35:29'),(100068,'Nokia BH-202单机','New','Computer',11,0,'2012-03-06 19:19:28'),(100069,'Nokia BH-203','New','Computer',1,0,'2012-03-20 22:03:17'),(100070,'Nokia BH-204','New','Computer',1,0,'2012-03-01 18:41:36'),(100071,'Nokia BH-205','New','Computer',3,0,'2012-01-17 23:38:05'),(100072,'nokia BH-207 全套 盒装','New','Computer',0,0,'2011-12-25 01:19:23'),(100073,'Nokia BH-209','New','Computer',4,0,'2011-08-28 07:16:38'),(100074,'nokia BH-300单机','New','Computer',1,0,'2012-01-17 19:05:44'),(100075,'nokia BH-302单机','New','Computer',0,0,'2012-03-13 19:23:44'),(100076,'nokia BH-500单机','New','Computer',0,0,'2012-02-05 01:19:55'),(100077,'nokia BH-600单机','New','Computer',4,0,'2012-03-06 18:21:41'),(100078,'nokia BH-800 单机','New','Computer',19,0,'2012-03-11 20:10:35'),(100079,'nokia BH-803','New','Computer',0,0,'0000-00-00 00:00:00'),(100080,'nokia BH-900单机','New','Computer',8,0,'2012-03-25 02:30:08'),(100081,'nokia BH-902 ','New','Computer',2,0,'0000-00-00 00:00:00'),(100082,'Nokia HS-3W','New','Computer',3,0,'2011-12-14 18:39:44'),(100083,'Nokia HS-4W','New','Computer',39,0,'2012-03-25 04:32:14'),(100084,'Nokia HS-11W 单机','New','Computer',19,0,'2012-03-04 01:59:55'),(100085,'Nokia HS-11W 盒装','New','Computer',0,0,'2011-06-25 23:20:59'),(100086,'Nokia HS-12W 单机','New','Computer',-1,0,'2012-03-06 18:24:50'),(100087,'Nokia HS-36W 单机 三星电源','New','Computer',5,0,'2012-02-09 19:17:30'),(100088,'Nokia HF-31W','New','Computer',0,0,'2011-05-22 19:44:37'),(100089,'samsung WEP200  盒装','New','Computer',2,0,'2011-07-02 23:11:19'),(100090,'索爱 HBH-600 深蓝 单机','New','Computer',0,0,'0000-00-00 00:00:00'),(100091,'索爱 HBH-608 盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100092,'索爱 HBH-608 单机','New','Computer',0,0,'2011-07-05 19:53:09'),(100093,'索爱 HBH-PV702','New','Computer',0,0,'2011-11-29 18:47:02'),(100094,'索爱 HBH-PV703','New','Computer',0,0,'2011-12-16 23:32:58'),(100095,'索爱 HBH-PV705','New','Computer',2,0,'2011-12-10 20:51:11'),(100096,'索爱 HBH-DS220 ','New','Computer',0,0,'2012-01-29 20:09:28'),(100097,'索爱 HBH-PV710','New','Computer',0,0,'2012-03-19 20:27:30'),(100098,'PLANTRONICS220 全新单机','New','Computer',1,0,'2011-12-25 19:31:37'),(100099,'PLANTRONICS320 单机+USB线','New','Computer',43,0,'2012-01-30 01:39:37'),(100100,'PLANTRONICS320 盒装','New','Computer',0,0,'2011-04-17 04:48:22'),(100101,'PLANTRONICS330 盒装','New','Computer',0,0,'2011-05-04 19:31:53'),(100102,'PLANTRONICS330 单机','New','Computer',11,0,'2011-12-27 18:33:34'),(100103,'PLANTRONICS340 盒装','New','Computer',0,0,'0000-00-00 00:00:00'),(100104,'PLANTRONICS340 单机','New','Computer',0,0,'2011-06-06 19:30:35'),(100105,'PLANTRONICS925 全新单机 ','New','Computer',8,0,'2011-12-20 23:23:13'),(100106,'PLANTRONIC 851 855','New','Computer',8,0,'2011-12-19 21:37:20'),(100107,'PLANTRONIC 510','New','Computer',3,0,'2011-11-29 21:52:39'),(100108,'PLANTRONIC 520','New','Computer',18,0,'2011-12-12 19:11:07'),(100109,'Plantronics Discovery 640E 全新盒装','New','Computer',1,0,'0000-00-00 00:00:00'),(100110,'PLANTRONICS VOYAGER PRO','New','Computer',0,0,'2012-01-10 02:18:27'),(100111,'捷波朗 Jabra BT250V  ','New','Computer',11,0,'2012-03-25 02:25:28'),(100112,'捷波朗 Jabra BT250','New','Computer',9,0,'2012-03-25 04:50:43'),(100113,'捷波朗 BT320S','New','Computer',8,0,'2012-02-21 18:37:22'),(100114,'艾美特 Ultimate170VI','New','Computer',7,0,'2012-03-18 03:23:53'),(100115,'艾美特 Ultimate220 ','New','Computer',12,0,'2012-03-22 19:45:22'),(100116,'艾美特 Ultimate220VI 带麦的','New','Computer',24,0,'2012-03-25 05:28:13'),(100117,'艾美特 UE 150','New','Computer',18,0,'2012-03-05 01:58:52'),(100118,'森海塞尔 CX 680','New','Computer',0,0,'2011-04-10 08:12:29'),(100119,'森海塞尔 CX 680i','New','Computer',0,0,'0000-00-00 00:00:00'),(100120,'森海塞尔 MX 680 带配件','New','Computer',0,0,'0000-00-00 00:00:00'),(100121,'森海塞尔 MX 680i','New','Computer',0,0,'2011-04-04 21:47:59'),(100122,'森海塞尔 OMX 680 带配件','New','Computer',0,0,'0000-00-00 00:00:00'),(100123,'森海塞尔 OMX 680I 带麦的','New','Computer',0,0,'0000-00-00 00:00:00'),(100124,'森海塞尔 CX280','New','Computer',0,0,'0000-00-00 00:00:00'),(100125,'森海塞尔 CX281','New','Computer',0,0,'0000-00-00 00:00:00'),(100126,'舒尔shure E2C   黑色','New','Computer',23,0,'2011-05-17 20:09:47'),(100127,'舒尔shure E2C  透明','New','Computer',0,0,'2011-05-18 20:14:47'),(100128,'HP 970012','New','Computer',6,0,'2011-10-03 19:44:48'),(100129,'ZAGG品牌电池 ','New','Computer',1,0,'2011-12-12 18:43:22'),(100130,'zagg 车充','New','Computer',18,0,'2012-03-18 19:24:43'),(100131,'WMN1000C','New','Computer',0,0,'2011-12-05 04:49:54'),(100132,'WMN1000B ','New','Computer',0,0,'2011-12-18 19:46:34'),(100133,'WMN1000A ','New','Computer',0,0,'2011-09-04 19:53:24'),(100134,'创新声卡SB1140','New','Computer',10,0,'2012-03-25 04:16:25'),(100135,'诺基亚 LD-3W ','New','Computer',0,0,'2011-12-26 18:42:57'),(100136,'雷凌（Ralink）RT2870F','New','Computer',0,0,'2011-09-15 19:46:51'),(100137,'雷凌（Ralink）RT2870F +CD 包装','New','Computer',0,0,'2011-05-10 20:26:12'),(100139,'Grohe Shower 高仪花洒','New','Computer',41,0,'2012-03-19 19:23:11'),(100140,'Grohe 高仪1.6米的水管','New','Computer',8,0,'2012-03-25 04:49:19'),(100141,'HP media center+remote+emitter','New','Computer',13,0,'2012-03-20 22:40:28'),(100142,'40-Pin 3.5\" to 44-Pin 2.5\" Laptop IDE Hard Drive Cable','New','Computer',36,0,'2012-03-01 01:09:29'),(100143,'IDE 44 Pin laptop 2.5\" Female Hard Drive Cable(2\"44pin)','New','Computer',45,0,'2012-03-22 21:04:51'),(100144,'40pin to 40pin male to female IDE cable ','New','Computer',56,0,'2012-03-16 01:59:00'),(100145,'VGA 转RJ45','New','Computer',144,0,'2012-03-22 20:08:00'),(100146,'LS-10DT canon太阳能计算器','New','Computer',32,0,'2012-03-18 01:34:25'),(100147,'INOVA(爱诺华) T4 手电 透镜版','New','Computer',0,0,'0000-00-00 00:00:00'),(100148,'INOVA(爱诺华) T4 手电 光杯版','New','Computer',0,0,'2011-05-25 20:29:12'),(100149,'INOVA(爱诺华) T4 手电 光杯版电池','New','Computer',0,0,'2012-01-08 18:57:38'),(100150,'光杯版手电充电器110-220V','New','Computer',6,0,'2011-11-07 18:40:30'),(100151,'JEEP 多功能钳 ','New','Computer',11,0,'2011-05-24 20:16:37'),(100152,'Philip HP8309 salonstraight','New','Computer',0,0,'2011-06-06 01:22:31'),(100153,'原装肯辛通 Kensington K64325 专家型轨迹球CAD制图专用','New','Computer',0,0,'2012-01-14 23:58:01'),(100154,'SONY UWA-BR100','New','Computer',0,0,'2011-06-19 20:30:53'),(100155,'SONY原装VGP-DA10 ','New','Computer',6,0,'2012-03-20 19:35:20'),(100156,'VISENTA V1无线键盘黑色','New','Computer',3,0,'2012-03-21 19:17:51'),(100157,'VISENTA V1无线键盘白色','New','Computer',1,0,'0000-00-00 00:00:00'),(100158,'IPAD 带皮套蓝牙键盘 黑色            ','New','Computer',0,0,'2011-05-04 19:59:40'),(100159,'IPAD 蓝牙键盘 白色                       ','New','Computer',0,0,'2011-04-04 06:49:11'),(100160,'apple G6 keyboard                     ','New','Computer',3,0,'2011-09-13 19:57:00'),(100161,'microsoft 8000 mouse','New','Computer',1,0,'2011-12-14 18:20:25'),(100162,'森松尼 SM-EM19 七绝魔蝎 7D鼠标    ','New','Computer',1,0,'0000-00-00 00:00:00'),(100163,'森松尼 SM-8509  5D 鼠标                ','New','Computer',1,0,'0000-00-00 00:00:00'),(100164,'Ajazz 黑爵 幻彩甲虫A1080 有线游戏鼠标 6D ','New','Computer',1,0,'0000-00-00 00:00:00'),(100165,'Sierra Wireless MC8775 通用版','New','Computer',0,0,'2011-12-14 18:25:54'),(100166,'Sierra Wireless MC8775 IBM版','New','Computer',17,0,'2012-02-29 18:38:52'),(100167,'Sierra Wireless MC8775 HP 版 new','New','Computer',0,0,'0000-00-00 00:00:00'),(100168,'Sierra Wireless MC8780 new GPS','New','Computer',10,0,'2012-03-22 01:19:26'),(100169,'Sierra Wireless MC8781 new  GPS','New','Computer',8,0,'2012-03-23 02:02:35'),(100170,'Sierra Wireless MC8790 new','New','Computer',21,0,'2012-03-18 19:09:33'),(100171,'F3507G 通用版 全新','New','Computer',10,0,'2012-03-15 19:35:48'),(100172,'F3507G IBM版 二手','New','Computer',0,0,'2011-11-23 04:24:30'),(100173,'Option GTM 380 new','New','Computer',0,0,'0000-00-00 00:00:00'),(100174,'Option GTM 382 new GPS','New','Computer',0,0,'2011-07-15 01:37:18'),(100175,'华为 EM660','New','Computer',0,0,'2011-06-08 03:16:51'),(100176,'华为EM770','New','Computer',0,0,'0000-00-00 00:00:00'),(100177,'华为EM770W','New','Computer',0,0,'2011-06-06 01:10:38'),(100178,'F3607GW 通用','New','Computer',2,0,'2012-03-10 23:20:53'),(100179,'半高卡架子 braket','New','Computer',8,0,'2012-03-14 03:53:59'),(100180,'3G wwan 天线','New','Computer',84,0,'2012-03-25 05:09:22'),(100181,'IBM X200 antenna','New','Computer',6,0,'2012-03-18 07:15:35'),(100182,'IBM X200T antenna','New','Computer',3,0,'2012-03-04 18:39:27'),(100183,'DWL-G122','New','Computer',0,0,'2011-05-24 19:43:33'),(100184,'apple airport 一代卡  旧','New','Computer',0,0,'2011-10-07 02:35:15'),(100185,'apple airport extreme 二代卡 旧','New','Computer',13,0,'2012-03-05 18:33:38'),(100186,'apple airport extreme 二代卡新的','New','Computer',27,0,'2012-03-18 07:00:07'),(100187,'apple adapter ','New','Computer',13,0,'2012-01-29 20:10:02'),(100188,'apple 4321','New','Computer',0,0,'2011-08-16 04:08:04'),(100189,'apple 4322  BCM94322MC 旧的','New','Computer',0,0,'0000-00-00 00:00:00'),(100190,'apple 4322 BCM94322MC 新的','New','Computer',0,0,'0000-00-00 00:00:00'),(100191,'apple AR9280 AR5BXB92','New','Computer',30,0,'2012-03-19 20:03:57'),(100192,'apple USB 猫 旧 2针 旧的','New','Computer',0,0,'2011-11-14 18:54:40'),(100193,'apple mighty mouse 新','New','Computer',65,0,'2012-03-25 05:25:42'),(100194,'apple Ipad dock','New','Computer',0,0,'2011-08-22 20:21:21'),(100195,'intel 622AGXHMW','New','Computer',4,0,'2012-03-14 02:16:53'),(100196,'IBM 6250 ANX','New','Computer',2,0,'2012-02-05 18:56:39'),(100197,'dell 4321','New','Computer',5,0,'2012-03-04 19:34:39'),(100198,'DELL 1510','New','Computer',31,0,'2012-03-25 03:13:47'),(100199,'DW 1520 半高 旧的','New','Computer',0,0,'2011-04-10 07:48:54'),(100200,'HP 4322 二手 BCM94322MC 全高  ','New','Computer',0,0,'0000-00-00 00:00:00'),(100201,'broadcom 半高4322','New','Computer',6,0,'0000-00-00 00:00:00'),(100202,'HP版 BCM4322半高卡 ','New','Computer',17,0,'2012-03-25 02:22:17'),(100203,'atheros 5008 新','New','Computer',23,0,'2012-03-18 19:11:42'),(100204,'atheros 5008 旧','New','Computer',0,0,'2011-04-11 00:15:16'),(100205,'IBM AR5008','New','Computer',8,0,'2012-03-20 19:42:07'),(100206,'HP AR5008','New','Computer',9,0,'2011-12-10 21:28:24'),(100207,'atheros 5424  IBM','New','Computer',8,0,'2012-03-01 19:04:32'),(100208,'atheros 5213A  IBM','New','Computer',5,0,'2012-03-19 20:23:15'),(100209,'AR9287','New','Computer',13,0,'2012-03-07 19:02:23'),(100210,'AR5B93 半高 新','New','Computer',44,0,'2012-03-25 04:14:17'),(100211,'AR5B95 半高 新 AR9285','New','Computer',41,0,'2012-03-25 02:18:29'),(100212,'atheros 9281 新','New','Computer',11,0,'2012-03-11 20:13:28'),(100213,'intel 4965','New','Computer',0,0,'0000-00-00 00:00:00'),(100214,'intel 5150半高 正式 新','New','Computer',0,0,'2011-07-25 04:01:38'),(100215,'intel 5150 通用全高','New','Computer',0,0,'0000-00-00 00:00:00'),(100216,'intel 5150 全高 IBM版','New','Computer',7,0,'0000-00-00 00:00:00'),(100217,'intel 5350 正式版 IBM','New','Computer',0,0,'0000-00-00 00:00:00'),(100218,'intel 5100 半高卡 ','New','Computer',0,0,'2011-06-12 19:37:20'),(100219,'intel 5300半高  正式 新','New','Computer',0,0,'2011-07-25 22:47:26'),(100220,'intel 5300 全高卡 正式 新','New','Computer',10,0,'2012-03-25 04:17:02'),(100221,'intel 5300 全高卡 IBM ','New','Computer',7,0,'2012-03-18 02:50:32'),(100222,'intel 5350 ','New','Computer',7,0,'2012-02-01 18:37:36'),(100223,'Marvell 88W8363 通用版','New','Computer',17,0,'2012-03-20 20:10:34'),(100224,'Powchip POW-N18','New','Computer',0,0,'2011-11-20 18:39:50'),(100225,'2.0单独模块','New','Computer',11,0,'2012-01-07 22:59:55'),(100226,'Dell mini 9','New','Computer',-8,0,'2012-03-13 04:18:02'),(100227,'Dell mini10 10v 1010 1011','New','Computer',0,0,'2012-03-11 20:11:59'),(100228,'gateway P-7811 P-7805U P-7801U','New','Computer',6,0,'2011-04-01 19:36:37'),(100229,'S10  OEM','New','Computer',2,0,'2012-03-25 02:38:18'),(100230,'S10-2 8pin 1.0 8cm 五线连接','New','Computer',2,0,'2012-02-26 00:41:56'),(100231,'华硕10pin 0.8 6cm (A8/Z99/F8/N80/U5/U6/EEEPC1101HA/EEEPC1005/W5F)','New','Computer',-3,0,'2012-03-22 19:32:22'),(100232,'华硕10pin 0.8 10cm (V1S/E99/F8/N80)','New','Computer',1,0,'2011-12-17 00:29:39'),(100233,'华硕 10pin 1.0 15cm (F5/Z53/F3/M51/G50)','New','Computer',5,0,'2011-10-27 03:42:22'),(100234,'华硕 10 pin 1.0 5cm ( epc901 epc1000)','New','Computer',3,0,'2012-02-05 18:52:15'),(100235,'华硕 8pin 1.0 6cm (G1S/A6/Z92)','New','Computer',-1,0,'2012-03-06 23:15:58'),(100236,'acer 4pin 1.25 3cm (Timeline 4810 4810T 5810 3820T)','New','Computer',5,0,'2011-11-07 18:45:04'),(100237,'acer 4pin1.25 4cm (AS 5540 5542, 5560 5562, 5590 5595 )','New','Computer',2,0,'2011-09-11 22:53:50'),(100238,'acer 4pin1.25 5cm (As 4310 4310G 4710 4710G 4920 4920G)','New','Computer',5,0,'0000-00-00 00:00:00'),(100239,'acer 4pin1.25 6cm(T M 4720 4320 Extensa 4620 4620z 4220， Aspire 7738G 5740 8730 7738 7740)','New','Computer',0,0,'2012-03-22 19:38:20'),(100240,'acer 4pin1.25 8cm (AS 5235 5335 5535 5735 5735Z 5738Z 5338)','New','Computer',2,0,'2012-03-25 02:16:39'),(100241,'acer 4pin1.25 15cm (TravelMate 5720 5720G 5320, Extensa 5420 5420G  5220, 5620, 5620Z Aspire 5550 5551 5552)','New','Computer',3,0,'2012-03-01 19:06:29'),(100242,'Acer  4pin 1.25 15cm （aspire D250）薄型黑色头','New','Computer',9,0,'0000-00-00 00:00:00'),(100243,'acer 4pin1.25 18cm  (AS 9410 9411 9420 9423 9424 7110 7000 9300 Travelmate  5110 5610 5620 7510 7512 7513 7514)','New','Computer',0,0,'2012-02-20 02:00:32'),(100244,'acer 4pin1.25 20cm (TM 5520 5530)','New','Computer',12,0,'2011-10-15 06:31:38'),(100245,'acer 5pin 1.25 3cm ( Aspire Timeline 1810 1410 1410T)','New','Computer',0,0,'2012-03-19 19:53:15'),(100246,'acer 5pin1.25 4cm (AS 4230 4530 7730 7730g 7730Z Travelmate 7730 7730A ','New','Computer',4,0,'2012-03-21 19:34:37'),(100247,'acer 5pin1.25 6cm   (AS 6930 6530 6530G 6930G Extensa 5235) ','New','Computer',-13,0,'2012-03-20 22:30:11'),(100248,'acer 5pin1.25 15cm (AS 5920 5920G)','New','Computer',-5,0,'2012-03-13 03:48:30'),(100249,'acer 5pin1.25 20cm (4720 4720G 4720Z 4320 4220 4220G 4520 4520G AO751h)','New','Computer',-1,0,'2012-03-01 00:04:49'),(100250,'acer 6pin1.25 23cm (AS 3680 5580 5570 5570z 5050 ) ','New','Computer',-13,0,'2012-03-14 19:28:55'),(100251,'acer 8pin0.8 16cm   (AS 6920 6920G 6935 6935G)','New','Computer',0,0,'2012-02-05 19:02:10'),(100252,'acer 8pin1.0 3cm (AS 3810 3810T)','New','Computer',1,0,'2011-12-09 00:37:53'),(100253,'acer 8pin 1.0 (4连线）5cm aspire  D150 ','New','Computer',2,0,'2011-12-07 19:26:55'),(100254,'acer 8pin1.00 6cm  (AS 4730 4930 4730G 4930G 4730z 4930z)','New','Computer',8,0,'2012-01-12 18:53:19'),(100255,'acer 8pin1.00 6cm （AS 8920 8920G 8930) 线序不同','New','Computer',2,0,'0000-00-00 00:00:00'),(100256,'acer 8pin1.00 8cm (AS 5100 5110 3100  5680 5630 3690 TravelMate 5210 5510 2400 3210 3220 3230 4280 4230 2490. Extensa 5010 5410)','New','Computer',-3,0,'2012-02-26 00:32:55'),(100257,'acer 8pin1.00 15cm (AS 5620 5672 5720 5720G 5220 5220G 5310 5310G 5710 5710G 7720 7720G 7720Z )','New','Computer',2,0,'2012-03-18 19:08:17'),(100258,'acer 8pin1.00 18cm (AS 5520 5520G 5530 )','New','Computer',1,0,'2012-03-13 19:22:40'),(100259,'acer 8pin1.25 10cm (TM 3000 3020 3040 TM3002  TravelMate 4210 4270 4670 AS5760 )','New','Computer',3,0,'2012-03-10 22:41:01'),(100260,'acer 8pin1.25 35cm (Aspire 3500 )','New','Computer',1,0,'0000-00-00 00:00:00'),(100261,'HP 8pin 1.0 3cm  (HP Compaq nw8000 nc8230 nw8240 nw8440 \nHP mini 2133 2140\nHP Compaq NX7300 NX7400)','New','Computer',-3,0,'2012-03-18 03:28:49'),(100262,'HP 8pin 1.0 3cm 线序反 (HP Pavilion zd8000, Compaq Presario x6000, HP Compaq nx9600)','New','Computer',2,0,'0000-00-00 00:00:00'),(100263,'\nHP 8pin 1.0 12cm (Pavilion DV2000 DV2100 DV2200 DV2500 DV2600 DV2700 DV2800 DV2900\nPavilion DV8000 DV8100 DV8200 DV8300 DV8400\nPresario V4000 V4100 V4200 V4400\nPresario V3000 V3100 V3400 V3600)','New','Computer',1,0,'2011-09-06 20:44:40'),(100264,'HP 8pin 1.0 18cm 4线连 (HP ProBook 4410S 4411S 4415S 4416S 4510S 4515S 4710S)','New','Computer',4,0,'2011-11-05 22:47:57'),(100265,'HP 8pin 1.0 20cm (HP Compaq nc6220 nc6230 8710w nw9440 nx9420)','New','Computer',1,0,'2011-09-04 04:29:54'),(100266,'HP 8pin 1.0 20cm 线序反的 (HP Compaq NC6320 NC6400)','New','Computer',5,0,'0000-00-00 00:00:00'),(100267,'HP 8pin 1.0 23cm (NC4200 NC4400 TC4200 TC4400 Compaq Presario CQ45, HP Pavilion DV4 Pavilion DV7\nDV5000 V5000','New','Computer',-7,0,'2012-03-04 18:54:02'),(100268,'HP 8pin 1.0 25cm 4线连 (HP Compaq 6530S 6531S 6535S)','New','Computer',4,0,'0000-00-00 00:00:00'),(100269,'HP 8pin 1.25 3cm (HP Pavilion ZE2000 ZE2200 ZE2300 ZE2500\nHP Pavilion DV1000 DV1100 DV1300 DV1500 DV1600 DV1700\nCompaq Presario V2000 V2100 V2200 V2300 V2400 V2600 M2000 M2200 M2500)','New','Computer',2,0,'0000-00-00 00:00:00'),(100270,'HP 8pin 1.25 18cm (Pavilion DV6000 DV6000t DV6000z DV6100 DV6200 \nDV6300 DV6400 DV6500 DV6500t DV6500z \nDV6700 DV6700t DV6700z DV6800 DV6900)','New','Computer',6,0,'2012-03-08 18:26:48'),(100271,'HP 8pin 1.25 25cm (Pavilion DV9000 DV9000Z DV9100 DV9200 DV9800 DV9900\nDV9500 DV9500t DV9500z DV9700 DV9700t DV9700z )','New','Computer',-10,0,'2012-03-06 18:47:25'),(100272,'HP 8pin 0.8 3cm (Presario TX1000 TX1000z TX1200 TX2000 TX2000z TX2015 TX2500 TX2500z TX2z)','New','Computer',-2,0,'2012-03-07 19:06:04'),(100273,'HP 6pin 1.0 12cm (Pavilion DV5 HDX X16)','New','Computer',6,0,'2012-03-11 20:23:37'),(100274,'??','New','Computer',0,0,'0000-00-00 00:00:00'),(100275,'benq s31/s32/t31','New','Computer',1,0,'0000-00-00 00:00:00'),(100276,'benq s41/s42','New','Computer',1,0,'0000-00-00 00:00:00'),(100277,'benq s61','New','Computer',1,0,'0000-00-00 00:00:00'),(100278,'benq r55','New','Computer',1,0,'2011-07-06 02:57:56'),(100279,'samsung r40/r70/r45','New','Computer',0,0,'2011-11-12 02:49:34'),(100280,'samsung r453','New','Computer',1,0,'0000-00-00 00:00:00'),(100281,'samsung r18/r25/r20','New','Computer',0,0,'2012-02-17 19:04:15'),(100282,'samsung nc10/nd10/nc20  4pin 1.25 R620 N110 N120 N140','New','Computer',-2,0,'2012-03-25 03:10:58'),(100283,'samsung q1/q1u','New','Computer',8,0,'2011-12-25 02:35:16'),(100284,'samsung x11','New','Computer',1,0,'0000-00-00 00:00:00'),(100285,'samsung x9','New','Computer',1,0,'0000-00-00 00:00:00'),(100286,'2.1单独模块','New','Computer',3,0,'2011-12-27 18:45:13'),(100287,'Dell mini 9 J613H','New','Computer',5,0,'2012-03-06 18:33:06'),(100288,'Dell mini10 10v 1010 1011','New','Computer',0,0,'2012-02-26 00:47:24'),(100289,'gateway P-7811 P-7805U P-7801U','New','Computer',5,0,'2012-02-07 19:42:19'),(100290,'S10  OEM','New','Computer',17,0,'2011-10-20 01:07:51'),(100291,'S10-2 8pin 1.0 8cm 五线连接','New','Computer',1,0,'2012-03-08 19:12:12'),(100292,'acer 4pin1.25 3cm (Timeline 4810 5810)','New','Computer',4,0,'2011-12-12 18:31:41'),(100293,'acer 4pin1.25 4cm (AS 5540 5542, 5560 5562, 5590 5595 )','New','Computer',5,0,'2012-03-20 19:37:13'),(100294,'acer 4pin1.25 5cm (As 4310 4310G 4710 4710G 4920 4920G)','New','Computer',4,0,'0000-00-00 00:00:00'),(100295,'acer 4pin1.25 6cm (TM 4720 4320 Extensa 4620 4620z 4220 4200，Aspire 7738G 5740 8730 7735 7738 7740)','New','Computer',0,0,'2012-03-11 20:07:04'),(100296,'acer 4pin1.25 8cm (AS 5235 5335 5535 5735 5735Z 5738Z 5338 5536 5236 5536G)','New','Computer',4,0,'2012-03-12 19:19:58'),(100297,'acer 4pin1.25 15cm (TravelMate 5720 5720G 5320, Extensa 5420 5420G  5220, 5620, 5620Z Aspire 5550 5551 5552)','New','Computer',-9,0,'2012-02-01 19:45:27'),(100298,'Acer 4pin 1.25 15cm （aspire D250）薄型黑色头','New','Computer',4,0,'2011-07-28 20:26:17'),(100299,'acer 4pin1.25 18cm  (AS 9410 9411 9420 9423 9424 7110 7000 9300 Travelmate  5110 5610 5620 7510 7512 7513 7514)','New','Computer',0,0,'2012-03-20 19:44:12'),(100300,'acer 4pin1.25 20cm (TM 5520 5530)','New','Computer',1,0,'2012-03-22 19:28:39'),(100301,'acer 5pin 1.0 3cm （AS 4745 4820T）','New','Computer',5,0,'2012-02-14 21:10:47'),(100302,'Acer 5pin1.25 3cm ( Aspire Timeline 1810 1410 1410T 1810T 1810TZ) ','New','Computer',-15,0,'2012-02-20 02:45:23'),(100303,'acer 5pin1.25 4cm (AS 4230 4530 7730 7730g 7730Z Travelmate 7730 7730A ','New','Computer',5,0,'2011-09-12 04:30:56'),(100304,'acer 5pin1.25 6cm   (AS 6930 6530 6530G 6930G Extensa 5235) ','New','Computer',0,0,'2012-02-05 00:16:05'),(100305,'acer 5pin1.25 15cm (AS 5920 5920G)','New','Computer',1,0,'2012-01-29 20:07:16'),(100306,'acer 5pin1.25 20cm (AS 4720 4720G 4720Z 4320 4220 4220G 4520 4520G AO751h)','New','Computer',5,0,'2012-03-10 23:18:51'),(100307,'acer 6pin1.25 23cm (AS 3680 5580 5570 5570z 5050 ) ','New','Computer',-2,0,'2012-01-15 05:27:59'),(100308,'acer 8pin0.8 16cm   (AS 6920 6920G 6935 6935G)','New','Computer',-1,0,'2011-11-02 20:15:43'),(100309,'acer 8pin1.0 3cm (AS 3810 3810T, Timeline 3810 3810T)','New','Computer',6,0,'2012-02-12 03:54:29'),(100310,'acer 8pin 1.0 5cm (4连线） aspire D150 ','New','Computer',4,0,'2011-08-14 19:44:25'),(100311,'acer 8pin1.0 6cm  (AS 4730 4930 4730G 4930G 4730z 4930z)','New','Computer',10,0,'2011-07-24 21:45:23'),(100312,'acer 8pin1.00 6cm （AS 8920 8920G 8930 ) 线序不同','New','Computer',11,0,'2012-02-02 20:10:24'),(100313,'acer 8pin1.00 8cm (AS 5100 5110 3100  5680 5630 3690 TravelMate 5210 5510 2400 3210 3220 3230 4280 4230 2490. Extensa 5010 5410)','New','Computer',21,0,'2012-02-01 19:18:47'),(100314,'acer 8pin1.00 10cm （AS4740）','New','Computer',2,0,'2012-03-25 03:29:05'),(100315,'acer 8pin1.00 15cm (AS 5620 5672 5720 5720G 5220 5220G 5310 5310G 5710 5710G 7720 7720G 7720Z  TravelMate 4210 4270 4670)','New','Computer',-1,0,'2012-02-26 00:57:02'),(100316,'acer 8pin1.00 18cm (AS 5520 5520G 5530 )','New','Computer',4,0,'2012-03-10 23:16:15'),(100317,'acer 8pin1.25 10cm (TM 3000 3020 3040 TM3002  TravelMate 4210 4270 4670 AS5760 )','New','Computer',3,0,'2011-05-14 04:49:16'),(100318,'acer 8pin1.25 35cm (Aspire 3500 )','New','Computer',2,0,'0000-00-00 00:00:00'),(100319,'HP 8pin 1.0 3cm  (HP Compaq nw8000 nc8230 nw8240 nw8440 \nHP mini 2133 2140\nHP Compaq NX7300 NX7400)','New','Computer',-4,0,'2012-03-18 01:13:08'),(100320,'HP 8pin 1.0 3cm 线序反 (HP Pavilion zd8000, Compaq Presario x6000, HP Compaq nx9600)','New','Computer',-3,0,'2012-02-29 02:14:04'),(100321,'HP 8pin 1.0 12cm (Pavilion DV2000 DV2100 DV2200 DV2500 DV2600 DV2700 DV2800 DV2900\nPavilion DV8000 DV8100 DV8200 DV8300 DV8400\nPresario V4000 V4100 V4200 V4400\nPresario V3000 V3100 V3400 V3600)','New','Computer',1,0,'2011-11-06 18:51:47'),(100322,'HP 8pin 1.0 18cm 4线连 (HP ProBook 4410S 4411S 4415S 4416S 4510S 4515S 4710S)','New','Computer',7,0,'2011-08-13 23:51:30'),(100323,'HP 8pin 1.0 20cm (HP Compaq nc6220 nc6230 8710w nw9440 nx9420)','New','Computer',9,0,'2012-03-13 21:17:07'),(100324,'HP 8pin 1.0 20cm 线序反的 (HP Compaq NC6320 NC6400)','New','Computer',4,0,'2011-12-10 20:51:59'),(100325,'HP 8pin 1.0 23cm (NC4200 NC4400 TC4200 TC4400 Compaq Presario CQ45, HP Pavilion DV4 Pavilion DV7\nDV5000 V5000','New','Computer',-9,0,'2012-03-10 23:10:02'),(100326,'HP 8pin 1.0 25cm 4线连 (HP Compaq 6530S 6531S 6535S)','New','Computer',6,0,'0000-00-00 00:00:00'),(100327,'HP 8pin 1.25 3cm (HP Pavilion ZE2000 ZE2200 ZE2300 ZE2500\nHP Pavilion DV1000 DV1100 DV1300 DV1500 DV1600 DV1700\nCompaq Presario V2000 V2100 V2200 V2300 V2400 V2600 M2000 M2200 M2500)','New','Computer',4,0,'2011-09-18 19:50:22'),(100328,'HP 8pin 1.25 18cm (Pavilion DV6000 DV6000t DV6000z DV6100 DV6200 \nDV6300 DV6400 DV6500 DV6500t DV6500z \nDV6700 DV6700t DV6700z DV6800 DV6900)','New','Computer',-7,0,'2012-03-13 22:17:59'),(100329,'HP 8pin 1.25 25cm (Pavilion DV9000 DV9000Z DV9100 DV9200 DV9800 DV9900\nDV9500 DV9500t DV9500z DV9700 DV9700t DV9700z )','New','Computer',7,0,'2011-12-27 18:39:31'),(100330,'HP 8pin 0.8 3cm (Presario TX1000 TX1000z TX1200 TX2000 TX2000z TX2015 TX2500 TX2500z TX2z)','New','Computer',8,0,'2012-02-22 18:59:55'),(100331,'HP 6pin 1.0 12cm (Pavilion DV5 HDX X16)','New','Computer',1,0,'2012-03-20 02:28:07'),(100332,'3.0单独模块','New','Computer',6,0,'2012-02-20 02:23:40'),(100333,'HP 5pin1.0 20cm (CQ42，G42)','New','Computer',0,0,'2012-02-21 18:47:23'),(100334,'HP 6pin1.0 3cm (probook 4321s 4421s 4325s 4326s \n4425s 5220m MINI311) ','New','Computer',-4,0,'2012-02-20 18:59:34'),(100335,'Hp 8pin1.0 3cm (mini5101 mini5102)','New','Computer',1,0,'2012-02-09 18:54:13'),(100336,'HP 8pin1.0 8cm ( 5310M) \n','New','Computer',-1,0,'2012-03-15 19:46:16'),(100337,'HP 8pin1.0 18cm (probook 4311s )','New','Computer',4,0,'2011-10-19 20:11:38'),(100338,'AKE BC168','New','Computer',5,0,'2012-03-10 22:51:11'),(100339,'AKE BC188 ','New','Computer',13,0,'2012-03-05 23:17:11'),(100340,'AKE BC268 四口','New','Computer',0,0,'2011-04-08 01:18:28'),(100341,'IBM Thinkpad 2nd HDD Caddy for T40 T60 ','New','Computer',0,0,'2011-07-19 19:36:59'),(100342,'DVD slim for T40','New','Computer',0,0,'2011-07-16 00:09:41'),(100343,'apple HDD caddy','New','Computer',-5,0,'2012-03-25 03:40:52'),(100344,'AuthenTec 指纹仪 指纹加密识别器','New','Computer',20,0,'2012-03-15 00:09:30'),(100345,'APC Password Fingerprint Manager USB','New','Computer',0,0,'2011-08-03 00:17:41'),(100346,'APC UPB50','New','Computer',1,0,'0000-00-00 00:00:00'),(100347,'PVDM-256K-4','New','Computer',0,0,'2011-10-13 03:40:28'),(100348,'PVDM-256K-8','New','Computer',0,0,'2011-11-06 19:02:56'),(100349,'PVDM-256K-12','New','Computer',0,0,'2011-10-24 19:25:07'),(100350,'PVDM2-8','New','Computer',0,0,'0000-00-00 00:00:00'),(100351,'PVDM2-16','New','Computer',0,0,'2012-01-09 19:10:06'),(100352,'PVDM2-32','New','Computer',0,0,'2011-06-08 19:58:33'),(100353,'HJ-112','New','Computer',0,0,'2011-10-20 20:16:31'),(100354,'tyco antenna*2','New','Computer',33,0,'2012-03-25 02:22:17'),(100355,'tyco antenna*3','New','Computer',-1,0,'2012-03-23 02:25:30'),(100357,'APPLE天线','New','Computer',0,0,'2011-04-12 19:51:06'),(100358,'罗技USB线','New','Computer',45,0,'2012-03-25 05:12:00'),(100359,'缤特力车充','New','Computer',85,0,'2011-07-18 19:30:45'),(100360,'缤特力车充','New','Computer',100,0,'0000-00-00 00:00:00'),(100361,'MOTOV3车充','New','Computer',70,0,'2012-01-02 00:27:46'),(100362,'MOTOV8车充','New','Computer',100,0,'0000-00-00 00:00:00'),(100363,'诺记亚细头车充','New','Computer',43,0,'2012-03-13 22:19:06'),(100364,'apple 8GB USB FLASH DRIVE','new','computer',11,100,'2012-03-25 02:19:22'),(100365,'apple 8GB install driver','new','computer',0,100,'2012-02-21 18:30:47'),(100366,'Logitech IO notebook','new','computer',16,15,'2012-03-11 01:59:33'),(100367,'PLANTRONIC Calisto pro','new','computer',5,70,'2012-01-15 18:34:15'),(100368,'3M 9322 respirator','new','computer',2,28,'2011-12-13 23:34:13'),(100369,'FY-II audible radiometer ','new','computer',1,598,NULL),(100370,'nokia BH-700单机 ','new','computer',0,55,'2012-03-22 20:09:56'),(100371,'索爱 HBH-DS200  欧标电源','new','computer',9,150,'2011-09-12 04:10:59'),(100372,'logitech nano receiver','new','computer',25,35,'2012-03-25 04:32:38'),(100373,'VISENTA i0 mouse','new','computer',3,50,'2011-04-17 08:59:29'),(100374,'VISENTA i4 mouse','new','computer',3,57,'2011-12-07 19:10:49'),(100375,'VISENTA i5 mouse ','new','computer',0,99,'2011-12-01 20:33:11'),(100376,'VISENTA i6 mouse  ','new','computer',4,60,NULL),(100377,'罗技 890 extender ','used','computer',18,85,'2012-02-26 04:31:29'),(100378,'VGA 转RJ45 white','new','computer',127,3.5,'2012-03-25 05:14:20'),(100379,'Lenovo 4337 笔记本扩展坞','new','computer',0,250,'2011-09-26 20:04:17'),(100380,'logitech MX518 鼠标new 华硕限量版','new','computer',1,120,'2011-12-07 18:52:25'),(100381,'2.8\'\' 4G MP4  黑/白 ','new','computer',0,145,'2011-08-04 20:20:45'),(100382,'HP media centre+big receiver+emitter','new','computer',27,50,'2012-03-25 04:10:11'),(100383,'Logitech 890 emitter 单头','new','computer',187,5,'2012-02-26 04:31:29'),(100384,'intel 6250 622ANXHMW 通用','new','computer',34,180,'2012-03-25 05:13:51'),(100385,'HP midia centre+emitter','new','computer',17,32,'2012-03-25 04:49:48'),(100386,'micorsoft 极动鲨 mouse black','new','computer',39,40,'2012-03-25 05:15:42'),(100387,'TP-LINK TL-WN821N ','new','computer',5,84,'2012-03-18 02:54:36'),(100388,'NOKIA SU-8W bluetooth keyboard','new','computer',5,265,'2011-11-09 18:39:01'),(100389,'ESI maya44 声卡','new','computer',5,195,'2012-03-25 04:58:14'),(100390,'Jabra JX10 headset black','new','computer',0,50,'2012-01-15 18:32:27'),(100391,'plantronics BUA-100 receiver','new','computer',1,23,'2011-10-24 19:47:34'),(100392,'logitech IO 数码笔','new','computer',5,95,'2012-03-11 19:34:52'),(100393,'WMN2000B','new','computer',1,250,'2011-12-07 19:13:49'),(100394,'Samsung SSG-2100AB 3D眼镜 ','new','computer',38,200,'2012-03-25 05:26:14'),(100395,'BCM94313 BCM2070  无线蓝牙二合一','new','computer',28,35,'2012-03-21 20:03:27'),(100396,'sony TDG-BR100 3D glasses','new','computer',0,399,'2011-11-06 18:44:50'),(100397,'DENON RC-969遥控','new','computer',2,158,'2011-08-10 19:43:06'),(100398,'罗技M950鼠标外壳  ','new','computer',13,50,'2012-03-18 19:33:52'),(100399,'罗技M705鼠标外壳  ','new','computer',12,30,'2012-02-01 18:40:33'),(100400,'罗技MX518鼠标外壳   ','new','computer',9,32,'2012-03-14 19:22:29'),(100401,'罗技M905鼠标外壳 ','new','computer',10,40,'2012-03-19 01:58:26'),(100402,'罗技G500鼠标外壳','new','computer',0,40,'2011-07-30 21:32:07'),(100403,'AUI Transceiver 210TS new in box','new','computer',0,40,'2011-06-11 09:48:29'),(100404,'捷波朗 Jabra BT2080 box','new','computer',0,50,'2011-08-24 19:45:53'),(100405,'samsung SSG-P2100S 3D glasses box','new','computer',0,470,'2011-06-02 19:45:08'),(100406,'samsung SSG-2200KR 3D眼镜 box','new','computer',1,330,'2011-08-02 19:26:59'),(100407,'FireFly keyboard','new','computer',3,95,'2012-03-21 19:33:23'),(100408,'samsung WEP200 box black','new','computer',0,50,'2012-01-31 22:09:03'),(100409,'samsung 3D Blu-ray 3 imax','new','computer',0,10,'2011-11-30 19:02:34'),(100410,'Jabra BT125','new','computer',0,35,'2011-11-28 19:41:16'),(100411,'Jabra BT135 ','new','computer',0,38,'2012-02-07 19:43:04'),(100412,'Jabra BT800  ','new','computer',0,80,'2011-08-24 19:39:04'),(100413,'Jabra 9460 box','new','computer',3,600,'2012-03-04 21:40:24'),(100414,'PLANTRONIC headset 903','new','computer',24,160,'2012-01-02 00:25:01'),(100415,'plantronics backbeat adapter','new','computer',4,60,'2012-01-17 19:45:34'),(100416,'Philips SHB6102 澳标','new','computer',0,210,'2012-03-04 23:31:30'),(100417,'ASUS N554 bluetooth mouse','new','computer',0,60,'2012-03-22 19:38:50'),(100418,'linksys  DMP-100 ','new','computer',1,330,'2012-02-12 00:04:18'),(100419,'samsung  wep250 ','new','computer',8,35,'2012-02-29 19:11:21'),(100420,'samsung  wep300','new','computer',0,45,'2012-01-12 18:49:23'),(100421,'Nokia BH-103 盒装','New','computer',0,95,'2011-12-21 18:49:14'),(100422,'motorola H710 new','new','computer',6,80,'2012-01-18 17:50:56'),(100423,'sony TDG-BR250 3D glasses','new','computer',50,280,'2012-03-25 05:26:48'),(100424,'samsung SSG-P2100X  3D眼镜 box','new','computer',0,450,NULL),(100425,'Grohe 高仪 花洒座 ','new','computer',19,40,'2012-03-15 20:07:29'),(100426,'罗技 USB receiver no shell','new','computer',0,18,'2012-02-12 18:44:08'),(100427,'Logitech MX revolution mouse 简装 used','used','computer',1,50,'2012-02-09 22:48:01'),(100428,'Plantronics 610 单机','new','computer',0,25,'2011-06-06 01:36:30'),(100429,'兼容型3D眼镜 通用型','new','computer',264,190,'2012-03-25 04:57:43'),(100430,'兼容型3D眼镜接收器 ','new','computer',0,190,'2012-02-05 19:31:49'),(100431,'Griffin car charger','new','computer',-1,26,'2011-11-01 05:21:17'),(100432,'fire-pad','new','computer',9,0,'2012-03-25 03:16:55'),(100433,'Samsung G2 portable Hard drive 320G','new','computer',0,288,'2011-11-21 20:08:04'),(100434,'罗技 M215 mouse','new','computer',7,79,'2011-08-20 21:14:43'),(100435,'罗技 M505 mouse','new','computer',1,135,'2012-02-21 18:54:11'),(100436,'PLANTRONIC 851 855 used','new','computer',2,100,'2011-12-05 19:19:13'),(100437,'Microsoft MOD IE3.0X06 SK mouse','new','computer',0,120,'2011-09-01 02:12:21'),(100438,'罗技 MX1000 mouse used','used','computer',1,60,'2011-11-23 18:47:23'),(100439,'IBM AR5008 box','new','computer',0,80,'2011-10-16 04:29:33'),(100440,'雷凌（Ralink）RT2870F chip','new','computer',0,50,'2011-11-15 18:59:29'),(100441,'samsung SSG-2200AR  3D眼镜 box','new','computer',0,400,'2011-09-28 21:05:17'),(100442,'JBL Reference 220 headset','new','computer',7,21,'2012-01-04 19:07:53'),(100443,'amazon adapter for apple ','new','computer',29,15,'2012-01-15 00:47:10'),(100444,'AKG Q460 headset','new','computer',3,260,'2011-08-08 19:36:21'),(100445,'WMN1000A OEM','new','computer',-3,80,'2012-03-01 18:48:16'),(100446,'WMN1000B OEM','new','computer',7,80,'2012-03-23 01:52:43'),(100447,'Nokia BH-100','new','computer',4,32,'2012-03-08 18:21:51'),(100448,'3D Blu-ray Monster vs Aliens','new','computer',1,35,'2011-12-01 20:49:29'),(100449,'兼容型3D眼镜  显示器 专用','new','computer',6,190,'2012-02-05 19:31:49'),(100450,'兼容型3D眼镜  samsung 专用','new','computer',0,160,'2011-11-06 19:22:46'),(100451,'3D Blu-ray AVATAR','new','computer',29,180,'2011-09-05 02:01:01'),(100455,'logitech 890 pro shell','new','computer',29,50,'2012-03-15 19:44:10'),(100452,'samsung WMN2000A ','new','computer',7,250,'2012-03-22 19:46:08'),(100453,'samsung WMN2000C','new','computer',0,250,'2011-11-27 18:39:56'),(100454,'samsung SSG-2200AR used','used','computer',0,280,'2011-09-07 00:30:09'),(100456,'Transparent rain Umbrella  伞','new','umbrella',76,15,'2012-03-25 04:18:21'),(100457,'3D Blu-ray monster house','New','computer',18,40,'2012-01-03 19:14:12'),(100458,'3D Blu-ray Alice in wonderland','new','computer',48,40,'2011-12-28 18:55:46'),(100459,'car pressure wash 8L','new','computer',2,75,'2011-11-28 19:26:46'),(100460,'samsung WIS09ABGN','new','computer',-1,230,'2012-01-09 02:47:00'),(100461,'HD gear 5.1 digital audio decoder','new','computer',2,250,'2012-01-15 05:59:08'),(100462,'3D Blu-ray ICE AGE 3','new','computer',32,80,'2011-12-29 23:13:07'),(100463,'3D Blu-ray Narnia 3','new','computer',29,65,'2011-12-18 19:13:49'),(100464,'umbrella 荷叶边伞 ','new','umbrella',5,22,'2012-03-14 19:04:21'),(100465,'umbrella小熊维尼三折叠伞 ','new','umbrella',6,19,NULL),(100466,'umbrella 向日葵三折叠伞 ','new','umbrella',-1,28,'2012-03-25 03:33:06'),(100467,'umbrella 向日葵长柄伞  ','new','umbrella',5,30,'2012-03-18 03:23:21'),(100468,'umbrella蕾丝蝴蝶结伞 黑色','new','umbrella',19,25,'2012-03-14 03:17:28'),(100469,'umbrella 地图伞 ','new','umbrella',13,25,'2012-03-11 20:09:48'),(100470,'24K 多色伞 umbrella','new','umbrella',24,34,'2012-03-20 19:34:50'),(100471,'黑底七色边彩虹伞 umbrella','new','umbrella',6,26,'2012-03-21 19:41:31'),(100472,'umbrella 钢琴美女伞 ','new','umbrella',32,34,'2012-03-25 03:17:24'),(100473,'umbrella蕾丝花边伞 ','new','umbrella',49,22,'2012-03-20 21:29:00'),(100474,'umbrella西瓜伞 ','new','umbrella',7,25,'2012-03-08 19:25:15'),(100475,'umbrella草莓伞 ','new','umbrella',0,25,'2012-01-16 23:47:59'),(100476,'umbrella美女涂鸦伞 ','new','umbrella',6,23,'2012-02-29 20:38:53'),(100477,'Jabra BT500 ','new','computer',5,70,'2012-03-21 20:04:26'),(100478,'Jabra BT500V','new','computer',4,70,'2012-03-22 19:41:07'),(100479,'索爱 HBH-DS970','new','computer',6,130,'2012-03-07 00:33:02'),(100480,'philips HX6950 handle','new','home&beauty',73,200,'2012-03-25 05:28:42'),(100481,'philips HX6930 handle','new','home&beauty',-3,175,'2012-03-04 03:59:19'),(100482,'philips travel charger  ','new','home&beauty',70,50,'2012-03-25 04:28:11'),(100483,'philips proresults brush head ','new','home&beauty',1,30,'2011-09-12 21:25:30'),(100484,'Logitech 3Dconnexion SpacePilot mouse','new','computer',3,750,'2012-03-12 19:29:35'),(100485,'3D Blu-ray 2010 FIFA world cup','n','computer',30,39,'2012-01-03 19:00:51'),(100486,'Atheros AR5B195','new','computer',11,NULL,'2012-03-23 00:14:18'),(100487,'Logitech MX revolution  mat','new','computer',18,6,'2012-03-21 19:55:12'),(100488,'银胶巴黎铁塔伞   umbrella','new','umbrella',2,37,'2012-03-21 19:07:47'),(100489,'网眼豹纹双层网纱长柄伞  umbrella','new','umbrella',7,29,'2012-02-15 19:15:07'),(100490,'海星三折伞 umbrella','new','umbrella',4,20,NULL),(100491,'照镜子伞    umbrella','new','umbrella',1,22,'2011-11-08 04:22:08'),(100492,'小蝌蚪长柄伞  umbrella','new','umbrella',0,35,'2011-12-22 20:59:57'),(100493,'16骨长柄自动伞  umbrella','new','umbrella',20,22,'2012-03-10 22:55:47'),(100494,'ProLee24K超轻碳纤骨长柄伞  umbrella','new','umbrella',1,33,'2012-03-13 19:26:36'),(100495,'正红色长柄婚庆伞 umbrella','new','umbrella',8,23,'2012-02-29 19:37:48'),(100496,'枫叶小熊长柄伞   umbrella','new','umbrella',11,27,NULL),(100497,'野性豹纹蕾丝蝴蝶结长柄伞  umbrella','new','umbrella',5,28,'2012-01-29 23:51:17'),(100498,'w.p.c条纹碎花伞  umbrella','new','umbrella',1,33,'2011-11-13 17:52:36'),(100499,'日本外贸经典条纹长柄伞 umbrella','new','umbrella',2,33,'2011-10-01 20:46:35'),(100500,'蕾丝蝴蝶结长柄伞   umbrella 红色','new','umbrella',-1,25,'2011-11-30 19:46:23'),(100501,'点点花边公主伞     umbrella','new','umbrella',-1,25,'2012-02-23 23:27:25'),(100502,'w.p.c蕾丝花边 遮阳伞 umbrella','new','umbrella',2,35,NULL),(100503,'SONY TDG-BR50 3D glasses pink/blue S','n','computer',0,249,'2011-10-24 19:30:06'),(100505,'Logitech M950  mat','new','computer',14,6,'2012-03-25 04:36:58'),(100506,'i-tech SolarVoice 908 headset','new','computer',14,110,'2012-03-04 05:24:20'),(100507,'HP media center+ microsoft remote+emitter','new','computer',4,39,'2012-02-13 02:21:31'),(100508,'Grohe 加压花洒 ','new','home&beauty',1,38,'2011-10-02 19:38:47'),(100509,'Grohe 大水量花洒','new','home&beauty',13,42,'2012-03-22 19:28:17'),(100510,'Grohe 水枪','new','home&beauty',7,68,'2012-03-21 20:00:02'),(100512,'LED发光伞 umbrella','new','umbrella',11,36,'2012-03-12 04:03:21'),(100513,'白色蕾丝新娘伞 umbrella','new','umbrella',8,26,'2012-03-04 01:18:35'),(100514,'韩版透明伞 umbrella','new','umbrella',32,NULL,'2012-03-22 19:42:22'),(100515,'DLP 3D ready 投影仪兼容眼镜','new','computer',83,200,'2012-03-25 03:32:12'),(100516,'philips sonicare HX6942','new','computer',0,440,'2011-11-02 20:16:41'),(100517,'3.0 ASUS 6pin 6CM  （N43 N73 U80 N61 UL30 U31 U36 A40 UX50）','New','Computer',-3,45,'2012-01-11 18:48:43'),(100518,'3.0 ASUS 6PIN 12CM  （N53 G53 UL50 UL80 ）','new','computer',-4,45,'2012-03-13 19:43:17'),(100519,'3.0 lenovo S10-3S E46A E46L E47A E47L E27 ','new','computer',0,45,'2012-03-25 03:20:52'),(100520,'3.0 lenovo Y460','new','computer',3,45,'2011-09-19 20:27:44'),(100521,'DENON RC-970 remote control','New','Computer',-1,160,'2012-03-11 01:24:55'),(100522,'DENON RC-1050 remote control','new','computer',2,80,'2011-10-12 19:45:05'),(100523,'Iqua BHS-608 bluetooth headset ','new','computer',6,110,'2012-03-11 19:29:19'),(100524,'HP 2.4G mouse','new','computer',7,55,'2012-03-06 19:52:08'),(100525,'Kodak wifi card','new','computer',4,70,'2012-02-26 01:01:08'),(100511,'红酒瓶伞 umbrella','New','umbrella',1,10,'2011-09-09 01:57:48'),(100526,'BOSE IE2 headset    ','New','Computer',2,150,NULL),(100527,'BOSE IE2  mic headset ','new','computer',1,240,'2011-10-22 21:52:52'),(100528,'TWINBIRD HC 4107  迷你键盘吸尘器','new','computer',1,25,'2012-02-14 20:41:59'),(100529,'YAMAHA RAV255 remote control','used','computer',1,80,'2012-03-22 20:07:23'),(100530,'GPS USB receiver+antenna','new','computer',4,100,'2012-02-09 02:46:08'),(100531,'罗兰 LOWRANCE Explorer GPS 手持机','new','computer',0,300,'2011-10-08 23:02:05'),(100532,'蓝天白云长柄伞 umbrella','new','umbrella',12,26,'2012-03-21 19:17:16'),(100533,'samsung SSG-3100GB 3D glasses','new','computer',1,270,'2011-11-20 01:15:34'),(100534,'philiphs SPZ5000 摄像头','new','computer',0,80,'2012-03-04 01:53:53'),(100535,'philiphs SPZ3000 摄像头','new','computer',0,80,'2012-01-15 05:53:49'),(100536,'AKG Q460 headset box','new','computer',0,300,'2011-09-23 03:58:32'),(100537,'AKG K450 box','new','computer',0,190,'2011-09-30 00:48:58'),(100538,'panisonic ES2400C nail polisher  自动美甲器','new','home&beauty',4,45,'2011-10-23 04:01:15'),(100539,'大哥大 GSM Classic Mobile Brick Phone','new','computer',1,130,'2012-02-27 18:53:52'),(100540,'rii mini keyboard','new','computer',0,128,'2011-10-05 19:15:19'),(100541,'apple 4GB USB FLASH DRIVE','new','computer',0,45,'2011-09-29 20:01:45'),(100542,'罗兰LOWRANCE Explorer GPS 手持机 彩屏 ','used','computer',0,450,'2011-11-30 19:17:10'),(100543,'samsung SSG-3700CR 3D glasses','new','computer',1,442,'2012-03-18 21:58:58'),(100544,'philips HX5500   handle','new','home&beauty',0,50,'2011-11-09 18:59:25'),(100545,'philips HX7500   handle ','new','computer',63,70,'2012-03-25 04:49:58'),(100546,'路易甜美公主自动三折伞 umbrella','new','umbrella',1,35,'2011-11-20 00:05:21'),(100547,'韩版可爱涂鸦三折伞 umbrella','new','umbrella',1,18,'2012-02-12 18:54:24'),(100548,'la petty a loup 三折伞 umbrella','new','umbrella',3,45,'2011-12-25 22:56:34'),(100549,'韩版加粗报纸三折伞 umbrella','new','umbrella',4,15,'2012-03-08 18:07:30'),(100550,'可爱猫咪波浪边 三折伞  umbrella','new','umbrella',0,26,'2012-01-17 18:49:14'),(100551,'罗兰LOWRANCE finder H2OC  GPS 彩色 ','used','computer',19,350,'2012-03-20 21:20:49'),(100552,'罗兰LOWRANCE finder PhD GPS    黑白  ','used','computer',0,320,'2012-03-12 19:43:48'),(100553,'North bayou NBT717M projector mount','new','computer',-1,45,'2011-11-21 18:38:56'),(100554,'nokia BH-900单机 旧','used','computer',0,80,'2011-12-04 21:04:27'),(100555,'BOSE IE2  mic headset   no volume','new','computer',2,170,NULL),(100556,'apple jobs 8G U盘','new','computer',6,65,'2012-03-11 19:30:23'),(100557,'SONY MCE remote RM-MCV10T 原装接收器','new','computer',4,50,'2012-03-25 05:08:48'),(100558,'SONY MCE 遥控  白色   RM-MCE20E','new','computer',6,45,'2012-03-25 04:12:15'),(100559,'SONY MCE 遥控  黑色   RM-MCE10E','new','computer',-2,45,'2012-02-15 01:52:51'),(100560,'plantronics 851 副耳机 ','new','computer',-2,20,'2011-12-18 18:51:22'),(100561,'行车记录仪 car camera dashboard  1080P HDMI','new','computer',0,295,'2012-02-15 19:54:09'),(100562,'行车记录仪 car camera dashboard 720P ','new','computer',5,155,'2012-03-25 04:47:59'),(100563,'索爱 MW600 headset','new','computer',4,225,'2012-03-18 19:26:15'),(100564,'索爱 MH110 headset new in box','new','computer',3,215,NULL),(100565,'nokia HS-26W','new','computer',9,20,'2012-02-16 18:49:18'),(100566,'i.Tech Clip II mini  black','new','computer',19,85,'2012-02-28 18:50:20'),(100567,'i.Tech Clip II mini  white','new','computer',9,85,'2012-03-25 03:10:13'),(100568,'i.Tech Clip II mini  blue','new','computer',4,85,'2012-03-22 20:16:05'),(100569,'micorsoft 极动鲨 mouse white','new','computer',20,35,NULL),(100570,'Jabra JX10 headset silver','new','computer',12,50,'2012-03-19 19:36:10'),(100571,'Jabra JX10 headset red','new','computer',9,50,'2012-03-21 22:52:51'),(100572,'URK fingerprint time and attendance','new','computer',1,299,NULL),(100573,'兼容型3D眼镜  Korea TV专用','new','computer',0,125,'2012-01-02 02:43:37'),(100574,'philips  brush head HX6021','new','computer',6,40,'2012-03-16 02:23:24'),(100576,'LG 3D glasses AG-F210 （2 pairs in box bundle）','new','computer',0,40,'2011-12-25 01:44:41'),(100577,'LG wireless adapter AN-WF100 wifi dongle','new','computer',120,150,'2012-03-25 05:00:47'),(100578,'LG magic motion remote AN-MR200','new','computer',69,140,'2012-03-25 05:14:59'),(100579,'LG 3D glasses AG-S110 ','new','computer',6,140,'2012-03-14 19:39:26'),(100580,'Samsung WMN2000B OEM ','new','computer',5,80,'2012-01-29 18:55:55'),(100581,'GPS Tk-102','new','computer',28,220,'2012-03-22 20:41:15'),(100582,'GPS Tk-103  ','new','computer',5,350,'2012-03-18 03:29:48'),(100583,'GPS Tk-103-2 ','new','computer',6,450,'2012-03-25 05:02:12'),(100584,'GPS 高明GARMIN 12XL  手持  ','new','computer',0,300,'2012-02-01 21:44:43'),(100585,'UGEE rainbow3  graphic tablet 数位板 ','new','computer',0,699,'2012-03-20 19:28:01'),(100586,'lamborghini mouse','new','computer',12,80,'2012-03-13 21:20:25'),(100587,'3D blu-ray 加勒比海盗','new','computer',18,35,'2012-01-03 19:04:34'),(100588,'罗技G7 鼠标电池  used','used','computer',11,17,'2012-03-18 06:53:27'),(100589,'car pressure wash 12L','new','computer',0,87,'2011-12-03 22:09:52'),(100592,'logitech G9X 银色  silver mouse shell','new','computer',9,30,'2011-12-11 18:24:57'),(100593,'logitech G9X 大黑色 black  ver 1 mouse shell   ','new','computer',2,32,'2012-03-25 04:59:46'),(100594,'logitech G9X 小黑色 black ver 2  mouse shell','new','computer',9,30,'2012-02-21 18:38:08'),(100595,'LG AG-F110 3D glasses','new','computer',-5,40,'2012-01-15 00:41:16'),(100596,'LG AG-F214  white 3D glasses ','new','computer',0,100,'2012-01-02 18:05:24'),(100597,'philips SHQ4000   headset','new','computer',0,145,'2012-03-20 20:40:41'),(100598,'philips SHS4800   yelllow headset','new','computer',1,66,'2012-02-12 09:03:34'),(100599,'philips SHS4840   black headset','new','computer',2,57,NULL),(100600,'philips SHS4843   blue headset','new','computer',0,57,'2012-03-20 19:31:38'),(100601,'philips SHS4844   green headset','new','computer',2,57,NULL),(100602,'philips SHS4847  orange headset','new','computer',2,57,'2012-02-02 18:37:31'),(100603,'motorola H721 headset','new','computer',7,80,'2011-12-26 18:45:58'),(100604,'motorola H715 headset','new','computer',19,80,'2011-12-24 06:18:50'),(100605,'logitech MX1100 mat','new','computer',12,3,'2012-02-23 21:30:23'),(100606,'Sharp AN-3DG20-B   3D glasses','new','computer',2,430,'2012-01-12 19:10:30'),(100607,'LG premium filter ','new','computer',11,160,'2012-03-25 04:33:14'),(100608,'samsung aqua pwie water filter','new','computer',26,150,'2012-03-25 05:04:51'),(100609,'samsung water filer WSF-100','new','computer',5,190,'2012-03-15 20:07:53'),(100610,'爱雨透明伞              umbrella ','new','umbrella',6,19,'2012-03-25 02:39:14'),(100611,'接边斑马纹透明伞   umbrella ','new','umbrella',2,19,'2012-03-13 03:19:17'),(100612,'接边蕾丝透明伞       umbrella  ','new','umbrella',1,19,'2012-03-10 23:50:33'),(100575,'philips HX5300   handle ','new','computer',86,40,'2012-03-20 19:30:40'),(100613,'TK-102 外接电池 battery','new','umbrella',36,100,'2012-03-21 19:27:38'),(100614,'钢琴调音工具 8件套','new','computer',1,120,'2012-02-28 19:04:53'),(100615,'HP wireless mouse + receiver ','new','computer',7,30,'2012-03-25 04:38:38'),(100616,'logitech 895 remote control     used','used','computer',-1,400,'2012-01-09 18:58:17'),(100617,'Nokia bluetooth headset 806    ','new','computer',0,280,'2012-01-02 22:07:35'),(100618,'i-Tech Clip Music 802i  headset ','new','computer',0,180,'2012-03-11 19:16:23'),(100619,'philips SHB9100  headset  ','new','computer',3,380,'2012-03-19 19:29:34'),(100620,'BELKIN F5D7050 wireless card+USB base ','new','computer',42,25,'2012-03-25 04:48:23'),(100621,'samsung SSG-3300GR   3D glasses  ','new','computer',9,310,'2012-03-13 19:50:04'),(100622,'samsung SSG-3500CR   3D glasses','new','computer',6,330,'2012-03-04 00:38:52'),(100623,'highstar 4 port USB LED board  ','new','computer',0,31,'2012-01-30 20:02:50'),(100624,'USB  battery   1450mah     ','new','computer',30,11,'2012-03-22 19:30:04'),(100625,'UFO 魔术飞碟                                ','new','computer',0,4.9,'2012-02-06 18:42:42'),(100626,'UINEA fish hook','new','home & beauty',37,2.5,'2011-12-24 00:09:49'),(100627,'lowrance   ifinder hunt   used','used','computer',0,300,'2012-03-22 19:40:30'),(100628,'lowrance    AIRMAP600C  used','used','computer',3,600,'2012-03-21 19:19:21'),(100629,'HP car charger','new ','computer',20,12,NULL),(100630,'蓝天白云三折伞 umbrella','new','umbrella',-4,22,'2012-03-22 19:14:08'),(100631,'偏光眼镜  家庭装  ','new','computer',1,80,NULL),(100632,'2200mah charger    5色各一        ','new','computer',4,70,'2012-03-19 01:40:03'),(100633,'HoneyHub 波点网纱双层长柄伞','new','umbrella',0,31,'2012-02-01 19:29:44'),(100634,'迷彩弯钩长柄伞 男士商务伞','new','umbrella',1,31,NULL),(100635,'企鹅图三折全自动伞','new','umbrella',3,36,'2012-03-01 00:36:45'),(100636,'创意心形长柄伞','new','umbrella',-2,31,'2012-03-18 03:29:19'),(100637,'Family甜美素色长柄伞 波点接边晴雨伞 5色','new','umbrella',5,38,NULL),(100638,'24骨轻量长柄雨伞 泡泡款     3色','new','umbrella',1,31,'2012-03-19 19:31:01'),(100639,'绅士猫咪波点晴雨伞 弯柄长柄伞','new','umbrella',4,38,'2012-03-15 19:38:05'),(100640,'Citymoon透明加厚面料印度花长柄伞  3色','new','umbrella',9,28,'2012-03-19 19:38:54'),(100641,'骏马图三折雨伞  ','new','umbrella',4,17,'2012-03-15 20:17:47'),(100642,'奥特蓝星 Altec Lansing  UHP326 headset ','new','computer',16,35,'2012-03-25 05:12:44'),(100643,'奥特蓝星 Altec Lansing  UHP206 headset','new','computer',30,30,'2012-03-25 04:46:17'),(100644,'ZALMAN 思民 FG1000 FPSGUN mouse 射击鼠标 ','new','computer',1,88,'2012-02-21 18:56:26'),(100645,'哈利波特7  3D  blue-ray 上下集（ 2张2D+2张3D）','new ','computer',5,160,NULL),(100646,'Samsung WMN2050A   mount','new','computer',6,130,NULL),(100647,'Samsung WMN2050B1   mount','new','computer',5,130,'2012-02-20 02:33:07'),(100648,'Samsung WMN2050B2  mount','new','computer',5,130,NULL),(100649,'Samsung WMN2050C  mount','new ','computer',6,130,'2012-03-04 19:09:05'),(100650,'诺基亚 nokia   BH-104  headset','new','computer',2,43,'2012-02-12 08:56:49'),(100651,'诺基亚 nokia  BH-904  headset','new','computer',0,230,'2012-02-26 00:37:03'),(100652,'诺基亚 nokia  BH-301   headset  5种颜色','new','computer',2,50,'2012-03-11 19:36:13'),(100653,'motorola EQ5     headset','new','computer',2,150,NULL),(100654,'全透明伞 full transparent  umbrella','new','umbrella',8,19,'2012-03-25 03:12:44'),(100655,'魔发奇缘 Tangled 3D blu-ray ','new','computer',5,35,NULL),(100656,'SONY TMR-BR100 3D transmitter ','new','computer',101,85,'2012-03-25 02:26:32'),(100657,'LG AG-F200   3D glasses','new','computer',1,40,'2012-01-15 05:37:23'),(100658,'超宽曲面后视镜  Rear View Mirror  (convex)','new','car accessary',0,16,'2012-02-26 04:35:46'),(100659,'超宽平面后视镜  Rear View Mirror  (flat)','new','car accessary',4,16,'2012-03-06 19:14:06'),(100660,'倒车雷达 有显示有蜂鸣 Parking Sensor','new','car accessaries',18,50,'2012-03-13 19:15:36'),(100661,'倒车雷达 无显示有蜂鸣 Parking Sensor','new','car accessaries',0,40,'2012-03-25 04:40:16'),(100662,'Panasonic  TY-EW3D3MC   3D glasses ','new','computer',249,330,'2012-03-25 03:07:41'),(100663,'special made apple HDD caddy','new','computer',7,40,'2012-03-11 01:29:00'),(100664,'HP remote control big','new','computer',63,13,'2012-03-25 05:11:07'),(100665,'HP remote control small','new','computer',102,8,'2012-03-25 05:10:10'),(100666,'TK102 adapter','new','car accessory',46,9,'2012-03-15 19:58:06'),(100667,'tracker car charger 车充  TK系列','new','car accessory',9,10,'2012-03-22 20:41:15'),(100668,'tracker 电瓶充  TK系列','new','car accessory',10,15,NULL),(100669,'TK-102-2  ','new','car accessory',1,430,NULL),(100670,'TK-201   ','new','car accessory',1,300,NULL),(100671,'奥特蓝星 Altec Lansing MZX736 headset','new','car accessory',1,45,NULL),(100672,'philips HX9340 toothbrush handle','new','home&beauty',10,400,NULL),(100673,'adjustable round Rear View Mirror','new','car accessory',4,5,NULL),(100674,'DLP 3D glasses child ','new','computer',1,150,NULL),(100675,'兼容眼镜 3D glasses white','new','computer',1,120,NULL);
/*!40000 ALTER TABLE `hmsh_ebay_eastar_stock` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_eastar_transaction`
--

DROP TABLE IF EXISTS `hmsh_ebay_eastar_transaction`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_eastar_transaction` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `transaction_ID` bigint(20) NOT NULL,
  `ebay_itemID` bigint(20) NOT NULL,
  `ebay_itemTitle` varchar(2048) DEFAULT NULL,
  `quantity` int(4) DEFAULT NULL,
  `hmsh_sku` varchar(255) DEFAULT NULL,
  `amountPaid` double DEFAULT NULL,
  `ebay_sellerID` varchar(255) DEFAULT NULL,
  `ebay_buyerID` varchar(255) DEFAULT NULL,
  `ebay_buyerEmail` varchar(255) DEFAULT NULL,
  `shipping_name` varchar(255) DEFAULT NULL,
  `shipping_street` varchar(1024) DEFAULT NULL,
  `shipping_city` varchar(255) DEFAULT NULL,
  `shipping_state` varchar(255) DEFAULT NULL,
  `shipping_country` varchar(255) DEFAULT NULL,
  `shipping_zip` varchar(255) DEFAULT NULL,
  `shipping_phone` varchar(255) DEFAULT NULL,
  `ebaypaymentstatus` varchar(255) DEFAULT NULL,
  `checkoutstatus` varchar(255) DEFAULT NULL,
  `shippingservice` varchar(255) DEFAULT NULL,
  `paid_time` datetime DEFAULT NULL,
  `shippingstatus` tinyint(4) DEFAULT '0',
  `shipping_time` datetime DEFAULT NULL,
  `item_status` tinyint(4) NOT NULL DEFAULT '0',
  `stock_status` tinyint(4) NOT NULL DEFAULT '0',
  `shipping_method` tinyint(4) NOT NULL DEFAULT '0',
  `if_printed` tinyint(2) NOT NULL DEFAULT '0',
  `tracking_id` varchar(256) DEFAULT NULL,
  `notes` varchar(4096) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ebayDuplicate` (`transaction_ID`,`ebay_itemID`,`ebaypaymentstatus`)
) ENGINE=MyISAM AUTO_INCREMENT=24440 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_eastar_transaction`
--

LOCK TABLES `hmsh_ebay_eastar_transaction` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_eastar_transaction` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (267,561701810013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',13.49,'eastar4','sandmanrus','a_sandman@bk.ru','Andrey Schastnyy','Svobody St. 13A- 308','Kemerovo','','RUSSIAN FEDERATION','650070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:58:18',0,NULL,3,0,2,1,NULL,'sandmanrus、'),(266,756605251012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','welectronicss','sales@wholesalelectronics.org','CHris Sanders','780 Amelia Grove Ln','Lawrenceville','GA','UNITED STATES','30045','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 05:37:47',0,NULL,3,0,1,1,NULL,'welectronicss、'),(265,561689912013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','e**ch','simonezracohen@hotmail.com','EZRA CH. COHEN','Rua Sergipe 475 -Sala 204','Sao Paulo','Sao Paulo','BRAZIL','01243001','55+11+36617983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 04:20:42',0,NULL,3,0,2,1,NULL,'e**ch、'),(264,754978540012,220704730419,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',37.5,'eastar4uk','goetmals','benjamindecotte@hotmail.com','Benjamin Decotte','108 avenue du general leclerc','La Fere','Picardie','FRANCE','02800','06-76-83-74-20','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 07:00:41',0,NULL,3,0,3,1,NULL,'goetmals   欧标RA022497905CN、'),(263,516696835004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','zoraya18','minor-solano@hotmail.com','Zoraya Gautier','2236 Dean Rd','Kernersville','NC','UNITED STATES','27284-8915','(336) 497-4268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 03:19:27',0,NULL,3,0,1,1,NULL,'zoraya18、'),(262,561678577013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','wbretas','wbretas@gmail.com','Wagner','Rua Jorge Lossio, 342 / ap 301','Teresópolis','Rio de Janeiro','BRAZIL','25961-265','(+55) 21-8755-1942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 03:15:53',0,NULL,3,0,2,1,NULL,'wbretas、'),(261,681217647011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',10,'KBVI001',1000,'eastar4','tralda','adrian@concordia.sa.edu.au','Adrian Wuttke','45 Cheltenham St. Highgate','Adelaide','South Australia','AUSTRALIA','5063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 01:42:19',0,NULL,3,0,6,1,NULL,'tralda    黑色的\rEE389037529CN\r'),(260,510856084003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 01:02:51',0,NULL,3,0,1,1,NULL,'crazystargrl'),(259,514433014004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','smcm2894','impapabear43@yahoo.com','STEVEN MCMANN','8915 Buena Pl<br>Apt 4107','Windermere','FL','UNITED STATES','34786-9418','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 22:52:34',0,NULL,3,0,1,1,NULL,'smcm2894'),(258,757035046012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','lisae.1-2007','lisae123@hotmail.co.uk','lisa eden','30 goffs oak ave<br>goffs oak','hertfordshire','Hertfordshire','UNITED KINGDOM','EN7 5NJ','01707880012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 22:22:08',0,NULL,3,0,3,1,NULL,'lisae.1-2007   英标\rRA022497998CN、'),(257,681150860011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','shpantzeri','ishpantzer@celight.com','Isaac Shpantzer','8312 rising ridge way','Bethesda','MD','UNITED STATES','20817-6944','(301) 365-8976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 22:02:00',0,NULL,3,0,1,1,NULL,'shpantzeri'),(256,757013066012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','ikarus.vienna','arnold.vorraber@aon.at','Arnold Vorraber','Kanalstrasse 33/A16','Wien','','AUSTRIA','1220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 21:35:50',0,NULL,3,0,2,1,NULL,'ikarus.vienna、'),(255,757008586012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.69,'eastar4uk','jonny321321','jonny-leech@hotmail.com','Jonathan Leech','Tomfarney<br>Clonroche','Enniscorthy','Wexford','IRELAND','default','0863886880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 21:28:00',0,NULL,3,0,3,1,NULL,'jonny321321   英标\rRA022497627CN'),(254,757005650012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','1010diablo','10diablo@mail.ru','Alexander Leonov','post box 4','Moscow','Russia','RUSSIAN FEDERATION','125424','+7 (495) 5002583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 21:21:40',0,NULL,3,0,2,1,NULL,'1010diablo   欧标、'),(253,516594578004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','scuderia-italiana','ebay@scuderiaitaliana.it','Giancarmine Spadaro','Via Vitrani, 31/33','Barletta','BA','ITALY','70051','3477644808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:14:07',0,NULL,3,0,3,1,NULL,'scuderia-italiana\rRA022497715CN\r'),(252,512793107004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','gustavo5694','farahzinho@hotmail.com','Gustavo Farah','Rua: Raimundo Leão de Moura<br>nº 203, Bloco B, Ap 401, Bairro: Nova Betânia.','Mossoró','Rio Grande do Norte','BRAZIL','59611320','(084) 88965705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:14:00',0,NULL,3,0,3,1,NULL,'gustavo5694\rRA022497785CN、'),(251,681089433011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','antti12345','antti.halonen1@gmail.com','Antti Halonen','Tarhurintie 10 C 42','Vantaa','','FINLAND','01350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:07:14',0,NULL,3,0,2,1,NULL,'antti12345、'),(250,516589576004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','splashlacey','tomoly@comcast.net','Tom McCain','1722 Timberlake Ct SE','Lacey','WA','UNITED STATES','98503-3049','(360) 866-1277','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 20:01:59',0,NULL,3,0,1,1,NULL,'splashlacey'),(249,516587663004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','sherman720','bigduff79@yahoo.com','Sherman Duffie','23 Redstone Ct','Durham','NC','UNITED STATES','27703-6315','(919) 648-1930','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 19:57:33',0,NULL,3,0,1,1,NULL,'sherman720   旧的'),(248,510739655003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',26.95,'cnfaner','11hacker11','alexbezrodny@gmail.com','Alexandr Yurievich Bezrodny','Petra Vershygory St, 3b, apt. 8','Kiev','Kyiv','UKRAINE','02218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:51:12',0,NULL,3,0,3,1,NULL,'11hacker11   \rRA022497732CN\r'),(247,756911212012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',10.49,'eastar4','driver.shot','roland.menet@hispeed.ch','Roland Menet','Dorfstrasse 21','Algetshausen','','SWITZERLAND','9249','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:20:31',0,NULL,3,0,2,1,NULL,'driver.shot、'),(246,756907528012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','paulo*maia','pcsmaia@gmail.com','Paulo Maia','Al Praia de Guarapari, 209<br>casa 87','Salvador','BA','BRAZIL','41600110','+557136046187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:43:35',0,NULL,3,0,2,1,NULL,'paulo*maia、'),(245,681022910011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lkbleet','lkbleet@aol.com','Lynda  M Kornbleet','1331 Seamist Dr','Houston','TX','UNITED STATES','77008-5017','(713) 868-1021 ext.: 101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 18:01:15',0,NULL,3,0,1,1,NULL,'lkbleet'),(244,756883522012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','kashpon-rus','kashpon@gmail.com','Belyanikov Alexei','st. Holzunova, h. 36/1, fl. 93','Volgograd','Volgogradskaya oblast','RUSSIAN FEDERATION','400105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:54:19',0,NULL,3,0,3,1,NULL,'kashpon-rus       \r RA022497817CN、\r'),(243,756875050012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','todotecno','cococarrey@hotmail.com','Jose Alberto Moreno Raposo','Paseo de la Esperanza 35, 1 Izda','MAdrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:38:46',0,NULL,3,0,3,1,NULL,'todotecno    欧标头\rRA022497635CN'),(242,756859153012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','shashank.chaturvedi85','ricky_chatur2005@yahoo.com','Shashank Chaturvedi','32-D ExpressView Apartment ( Super Mig)<br>Sector-93','Noida','UP','INDIA','201304','9899430045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:10:34',0,NULL,3,0,2,1,NULL,'shashank.chaturvedi85、'),(241,756862133012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','wbrjbr','wbrjbr@bellsouth.net','Walter Rose','58 N Crest Rd','Chattanooga','TN','UNITED STATES','37404-1828','(423) 698-8692','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 17:07:50',0,NULL,3,0,1,1,NULL,'wbrjbr'),(240,756857996012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','armandojpp','armando_pinheiro@hotmail.com','armando pinheiro','rua conde de bonfim 785 apt 101','rio de janeiro','rio de janeiro','BRAZIL','20530000','552134370095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:05:14',0,NULL,3,0,2,1,NULL,'armandojpp、'),(239,510711607003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','dankaert','casmat@gmail.com','Matteo Casalini','Via Copernico 14/A - c/o ASYS SRL','Podenzano - PC','Piacenza','ITALY','29027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 16:43:27',0,NULL,3,0,3,1,NULL,'dankaert        客户的新地址        \r\r Matteo Casalini\rc/o ASYS SRL\rVia Copernico 14/A\r29027 Podenzano (PC)\rITALY\rRA022497729CN\r\r'),(238,510708329003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','yitzhandel','ebay@thehandels.com','Yitzchak Handel','954 Country Club Dr','Teaneck','NJ','UNITED STATES','07666','(201) 837-2844','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:30:20',0,NULL,3,0,1,1,NULL,'yitzhandel'),(237,516506241004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','robersonfeitosa','roberson.batista@credicarditau.com.br','Roberson Feitosa Batista','Rua Teixeira de Melo Nº 355 apto 1085<br>Tatuapé','São Paulo','SÃO PAULO','BRAZIL','03067000','(551) 184-3453 ext.: 13','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 15:35:28',0,NULL,3,0,3,1,NULL,'robersonfeitosa\rRA022497865CN'),(236,516499890004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','e_bay_dragon','longmuaban@yahoo.com','Long Bui','300 NW 18th St<br>Apt 25','Gainesville','FL','UNITED STATES','32603-1678','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 14:59:05',0,NULL,3,0,1,1,NULL,'e_bay_dragon'),(235,756787301012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','probirpaul','probirkrpaul@yahoo.com','Probir Paul','Vill- Baninagar<br>P.O. Pritinagar','Payradanga','West Bengal','INDIA','741247','9831355898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:45:26',0,NULL,3,0,2,1,NULL,'probirpaul、'),(234,680945058011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jsynthesizer','psynthesizer@gmail.com','Jonathan Jia','2110 Lerner Hall<br>2920 Broadway','New York','NY','UNITED STATES','10027-8385','(908) 917-2888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 14:35:02',0,NULL,3,0,1,1,NULL,'jsynthesizer'),(233,561370477013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',26.1,'eastar4','kawa9green','pean79@telia.dk','Per Worsøe','Bakkevej 9A','Virum','','DENMARK','2830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:24:44',0,NULL,3,0,2,1,NULL,'kawa9green    一共买了三个CAB-6060、'),(232,678433897011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',119.99,'eastar4','cofman1941','bigfatkitty@carolina.rr.com','Bruce Cofman','5918 Waverly Lynn Ln','Charlotte','NC','UNITED STATES','28269-1455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 14:15:01',0,NULL,3,0,1,1,NULL,'cofman1941、'),(231,756790342012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','grlgf','graham_langford@btinternet.com','Graham Langford','69 Grove Rd','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 1EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 13:58:44',0,NULL,3,0,3,1,NULL,'grlgf\rRA022497940CN\r'),(230,510658115003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','javierk65','ebjk@aptix.net','Javier Kohan','Pellegrini 391<br>Planta Alta','Rosario','Santa Fe','ARGENTINA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:35:58',0,NULL,5,0,3,1,NULL,'javierk65'),(229,561426753013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','ziv1281','ziv2312@yahoo.com','Ziv Shchori','10 Amoraeim st. apt. 2','Rehovot','','ISRAEL','76549','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:34:19',0,NULL,3,0,2,1,NULL,'ziv1281、'),(228,680898739011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','evggger','evgencyb@gmail.com','Evgeny Tsybin','Vatutina 1','Khimki','Moscow','RUSSIAN FEDERATION','141400','9067266946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:23:27',0,NULL,3,0,2,1,NULL,'evggger、'),(227,680901708011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','alphalove48','alex.scott.spam@gmail.com','Alexander Scott','PO Box 7047','Cloisters Square','Western Australia','AUSTRALIA','6850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 12:07:19',0,NULL,3,0,2,1,NULL,'alphalove48、'),(226,561413319013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ramy_b','r.bakhos@gmail.com','Ramy Bakhos','7 Janali Ave','Bonnyrigg','New South Wales','AUSTRALIA','2177','0423244445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:31:19',0,NULL,3,0,3,1,NULL,'ramy_b\rRA022498004CN'),(225,680892708011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','liverpoollad1','stephen.twist@tesco.net','Stephen Twist','telent<br>Carr Lane','Chorley','Lancashire','UNITED KINGDOM','PR7 3JP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:31:41',0,NULL,3,0,2,1,' ','liverpoollad1、'),(224,516178100004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',37.95,'cnfaner','pcsystemsfinland','paypal@pcsystems.fi','PC Systems Finland','PL 54','HELSINKI','FI','FINLAND','00501','+358504020376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 11:15:20',0,NULL,3,0,3,1,NULL,'pcsystemsfinland\rRA022497922CN'),(223,756724794012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',16.59,'eastar4','volocha-bobi','volocha@tut.by','ULADZIMIR MAKHNACH','RAFIEVA,85-242','MINSK','','BELARUS','220051','+375296790085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 10:44:02',0,NULL,3,0,2,1,NULL,'volocha-bobi            HP 8pin 1.0 18cm 4线连、'),(222,756716376012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','kenfong88','hua_88@live.com.my','ken fong','55 jalan permas 15/2<br>bandar baru permas jaya','masai','johor','MALAYSIA','81750','0177303339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 10:41:52',0,NULL,3,0,2,1,NULL,'kenfong88、'),(221,516445717004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','jana677_2009','jana677@hotmail.com','Hanin Bukhari box#JED 7289','147 29 182nd St','Springfield Gardens','NY','UNITED STATES','11413','718 553 8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 10:14:33',0,NULL,3,0,2,1,NULL,'jana677_2009  \r\r客户新地址        \r\rAtif Ali Ajlan\rSaudi Hollandi Bank\rTahlya Street\rbox No :67\rJeddah   21411 \rKingdom of Saudi Ariba\\\r\r'),(219,680851391011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3000+BTHP3002',29.99,'eastar4','benzinoid','planetmir@gmx.net','Ove Peter','Werrestrasse 120','Herford','','GERMANY','32049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:40:49',0,NULL,3,0,2,1,NULL,'benzinoid      HP 6pin1.0 3cm 、'),(59,559822473013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','fn800m','schizophrenicx@gmail.com','Tian Zun Aw','22 Sin Ming Road<br>#09-216','default','','SINGAPORE','570022','96541576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 08:06:25',0,NULL,3,0,11,1,NULL,'从此开始    fn800m\r'),(60,678760863011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',2,'CACN001',39.8,'eastar4','vladimir108108','hruby@rackspace.cz','vladimir hruby','trojska 53/782','prague8','','CZECH REPUBLIC','18200','+420720705130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 08:27:37',0,NULL,3,0,3,1,NULL,'RA022490460CN     vladimir108108\r '),(61,678789187011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',5,'WWSI006',295,'eastar4','flozwo','floriank@kempff.net','IPmotion GmbH','Ludwig-Rinn-Straße 14','Heuchelheim','','GERMANY','35452','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 10:33:44',0,NULL,3,0,3,1,NULL,'RA022490694CN       flozwo\r '),(62,754449665012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','duncantanner','duncan_tanner@hotmail.com','Duncan Tanner','191 Rownhams Lane<br>North Baddesley','Southampton','Hampshire','UNITED KINGDOM','SO52 9LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 10:42:50',0,NULL,3,0,2,1,NULL,'从此开始 duncantanner'),(63,754453483012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',14.49,'eastar4','julienp21','blondin21@free.fr','Julien PAGOT','30, rue du recteur Marcel BOUCHARD','Dijon','Bourgogne','FRANCE','21000','0619591562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 10:59:27',0,NULL,3,0,2,1,NULL,'acer 8pin1.00 8cm     julienp21'),(64,678806620011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','iamthepilot','lloydstearns@suddenlink.net','Lloyd Stearns','512 Deer Meadow Cir','Georgetown','TX','UNITED STATES','78633-4692','(512) 686-1344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 11:40:27',0,NULL,3,0,1,1,NULL,'iamthepilot '),(65,509238770003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',89.9,'cnfaner','tuisquash','tuisquash@uol.com.br','luiz arthur holland baptista','r: jose ramon urtiza n209 ap241-b','sao paulo','sao paulo','BRAZIL','05717-270','(551) 137-4344 ext.: 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 12:29:28',0,NULL,3,0,3,1,NULL,'从此开始 \rRA022490513CN     tuisquash\r'),(66,754477977012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','thanei','thanei@gmail.com','Lukasz Jaskiewicz','Bellerstraße 42','Hürth','','GERMANY','50354','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 12:30:06',0,NULL,3,0,2,1,NULL,'thanei '),(67,559890710013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','cdr_80','akine@euskalnet.net','Miguel Angel Aguado','Barrio Alai 15 Bajo B','Zumaia','País Vasco','SPAIN','20750','680164253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 14:06:14',0,NULL,3,0,3,1,NULL,' RA022490439CN      cdr_80'),(68,754530185012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',16.59,'eastar4','christianrodler','afirejar@googlemail.com','Christian Rodler','Hammerweg 7','Waldkirchen','','GERMANY','94065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 15:04:03',0,NULL,3,0,2,1,NULL,'Acer 5pin1.25 3cm      christianrodler'),(69,678889058011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',16.75,'eastar4','grosrien','gliboiron@videotron.ca','Gilles Liboiron','107 de Laval','Bromont','QC','CANADA','J2L1M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 16:07:37',0,NULL,3,0,2,1,NULL,'grosrien '),(70,515117401004,140516102911,'Genuine Logitech G7 Rechargeable Battery+charger',1,'BALO005+BALO006',19.99,'cnfaner','scissorjammer','scissorjammer@gmail.com','Alexander Rakoczy','600 W Chicago Ave<br>Suite 620 - Groupon','Chicago','IL','UNITED STATES','60654-2801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 16:32:04',0,NULL,3,0,1,1,NULL,'scissorjammer '),(71,754577597012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',49.98,'eastar4','marlonjerry','marlokw1988@gmail.com','Marlo Wilson','7462 E Candice Dr','Camby','IN','UNITED STATES','46113-8656','(317) 361-5580','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 17:18:44',0,NULL,3,0,1,1,NULL,'marlonjerry '),(72,754576720012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','julie55441','julie55441@msn.com','Julie Brown','416 Phillips 308','West Helena','AR','UNITED STATES','72390','(916) 397-3688','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 17:58:45',0,NULL,3,0,1,1,NULL,'julie55441 '),(73,678941208011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:10:23',0,NULL,3,0,11,1,NULL,'dorit710 '),(74,750036649012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','harley.ray','shoei500@hotmail.com','RAYMOND GIRARD','5433 RUE DU CONCERTO','CHARNY','QC','CANADA','G6X 2W8','(418) 832-6472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:13:54',0,NULL,3,0,2,1,NULL,'harley.ray '),(75,559974814013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',2,'HSJA002',43,'eastar4','enygyzer','enygyzer@yahoo.com','Mekia Chatman','1103 Benning Dr','Columbus','GA','UNITED STATES','31903-2107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 19:01:58',0,NULL,3,0,1,1,NULL,'enygyzer '),(76,509360377003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',67.47,'cnfaner','nakdemir','postmail.ebay@gmail.com','Nejdet Akdemir','Kirkkonaklar mh. Semsettin Gunaltay cd<br>363 sok. 3/4','ANKARA','cankaya','TURKEY','06610','903124963904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:12:07',0,NULL,3,0,3,1,NULL,' RA022490473CN     nakdemir'),(77,515187404004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','philipp19701970','philipp@mmserv.ru','Philipp Boreysha','Pestelya Str, 9-164','Moscow','RU','RUSSIAN FEDERATION','127490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:18:07',0,NULL,3,0,3,1,NULL,'RA022490685CN      philipp19701970\r '),(78,509365084003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','luvactive','princessofpurses@gmail.com','Katherine Robinson','6710 Leanne Street','mira loma','CA','UNITED STATES','91752','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 20:25:09',0,NULL,3,0,1,1,NULL,'luvactive '),(79,515197784004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','amirsofir','sofert@zahav.net.il','amir sofir','kharcom 34','hod hasharon','','ISRAEL','45224','972-97457397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:51:10',0,NULL,3,0,3,1,NULL,'RA022490575CN\r amirsofir'),(80,679055116011,320585224260,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',1,'WLIN009+ANTY001*3',22.95,'eastar4','basketsbaldo','kdbalding@sbcglobal.net','Kim K Balding','307 N Maple Glade Cir','The Woodlands','TX','UNITED STATES','77382','(281) 367-1818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-11 22:12:40',0,NULL,3,0,1,1,NULL,'basketsbaldo '),(81,560048274013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','hsyenhuai','bryan0812@gmail.com','Hsyenhuai Kao','2701 E 24th Avenue','Vancouver','BC','CANADA','V5R1E3','(778) 389-0932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 22:29:41',0,NULL,3,0,2,1,NULL,'hsyenhuai '),(82,754767782012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'eastar4','alessandro.figliolo','alessandrofigliolo@gmail.com','Alessandro Figliolo','Avenida Manoel Ribas, 9110 casa 01','Curitiba','Paraná','BRAZIL','82400000','554136777764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 23:51:19',0,NULL,3,0,3,1,NULL,' RA022490487CN      alessandro.figliolo'),(83,515242282004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','antigravityworkshop','colin@antigravityworkshop.com','Colin Lamb','1410 STARVIEW DR','CEDAR FALLS','IA','UNITED STATES','50613-4962','(563) 663-0767','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 23:54:43',0,NULL,3,0,1,1,NULL,'antigravityworkshop '),(84,679093998011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','williamjlyall','nascarbayou@yahoo.com','william lyall','402 Crane St','aurora','IL','UNITED STATES','60505-3258','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 00:18:11',0,NULL,3,0,1,1,NULL,'williamjlyall '),(85,509426463003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',61.85,'cnfaner','carlito_green','carlo.gardani@sidel.com','Carlo Gardani','Via Broli Antichi 27','Villafranca di Verona','VR','ITALY','37069','3475970310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 00:44:56',0,NULL,3,1,3,1,NULL,'欧标     再发一个NOKIA_BH-202+Carcharger   HSNO006+CCNO001\rRA022490601CN     carlito_green\r'),(86,754785478012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','langdu_2011','tintran09@yahoo.com','Tin Tran','177 East St','Windsor','CT','UNITED STATES','06095-2408','(860) 882-9016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 00:53:02',0,NULL,3,0,1,1,NULL,'langdu_2011 '),(87,754815274012,220713846482,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 02:54:26',0,NULL,8,0,17,0,NULL,NULL),(88,560104000013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','bitsorbytes','ajpalm@gmail.com','Andrew Palm','27 Montalbo Rd','Ringwood Nth','Victoria','AUSTRALIA','3134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 02:57:05',0,NULL,3,0,3,1,NULL,' RA022490495CN     bitsorbytes'),(89,754816992012,220713846482,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',20.8,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 02:57:11',0,NULL,3,0,3,1,NULL,'一共买了三个    欧标\rRA022490748CN     vasileioslos\r'),(90,515294964004,140427930388,'2.1 Acer Aspire 5536 bluetooth module we offer track#',1,'BTAC2105',16.59,'cnfaner','parcayos','parcayo@hotmail.com','Jose Carlos Barajas','Campeche No. 143 Int.1<br>Colonia Roma sur','Mexico DF.','Mexico DF','MEXICO','06760','5528446773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 06:01:57',0,NULL,3,0,3,1,NULL,'acer 4pin1.25 8cm \rRA022490805CN      parcayos\r'),(91,515092112004,140516807631,'NIB Genuine Altec Lansing M602 iPod Speaker System nano',1,'SPAL001',117,'cnfaner','tamlyly','tam_lee1@yahoo.com','Tam le','14941 dillow st','westminster','CA','UNITED STATES','92683-5910','(714) 684-4185','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 06:26:06',0,NULL,3,0,4,1,NULL,'\rYW864871250CN'),(92,560134412013,230490512845,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','forme2509','tranquoctri@hotmail.com','Tri Tran','10111 Woodico Dr','Houston','TX','UNITED STATES','77038-2435','(832) 677-3666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 06:27:36',0,NULL,3,0,1,1,NULL,'forme2509 '),(93,509484314003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','mathewcb1','mathewcb@hotmail.com','Mathew Bevis','230 Forrest Avenue','Winnipeg','MB','CANADA','R2V 1K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:36:10',0,NULL,3,0,3,1,NULL,'RA022490527CN      mathewcb1\r '),(94,509493671003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','dgrkee9280','dgrkee@hotmail.com','Daniel Kee','3/36 Bream St<br>Coogee','Sydney','New South Wales','AUSTRALIA','2034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 08:38:58',0,NULL,3,0,3,1,NULL,'RA022490734CN\r dgrkee9280'),(95,754890196012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','steveb3836','highview56@sky.com','steve brazill','56 arundel road','newhaven','East Sussex','UNITED KINGDOM','bn9 0nf','01273517084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 08:49:58',0,NULL,3,0,2,1,NULL,'steveb3836 '),(96,560162262013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','gabor.kovacs','gabriel.sintes@gmail.com','Gabriel Sintes','Avda. Canaletas 41 6 2a','Cerdanyola','Cataluña','SPAIN','08290','638024945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 09:30:38',0,NULL,3,0,2,1,NULL,' CAB-6060     gabor.kovacs'),(97,515366802004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','mollaguliev','mollaguliyev@gmail.com','Orkhan Mollaguliyev','Yeni Guneshli, A/B 129, 95','Baku','','AZERBAIJAN','1133','+994556575310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 13:19:54',0,NULL,3,0,3,1,NULL,' RA022490646CN      mollaguliev'),(98,509556854003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','miamimegahz','jeffrey.heerts@kaplanzeena.com','Jeffrey Heerts','2 S Biscayne Blvd<br>Ste 3050','Miami','FL','UNITED STATES','33131-1808','(305) 530-0800 ext.: 1002','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 14:06:33',0,NULL,3,0,1,1,NULL,'miamimegahz '),(99,515392560004,140442124370,'2.0 dell mini 9 J613H bluetooth module Track#4eachorder',2,'BTDE2001',25.6,'cnfaner','snuggledog12','smithgl4@austin.rr.com','Geoffrey Smith','5910 Cape Coral Dr','Austin','TX','UNITED STATES','78746-7268','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:06:22',0,NULL,3,0,1,1,NULL,'snuggledog12\r 、'),(100,509571656003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','joinermike','joinerm@comcast.net','Michael Joiner','4539 Hawk Woods Dr','West Bloomfield','MI','UNITED STATES','48322-4571','(248) 737-5505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:11:10',0,NULL,3,0,1,1,NULL,'joinermike '),(101,509576350003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','gecko6375','marc@mnfamily.org','marc baker','1512 132nd Ln NW','Coon Rapids','MN','UNITED STATES','55448-7102','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 15:19:47',0,NULL,3,0,1,1,NULL,'gecko6375 '),(102,509582953003,130458050482,'NIB Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL004',23.9,'cnfaner','barakm22','barakmor22@walla.co.il','barak mor','alenbi 88','haifa','israel , haifa , kiryat eliezer','ISRAEL','35666','0545271164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:44:22',0,NULL,3,0,3,1,NULL,' RA022490500CN       barakm22'),(103,560252826013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'eastar4','ejviana1981','ejviana@gmail.com','Edgar Viana','Av. Dr. Afonso Vergueiro, 2738<br>Salas 1/2 (Caixa) - Bairro Vila Augusta','Sorocaba','Sao Paulo','BRAZIL','18040-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:52:51',0,NULL,3,0,2,1,NULL,' 旧的    ejviana1981'),(104,755068318012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','paprotka15marta','paprotka15@buziaczek.pl','Marta Kurdziel','84 Macnaghten Road <br>hampshire','Southampton','Hampshire','UNITED KINGDOM','So18 1Gj','07856286335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 16:55:19',0,NULL,3,0,2,1,NULL,'英标头       paprotka15marta'),(105,509611755003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','doronmerdinger2008','doron@doronmerdinger.com','Doron Merdinger','9 Ha-erez st','Karmey Yosef','Israel','ISRAEL','99797','+972544820820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:15:47',0,NULL,3,0,3,1,NULL,' RA022490589CN      doronmerdinger2008'),(106,755084193012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','carlos6725','carlos83@ebuyclub.com','Carlos Maia Vieira','408 chemin de la coualo','Vidauban','Provence-Alpes-Côte d\'Azur','FRANCE','83550','0494731580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:24:41',0,NULL,3,0,2,1,NULL,' 旧的      carlos6725'),(107,515440209004,140433914756,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','dimitris_biziouras','current94@gmail.com','Dimitrios Biziouras','Ioanninon 39<br>Voula','Athens','Attiki','GREECE','166 73','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:42:23',0,NULL,5,0,18,0,NULL,' '),(108,755118282012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',39.98,'eastar4','acaddesign','acaddesign@cox.net','Richard G. Horvath','27151 Neda','Mission Viejo','CA','UNITED STATES','92692','(949) 582-3745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 18:25:12',0,NULL,5,0,1,1,NULL,'acaddesign '),(109,560308512013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',119.99,'eastar4','lustigjm','julian-lustig@hotmail.com','Julian Lustig','16 Creekside Drive<br>PO Box 599','St.David\'s','ON','CANADA','L0S1P0','(289) 296-2785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:26:47',0,NULL,3,0,3,1,NULL,'   lustigjm\rRA022497701CN'),(110,515454484004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',17.99,'cnfaner','ng_mow','ngondaryov@mail.ru','Nikolay Gondaryov','app.55, 11A, Zoi i Alexandra<br>Kosmodemyanskih street','Moscow','Moscow region','RUSSIAN FEDERATION','125130','+79166955040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:27:00',0,NULL,3,0,3,1,NULL,'RA022490561CN        ng_mow\r '),(111,755128684012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',22.9,'eastar4','packageradio','paule-panzer@gmx.net','Benedikt Schleusener','Brunnenäcker 18','Heldenfingen','','GERMANY','89547','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:42:54',0,NULL,3,0,2,1,NULL,'再发一个 3G WWAN antenna   ANCN001     packageradio'),(112,515260641004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sparklegirl924','krlombardo@gmail.com','Kristen Lombardo','37 Driggs Ave<br>Apt 2B','Brooklyn','NY','UNITED STATES','11222-4512','(347) 752-2399','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 18:54:02',0,NULL,3,0,1,1,NULL,'sparklegirl924 '),(113,515474753004,140481828186,'New Plantronics Voyager Pro Bluetooth Headset+carcharge',1,'HSPL013+CCPL001',47.9,'cnfaner','richier80','richier@paradise.net.nz','Richard Reynolds','73 Ohariu Road<br>Johnsonville','Wellington','','NEW ZEALAND','6037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:19:45',0,NULL,3,0,3,1,NULL,' RA022490615CN      richier80'),(114,509653070003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',48.98,'cnfaner','slider_spb','antonov_mail@mail.ru','Anatoly Antonov','Turistskaja, dom 2, kv. 96','St-Petersburg','St-Petersburg','RUSSIAN FEDERATION','197374','+79052255598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:24:11',0,NULL,3,0,3,1,NULL,' RA022490650CN       slider_spb'),(115,515486774004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','kleclerc3','kleclerc3@verizon.net','Kellie Leclerc','22 Adams St','Silver Creek','NY','UNITED STATES','14136','(716) 934-3408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 19:54:36',0,NULL,3,0,1,1,NULL,'kleclerc3 '),(116,755206917012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','irene12111','mvb@onetoonerealty.com','Michael Von Bank-','3844 Bexley Sq','Reno','NV','UNITED STATES','89503-1819','(775) 287-4027','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-12 20:54:47',0,NULL,3,0,1,1,NULL,'irene12111 '),(117,515514367004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','algisavia','algis_kr@yahoo.com','Algimantas Krikscikas','1592 Canterbury Rd N','Saint Petersburg','FL','UNITED STATES','33710-5658','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 21:13:20',0,NULL,3,0,1,1,NULL,'algisavia '),(118,755227175012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','webwebes','alejandro_spa@hotmail.com','Alejandro Alvarez Ramos','C/Juan I Portugal 1 Blq.2, 6ºb (Residencial Larios)','Ceuta','Ceuta','SPAIN','51001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 21:32:59',0,NULL,3,0,3,1,NULL,' RA022490751CN      webwebes'),(119,509709233003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','ebuyer_uy','vendoxml@gmail.com','Ernesto Mariani','Canelones 1804','Montevideo','','URUGUAY','11200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:00:57',0,NULL,3,0,3,1,NULL,' RA022490703CN      ebuyer_uy'),(120,679525679011,320394892477,'Acer Aspire 5235 5335 5535 Bluetooth Module 2.0 +cable',1,'BTAC2005',14.49,'eastar4','joaquinal','donjoaquinal@yahoo.com','joaquin aldeguer quintana','c/ colegial nº 15 5º aptº 51','torremolinos','Malaga','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:17:03',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 8cm       joaquinal'),(121,515542336004,140428348853,'2.1 Acer Aspire 4730Z bluetooth module we offer track#',1,'BTAC2120',16.59,'cnfaner','skwarkenklux','prof.skwarkenklux@gmail.com','Michael Carver','1577 N Linder rd<br># 108','Kuna','ID','UNITED STATES','83634','(208) 859-9343','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 22:56:21',0,NULL,3,0,1,1,NULL,'acer 8pin1.0 6cm      skwarkenklux'),(122,679549720011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','websterh','beknweb@gmail.com','Weber Hsu','661 South Pine Road','Everton Park','Queensland','AUSTRALIA','4053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 23:27:40',0,NULL,3,0,2,1,NULL,'websterh '),(123,560425746013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','ungaulois2926','ungaulois@hotmail.com','Mario Ouellette','2926 Carré des argiles','Quebec','QC','CANADA','G2C1K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 00:28:08',0,NULL,3,0,2,1,NULL,'ungaulois2926 '),(124,560424314013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27.16,'eastar4','senatordl','sendl1@verizon.net','Richard LaRossa','150 Bull Run Rd','Ewing','NJ','UNITED STATES','08638-1316','(609) 882-1071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 00:46:12',0,NULL,3,0,1,1,NULL,'senatordl '),(125,515569166004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','marandayoung','marandayounger@yahoo.com','maranda younger','103 Ross Ln','vicksburg','MS','UNITED STATES','39180','(601) 218-9401','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 01:05:44',0,NULL,3,0,1,1,NULL,'marandayoung '),(126,679580192011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',9.99,'eastar4','ltlopes1vk0','ltlopes@gmail.com','Leandro Lopes','Av. Protasio Alves, 1205','Pinheiro Machado','Rio Grande do Sul','BRAZIL','96470-000','55 53 91036993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 01:13:37',0,NULL,3,0,2,1,NULL,'ltlopes1vk0 '),(127,560325832013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','kparise10','ken.parise@wgint.com','Kenneth Parise','11214 Lynbrook Dr','Houston','TX','UNITED STATES','77042','(832) 247-4069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 01:46:51',0,NULL,3,0,1,1,NULL,'kparise10 '),(128,560447081013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','basketball*wildcat','scootswv@insightbb.com','scott vittitow','8107 Florist Rd','louisville','KY','UNITED STATES','40228-2206','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 02:08:16',0,NULL,3,0,1,1,NULL,'basketball*wildcat '),(129,515584046004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','bensau2003','bensau@acn.net','Benoit Sauvageau','212, rue de l\'Estran','Lachenaie','QC','CANADA','J6W 6A1','(450) 471-6424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 02:25:59',0,NULL,3,0,3,1,NULL,'RA022490725CN\r bensau2003'),(130,560462270013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',20.98,'eastar4','corinthiancobra','paschal304@verizon.net','Sam Paschal','304 Vickery Way','Denton','TX','UNITED STATES','76210-5271','(817) 368-6697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 03:25:22',0,NULL,3,0,1,1,NULL,'corinthiancobra '),(131,679619704011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','c_gadgetz','custom.gadgetz@gmail.com','David Mathews','30 Wakelin Circuit','Weston creek','Australian Capital Territory','AUSTRALIA','2611','0432288824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 03:54:08',0,NULL,3,0,2,1,NULL,'c_gadgetz '),(132,509786909003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','svorbei','zvorbei@gmail.com','Shan Qiu','515 Jackson Ave','Vancouver','BC','CANADA','V6A 3W2','(604) 255-5526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 04:40:57',0,NULL,3,0,3,1,NULL,'RA022490677CN       svorbei\r '),(133,755380365012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',24.99,'eastar4','baandrews10','baandrews@gmail.com','Olivier Simard','1021 Lund Road','Houston','BC','CANADA','V0J1Z1','(250) 845-2447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 06:21:22',0,NULL,3,0,2,1,NULL,'baandrews10 '),(134,755392010012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',19.99,'eastar4','dcheng-117','kaheng117@yahoo.com','david  cheng','407 Silverdale Dr','pomona','CA','UNITED STATES','91767-1427','(626) 484-5350','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 07:12:19',0,NULL,3,0,1,1,NULL,'dcheng-117 、'),(135,560516730013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','xale21','aagogin@gmail.com','Alexey Gogin','Kulikova street, house № 77, flat № 3','Astrakhan','RU','RUSSIAN FEDERATION','414041','7-9170-8512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:10:24',0,NULL,3,0,2,1,NULL,'欧标头 银色的    xale21'),(136,515650807004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','mbhand','madddy84@gmail.com','MADHUKAR BHANDARI','#FC, MODERN VIEW APRTMENT<br>4TH MAIN CHANNAPANNAHALLI','BANGALORE','KA','INDIA','560037','919900056463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:38:18',0,NULL,3,0,3,1,NULL,'RA022490632CN     mbhand\r '),(137,755442031012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.6,'eastar4','testbenzin','oelnase@freenet.de','Peter Neu','A-S-R 5a','Itzehoe','','GERMANY','25524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 09:57:13',0,NULL,3,0,2,1,NULL,'欧标头      testbenzin'),(138,509840557003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','marting811','martingruen@aon.at','Martin Grün','Platti 317','Kappl','','AUSTRIA','6555','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 10:06:26',0,NULL,3,0,3,1,NULL,'欧标 \rRA022490629CN    marting811\r'),(139,755085945012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',49.98,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 10:56:21',0,NULL,3,0,3,1,NULL,' RA022490535CN    solopo2009'),(140,679756650011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4','deluxdealz','deluxfla@gmail.com','Chris Brownell','9210 SW 3rd St<br>Apt 201','Boca Raton','FL','UNITED STATES','33428-4565','(561) 213-7601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 11:55:40',0,NULL,3,0,1,1,NULL,'deluxdealz '),(141,560569371013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',89.9,'eastar4','krazy-jack','crazyjack@bigpond.com','Gordon Bogdanoski','12 RIBBONWOOD RD','UNANDERRA','New South Wales','AUSTRALIA','2526','0242724888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:06:20',0,NULL,3,0,3,1,NULL,' RA022490558CN     krazy-jack'),(142,755503073012,220748081734,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',19.99,'eastar4','501sharon56','lewis7797@sbcglobal.net','Sharon Lewis','6509 Pecan Ln','Little Rock','AR','UNITED STATES','72206','(501) 490-0233','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 12:07:36',0,NULL,3,0,1,1,NULL,'501sharon56 '),(143,560575362013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','raptor_htk','stefantomaschek@web.de','Stefan Tomaschek','Im Haindell 105','Sulzbach am Taunus','','GERMANY','65843','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:26:25',0,NULL,3,0,2,1,NULL,'raptor_htk '),(144,560587552013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','ken86c','kennethtse@live.com.au','Kenneth Tse','Level 7 NW<br>105-153 Miller Street','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 13:02:04',0,NULL,3,0,3,1,NULL,' RA022490442CN      ken86c'),(145,560611153013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'eastar4','d_peter','p.duscha@gmx.net','Peter Duscha','Künnestr.1a','Düsseldorf','other','GERMANY','40625','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:07:48',0,NULL,3,0,2,1,NULL,'d_peter '),(146,515744669004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','gleb-den','glebden@gmail.com','Gleb Denisov','Baykalskaya, 14/2, 21','Moscow','Moscow','RUSSIAN FEDERATION','107241','+79032096320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:46:21',0,NULL,8,0,17,0,NULL,NULL),(147,560627390013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'eastar4','eritonb','sediveneb@gmail.com','Eriton Benevides','rua 21, nr. 500, apto 201, Ed. Indaiá<br>Setor Central','Goiânia','Goiás / Goiânia','BRAZIL','74030070','+556232234688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:52:39',0,NULL,3,0,2,1,NULL,'eritonb '),(148,509918135003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','gleb-den','glebden@gmail.com','Gleb Denisov','Baykalskaya, 14/2, 21','Moscow','Moscow','RUSSIAN FEDERATION','107241','+79032096320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:52:51',0,NULL,3,0,3,1,NULL,'再发一个Atheros AR5008 旧的 WLAT002 \rRA022490717CN     gleb-den\r'),(149,560636042013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','legionovo','grzegorz.daniluk@wystroje.eu','Grzegorz Daniluk','Warszawska 57','Legionowo','mazowieckie','POLAND','05-120','601 555999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:15:35',0,NULL,3,0,2,1,NULL,'\r 银色的和白色的     '),(150,560647626013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.9,'eastar4','okauf','okauf@arcor.de','Ralf Ohmayer','Hauptstraße 17','Isny - Großholzleute','other','GERMANY','88316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:39:47',0,NULL,3,0,3,1,NULL,' RA022490411CN'),(151,677384758011,320666253128,'INOVA T4 LED FLASHLIGHT TORCH + new charger',1,'BAIN002+TOIN002',55.9,'eastar4','robgalvez187','robgalvez1@yahoo.com','Carole Galvez','58227 S. 299th Ave','Gila Bend','AZ','UNITED STATES','85337','(623) 764-6224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 15:45:02',0,NULL,3,0,1,1,NULL,'RA022490544CN      robgalvez187'),(152,755712775012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','neural69','aj.norcross@yahoo.co.uk','Alastair Norcross','151 Glenfrome Rd<br>Eastville','Bristol','Bristol','UNITED KINGDOM','BS5 6XF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 17:37:57',0,NULL,3,0,2,1,NULL,'neural69 '),(153,510002551003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','underwoj','jamesrobertunderwood@yahoo.com','James R Underwood','140 Berkshire Ln','Waxahachie','TX','UNITED STATES','75165-4811','(469) 337-2779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 17:48:58',0,NULL,3,0,1,1,NULL,'underwoj '),(154,679975966011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','elyase','yaser.martinez@gmail.com','Ella Gramm','Schubertstrasse 26','Gedern-Wenings, Hessen','','GERMANY','63688','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 17:59:17',0,NULL,3,0,3,1,NULL,'RA022490544CN      elyase'),(155,515472694004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','burnsmark','mtburns1@verizon.net','Mark Burns','9711 Wyman Way','Upper Marlboro','MD','UNITED STATES','20772','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 18:10:40',0,NULL,3,0,1,1,NULL,'burnsmark '),(156,510056258003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','lycan_nl','wingtai_chan@hotmail.com','Wing Tai Chan','Vaillantlaan 322','Den Haag','','NETHERLANDS','2526 HT','0646103503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 18:49:57',0,NULL,3,0,3,1,NULL,'RA022490425CN     lycan_nl'),(157,560789929013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','roik11','ivan4enko-roik@yandex.ru','Elena Ivanchenko-Roik','Bratskaya 1/45 flat.30','Moscow','Moscow','RUSSIAN FEDERATION','111141','+79067269810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:17:20',0,NULL,3,0,2,1,NULL,'欧标头 roik11、'),(158,515898792004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','whichwayisfriday','keithlaface@gmail.com','Keith LaFace','24 Paulman Cir','West Roxbury','MA','UNITED STATES','02132-1223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 19:18:11',0,NULL,3,0,1,1,NULL,'whichwayisfriday '),(159,515912108004,140442124370,'2.0 dell mini 9 J613H bluetooth module Track#4eachorder',1,'BTDE2001',12.8,'cnfaner','paz-man','pasi.pinta@gmail.com','Pasi Pinta','4322 Mapleward Road','Thunder Bay','ON','CANADA','P7K 1A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:39:17',0,NULL,3,0,3,1,NULL,'RA022490592CN     paz-man\r'),(160,515929001004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','asafsapira11','asafsapira@walla.com','asaf sapir','hagalil st. 114a','haifa','','ISRAEL','32683','0502795137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:17:58',0,NULL,3,0,3,1,NULL,'    asafsapira11\rRA022497556CN'),(161,755931862012,220705174913,'Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO014',19.95,'eastar4uk','karen7c','karenmc_25@hotmail.co.uk','Karen McCrory','31 Harrogate Street','Belfast','Antrim','UNITED KINGDOM','BT12 7AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 20:52:19',0,NULL,3,0,3,1,NULL,' 英标       karen7c\rRA022497471CN\r'),(162,516002763004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','mancari1','fmancari@aol.com','Frank Mancari','307 Palmer Dr','North Syracuse','NY','UNITED STATES','13212','(315) 458-4024','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:47:53',0,NULL,3,0,1,1,NULL,'mancari1 '),(163,560924295013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','lukie4me','bocanegra_4@yahoo.com','Elizabeth Laniohan','3725 NW Poplar Ave','Redmond','OR','UNITED STATES','97756-8158','(541) 480-0398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-13 23:47:56',0,NULL,3,0,1,1,NULL,'lukie4me '),(164,516023654004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',37.95,'cnfaner','cjowett','kt@odcia.org','Kristoffer Tjensvoll','Øvrevollveien 54','Bærum','Akershus','NORWAY','1358 Jar','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:08:06',0,NULL,3,0,3,1,NULL,'cjowett \rRA022497423CN\r'),(165,680017116011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','mojdeh321','mojdeh321@yahoo.ca','mojdeh mahmoudian','45 pixley private Ottawa ont ','Ottawa','ON','CANADA','k1G 4C3','(613) 421-5009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:14:53',0,NULL,3,0,3,1,NULL,' RA022490558CN        mojdeh321'),(166,680264592011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','supercuban89','supercuban89@yahoo.com','Esteban Betancourt','4953 W Eddy St','Chicago','IL','UNITED STATES','60641-3550','(773) 685-8012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 00:38:26',0,NULL,3,0,1,1,NULL,' RA022490535CN supercuban89'),(167,560942069013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','layinlowcivic','sdhonda153@hotmail.com','Steve Cockburn','1805 Kenny Ave','Champaign','IL','UNITED STATES','61822-6808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 00:48:20',0,NULL,3,0,1,1,NULL,'layinlowcivic '),(168,756064919012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',2,'MOLO001',130,'eastar4','skofarrell','skofarrell@yahoo.com','Sean O\'Farrell','1106 E 82nd St','Indianapolis','IN','UNITED STATES','46240','(317) 292-7660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:08:13',0,NULL,3,0,1,1,NULL,'skofarrell '),(169,680279336011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',20.98,'eastar4','krissymain','mmain@cmfiber.com','Michael Main','1525 Riviera Dr','Pasadena','Ca','UNITED STATES','91107-1663','(951) 237-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:20:17',0,NULL,3,0,1,1,NULL,'krissymain '),(170,560952504013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','outofexcile','curtness@hotmail.com','curt perehudoff','22 davidson cres','saskatoon','SK','CANADA','s7l 4a1','(306) 382-3379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:23:04',0,NULL,3,0,2,1,NULL,'outofexcile '),(171,680282304011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','dbastin','donbastin@gmail.com','Don Bastin','83 W Garfield Ave','Martinsville','IN','UNITED STATES','46151-2416','(765) 342-3838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 01:24:55',0,NULL,3,0,1,1,NULL,'dbastin '),(172,560959630013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','cyberuncle2010','rarid2005@yahoo.com','Sanjeev Nayyar','5 Maddybeth Crescent<br>(Basement)','Brampton','ON','CANADA','L6Y5R7','(416) 273-8766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:46:17',0,NULL,3,0,2,1,NULL,'银色的 cyberuncle2010、'),(173,510253598003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',10.79,'cnfaner','sbubandit','sbubandit@hotmail.com','Peter Reddish','281 Pompano Ct.','Lapeer','MI','UNITED STATES','48446','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 02:53:59',0,NULL,3,0,1,1,NULL,'sbubandit '),(174,560981577013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','cr1sch','crsch@telus.net','Charles Schmidt','#307, 8903 - 106 A Avenue','Edmonton','AB','CANADA','T5H 3Y7','(780) 425-7973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 02:58:24',0,NULL,3,0,3,1,NULL,' cr1sch\rRA022497445CN\r'),(175,756121599012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',65,'eastar4','kml246','shadow1970@verizon.net','mel matthews','11671 Whitetail Dr','marilla','NY','UNITED STATES','14102-9710','(716) 853-5000 ext.: 18','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 03:33:20',0,NULL,3,0,1,1,NULL,'kml246÷÷ '),(176,510263159003,130493246602,'Logitech harmony Li-ion Rechargeable Battery 930mAh',1,'BALO002',10.5,'cnfaner','vitoa4747','vitoa4747@hotmail.com','Vito Alfino','42 Crestlawn Gate','Woodbridge','ON','CANADA','L4H 0H8','(905) 265-2359','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 03:37:24',0,NULL,3,0,3,1,NULL,'vitoa4747 \rRA022497437CN'),(177,510265765003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',22,'cnfaner','ttschida11','toddtschida@comcast.net','Todd Tschida','740 N Hay Lake Rd','Eagan','MN','UNITED STATES','55123-3024','(651) 457-2881','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 03:51:41',0,NULL,3,0,1,1,NULL,'ttschida11 '),(178,516091688004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','nissi6k','bjjeon@samaneng.com','Jeon beom-jin','706-206,Mugunghwa Kunyoung Apt., Sinchon-dong, Dongan-gu','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-791','82-10-6202-2740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 05:28:12',0,NULL,3,0,3,1,NULL,'nissi6k \rRA022497366CN'),(179,559532258013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',16.59,'eastar4','vojak.p','p.rubas@seznam.cz','Pavel Rubáš','Týnec 46','Janovice nad Úhlavou','Janovice nad Úhlavou','CZECH REPUBLIC','34021','724958271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 07:32:31',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 15cm    vojak.p'),(180,510294609003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','stu2565','sfellows@iprimus.com.au','stuart fellows','2565 helena valley rd','helena valley','Western Australia','AUSTRALIA','6056','0892552467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 07:56:45',0,NULL,3,0,3,1,NULL,'stu2565 \rRA022497485CN'),(181,756176391012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','bulzache','florin.cioponea@gmx.com','florin cioponea','Drm. Padurea Pustnicu nr.141B bl. RU37 et.2 ap.6','bucuresti','sector 1','ROMANIA','014042','0040729100276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 08:04:44',0,NULL,3,0,2,1,NULL,'bulzache '),(182,756182555012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','enfant_des_dieux','goulven.riant@laposte.net','Goulven RIANT','7, Avenue Parmentier<br>SUPINFO','Toulouse','Midi-Pyrénées','FRANCE','31200','0699334951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 08:32:36',0,NULL,3,0,2,1,NULL,'enfant_des_dieux '),(183,516121248004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',32.8,'cnfaner','er_garry','er_garry@hotmail.com','Alejandro Garrido Suárez','Jenaro de la Fuente<br>Nº44,6ºA','Vigo','Pontevedra','SPAIN','36205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 09:54:58',0,NULL,3,0,3,1,NULL,'er_garry \rRA022497975CN'),(184,756242197012,220477365327,'UNLOCKED Option GTM382 PCI-E Modem WWAN GTM 382+antenna',1,'WWOP003+ANCN001',48.59,'eastar4','girbucks','g_morales_84@yahoo.com','Gilbert S Morales','293 Arandia St., Wildcat Vill., Brgy. Ususan','Taguig','','PHILIPPINES','1634','6323810782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:11:19',0,NULL,3,0,3,1,NULL,'girbucks                                     \r\r客户的新地址：\r\rGilbert S Morales\r293 Arandia St., Wildcat Vill., Brgy. Ususan\rTaguig  1634\rPHILIPPINES\r6323810782    \r                                         postal office @ Taguig Postal Office, Metro Manila, PH c/o Gilbert Morales\rRA022497661CN\r'),(185,680448685011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','biddie58','t.eggins@sky.com','Tim Eggins','18 Minehurst Road<br>MYTCHETT','CAMBERLEY','SURREY','UNITED KINGDOM','GU16 6JP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:49:53',0,NULL,3,0,2,1,NULL,'biddie58 \rRA022493639CN'),(186,680448812011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',10,'CASS003',87,'eastar4','andre.iacono','lorenalive@hotmail.co.uk','Andre Iacono de Souza','SRTVS, Qd 701 - Bloco K - Sala 303<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','556186120228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:57:59',0,NULL,3,0,3,1,NULL,'andre.iacono \rRA022497542CN\r'),(187,680461622011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',14.49,'eastar4','dj-ghost','djglhlost@yahoo.com','Bryan Enciso','1000 South 2nd Street<br>AF Supply - Quality Warehouse','Harrison','NJ','UNITED STATES','07029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 13:32:12',0,NULL,3,0,1,1,NULL,'acer 4pin1.25 15cm     dj-ghost'),(188,756277235012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','pedro_vitorino','pedro.vitorino@gmail.com','Pedro Miguel Vitorino','Rua das Palmeiras, 13 - 1º Andar','Alcantarilha','','PORTUGAL','8365-021','+351964685450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 14:00:41',0,NULL,3,0,3,1,NULL,'pedro_vitorino     \rRA022497750CN'),(189,561097335013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','den6749','denmy501@hotmail.com','chai chang yu','148/38<br>Mount Alexander Road','Travancore','Victoria','AUSTRALIA','3032','0423347433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:05:30',0,NULL,3,0,2,1,NULL,'den6749 '),(190,756308829012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','oscarpt1981','oscarpt1981@yahoo.es','OSCAR PEREZ TIRADO','CALLE VILLALMANZO, NUM 5, 3º C','MADRID','Madrid','SPAIN','28032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 15:21:35',0,NULL,3,0,3,1,NULL,'oscarpt1981 \rRA022497967CN'),(191,510381133003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','davilar74','davilar74@yahoo.com','nigel davilar','14460 40th place north','plymouth','MN','UNITED STATES','55446','(763) 566-2344','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 15:43:53',0,NULL,3,0,1,1,NULL,'davilar74 '),(192,510395015003,130458050899,'New GENUINE Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',44.9,'cnfaner','alexnochmal','alexnochmal@inbox.ru','Alex N','Semenov<br>Tchebysheva 6-628','Ekaterinburg','Sverdolvskaya','RUSSIAN FEDERATION','620062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 16:35:58',0,NULL,5,0,3,1,NULL,'欧标 alexnochmal'),(193,561143082013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'eastar4','nightwolf-ng','nightwolf_ng@mail.ru','Kirill Burliaev','8-4-31 Gerasima Kurina street','Moscow','Moscow City','RUSSIAN FEDERATION','121108','+79851445596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 17:02:03',0,NULL,3,0,2,1,NULL,'nightwolf-ng '),(194,756370967012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','koren.zitser','korenzitser@hotmail.com','koren zitser','hava lutski 9/9','rehovot','merkaz','ISRAEL','76251','972524772300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 17:43:41',0,NULL,3,0,2,1,NULL,'koren.zitser '),(195,756388333012,220477365327,'UNLOCKED Option GTM382 PCI-E Modem WWAN GTM 382+antenna',1,'WWOP003+ANCN001',53.49,'eastar4','jedrzej.marszalkowski','gollum@reddragon.pl','Jędrzej Marszałkowski','Bagienna 2','Sieradz','łódzkie','POLAND','98200','503 113445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 18:16:26',0,NULL,3,0,3,1,NULL,'再发一个3G antenna ANCN001       jedrzej.marszalkowski\rRA022497410CN\r'),(196,561190160013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','pythqn','darvishzadeh@gmail.com','Mostafa Darvishzadeh S.','A-5-3, Arena Green, Bukit Jalil','Kuala Lumpur','WP Kuala Lumpur','MALAYSIA','57000','0173838411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 19:02:05',0,NULL,3,0,2,1,NULL,'pythqn '),(197,756421439012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','p0lpot','namitakirin@gmail.com','John F Schwamlein','906 Villa Venicia Way','Tampa','FL','UNITED STATES','33606-3406','(813) 508-7320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 19:06:18',0,NULL,3,0,1,1,NULL,'p0lpot '),(198,680652559011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',16.59,'eastar4','javgim78','javgim78@ono.com','Javier Gimeno','Magistrado Monterde 7, 9','Torrente','Comunidad Valenciana','SPAIN','46900','686278183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 20:35:02',0,NULL,3,0,2,1,NULL,'acer 4pin1.25 6cm    javgim78'),(199,561249674013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',5,'CASS001',43.5,'eastar4','sharmack96','sharmack96@yahoo.co.uk','S.P. Filipek','151 Silbury Blvd','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK91LH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 21:16:28',0,NULL,3,0,3,1,NULL,'sharmack96 \rRA022497468CN\r'),(200,510505963003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','rimautay','rimautay@yahoo.com','Richard Taylor','2613 Cordova rd','Orangeburg','SC','UNITED STATES','29115-9247','(803) 269-7155','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 21:43:57',0,NULL,3,0,1,1,NULL,'rimautay '),(201,680692594011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','2gbwhitman','togbwhitman@hotmail.com','Gregory Whitman','5822 Dusty Heath Ct','Katy','TX','UNITED STATES','77450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 21:50:37',0,NULL,3,0,1,1,NULL,'2gbwhitman '),(202,680695063011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',12.95,'eastar4','rm_hurst','rm_hurst@yahoo.com','Rob Hurst','1500 S Jupiter Rd<br>Apt 1011','ALLEN','TX','UNITED STATES','75002-4144','(214) 383-3257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-14 21:56:52',0,NULL,3,0,1,1,NULL,'rm_hurst '),(203,680697807011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',29.98,'eastar4','moses10777','rolf_030@gmx.net','Peter Pilz','Motzstr. 22<br>abgeben in The JAXX,Motzstr.19,ab 12 Uhr geöffnet','Berlin','','GERMANY','10777','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:03:30',0,NULL,3,0,3,1,NULL,'moses10777 \rRA022497675CN'),(204,561268335013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'eastar4','webwebes','alejandro_spa@hotmail.com','Alvaro Castilla','Plaza Europa Nº7 ; 1ºDcha','Torrejon de Ardoz','Madrid','SPAIN','28850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:10:56',0,NULL,3,0,3,1,NULL,'webwebes \rRA022497953CN\r'),(205,510516990003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','one813','raiseone@aol.com','Fred serrano','2960 drew st apt 1021','clearwater','FL','UNITED STATES','33759','(727) 831-7183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 22:22:20',0,NULL,3,0,1,1,NULL,'one813 '),(206,756556155012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',10.49,'eastar4','alexandre_cgr','alexandrepalhares@gmail.com','Alexandre Garcia Palhares','maria madalena','campo grande,','mato grosso do sul','BRAZIL','79004360','+55 67 33821690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 23:20:52',0,NULL,3,0,3,1,NULL,'alexandre_cgr \rRA022497746CN'),(207,753426721012,220750775183,'NEW seal SAMSUNG WIS09ABGNX/XTT WIS09ABGN Wi-Fi Adapter',1,'',69.99,'eastar4','skramdan','dantheskram@yahoo.com.au','daniel marks','19 delphi court<br>rossmoyne','perth','Western Australia','AUSTRALIA','6148','0894577924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 23:13:23',0,NULL,3,0,3,1,NULL,'skramdan \rRA022497984CN'),(208,756577704012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','lwonpurpose','lwhite@pcsii.com','Larry White','14 Highland Park Dr','Highland','AR','UNITED STATES','72542-9324','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 00:05:47',0,NULL,3,0,1,1,NULL,'lwonpurpose '),(209,516358719004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','prodinet.computacion','snc1972@hotmail.com','Sergio Czop','Carlos Pellegrini 650','Quilmes','Buenos Aires','ARGENTINA','1878','011 42545000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 00:25:33',0,NULL,3,0,3,1,NULL,'prodinet.computacion \rRA022497882CN'),(210,756584483012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','kaydonwelder334','kaydonwelder@yahoo.com','Scotty Daniel','1080 County Road 26','Roanoke','AL','UNITED STATES','36274','(334) 863-6955','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 00:28:33',0,NULL,3,0,1,1,NULL,'kaydonwelder334 '),(211,510555533003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','auctionwidower','ken.ebay@minker.dyndns.org','Ken Mink','12901 Edsel Dr','Raleigh','NC','UNITED STATES','27613','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck   auctionwidower'),(212,680761679011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','dannir0','dan_nir@hotmail.com','Dan Nir','397 Front St. W.<br>Apt. 3310','Toronto','ON','CANADA','M5V 3S1','(647) 216-5988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 01:16:32',0,NULL,3,0,2,1,NULL,'dannir0 、'),(213,680805575011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','1234garyl','garry.leech@internode.on.net','David Veldkamp','1 Collin Court<br>Kingston','Brisbane','Queensland','AUSTRALIA','4114','0424784131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:05:36',0,NULL,3,0,2,1,NULL,'1234garyl \\'),(214,756658728012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','pvt333','phuongtran333@yahoo.com','Phuong V. Tran','18219 Wall St','Carson','CA','UNITED STATES','90746','(714) 670-9038','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 04:49:58',0,NULL,3,0,1,1,NULL,'pvt333  \r发重了   周一再发一个 \\'),(220,756719918012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','tinguely_de','cesar.perera@bluewin.ch','Cesar Perera','Rebmattweg 30','Merlischachen','','SWITZERLAND','6402','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 09:59:22',0,NULL,3,0,2,1,NULL,'tinguely_de、'),(215,561375626013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.99,'eastar4','ca4ho','sanchowork@yandex.ru','Alexander Gutarov','27-Parts\'ezda Str. 4, app.36','Kinel','Samara region','RUSSIAN FEDERATION','446430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 07:25:16',0,NULL,3,0,2,1,NULL,'ca4ho、'),(216,510615537003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','cokivg','k_cuncic@yahoo.com','Krešimir Čunčić','Matice Hrvatske 7','Velika Gorica','CROATIA','CROATIA','10410','095/808-4398','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-15 08:06:59',0,NULL,3,0,3,1,NULL,'cokivg\rRA022497936CN'),(217,516428503004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','marianob9960','mariano.beguer@eu.omron.com','MARIANO BEGUER HORNA','CALLE RIO PEÑÓN 11','GUADALAJARA','Castilla-La Mancha','SPAIN','19005','949881030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:14:31',0,NULL,3,0,3,1,NULL,'marianob9960\rRA022497896CN、'),(218,516430093004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','chrischixxx','maackralf@wtnet.de','Ralf Maack','Rechnung<br>Poppenbütteler Str. 266a','Norderstedt','','GERMANY','22851','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 08:26:12',0,NULL,3,0,3,1,NULL,'chrischixxx\r'),(268,681286643011,320473794410,'New Logitech  battery 1250mAh Harmony remote 1000 1100',1,'BALO003',11.99,'eastar4','mbafalos','alexiosk@cytanet.com.cy','Alexios Koniotis','Tandalidi 3A','Larnaca','Larnaca','CYPRUS','6056','0035799533137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:05:21',0,NULL,3,0,2,1,NULL,'mbafalos、'),(269,516725931004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','brilthor2','john@wice.ca','Jon Wice','Basement<br>144 Emerson St','Hamilton','ON','CANADA','L8S2X9','(253) 753-2095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:29:14',0,NULL,3,0,3,1,NULL,'brilthor2、RA022497834CN'),(270,516561576004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','paoloborghesi','spaceman1973@gmail.com','Paolo Borghesi','16 Rue Mathias Tresch','Luxembourg','','LUXEMBOURG','L-2626','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 08:15:43',0,NULL,3,0,2,1,NULL,'paoloborghesi   欧标、'),(271,510920638003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','igorfarkas','igor.farkas@email.t-com.hr','igor farkas','zvonimirova 16','velika gorica','','CROATIA','10410','+38598392156','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-16 08:17:07',0,NULL,3,0,3,1,NULL,'igorfarkas\rRA022495453CN'),(272,681312863011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','nicolle1031','ndube31@gmail.com','Nicolle Levesque','69 Sigourney St','Bristol','CT','UNITED STATES','06010','(860) 261-4624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 09:14:42',0,NULL,3,0,1,1,NULL,'nicolle1031、'),(273,561732670013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','bergler11','adrian_heel@hotmail.com','Heel Adrian','Oberbach 43','Bach im Lechtal','','AUSTRIA','6653','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:49:52',0,NULL,3,0,3,1,NULL,'bergler11\rRA022496140CN'),(274,516766620004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','zerg_32','serg.karpushev@gmail.com','Serg Karpushev','Chkalovsky 9 28','Saint-Petersburg','','RUSSIAN FEDERATION','197110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:25:14',0,NULL,3,0,3,1,NULL,'zerg_32\rRA022496065CN'),(275,681350150011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','chubuts','alex@chubays.com','Alexander Emshanov','Yauzskaya str. 6/8-41','Moscow','RU','RUSSIAN FEDERATION','109240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:44:52',0,NULL,3,0,2,1,NULL,'chubuts、'),(276,561758690013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','makroae1','christoph.jeker@intergga.ch','Christoph Jeker','Talackerstr. 9','Reinach/BL','','SWITZERLAND','4153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 12:07:24',0,NULL,3,0,3,1,NULL,'makroae1\rRA022496153CN'),(277,561760827013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','monavita75','shelegs@gmail.com','Sergej Seleg','L. Asanaviciutes 48 - 54','Vilnius','Vilniaus','LITHUANIA','04319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 12:18:40',0,NULL,3,0,2,1,NULL,'monavita75           欧标、'),(278,0,230597232803,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','beanman63','tvwcpa@comcast.net','Ted VanderWall','17413 Deer Point Dr','Orland Park','IL','UNITED STATES','60467','(708) 403-9654','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-16 13:16:54',0,NULL,3,0,1,1,NULL,'beanman63、'),(279,561787893013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','art22','artsworkshop1@comcast.net','Arthur J. Sulik','310 E Ridgewood Ave','Galloway','NJ','UNITED STATES','08205-9767','(609) 457-2190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 14:22:24',0,NULL,3,0,1,1,NULL,'art22\\'),(280,681417467011,320586526867,'HP Broadcom BCM94322 4322  mini PCI-E card wifi AGN',1,'WLHP001',18.99,'eastar4','heey09','c.asche@gmail.com','Christoph Asche','Woermannstr 20','Hannover','','GERMANY','30455','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:14:49',0,NULL,3,0,2,1,NULL,'heey09、'),(281,0,320671446937,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'',12.5,'eastar4','n00bhauser','hanky.mei@gmail.com','Georgia Tech Post Office','350 Ferst Drive<br>Attn: Heqing Mei Box #: 325679','Atlanta','GA','UNITED STATES','30332-0001','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 15:20:27',0,NULL,3,0,1,1,NULL,'n00bhauser   RELO002、'),(282,511005414003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','kazu4898','kazuo@e.email.ne.jp','Kazuo MORIOKA','Imajuku 2-12-10-16','Moriyama','Shiga','JAPAN','5240046','817775760421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:39:37',0,NULL,3,0,3,1,NULL,'kazu4898\rRA022496238CN'),(283,516715102004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','caretruck','datauto@hotmail.com','Juan Clemente Sanchez Rodriguez','Ildefonso Vasquez#1310 col. Francisco<br>I. Madero','Monterrey','Nuevo Leon','MEXICO','064560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 15:59:12',0,NULL,3,0,3,1,NULL,'caretruck\rRA022496136CN'),(284,757334159012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY001*3',17.9,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','+380674097000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:04:49',0,NULL,3,0,2,1,NULL,'germanskynet    、'),(285,757238099012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','gena_sh','gena08@gmail.com','shalva pichkhadze','hatsivoni 7-3','nesher','Israel','ISRAEL','38681','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:11:02',0,NULL,3,0,3,1,NULL,'gena_sh\rRA022496309CN'),(286,0,230597229448,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.76,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 16:32:07',0,NULL,3,1,1,1,NULL,'4278dennis     再发一个8V -AC adapter、'),(287,511026606003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','hydoc73','hdwosh@rogers.com','Hy Dwosh','347 Cortleigh Blvd','Toronto','ON','CANADA','M5N1R4','(416) 418-7080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:59:14',0,NULL,3,0,3,1,NULL,'hydoc73RA022496224CN'),(288,681455958011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','cdtan99','charlesdonaldtan@gmail.com','Charles Donald Tan','M/F, ATL Logistics Centre B- Safety<br>Berth 3, Kwai Chung','New Territtory','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 17:05:59',0,NULL,3,0,2,1,NULL,'cdtan99、'),(289,516846696004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','thikalicious68','dionnika1968@yahoo.com','Miranda Vaughn','2622 Lee Road 239','Smiths Station','AL','UNITED STATES','36877-4730','(334) 214-5574','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 17:12:06',0,NULL,3,0,1,1,NULL,'thikalicious68、'),(290,757391809012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','rivell56143','zigen@rkmail.ru','Vacheslav Abramovsky','Bumashnikov 8-8','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','89214650777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:07:04',0,NULL,3,0,2,1,NULL,'rivell56143、'),(291,757396916012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','dread_hunter777','dread86@bk.ru','Sergey Yakushev','Dror56/9','Rishon-Le-Zion','','ISRAEL','75296','+972 547899650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:16:35',0,NULL,3,0,2,1,NULL,'dread_hunter777、'),(292,516703754004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','pcsncards','itznanna@aol.com','curtis Lavin','13841 N 57th St','Scottsdale','AZ','UNITED STATES','85254-3013','(914) 441-8763','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 19:29:23',0,NULL,3,0,1,1,NULL,'pcsncards、'),(293,511095329003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','boscarorudy','rudyboscaro@hotmail.it','enrico boscaro','via chiesa 114<br>gambarare','mira','VE','ITALY','30034','3332675755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:16:32',0,NULL,3,0,3,1,NULL,'boscarorudy  欧标\rRA022496215CN'),(294,681570234011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','alfre1975','alfredo.nunez@terra.es','Esther Saldaña Bernal','CPerdiguero de Burgos 14 5ºC','Burgos','Castilla y León','SPAIN','09003','645774108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:36:03',0,NULL,3,0,2,1,NULL,'alfre1975、'),(295,681569959011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dimjan12','dimjan-12@inbox.lv','Dmitrijs Vaitjulevics','Pavasara gatve 6-54','Riga','','LATVIA','LV1082','(371)29503493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 20:40:08',0,NULL,3,0,2,1,NULL,'dimjan12、'),(296,757464861012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','dimaluk','dima-lukashenko@yandex.ru','Дмитрий Лукашенко','ул.Орловская д.27 кв.10','Брянск','','RUSSIAN FEDERATION','241012','+7(920)6002838','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 20:57:47',0,NULL,3,0,3,1,NULL,'dimaluk\rRA022496079CN'),(297,681590633011,320473794410,'New Logitech  battery 1250mAh Harmony remote 1000 1100',1,'BALO003',11.99,'eastar4','mhandmh','mhx2@bellsouth.net','Michael J. Holmbeck','13526 Emeraldview Dr','Orlando','FL','UNITED STATES','32828','(407) 616-8088','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-16 21:19:40',0,NULL,3,0,1,1,NULL,'mhandmh、'),(298,561927785013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','yaboy1956','buenterprises@yahoo.com','Alvin Wright','8448 Crossland Loop<br>Ste 142','Montgomery','AL','UNITED STATES','36117-0951','(334) 649-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 21:25:41',0,NULL,3,0,1,1,NULL,'yaboy1956   银色的\\'),(299,561944232013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','kesh342','patr1ck342@mail.ru','Dmitry Popov','Moskovskaya street 342/9-56','Brest','Belarus','RUSSIAN FEDERATION','224023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 22:07:39',0,NULL,3,0,2,1,NULL,'kesh342、'),(300,511149088003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',25.98,'cnfaner','herr_mimiker','cesar.parra.r@gmail.com','César Parra','Los Vilos 7855','Santiago','Región Metropolitana','CHILE','8780669','+56982238282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 23:13:36',0,NULL,3,0,3,1,NULL,'herr_mimiker\rRA022496241CN'),(301,561008106013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.99,'eastar4','richlock10','r.lock1@verizon.net','richard lockett','23502 Coyote Springs Dr','diamond bar','CA','UNITED STATES','91765-2621','(909) 612-0735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 23:34:16',0,NULL,3,0,1,1,NULL,'richlock10、'),(302,757568425012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',44,'eastar4','davegees','skillz04@yahoo.com','dave brown','625 caroline dr','norristown','PA','UNITED STATES','19401-3517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 23:54:59',0,NULL,3,0,1,1,NULL,'davegees、'),(303,516976193004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','onlydarling','ravi.saraswat@gmail.com','Ravi Saraswat','53,Tineta Crescent,<br>Scarborough','TORONTO','ON','CANADA','M1S 2Y5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:07:53',0,NULL,3,0,3,1,NULL,'onlydarling\rRA022496272CN  \r'),(304,561977098013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','lien197171','bos157@ziggo.nl','E van den Bos','Egellaan 28','VEENENDAAL','','NETHERLANDS','3903CP','0318553702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:19:14',0,NULL,3,0,2,1,NULL,'lien197171    欧标 \\'),(305,681666945011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','mpronovost1','martin@yaknet.ca','martin pronovost','106 santa','st-jerome','QC','CANADA','j7y4l6','(450) 436-9923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:50:50',0,NULL,3,0,3,1,NULL,'mpronovost1RA022496365CN   '),(306,681668686011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','tdhalbert','thalbert@yahoo.com','Tom Halbert','Box 563 - 1023 Creekside Village<br>500 Adelaide St.','Pincher Creek','AB','CANADA','T0K1W0','(403) 627-2411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:57:51',0,NULL,3,0,2,1,NULL,'tdhalbert\\'),(307,561982545013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','wit-sh','wit_sh@gmx.net','Pisec GmbH, vitali chichkine','Goettweihergasse 1/8','wien','','AUSTRIA','1010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 01:06:34',0,NULL,3,0,2,1,NULL,'wit-sh   欧标、'),(308,0,230597232246,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.25,'eastar4','dsharp101','jdavis6825@aol.com','joseph davis','Po box 321','east orange','NJ','UNITED STATES','07019-0321','(973) 449-3355','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 02:49:24',0,NULL,3,0,1,1,NULL,'dsharp101、'),(309,757622397012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',2,'HSMO005',25.98,'eastar4','adambergen1204','adam_stargate@yahoo.ca','adam bergen','box 486','winkler','MB','CANADA','r6w4a7','(120) 436-2634 ext.: 6','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 03:08:56',0,NULL,3,0,2,1,NULL,'adambergen1204  黑色的\\'),(310,753048822012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','superkoala','trimakasi@freenet.de','Ralf Richter','Meyerstraße 56','Bremen','','GERMANY','28201','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'superkoala'),(311,757691859012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',20.98,'eastar4','unifix2004','arcelina@t-online.de','Frank Raschke','Lökesfeld 26','Ratingen','','GERMANY','40885','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:54:47',0,NULL,3,0,2,1,NULL,'unifix2004\\'),(312,562068306013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','mat0373','mathewv@pb.ozemail.com.au','Mathew Phillip Vanderleer','24 Bayside Boulevard<br>Port Kennedy','Perth','Western Australia','AUSTRALIA','6172','0895246239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 09:48:04',0,NULL,3,0,3,1,NULL,'mat0373\rRA022496493CN\\'),(313,757725881012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',15.99,'eastar4uk','yoshiyasukouichi','yoshiyasu@toughenough.jp','Koichi Yoshiyasu','Higashi 4-4-12<br>#106','Shibuya ku','Tokyo','JAPAN','150-0011','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-17 11:07:22',0,NULL,3,0,2,1,NULL,'yoshiyasukouichi\\'),(314,757732634012,220455477514,'HP 8710w nw9440 nx9420 Bluetooth Module EDR 2.0 +cable',2,'BTHP2005',28.98,'eastar4','69monkee','lmwyss1@gmail.com','Larry Wyss','2909 Hameln Dr','Saint Charles','MO','UNITED STATES','63301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 11:32:37',0,NULL,3,0,1,1,NULL,'69monkee    HP 8pin 1.0 20cm、'),(315,757741105012,220743499505,'NEW Genuine Motorola S9 Bluetooth Stereo Headset',1,'HSMO002',31,'eastar4uk','ben-hearne','bernard.hearne@gmail.com','Ben Hearne','Milestown<br>Cloneen','Clonmel','Tipperary','IRELAND','','0868562275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-17 12:01:24',0,NULL,3,0,3,1,NULL,'ben-hearne   英标\rRA022496768CN\\'),(316,681816571011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','plazomat','plaz@rogers.com','Tony Perfetto','123 Belair Way','Woodbridge','ON','CANADA','L4L 7S9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:24:00',0,NULL,3,0,2,1,NULL,'plazomat\\'),(317,681821318011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',16.59,'eastar4','seluxxl','seluxl@hotmail.com','selu valladolid','santa isabel 16','almonte (huelva)','Andalucía Ceuta y Melilla','SPAIN','21730','959451454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:40:34',0,NULL,3,0,2,1,NULL,'seluxxl    acer 8pin1.00 15cm\\'),(318,681847306011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','gsollfrank','georg.sollfrank@web.de','Georg Sollfrank','Wilhelm Leibl Str. 23','Holzkirchen','','GERMANY','83607','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:11:30',0,NULL,3,0,2,1,NULL,'gsollfrank\\'),(319,511292749003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','htunlogic','tibor.hudik@gmail.com','Tibor Hudik','Kapelska 6','Osijek','CA','CROATIA','31000','091 210 8865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:43:33',0,NULL,3,0,3,1,NULL,'htunlogic\rRA022496808CN\\'),(320,510348526003,130489932541,'%%% NEW Lowepro Rover AW II Photo Camera Bag Backpack ',1,'',79.99,'cnfaner','drishteemungur','drishtee21@gmail.com','Drishtee Mungur','49, Lapeyrousse Street<br>Eau-Coulee','Curepipe','Curepipe','MAURITIUS','230','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 12:58:55',0,NULL,5,0,18,0,NULL,'drishteemungur'),(321,0,320671982482,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'',8.99,'eastar4','chinabeach65','giongabor@yahoo.com','Gabor GION','5, Odos Athinon','Lefkosia','AGIOS DOMETHIOS','CYPRUS','2363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:11:11',0,NULL,3,0,2,1,NULL,'chinabeach65    HSPL001\\'),(322,0,320671983552,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','gregoryc631','funaki4u@gmail.com','gregory carter','203 hawthorne ave apt 30','central islip','NY','UNITED STATES','11722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:17:55',0,NULL,3,0,1,1,NULL,'gregoryc631、'),(323,681873340011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','dabue','dabue1983@yahoo.com','david bue','5175 jumper st','cocoa','FL','UNITED STATES','32927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:24:02',0,NULL,3,0,1,1,NULL,'dabue、'),(324,0,320671980941,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',12.24,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 15:44:37',0,NULL,3,0,1,1,NULL,'4278dennis    一共买了两个、'),(325,757817712012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',15.99,'eastar4','limooihwa','ohlim@yahoo.com','Lim Ooi Hwa','Wisma Algotech, 43-1 & 43-M, Medan Setia 1, Plaza Damansara, Damansara Heights','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:55:54',0,NULL,3,0,2,1,NULL,'limooihwa\\'),(326,562155311013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','10tdm850','sergei0508@mail.ru','Сергей Горячев','Карла маркса, 19, 19','Верхняя Салда','Свердловская область','RUSSIAN FEDERATION','624760','89222175772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:27:52',0,NULL,3,0,2,1,NULL,'10tdm850   欧标\\'),(327,757831741012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korolevich1968','kristinakor@balticum-tv.lt','Sergej Koroliov','Laukininku<br>35-09','Klaipeda','Klaipeda','LITHUANIA','95173','0037063122648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:24:06',0,NULL,3,0,2,1,NULL,'korolevich1968\\'),(328,561632925013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','lcs200977','lcs77@gmx.de','Patrick Sauer','Am Köpping 5','Eisenach','','GERMANY','99817','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 16:23:27',0,NULL,3,0,3,1,NULL,'lcs200977\rRA022496710CN\\\r'),(329,517139462004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','gorodok0','grabsky@sbcglobal.net','val grabsky','1207 Moncoeur Dr','Saint Louis','MO','UNITED STATES','63146-5342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 16:27:37',0,NULL,3,0,1,1,'、\r ','gorodok0、'),(330,0,320671984923,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'',13.99,'eastar4','skiptomymoo','jeffreyluu@gmail.com','Jeffrey Luu','24540 Skyridge Dr','Newhall','CA','UNITED STATES','91321-3552','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 16:40:51',0,NULL,3,0,1,1,NULL,'skiptomymoo    WLDE002、'),(331,562158742013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','imazshna','n_peermohamed@yahoo.com','Imran Peermohamed','41 Windy Golfway','Toronto','ON','CANADA','M3C3A6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:39:31',0,NULL,3,0,2,1,NULL,'imazshna\\'),(332,0,320671983892,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','shenshaw1976','henshaw76@hotmail.com','stuart henshaw','27 pacific way<br>beldon','perth','Western Australia','AUSTRALIA','6027','0422927547','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'shenshaw1976'),(333,511331895003,130458644453,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET track#',1,'HSNO015',35.99,'cnfaner','igarok82','igal821@bezeqint.net','Igal Berger','Yoav Ben Zroya 10/40','Ashdod','Israel','ISRAEL','77525','+256006363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:05:52',0,NULL,3,0,3,1,NULL,'igarok82\rRA022496480CN\r'),(334,562171127013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','gugadalmolin','guga_dalmolin@hotmail.com','Gustavo Dal Molin','Rua Silveiro, 1007, Casa 5','Porto Alegre','Rio Grande do Sul','BRAZIL','90850-000','5132321199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:22:08',0,NULL,3,0,3,1,NULL,'gugadalmolin\rRA022496414CN\\'),(335,681831103011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','phlash2k','msp084@hotmail.com','Mike Potter','5311 Cider Mill Rd','Erie','PA','UNITED STATES','16509-3947','(412) 417-6847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 13:14:20',0,NULL,3,0,1,1,NULL,'phlash2k、'),(336,757877292012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',3,'OTGR001',59.7,'eastar4','vladimirmi','finwise@gmail.com','VOLODIMIR MIHAYLOV','per.2 Odesskij dom 9 kv.2','Cherkassy','Cherkasy region','UKRAINE','18000','+380505025230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 18:04:37',0,NULL,3,0,3,1,NULL,'vladimirmi\rRA022496476CN\\'),(337,681947019011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',19.9,'eastar4','modulist','belkons69@gmail.com','Konstantin Belov','prospekt  Gagarina, d 13, kv 1','Yoshkar-Ola,','Mari El','RUSSIAN FEDERATION','424006','+79276806910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 18:36:47',0,NULL,3,0,2,1,NULL,'modulist     欧标\\'),(338,0,220755495501,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'',9.99,'eastar4','country*1','howard.gerdes@mchsi.com','Howard Gerdes','PO Box 113<br>104 E. Gilman','Secor','IL','UNITED STATES','61771','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-17 19:49:22',0,NULL,3,0,1,1,NULL,'country*1   OMHJ001、'),(339,682021230011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','gary811000','gary811000@yahoo.com','GARY GREENWALD','811 Hidden Valley Ln','RICHMOND','IN','UNITED STATES','47374-5161','(765) 962-7486','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 20:54:06',0,NULL,3,0,1,1,NULL,'gary811000、'),(340,562250559013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',16.59,'eastar4','tkuepper','microship@gmx.net','Thomas Küpper','Lothringer Str. 13','Mönchengladbach','','GERMANY','41061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:58:48',0,NULL,3,0,2,1,NULL,'tkuepper      HP 8pin 1.0 23cm \\'),(341,511394343003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','shannie250','reggie250@hotmail.com','reinaldo','urb loma alta calle 4 blq.C #41<br>urb loma alta calle 4 blq.C #41','Carolina','PR','UNITED STATES','00987','(787) 698-0090','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 20:27:58',0,NULL,3,0,1,1,NULL,'shannie250、'),(342,681872512011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ccharlesh','charleshan-@hotmail.com','Charles Han','20792 123 Ave.','Maple Ridge','BC','CANADA','V2X4A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:21:13',0,NULL,3,0,2,1,NULL,'ccharlesh\\'),(343,757964801012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','8727stevenj','stevenjohnson4@hotmail.com','steven johnson','9907 crystal falls drive','hagerstown','MD','UNITED STATES','21740','(240) 723-6806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 20:40:26',0,NULL,3,0,1,1,NULL,'8727stevenj、'),(344,682035905011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',118.99,'eastar4','mceachern_jr','mceachern_jr@yahoo.com','Bob McEachern Jr.','720 N 64th St','Waco','TX','UNITED STATES','76710-4387','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 21:21:56',0,NULL,3,0,1,1,NULL,'mceachern_jr\\'),(345,757986114012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','spark33150','spark3315@hotmail.com','Hatice Karaca','Dedekorkut mh.eserler sk<br>Raykent Sit.Nu.:19-4','konya,meram','TN','TURKEY','42080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:23:47',0,NULL,3,0,2,1,NULL,'spark33150\\'),(346,681905420011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','dino_ferrari','myles_melillo@snet.net','myles melillo','30 Melillo Cir','north haven','CT','UNITED STATES','06473-2126','(203) 248-1148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-17 16:58:23',0,NULL,3,0,1,1,NULL,'dino_ferrari、'),(347,562268415013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','teixeiramarcelo2010','teixeiramarcelo1@hotmail.com','Mauricio Alves Teixeira','Euler de Azevedo nº 417','Campo Grande','Mato Grosso do Sul','BRAZIL','79116-610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:52:22',0,NULL,3,0,2,1,NULL,'teixeiramarcelo2010   CAB-6060    三个\\'),(348,517216069004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','kyssis13','jan.kyselka@tiscali.cz','jan kyselka','nawkova 345','ceska lipa','liberecky kraj','CZECH REPUBLIC','47001','420737137070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:26:01',0,NULL,3,0,3,1,NULL,'kyssis13   欧标\rRA022496723CN\\   '),(349,682017156011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','mariano.bispo','mariano_bispo@hotmail.com','Mariano Bispo Silva Neto','Rua:quinta do Regalo,71<br>Americanopolis','São Paulo','SP','BRAZIL','04335-120','11-5562-0035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:45:42',0,NULL,3,0,2,1,NULL,'mariano.bispo\\'),(350,682081296011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','diegosanabrazil','diego.flogao@uol.com.br','Diego  de Morais Sana','Rua Diogenes Nascimento das Neves 165/102B','Vitoria','Espirito Santo-ES','BRAZIL','29055915','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:24:50',0,NULL,3,0,3,1,NULL,'diegosanabrazil\rRA022496842CN\\'),(351,758050828012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',2,'HSNO005',21.76,'eastar4uk','02finchley','ash1ferrari@hotmail.com','Ashraf Borghol','283 Finchley Road','London','London','UNITED KINGDOM','NW36ND','02076927199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 00:06:44',0,NULL,3,0,3,1,NULL,'02finchley   英标\rRA022496856CN\\   '),(352,754361018012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',20,'TRMX003',309,'eastar4','snappy-seller','nabeel.malik@hotmail.com','Nabeel Malik','339 Knollwood Trl','Richmond Heights','OH','UNITED STATES','44143','(216) 272-8251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 00:09:44',0,NULL,3,0,4,1,NULL,'snappy-seller   一共买了20个210TS       20个MX20T\rYW864871143CN\r'),(353,0,230597696391,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',12.99,'eastar4','vealbird','jrob2524@yahoo.com','James Robinson','2526 Meredith St','Philadelphia','PA','UNITED STATES','19130-2422','(215) 765-1840','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'vealbird'),(354,562309858013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','saucy_28','cmoney85222@hotmail.com','Cruz  bradford','637 E Manor Dr','Casa Grande','AZ','UNITED STATES','85222','(520) 208-5369','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 00:38:37',0,NULL,3,0,1,1,NULL,'saucy_28、'),(355,562312877013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','fdamata','fabianodamata@yahoo.com.br','Fabiano da Mata Almeida','Rua Domingos Belem, 47/204<br>Fonte Grande','Contagem','MG','BRAZIL','32013-130','+55 31 86343417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 00:56:54',0,NULL,3,0,3,1,NULL,'fdamata\rRA022496502CN\\'),(356,0,230597704797,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.49,'eastar4','heberthunt','heberthunt@hotmail.com','David Hebert','144 Grand Ave','Lafayette','LA','UNITED STATES','70503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 02:16:43',0,NULL,3,0,1,1,NULL,'heberthunt、'),(357,758095559012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',15.9,'eastar4uk','mokirra','kirra9@hotmail.com','michael keily','48 roden st','melb','Victoria','AUSTRALIA','3003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 02:42:09',0,NULL,3,0,2,1,NULL,'mokirra   澳标\\'),(358,758096593012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','rcoberly75','allen.coberly@yahoo.com','richard  coberly','102 tarleton bivouac','williamsburg','VA','UNITED STATES','23185-6227','(757) 218-3089','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 02:47:45',0,NULL,3,0,1,1,NULL,'rcoberly75、'),(359,562339371013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',83.6,'eastar4','kweechuan73','kcang73@hotmail.com','Kwee Chuan Ang','Blk 231 Ang Mo Kio Ave 3<br>#09-1228','default','','SINGAPORE','560231','96536223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 03:11:14',0,NULL,3,0,3,1,NULL,'kweechuan73    BAZA001 \rRA022496555CN\\'),(360,682145510011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',12.88,'eastar4','bigsoftkitty7','hairybbw@ymail.com','Nina Kirsanova','MD2044 Moldova, repulic of, Chisinau, A.Russo str. 63/4 ap.43','Chisinau','mun Chisinau','MOLDOVA, REPUBLIC OF','MD2044','+37369428894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 03:22:50',0,NULL,3,0,2,1,NULL,'bigsoftkitty7    \r10 pin 1.0 5cm \r\\'),(361,0,220755501016,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'',10.29,'eastar4','shawabkeh86','i_d_shawabkeh@yahoo.com','shawabkeh86 alshawabkeh','37 royal crest dr<br>apt 6','nashua','NH','UNITED STATES','03060-6623','(508) 440-9646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 03:29:52',0,NULL,3,0,1,1,NULL,'shawabkeh86    HSPL005、'),(362,682074566011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tlb_global','ebay@thefubar.co.uk','Tony Butcher','10 Thorkhill Road','Thames Ditton','Surrey','UNITED KINGDOM','KT7 0UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:02:04',0,NULL,3,0,2,1,NULL,'tlb_global\\'),(363,758122136012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jasonglasser','jasondglasser@gmail.com','Jason Glasser','980 Montecito Dr<br>Ste 202','Corona','CA','UNITED STATES','92879-1795','(951) 858-8975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 04:41:24',0,NULL,3,0,1,1,NULL,'jasonglasser、'),(364,511499186003,130490207271,'New Logitech harmony Li-ion Rechargeable Battery1250mAh',1,'BALO003',11.99,'cnfaner','waltdarmanin','waltd2@bigpond.com','walt darmanin','12  sea cliff place','caves beach','New South Wales','AUSTRALIA','2281','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 04:46:03',0,NULL,5,0,18,0,NULL,'waltdarmanin'),(365,758123779012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',15,'eastar4uk','bazzelsm218','mbazzel@hotmail.com','Susan Bazzel','27 White Oak Rd','Landenberg','PA','UNITED STATES','19350-1027','(610) 255-0354','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 04:51:04',0,NULL,3,0,1,1,NULL,'bazzelsm218、'),(366,562359248013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','phlwbg131517','philippe.lowemberg@wanadoo.fr','Philippe LOWEMBERG','11 quai Francois Mauriac<br>CODE GRILLE 15461','PARIS','Île-de-France','FRANCE','75013','01.44.24.16.50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 05:15:11',0,NULL,3,0,3,1,NULL,'phlwbg131517     MOSA003\rRA022496462CN\\'),(367,511504544003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','haygij85','haygij@gmail.com','Karen Ashotyan','Ha\'atsmaut 40/20','Herzeliya','Hasharon','ISRAEL','46789','0545299908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 05:43:19',0,NULL,3,0,2,1,NULL,'haygij85   \\'),(368,682179797011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sonnyblack273','thomas.hippold@online.de','Thomas Hippold','Rheinstr. 37h','Osthofen','','GERMANY','67574','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 06:59:21',0,NULL,3,0,2,1,NULL,'sonnyblack273'),(369,562374926013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','robbotheyobbo08','robby0809@yahoo.com.au','Robby Bruce','9/36 Epsilon Drive<br>Rockingham','Perth','Western Australia','AUSTRALIA','6168','0061450221468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:41:10',0,NULL,3,0,3,1,NULL,'robbotheyobbo08       MOSA002\r RA022496860CN\\'),(370,758154020012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',1,'ANYA001',14.45,'eastar4','ksy_com','ksycom@gmail.com','KSY.Computer','43 Sangchuto Rd.<br>T.Tamakam','Moung','Kanchanaburi','THAILAND','71000','6634624422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:53:50',0,NULL,3,0,11,1,NULL,'ksy_com   ANYA001'),(371,682178098011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','astro_ca','gpuntchev@gmail.com','Gueorgui I Pountchev','231-7280 Darcel Ave.','Mississauga','ON','CANADA','L4T 3T7','(416) 428-3401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 06:47:40',0,NULL,3,0,2,1,NULL,'astro_ca'),(372,758159216012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','ssargavinski','percival@tele2.hr','Srđan Šargavinski','E. Kvaternika 14','Čepin','','CROATIA','31431','+385955055144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:18:04',0,NULL,3,0,2,1,NULL,'ssargavinski'),(373,562383618013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','nittenyadhav3','nittenyadhavebay@gmail.com','Nitten Yadhav','SkillSoft Ireland<br>Block 7, Belfield Office Park, Clonskeagh','Dublin','Dublin','IRELAND','4','0877479291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:41:27',0,NULL,5,0,2,1,NULL,'nittenyadhav3'),(374,562385693013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',64.45,'eastar4','kokdima','volde@mail.ru','Dmitriy Volodenkov','Mayakovskogo str. 18-197','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660003','8(391)275-79-50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:55:23',0,NULL,8,0,17,0,NULL,'kokdima'),(375,682202326011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','kokdima','volde@mail.ru','Dmitriy Volodenkov','Mayakovskogo str. 18-197','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660003','8(391)275-79-50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:56:37',0,NULL,3,0,3,1,NULL,'kokdima  再发一个IBM Intel Advanced-N WiMAX 6250 622ANXHMW       RA022496989CN  \\'),(376,562389857013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','teeem','tim.mironov@gmail.com','Veronika Mironova','Amirkhana str, 10a/2, apt. 74','Kazan','Tatarstan','RUSSIAN FEDERATION','420126','+7-917-897-96-88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 09:27:46',0,NULL,3,0,3,1,NULL,'teeem\rRA022496670CN\r'),(377,511536068003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','mfotinakis68','michael.fotinakis@gmail.com','Michael Fotinakis','Karaoli 40-42','Athens','Aharnai','GREECE','13671','6942433343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 09:58:00',0,NULL,3,0,3,1,NULL,'mfotinakis68   欧标\rRA022495201CN\r'),(378,562398119013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vitalybu','vitalybu@gmail.com','Vitaly Bukhovsky','14 Vered St.','Bney-Aish','','ISRAEL','60860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:15:39',0,NULL,3,0,3,1,NULL,'vitalybu\rRA022496771CN\r'),(379,562404324013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','elise2k1','chun168@yahoo.com','Man Wong','Optus OCSE3, 1 Lyonpark Road<br>Macquarie Park','Sydney','New South Wales','AUSTRALIA','2113','0423609953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:49:07',0,NULL,3,0,3,1,NULL,'elise2k1\rRA022495246CN\r'),(380,561778495013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',8,'WLAP008',151.92,'eastar4','don-bx11','hae_tho_don@gmx.de','Thomas Häckl','Geschwister-Scholl-str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:52:08',0,NULL,3,0,3,1,NULL,'don-bx11 \rRA022496604CN\r'),(381,561779309013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',5,'WLAT001',74.95,'eastar4','www_nontoxic-store24_de','info@nontoxic-store24.de','Thomas Häckl','Geschwister-Scholl-Str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:57:16',0,NULL,3,0,3,1,NULL,'www_nontoxic-store24_de\rRA022495881CN\r'),(382,517388581004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','asus78m','asus78@yahoo.it','rosa santangelo','viale regione siciliana sud est<br>2219','palermo','PA','ITALY','90126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 12:52:52',0,NULL,3,0,3,1,NULL,'asus78m   欧标\rRA022495904CN\r'),(383,758247769012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',81.95,'eastar4','stevebv','stefanvock@gmx.at','Vock Stefan','Marchetstrasse 14','Baden','','AUSTRIA','2500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 13:37:55',0,NULL,3,0,3,1,NULL,'stevebv\rRA022495935CN\r'),(384,758275590012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','silviademelao','silviademelao@hotmail.com','RICARDO  MACHADO','Rua Otto Lacerda França 27<br>Bandeirantes','Leopoldina','Minas Gerais','BRAZIL','36700-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:54:42',0,NULL,3,0,2,1,NULL,'silviademelao\\'),(385,511596564003,130490963246,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',15.5,'cnfaner','csjsolar','csj@atvci.net','Charlie R Solar JR','7212 Highway 182 E','Morgan City','LA','UNITED STATES','70380-2167','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:11:32',0,NULL,3,0,1,1,NULL,'csjsolar\\'),(386,510555533003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','auctionwidower','ken.ebay@minker.dyndns.org','Ken Mink','12901 Edsel Dr','Raleigh','NC','UNITED STATES','27613','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:46:31',0,NULL,3,0,1,1,NULL,'auctionwidower\\'),(387,0,220754847095,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','peterr0123','peterr0123@yahoo.gr','Peter Triantafyllopoylos','DOCK 10  (APOTHIKI DUTY FREE) tel +30 6977218078<br>PATRAS PORT','PATRA','ACHAIA','GREECE','26223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 15:47:32',0,NULL,3,0,3,1,NULL,'peterr0123\rRA022495952CN\r'),(388,758273886012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',21.38,'eastar4','xmen4ugt','xmen4u@gmail.com','Gil Tamari','10 Nemirover St.','Tel aviv','','ISRAEL','69713','97236447976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:24:57',0,NULL,3,0,2,1,NULL,'xmen4ugt\\'),(389,758313345012,220459525292,'Acer Aspire 5550 5551 5552 Bluetooth Module 2.0 +cable',1,'BTAC2006',14.49,'eastar4','malacat_ent','steve@malacat.ca','Steve Bradshaw','1033 Braithwaite Drive','Cobble Hill','BC','CANADA','V0R1L4','(250) 743-3137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:29:01',0,NULL,3,0,2,1,NULL,'malacat_ent     acer 4pin1.25 15cm \\'),(390,517439898004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','lj_kokomo','lj_kokomo@yahoo.com','Joseph Petrich','14814 Burbank Blvd<br>Apt 12','Sherman Oaks','CA','UNITED STATES','91411','(323) 857-3512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 16:35:02',0,NULL,3,0,1,1,NULL,'lj_kokomo\\'),(391,0,230597229456,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',22.02,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 16:41:12',0,NULL,8,0,17,0,NULL,'4278dennis     SCLO001     \r 再发一个AC adapter     POLO001  '),(392,562497156013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','sasiri_w','sasiriw@gmail.com','Dr Sashika Weerathunga.','905 / 1,<br>Aluwihare,','Mathale.','','SRI LANKA','0000','+94772314617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:16:30',0,NULL,3,0,2,1,NULL,'sasiri_w\\'),(393,758347922012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','sonocite','sonocite@yahoo.fr','SONO CITE Service Technique','avenue de la libération 16','ghlin','','BELGIUM','7011','0494-276983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:47:19',0,NULL,3,0,2,1,NULL,'sonocite\\'),(394,682302118011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','physics_tech_man','rbeery@i2k.com','Ronald Beery','760 S Waverly Rd<br>C/O A.S.M.','Holland','MI','UNITED STATES','49423-9121','(616) 209-5266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 18:02:38',0,NULL,3,0,1,1,NULL,'physics_tech_man\\'),(395,517473358004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','slava1661','s_l_a_w_a@inbox.lv','Vjaceslavs Kursits','Smiltenes iela 4-6','Daugavpils','Latgale','LATVIA','LV-5401','+37129959984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 18:30:10',0,NULL,3,0,3,1,NULL,'slava1661    欧标\rRA022496697CN\r\r'),(396,511647433003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','shorah_ann','shorah.ann@gmail.com','Anna Doroshina','Minskaya 21-70','Smolensk','Smolensk','RUSSIAN FEDERATION','214034','+79517055202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:10:51',0,NULL,3,0,3,1,NULL,'shorah_ann\rRA022495192CN\r'),(397,562533161013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','themooschina','d.velin@mail.ru','Dmitry Velin','pr. Lenina, 30a, 45','Chelyabinsk','','RUSSIAN FEDERATION','454091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:03:21',0,NULL,3,0,2,1,NULL,'themooschina   欧标\\'),(398,562543934013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','shelby220077','redteam_77@hotmail.com','Ste-marie Jean','810 coté','Thetford mines','QC','CANADA','G6G7B6','(418) 338-4979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:31:38',0,NULL,3,0,2,1,NULL,'shelby220077\\'),(399,562562272013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','dieterhm','dieter.h.mayer@t-online.de','Dieter Mayer','Falkenweg 4 1/2','Königsbrunn','','GERMANY','86343','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 20:22:51',0,NULL,3,0,2,1,NULL,'dieterhm   欧标\\'),(400,516628254004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',32.8,'cnfaner','just371','wlkjr7@aol.com','Jerome Walker','230 W Runyon St','Newark','NJ','UNITED STATES','07108-1722','(732) 921-2387','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 20:29:19',0,NULL,3,0,1,1,NULL,'just371、'),(401,682458900011,320586526867,'HP Broadcom BCM94322 4322  mini PCI-E card wifi AGN',1,'WLHP001',18.99,'eastar4','coinburgh','timkrofchik@gmail.com','Tim Krofchik','435 Violet Dr','Lower Burrell','PA','UNITED STATES','15068-3339','(412) 951-8455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 21:07:39',0,NULL,3,0,1,1,NULL,'coinburgh\\'),(402,682463210011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','drulf42','2ulf@gmx.de','Ulf Garbotz','Baumschulenweg 74','Remagen','','GERMANY','53424','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'drulf42'),(403,758445899012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','hudson7910','hudson7910@comcast.net','matt hudson','12307 nw 36th ave','vancouver','WA','UNITED STATES','98685-2222','(503) 895-0609','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 21:00:07',0,NULL,3,0,1,1,NULL,'hudson7910\\'),(404,682462322011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','chris4p8o','chris@yewchuk.com','A. Junaki','50 Dent Street','Glen IRIS','Victoria','AUSTRALIA','3146','(862) 812-3176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:02:27',0,NULL,3,0,2,1,NULL,'chris4p8o\\'),(405,682463210011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','drulf42','2ulf@gmx.de','Ulf Garbotz','Baumschulenweg 74','Remagen','','GERMANY','53424','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:36:52',0,NULL,3,0,2,1,NULL,'drulf42\\'),(406,511715020003,130490976186,'New Atheros AR5B95 AR9285 Half Mini PCI-E card+antenna',1,'WLAT009+ANTY001',17.5,'cnfaner','henriquet.carvalho','cht.info@bol.com.br','Carlos Henrique Teixeira de Carvalho','av Getúlio Vargas, nº 632','candelaria','Rio Grande do Sul','BRAZIL','96930000','(+55 51) 8475 4911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:57:34',0,NULL,3,0,3,1,NULL,'henriquet.carvalho\rRA022496745CN\r'),(407,511732561003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','wnaimu','wneumu@gmail.com','Waldemar Neumüller','Steinbeisstrasse 31','Aalen','','GERMANY','73430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:12:28',0,NULL,3,0,3,1,NULL,'wnaimu\rRA022496754CN\r'),(408,562614443013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',2,'WWSI004+ANCN001',74.4,'eastar4','neolore_ca','purchasing@neolore.com','NeoLore Networks Inc.','2781 Lancaster Raod<br>Suite 302','Ottawa','ON','CANADA','K1B1A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:23:09',0,NULL,3,0,3,1,NULL,'neolore_ca  \rRA022495436CN\r'),(409,682517984011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','leinadnitnac','cantin.daniel@gmail.com','Daniel Cantin','7353 Coffee','Montreal','QC','CANADA','H4B 1J9','(514) 515-3801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:37:41',0,NULL,3,0,2,1,NULL,'leinadnitnac\\'),(410,511738813003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','mshalo54','ebaymine@att.net','Angela Puklavetz','4506 Avenida de las Flores','Yorba Linda','CA','UNITED STATES','92886','(714) 875-2666','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-18 23:49:08',0,NULL,3,0,3,1,NULL,'mshalo54\rRA022496578CN\r'),(411,511739947003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','crle666teo','teodor.prizmic@ri.t-com.hr','Teodor Prizmić','Mate Lovraka 16','Rijeka','','CROATIA','51000','++385 51 625 422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:50:48',0,NULL,3,0,3,1,NULL,'crle666teo\rRA022496595CN\r'),(412,758514353012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.97,'eastar4','lvkilo','kiloinvegas@gmail.com','Harold Kinchelow Jr','7736 Crenshaw Way','Las Vegas','NV','UNITED STATES','89129-5498','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 23:57:37',0,NULL,3,0,1,1,NULL,'lvkilo\\'),(413,517568862004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','tiagotrentini','denistrentini@gmail.com','Erika Iris Trentini','Getulio Vargas, 2580','Sao Jose','Santa Catarina','BRAZIL','88103-400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 00:33:24',0,NULL,3,0,3,1,NULL,'tiagotrentini\rRA022496635CN\r'),(414,682533770011,320451492463,'Atheros AR5008 802.11N 300M Wireless PCI-E+ 3 antenna',3,'WLAT002+ANTY001*3',46.47,'eastar4','jakub_16hc','jakub_k@o2.pl','jakub kochan','62 the paddocks','newcastle west','Limerick','IRELAND','default','06977604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 00:35:15',0,NULL,3,0,3,1,NULL,'jakub_16hc   用新的发\r\rRA022495440CN\r'),(415,682433888011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lafond2010paul','lafond3@hotmail.com','Paul Pelletier','39 Chaplin St.','Pawtucket','RI','UNITED STATES','02861','(401) 585-2745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 20:00:07',0,NULL,3,0,1,1,NULL,'lafond2010paul\\'),(416,758545571012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',1,'HSMO005',12.99,'eastar4','qda22','qda22@yahoo.com','glen simpson','72 mckall','winnipeg','MB','CANADA','r3x1t8','(204) 255-7338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 01:54:22',0,NULL,3,0,2,1,NULL,'qda22\\'),(417,758548747012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','northwest_treasurechest','jarfanci@comcast.net','Elizabeth Cordero','1219 Mountain Aire Way SE','Lacey','WA','UNITED STATES','98503-1920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 02:07:00',0,NULL,3,0,1,1,NULL,'northwest_treasurechest\\'),(418,682425535011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','propshaft4','j.p.gerrits@ziggo.nl','j.p. gerrits','De Niagara 4','DRUNEN','','NETHERLANDS','5152VB','0416753575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:45:16',0,NULL,3,0,2,1,NULL,'propshaft4\\'),(419,0,220754847098,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'',8.99,'eastar4','nikkay77','nikkay77@yahoo.com','Nikki Kimsey','16524 Spaulding Ave','Markham','IL','UNITED STATES','60428-5525','(708) 566-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 03:28:17',0,NULL,3,0,1,1,NULL,'nikkay77   HSPL001\\'),(420,511788354003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','earthbodysoul','mbytheway@optusnet.com.au','Marc Bytheway','172 Humphries Road','Mt Eliza','Victoria','AUSTRALIA','3930','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 05:31:10',0,NULL,3,0,3,1,NULL,'earthbodysoul\rHSUE004\rRA022496621CN\r'),(421,758606996012,220705174844,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',9.26,'eastar4uk','bizeloui','d.othonos@cytanet.com.cy','Despo Othonos','Anexartisias 7A, Aglantzia','Nicosia','','CYPRUS','2108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 07:09:06',0,NULL,3,0,2,1,' ','bizeloui   英标\\'),(422,758615251012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','larkeylou','joycielou11@gmail.com','Joyce Stroud','1979 Crescent Dr','Las Cruces','NM','UNITED STATES','88005-3322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 07:51:27',0,NULL,3,0,1,1,NULL,'larkeylou   \\'),(423,757732319012,220743499595,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','patakurko','tuomaslaukkanen@hotmail.com','Tuomas Laukkanen','kalevankatu 18b b15','Joensuu','','FINLAND','80110','0504120998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 07:52:10',0,NULL,3,0,3,1,NULL,'patakurko   OTRA002\r\r客户新地址\r\rTuomas Laukkanen\rHofinkatu 6A\rJoensuu  80140\rFinland\rRA022496581CN\r\r\r'),(424,758620521012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','atomic_shrimp','ebaycontact@gurman.co.uk','Mike Gurman','9 Rectory Court<br>Botley','Southampton','Hampshire','UNITED KINGDOM','SO30 2SJ','','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'atomic_shrimp\rRA022495294CN\r'),(425,758623994012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','mihhaila_123','mihhaila@hotmail.com','Mihhail Aulov','Peterburi tee 24-56','Tallinn','Harjumaa','ESTONIA','11411','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 08:30:39',0,NULL,3,0,2,1,NULL,'mihhaila_123  欧标\\'),(426,562701944013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','mich2780','computercleanau@yahoo.com.au','Michelle Riccio','3 Jellicoe Street, Caringbah','Sydney','New South Wales','AUSTRALIA','2229','0410531047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 08:57:35',0,NULL,3,0,2,1,NULL,'mich2780\\'),(427,511814105003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220114','375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:10:13',0,NULL,3,0,3,1,NULL,'ekimovsi1982\rHSNO008   欧标\rRA022495475CN\r'),(428,758643098012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','inbio','sergeyproskuryakov@gmail.com','Sergey Proskuryakov Сергей Проскуряков','ul. Voronezhskaya, d. 88, ул. Воронежская, д. 88','Tambov, Тамбов','Tambovskaya oblast\', Тамбовская область','RUSSIAN FEDERATION','392022','(905) 547-60-25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:42:50',0,NULL,3,0,2,1,NULL,'inbio  MX20T\\'),(429,562712186013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','jnboutique','jess@creativedigitalmedia.com.au','Jessica McLennan','38 Arena Parade','Officer','Victoria','AUSTRALIA','3809','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 09:54:14',0,NULL,3,0,3,1,NULL,'jnboutique   MOSA001\rRA022496825CN\r'),(430,562716046013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220114','375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 10:44:51',0,NULL,8,0,17,0,NULL,'ekimovsi1982'),(431,758671083012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','antiqboy31221','telez444@rambler.ru','Vladimir Grigoriev','kesk 6-61','Kohtla-Jarve','Esti  ee','ESTONIA','31221','+3725227829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 11:16:49',0,NULL,3,0,2,1,NULL,'antiqboy31221   欧标\\'),(432,562731315013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','i_naama','shai178@walla.com','Shai Nachmani','Emek Ha\'ela 98','Modiin','Israel','ISRAEL','71723','(972)52-552-9002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 11:31:50',0,NULL,3,0,2,1,NULL,'i_naama\\'),(433,758684896012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',29.9,'eastar4uk','ingridmrsi','gandi@zippy-uk.com','mrs I Morrish','9 Lexington Way','Barnet','Hertfordshire','UNITED KINGDOM','En5 2SN','02084470180','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-19 12:02:41',0,NULL,3,0,3,1,NULL,'ingridmrsi\rOTGR001+OTGR002\rRA022495515CN\r'),(434,682679457011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.8,'eastar4','dan.2007407','danherghelegiu@yahoo.com','Dan Herghelegiu','Bd. GRIVITEI 49 / Bl. 34 / Sc. A / Ap. 28','Brasov','Brasov','ROMANIA','500177','+40 723 559491','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 12:08:01',0,NULL,3,0,3,1,NULL,'dan.2007407\rMOSA001\rRA022496839CN\r'),(435,562741643013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','vaiana22','isadadoulove@hotmail.fr','DUPONT-DUMOULIN DAMIEN OU ISABELLE','17 RUE DES MALPIQUES','GENNES','Pays de la Loire','FRANCE','49350','0610703530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 12:22:31',0,NULL,3,0,2,1,NULL,'vaiana22   欧标\\'),(436,758707262012,220743499522,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',9.2,'eastar4uk','guladem','agul@ofisiletisim.com','ADEM GUL','IZZETPASA MAH. YENIYOL CAD. AYAZMAYOLU SOK. IKIZDERE HAN. NO:1/2<br>SISLI','ISTANBUL','SISLI','TURKEY','34387','902122198877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 13:08:59',0,NULL,3,0,2,1,NULL,'guladem\\'),(437,758714979012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.69,'eastar4uk','brianarsenal71','btipper69@virginmedia.com','b tipper','7 chapel end','hoddesdon','Hertfordshire','UNITED KINGDOM','en11 8dn','01992465684','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-19 13:35:45',0,NULL,3,0,3,1,NULL,'brianarsenal71   英标\rHSPL010\rRA022495189CN\r'),(438,517698443004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','brunovegar','brunoveg@yahoo.com','Bruno Veguillas','Santa Fe 1173','Rosario','Santa Fe','ARGENTINA','S2000ATO','+54 (0341) 156953591','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 14:13:55',0,NULL,3,0,3,1,NULL,'brunovegar\rHSNO003\rRA022496618CN\r'),(439,758741810012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','818vinscuzzy','vinscuzzy@hotmail.com','jason  rabinowitz','7842 fairchild ave','canoga park','CA','UNITED STATES','91306-2008','(818) 621-4043','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 14:47:31',0,NULL,3,0,1,1,' ','818vinscuzzy'),(440,0,230597693894,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','dollysboutique7','dollysboutique@hotmail.com','CARMEN BURGOS','URB. VILLA MADRID<br>O-11','COAMO','PR','UNITED STATES','00769','(787) 344-3619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:10:59',0,NULL,3,0,1,1,NULL,'dollysboutique7\\'),(441,0,220755498710,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',13.25,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:12:26',0,NULL,8,0,17,0,NULL,'4278dennis\r一共买了两个'),(442,0,230597695271,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','rautzu','rautzu@yahoo.com','PAUL POPA','5488, Rue Avonmore, #204','Montreal','QC','CANADA','H3X1Z3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 15:16:55',0,NULL,3,0,2,1,NULL,'rautzu\\'),(443,562786002013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','asphix1028','asphix20@gmail.com','Bernardo Garibay','409 Broad St','Windsor','CT','UNITED STATES','06095-3006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:21:24',0,NULL,3,0,1,1,NULL,'asphix1028\\'),(444,0,220755505373,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',14.51,'eastar4','dbluband','dbluband@gmail.com','David Bluband','1636 Scott St','Saint Helena','CA','UNITED STATES','94574-1728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 15:34:22',0,NULL,3,0,1,1,NULL,'dbluband\\'),(445,0,320671979928,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jgeer100','johngeer1@gmail.com','John Geer','643 Bair Island Rd<br>Consolidated Investments Ste 100','Redwood City','CA','UNITED STATES','94063-2755','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-19 15:46:37',0,NULL,3,0,1,1,NULL,'jgeer100\\'),(446,682756338011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lemmingleader','lennartz@lennartz.org','Thomas Lennartz','Am Kärling 80','Castrop-Rauxel','','GERMANY','44581','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 15:48:55',0,NULL,3,0,2,1,NULL,'lemmingleader\\'),(447,517726719004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','askoldvadim','rozanow@mail.ru','Vadim Rozanov','Kolomyazhsky Prospect, home 28,<br>housing 1, flat 82','St. Petersburg','','RUSSIAN FEDERATION','197341','011-7-812-336-04-82','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 16:00:50',0,NULL,3,0,3,1,NULL,'askoldvadim\rOMHJ001\rRA022495966CN\r'),(448,682801723011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','cmanuelsantos','carlos.thalesgroup@gmail.com','Carlos De Los Santos','8532 NW 66th St<br>Apt 013419','Miami','FL','UNITED STATES','33166','(829) 640-3391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 17:32:46',0,NULL,3,0,1,1,NULL,'cmanuelsantos\\'),(449,758556844012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',33.97,'eastar4','jck-p','jck_p@hotmail.com','Jack R. Poudrier','1732 Lakeview Ave','Klamath Falls','OR','UNITED STATES','97601','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 02:47:55',0,NULL,3,0,1,1,NULL,'jck-p\r再发一个HP Broadcom BCM4322     WLHP001 \r'),(450,562855552013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','buffet66','dspeich66@netscape.net','Douglas Speich','15 Biddlecum Rd','Pennellville','NY','UNITED STATES','13132','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 18:52:32',0,NULL,3,0,1,1,NULL,'buffet66\\'),(451,511984394003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','j89j','jj89jj@msn.com','Jerrold Jackson','606 SW Langston Rd','Renton','WA','UNITED STATES','98057-2208','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 20:19:03',0,NULL,3,0,1,1,NULL,'j89j\\\r'),(452,562890144013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','leovirgo28','george@tapped-out.com','George Constantinou','8A Demonicou Street','Larnaca','Larnaca','CYPRUS','6016','0035796799507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 20:15:45',0,NULL,3,0,2,1,NULL,'leovirgo28\\'),(453,517813407004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',23.99,'cnfaner','anichkin_a.g','klasika@bk.ru','Anichkin Alexander','Volhovskiy pereulok 2, apt.180','Moscow','Moskva','RUSSIAN FEDERATION','105005','8(916)982-2332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 20:19:20',0,NULL,3,0,3,1,NULL,'anichkin_a.g\rWLIN010 +ANTY001*3\rRA022496799CN\r'),(454,517828040004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','olegja','olegja@navigator.lv','Oleg Jarmakov','Gobas 35-4','Riga','','LATVIA','LV-1016','371-7433431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 21:09:18',0,NULL,3,0,3,1,NULL,'olegja\rWWSI005\rRA022496666CN\r'),(455,517841639004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','michaelthorn','mthorn@aol.com','Michael Thorn','19 Argyle Dr','Shirley','NY','UNITED STATES','11967-4201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 21:57:54',0,NULL,3,0,1,1,NULL,'michaelthorn  旧的\\'),(456,562924080013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','sowji_kambam','kambam.sowjanya@gmail.com','sowjanya kambam','38319 GolfView Dr','Farmington Hills','MI','UNITED STATES','48331-2957','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 21:56:45',0,NULL,3,0,1,1,NULL,'sowji_kambam\\'),(457,758978852012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',8,'CASS003',69.6,'eastar4','felix.rm','radmilo.felix@gmail.com','Radmilo Felix','9, Hotin street','Bucharest','Bucharest','ROMANIA','012971','+40724588505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 22:35:26',0,NULL,3,0,3,1,NULL,'felix.rm    CAB-6060   CASS003\rRA022495970CN\r'),(458,758941210012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gpakraemer','wkraemer@nwi.net','William Kraemer','PO Box 2222<br>225 W Highland #2','Chelan','WA','UNITED STATES','98816-2222','(509) 682-4701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 21:12:50',0,NULL,3,0,1,1,NULL,'gpakraemer\\'),(459,514814822004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',41.9,'cnfaner','luizserafim','serafimc@terra.com.br','luiz carlos serafim','prof. abelardo rupp, 255, j.itaguaçu','florianopolis','santa catarina','BRAZIL','88085595','55-48-78110508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:00:05',0,NULL,3,0,3,1,NULL,'luizserafim\rTOIN002+BAIN002+BAIN001\rRA022495232CN\r'),(460,758990202012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.8,'eastar4','jstmco','holaccounts@cableone.net','Marv Fulcher','1222 W Brown Trout Dr','Meridian','ID','UNITED STATES','83642-7730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:03:05',0,NULL,3,0,1,1,NULL,'jstmco\\'),(461,0,220755518895,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','pkm.sal','ptka@live.fi','Petri Salenius','Pännitie 4','Nummela','','FINLAND','03100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 21:45:00',0,NULL,3,0,3,1,NULL,'pkm.sal\rOTRA002\rRA022496706CN\r'),(462,512033750003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','artemisa777','emerleon@gmail.com','CARLOS LUENGO','MOISÉS DE LEÓN 34;6-A','LEÓN','Castilla y León','SPAIN','24006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:09:49',0,NULL,3,0,3,1,NULL,'artemisa777  欧标\rHSMO016\rRA022496683CN\r'),(463,0,220756937052,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',16,'eastar4','thickstudny','thickstudny@aol.com','George Beletsis','4489 Broadway<br>Apt 4F','New York','NY','UNITED STATES','10040-2495','(646) 533-0763','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:16:56',0,NULL,3,0,1,1,NULL,'thickstudny\\'),(464,681255022011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','caroubay','enor.caroupin@wanadoo.fr','ENOR CAROUPIN','PINTADE','BASSE-TERRE','GUADELOUPE','GUADELOUPE','97100','0690901166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:19:47',0,NULL,3,0,2,1,NULL,'caroubay\\'),(465,562948797013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','mossete','minamibia@gmail.com','JOSE MANUEL CABEZUDO ARTERO','C/ Pantano Puerto Peña 63. Vivienda nº 6','Badajoz','Extremadura','SPAIN','06010','639752633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:25:26',0,NULL,3,0,3,1,NULL,'mossete\rMOSA001\rRA022496900CN\r'),(466,512024290003,130460438605,'New Plantronics Explorer 340 BLUETOOTH HEADSET track#',1,'HSPL007',19.9,'cnfaner','phinzhater','boomer_67@comcast.net','Keith A. Landers Jr.','6508 Kenwood Ave','Rosedale','MD','UNITED STATES','21237-1814','(443) 798-1957','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 22:30:23',0,NULL,3,0,1,1,NULL,'phinzhater、'),(467,562949723013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','mwgolson','mgolson1123@gmail.com','Melanie   Golson','1541 Pine Ridge Rd','Montgomery','AL','UNITED STATES','36109-1355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-19 23:30:45',0,NULL,3,0,1,1,NULL,'mwgolson\\'),(468,759014329012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','dracomoye','dracomoye@hotmail.com','Fontaine Sylvain','1060 principale ouest','Lawrenceville','QC','CANADA','J0E 1W0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 00:14:02',0,NULL,3,0,2,1,NULL,'dracomoye\\'),(469,682991381011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','rmccain316','robert@infodesignsolutions.com','Robert M. McCain','8860 E Chaparral Rd<br>Ste 100','Scottsdale','AZ','UNITED STATES','85250-2610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 00:53:41',0,NULL,3,0,1,1,NULL,'rmccain316\\'),(470,517889768004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','sagueb30','sagueb.sbeb@gmail.com','sebastien sues','6 chemin du figuier<br>hameau de sinsans','calvisson','Languedoc-Roussillon','FRANCE','30420','0646253923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:27:09',0,NULL,3,0,3,1,NULL,'sagueb30\rWLDE002\rRA022496785CN\\'),(471,562977512013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','t3knique','t3k@2x.ca','Will Law','2107 - 7088 Salisbury Ave','Burnaby','BC','CANADA','V5E0A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:37:07',0,NULL,3,0,2,1,NULL,'t3knique\\'),(472,759040647012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','bopperd','bopperda@yahoo.com','Dave Schinbeckler','Rural Route 1','Mindemoya','ON','CANADA','p0p1s0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 01:39:51',0,NULL,3,0,3,1,NULL,'bopperd\rOTGR001+OTGR002\rRA022495921CN\r'),(473,562982453013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','eldume83','joan.dume@yahoo.com','Juan Dume','97 Camden St<br>Roxbury Apt 320','boston','MA','UNITED STATES','02118','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 02:00:02',0,NULL,3,0,1,1,NULL,'eldume83\\'),(474,562992722013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','jack*of*hearts','cjohns13@hotmail.com','Dan Johnson','937 Grandmere Rd','Lawrenceburg','TN','UNITED STATES','38464-7027','(931) 766-0407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 02:55:42',0,NULL,3,0,1,1,NULL,'jack*of*hearts\\'),(475,0,220755500341,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',16.5,'eastar4','ekimovsi1982','ekimovsi@gmail.com','Siarhei Yakimau','Nezavisimosti pr. , 151-87','Minsk','','BELARUS','220117','+375296542585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 03:00:53',0,NULL,3,0,3,1,NULL,'ekimovsi1982\r一共买了三个\rRA022495878CN\r'),(476,562998171013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','rodolfofonseca94','fonseca.elder@superig.com.br','Elder Fonseca','Rua carlos morgado number 03<br>House 1','São Paulo','São Paulo','BRAZIL','02219-060','5511-22010419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 03:34:46',0,NULL,3,0,3,1,NULL,'rodolfofonseca94\rMOSA002\rRA022496811CN'),(477,562313206013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','thor1364','eric_s_davis@hotmail.com','Eric Davis','5124 Panorama Drive','Cheyenne','WY','UNITED STATES','82009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 04:28:47',0,NULL,3,0,1,1,NULL,'thor1364\\'),(478,0,230597230040,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12,'eastar4','hormel-ugcs','pablo@alumni.caltech.edu','Paul Thienprasit','358 Alvarez Common','Milpitas','CA','UNITED STATES','95035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 08:12:13',0,NULL,3,0,1,1,NULL,'hormel-ugcs\\'),(479,563041879013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','sal_paradise00','andrewcunningham@mac.com','Andrew Cunningham','1 Hone Street','Parkside','South Australia','AUSTRALIA','5063','61439865012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:30:00',0,NULL,3,0,3,1,NULL,'sal_paradise00\rMOSA003\rRA022496895CN\r'),(480,683114993011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ksstyle831','zhenwenxuan@hotmail.com','ZHIHUA HE','46 MINTARO AVE<br>STRATHFIELD','SYDNEY','New South Wales','AUSTRALIA','2135','61405093438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:53:49',0,NULL,3,0,2,1,NULL,'ksstyle831\\'),(481,563058923013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mavieillepeugeot504','mavieillepeugeot@live.fr','rachid dali','33 boulevard du bosphore résidence val pins<br>batiment c3','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13015','0659298238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:44:11',0,NULL,3,0,2,1,NULL,'mavieillepeugeot504\\'),(482,512142046003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','massimo.sabia','massimosabia@hotmail.com','Massimo Sabia','Via Feltre<br>n21','Belluno','BL','ITALY','32100','0437 941662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 10:12:55',0,NULL,3,0,3,1,NULL,'massimo.sabia\rRELO002\rRA022495285CN\r'),(483,759168476012,220748684536,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','ketron040','jukka.t@japo.fi','Jukka Turja','Suvitie 278','62830 Luoma-aho','länsisuomi','FINLAND','62830','040 7404230','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 10:40:29',0,NULL,3,0,2,1,NULL,'ketron040\\'),(484,561891316013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','mikalaiblr','nickblack@tut.by','Mikalai Krautsou','Julpva str. 36/2 - 40','Gomel','','BELARUS','246029','+375257408137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 11:08:58',0,NULL,3,0,2,1,NULL,'mikalaiblr\\'),(485,683176049011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','mad_max_8','jeroenklaassen@home.nl','Jeroen Klaassen','Willem-Alexanderlaan 17','HAPS','','NETHERLANDS','5443BX','0617136656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:18:24',0,NULL,3,0,2,1,NULL,'mad_max_8\\'),(486,0,230597232820,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.25,'eastar4','karooumba','karooumba@hotmail.com','Karine Latraverse','119 Place Fontainebleau','Saint-Lambert','QC','CANADA','J4S 1X6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:34:19',0,NULL,3,0,2,1,NULL,'karooumba\\'),(487,563112833013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','cheyque','blundface@gmail.com','Jesse G Herrera','1101 Sapphire St','Laredo','TX','UNITED STATES','78045-8053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 12:44:33',0,NULL,3,0,1,1,NULL,'cheyque\\'),(488,563113569013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','georgebouk','schorsch@freemail.gr','Bouklas Georgios','Omirou str.10','Grevena','','GREECE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:52:20',0,NULL,3,0,2,1,NULL,'georgebouk    欧标\\'),(489,759255413012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',21.99,'eastar4uk','janiugrinb','jani.ugrin@me.com','Jani Ugrin','Klariceva ulica 11','Koper','','SLOVENIA','6000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 13:16:21',0,NULL,3,0,3,1,NULL,'janiugrinb\rHSUE002\rRA022495949CN\r'),(490,563123302013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','kipishev','tiki@list.ru','Andrey Tikishev','ul. Pozharskogo d.18 kv.12','Himki','Moskovskaya obl','RUSSIAN FEDERATION','141411','(926)593-1128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:17:29',0,NULL,3,0,3,1,NULL,'kipishev\rMOSA002\rRA022496649CN\r'),(491,0,220754849414,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'',9.99,'eastar4','joejv4321','joevaladez10@yahoo.com','joe valadez','140 Norma St','san angelo','TX','UNITED STATES','76903','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-20 13:23:58',0,NULL,3,0,1,1,NULL,'joejv4321\rOMHJ001\\'),(492,518032683004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','versat9110','pandosantos@gmail.com','verissimo alfredo pando santos','urbanização quinta da palmeira<br>lote 52 2º. ESQ.','FARO','FARO','PORTUGAL','8005-546','911020759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:45:33',0,NULL,3,0,3,1,NULL,'versat9110   欧标\rHSNO005\rRA022495895CN\r'),(493,759273310012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','dariusp85','darius@onrails.lt','Darius Pėža','Nykos 5, Gerdžiūnų km. Šakių raj. Lithuania','Šakiai','','LITHUANIA','4744','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 13:52:12',0,NULL,3,0,2,1,NULL,'dariusp85\rHSNO006\r欧标\\'),(494,0,230598822052,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','7529jeffrey','delete3970@aol.com','Jeffrey Muto','218 McChain Rd','Finleyville','PA','UNITED STATES','15332-4111','(724) 348-5716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 14:26:15',0,NULL,3,0,1,1,NULL,'7529jeffrey\\'),(495,0,320673333383,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'eastar4','dajkam','dajmik@freemail.hu','Miklós Dajka','Csokonai út 53. 1/2.','Szolnok','','HUNGARY','5000','+36203424949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:30:02',0,NULL,3,0,2,1,NULL,'dajkam\r欧标\\'),(496,759308003012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','jaltin','jaltin@gmx.de','jörg altintzoglou','gerhart hauptmann str 40','erkrath','','GERMANY','40699','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:57:39',0,NULL,3,0,2,1,NULL,'jaltin\\'),(497,759307667012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','electric-assembler','kalleniskanen@gmail.com','Kalle-Hermanni Niskanen','Soliskyläntie 10','Viitasaari','','FINLAND','44500','+358408667011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:58:54',0,NULL,3,0,2,1,NULL,'electric-assembler\\'),(498,512236394003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','ravst8o','phepso@broadpark.no','Petter Hepso','Markaplassen 9<br>7054 Ranheim','Trondheim','','NORWAY','nozip','+4790750217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:25:40',0,NULL,3,0,3,1,NULL,'ravst8o\rRCLO005\rRA022495498CN\r'),(499,563171241013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','belevichd','denis@belevich.net','Denis Belevich','ul. Lenina 112 - 6','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:34:46',0,NULL,3,0,2,1,NULL,'belevichd\\'),(500,759373243012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',29.5,'eastar4','kasparavicius123','maria_mrrqn@yahoo.com','MARIA KASPARAVICIUS','409 Addison St<br>Apt 1','ELGIN','IL','UNITED STATES','60120-4434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 16:44:23',0,NULL,3,0,1,1,NULL,'kasparavicius123\\'),(501,512278035003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','ingpoint17','mbas@email.it','PAMELA LOSURIELLO','VIA VITTORIO VENETO 97','ADELFIA','BARI','ITALY','70010','328-5518721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:05:03',0,NULL,3,0,3,1,NULL,'ingpoint17  欧标\rHSNO008\rRA022495864CN\r'),(502,512269086003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','dido22_974','david.hivanhoe@sfr.fr','David Hivanhoé','App 63, Central FAC 6<br>1 Rue de Grêce','Le Tampon','Réunion','REUNION','97430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 16:46:25',0,NULL,3,0,3,1,NULL,'dido22_974\rRELO002\rRA022495161CN\r'),(503,512271310003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','fulviocam','fulvio.campagnoli@virgilio.it','GIUSEPPE CAMPAGNOLI','VIA U.FOSCOLO N°13','ARCISATE','VA','ITALY','21051','0332470685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 16:50:23',0,NULL,3,0,3,1,NULL,'fulviocam  欧标\rHSNO008\rRA022496564CN\r'),(504,518112552004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',2,'WLAT001+ANTY001*3',35.98,'cnfaner','akhu','jprohart@free.fr','Jean Philippe Rohart','31 rue Louis Braille','Bordeaux','Aquitaine','FRANCE','33000','06 58 16 14 08','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:10:38',0,NULL,3,0,3,1,NULL,'akhu     WLAT001+ANTY001*3\rRA022495250CN\r'),(505,683359707011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','6969traba','markerbeacon@att.net','Michael Abart','8534 Red Baron Blvd','Reno','NV','UNITED STATES','89506','(775) 677-0923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:38:32',0,NULL,3,0,1,1,NULL,'6969traba、'),(506,0,230597230034,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',15.5,'eastar4','dgrunsten','dgrunsten@yahoo.com','Dehn Grunsten','928 Prairie Ridge Ct','Burr Ridge','IL','UNITED STATES','60527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:50:24',0,NULL,3,0,1,1,NULL,'dgrunsten\\'),(507,759470015012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','mariusz7879','mariusz7879@hotmail.com','Anna  Goralik','2828 Pearl St','Franklin Park','IL','UNITED STATES','60131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 18:28:10',0,NULL,3,0,1,1,NULL,'mariusz7879\\'),(508,0,220754847104,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 18:36:37',0,NULL,3,0,1,1,NULL,'lilfelacamacho440\r一共买了2个 PLANTRONICS 220\r2个PLANTRONICS 330\\\r'),(509,683356191011,320443637303,'Acer Timeline 4810 5810 Bluetooth Module 2.0 EDR+ cable',1,'BTAC2001',14.49,'eastar4','seborss','borshchenko@gmail.com','Sergii Borshchenko','Kovpaka 4, 95','Kyiv','Kyiv','UKRAINE','03150','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-20 18:23:28',0,NULL,3,0,2,1,NULL,'seborss\racer 4pin 1.25 3cm\\'),(510,0,230598822363,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',29.99,'eastar4','artleks','art2003@inbox.ru','Artem Kulev','Arhipova st. 4-7','Petrozavodsk','','RUSSIAN FEDERATION','185000','+79114110120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 17:07:06',0,NULL,3,0,2,1,NULL,'artleks\\'),(511,512399843003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','shirikaro','itay50@gmail.com','shiri karo','mohaliver 130','yehud','israel','ISRAEL','56209','0508355836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:09:54',0,NULL,3,0,3,1,NULL,'shirikaro\rHSNO008\rRA022496652CN\r'),(512,0,220756896741,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','trmnshwrx','dovereb@yahoo.com','Don Bishop','PO Box 772','Sublette','KS','UNITED STATES','67877','(801) 753-8257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 20:03:53',0,NULL,3,0,1,1,NULL,'trmnshwrx\\'),(513,0,220754846386,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',21.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 20:09:57',0,NULL,3,0,1,1,NULL,'4278dennis\r再发一个保护屏\\\r4  电源    \r2  屏幕    、'),(514,563365659013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','tomek*111','tomasz.wysocki@aster.pl','Tomasz Wysocki','J.Nowaka-Jeziorańskiego<br>9/330','Warsaw','mazowieckie','POLAND','03-984','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:37:35',0,NULL,3,0,3,1,NULL,'tomek*111\rMOSA002\rRA022495626CN\r'),(515,683514293011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','afzaal2010afzaal','afzaal81@yahoo.com','AFZAAL RANA','200 Woodydell ave','winnipeg','MB','CANADA','R2M2V1','(120) 496-0826 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:20:26',0,NULL,3,0,2,1,NULL,'afzaal2010afzaal\\'),(516,563400613013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','vanessa_wiest','van.m.vincent@gmail.com','Vanessa Vincent','352 Meredith Sq','Columbia','SC','UNITED STATES','29223-2268','(801) 494-4444','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-20 21:37:56',0,NULL,3,0,1,1,NULL,'vanessa_wiest\\'),(517,759641343012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','hubbify77x','hubbify77x@hotmail.com','Derek Husband','6210 Santa Ana Way','Stockton','CA','UNITED STATES','95215-9657','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 21:10:17',0,NULL,5,0,18,0,NULL,'hubbify77x'),(518,759668266012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',96.8,'eastar4','proszper','proszper@freemail.hu','László Kiss','Középszer u. 62. 8/2','Miskolc','','HUNGARY','3529','+36209154854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:51:11',0,NULL,3,0,3,1,NULL,'proszper    欧标\r再发一个1000B\r\rRA022494047CN\r'),(519,759683948012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','miguel_viana','viana_miguel@yahoo.com','Miguel Viana','R. Alvaro Guerra Lt.5 3º Dt.º','Póvoa de Santa Iria','','PORTUGAL','2625-268','+351963803798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 22:17:52',0,NULL,3,0,2,1,NULL,'miguel_viana\\'),(520,518305668004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','meemee64','meemee64@hotmail.com','La\'Meesha Richardson','228 S 60th St<br>Fl 3','Philadelphia','PA','UNITED STATES','19139','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 23:08:22',0,NULL,3,0,1,1,NULL,'meemee64、'),(521,512459326003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'cnfaner','sammaramma','sammeehoo@yahoo.ca','Sam Niemi','PO Box 10496','Thunder Bay','ON','CANADA','P7B 6T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 22:50:33',0,NULL,3,0,3,1,NULL,'sammaramma\rRA022495263CN\r'),(522,759725630012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','clckleezer','cleezer@wowway.com','Christina Leezer','5691 Buenos Aires Blvd','Westerville','OH','UNITED STATES','43081-4245','(614) 895-3524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 23:50:36',0,NULL,3,0,1,1,NULL,'clckleezer\rLK032969309CN\r\\'),(523,0,320671449348,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:09:16',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(524,759715474012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','sean5167','seanbehan4@hotmail.com','sean behan','2 craigmuir gardens','blantyre','South Lanarkshire','UNITED KINGDOM','g72 9ry','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 23:27:58',0,NULL,3,0,3,1,NULL,'sean5167\rRA022495229CN\r'),(525,518326890004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'cnfaner','youpla.b','youpla.b@gmail.com','Damien Leblanc','11 rue de Seine','Sartrouville','Île-de-France','FRANCE','78500','+33668434788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:19:36',0,NULL,3,0,3,1,NULL,'youpla.b    加一个IBM  X200  antenna \rRA022495277CN\r\r'),(526,683633153011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',8,'CASS002',130.5,'eastar4','leander.janssen','leander@slaco.net','Leander Janssen','Van der Stoklaan 9','Den Haag','Zuid Holland','NETHERLANDS','2493BX','+31654947981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 23:41:37',0,NULL,3,0,5,1,NULL,'leander.janssen\r一共买了8个CAB-2660\r3个CAB－6060\r4个CAB－2626  \rCP226379436CN\r\r\r'),(527,759743234012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','youpla.b','youpla.b@gmail.com','Damien Leblanc','11 rue de Seine','Sartrouville','Île-de-France','FRANCE','78500','+33668434788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:34:45',0,NULL,8,0,17,0,NULL,'youpla.b'),(528,683674616011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','maro_jp','mstudio.jp@gmail.com','Masahiro Matsushita','2-1, E-103 Minami-Numagami<br>Aoi-Ku','Shizuoka','Shizuoka','JAPAN','4200905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 01:29:50',0,NULL,3,0,2,1,NULL,'maro_jp\\'),(529,563495226013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','emangel415','eakreppel@gmail.com','Emilie  Kreppel','16 Hoover Ave','Kenmore','NY','UNITED STATES','14217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 02:41:32',0,NULL,3,0,1,1,NULL,'emangel415\rLK032967577CN\\'),(530,563495181013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','danfromengland','dan.mcgrath@tng.ca','Daniel McGrath','17 Campkin Street','Brampton','ON','CANADA','L6Y 3G9','(647) 801-8856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 02:44:26',0,NULL,3,0,2,1,NULL,'danfromengland\\'),(531,563339937013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','valearlf','vfrederick@gmail.com','Val Frederick','12143 Valleyheart Dr<br>Apt 3','North Hollywood','CA','UNITED STATES','91604-2089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 19:51:58',0,NULL,3,0,1,1,NULL,'valearlf、'),(532,563164719013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','jacki312','epifini@gmail.com','Jacki Kinzy','6759 Tribal Ct','Long Grove','IL','UNITED STATES','60047-5119','(847) 566-3135','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 04:01:17',0,NULL,3,0,1,1,NULL,'jacki312\\'),(533,563512171013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','thealy_ir','thealy@rocoil.com.au','Tim Healy','Rocoil, Level 18<br>321 Kent Street','Sydney','New South Wales','AUSTRALIA','2000','0405623971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 04:08:37',0,NULL,3,0,2,1,NULL,'thealy_ir\\'),(534,563506169013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','tribocharge','jjcollett@triad.rr.com','John Collett','1321 Cedar Dr','Thomasville','NC','UNITED STATES','27360','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 03:33:14',0,NULL,3,0,1,1,NULL,'tribocharge\rLK032939845CN \\'),(535,759829267012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',1,'ANYA001',14.45,'eastar4','junior2426','adalbertojun28@gmail.com','junior gonzalez','HC 2 Box 7386<br>Bo Montones 4','Las Piedras','PR','UNITED STATES','00771','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 05:10:13',0,NULL,3,0,11,1,NULL,'junior2426\\'),(536,0,220756896424,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:10:24',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(537,0,320673334007,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 00:10:57',0,NULL,8,0,17,0,NULL,'lilfelacamacho440'),(538,563451968013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','koorni71','kai.oorni@gmail.com','Kai Öörni','Kuuraparrantie 19 E 2','Oulu','','FINLAND','90630','358405484661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 00:17:58',0,NULL,3,0,3,1,NULL,'koorni71  \rRA022495348CN\r'),(539,683713403011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','nanu4k7','nan4k7@gmail.com','Hernán Nesprías','Hipólito Yrigoyen 480','Buenos Aires','Ciudadela','ARGENTINA','1702','11-63517176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 03:37:55',0,NULL,3,0,2,1,NULL,'nanu4k7\\'),(540,563535874013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','cmancini','cmancini1@yahoo.com','Cesare Mancini','84-78 Austin st.','Kew Gardens','NY','UNITED STATES','11415-2205','(917) 282-4745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 07:22:54',0,NULL,3,0,1,1,NULL,'cmancini\\'),(541,759873793012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',55.98,'eastar4uk','mmil5305','kirsty.brisco@alterfencing.com','Mary Miller','Weels Farm<br>Lochwinnoch','Glasgow','Renfrewshire','UNITED KINGDOM','PA12 4LD','01505842201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 08:56:24',0,NULL,3,0,3,1,NULL,'mmil5305\r英标   HSNO019\rRA022495365CN\r'),(542,683773861011,320613191693,'NEW Motorola H700 Gold DG Bluetooth Headset+car charger',1,'HSMO012+CCMO001',19.9,'eastar4','guyarkoni','guyark@hotmail.com','guy yarkoni','halamed hey','kfar-saba','','ISRAEL','44395','972-546655527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 09:10:47',0,NULL,3,0,2,1,NULL,'guyarkoni\\'),(543,512593944003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','mecenat76','khlupov@km.ru','Alexandr Khlupov','Altaiskaya  21-160','Moscow','','RUSSIAN FEDERATION','107589','+79161422461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 10:27:33',0,NULL,3,0,3,1,NULL,'mecenat76\rWWSI005 +ANCN001\rRA022495379CN\r'),(544,683621163011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jimbowey','jim.bowey@comcast.net','Jim Bowey','4002 NW Poppy Dr','Corvallis','OR','UNITED STATES','97330-3477','(541) 752-1620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 23:07:19',0,NULL,3,0,1,1,NULL,'jimbowey\\'),(545,683808589011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT003',31.9,'eastar4','steff.killer','steff_killer@hotmail.com','stephane INION','6 rue falque','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13006','06.23.17.85.95','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:25:44',0,NULL,3,0,3,1,NULL,'steff.killer\rWLAT003  \rRA022495776CN\r'),(546,683578327011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','berlin6776','rafael.burghardt@gmx.de','Rafael Burghardt','Pariser Strasse 55','Berlin','','GERMANY','10719','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 21:36:38',0,NULL,3,0,2,1,NULL,'berlin6776、'),(547,563597045013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','ophtha72','ophtha@empal.com','Jonghyun Lee','Hyundae-Hometown 3rd. Apartment 302-402, Bang-Bae-Dong 2233<br>Seo-Cho-Gu','Seoul','','KOREA,REPUBLIC OF','137-060','(822) 592-4329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:12:22',0,NULL,3,0,2,1,NULL,'ophtha72、'),(548,0,320673821326,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32,'eastar4','oldmanuals','harley.abud@gmail.com','Harley Zanarotti Abud','Rua David Maria M. Gomes, 40 / 34<br>Centro - CEP 12020-300','Taubate','São Paulo','BRAZIL','12020-300','(128) 827-5375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:12:26',0,NULL,3,0,3,1,NULL,'oldmanuals\rOTRA002\rRA022495396CN\r'),(549,683841445011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','hojuguy','rosspacker@gmail.com','Ross Packer','2 Botany Court','Wantirna','Victoria','AUSTRALIA','3152','0398840513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:18:28',0,NULL,3,0,2,1,NULL,'hojuguy\r澳标\\'),(550,512626760003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:21:29',0,NULL,3,0,3,1,NULL,'masteroll2010\rRELO002\rRA022495484CN\r\\'),(551,563601945013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','sjmont5','bsm5000@yahoo.com','steve monterio','36 spartan arrow rd','littleton','MA','UNITED STATES','01460-1257','(508) 864-6212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 13:27:39',0,NULL,3,0,1,1,NULL,'sjmont5\\'),(552,518467290004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','dramisys','yvan@simard.com','Yvan  Simard','332 Joseph-Leduc','St-Eustache','QC','CANADA','J7R7K1','(514) 231-0535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:50:50',0,NULL,3,0,3,1,NULL,'dramisys\rRA022495334CN\r'),(553,563615951013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','divemasterlv','divemaster.lv@gmail.com','Toms Uzans','Ezera 9-17','Riga','Latvia','LATVIA','LV-1005','22339758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:20:45',0,NULL,3,0,2,1,NULL,'divemasterlv\\'),(554,683870978011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','quest_fore_eagle','fernand_couture@sympatico.ca','Fernand Couture','C/O Richelieu Hosiery Int\'l Inc.<br>600 Campbell','Cornwall','ON','CANADA','K6H 6C9','(613) 938-6461 ext.: 236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:46:18',0,NULL,3,0,2,1,NULL,'quest_fore_eagle、'),(555,0,320671984289,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',11.25,'eastar4','wanderingwizard','chaitu45@gmail.com','Chaitanya Reddy Teegela','3307 Jefferson Ave<br>Apt 5','Cincinnati','OH','UNITED STATES','45220-2120','(513) 545-8384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 15:17:23',0,NULL,3,0,1,1,NULL,'wanderingwizard\\'),(556,0,320671980191,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','xpo040','youllbsmiling@gmail.com','Pheing Ngo','696 Seyton Dr.','Ottawa','ON','CANADA','K2H1A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:21:31',0,NULL,3,0,2,1,NULL,'xpo040\\'),(557,0,320672002304,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',35,'eastar4','ivan_piter','arhipov_2000@mail.ru','Иван Михайлович Архипов','ул. Воронежская, д.15, кв.33<br>St-Peterburg, st. Voronejskay d,15, kv.33','Санкт-Петербург','','RUSSIAN FEDERATION','191119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:50:44',0,NULL,3,0,3,1,NULL,'ivan_piter\rOTRA002\rRA022495538CN\r'),(558,760003942012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','zman.2009','anonexaykittirath@yahoo.com','anonexay kittirath','General Delivery','Ringgold','LA','UNITED STATES','71068-9999','(337) 366-7331','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 15:51:10',0,NULL,3,0,1,1,NULL,'zman.2009\\'),(559,760008560012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','xpmaster_antofagasta','acortes@nortraining.com','Alvaro Cortes','Cerro Colorado 3746 Edificio Radiatta Dept. 503<br>Condominio Jardines del Sur','Iquique','Tarapacá','CHILE','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 15:59:29',0,NULL,3,0,2,1,NULL,'xpmaster_antofagasta、'),(560,563418523013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',125.99,'eastar4','wulfy19','dave.dewulf@gmail.com','Dave Dewulf','409 Gilpin Dr','Newmarket','ON','CANADA','L3X3H3','(289) 221-5333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 16:20:04',0,NULL,3,0,3,1,NULL,'wulfy19\rRCLO003\rRA022494055CN\r'),(561,518502347004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','jrgnmrn','jhw58@arcor.de','Jürgen Wilke','An den Birken 5','Hohen Neuendorf','','GERMANY','16562','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 16:20:52',0,NULL,3,0,3,1,NULL,'jrgnmrn\rBALO007\rRA022495351CN\r'),(562,516070829004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','arquivision','joaquin2112@gmail.com','Joaquin Rosales','18 Av. 37-00 Zons 12 Cond. Villa Sol Apto. 824','Guatemala','Guatemala','GUATEMALA','01012','502-24766680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:11:27',0,NULL,3,0,3,1,NULL,'arquivision\rOTCR001\rRA022495422CN\r'),(563,518524486004,140516102898,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'cnfaner','punkrockallstar','punkrockallstar1@gmail.com','Sooksan Pashayanukun','118 Mb. Pontep , soi Patanakarn 54<br>Patanakarn Rd. , Suanluang','Bangkok','','THAILAND','10250','66819077677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:41:23',0,NULL,3,0,3,1,NULL,'punkrockallstar\rBALO005\rRA022495325CN\r'),(564,518521393004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','7040014','ilan.neeman@gmail.com','Ilan Neeman','36 Visbourg St.','Tel-Aviv','','ISRAEL','69358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:42:17',0,NULL,3,0,3,1,NULL,'7040014\rHSPL010\rRA022495215CN\r\\'),(565,0,220755498992,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',14.24,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 17:53:08',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个New US Logitech Harmony AC Power Adapter 720 880 890\\'),(566,518536093004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','artur.rodrigo','arturrodrigo@terra.com.br','Artur Rodrigo Oliveira Dias','Rua São Florêncio, 1300 casa 55<br>Cangaíba','São Paulo','SP','BRAZIL','03733-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 18:17:04',0,NULL,3,0,3,1,NULL,'artur.rodrigo\rHSJA002\rRA022495405CN\r'),(567,683980346011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','volfenhag666','volfenhag666@hotmail.com','Thomas MOREL','23 Rue St Michel','CORBIERES','Provence-Alpes-Côte d\'Azur','FRANCE','04220','0678912904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 18:58:36',0,NULL,3,0,2,1,NULL,'volfenhag666\\'),(568,760103446012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',16.59,'eastar4','digitalwimp','st.rieder@web.de','Stefan Rieder','Dammerkamp 7','Mühlenbarbek','','GERMANY','25548','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:07:12',0,NULL,3,0,2,1,NULL,'digitalwimp  Acer 5pin1.25 3cm\r新地址\rStefan Rieder\rSARmedia\rDammerkamp 7\rMühlenbarbek  25548\rGERMANY\\'),(569,683669802011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','minwye','minwye@gmail.com','Min Wye Chan','Visual Eyes 444 Brunswick Street','Fortitude Valley','Queensland','AUSTRALIA','4006','610404327468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 01:18:56',0,NULL,3,0,2,1,NULL,'minwye\\'),(570,760110365012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','asti4268','davoserem@cox.net','Albert Stiehle','627 Windsor Circle','Chula Vista','CA','UNITED STATES','91910','(619) 425-5217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 19:14:20',0,NULL,3,0,1,1,NULL,'asti4268\rLK032811190CN\r'),(571,563724898013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','floridabeaches','doug@digital-ocean.net','Douglas Darlington','4431 Windsmere Blvd','Orlando','FL','UNITED STATES','32835','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 19:48:02',0,NULL,3,0,1,1,NULL,'floridabeaches\\'),(572,563717893013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ebuymyshop','akkara111@yahoo.com','Akkara Lekkla','2641 Moo 3 Soi Baring 19<br>Somrongnai','Maung','Samutprakarn','THAILAND','10270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:33:54',0,NULL,3,0,2,1,NULL,'ebuymyshop\\'),(573,512734158003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','duskabond','bondarenkoandrej@mail.ru','ANDREI BANDARENKA','N.DVORNIKOVA 14/36','GOMEL','','BELARUS','246004','375293551382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:47:54',0,NULL,3,0,3,1,NULL,'duskabond\rHSSE003   欧标\rRA022495303CN\r'),(574,684033694011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','guillaume_fp','guillaume.coeffe@ecl2006.ec-lyon.fr','guillaume Coeffe','48, Rue Saint Ferdinand','PARIS','Île-de-France','FRANCE','75017','0632418579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:23:35',0,NULL,3,0,2,1,NULL,'guillaume_fp、'),(575,563736687013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','romanenko2010','romanenkooleksandr@gmail.com','Oleksandr Romanenko','proulok.Karla Marksa street. 18 app 73','vinnitsa','vinnitsa region','UKRAINE','21034','0672185338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:13:05',0,NULL,3,0,2,1,NULL,'romanenko2010\\'),(576,760171460012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','katmandunor','katmandu@live.com','Odd Viggo Roeggen','Bokfinkveien 28a','Kristiansand','','NORWAY','4626','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:49:40',0,NULL,3,0,3,1,NULL,'katmandunor\rWLDE002\rRA022495541CN\r'),(577,0,320671985860,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','mafiaface','tntmafiaface@aol.com','Terry Nham','2752 California St','Berkeley','CA','UNITED STATES','94703-1847','(510) 610-7109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 21:11:31',0,NULL,3,0,1,1,NULL,'mafiaface\\'),(578,760186372012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','pauk_88','stufler@rambler.ru','Иван Дриль','Россия<br>пер. Попова д.9','Брянск','RI','RUSSIAN FEDERATION','241028','8-953-270-72-70','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 21:26:45',0,NULL,3,0,2,1,NULL,'pauk_88、'),(579,0,320671984492,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',11.25,'eastar4','james_speck','speck@tut.by','Dzmitry Hiz','Miroshnichenko st.<br>15-98','Minsk','','BELARUS','220131','+375296462580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 22:02:02',0,NULL,3,0,2,1,NULL,'james_speck\\'),(580,512822855003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','jams1970160','jorgesousa@netcabo.pt','Jorge Amadeu Moreira Sousa','Rua Delfim de Lima, 1883','Canelas','','PORTUGAL','4410-227','00351938307186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 00:19:20',0,NULL,3,0,3,1,NULL,'jams1970160\rHSNO005+CCNO001\rRA022495555CN\r'),(581,760265760012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',5.98,'eastar4uk','jhow1779','jeff.caroline@btinternet.com','Jeffrey Howard','113 Potter Street','Harlow','Essex','UNITED KINGDOM','CM17 9AN','01279445269','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 00:23:29',0,NULL,3,0,3,1,NULL,'jhow1779\rOTCN003\rRA022495382CN\r'),(582,563823193013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','bordij','jbev@bordyfamily.com','John Bordy','3215 Hampshire Ln','Oklahoma City','OK','UNITED STATES','73179-1205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 00:46:11',0,NULL,3,0,1,1,NULL,'bordij\rLK032827760CN\r'),(583,512828622003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','989dave3301','dmging1@verizon.net','Dave Gingerich','7933 Wildcat Rd','Ovid','MI','UNITED STATES','48866-9656','(989) 277-8827','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:46:21',0,NULL,3,0,1,1,NULL,'989dave3301\\'),(584,684084480011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',2,'WLAP001',29.62,'eastar4','whitenoise.dac','whitenoise.alejandro@gmail.com','Alejandro Blanco','Ramon Falcon 6411 Dpto C','Capital Federal','Buenos Aires','ARGENTINA','1408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 01:02:57',0,NULL,3,0,2,1,NULL,'whitenoise.dac\\'),(585,760286800012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','quesnyv','yves.quesnel@videotron.ca','yves quesnel','105 rue du foin','saint-augustin de desmaures','QC','CANADA','g3a 2s1','(418) 878-8664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 01:28:16',0,NULL,3,0,2,1,NULL,'quesnyv\\'),(586,0,230597232252,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'',10.8,'eastar4','vickie13100','chewbacca42499@yahoo.com','Vickie Smith','470 N Front St','Steelton','PA','UNITED STATES','17113','(717) 635-0464','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:28:54',0,NULL,3,0,1,1,NULL,'vickie13100\rHSPL005\\'),(587,518681841004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','soulgravy','likwidsoul007@yahoo.com','George Hermantin','1747 Sophias Dr<br>Apt 106','Melbourne','FL','UNITED STATES','32940-6209','(321) 505-2292','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 02:32:09',0,NULL,3,0,1,1,NULL,'soulgravy\\'),(588,0,320671980077,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.25,'eastar4','doglipz','19val70@sbcglobal.net','Valdemar Perez','5101 Prairie Dunes Dr','Austin','TX','UNITED STATES','78747','(512) 280-6020','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 02:34:32',0,NULL,3,0,1,1,NULL,'doglipz\\'),(589,760309869012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','trickybiddy','trickybid@gmail.com','G Nakamoto','568 McGraw St','Seattle','WA','UNITED STATES','98109-2250','(206) 852-4291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:44:57',0,NULL,3,0,1,1,NULL,'trickybiddy\\'),(590,684176622011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jfbimkiii','jfbimkiii@hotmail.com','JF Bienvenu','2190 Gertrude','Carignan','QC','CANADA','j3l4h1','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jfbimkiii'),(591,684178125011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','dimitri6957','dimivanhemelrijck@hotmail.com','Dimitri Vanhemelrijck','landbeekstraat 10','Meise','','BELGIUM','1860','32486565322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 02:54:24',0,NULL,3,0,2,1,NULL,'dimitri6957\\'),(592,563855874013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','littlejohn1134','johnmeindersee@yahoo.com','John Meindersee II','513 Richardson ST','Martinez','CA','UNITED STATES','94553-1522','(925) 588-4279','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 03:15:12',0,NULL,3,0,1,1,NULL,'littlejohn1134\\'),(593,563857271013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','yogrark','retlaw@rogers.com','Walter Smith','69 Bushey Ave','Toronto','ON','CANADA','M6N2R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 03:20:53',0,NULL,3,0,2,1,NULL,'yogrark\\'),(594,760335019012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',14.49,'eastar4','mnorton1967','markdjnorton@internode.on.net','Mark Norton','59 Dalkeith Drive','Mount Gambier','South Australia','AUSTRALIA','5290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:31:26',0,NULL,3,0,2,1,NULL,'mnorton1967\racer 8pin1.00 18cm\\'),(595,684201507011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','0valka0','vvionov2007@gmail.com','Хабаровский край Ионов','Запарина<br>160','Хабаровск','Хабаровский край','RUSSIAN FEDERATION','680011','+79147704950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:57:31',0,NULL,3,0,2,1,NULL,'0valka0\\'),(596,563874998013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','fifita-2008','simphonie08@yahoo.com','legette cruz','6 Abington Ave<br>Apt 4','newark','NJ','UNITED STATES','07104-1463','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 05:35:54',0,NULL,3,0,1,1,NULL,'fifita-2008\rLK032934503CN\\'),(597,760349327012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','kasiuskarm','serega70@gmail.com','Sergey Vandalovsky','Khativat Karmeli 21 / 3','Karmi\'el','Zafon','ISRAEL','21991','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 06:02:55',0,NULL,3,0,2,1,NULL,'kasiuskarm\\'),(598,684218604011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',16.59,'eastar4','exileo','esanhusky@comcast.net','Michael Marr','17 Euclid Ave','Washington','PA','UNITED STATES','15301-5461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 06:50:05',0,NULL,3,0,1,1,NULL,'exileo\rHP 8pin 1.25 18cm\\'),(599,512889657003,130466041713,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',69.9,'cnfaner','y.krasnov','y.krasnov.ebay@gmail.com','Jyri Krasnov','21 King Street<br>New Market','Maidenhead','Berkshire','UNITED KINGDOM','SL6 1DR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:02:33',0,NULL,3,0,3,1,NULL,'y.krasnov    WWOT002\r新地址\r\rJyri Krasnov\rBarrikadnyi 36\rBishkek Kyrgyzstan 720007\rKyrgyzstan\rRA022494841CN\r'),(600,563895285013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','szubrilov','zubrilov@freenet.com.ua','Sergey Zubrilov','7 Myshugy Street<br>Apt. 37','Kyiv','','UKRAINE','02140','380445728041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:30:58',0,NULL,3,0,3,1,NULL,'szubrilov\rRA022494824CN\r'),(601,563897208013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','d.thomas2011','d.thomas@stryker.com','DAVID Thomas','38 Mulyan Street','Como','New South Wales','AUSTRALIA','2226','0402164454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 08:41:05',0,NULL,3,0,3,1,NULL,'d.thomas2011\rRA022494767CN\r'),(602,684243814011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','sergiabo','sergionietodelamo@gmail.com','Francisco Dominguez','C Marques de Santillana, Nº 1  3ºD','Valladolid','Castilla y León','SPAIN','47010','609203599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 09:02:32',0,NULL,3,0,2,1,NULL,'sergiabo\\'),(603,683859377011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jmok222','jmok@hotmail.com','James Mok','149 Lakeshore Rd. E.','Mississauga','ON','CANADA','L5G 4T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:14:26',0,NULL,3,0,2,1,NULL,'jmok222\\'),(604,684254556011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',2,'MOCN001',9.32,'eastar4','n.dmitry','ndmitry@gmail.com','Dmytro Nyeizvyestnyy','10, Kruhlo-Universytetska str.','Kyiv','','UKRAINE','01024','+380674400044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 09:47:47',0,NULL,3,0,2,1,NULL,'n.dmitry\\'),(605,518738945004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','adwraj','me@adwraj.com','Andrew Raj','No 21, SS3/23,<br>Taman Universiti,','Petaling Jaya','Selangor','MALAYSIA','47300','0175809780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:02:10',0,NULL,3,0,3,1,NULL,'adwraj\rRA022494943CN\r'),(606,746208073012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',50,'eastar4','denand71','denand@live.ru','Andrey Denisov','8 peschaniy st.6','Tula','Tulskaya obl','RUSSIAN FEDERATION','300031','+7 903 6588888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-02-24 05:15:15',0,NULL,5,0,18,0,NULL,'denand71'),(607,760410444012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','rothschildinvestment','gtanasic@gmail.com','Gavrilo Tanasic','Zuercherstrasse 13','Basel','','SWITZERLAND','4052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:42:17',0,NULL,3,0,2,1,NULL,'rothschildinvestment\\'),(608,518751667004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','os1samba','user@os9samba.com','Ilja Levinson','Pervomayskaya st., 67-4','Yekaterinburg','','RUSSIAN FEDERATION','620062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:21:46',0,NULL,3,0,3,1,NULL,'os1samba\rRA022494651CN\r'),(609,518297376004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','annak541','annakrug@hotmail.com','Anna Krug','905 Darneille Ln','Grants Pass','OR','UNITED STATES','97527-6181','(541) 582-1118 ext.: 42','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 11:22:27',0,NULL,3,0,1,1,NULL,'annak541\r\\'),(610,563927521013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','rensu83','juha-matti.rensujeff@dlc.fi','Juha-Matti Rensujeff','Kuukkelitie 3A6','Rovaniemi','','FINLAND','96910','+358445556564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:33:57',0,NULL,3,0,3,1,NULL,'rensu83\rRA022494784CN\r'),(611,518754741004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','assaframan','asaf_at_china@yahoo.com','Assaf Raman','4/8 Jericho street','Tel Aviv','','ISRAEL','62035','+972528391448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:37:52',0,NULL,3,0,3,1,NULL,'assaframan\rRA022494722CN\r'),(612,512926931003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','anubhav4you','anubhav4you@hotmail.com','Anubhav Visen','112 W 51st St<br>Apt 102','Kansas City','MO','UNITED STATES','64112-2442','(816) 651-6962','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-22 11:59:13',0,NULL,3,0,3,1,NULL,'anubhav4you\rRA022494515CN\r'),(613,760435457012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','siciliano1954','siciliano2002@gmail.com','carlos alberto siciliano','rua prof. pedreira de freitas, 69<br>apto 91 - tatuape','São Paulo','SP','BRAZIL','03312052','055 21 82311262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:10:14',0,NULL,3,0,2,1,NULL,'siciliano1954\\'),(614,0,230597696898,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','superjett55','superjett55@hotmail.com','Joshua Gardner','61 Beaucourt Road','Hamilton','ON','CANADA','L8S 2R2','(416) 818-1231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:12:14',0,NULL,3,0,2,1,NULL,'superjett55\r一共买了两个\r\\'),(615,518760570004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','pjy85n','85park@hanmail.net','JUNYOUNG PARK','303ho, 33-7<br>Sosa-dong, Wonmi-gu','Bucheon-si','Gyeonggi-do','KOREA,REPUBLIC OF','420-818','011)93811353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:19:02',0,NULL,3,0,3,1,NULL,'pjy85n\rRA022494563CN\r'),(616,518762987004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','mrbud321','mrbud321@yahoo.com','Scott Wages','1440 Lakes Pkwy<br>Ste 600','Lawrenceville','GA','UNITED STATES','30043-5896','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 12:53:44',0,NULL,5,0,18,0,NULL,'mrbud321'),(617,684302804011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','riantini','riantini999@yahoo.co.id','Riantini Pujianto','Jl. Wijaya Kusumah IV Blok XI No 87<br>Rt 07/Rw 19 Cijerah','Cimahi Selatan','Jawa Barat','INDONESIA','40534','+6285759939999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:54:14',0,NULL,3,0,2,1,NULL,'riantini\\'),(618,563953215013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',7.98,'eastar4','jaccogeul','j.geul@haphana.org','Jacco Geul','Strevelsweg 966','Rotterdam','','NETHERLANDS','3083LW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:40:28',0,NULL,3,0,2,1,NULL,'jaccogeul  再发一个44pin的\rOTCN002\\'),(619,0,320674541191,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','djohnsencep','djohnsen@chicagoequity.com','David Johnsen','180 N La Salle St<br>Suite 3800','Chicago','IL','UNITED STATES','60601','(312) 629-5771','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 14:29:02',0,NULL,3,0,1,1,NULL,'djohnsencep\\'),(620,0,220758135568,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','ag14141414','ag1414@hotmail.com','Angela Gaffke','606 165th St S','Spanaway','WA','UNITED STATES','98387','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 14:29:33',0,NULL,3,0,1,1,NULL,'ag14141414\r\\'),(621,760486972012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','macei1','macei1@hotmail.com','luis gustavo macei','rua piratininga 805','ribeirao preto','sao paulo','BRAZIL','14050150','+55 16 3019-2690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 14:44:29',0,NULL,3,0,2,1,NULL,'macei1\\'),(622,760203909012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','sillyppl','sillyppl76@hotmail.com','Austin Sharp','PO Box 502<br>103 West South St.','Anna','OH','UNITED STATES','45302-0502','(937) 394-8217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 21:46:23',0,NULL,3,0,1,1,NULL,'sillyppl'),(623,563972810013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','webwebes','alejandro_spa@hotmail.com','Alberto Albear','Alfabeguer, 2, pta 8','Manises','Comunidad Valenciana','SPAIN','46940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:05:48',0,NULL,3,0,3,1,NULL,'webwebes\rOTRA002\rRA022494594CN\r'),(624,563977085013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','natali.gomel','natali_gomel@yahoo.com','Aliaksandr Hvozdz','MZK \'Solnechnyi\', korpus 5, kv. 71<br>мжк\"Солнечный\" корп.5 кв71','Gomel','','BELARUS','246012','353867711758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:25:15',0,NULL,3,0,2,1,NULL,'natali.gomel\\'),(625,563981519013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','strikerspb','kirill@striker.ru','Kirill Blaushild','Ordjonikidze str., d.43, kv.85','Saint-Petersburg','','RUSSIAN FEDERATION','196158','(911)215-8793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:48:47',0,NULL,3,0,3,1,NULL,'strikerspb\rRA022494603CN\r'),(626,760516900012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','clive486','clive.laycock@ntlworld.com','Clive Laycock','195 Harrowby Lane','Grantham','Lincolnshire','UNITED KINGDOM','NG31 9HQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 16:08:10',0,NULL,3,0,3,1,NULL,'clive486\r英标\rRA022494775CN\r'),(627,0,230597696391,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'',12.99,'eastar4','vealbird','jrob2524@yahoo.com','James Robinson','2526 Meredith St','Philadelphia','PA','UNITED STATES','19130-2422','(215) 765-1840','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 16:15:14',0,NULL,3,0,1,1,NULL,'vealbird\rSCLO001\\'),(628,518814817004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','kristenwin','kwinter22@gmail.com','Kristen Winter','3522 Summit Pointe Ct','Forest Grove','OR','UNITED STATES','97116-2958','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 16:27:31',0,NULL,3,0,1,1,NULL,'kristenwin\\'),(629,684375070011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','siminfo','sim.sales@skynet.be','M. Abou','boulevard du jubilé 40','bruxelles','','BELGIUM','1080','024201765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 16:34:49',0,NULL,3,0,2,1,NULL,'siminfo\\'),(630,760553174012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','teddy9497-2008','terjuan535@clear.net','TERJUAN ROGERS','535 N Luzerne Ave','BALTIMORE','MD','UNITED STATES','21205','(443) 758-2080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:32:34',0,NULL,3,0,1,1,NULL,'teddy9497-2008\\'),(631,564015455013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vpal8821','vpaluri@yahoo.com','Vasantha Paluri','16, St James Street','Monroe','NJ','UNITED STATES','08831','(732) 656-1913','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:39:04',0,NULL,3,0,1,1,NULL,'vpal8821\\'),(632,0,230599766158,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:39:31',0,NULL,3,0,1,1,NULL,'michael2289xd\\'),(633,760561309012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','frankster1962','fdfrankster8@gmail.com','frank depaz','2841 s marigold ave','ontario','CA','UNITED STATES','91761','(909) 815-5894','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:48:59',0,NULL,3,0,1,1,NULL,'frankster1962\\'),(634,564019596013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','abdulrahim79','lucky_3abdu@hotmail.com','Abdulrahim alharthi','oman<br>P.O BOX NO:74 , P.CODE:122  MABELLAH,SEEB','seeb','MUSCAT','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 17:53:49',0,NULL,3,0,2,1,NULL,'abdulrahim79\\'),(635,518841464004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',2,'HSPL010',49.98,'cnfaner','dam005','derekm@southslope.net','Derek Miller','1875 State St','Ely','IA','UNITED STATES','52227','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:05:26',0,NULL,3,0,1,1,NULL,'dam005\\'),(636,760615560012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','w11337','houbeau_christophe@hotmail.com','Christophe Houbeau','Langesthal, 163','Eupen','','BELGIUM','4700','0476936458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:28:25',0,NULL,3,0,2,1,NULL,'w11337\\'),(637,684037937011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','rostien0','dpav28@msn.com','dave','1130 37A AVE NW','edmonton','AB','CANADA','T6T0E7','(780) 756-3192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:30:50',0,NULL,3,0,2,1,NULL,'rostien0'),(638,564071082013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','epvenom13','epvenom13@hotmail.com','Edgar Nava','12528 Crystal Ridge St','El Paso','TX','UNITED STATES','79938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:07:11',0,NULL,3,0,1,1,NULL,'epvenom13\r\\'),(639,760631191012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jimry','jimry@ccaonline.com','Jim R. Youngquist','601 Keokuk St','Lincoln','IL','UNITED STATES','62656-1730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:28:59',0,NULL,3,0,1,1,NULL,'jimry\\'),(640,0,320674545985,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.49,'eastar4','edznewone','edznew1@gmail.com','John Wright','720 Newport Dr','Villa Rica','GA','UNITED STATES','30180-7456','(678) 427-2266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 20:45:13',0,NULL,3,0,1,1,NULL,'edznewone\\'),(641,564086810013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','javi_cordoba','haynsur@hotmail.com','Javier Gutierrez','cazkuene 35, 7ºC','San Sebastian','País Vasco','SPAIN','20017','665286795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:47:19',0,NULL,3,0,3,1,NULL,'javi_cordoba\rRA022494838CN\r'),(642,564099490013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','bootybates','denariusbates@yahoo.com','Denarius Bates','4488 Spears Rd','Liberty','MS','UNITED STATES','39645-6107','(601) 657-8559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 21:18:20',0,NULL,3,0,1,1,NULL,'bootybates\\'),(643,684174796011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','triplethinker','evelyn_design@hotmail.com','Yi Xiao','523 W 112th St<br>Apt 44B','New York','NY','UNITED STATES','10025-1619','(347) 429-3887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 02:43:45',0,NULL,3,0,1,1,NULL,'triplethinker'),(644,518919585004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','barsaxd','s.bertas@gmail.com','Robertas Sabunas','Respublikos 10-14','Kedainiai','','LITHUANIA','57399','0037061697232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:41:48',0,NULL,3,0,3,1,NULL,'barsaxd\rRA022494577CN\r'),(645,564098353013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','pdfuzzbug','jesseboulard@gmail.com','Jesse Boulard','7416 Apple Mill Dr','Louisville','KY','UNITED STATES','40228','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-22 21:42:41',0,NULL,3,0,1,1,NULL,'pdfuzzbug\\'),(646,513085357003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','alkagirish','alka_talati@hotmail.com','Alka Talati','1811 Nours Landing Way','Duluth','GA','UNITED STATES','30097-3420','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:51:20',0,NULL,3,0,1,1,NULL,'alkagirish\\'),(647,563706661013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','natasha1808','natasa.marcinkovic@gmail.com','NATAŠA MARČINKOVIĆ','BANA JOSIPA JELAČIĆA 48<br>EMINOVCI','JAKŠIĆ','POŽEGA','CROATIA','34308','0038534247041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 22:06:21',0,NULL,3,0,3,1,NULL,'natasha1808\rRA022494585CN\r'),(648,513091140003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','krissylynnw','krissylynng@yahoo.com','Peggy Key','1000 SE Prairie Ln<br>Apt 22','Oak Grove','MO','UNITED STATES','64075-9393','(816) 778-4382','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 22:07:08',0,NULL,3,0,1,1,NULL,'krissylynnw\\'),(649,0,320674541016,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',12.99,'eastar4','imamacuserartist','tadlakelady@gmail.com','Dianne Clowes','5391 Helena Lake Road','One Hundred Mile House','BC','CANADA','V0K 2E1','(250) 791-7222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 22:18:36',0,NULL,3,0,2,1,NULL,'imamacuserartist\\'),(650,684553228011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','jasonmiles','miles267@gmail.com','Jason Miles','6511 Hearth Falls Dr','Rogers','AR','UNITED STATES','72758-4182','(904) 610-8795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 22:42:05',0,NULL,3,0,1,1,NULL,'jasonmiles\r\\'),(651,760332130012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','shirishagra','shirishsinha@sancharnet.in','Shirish Sinha','C 3 third floor<br>Surajdham Apartment Shamshabad Road','Agra','UP','INDIA','282001','9897048405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 04:17:55',0,NULL,3,0,2,1,NULL,'shirishagra'),(652,684200075011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','winnie_yang21','yangmei711@hotmail.com','Hsiao-Yu Yang','645 Chestnut Ave<br>Apt 303','Long Beach','CA','UNITED STATES','90802-1275','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 04:45:13',0,NULL,3,0,1,1,NULL,'winnie_yang21\rLK032927017CN'),(653,0,320674546151,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','bright_spark_it','tskinner82@hotmail.com','Timothy Skinner','75A Pearce Dr','Coffs Harbour','New South Wales','AUSTRALIA','2450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:29:50',0,NULL,3,0,3,1,NULL,'bright_spark_it\rRA022494798CN\r\r'),(654,0,320671983892,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12,'eastar4','shenshaw1976','henshaw76@hotmail.com','stuart henshaw','27 pacific way<br>beldon','perth','Western Australia','AUSTRALIA','6027','0422927547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:41:51',0,NULL,3,0,2,1,NULL,'shenshaw1976\\'),(655,684149503011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ncdebpas','ncdebpas@hotmail.com','Deborah Pasquantonio','3512 Edsel Pl','Charlotte','NC','UNITED STATES','28205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 01:13:55',0,NULL,3,0,1,1,NULL,'ncdebpas'),(656,760758666012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','raytatover','jason.oatway@gmail.com','Jason Oatway','22A Locks Rd','Dartmouth','NS','CANADA','b2x2j5','(902) 405-2395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:32:26',0,NULL,3,0,2,1,NULL,'raytatover\\'),(657,684599630011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','tongael14','fedeel14@gmail.com','Gaston Lopez Duarte','Lima 1445 11b','Capital Federal','Capital Federal','ARGENTINA','1138','43053745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 01:15:53',0,NULL,3,0,2,1,NULL,'tongael14\\'),(658,513138125003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',2,'BAZA001',151.2,'cnfaner','will_andrew','sublimeatucf@gmail.com','William Campbell','PO Box 8079','Coral Springs','FL','UNITED STATES','33075','(407) 625-4590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 01:36:33',0,NULL,3,0,1,1,NULL,'will_andrew\\'),(659,564168295013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bdgold','asubhan175@yahoo.com','Abdus Subhan','C/ Carretes 34, 01º 01ª','Barcelona','Cataluña','SPAIN','08001','634273405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 01:47:18',0,NULL,3,0,2,1,NULL,'bdgold\\'),(660,518976101004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','rugrats_10','car105_ac@hotmail.com','jorge  marquez','4402 little moser ln','charlotte','NC','UNITED STATES','28227-8673','(704) 545-8838','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 02:02:23',0,NULL,3,0,1,1,NULL,'rugrats_10\r\\'),(661,0,320674798915,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',8.99,'eastar4','rook1961','lunnakitty3@aol.com','Tori Johnson','2008 Dement Hollow Rd','Readyville','TN','UNITED STATES','37149-5176','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 02:02:25',0,NULL,3,0,1,1,NULL,'rook1961\\'),(662,518977313004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','vinnyozzy','viniscsp@gmail.com','Vinícius da Silva Costa','Rua Inacio Manuel alvares, #95','São Paulo','São Paulo','BRAZIL','05372-110','55 11 94996391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 02:03:02',0,NULL,3,0,3,1,NULL,'vinnyozzy\rRA022494855CN\r'),(663,518971071004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','babimisti1','babimisti1@aol.com','AMBER MARES','1803 Childers Dr NE','albuquerque','NM','UNITED STATES','87112','(505) 362-3329','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 02:12:04',0,NULL,3,0,1,1,NULL,'babimisti1\r\\'),(664,684616877011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',16.59,'eastar4','t40puter','t40cal@comcast.net','Timothy  Overton','630 Lolita Dr','Murfreesboro','TN','UNITED STATES','37130-3217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 02:12:35',0,NULL,3,0,1,1,NULL,'t40puter\rHP 8pin 1.25 25cm \r\\'),(665,0,220758409604,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',11.98,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 03:50:43',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共买了两个\\'),(666,684640764011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','fcollingwood','frank@collingwood.me.uk','Frank Collingwood','125 Hanham Road<br>RD1','Kumeu','Rodney','NEW ZEALAND','0891','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 03:52:32',0,NULL,3,0,2,1,NULL,'fcollingwood\\'),(667,0,230600020579,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','solidgolds','nitnem@hotmail.com','Jaswinder Singh','159 wexford road','Brampton','ON','CANADA','L6Z 2P8','(647) 449-4744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 04:09:09',0,NULL,3,0,2,1,NULL,'solidgolds\\'),(668,564198318013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','rpas9523','fhptrooper1@bellsouth.net','RAYMOND PASTRANA','4081 Heirloom Rose Pl','OVIEDO','FL','UNITED STATES','32766-6681','(407) 256-6132','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 04:35:48',0,NULL,3,0,1,1,NULL,'rpas9523\\'),(669,513168045003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',58.74,'cnfaner','nevelin78','nino2003ca@yahoo.ca','Nevelin Nonchev','1818-55 wynford heights cres','Toronto','ON','CANADA','m3c1l4','(647) 885-0909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 04:40:57',0,NULL,3,0,3,1,NULL,'nevelin78\r再发一个 NOKIA  BH 900\rRA022494648CN\r'),(670,519006126004,140481827765,'NIB Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL003',17.5,'cnfaner','*jaby*','taurus39208@yahoo.com','erika bowden','105 cedar ridge blvd','pearl','MS','UNITED STATES','39208-8088','(601) 209-1342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 05:08:33',0,NULL,3,0,1,1,NULL,'*jaby*\\'),(671,519010335004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','majidafzal404mario','majidafzal404@yahoo.com','mario afzal','10431 Pilot Rock Rd','collierville','TN','UNITED STATES','38017-1962','(901) 463-8223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 05:50:07',0,NULL,3,0,1,1,NULL,'majidafzal404mario\\'),(672,513176266003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','kavinduinfo','kavindu@live.com','Kavindu Kanishka','No 226,<br>Kandawatta, Dediyawala,','Waskaduwa','Western','SRI LANKA','12580','94342238006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:02:23',0,NULL,3,0,3,1,NULL,'kavinduinfo\rRA022494665CN\r\r\r'),(673,684289771011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hyunkel8424','hyunkellll@hotmail.com','maxime roy','10300 gouin st','montreal','QC','CANADA','h1c1b1','(514) 881-2671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:05:37',0,NULL,3,0,2,1,NULL,'hyunkel8424\\'),(674,0,320674798930,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','purchase4u','tjmbartlett@gmail.com','Timothy Bartlett','Kappinghat 289 Property<br>198-204 Wandobah Rd.','Gunnedah','New South Wales','AUSTRALIA','2380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:52:57',0,NULL,3,0,3,1,NULL,'purchase4u\rRA022494149CN\r\\'),(675,519020449004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','ahhuss','m.annab@yahoo.com','Annabella Markus','Toldi Miklós u. 28/A','Gyal','Pest','HUNGARY','2360','+36 30 257 67 25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 07:29:50',0,NULL,3,0,3,1,NULL,'ahhuss\r欧标\rRA022494152CN\r\\'),(676,564221549013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','botaksetan','support.ibu4aceh@gmail.com','Adi Sunardy','Gedung Danamon Lantai 8<br>Jl. Diponegoro No. 35','Medan','Sumatera Utara','INDONESIA','20152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 07:51:17',0,NULL,3,0,3,1,NULL,'botaksetan\rRA022494740CN\r\\'),(677,760734111012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','kontesa7','zrinac@gmail.com','Zrinka Nazor','Dobroniceva 15','Zagreb','Croatia','CROATIA','10110','+385958589520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 08:23:50',0,NULL,3,0,2,1,NULL,'kontesa7   欧标\r\\'),(678,760876977012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','driven888','dchiu@telus.net','Daniel Chiu','46 West 22nd Avenue','Vancouver','BC','CANADA','V5Y 2E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 09:10:22',0,NULL,3,0,2,1,NULL,'driven888\r\\'),(679,519038556004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','chanuka11','chanuka1992@gmail.com','chanuka','195/5,rajaphilla mw ,kandy','kandy','','SRI LANKA','20000','+940777227728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 09:41:19',0,NULL,3,0,3,1,NULL,'chanuka11\rRA022494104CN\r\\'),(680,0,220758409526,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.99,'eastar4','stuff_e_nuff','stef@statice.eu','Stef den Mulder','De Oude Kooien 15','Beringe','Limburg','NETHERLANDS','5986 PJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:29:59',0,NULL,3,0,2,1,NULL,'stuff_e_nuff\r\\'),(681,684717648011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','shantavatapipi','shantava1@abv.bg','Vasil Lefterov','GETECH Kitson House<br>Elmete lane','Leeds','West Yorkshire','UNITED KINGDOM','LS8 2LJ','07807753598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:40:51',0,NULL,3,0,2,1,NULL,'shantavatapipi\r\\'),(682,684398455011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mahmoud_yassine','mahmoudyassine@gmail.com','Ehab Neama Wahba','147-29 182nd Street, KWI 15536<br>KWI 15536','Springfield Gardens','NY','UNITED STATES','11413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 17:35:56',0,NULL,3,0,1,1,NULL,'mahmoud_yassine'),(683,564251699013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','s.kamenskih','skamenskih@gmail.com','Sergey Kamenskikh','Leninskij pr., d. 79, k.2, kv. 318','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','(921) 9464710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:08:09',0,NULL,3,0,3,1,NULL,'s.kamenskih\rRA022494753CN\r\\'),(684,564255897013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','arnoldso','arnoldso@yahoo.com','Arnoldo Suarez Ortega','Maria Uribe #449','Guadalajara','Jalisco','MEXICO','44820','+523336052763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:24:37',0,NULL,3,0,2,1,NULL,'arnoldso\r\\'),(685,564256752013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','tomykas0','tomykui@gmail.com','Tomas Kuciukas','Baltu pr. 25 - 3','Kaunas','LT','LITHUANIA','48237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 11:28:45',0,NULL,3,0,2,1,NULL,'tomykas0\r\\'),(686,563840460013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','china73','ciuped@yahoo.com','Ioan Ciupe','4825 W Warner Ave','Chicago','IL','UNITED STATES','60641-1815','(773) 297-0399','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 11:41:14',0,NULL,3,0,1,1,NULL,'china73'),(687,519065509004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','nuriel79','nuriel1985@walla.com','nuriel maynayev','tzahal 2','Petah Tiqva','ramat verber','ISRAEL','49521','039234632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:18:34',0,NULL,3,0,3,1,NULL,'nuriel79\rRA022494679CN\r\\'),(688,518920020004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','marazza_58','marazza_58@yahoo.it','Siegfried MUELLER','Strada da l\'ort 8','Lugano','','SWITZERLAND','6915','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:44:55',0,NULL,3,0,3,1,NULL,'marazza_58\rRA022494081CN\r\\\r'),(689,760936045012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','nibelungen-kiez','w.ahlgrimm@gmx.de','Ahlgrimm Werner','Guntherstr. 37A','Berlin','','GERMANY','10365','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 12:51:37',0,NULL,3,0,2,1,NULL,'nibelungen-kiez\r欧标\r\\'),(690,760945469012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','gvpieper','gary.piper@snet.net','Gary V. Pieper','47 Bayberry Dr','Wallingford','CT','UNITED STATES','06492-4713','(203) 265-6105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 13:14:31',0,NULL,3,0,1,1,NULL,'gvpieper\r、'),(691,760953788012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','rob00120','rob0013@blueyonder.co.uk','robert pearson','50 whitbeck court<br>slatyford','newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','NE52XF','07769717000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 13:43:35',0,NULL,3,0,3,1,NULL,'rob00120\rRA022494078CN\r\\'),(692,519085817004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','hitmanoh','tom.mason@promevo.com','Tom Mason c/o Promevo','808 Lyndon Ln<br>Suite 205','Louisville','KY','UNITED STATES','40222-7899','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:01:48',0,NULL,3,0,1,1,NULL,'hitmanoh\r、'),(693,0,320674976735,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','williamshernandez','willyraque@hotmail.com','William Hernández','Calle Nicaragua, Número 7, 3 Izquierda.','Telde, Gran Canarias.','Canarias','SPAIN','35210','675942125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:13:26',0,NULL,3,0,3,1,NULL,'williamshernandez\rRA022494682CN\r\\'),(694,513256612003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','muskie99d','derek.longman@bell.net','Derek Longman','33387 Coursey Line<br>RR 1','Lucan','ON','CANADA','N0M 2J0','(519) 227-1732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:28:33',0,NULL,3,0,3,1,NULL,'muskie99d\rRA022494118CN\r\\'),(695,760973102012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korobkinoleg','korobkin.o@gmail.com','Oleg Korobkin','Goloseevskaya 16. App. 137','Kiev','UA','UKRAINE','03039','380636180149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:35:26',0,NULL,3,0,2,1,NULL,'korobkinoleg\r\\'),(696,760971949012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','korobkinoleg','korobkin.o@gmail.com','Azarov Anton','Lesya Kurbasa 4 st. app. 67','Kiev','','UKRAINE','03148','+380936844412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 14:38:39',0,NULL,3,0,2,1,NULL,'korobkinoleg\r\\'),(697,564315599013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','warhol1959','nc-meumerju@netcologne.de','Juergen Meumerzheim','Pützfelder weg 15','Bonn','','GERMANY','53177','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:52:19',0,NULL,3,0,3,1,NULL,'warhol1959\rRA022494135CN\r\\'),(698,513275143003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','jlofish','jlpuente@telefonica.net','JOSE LUIS LOPEZ PUENTE','Cl. Canalillo, 8 - 6º A','Madrid','Madrid','SPAIN','28028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:53:35',0,NULL,3,0,3,1,NULL,'jlofish\rRA022494064CN\r\\'),(699,684631075011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',118.99,'eastar4','mkpwl3','mickpwl@yahoo.com','Michael Powell','592 N 100 E','Springville','UT','UNITED STATES','84663-1179','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 16:14:33',0,NULL,3,0,1,1,NULL,'mkpwl3\r、'),(700,519118204004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'cnfaner','christopher.714','thichdathe@yahoo.com','christopher hoang','8162 Lambert Dr','huntington beach','CA','UNITED STATES','92647-4816','(714) 596-6194','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:24:11',0,NULL,3,0,1,1,NULL,'christopher.714\r再发一个水管'),(701,518898499004,140429833142,'2.1 Acer Aspire One 751 AO751h bluetooth module track#',1,'BTAC2115',16.59,'cnfaner','p13w13','maartenklein@home.nl','Maarten Klein','Lambertinck 31','Den Ham','','NETHERLANDS','7683WR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:40:44',0,NULL,3,0,3,1,NULL,'p13w13\racer 5pin1.25 20cm\rRA022494532CN\r\\'),(702,761034759012,220723618818,'Nokia HF-31W Bluetooth Plug-in Car Kit Speakphone',1,'HSNO027',15.5,'eastar4','dimasas','pankdima@takas.lt','Dmitrij Pankejev','Mickeviciaus 19-89','Siauliai','','LITHUANIA','LT-77165','+37060475330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:12:49',0,NULL,3,0,2,1,NULL,'dimasas\r\\'),(703,0,230597705940,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',30.5,'eastar4','quegc22','gastonchaine@sympatico.ca','Gaston Chaine','7750 Ch. Sainte-Marguerite','Trois-Rivieres Secteur Ouest','QC','CANADA','G9A 5C9','(819) 377-5403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:15:38',0,NULL,3,0,3,1,NULL,'quegc22\rRA022494095CN\r\\'),(704,519133984004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','christopher.714','thichdathe@yahoo.com','christopher hoang','8162 Lambert Dr','huntington beach','CA','UNITED STATES','92647-4816','(714) 596-6194','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:23:22',0,NULL,8,0,17,0,NULL,'christopher.714'),(705,761043733012,220752720350,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','amlbr','amlbrfr@gmail.com','Marcelo ARAUJO DE ALMEIDA','76, rue des fleurs','carrières sous poissy','Île-de-France','FRANCE','78955','0130743767','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 17:36:47',0,NULL,3,0,2,1,NULL,'amlbr\r\\'),(706,564344512013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ninie5781','vin.vir@orange.fr','Virginie KREMER','26, route d\'Elzange','INGLANGE','Lorraine','FRANCE','57970','03.82.56.06.29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 17:39:59',0,NULL,3,0,3,1,NULL,'ninie5781\rRA022494546CN\r\\'),(707,684863687011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','dracosilv','dracosilver@wi.rr.com','Jonathan Herr','3505 69th St','Kenosha','WI','UNITED STATES','53142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 18:06:15',0,NULL,3,0,1,1,NULL,'dracosilv\r、'),(708,564357748013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','pushap905','paulsidhu28@rogers.com','Gurpaul Sidhu','1328 Godwick drive','Mississauga','ON','CANADA','l5n7x3','(416) 828-2985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 18:17:17',0,NULL,3,0,2,1,NULL,'pushap905\r\r新地址\rGurpaul Sidhu\r3350 Thomas Street Unit 14 Mississauga Ontario L5M0R2\rCanada\r\\'),(709,684470851011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maros730522','maros73@gmail.com','Maros Urminsky','77 Verdemont<br>Snugborough road','Blanchardstown','Dublin','IRELAND','D15','0833341699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:53:32',0,NULL,3,0,2,1,NULL,'maros730522\r\\'),(710,564369080013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','therealtomahawk','felipe@gaete.cl','Felipe Gaete','Bergen 211, dept 1004<br>Las Condes','Santiago','Region Metropolitana','CHILE','7560786','562-7161351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 18:47:07',0,NULL,3,0,3,1,NULL,'therealtomahawk\rRA022494705CN\r\\'),(711,761111738012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','gd_n','gd_n2@yahoo.com','Georgi Nalbantov','Slavianska 85','Plovdiv','Plovdiv','BULGARIA','4000','+359878440198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:36:02',0,NULL,3,0,2,1,NULL,'gd_n\r欧标\r\\'),(712,564395180013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','woofer2010','alexraik@mail.ru','Raikov Alexey','110-2-141, Leninskiy pr.','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198303','+7-921-322-4045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:50:22',0,NULL,3,0,3,1,NULL,'woofer2010\rRA022494696CN\r\\'),(713,0,230600160103,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:11:28',0,NULL,3,0,1,1,NULL,'michael2289xd'),(714,513366184003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','tgri5349','taryn_griffin@comcast.net','Taryn Griffin','556 Tudor Rd','San Leandro','CA','UNITED STATES','94577','(510) 499-9221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 20:36:29',0,NULL,3,0,1,1,NULL,'tgri5349\r、'),(715,761152683012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','puddingkappes','kettner@gmx.net','Viktor Makelki','Frischmuthstrasse 5','Grevenbroich','','GERMANY','41515','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:40:57',0,NULL,3,0,2,1,NULL,'puddingkappes\r\\'),(716,761109985012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','jnsamuelson91','jnsamuelson@gmail.com','Jared Samuelson','24 Mattison way','Salem','NY','UNITED STATES','12865','(518) 728-5449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:45:28',0,NULL,3,0,1,1,NULL,'jnsamuelson91\r、'),(717,564417765013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','serandinas','sdaoviedo@hotmail.com','SERGIO DAVILA ANDRES','C/. CARDENAL ALVAREZ MARTINEZ 8 4ºA','OVIEDO','Asturias','SPAIN','33011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:47:15',0,NULL,3,0,3,1,NULL,'serandinas\rRA022494736CN\r\\'),(718,564418264013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',9.99,'eastar4','moldovan.vyacheslav','moldovan.v@hotmail.com','Moldovan Vyacheslav','Profsojuznaia str, 98, 1, 299','Moscow','','RUSSIAN FEDERATION','117485','(917) 5790360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:49:23',0,NULL,3,0,2,1,NULL,'moldovan.vyacheslav\r\\'),(719,761158350012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',81.95,'eastar4','oswellh','cliffordh@mac.com','Darold Howard','PO Box 1256<br>1840 Hwy 87','Crystal Beach','TX','UNITED STATES','77650','(409) 256-4123','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 20:52:18',0,NULL,3,0,1,1,NULL,'oswellh'),(720,513378463003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','har84man','har8man@gmail.com','Harutyun Manukyan','Vrt.Papazyan st #61','Yerevan','Kanaker Zeytoun','ARMENIA','0037','37499250929','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 21:12:38',0,NULL,3,0,3,1,NULL,'har84man\rRA022494529CN\r\\'),(721,564435190013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','cfanjul','info@cyberdyne.com.ar','JORGELINA GARABAN','5101 NW 105th Ct','Doral','FL','UNITED STATES','33178-3216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:39:40',0,NULL,3,0,1,1,NULL,'cfanjul'),(722,761188424012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',14.99,'eastar4','lotusmach10','paulandkay1993@sbcglobal.net','Paul Pakizer','3747 Deer Springs Dr','Rochester Hills','MI','UNITED STATES','48306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:47:23',0,NULL,3,0,1,1,NULL,'lotusmach10'),(723,519233885004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','aliexas','aliexas@yahoo.co.uk','Aleksandr Ostanin','LA Drape.Internet House<br>Aston Lane North.Preston Brook','Runcorn','Cheshire','UNITED KINGDOM','WA7 3PE','07913573945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:16:36',0,NULL,3,0,3,1,NULL,'aliexas\rRA022494121CN\r\\\r\r'),(724,761222438012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',27.98,'eastar4','cmangeri','mangericrafters@comcast.net','Christopher Mangeri','1607 Heather Dr','Downingtown','PA','UNITED STATES','19335-3577','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:08:34',0,NULL,3,0,1,1,NULL,'cmangeri\r再发一个保护屏\r、'),(725,684913090011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mikroft','acwleung@shaw.ca','Andrew Leung','2482 Triumph St.','Vancouver','BC','CANADA','V5K 1S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 19:39:28',0,NULL,3,0,2,1,NULL,'mikroft\r\\'),(726,761225388012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','087lagunaman2','johnjamesgalligan@o2.ie','james galligan','ballinaloe','coole','Westmeath','IRELAND','wh','0872232287','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 23:22:41',0,NULL,3,0,3,1,NULL,'087lagunaman2\r英标\rRA022494206CN\r\\  '),(727,0,220758608676,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','williaal80','williaal80@yahoo.com','Audrey Williams','787 Old Brook Rd','Charlottesville','VA','UNITED STATES','22901','(434) 202-1590','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:46:11',0,NULL,3,0,1,1,NULL,'williaal80\r、'),(728,685029175011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 23:58:35',0,NULL,3,0,11,1,NULL,'dorit710'),(729,564475769013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','ultek02','jangstadt@gmail.com','Jeffery Angstadt','19935 Paso Robles Ave','Redding','CA','UNITED STATES','96003-7835','(530) 227-8154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 00:03:20',0,NULL,3,0,1,1,NULL,'ultek02\r、'),(730,564480527013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','requin03','yanquenneville@videotron.ca','Yan Quenneville','1595 boul. du  souvenir #902','laval','QC','CANADA','H7N 4Z7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 00:35:33',0,NULL,3,0,3,1,NULL,'requin03\rRA022494550CN   '),(731,685052975011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','phil31589','plynch@dsisd.k12.mi.us','Phil Lynch','322 S 16th St','Escanaba','MI','UNITED STATES','49829-2630','(906) 786-2396','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 01:21:36',0,NULL,3,0,1,1,NULL,'phil31589'),(732,564498225013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','palacesong','korosh@gmail.com','Alexander Afshar','90 William St<br>Apt 15E','New York','NY','UNITED STATES','10038-0106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 01:46:42',0,NULL,3,0,1,1,NULL,'palacesong'),(733,0,220758608683,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',9.99,'eastar4','nate64516tc','nate645@hotmail.com','Nathan Giles','430 Charter Ct','Lawrenceville','GA','UNITED STATES','30046-8308','(678) 886-5421','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 02:04:09',0,NULL,3,0,1,1,NULL,'nate64516tc\r、'),(734,564504347013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','xetsus09','xetsus@gmail.com','Jorge Alberto Sanchez Diaz','Fernando Castillo # 7','Texcoco','Mexico/Texcoco/Unidad ISSSTE','MEXICO','56230','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,2,1,NULL,'xetsus09\r\\'),(735,761319620012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.99,'eastar4','llaval22','llaval22@yahoo.com','Kelly Taylor','754 W Pinkley Ave','Coolidge','AZ','UNITED STATES','85128-4218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 04:59:05',0,NULL,3,0,1,1,NULL,'llaval22\\'),(736,519308937004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','garfld02','rick@fromorbit.com','Rick Garfield','C/- The PA People<br>9 - 11 LEEDS STREET','RHODES','New South Wales','AUSTRALIA','2138','0287558700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 05:20:05',0,NULL,3,0,3,1,NULL,'garfld02      澳标\rHSPL010\rRA022494400CN\r\\'),(737,684959090011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','kdpaine4a1h','kdpaine@kdpaine.com','KDPaine & Partners, LLC','51 Durham Point Rd','Durham','NH','UNITED STATES','03824-3100','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 21:13:06',0,NULL,5,0,18,1,'/\r','kdpaine4a1h'),(738,513476982003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',2,'HSMO006',23.98,'cnfaner','mejzeej','youahlubmailee@yahoo.com','Youa Thao','1836 W Weiland Ln<br>Apt 3','Appleton','WI','UNITED STATES','54914-2078','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 05:46:41',0,NULL,3,0,1,1,NULL,'mejzeej'),(739,513479779003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','10usmanali','maakabata@gmail.com','muhammed javed','225,oak view dr','regina','SK','CANADA','s4r7e8','(306) 205-3503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 06:11:34',0,NULL,3,0,3,1,NULL,'10usmanali\rHSSE003\rRA022494311CN\r\\'),(740,564540864013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',118.99,'eastar4','cncjunky','cmcjunky@hotmail.com','brian lutzen','N82W22020 Dubnicka Dr','sussex','WI','UNITED STATES','53089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 06:28:34',0,NULL,3,0,1,1,NULL,'cncjunky'),(741,684994394011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',14.98,'eastar4','richardc8113','prnrich@aol.com','Richard Cohen','42  Newton  St','New Bedford','MA','UNITED STATES','02740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 22:17:11',0,NULL,3,0,1,1,NULL,'richardc8113'),(742,564548413013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','jeffreyhill1998','sales@overstockandstuff.net','amanda hill','7741 e vancouver pl','tucson','AZ','UNITED STATES','85730-3421','(520) 940-4669','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 07:31:51',0,NULL,3,0,1,1,NULL,'jeffreyhill1998\r、'),(743,564090637013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',1,'HSMO012',17.9,'eastar4','kariwka2007','inkognito2004@one.lv','Gleb Maslovs','18210 Oxnard St<br>Tarzana Unit 143','Tarzana','CA','UNITED STATES','91356-1720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 07:33:40',0,NULL,3,0,1,1,NULL,'kariwka2007\r'),(744,519323418004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',2,'HSNO022',29.96,'cnfaner','tahantahan','raxpaks@hotmail.com','Ragnar Kivisaar','Janese 26','Tartu','','ESTONIA','51009','372 56931255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 07:42:44',0,NULL,3,0,3,1,NULL,'tahantahan\r欧标\rHSNO022   银色的\rRA022491010CN\r\\'),(745,685053823011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chengyunthirteen','thirteen.li13@gmail.com','Dian(Kimi) Wang','540 Lakeshore Road West','Oakville','ON','CANADA','L6K 3P1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 01:27:29',0,NULL,3,0,2,1,NULL,'chengyunthirteen\r\\'),(746,519334658004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','arn2523','praparlk@yahoo.com','Praparl Kanjanophas','10 Rongmuang2 (Praram6soi3) Rongmuang Patumwan','Bangkok','Bangkok','THAILAND','10330','6626139314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:07:54',0,NULL,3,0,3,1,NULL,'arn2523\rHSPL011\rRA022491054CN\r\\'),(747,564564175013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','sirarchy9977','shatrov@inbox.ru','Arkadiy Shatrov','49, 26/1, Stoykosti str.','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198261','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:20:11',0,NULL,3,0,2,1,NULL,'sirarchy9977\r\\'),(748,685018365011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','dickcu2125','dickcu@comcast.net','Dick Curtis','4490 248th Ln SE','Issaquah','WA','UNITED STATES','98029','(425) 369-9518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-23 23:23:54',0,NULL,3,0,1,1,NULL,'dickcu2125'),(749,685146300011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',138.99,'eastar4','bigmadmex','sifuentj@yahoo.com','joshua sifuentes','136 N Porter St','Waynesburg','PA','UNITED STATES','15370-1430','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 09:21:29',0,NULL,3,0,1,1,NULL,'bigmadmex\r、'),(750,761370003012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','akebono123','i.ivanov@spnet.net','Ivan Ivanov','52 Borisova Str<br>flat 6','Ruse','Ruse','BULGARIA','7012','+359887758006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:24:32',0,NULL,3,0,2,1,NULL,'akebono123\r欧标\r\\'),(751,519338352004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','ilskryabin','lolzeppelin@gmail.com','Илья Плотников','Новосибирская, д.24 к.5','Пермь','Пермский край','RUSSIAN FEDERATION','614033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:34:53',0,NULL,3,0,3,1,NULL,'ilskryabin\rWWSI005\rRA022491947CN\r\\'),(752,684594327011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','yiri_ma','dss@mail.ru','Kirill Vasilyev','Molodezhnaya<br>3/336','Moscow','','RUSSIAN FEDERATION','119226','+79653081275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:40:58',0,NULL,3,0,2,1,NULL,'yiri_ma\r\\'),(753,685156495011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','cmpmal','cmpmal111@yahoo.com.au','Malcolm Pryor','12 Kanooka Ave.,','Ashwood','Victoria','AUSTRALIA','3147','(039) 888-8778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:07:00',0,NULL,3,0,2,1,NULL,'cmpmal\r\\'),(754,564574522013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','charmo-71','canddchalmers@bigpond.com','chris chalmers','23  dalray  crescent','new gisborne','Victoria','AUSTRALIA','3438','0354288571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:19:57',0,NULL,3,0,3,1,NULL,'charmo-71\rMOSA002\rRA022494339CN\r\\'),(755,761386026012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','darrenbeedie1976','darrenbeedie@hotmail.co.uk','Darren Beedie','4 Hillcrest','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9NB','01346510718','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 10:26:00',0,NULL,8,0,17,0,NULL,'darrenbeedie1976'),(756,761390178012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','darrenbeedie1976','darrenbeedie@hotmail.co.uk','Darren Beedie','4 Hillcrest','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9NB','01346510718','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 10:41:48',0,NULL,3,0,3,1,NULL,'darrenbeedie1976\r再发一个40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable\rOTCN001+OTCN002\r\r\\'),(757,564583923013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','dr_ahmad','dr_ahmad_banai@yahoo.com.au','ahmad banai','238 old northern road','castle hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 11:19:12',0,NULL,3,0,3,1,NULL,'dr_ahmad\rMOSA002\rRA022494325CN\r\\'),(758,761400802012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','bestdeal02','hondaguy28@gmail.com','Vinny Huynh','8 Travis Rd','shrewsbury','MA','UNITED STATES','01545-6316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 11:23:50',0,NULL,3,0,1,1,NULL,'bestdeal02'),(759,519356190004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','humanness_restate','raaymann007@yahoo.de','Danilo Raaymann','Bornaische Straße 25','Leipzig','','GERMANY','04277','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-24 11:24:18',0,NULL,3,0,5,1,NULL,'humanness_restate\r\rCP226379453CN\r'),(760,564485248013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mros4881','mariwils@gmail.com','Mari Rosenberger','209 Crescent Lane, Apt A','Cliffside Park','NJ','UNITED STATES','07010','(201) 787-4398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 00:46:07',0,NULL,3,0,1,1,NULL,'mros4881\rLK035155538CN  我又该了一个补发了\re邮宝没有走掉还在上门拦收里'),(761,761411373012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','hifista','info@artdigital.sk','Ivan Filgas','Tomasikova 1','Kosice','','SLOVAK REPUBLIC','040 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:00:55',0,NULL,3,0,2,1,NULL,'hifista\r\\'),(762,519363428004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','krbo2009','0krbo0@gmail.com','Nenad Krbavac','Naselje Lutvinka K','Slavonski Brod','','CROATIA','35000','+385981399349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:08:51',0,NULL,3,0,3,1,NULL,'krbo2009\rOMHJ001\rRA022491023CN\r\\'),(763,761414781012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','ady_dj','amrsic@hotmail.com','Adnan Mrsic','Rolf Hofmos Gate 17','Oslo','Oslo','NORWAY','0655','98853123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 12:12:09',0,NULL,3,0,2,1,NULL,'ady_dj\r\\'),(764,519382477004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','bigbertieman','russell.gillen@ntlworld.com','russell gillen','92 moorfield avenue','port glasgow','Inverclyde','UNITED KINGDOM','PA145XT','01475713909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 13:46:45',0,NULL,3,0,3,1,NULL,'bigbertieman\rOMHJ001\rRA022491955CN\r\\'),(765,685218943011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','smlfinder','mwaschke@gmx.net','Matthias Waschke','Hirtenweg 24','Taufkirchen','','GERMANY','82024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 13:57:54',0,NULL,3,0,2,1,NULL,'smlfinder\r\\'),(766,761446585012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','romus24','mchrzanowiecki@plusnet.pl','Marek Chrzanowiecki','Sikorskiego<br>40/10','Luboń','wielkopolskie','POLAND','62030','61 6499042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:05:32',0,NULL,3,0,2,1,NULL,'romus24\r\\'),(767,685222655011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','crush31','joelwk@hotmail.com','Joel Kepecs','2116 Baldwin Park Dr','Mount Pleasant','SC','UNITED STATES','29466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 14:08:59',0,NULL,3,0,1,1,NULL,'crush31'),(768,685223619011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',5,'CASS002',43.5,'eastar4','has.2009','mete@eosbil.com.tr ','Mete Can GURCAN','Perpa B Blok Kat 6 No 653<br>Sisli','Istanbul','','TURKEY','34384','+90-532-668-1191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:12:39',0,NULL,3,0,3,1,NULL,'has.2009\rCASS002\rRA022492046CN\r\\'),(769,0,230599769177,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.99,'eastar4','coolwinger2','danygagne88@hotmail.com','DANY GAGNE','UdeS (Fac. sciences Local D3-1027-2)<br>2500, boul. de l\'Universite','Sherbrooke','QC','CANADA','J1K 2R1','(819) 437-8888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:34:35',0,NULL,3,0,2,1,NULL,'coolwinger2\r\\'),(770,0,220758137616,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','afrika-bambatafotos','tomas.martoch@email.cz','Tomas Martoch','Y Soft Corporation<br>Podnikatelska 4, Technology Park','Brno','','CZECH REPUBLIC','612 00','+420-608-403 450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 14:40:52',0,NULL,3,0,3,1,NULL,'afrika-bambatafotos\rOTRA002\rRA022491037CN\r\\'),(771,0,320674541405,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tminted','marcus@rectorseal.com','marcus taylor','2601 Spenwick Dr<br>Rectorseal Corp','Houston','TX','UNITED STATES','77055','(281) 658-8770','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-24 15:47:30',0,NULL,3,0,1,1,NULL,'tminted'),(772,761502045012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','rhw61','rward1961@yahoo.com','Roland Ward','700 Castner Rd','Waldoboro','ME','UNITED STATES','04572-5859','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 16:29:27',0,NULL,3,0,1,1,NULL,'rhw61'),(773,513589967003,130490976227,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',15.99,'cnfaner','nightalon','nightalon@gmail.com','Barrett Williams','206 W 106th St<br>Apt 52','New York','NY','UNITED STATES','10025-3673','(917) 846-8761','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:41:52',0,NULL,3,0,1,1,NULL,'nightalon'),(774,685289918011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','risto1966','risto.espo@nesteoil.com','Risto Espo','Kukkumäenkuja 12 as 19','Espoo','ESPOO','FINLAND','02280','+358504584783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 17:37:57',0,NULL,3,0,2,1,NULL,'risto1966\r\\'),(775,0,320674542999,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',11.98,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 17:41:07',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共买了两个'),(776,513610304003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',44.99,'cnfaner','bejzer','alexgrud@hot.ee','aleksei grudin','raadiku 19-56','tallinn','Harjumaa','ESTONIA','13817','+37255591633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 17:55:37',0,NULL,3,0,3,1,NULL,'bejzer\rHSNO019+CCNO001\rRA022492050CN\r\\'),(777,564682466013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','deins321seins','mail@halebi.de','Erol Halebi','Jakob Becker Strasse 31','Landau','','GERMANY','76829','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 18:06:46',0,NULL,3,0,2,1,NULL,'deins321seins\r\\'),(778,761544381012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','ldartoraleandro','ldartora@gmail.com','Leandro Dartora','Manoel da Nobrega, 614','Cascavel','Parana','BRAZIL','85803-640','00554599064139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 18:14:30',0,NULL,3,0,3,1,NULL,'ldartoraleandro\rRELO002\rRA022491045CN\r\\'),(779,519457892004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','kleclerc3','kleclerc3@verizon.net','Kellie Leclerc','22 Adams St','Silver Creek','NY','UNITED STATES','14136','(716) 934-3408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 18:51:22',0,NULL,3,0,1,1,NULL,'kleclerc3'),(780,564689884013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','tonysx-maslist','bpmftom@windstream.net','Michele Rispoli','628 SW Van Buren Rd','Mayo','FL','UNITED STATES','32066-6202','(954) 605-9927','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 19:08:22',0,NULL,3,0,1,1,NULL,'tonysx-maslist'),(781,761580207012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','10cvetan','jaguar_1990@abv.bg','Cvetan Smilenov','27/6<br>Malo Konare','Malo Konare','Pazardjik','BULGARIA','4450','0359883430004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:17:06',0,NULL,3,0,2,1,NULL,'10cvetan\r\\'),(782,564712430013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','parmakit','polo_g40@bluewin.ch','Gerber Stefan','Gnappen 1206b','Grünenmatt','','SWITZERLAND','3452','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:28:04',0,NULL,3,0,3,1,NULL,'parmakit\rMOSA002\rRA022494342CN\r\\'),(783,519474486004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','paulct974','paul.chane-tune@live.fr','Paul CHANE TUNE','9 Impasse des églantines<br>Domaine Indigo','Sainte-Marie','Réunion','REUNION','97438','02.62.53.10.88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:36:52',0,NULL,3,0,3,1,NULL,'paulct974\rHSNO022\rRA022492029CN\r\\'),(784,685310276011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sawa232','rafal1375@yahoo.co.uk','Rafal Wojciech Kowalski','10 Monarch Court<br>Cook Street','Wednesbury','West Midlands','UNITED KINGDOM','WS10 9FD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 18:12:46',0,NULL,3,0,2,1,NULL,'sawa232\r\\'),(785,761614954012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','777energy777','valentina.lizenberg@gmx.de','Valentina Lizenberg','Heinrich-Böllstr.5','Cloppenburg','','GERMANY','49661','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:10:14',0,NULL,3,0,2,1,NULL,'777energy777\r欧标\r\\'),(786,761629187012,220741015891,'New Motorola H350 Bluetooth Wireless Headset H 350',1,'HSMO005',12.99,'eastar4','shaharsoper2011','shaharsoper@hotmail.co.il','shahar eliyau','biyalik 19, apt.13<br>apt.13','holon','israel','ISRAEL','58333','0527457458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:37:54',0,NULL,5,0,18,0,NULL,'shaharsoper2011'),(787,685380455011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','baroper2','baroper@gmail.com','Bill Roper','1441 Highwood Blvd.','Devon','AB','CANADA','T9G2E9','(780) 504-7809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:24:29',0,NULL,3,0,2,1,NULL,'baroper2\r\\'),(788,761634294012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sabrina.alireza','dimartino.sabrina@yahoo.com','Hooman Mokri','Torparegatan 48<br>58332 Linkoping','Linkoping','Linkoping','SWEDEN','58332','46707404037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:45:31',0,NULL,3,0,2,1,NULL,'sabrina.alireza\r欧标\r\\'),(789,761643098012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','femills1','francismills1@aol.com','nigel mills','2a straid road','ballycastle','Antrim','UNITED KINGDOM','bt54 6hq','07775918663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 21:05:34',0,NULL,3,0,3,1,NULL,'femills1\rOTRA002\rRA022491108CN\r\\'),(790,685379600011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','csabah_123hu','csabah@t-online.hu','Csaba Harangozó','Bányász utca 15.','Tapolca','','HUNGARY','8300','+36304064586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 21:16:05',0,NULL,3,0,2,1,NULL,'csabah_123hu\r\\'),(791,0,230600020600,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','webwebes','alejandro_spa@hotmail.com','Claudio Vazquez Gonzalez','C/ Itaca nº 33<br>Mairena del Aljarafe','Sevilla (Andalucia)','Andalucía Ceuta y Melilla','SPAIN','41927','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 22:09:32',0,NULL,3,0,3,1,NULL,'webwebes\rOTRA002\rRA022491978CN\r\\'),(792,761684193012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','vevgeniev','cannibalcho@yahoo.com','Veselin  Evgeniev','4247 Wesley Ter','Schiller Park','IL','UNITED STATES','60176-1925','(773) 807-9941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 22:19:27',0,NULL,3,0,1,1,NULL,'vevgeniev\r、'),(793,761704435012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',33.9,'eastar4uk','stevijospen','shaun.spenner@sky.com','SHAUN SPENNER','321 BILLET ROAD','WALTHAMSTOW','LONDON','UNITED KINGDOM','E17 5PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:11:15',0,NULL,8,0,17,0,NULL,'stevijospen'),(794,761709143012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',13.99,'eastar4uk','stevijospen','shaun.spenner@sky.com','SHAUN SPENNER','321 BILLET ROAD','WALTHAMSTOW','LONDON','UNITED KINGDOM','E17 5PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:20:39',0,NULL,3,0,3,1,NULL,'stevijospen\r再发两个MOTOROLA H710 BLUETOOTH HEADSET  BLACK    英标\rHSMO014*2+HSMO018\rRA022492032CN\r\\\r'),(795,519546174004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','marioe1313','pleonero@yahoo.com','mario Chica','PO Box 531534','Grand prairie','TX','UNITED STATES','75053-1534','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 23:35:18',0,NULL,3,0,1,1,NULL,'marioe1313'),(796,685468676011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','spyro5756','bobliguori5756@aol.com','robert liguori','260 Bel-air Dr','massapequa park','NY','UNITED STATES','11762-3209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-24 23:58:07',0,NULL,3,0,1,1,NULL,'spyro5756'),(797,761762483012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',20.8,'eastar4uk','prockey111','j.e.hamer@web.de','Bettina Kimpfbeck','Westerwaldstr. 19 A','Ehringshausen-Greifenthal','','GERMANY','35630','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 02:11:19',0,NULL,3,0,3,1,NULL,'prockey111\rHSNO022     欧标\rRA022492015CN \r\\'),(798,513755194003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','shopper_ez','hall_erin@hotmail.com','Erin Hall','4 Millson Close','Bundoora','Victoria','AUSTRALIA','3083','0394674835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 02:36:09',0,NULL,3,0,3,1,NULL,'shopper_ez\rBAZA001\r\\\rRA022491995CN\r'),(799,685525521011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','aceswild9','chitty61@hotmail.com','Matthew Chidester C/O 507 Student Center','4201 S Washington St','Marion','IN','UNITED STATES','46953-4974','(740) 262-6593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 03:35:10',0,NULL,3,0,1,1,NULL,'aceswild9'),(800,685533156011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','sli80','stradith@gmail.com','Samson Li','4136 Winnifred Street','Burnaby','BC','CANADA','V5J 2S4','(604) 838-1441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 04:19:37',0,NULL,3,0,2,1,NULL,'sli80\r\\'),(801,519572190004,140428312392,'2.1 Acer Aspire 9300 bluetooth module we offer track#',1,'BTAC2108',16.59,'cnfaner','hfer3733','leonj100k@yahoo.com','Hugo L. Fernandez','5 Madison Ave<br>Apt 2','Plainfield','NJ','UNITED STATES','07060-1162','(908) 754-2542','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:51:33',0,NULL,3,0,1,1,NULL,'hfer3733\racer 4pin1.25 18cm\rLK033726935CN'),(802,761814296012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gigman01','mikethomas1@earthlink.net','Michael D Thomas','618 E Dalton Ave','Glendora','CA','UNITED STATES','91741-2704','(626) 224-6716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 06:30:04',0,NULL,3,0,1,1,NULL,'gigman01'),(803,761765056012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',3,'ANTY001*3',10.74,'eastar4','spagnoli','powerstrokerexhaustbrake@yahoo.com','Jerome Karsonovich','472 Madison Street','Sharon','PA','UNITED STATES','16146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 02:19:30',0,NULL,3,0,1,1,NULL,'spagnoli'),(804,685512413011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',38.97,'eastar4','celerinaman','maritrju@yahoo.com','lucien willocks','po box 85202','lexington','SC','UNITED STATES','29073-0025','(803) 518-8020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 02:42:33',0,NULL,3,0,1,1,NULL,'celerinaman\r一共买了三个\\'),(805,685564406011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','slgeo78','slgeo@mail.ru','Gegiya Vyacheslav','1-i Koroleva Str. , Apt.141<br>+79034000736','Rostov-on-Don','Rostovskaya oblast','RUSSIAN FEDERATION','344092','+79034000736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 07:35:24',0,NULL,3,0,2,1,NULL,'slgeo78\r\\'),(806,564874825013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','paul_in_sweden','paul.seymour@mail.com','Paul Seymour','23 ironside St','Weston','Australian Capital Territory','AUSTRALIA','2611','612 62883276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 07:42:11',0,NULL,3,0,3,1,NULL,'paul_in_sweden\rMOSA002\rRA022491085CN\r\\\r'),(807,685524825011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ggal555','dlaeoqls7771@naver.com','byung sun choi','354 S Normandie Ave','Los Angeles','CA','UNITED STATES','90020-3182','(213) 258-7272','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 03:32:06',0,NULL,3,0,1,1,NULL,'ggal555\rLK033747612CN'),(808,564546756013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','alone_091','trsmarquezroman@telefonica.net','Miguel Angel Román Márquez','C La Viña nº 45 Vivienda A','Velilla de San Antonio','Madrid','SPAIN','28891','679451115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:06:06',0,NULL,3,0,3,1,NULL,'alone_091\rMOSA003   \rRA022491920CN\r\\'),(809,519639330004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'cnfaner','ksy_com','ksycom@gmail.com','KSY.Computer','43 Sangchuto Rd.<br>T.Tamakam','Moung','Kanchanaburi','THAILAND','71000','6634624422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:13:18',0,NULL,3,0,3,1,NULL,'ksy_com\rRA022491068CN\r\\'),(810,685610180011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.75,'eastar4','bromobutane','zhenhao.peh@gmail.com','Peh Zhen Hao','Blk 634 Hougang Ave 8<br>#10-35','Singapore','','SINGAPORE','530634','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:52:21',0,NULL,3,0,2,1,NULL,'bromobutane\r、'),(811,685622883011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20.99,'eastar4','ewgen1982','ewgen116@gmail.com','Ewgenij Tetjuev','Rossijskaja, 218-116','Cheljabinsk','','RUSSIAN FEDERATION','454090','(904) 3063952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 11:42:24',0,NULL,3,0,2,1,NULL,'ewgen1982\r\\'),(812,761895863012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','rjw5000','robjwarrington@hotmail.co.uk','Robert Warrington','NWF Agriculture<br>Wardle','Nantwich','Cheshire','UNITED KINGDOM','cw5 6aq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 12:02:00',0,NULL,3,0,3,1,NULL,'rjw5000\rRELO002\rRA022491350CN\r'),(813,685631004011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','jeeyoung0314','jyoung0314@hotmail.com','Kim, Jeongkyu','#306 Annex Soongsil University,<br>Sangdo1-dong, Dongjak-gu,','Seoul','','KOREA,REPUBLIC OF','156-743','(821) 090-4597 ext.: 87','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:34:10',0,NULL,3,0,2,1,NULL,'jeeyoung0314\r\\'),(814,761906834012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','pat43081','pwarczak@msn.com','Patrick Warczak Jr','415 Valleyview Dr','Kent','OH','UNITED STATES','44240-4523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 12:38:24',0,NULL,3,0,1,1,NULL,'pat43081\r、'),(815,564926431013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','e**ch','simonezracohen@hotmail.com','EZRA CH. COHEN','Rua Sergipe 475 -Sala 204','Sao Paulo','Sao Paulo','BRAZIL','01243001','55+11+36617983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:39:44',0,NULL,3,0,2,1,NULL,'e**ch\r、'),(816,685650038011,320441564467,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',16.59,'eastar4','macsob1981','mark.sobczyk@googlemail.com','Marek Sobczyk','115 Lincoln Way<br>North Wingfield','Chesterfield','Derbyshire','UNITED KINGDOM','s42 5rr','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:16:38',0,NULL,3,0,2,1,NULL,'macsob1981\racer 4pin1.25 4cm\r\\'),(817,685659957011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','danylebon','dlalancette57@hotmail.com','dany lalancette','599<br>rue lavallée','roberval','QC','CANADA','g8h1s4','(418) 275-9040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:48:08',0,NULL,3,0,3,1,NULL,'danylebon\rRCLO006\rRA022491859CN\r'),(818,513855616003,130490602150,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',31.98,'cnfaner','mikhail2507','mikhail.statsenko@gmail.com','Mikhail Statsenko','Kapotnya, 5 Kvartal 8-162','Moscow','','RUSSIAN FEDERATION','109649','(916) 959 - 3346','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 13:50:20',0,NULL,3,0,3,1,NULL,'mikhail2507\rWLIN004\rRA022491451CN\r'),(819,564946400013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',71.98,'eastar4','jdog51','jarodrichardson@gmail.com','Jarod Richardson','604 E 1st St','Hillsboro','KS','UNITED STATES','67063-1624','(620) 532-4543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:06:32',0,NULL,3,0,1,1,NULL,'jdog51\r、'),(820,0,220759571354,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.49,'eastar4','pyth0ss','peterbelanger@videotron.ca','Pierre Belanger','137 Tremblay Street','Sainte-Anne-de-Bellevue','QC','CANADA','H9X3Z7','(514) 783-0666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 14:09:19',0,NULL,3,0,3,1,NULL,'pyth0ss\rOTRA002\rRA022491553CN\r'),(821,685674999011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','axl-rose','cristiann82@hotmail.com','Cristi DeWolf','133 Lou Vicy Ln','Bells','TX','UNITED STATES','75414-3379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:33:52',0,NULL,3,0,1,1,NULL,'axl-rose\rPOLO001\r、'),(822,761948192012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4uk','dnkyshopper','dnky2@hotmail.com','Duncan Griffiths','unit A5, CCTV4u<br>Maritime Park','Pembroke Dock','Pembrokeshire','UNITED KINGDOM','SA72 6UL','08452263191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 14:38:04',0,NULL,3,0,3,1,NULL,'dnkyshopper\rCALO001\rRA022491465CN\r'),(823,519317051004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','francespal','frances_palomata@yahoo.com','Lizabeth Palomata','6451 San Pablo Ave','Oakland','CA','UNITED STATES','94608-1264','(408) 966-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:49:30',0,NULL,3,0,1,1,NULL,'francespal\r、'),(824,564960398013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',3,'WWOT001+ANCN001',143.04,'eastar4','jltibo','jltibo@hotmail.com','Jean-Luc Thibault','1661 de l\'industrie','Beloeil','QC','CANADA','J3G 4S5','(450) 536-1692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 15:00:47',0,NULL,3,0,3,1,NULL,'jltibo\rWWOT001+ANCN001\rRA022491479CN\r'),(825,564925582013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','1492galeon','galeonesperdidos@orange.es','Jose Luis Brea Herrera','C/. Bariloche, 5. 3º C','Madrid','Madrid','SPAIN','28042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 15:58:41',0,NULL,3,0,3,1,NULL,'1492galeon\rMOSA001\rRA022491624CN\r'),(826,685707626011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','delightfuly','dmitrykuz.eb@gmail.com','DMITRY KUZNETSOV','bulvar Dmitriya Donskogo, dom 13, kv. 105','Moscow','','RUSSIAN FEDERATION','117216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 16:07:15',0,NULL,3,0,2,1,NULL,'delightfuly\r\\'),(827,685710738011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gasciut','dfhockeyplaya7@aol.com','Gary Asciutto','113 Pine Lake Dr','central','SC','UNITED STATES','29630-9315','(803) 238-1028','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:17:36',0,NULL,3,0,1,1,NULL,'gasciut\r、'),(828,685714224011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','jhderonck','jderonck@ix.netcom.com','Jay DeRonck','59 Ringgold St','West Hartford','CT','UNITED STATES','06119-2156','(860) 232-5777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:37:48',0,NULL,3,0,1,1,NULL,'jhderonck\r、'),(829,564987236013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','jwcameo','jwerlin1@rochester.rr.com','Jeff Werlin','PO Box 422','Fishers','NY','UNITED STATES','14453-0422','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:38:58',0,NULL,3,0,1,1,NULL,'jwcameo\r、'),(830,564988886013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','buffy2','rajohnson@intergate.com','Robert Johnson','25 Deer Run Rd','Wappingers Falls','NY','UNITED STATES','12590-4501','(845) 298-8438','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:45:10',0,NULL,3,0,1,1,NULL,'buffy2\r、'),(831,761995021012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',4,'HSPL011',88,'eastar4','calebhaus1','caleb.musicface@gmail.com','caleb haus','6179 N Constance Ave','fresno','CA','UNITED STATES','93722-3379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:47:45',0,NULL,3,0,1,1,NULL,'calebhaus1\r、'),(832,762003848012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',14.49,'eastar4','zandieloo','scheree_productions@reallyfast.biz','Charles Sherrard','615 E Wonsley Dr<br>apt 248','Austin','TX','UNITED STATES','78753-6519','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 16:59:07',0,NULL,3,0,1,1,NULL,'zandieloo\racer 5pin1.25 6cm \r、'),(833,685744737011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','ayres_neto_2','ayresneto_2@hotmail.com','Ayres Netto','Av. Itacoatiara, 221<br>Bairro: Cachoeirinha','Manaus','Amazonas','BRAZIL','69065-090','55 92 81273232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 17:40:30',0,NULL,3,0,2,1,NULL,'ayres_neto_2\r\\'),(834,565022065013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','kacem14','bmorsli@hotmail.com','Belkacem Morsli','265 Long Elmes','Harrow','Middlesex','UNITED KINGDOM','HA3 6LE','0204260116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 18:31:33',0,NULL,3,0,2,1,NULL,'kacem14\rCAB-6060\r\\'),(835,762050639012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',2,'HSMO016',45.38,'eastar4','ciftampa','paula@ciflorida.com','George Southworth-Paula','11317 N 52nd St<br>Concrete Impressions Of Florida, Inc.','Tampa','FL','UNITED STATES','33617','(813) 899-4284','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 18:37:16',0,NULL,3,0,1,1,NULL,'ciftampa\r、'),(836,519750563004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','davidd3710','david_a_davis@hotmail.com','David Davis','1056 E Brookview Ln','Peoria','IL','UNITED STATES','61615-9567','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 18:53:07',0,NULL,3,0,1,1,NULL,'davidd3710\r、'),(837,565041616013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','frsm11','franxi_7@hotmail.com','Fco Rafael Sabariego Menjibar','Pasaje Pintor Ramirez n 3','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','605038849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 19:23:09',0,NULL,3,0,2,1,NULL,'frsm11\r欧标\r\\'),(838,565042709013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','ask4dee','ask4d@longandfoster.com','Deeda Carstens','300 Shannon Court','Virginia Beach','VA','UNITED STATES','23452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 19:25:52',0,NULL,3,0,1,1,NULL,'ask4dee\r、'),(839,685818909011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','crubirubi','rubi.cohen@gmail.com','Rubi Cohen','12 Y.L.Gordon St.','Hertzelia','','ISRAEL','46491','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:12:34',0,NULL,3,0,2,1,NULL,'crubirubi\r、'),(840,685827351011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fmelom','f.melo@live.com.pt','Francisco Melo','Rua 10 de Junho, n.º 54 N','Vila do Conde','Aveleda','PORTUGAL','4485-029','(351) 913940155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:28:33',0,NULL,3,0,2,1,NULL,'fmelom\r、'),(841,565072212013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','henk0782','hendrik@buitendemarge.nl','Henk Bergsma','Bernardus Gewinstraat 17c','Rotterdam','','NETHERLANDS','3031SB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:45:26',0,NULL,3,0,2,1,NULL,'henk0782\r\\'),(842,685837357011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','skatesurfsnowclothing','mathewmaloney@gmail.com','Mathew Maloney','60 MacLaren Street<br>Apt 505','Ottawa','ON','CANADA','K2P0K7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:05:43',0,NULL,3,0,2,1,NULL,'skatesurfsnowclothing\r\\'),(843,760934197012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','thierry_1988','thierry1988@gmail.com','Lam Thierry (Boite 41503)','5 rue Henri Barbusse','Aubervilliers','Île-de-France','FRANCE','93300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:44:24',0,NULL,3,0,2,1,NULL,'thierry_1988\r\\'),(844,514002315003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','orthowest','orthowest@ameritech.net','Michael Banks','7255 Old Oak Blvd., Ste C405','Middleburg Heights','OH','UNITED STATES','44130-3331','(440) 816-5380','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 22:17:35',0,NULL,3,0,1,1,NULL,'orthowest\r、'),(845,685888530011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY001*3',22.95,'eastar4','kiattivikrai','uthai.k@gmail.com','Uthai Kiattivikrai','222/17 Mu 2<br>Bangkanun','Bangkruay','Nonthaburi','THAILAND','11130','66818322555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 22:56:08',0,NULL,3,0,2,1,NULL,'kiattivikrai\r\\'),(846,565111624013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','wangholm','frankwang.ca@gmail.com','Yongyi F Wang','10 Holm Cres','Thornhill','ON','CANADA','L3T 5J3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 22:57:05',0,NULL,3,0,2,1,NULL,'wangholm\r\\'),(847,762196127012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','fashionetslondon','info@fashionets.com','Fashionet Saree','15 Gillett Avenue','London ','London','UNITED KINGDOM','e6 3aw','7891810329','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 23:46:58',0,NULL,3,0,3,1,NULL,'fashionetslondon\rRELO002\rRA022491540CN\r'),(848,760100381012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','junacik','tomas352@post.sk','Frano Tomas','Tematinska 8','Nove Mesto n/v','Slovakia','SLOVAK REPUBLIC','91501','+421904261303','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 00:01:23',0,NULL,3,0,2,1,NULL,'junacik\r\\'),(849,762210786012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','jeffleblanc759','jfleblanc@constructionlfg.com','Jean-Francois Leblanc','178, Route 132 Est','Saint-Omer','QC','CANADA','G0C 2Z0','(418) 364-7082 ext.: 235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 00:45:05',0,NULL,3,0,2,1,NULL,'jeffleblanc759\r、'),(850,685928156011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','tbird21957','nelsongeli@hotmail.com','E M Nelson','4643 Brightmore Rd','Bloomfield Hills','MI','UNITED STATES','48302-2123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 01:18:49',0,NULL,3,0,1,1,NULL,'tbird21957\r、'),(851,565150225013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','veneno.78','makeyourself78@yahoo.es','Pablo Morales','Nelson 1838<br>Ñuñoa','Santiago','Metropolitana','CHILE','7780288','83345175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:01:32',0,NULL,3,0,3,1,NULL,'veneno.78\rMOSA002\rRA022491672CN\r'),(852,565150988013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','rd0','pub_radu@syskey.com','Radu Duta','351 87th St','Brooklyn','NY','UNITED STATES','11209-5105','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:03:35',0,NULL,3,0,1,1,NULL,'rd0\r、'),(853,519867223004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','jeduardox','jeduardo@cefetes.br','Jose Eduardo Mendonca Xavier','R. Constante Sodre, 1053 - Garden, 1404B<br>Praia do Canto','Vitoria','ES','BRAZIL','29055-420','+55 27 93117690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:03:58',0,NULL,3,0,3,1,NULL,'jeduardox\rOTRA002\rRA022491584CN\r'),(854,762235400012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','r101j','randalljr@myfastmail.com','Randall Whiteman','1533 Molly Ct','stockton','CA','UNITED STATES','95206-5611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:08:12',0,NULL,3,0,1,1,NULL,'r101j\r、'),(855,514051196003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','medicalchest','spacesector666@gmail.com','Andy Maljin','400 Barcelone','Dollards Des Ormeaux','QC','CANADA','H9B 3M1','(514) 315-0722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 02:32:10',0,NULL,3,0,3,1,NULL,'medicalchest\rCRLO001+POLO001\rRA022491289CN\r'),(856,685944767011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','foureyes0','eyesfour@aol.com','Gregory Faith','5343 W. Ave. M2','Quartz Hill','CA','UNITED STATES','93536-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 02:28:11',0,NULL,3,0,1,1,NULL,'foureyes0\r、'),(857,685979853011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ricardogsaraujo','ricardogualda@gmail.com','Ricardo Araujo','20 Manhattan Close<br>Point Cook','Melbourne','Victoria','AUSTRALIA','3030','0404251234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 05:47:25',0,NULL,3,0,2,1,NULL,'ricardogsaraujo\r、'),(858,519900979004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','elilevy1212','elilevy2@zahav.net.il','Eli Levy','Harv Pinto 2<br>appartment 13','Petch Tikva','NA','ISRAEL','49294','972-54-2493507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 06:49:04',0,NULL,3,0,3,1,NULL,'elilevy1212\rHSMO007\rRA022491575CN\r'),(859,685995310011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maxter_pl','makster@tlen.pl','Kazimierz Napieracz','36 Grantley Street','Grantham','Lincolnshire','UNITED KINGDOM','NG31 6BW','07840644990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 07:23:37',0,NULL,3,0,2,1,NULL,'maxter_pl\\'),(860,565212923013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','mouseblue14','trezise@ymail.com','Kathy Trezise','PO Box 1038<br>Geelong','Geelong','Victoria','AUSTRALIA','3220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 09:41:15',0,NULL,3,0,2,1,NULL,'mouseblue14\r、'),(861,686032592011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','citroen-afy','xantia-afy@hotmail.com','keijaerts','roterlaan 40','Kortessem','','BELGIUM','3721','011727572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 09:54:31',0,NULL,3,0,2,1,NULL,'citroen-afy\r欧标\r、'),(862,686034221011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',16.59,'eastar4','robnepprm','nepprm@gmail.com','Rob Martin','1888 East 61st Avenue Basement','Vancouver','BC','CANADA','V5P 2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 10:03:56',0,NULL,3,0,2,1,NULL,'robnepprm\racer 4pin1.25 6cm \r\\'),(863,565234040013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','yoshie1976','joshlockhartmobile@gmail.com','Joshua Lockhart','8 Ewenton St','Balmain','New South Wales','AUSTRALIA','2041','0298108394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 11:04:23',0,NULL,3,0,2,1,NULL,'yoshie1976\r、'),(864,686056644011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lyza59','eddy.barbier@wanadoo.fr','eddy barbier','11 lotissement les bleuets','oye plage','Nord-Pas-de-Calais','FRANCE','62215','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 11:16:47',0,NULL,3,0,2,1,NULL,'lyza59\r\\'),(865,565243528013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','ken425ken','kenneththompson@live.com','ETC Thompson, Kenneth','PSC 451  Box 700','FPO','AE','AA','09834-2800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 11:42:54',0,NULL,3,0,1,1,NULL,'ken425ken\r、'),(866,762372000012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',15.99,'eastar4uk','cockney0_1','chrisward46@hotmail.com','Chris Ward','2 Hudson Close<br>Lower Wick','Worcester','Worcestershire','UNITED KINGDOM','WR2 4DP','01342328056','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 11:51:13',0,NULL,3,0,3,1,NULL,'cockney0_1\rOTGR001\rRA022491845CN\r'),(867,686071592011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','yabeug','eugenegrant@gmail.com','Eugene Grant','160 Collinswood<br>CollinsAvenue','Dublin ','Dublin','IRELAND','D9','0868417450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 12:05:08',0,NULL,3,0,2,1,NULL,'yabeug\r\\'),(868,762385322012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',14.49,'eastar4','lmvbbb','gereis@t-online.de','G. Eiserbeck','Am Kuschelhain 27','Velten','','GERMANY','16727','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 12:36:17',0,NULL,3,0,2,1,NULL,'lmvbbb\racer 8pin1.00 8cm\r\\'),(869,762393110012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','black_dragons_enterprises','driftrr@hotmail.com','David Flinn','440 SE Excel St','sheridan','OR','UNITED STATES','97378-1962','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 12:45:42',0,NULL,3,0,1,1,NULL,'black_dragons_enterprises\rMX20T  \r、'),(870,762405279012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','hjoci61','hjoci64@googlemail.com','jozef Horváth','13 the quays','moy','Tyrone','UNITED KINGDOM','bt717tg','07751927939','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 13:17:59',0,NULL,3,0,3,1,NULL,'hjoci61\rHSNO006   英标\rRA022491275CN\r'),(871,762404646012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','brijm1967','alsnbrn@aim.com','Brian Murray','hunters way<br>pulpit lane','oving','Buckinghamshire','UNITED KINGDOM','hp22 4ez','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 13:19:27',0,NULL,3,0,3,1,NULL,'brijm1967\rOTRA002\rRA022491213CN\r'),(872,761942096012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','santistuff2','michael@flexloop.com','Flexloop Systems','1260 E Woodland Ave<br>Ste 23','Springfield','PA','UNITED STATES','19064-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 13:20:23',0,NULL,3,0,1,1,NULL,'santistuff2\r、'),(873,762407403012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','ecle7855','eduardo.clerigues@gmail.com','Eduardo Clerigues','Avda. Dr. J.J. Domine 18 - 46','VALENCIA','Comunidad Valenciana','SPAIN','46011','693835441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:22:10',0,NULL,3,0,2,1,NULL,'ecle7855\rMX20T\r\\'),(874,762412353012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','markush9297','mhlastec@googlemail.com','Markus Hlastec','Blumenstrasse 24','Duisburg','','GERMANY','47179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:34:31',0,NULL,3,0,2,1,NULL,'markush9297\r、'),(875,565277775013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','slv_789','slv789@gmail.com','Salavat Khafizov','ul. 8 marta, 32, kv.106','Ufa','Republic of Bashkortostan','RUSSIAN FEDERATION','450078','(7) 91734090952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:06:34',0,NULL,3,0,2,1,NULL,'slv_789\r、'),(876,686121853011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','hnoy7657','herve.noyon@yahoo.fr','Hervé NOYON','24, avenue Raymond Boivin','PESSAC','Aquitaine','FRANCE','33600','05.56.46.26.25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:18:29',0,NULL,3,0,2,1,NULL,'hnoy7657\r、'),(877,762442511012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','nokiane64','nokiane@hotmail.com','JOSE GABRIEL MIGUEL LAVIN','PABLO DE ALZOLA Nº 25-- 4º C','BILBAO','País Vasco','SPAIN','48012','630379157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 14:43:57',0,NULL,3,0,2,1,NULL,'nokiane64\r、'),(878,762473477012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','kasper992000','nevesyscommunications@yahoo.com','Jean H Nevelus','4681 Chief Joseph Cir','Douglasville','GA','UNITED STATES','30135-8461','(347) 489-8741','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 15:50:52',0,NULL,3,0,1,1,NULL,'kasper992000\rMX20T\r、'),(879,686156964011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','091568','russi@bonafidemanagement.com','Ricardo Russi','13067 SW 133rd Ct','Miami','FL','UNITED STATES','33186-5849','(305) 244-1035','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 15:52:31',0,NULL,3,0,1,1,NULL,'091568\r、'),(880,686164483011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','plathome','jucoalco1@yahoo.com','Julio Cordero','5812 21st Ave<br>Apt 2F','Brooklyn','NY','UNITED STATES','11204-2031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 16:00:44',0,NULL,3,0,1,1,NULL,'plathome\r、'),(881,762479911012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','sunrise-citizen','sunrise.citizen@gmail.com','Steve Hopkins','3030 NW 113th Ave','Sunrise','FL','UNITED STATES','33323-1625','(954) 651-2037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 16:05:33',0,NULL,3,0,1,1,NULL,'sunrise-citizen\rMX20T\r、'),(882,0,220758137995,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.5,'eastar4','nanuk1sk','nanuk1sk@gmail.com','Dusan Janik','Na Návsi 525/6C','Dolni Mecholupy','Prague 10','CZECH REPUBLIC','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:06:18',0,NULL,3,0,3,1,NULL,'nanuk1sk\rOTRA002\rRA022491301CN\r'),(883,514202416003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',26.95,'cnfaner','fabiovalinhos7355','fabiovalinhos@gmail.com','Fábio de Albuquerque Vilalba','Rua Joaquim Martins, 364','Valinhos','SP','BRAZIL','13277-124','55 (019) 3869-1848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:07:58',0,NULL,3,0,3,1,NULL,'fabiovalinhos7355\rHSUE002\rRA022491394CN\r'),(884,520022280004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','09timka','turbo.gtr@hotmail.com','Leonid Timofejev','Isruties 14-48','Vilnius','','LITHUANIA','06220','+37067666068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:16:04',0,NULL,3,0,3,1,NULL,'09timka\rHSNO022  欧标\rRA022491227CN\r'),(885,759263043012,220578466424,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',19.99,'eastar4','khalilafandiyev','efendiyev_xelil@mail.ru','Khalil Afandiyev','Nizami district<br>Sherifli 96/20','Baku','Azerbaijan/Baku/Nizami','AZERBAIJAN','AZ1118','0503790395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:32:03',0,NULL,3,0,2,1,NULL,'khalilafandiyev\r单机\r、'),(886,565326281013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','olkip','o.kiptily@gmail.com','Olga Kiptily','4<br>Somerville','Didcot','Oxfordshire','UNITED KINGDOM','ox118ud','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:33:39',0,NULL,3,0,3,1,NULL,'olkip\rHSSH002\rRA022492179CN\r'),(887,565329282013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','4120100027034','pharaoh588@hotmail.com','Titaree Kajtanyakij','265/3 Soi Ngamwongwan3<br>Ngamwongwan Road','Muang','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 16:44:09',0,NULL,3,0,2,1,NULL,'4120100027034\r、'),(888,762502269012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',27.98,'eastar4uk','melvyn0722','chris_millard@sky.com','christopher  millard','19  Cowleaze','Chinnor','oxfordshre','UNITED KINGDOM','OX39 4TD','07834639154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 16:45:00',0,NULL,3,0,3,1,NULL,'melvyn0722\rHSMO018   英标\rRA022491385CN\r'),(889,0,220758136424,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',26.48,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 17:09:41',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个保护屏\r、'),(890,565351890013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','andym67','andymoss67@hotmail.com','Andrew Moss','45 Blackwood St<br>Knightswood','Glasgow','Glasgow (City of)','UNITED KINGDOM','G13 1AL','01236722154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 17:39:57',0,NULL,3,0,3,1,NULL,'andym67\rHSSH002\rRA022492182CN\r'),(891,0,230601702906,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11,'eastar4','stephnalty','stephnalty@yahoo.com','steph nalty','2105 tetlow pl','sarasota','FL','UNITED STATES','34239-4111','(843) 469-3663','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-26 17:48:27',0,NULL,3,0,1,1,NULL,'stephnalty\r、'),(892,514247801003,130490253015,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',2,'BAIN001',19.98,'cnfaner','tmtdigirad','mriveraalarcon@gmail.com','mauricio rivera alarcon','tangue 565','ovalle','IV region','CHILE','1840000','053-620207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 18:14:42',0,NULL,3,0,3,1,NULL,'tmtdigirad\rBAIN001\rRA022492165CN\r'),(893,565373001013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','inchwormz','jason@parentingbynature.com','Jason Champion','4186 Orkney Beach Rd.','Orillia','ON','CANADA','L3V 6H7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 18:29:27',0,NULL,3,0,3,1,NULL,'inchwormz\rHSSH002\rRA022492355CN\r\\'),(894,686242905011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','elkgene','elkgene@juno.com','eugene kanski','127 Spanish Moss Ln','lake jackson','TX','UNITED STATES','77566-4314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 18:32:21',0,NULL,3,0,1,1,NULL,'elkgene\r、'),(895,762566920012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','mirzailyas','m.m.ilyas786@gmail.com','ILYAS2011 MIRZA','44 HAMMPSHIRE AVENUE<br>SLOUGH','SLOUGH','Berkshire','UNITED KINGDOM','SL1 3AQ','7411633665','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 18:36:21',0,NULL,3,0,3,1,NULL,'mirzailyas\rHSMO014  英标\rRA022491363CN\r'),(896,520085288004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','whitetitan7','hatman@live.se','Michael Sannemo-Targama','Skogsbacken 22','Sundbyberg','Sundbyberg','SWEDEN','17241','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:01:35',0,NULL,3,0,3,1,NULL,'whitetitan7\rWLAT002\rRA117710378CN\r\\'),(897,762589213012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','smolstar','tema_67region@mail.ru','Artem Antonov','29 Koneva st.<br>181','Smolensk','','RUSSIAN FEDERATION','214019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:11:15',0,NULL,3,0,2,1,NULL,'smolstar\r、'),(898,565403670013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','colinchem','c.g.cameron@gmail.com','Colin G Cameron','659 South Rawdon Road','Mt. Uniacke','NS','CANADA','B0N 1Z0','(626) 757-0611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:41:13',0,NULL,3,0,2,1,NULL,'colinchem\r\\'),(899,520103692004,140516080226,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',48.5,'cnfaner','ccpeng1980','peng.terry@gmail.com','Yi-Ting','No.163, Ln. 192, Sec. 1, Fengxing Rd.<br>Tanzi Dist.','Taichung City','Taiwan','TAIWAN','42743','(092) 139-5657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 19:49:02',0,NULL,3,0,14,1,NULL,'ccpeng1980\rHSLO002\r010202949315\r'),(900,762619120012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','alabama_pink','ebil_t@yahoo.com','Tunzala Abil','Qaradag rayonu, Sahil qesebesi, M.Seyidov kuchesi 3/26','Baku','-','AZERBAIJAN','AZ 1083','+994124461605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 19:58:22',0,NULL,3,0,2,1,NULL,'alabama_pink\r\\'),(901,0,230599765719,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.5,'eastar4','aiea.reyn','reynnylen@hotmail.com','Reyn Nylen','98-1038 Moanalua Rd<br>Apt 108','Aiea','HI','UNITED STATES','96701-4610','(808) 375-3651','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-26 20:10:27',0,NULL,3,0,1,1,NULL,'aiea.reyn\r、'),(902,762640585012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',31.8,'eastar4uk','aquica','aquica@hotmail.com','Anna Melander','Banérgatan 13','Timrå','none','SWEDEN','86131','070-2448074','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 20:32:50',0,NULL,3,0,3,1,NULL,'aquica\rHSSE004  欧标\rRA022491329CN\r'),(903,565425547013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','vbam1877','viestursb@v-vdg.pro','Viesturs Bambans','11687 SW Teal Blvd Apt.F.','Beaverton','OR','UNITED STATES','97007','(503) 781-6724','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 20:34:07',0,NULL,3,0,1,1,NULL,'vbam1877\r、'),(904,762650214012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',43.68,'eastar4','szandal','belez@prohome.hu','Tibor Olmosi','Angol utca 34. (A16 Irodahaz.)','Budapest','Pest megye','HUNGARY','1149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 21:04:19',0,NULL,3,0,3,1,NULL,'szandal\rWWOT001\rRA022491156CN\r'),(905,686380078011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',48.89,'eastar4','sabrewolf_rex','nikolov.andon@gmail.com','andon nikolov','Esperantotie 2','Espoo','','FINLAND','02230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 23:09:19',0,NULL,3,0,3,1,NULL,'sabrewolf_rex\r再发一个 IBM版AR5008\rWLAT001+ANTY001*3\r+WLAT003\rRA022491235CN\r'),(906,565483171013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','urbancamel','urbancamel@gmail.com','Michael Aossey','4621 Country Walk Lane','Sylvania','OH','UNITED STATES','43560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-26 23:39:25',0,NULL,3,0,1,1,NULL,'urbancamel\r、'),(907,762737043012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',17.4,'eastar4','namttams','sm_att@hotmail.com','Matthew  Hart','56 Snows Rd<br>Stirling','Adelaide','South Australia','AUSTRALIA','5152','0883709328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 00:08:17',0,NULL,3,0,2,1,NULL,'namttams\rCAB-SS-2660\r\\'),(908,565515233013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','2000isoy','craft.mark@lincoln.navy.mil','Elizabeth Craft','4518 Eastlawn Ave','Woodbridge','VA','UNITED STATES','22193-2604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 02:04:34',0,NULL,3,0,1,1,NULL,'2000isoy\r、'),(909,686443750011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','dssjallen','dssjallen@nc.rr.com','Daniel Allen','840 W Chatham St<br>Apt i','Cary','NC','UNITED STATES','27511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 02:41:25',0,NULL,3,0,1,1,NULL,'dssjallen\r、'),(910,514409149003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 04:43:43',0,NULL,3,0,3,1,NULL,'hue_bui\rHSUE004\rRA022491142CN\r '),(911,520226663004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','resab892','resa892@bellsouth.net','Teresa Miller','892 Armena Rd','Leesburg','GA','UNITED STATES','31763-4218','(229) 436-5080','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 04:44:59',0,NULL,3,0,1,1,NULL,'resab892\r、'),(912,686468005011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY001*3',16.99,'eastar4','mdbecker','markglobal@suddenlink.net','Marcus Becker','3808 Sterling Pointe Dr.<br>Unit E-1','Winterville','NC','UNITED STATES','28590','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 04:45:10',0,NULL,3,0,1,1,NULL,'mdbecker\r、'),(913,565545795013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',2,'WLAT008',33.7,'eastar4','dalesbud8','djelliott81@gmail.com','David Elliott','1050 Grant St','Beloit','WI','UNITED STATES','53511-5014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 05:11:26',0,NULL,3,0,1,1,NULL,'dalesbud8\r、'),(914,686473648011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','kenskh','skhui@singnet.com','Sim Kwang Hui','47<br>Fulton Road','Singapore','Singapore','SINGAPORE','578930','(+65) 97355919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 05:22:04',0,NULL,3,0,11,1,NULL,'kenskh\rRA022491125CN\r'),(915,565549386013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',16.98,'eastar4','shammijayaraj','shammijayaraj@hotmail.com','shammi jayaraj','3117 E Coconino Dr','Gilbert','AZ','UNITED STATES','85298-8705','(480) 782-7959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 05:42:31',0,NULL,3,0,1,1,NULL,'shammijayaraj\r、'),(916,686487643011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','thebuyeraccount284','thebuyeraccount285@live.ca','Bowen Liu','#30-9699 152B St','Surrey','BC','CANADA','V3R 0G5','(604) 931-9183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 06:47:33',0,NULL,3,0,2,1,NULL,'thebuyeraccount284\r\\'),(917,565561755013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',2,'HSMO006',23.8,'eastar4','0503olson','stillhereinca2@gmail.com','claire olson','70 Sklar St<br>Apt 1208','ladera ranch','CA','UNITED STATES','92694-0777','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 07:22:51',0,NULL,3,0,1,1,NULL,'0503olson\r、'),(918,762843081012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',3,'OTGR001+OTGR002',119.7,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:32:07',0,NULL,3,0,3,1,NULL,'speedsterporsche\rOTGR001*3+OTGR00\r2*3\rRA022491332CN\r\r'),(919,565565424013,230397452111,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',13.49,'eastar4','torulf','torulf@improvisera.net','Torulf Ohman','Edeforsgatan 46','Lulea','Norrbotten','SWEDEN','97438','+46702695704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:39:02',0,NULL,3,0,2,1,NULL,'torulf'),(920,686506665011,320585234549,'New Intel 512ANX 5150 Half Mini PCI-E WIFI Card+antenna',1,'WLIN004+ANTY001',33.98,'eastar4','ldel7324','hobereau@gmail.com','Laurent Delebecque','Mercier Ferrier','Faux la montagne','Limousin','FRANCE','23340','0660278850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 08:09:38',0,NULL,3,0,2,1,NULL,'ldel7324\r\\'),(921,686506368011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeff3yan3','jeff3yan@gmail.com','Jeffrey Yan','50 Wilmay avenue<br>Papatoetoe','Auckland','','NEW ZEALAND','2025','+64211589611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 08:11:15',0,NULL,5,0,18,1,NULL,'jeff3yan3\r'),(922,514454563003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','marting811','martingruen@aon.at','Martin Grün','Platti 317','Kappl','','AUSTRIA','6555','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:28:26',0,NULL,3,0,3,1,NULL,'marting811\rHSNO016  欧标\rRA022491377CN\r'),(923,565596773013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','58415','kolbasa76@yandex.ru','Vetchinkin Evgeniy','ul. 22 April, dom 8-v, kv.4','Omsk','','RUSSIAN FEDERATION','644088','0079131410180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:53:45',0,NULL,3,0,2,1,NULL,'58415\r、'),(924,565606753013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','mikehampy','mikehamp78@gmail.com','Claire Milligan','4 Pledger Close','Diamond Creek','Victoria','AUSTRALIA','3089','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 10:26:55',0,NULL,3,0,3,1,NULL,'mikehampy\rMOSA003\rRA022491686CN\r'),(925,565612080013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','lamarshj','jefflamarsh@hotmail.com','Jeffrey LaMarsh','5889 Skeena St.','Powell River','BC','CANADA','V8A 4V5','(604) 414-0220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 10:45:49',0,NULL,3,0,2,1,NULL,'lamarshj\r\\'),(926,564249772013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','2004chandrashekar','vivekrao2@hotmail.com','chandrashekar gopal','36, corryton court','Wattle grove','New South Wales','AUSTRALIA','2173','0298253968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:29:59',0,NULL,3,0,3,1,NULL,'2004chandrashekar\rMOSA002\rRA022491757CN\r'),(927,686579859011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','dom1047','dominique.saint-loubes@wanadoo.fr','dominique saint - loubes','1705 cheminde pecau','bon-encontre','Aquitaine','FRANCE','47240','0553471991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:38:13',0,NULL,3,0,2,1,NULL,'\rdom1047\r\\'),(928,686605357011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ozzy_rus','ozzy_rus@tvcom.ru','Anatoly  O Ozeryanskiy','bul. Guseva , 4-37','Tver','Tver\' region','RUSSIAN FEDERATION','170030','+7 903 8011410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 12:20:38',0,NULL,3,0,2,1,NULL,'ozzy_rus\r、'),(929,762993564012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',3,'HSPL002',31.5,'eastar4uk','jjon7584','ivanstaxis@btconnect.com','Janet Jones-Parry','Is Silyn, 14 Hen Lon<br>Penygroes','Caernarfon','Gwynedd','UNITED KINGDOM','LL54 6RG','01286881590','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 13:25:26',0,NULL,3,0,3,1,NULL,'jjon7584\rHSPL002\rRA022491292CN\r'),(966,687192529011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','rfreyer8','rf8883@gmail.com','Richard Freyer','11/155 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','0292613400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:09:17',0,NULL,3,0,2,1,NULL,'rfreyer8\r、'),(930,0,220759571828,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jlneiman1234','neimansbrushstrokes@hotmail.com','Jessica Neiman','207 Greenwich St','Kutztown','PA','UNITED STATES','19530-1412','(610) 223-8422','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-27 14:12:59',0,NULL,3,0,1,1,NULL,'jlneiman1234\r、'),(931,686674120011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','antoinedp','antoinedepreux@hotmail.com','Antoine de Preux','Teufenertrasse 95','Sankt Gallen','','SWITZERLAND','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:43:05',0,NULL,3,0,2,1,NULL,'antoinedp\r\\'),(932,763041913012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','jackorgel','orge7j6ck@earthlink.net','John F. Pacelli','2113 Gray St','Schenectady','NY','UNITED STATES','12306-4301','(518) 355-0708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 14:53:24',0,NULL,3,0,1,1,NULL,'jackorgel\r、'),(933,520375251004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','abdfarae2009','abdfarae@hotmail.com','abdulla salih mohd','al-madra<br>gsm 92955775','Samail','oman','OMAN','219/620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:03:20',0,NULL,3,0,3,1,NULL,'abdfarae2009\rWWSI005\rRA022491641CN\r'),(934,565707214013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','bob.airky','airky777@gmail.com','Bob Randriambololona','4257, Kimber','Pierrefonds-montreal','QC','CANADA','H9H5C4','(514) 627-0123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:18:28',0,NULL,3,0,3,1,NULL,'bob.airky\rMOSA002\rRA022491669CN\r'),(935,565707386013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','cliffyo','cliffyo@frontiernet.net','Clifford Young','PO Box 290','Downsville','NY','UNITED STATES','13755','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 15:18:57',0,NULL,3,0,1,1,NULL,'cliffyo\r、'),(936,0,320677133271,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32,'eastar4','alain15050','alainbarbier5@aol.com','alain BARBIER','60 rue vincent faita','NIMES','Languedoc-Rousillon','FRANCE','30000','0466289612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 16:25:38',0,NULL,3,0,3,1,NULL,'alain15050\rOTRA002\rRA022491638CN\r'),(937,565751355013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','rayval_0','rayval@o2.co.uk','Rayval Rodman','25 Inchgarvie Pk','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH309RN','07752302333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 16:43:33',0,NULL,3,0,2,1,NULL,'rayval_0\rCAB-6060\r\\'),(938,565755634013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','coffeeman410','snmeagher@gmail.com','sean meagher','1702 aberdeen rd','parkville','MD','UNITED STATES','21234-5102','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 16:52:31',0,NULL,3,0,1,1,NULL,'coffeeman410\r、'),(939,520435821004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','mamamia1236','info@exumrecording.com','Scott Exum','1066 Camellia St','Escondido','CA','UNITED STATES','92027-1532','(760) 739-9700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 17:07:17',0,NULL,3,0,1,1,NULL,'mamamia1236\rOMHJ001\r、'),(940,565810655013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','chipgolf','bryan@neighborspizza.com','Bryan Watari','1957 McGowan Pkwy<br>Ste 1','Olivehurst','CA','UNITED STATES','95961-4770','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 18:09:29',0,NULL,3,0,1,1,NULL,'chipgolf\r、'),(941,514690153003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','slesas','slesas666@yahoo.com','Aldas Kvaščiauskas','skuodo 51','Kaunas','','LITHUANIA','45126','867635340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:44:44',0,NULL,3,0,3,1,NULL,'slesas\rHSSE004\rRA022491567CN\r'),(942,514697960003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',2,'HSMO017',43.98,'cnfaner','123michee','homi01@msn.com','Michee Homidas','8048 Deerwood Cir','Tampa','FL','UNITED STATES','33610-9557','(813) 966-6524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 18:51:15',0,NULL,3,0,1,1,NULL,'123michee\r、'),(943,763316729012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','dj.c','efoparties@optonline.net','greg cooper','7a shadyside ave','port washington','NY','UNITED STATES','11050-2414','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 19:42:47',0,NULL,3,0,1,1,NULL,'dj.c\r、'),(944,565894288013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',8,'CASS003',69.6,'eastar4','gauravgoyal0022','gauravgoyal022@gmail.com','Gaurav Goyal','3 Maiden Place','reading','Berkshire','UNITED KINGDOM','RG63HA','07934012852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 19:47:50',0,NULL,3,0,3,1,NULL,'gauravgoyal0022\rCASS003*8\rRA022491315CN\r'),(945,565924537013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','maxromanoff','hurtman@mail.wplus.net','Romanov Maxim','Leninsky prospekt<br>dom 95 korpus 2, kv 636','St. Petersburg','','RUSSIAN FEDERATION','198330','+79119117911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 20:30:15',0,NULL,3,0,2,1,NULL,'maxromanoff\r\\'),(946,763390276012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','mhpyke','marktidcombe@yahoo.co.uk','Mark Tidcombe','3 Gifford Rd','Bristol','Avon','UNITED KINGDOM','BS10 7LR','01179087519','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 20:41:34',0,NULL,3,0,3,1,NULL,'mhpyke\r英标   HSNO006\rRA022491403CN\r'),(947,565969929013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','warriortamer','krisking1977@gmail.com','Kristopher King','114 waterwheel drive','commerce','GA','UNITED STATES','30529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 21:53:20',0,NULL,3,0,1,1,NULL,'warriortamer\r、'),(948,687053013011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fluffymoosedad','breconsulting@shaw.ca','Ross Ehalt','8 Hyde Court','St. Albert','AB','CANADA','T8N 5W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:01:13',0,NULL,3,0,2,1,NULL,'fluffymoosedad\r\\'),(949,514823134003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'cnfaner','mmurphy.5150','mmurphy.5150@juno.com','Mark Murphy','3 Ring Neck Rdg','Lloyd Harbor','NY','UNITED STATES','11743-9719','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 22:26:13',0,NULL,3,0,1,1,NULL,'mmurphy.5150\r、'),(950,687075081011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sarasimssara','sarasimonson@gmail.com','Sara Simonson','520 W 48th St<br>Apt 5P','New York','NY','UNITED STATES','10036-1146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-27 22:44:27',0,NULL,3,0,1,1,NULL,'sarasimssara\r、'),(951,687083969011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bluechilli1967','martin@bluechilli.co.uk','Martin Stone','1, Blagden Close<br>Greenham','Newbury','Berks','UNITED KINGDOM','RG19 8SF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 23:06:30',0,NULL,3,0,2,1,NULL,'bluechilli1967\r\\'),(952,687086106011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','mpc650','andre.b.marques@gmail.com','André Marques','Rua Manuel de Arriaga N6 1A','Odivelas','Ramada','PORTUGAL','2620-319','965660389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 23:12:54',0,NULL,3,0,2,1,NULL,'mpc650\r\\'),(953,763502209012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.88,'eastar4uk','ashrafb123','info@frognal.co.uk','Ashraf  Borghol','283 Finchley Road','London','London','UNITED KINGDOM','nw36nd','07770224712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 23:58:27',0,NULL,3,0,3,1,NULL,'ashrafb123\r英标   HSNO005\rRA022491346CN \r\r'),(954,566019381013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','ivannick6363','goddard6363@yahoo.com','Ivan Goddard','2481 Cranston Rd','letts','IA','UNITED STATES','52754-9512','(563) 262-8008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 00:35:39',0,NULL,3,0,1,1,NULL,'ivannick6363\r、'),(955,687117626011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fwarch','fwarchuleta@hotmail.com','Franklin Archuleta','128 Sydneys Way','Buda','TX','UNITED STATES','78610','(512) 312-2831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 00:40:03',0,NULL,3,0,1,1,NULL,'fwarch\rLK034402989CN\r、'),(956,520676046004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','deeehmon','nobumen@gmail.com','Patricio Meneses','psj.Buzeta #4430, Quinta normal','Santiago','Metropolitana','CHILE','8510612','0056991000888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 00:53:28',0,NULL,3,0,3,1,NULL,'deeehmon\rOTRA002\rRA022491655CN\r'),(957,687133757011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','scottmenard','scottmenard@bellsouth.net','scott menard','170 Old Carrollton Rd','roopville','GA','UNITED STATES','30170','(770) 547-5305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:23:51',0,NULL,3,0,1,1,NULL,'scottmenard\r、'),(958,566035372013,230601283994,'New Shure E2c Sound Isolating headset transparent ver',3,'HSSH002',197.97,'eastar4','geds2001','kenhebb@yahoo.com','Ken Hebb','1439 Highway E','Owensville','MO','UNITED STATES','65066-2255','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:27:23',0,NULL,3,0,1,1,NULL,'geds2001\r、'),(959,687137876011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',65.99,'eastar4','mmcroskey','mark.mcroskey@gmail.com','Mark McRoskey','502 E Boone Ave<br>MSC 2446','Spokane','WA','UNITED STATES','99258-1774','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 01:34:33',0,NULL,3,0,1,1,NULL,'mmcroskey\r、'),(960,520692813004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','danylina','dayli01@msn.com','Lina Heiser','4001 Beneva Rd<br>Apt 410','sarasota','FL','UNITED STATES','34233','(941) 822-2129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 02:00:31',0,NULL,3,0,1,1,NULL,'danylina\r、'),(961,0,220758134612,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','amgjay','amgdirectj@aol.com','Jay Ruditis','679 Nieves Ln','Saint Augustine','FL','UNITED STATES','32086-7706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 02:22:04',0,NULL,3,0,1,1,NULL,'amgjay\r、'),(962,566056791013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',21.98,'eastar4','ss67332010','sanderssavage2@bellsouth.net','sammurelle savage','5740 S W 26TH ST APT#A','HOLLYWOOD','FL','UNITED STATES','33023','(954) 865-3585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 02:52:52',0,NULL,3,0,1,1,NULL,'ss67332010、'),(963,514894790003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','komatsuyuri','yurikomatsu@gmail.com','Yuri Komatsu','João Dantas Figueira 1285<br>Jardim Brasília','Paranaíba','Mato Grosso do Sul','BRAZIL','79500000','+556736681650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 03:10:52',0,NULL,3,0,3,1,NULL,'komatsuyuri\rMOSA002\rRA022491258CN\r'),(964,514911568003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','dialmanik','manik@dialtrade.com','Ibrahim Adam','Dialcomplex.2/52Orchidmagu.<br>Mafannu','Male\'.','Maafannu','MALDIVES','2002','+960-3331983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 04:58:02',0,NULL,3,0,3,1,NULL,'dialmanik\rOTGR001\rRA022492196CN\r'),(965,763600582012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasammo','vsamoylov@pochta.ru','Vadim Samoylov','69-9<br>Gorkogo st.','Biysk','Altay region','RUSSIAN FEDERATION','659301','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 05:00:33',0,NULL,3,0,2,1,NULL,'vasammo\r欧标\r\\'),(967,763602363012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','jnsar64','jnsar64@yahoo.com.ar','Jose Sanguedolce','Tomas Moro 1782<br>Las Condes','Santiago','Chile','CHILE','7550000','(829) 648-99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:10:02',0,NULL,3,0,2,1,NULL,'jnsar64\r\\'),(968,520727039004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',16.59,'cnfaner','goliat_pl','golji@poczta.onet.pl','Tomasz Gralewski','Slowicza 23','Żary','lubuskie','POLAND','68200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:19:04',0,NULL,3,0,3,1,NULL,'goliat_pl\racer 4pin1.25 6cm \rBTAC2104\rRA022491831CN \r'),(969,687195222011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','inetsion','eddie_lau@hotmail.com','Eddie Lau','11 Jalan Puteri 3/1<br>Bandar Mahkota Cheras','Kajang','Selangor','MALAYSIA','43200','0122778788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 05:26:51',0,NULL,3,0,3,1,NULL,'inetsion\rWLAP001\rRA022491139CN\r'),(970,566092484013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','jb114.seo','lssjb114@paran.com','Jeongbeom Seo','Room #412, compact house<br>602-19, Namhyeon-dong, Gwanak-gu','Seoul','','KOREA,REPUBLIC OF','151-801','010-4775-5440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 06:43:20',0,NULL,3,0,3,1,NULL,'jb114.seo\rMOSA002\rRA022491111CN\r\r'),(971,687227850011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','mortan1979','mortan@email.ru','Dmitriy Urusov','ulitsa Saltykovskaya<br>dom 29 korpus 1 kvartira 195','Moskow','Moskow','RUSSIAN FEDERATION','111672','+79265919115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:19:37',0,NULL,3,0,2,1,NULL,'mortan1979\r\\'),(972,0,220758138156,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','tugageek','luismiguelsnt@gmail.com','Luís Miguel Santos','Av. Marechal Gomes da Costa, N.º21-D 2.º Piso<br>(Sorel Serviços)','Lisboa','Portugal','PORTUGAL','1800-255','+351 919 233 918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:20:28',0,NULL,3,0,3,1,NULL,'tugageek\rOTRA002\rRA022492514CN\r\\'),(973,763662771012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','azra2009','fantastischshop@gmx.de','Salim Ünyeli','Bülowstr. 9','Düsseldorf','','GERMANY','40476','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 09:48:50',0,NULL,3,0,2,1,NULL,'azra2009\r\\'),(974,520764125004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',2,'HSPL010',49.98,'cnfaner','redsoxfollower','jgcowden@yahoo.com','James G Cowden','18 Highland Ave','Barrington','RI','UNITED STATES','02806-4714','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 09:55:14',0,NULL,3,0,1,1,NULL,'redsoxfollower\r\\'),(975,566091802013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',2,'WLIN010',41.9,'eastar4','jttj2011','piypay@yandex.ru','Alexander Shatalov','ul. Rodonitovaya, dom 32, kv. 154','Yekaterinburg','Sverdlovsk region','RUSSIAN FEDERATION','620073','+79221172121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:04:12',0,NULL,3,0,3,1,NULL,'jttj2011\rWLIN010\rRA022492545CN\r\\'),(976,519965279004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','weezy024','kcopeland22@yahoo.com','Ken Copeland','404 Poinsetta St','Lake Jackson','TX','UNITED STATES','77566-5440','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 11:15:32',0,NULL,3,0,1,1,NULL,'weezy024\r\\'),(977,520783303004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','maveolento','mauri.kiviranta@gmail.com','Mauri Kiviranta','viskaripolku 3 A 4','turku','','FINLAND','20210','+358440823675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 11:43:59',0,NULL,3,0,3,1,NULL,'maveolento\rOMHJ001\rRA022492474CN\r\\'),(978,763714082012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.99,'eastar4uk','nht1969','sc0rp10ns69@hotmail.com','Neil Hopkin-Thomas','5 Glan-Y-Mor<br>The knap','Barry','The Vale of Glamorgan','UNITED KINGDOM','CF62 6FF','07540939550','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 12:39:52',0,NULL,3,0,3,1,NULL,'nht1969\rCALO001\rRA022492531CN\r\\ '),(979,565023106013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',41.2,'eastar4','wagnertw','wagnerw@mail.com','Wagner T. Watanabe','Av Rogério Delalibera, 332','Londrina','Paraná','BRAZIL','86035175','+55 44 96329171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 12:47:06',0,NULL,3,0,3,1,NULL,'wagnertw\rANCN001+WWSI004\r\\\rRA022492528CN\r'),(980,763723660012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',23.85,'eastar4','chrisygeezer','chris@wherestony.co.uk','Chris Adams','Winterflood Securities Ltd<br>The Atrium Building, 25 Dowgate Hill','Cannon Bridge','london','UNITED KINGDOM','EC4R 2GA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:14:40',0,NULL,3,0,2,1,NULL,'chrisygeezer\r\\'),(981,520803687004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','thatslifemusic','info@fsgrafik.de','fsgrafik','Frank Stickel<br>Hauptstraße 32','Wankheim','','GERMANY','72127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:26:48',0,NULL,3,0,3,1,NULL,'thatslifemusic\rHSNO022    欧标\rRA022492593CN\r\\'),(982,566168314013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','ihartavi','ihartavi@gmail.com','Ibrahim H.HARTAVIOGLU','Eskipazar Mah. Hopa Cad.<br>Ozen Apt. Daire-11','Cayeli','RIZE','TURKEY','53400','5527159163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:26:50',0,NULL,3,0,3,1,NULL,'ihartavi\rOTRA002\rRA022492491CN\r\\'),(983,687314526011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','eitantr1','eitantr@gmail.com','Eitan Traistman','Ygaal Yadin 51/31','modieen','','ISRAEL','71720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 13:41:37',0,NULL,3,0,3,1,NULL,'eitantr1\rRCLO006\rRA022492647CN\r\\'),(984,687316981011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','mgar4579','martin.garcia@mavs.uta.edu','Martin Garcia','3928 6th Ave','Fort Worth','TX','UNITED STATES','76110','(817) 924-0852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 13:46:21',0,NULL,3,0,1,1,NULL,'mgar4579\r\\'),(985,763744144012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',3,'HSNO005',44.25,'eastar4','panosvxr','astrarsp@gmail.com','Panagiotis Fryssas','Alis Teriant 6','Mytilene','AL','GREECE','81100','00302251029857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 14:08:50',0,NULL,3,0,3,1,NULL,'panosvxr\rHSNO005   欧标\rRA022492633CN\r\\'),(986,761277297012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',21.98,'eastar4','howxx','wehow@hotmail.com','W. Edward Howard, Jr.','102 Haygood Ave','Lexington','SC','UNITED STATES','29072','(803) 659-6996','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 14:14:11',0,NULL,3,0,1,1,NULL,'howxx'),(987,763749371012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','dream459','anthony@saviniconstruction.com','Anthony Savini','16902 Shingle Point Rd','milton','DE','UNITED STATES','19968-2554','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 14:25:40',0,NULL,3,0,1,1,NULL,'dream459\r\\'),(988,515010055003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','erivanmelo','erivancmelo@hotmail.com','Erivan carlos de Melo','Rua, da Estrela, 203<br>Parnamirim','Recife','Pernambuco','BRAZIL','52060160','+55 81 99733351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 14:40:37',0,NULL,3,0,3,1,NULL,'erivanmelo\rHSPL005   单机\rRA022492505CN\r\\'),(989,566193712013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','milbeyer','milbeyer@yahoo.com.br','Rodrigo Guessada','R AUDALIO GONCALVES DOS SANTOS 217<br>JARDIM THOMAZ','SAO PAULO','SP','BRAZIL','05833040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:03:48',0,NULL,3,0,2,1,NULL,'milbeyer\r\\'),(990,515022107003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jonys-il','jonys1982@gmail.com','jonny s','Arava 11<br>Israel','holon','ID','ISRAEL','58422','0545832815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:26:26',0,NULL,3,0,3,1,NULL,'jonys-il\rHSMO018\rRA022492602CN\r\\'),(991,762284650012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','blander38490','dipmann2002@yahoo.com','Brandon Anderson','PO Box 1051','Palm Springs','CA','UNITED STATES','92263-1051','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 16:12:03',0,NULL,3,0,1,1,NULL,'blander38490\r\\'),(992,566213759013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','synebrukhoff1974','synebrukhoff@gmail.com','Evgeny Zhavoronkov','Marshala Kozheduba, 14-27','Moscow','Russian Federation','RUSSIAN FEDERATION','109559','0079150997706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:12:59',0,NULL,3,0,2,1,NULL,'synebrukhoff1974\r\\'),(993,0,220758136774,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',27.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 16:22:16',0,NULL,3,0,1,1,NULL,'4278dennis\r一共买了两个保护屏'),(994,515037942003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','alex_arkadyev','arcadyev@gmail.com','Alexander Arkadyev','Grazhdanskiy prospect,<br>dom 115, k.1, kv. 105','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195299','+7-921-7457930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:26:23',0,NULL,3,0,3,1,NULL,'alex_arkadyev\rWLIN010\rRA022492559CN\r\\'),(995,520850313004,140519359288,'NIB Kensington Expert Mouse Optical UsbTrackball K64325',3,'OTKE001',237,'cnfaner','indexpinc','marcoindexp@gmail.com','Georgina Hernandez','9950 Marconi Dr<br>Ste 101','San Diego','CA','UNITED STATES','92154-7272','(619) 661-1820','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 16:32:54',0,NULL,5,0,18,0,NULL,'indexpinc\r'),(996,763808146012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.5,'eastar4uk','reonwai','reon_nite4ever@hotmail.com','Sai Wah Wai','apt27 mckee ave heath square dublin11 ireland','Finglas','Dublin','IRELAND','11','0871638824','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 16:42:01',0,NULL,3,0,3,1,NULL,'reonwai\rRELO002\rRA022492576CN\r\\'),(997,685912669011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','jbrady9999','jimrbrady@gmail.com','James Brady','3036 Thrushwood Dr','Austin','TX','UNITED STATES','78757','(512) 657-6106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 17:12:32',0,NULL,3,0,1,1,NULL,'jbrady9999、'),(998,0,320676730064,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','ricca1997','rsavarese1@comcast.net','RICCARDO SAVARESE','1 Edgewood Dr','pittsgrove','NJ','UNITED STATES','08318-4189','(856) 521-0303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 17:28:33',0,NULL,3,0,1,1,NULL,'ricca1997\r\\'),(999,515061733003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','chris291176','axoumissa@yahoo.gr','Christoforos Papasavvas','Agiou Haralambous 10A Lakatamia','Nicosia','','CYPRUS','2334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:42:13',0,NULL,3,0,3,1,NULL,'chris291176\rOTGR001\rRA022492620CN\r\\'),(1000,763847510012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','pra15bcoy','norman.laird@googlemail.com','Norman Laird','Broombank<br>Mintlaw','Peterhead','Aberdeenshire','UNITED KINGDOM','AB424ET','01771623044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 17:58:30',0,NULL,3,0,3,1,NULL,'pra15bcoy\rOTCN002\rRA022492562CN\r\\'),(1001,566248759013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','ryangosson','rsgosson@lakeheadu.ca','Ryan Gosson','196 Princess Street<br>Apt. 4','Saint John','NB','CANADA','E2L2N8','(506) 977-1418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:00:22',0,NULL,3,0,2,1,NULL,'ryangosson\r\\'),(1002,566253444013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.85,'eastar4','jenzek','jenz.ek@gmail.com','Jenz Ek','Blystigen 6C','Falun','SE','SWEDEN','79156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:06:24',0,NULL,3,0,2,1,NULL,'jenzek\r\\'),(1003,520889659004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','sar2t','sarthost@gmail.com','Andrei Zlotnikau','Checherskaya 29-16','Gomel','','BELARUS','246038','375336831313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:31:17',0,NULL,3,0,3,1,NULL,'sar2t\rHSPL001\rRA022492580CN\r\\'),(1004,763888507012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','rmcleskey','ryanmcleskey@yahoo.com','Ryan McLeskey','426 Eagle Dr','Ione','CA','UNITED STATES','95640','(209) 337-8548','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:08:03',0,NULL,3,0,1,1,NULL,'rmcleskey、'),(1005,566286450013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',2,'WLAT001',29.98,'eastar4','brenoalbuquerque','brenoemaria@hotmail.com','breno albuquerque','Oscar Gomes Moreira Junior n°890','Uberlândia','Minas Gerais','BRAZIL','38412-044','+553432369785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 19:23:20',0,NULL,3,0,2,1,NULL,'brenoalbuquerque\r\\'),(1006,0,320674543993,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','chubbs2','jenbob10@ptd.net','robert mcneal','141 Millers Gap Rd','marysville','PA','UNITED STATES','17053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:47:29',0,NULL,3,0,1,1,NULL,'chubbs2、'),(1007,687490917011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','nan-marge','dsmith7018@yahoo.com','Danny Smith','24401 S Ribbonwood Dr','Sun Lakes','AZ','UNITED STATES','85248-7749','(734) 775-4344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:01:20',0,NULL,3,0,1,1,NULL,'nan-marge、'),(1008,520930171004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',2,'HSNO009',31,'cnfaner','micanco1970','micanco@inwind.it','Michelangelo Ancona','Piazza Vittorio Emanuele, 30','Bari-Loseto','BA','ITALY','70129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:05:30',0,NULL,3,0,3,1,NULL,'micanco1970\r欧标   HSNO009\r\rRA117710466CN\r\\'),(1009,520929753004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','jcase212','j.case14@yahoo.com','Jeff Case','557 Enright Ave','Cincinnati','OH','UNITED STATES','45205-2132','(513) 498-3203','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 20:09:22',0,NULL,3,0,1,1,NULL,'jcase212、'),(1010,685200834011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sofiaquensel','sofiaquensel@hotmail.com','Sofia Quensel','Karinsgatan 20','Malmö','','SWEDEN','21459','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:20:30',0,NULL,3,0,2,1,NULL,'sofiaquensel\r\\'),(1011,763955159012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','master_brett','master_brett@yahoo.com','Brett Davis','6421 Sunnybrook Dr','North Richland Hills','TX','UNITED STATES','76180','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:44:25',0,NULL,3,0,1,1,NULL,'master_brett\r美标\r、'),(1012,566321763013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','derrick910318','dr.derrick.t@gmail.com','Dominic Lai','Dom 39/1, K.12-13<br>Ulitsa Akademika Volgina','Moscow','Moscow','RUSSIAN FEDERATION','117437','9166202283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 20:48:30',0,NULL,3,0,2,1,NULL,'derrick910318\r\\'),(1013,763958202012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','doxie1','vaughn30577@yahoo.com','RICHARD VAUGHN','3311 Rooster Ln','Hiawassee','GA','UNITED STATES','30546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 20:51:55',0,NULL,3,0,1,1,NULL,'doxie1\r\\'),(1014,687534557011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','paperman_2008','paperman@realsilver.ru','Aleksey Kozlov','Perovskaya st., 58-131','Moscow','','RUSSIAN FEDERATION','111394','+79854106310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 21:21:23',0,NULL,3,0,2,1,NULL,'paperman_2008\r\\'),(1015,687138042011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tarheelborn1','tarheelborn1@yahoo.com','Alex Copple','2601 University Ave SE<br>Apt 230','minneapolis','MN','UNITED STATES','55414-3297','(763) 412-9393','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:01:27',0,NULL,3,0,1,1,NULL,'tarheelborn1、'),(1016,763995984012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','crmichelini','crmalpha2@hotmail.com','Christopher Michelini','5201 W County Road 400 N','Muncie','IN','UNITED STATES','47304-9049','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:06:25',0,NULL,3,0,1,1,NULL,'crmichelini\r\\'),(1017,566351217013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','heyyu223','johnyu@guess.com','JOHN YU','1444 S Alameda St','Los Angeles','CA','UNITED STATES','90021-2433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:10:46',0,NULL,3,0,1,1,NULL,'heyyu223\r\\'),(1018,764000869012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',23.85,'eastar4','mmapplebeck','mmapplebeck@gmail.com','Marc A. Mapplebeck','C/O City Animal Hospital Ltd<br>Devon Park Plaza','Fredericton','NB','CANADA','E3A 3N2','(506) 471-7044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:18:11',0,NULL,3,0,2,1,NULL,'mmapplebeck\r\\'),(1019,764001537012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','mcface5','evan.mcewen@gmail.com','Evan McEwen','180 Second Avenue','Ottawa','ON','CANADA','K1S 2H7','(613) 600-2958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:20:19',0,NULL,3,0,2,1,NULL,'mcface5\r\\'),(1020,687560112011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','kb9mzx','galenf2847@aol.com','Galen Fromm','11590 State Highway 107','Hamburg','WI','UNITED STATES','54411-9160','(414) 807-8976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 22:25:20',0,NULL,3,0,1,1,NULL,'kb9mzx、'),(1021,764043433012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','hyrchung','rchunghy@aol.com','Ronald Chung','Unit 107B, 1/F, Building 5, No.6 Science Park West Avenue<br>Shatin, Hong Kong','default','','HONG KONG','default','60216900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 00:37:18',0,NULL,3,0,2,1,NULL,'hyrchung\r\\'),(1022,566398190013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 01:35:15',0,NULL,3,0,2,1,NULL,'update_marcelo\r\\'),(1023,764066288012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','dogdude62','dogdude62@hotmail.com','William Perkins','115 Bragdon Rd','Freeport','ME','UNITED STATES','04032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 01:40:41',0,NULL,3,0,1,1,NULL,'dogdude62、'),(1024,521018877004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','alternatif2','stef98436@hotmail.com','Olivier Stephane','43 rue Dagobert','Candiac','QC','CANADA','J5R6E8','(450) 659-8297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 01:57:00',0,NULL,3,0,3,1,NULL,'alternatif2\rCRLO002\rRA022492488CN\r\\'),(1025,687637481011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','quandaar','quandaar@hotmail.com','Soren Fox','320 River St','Iowa City','Ia','UNITED STATES','52246-3531','(319) 541-3209','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 02:57:21',0,NULL,3,0,1,1,NULL,'quandaar、'),(1026,687639656011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','samdramtheory','mytheory@gmail.com','Valentin Kravtchenko','834 3e avenue','verdun','QC','CANADA','h4g2x6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 03:07:32',0,NULL,3,0,2,1,NULL,'samdramtheory\r、'),(1027,764094832012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','wjk350','bluwil@aol.com','Willie Kirby','350 Sinbad Ave','Opa Locka','FL','UNITED STATES','33054','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 03:23:38',0,NULL,3,0,1,1,NULL,'wjk350、'),(1028,764097171012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ppacciardi','ppacciardi@aol.com','Pierluigi Pacciardi','6891 Kenyon Ave','Hesperia','CA','UNITED STATES','92345-7268','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 03:31:13',0,NULL,3,0,1,1,NULL,'ppacciardi'),(1029,764108909012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 04:26:39',0,NULL,3,0,2,1,NULL,'grandizom\r、'),(1030,515238299003,130489927197,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'cnfaner','deniseism','denisemccooey@comcast.net','denise mccooey','4504 Somerset Ln','kent','WA','UNITED STATES','98032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 05:31:20',0,NULL,3,0,1,1,NULL,'deniseism\r、'),(1031,515239849003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','rsletters','skletters@yandex.ru','Konstantin Strukov','dom.39 kv.21<br>Naro-Fominskie raion','pos.Selyatino','Moskovskaya oblast','RUSSIAN FEDERATION','143345','+79169558544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 05:45:10',0,NULL,3,0,3,1,NULL,'rsletters\rRA022492341CN\r\\'),(1032,566448144013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',43.98,'eastar4','brvclickhit2009','clickhit2009@yahoo.com','Budiman Rubia Viqih','Jl. Margonda Raya, Gg. H. Fatimah, Kemiri Muka, RT.002 RW.011<br>No.11A / 1A, Beji','Depok','Jawa Barat','INDONESIA','16423','085693133939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 06:38:14',0,NULL,3,0,3,1,NULL,'brvclickhit2009\rRA022492267CN\r\\'),(1033,684734671011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',8,'CASS003',69.6,'eastar4','anjanaelzabeth','gigivikraman@gmail.com','Gigi Vikraman','Al Dana Centre,410<br>Maktoum Road','Deira','Dubai','UNITED ARAB EMIRATES','64329','00971-559454771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 06:48:32',0,NULL,3,0,3,1,NULL,'anjanaelzabeth\rRA022492324CN\r\\  '),(1034,764145481012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','matoupri','matoupri@free.fr','Damien MATHEY','27 rue du pont tournant','LES FORGES','Lorraine','FRANCE','88390','03.29.35.74.74','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 07:35:28',0,NULL,3,0,3,1,NULL,'matoupri\rOTRA002\rRA117710364CN\r\\'),(1035,687690848011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',3,'OTCN002',11.97,'eastar4','gi-zu-ex','nathan-hein@wanadoo.nl','Neddim Hein','Suze Groenewegstraat 53','Tiel','','NETHERLANDS','4003ZT','0628294329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 07:42:56',0,NULL,3,0,2,1,NULL,'gi-zu-ex\r、'),(1036,764148606012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','rob_keeling','rob@rjkeeling.co.uk','Rob Keeling - Queen Elizabeth`s Grammar School','The Green Road','Ashbourne','Derbyshire','UNITED KINGDOM','DE6 1EP','01335343685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 07:49:01',0,NULL,3,0,3,1,NULL,'rob_keeling\rOTCN004*10\rRA117710276CN\r'),(1037,515258138003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','angelo*andrzej','andrew1863@poczta.fm','Andrzej Tkacz','Gajowa 1/11','Częstochowa','śląskie','POLAND','42200','34 3662202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:25:41',0,NULL,3,0,3,1,NULL,'angelo*andrzej\r欧标\rHSNO016\rRA117710165CN\r'),(1038,687337151011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:48:09',0,NULL,3,0,2,1,NULL,'nord975'),(1039,520806420004,140428311581,'2.1 Acer Aspire 9410 bluetooth module we offer track#',1,'BTAC2108',16.59,'cnfaner','jlpitre','jeanlou.pitre@gmail.com','Jean-Lou Pitre','609 Canso St., Apt 1','Dieppe','NB','CANADA','E1A 2A3','(506) 860-3471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 10:09:56',0,NULL,3,0,3,1,NULL,'jlpitre\racer 4pin1.25 18cm\rBTAC2108\rRA117710174CN\r\\'),(1040,521090874004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','darkkevind','darkkevind@hotmail.com','Kevin Dark','Riverside House, 4 Walls Yard<br>South Street','Rochford','Essex','UNITED KINGDOM','SS4 1GR','07813335117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 10:18:00',0,NULL,3,0,3,1,NULL,'darkkevind\rWWSI005\r\rRA117710510CN\r\\'),(1041,521102464004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','dr.wael-galal','wgalal@yahoo.com','Dr. Wael Galal Mostafa','King Fahad Hospital, B.O.Box: 204<br>Anesthesia Department, OR (3rd floor)','Al-Baha','Al-Baha','SAUDI ARABIA','65411','+966595788630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:28:41',0,NULL,3,1,3,1,NULL,'dr.wael-galal\rHSPL001\rRA117710347CN'),(1042,764205446012,220692197062,'IBM Ericsson F3507G 3G WWAN card+antenna FRU43Y6513',1,'WWOT002+ANCN001',73.9,'eastar4','naransula','burakbeyhan@yahoo.com','Burak Beyhan','Mersin Universitesi, Mimarlik Fakultesi<br>Ciftlikkoy Kampusu, Yenisehir','Mersin','','TURKEY','33343','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:45:29',0,NULL,5,0,18,0,NULL,'naransula'),(1043,687751403011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hinoi_jane1983','m.tonkin@ntlworld.com','Hinoi Tonkin','43 Wilton Way<br>Grangetown','Middlesbrough','Cleveland','UNITED KINGDOM','TS67QP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:50:57',0,NULL,3,0,2,1,NULL,'hinoi_jane1983'),(1044,764233621012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','pdsh7190','pj_1345@yahoo.com','Peter O\'Neill','1345 Old Black Horse Pike','Blackwood','NJ','UNITED STATES','08012-4734','(856) 228-7190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 12:57:10',0,NULL,3,0,1,1,NULL,'pdsh7190'),(1045,687772017011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','123-roudoudou','eric.plazen@laposte.net','PLAZEN eric','lieu-dit BERGERAT','MONTJOIE en Couserans','Midi-Pyrénées','FRANCE','09200','0561048793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 12:59:50',0,NULL,3,0,2,1,NULL,'123-roudoudou'),(1046,687775656011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','ltkoscianski','lkoscianski@ecmacservices.com','Larry Koscianski','2047 S Park Dr<br>Eastern Carolina Macservices Ste B','Winterville','NC','UNITED STATES','28590-9936','(252) 353-6227','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 13:11:17',0,NULL,3,0,1,1,NULL,'ltkoscianski'),(1047,0,320676726450,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','skip-br','skip.br@gmail.com','Ricardo Takahashi','Rua Rio Amazonas, 27','São Paulo','São Paulo','BRAZIL','08041-260','55 11 6153-9052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:48:44',0,NULL,3,0,3,1,NULL,'skip-br\rRA117710320CN\r\r'),(1048,515344180003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','anton.mingazov','a.mingazov@gmail.com','Anton Mingazov','Chkalova 11-18','Dzerginsk','Nijegorodskaya obl','RUSSIAN FEDERATION','606000','+79625180963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 15:41:47',0,NULL,3,0,3,1,NULL,'anton.mingazov\rWWSI005+ANCN001\r\rRA117710568CN\r\\'),(1049,566567728013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','zzubr','eshgin@gmail.com','Eshgin Mammadov','Tabriz 83<br>flat(manzil)7','Baku','BAKU','AZERBAIJAN','az1072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 16:23:06',0,NULL,3,0,2,1,NULL,'zzubr'),(1050,687852284011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','osudonkey','colinbwebb@gmail.com','Colin Webb','11805 Woodbridge Rd','Oklahoma City','OK','UNITED STATES','73162-3218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 16:47:08',0,NULL,3,0,1,1,NULL,'osudonkey'),(1051,764055070012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','501robert1976','rob_williams76@yahoo.com','robert williams','299 Fox Chase Dr','greers ferry','AR','UNITED STATES','72067-8501','(501) 825-8944','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 17:37:24',0,NULL,3,0,1,1,NULL,'501robert1976'),(1052,520781241004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','i100nets','sreiner@gmail.com','Vladimir Shreiner','Torujoe 21-1','Kohtla-Jarve','Ida-Virumaa','ESTONIA','30323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 18:10:50',0,NULL,3,0,3,1,NULL,'i100nets\rWWSI005\r\rRA117710571CN\r\\'),(1053,521202262004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','newcom8','newcomer39@hotmail.com','Thomas Newcomer','21338 Lynn Dr','Lexington park','MD','UNITED STATES','20653','(301) 862-4589','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 18:15:28',0,NULL,3,0,1,1,NULL,'newcom8'),(1054,687886776011,320575306082,'New Atheros DualBand AR9287 Wireless AGN 300M Half Card',1,'WLAT007',14.95,'eastar4','666mimi999','mimikoca@yahoo.com','Dhimiter Koca','Rruga \"Myslym Shyri\" Nr.134 Tirane','Tirane','','ALBANIA','134','0355683093207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 18:23:49',0,NULL,3,0,2,1,NULL,'666mimi999'),(1055,520985763004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','707ginger2','ldecota@cssara.org','Lynne DeCota','412 Adobe Canyon Rd','Kenwood','CA','UNITED STATES','95452','(707) 833-2013','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 18:27:48',0,NULL,3,0,1,1,NULL,'707ginger2'),(1056,687911402011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','andrewns240','andrewns@gmail.com','Andreas Saltos','118 N Howard St<br>Apt 515','Baltimore','MD','UNITED STATES','21201-3431','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 18:55:01',0,NULL,3,0,1,1,NULL,'andrewns240'),(1057,566627546013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','ediiazcos','ediazcos@gmail.com','Edgar A. Díaz Cosme','Arquimedes 202 #702<br>Colonia Polanco Reforma','Miguel Hidalgo','Distrito Federal','MEXICO','11550','555-255-1568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:08:40',0,NULL,3,0,2,1,NULL,'ediiazcos'),(1058,764399851012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','its_od','andrew.odonnell00@gmail.com','Andrew O\'Donnell','16 RATHMINES PARK','RATHMINES','DUBLIN','IRELAND','6','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 19:22:23',0,NULL,3,0,3,1,NULL,'its_od\rRA117710404CN\r'),(1059,521231325004,140490658273,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',42.99,'cnfaner','dimon1981saler','dimandroid1981@gmail.com','Dmitriy Larchenko','Molodeghnaya, house 9, flat 35','Fryanovo','Moscow region, Shchelkovo district','RUSSIAN FEDERATION','141147','+79653390298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:30:23',0,NULL,3,0,3,1,NULL,'dimon1981saler\rwwsi004+ancn001\rRA117710333CN\r'),(1060,521233867004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','ingylevi','andyng31@hotmail.com','andrew ng','72 Kingsway,Newton','chester','Cheshire','UNITED KINGDOM','CH2 2LL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:37:47',0,NULL,3,0,3,1,NULL,'ingylevi\rOTRA002\rRA117710381CN\r'),(1061,515424231003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',2,'HSNO019+CCNO001',89.98,'cnfaner','pedro50321','tompaul@netcologne.de','Tom Paul','Franz-von-Kempis-Weg 1','Bornheim','','GERMANY','53332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:39:19',0,NULL,3,0,3,1,NULL,'pedro50321\rHSNO019+CCNO001\rRA117710316CN\r\\'),(1062,764450152012,220682002486,'2.1 Acer Aspire 5338 5536 5236 Bluetooth Module +cable',1,'BTAC2105',16.59,'eastar4','cbservers','zarth@nepeanvalley.com.au','Sharon Zarth','12 Jular Place','Jamisontown','New South Wales','AUSTRALIA','2750','0402876310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 20:25:04',0,NULL,3,0,2,1,NULL,'cbservers\racer 4pin1.25 8cm '),(1063,687999688011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','dutchiechrissie','ebay@van-munster.com','Chris van Munster','De Beumkes 6','Rijssen','','NETHERLANDS','7462 pv','+31 548542344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 21:24:09',0,NULL,3,0,2,1,NULL,'dutchiechrissie'),(1064,764494253012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','spartaah','xz32@hotmail.com','Alejandro Castellanos','18 calle 31-32<br>zona 7 Villa Linda 2','Guatemala','Guatemala','GUATEMALA','01007','(502) 400-6668 ext.: 9','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 21:47:11',0,NULL,3,0,2,1,NULL,'spartaah'),(1065,688019998011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','lesliesol','leslie@solengineering.com','Leslie Howard','2831 Camino Del Rio S<br>Ste 109','San Diego','CA','UNITED STATES','92108-3827','(619) 270-8539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 22:13:44',0,NULL,3,0,1,1,NULL,'lesliesol'),(1066,521289000004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','hermano2020','hermano2020@verizon.net','Herman C McCrea','1759 N Dover St','Philadelphia','PA','UNITED STATES','19121','(215) 765-2485','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:25:56',0,NULL,3,0,1,1,NULL,'hermano2020'),(1067,764513622012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','dk_schneider','schneider.heating@rogers.com','Kaisa Schneider','141 Rebecca St','Stratford','ON','CANADA','N5A 3P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 22:33:31',0,NULL,3,0,2,1,NULL,'dk_schneider'),(1068,566543009013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','mrd169','jeremy.furman@gmail.com','Jeremy Furman','1050 Lenox Park Blvd<br>Apt 17106','Atlanta','GA','UNITED STATES','30319','(352) 281-1220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 22:39:07',0,NULL,3,0,1,1,NULL,'mrd169'),(1069,521292089004,140515704012,'New GENUINE NOKIA HS-36W  BLUETOOTH HEADSET track#',1,'HSNO026',15.5,'cnfaner','mickey7034','kapoormickey123@yahoo.com','mickey','5418 cleveland hwy','cohutta','GA','UNITED STATES','30710-9510','(404) 966-6822','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:39:41',0,NULL,3,0,1,1,NULL,'mickey7034'),(1070,0,230601698326,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',32.49,'eastar4','universalmajor1970','javierx7@gmail.com','Javier Andres Manriquez Gebert','El Escorial 370 depto 603','Temuco','Novena Region de la Araucania','CHILE','n/a','0056997317446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 22:45:26',0,NULL,3,0,3,1,NULL,'universalmajor1970\rOTRA002\rRA117710395CN\r\\'),(1071,515483815003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',41.99,'cnfaner','szogun80','szogun80@hotmail.com','SLAWOMIR SOKOLSKI','7307 W MONTROSE AVE','NORRIDGE','IL','UNITED STATES','60706-1157','(773) 627-9839','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 22:48:52',0,NULL,3,0,1,1,NULL,'szogun80'),(1072,688034933011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','uniquerican23','emmanuelruiz81@hotmail.com','emmanuel ruiz','3204 vermeer dr','virginia beach','VA','UNITED STATES','23453-3062','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-29 22:58:42',0,NULL,3,0,1,1,NULL,'uniquerican23'),(1073,764528749012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','duckman1221','duckman1221@gmail.com','Chris Duckett','532 S Hardy Ave','Independence','MO','UNITED STATES','64053-1508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 23:16:07',0,NULL,3,0,1,1,NULL,'duckman1221'),(1074,688043360011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fbarini','fabianobarini@hotmail.com','Fabiano Barini','Av. Rio Branco, 217 / 227','Franca ','Sao Paulo','BRAZIL','14405-080','(16) 3721-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 23:27:26',0,NULL,3,0,2,1,NULL,'fbarini'),(1075,521305707004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','manticdk','liljekrans@gmail.com','Danni Liljekrans','Døgnposten 657 / ID: 51801803','Odense M','Denmark','DENMARK','5230','004551801803','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-29 23:51:11',0,NULL,3,0,5,1,NULL,'manticdk\rCP226344785CN\r'),(1076,764554400012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','thanz','jmthanz@yahoo.com','jonathan mariano','DepEd, Pagadian City Division<br>San Jose Heights','pagadian city','zamboanga del sur','PHILIPPINES','7016','9298438569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 00:40:56',0,NULL,3,0,2,1,NULL,'thanz'),(1077,566737845013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','yaboy1956','buenterprises@yahoo.com','Alvin Wright','8448 Crossland Loop<br>Ste 142','Montgomery','AL','UNITED STATES','36117-0951','(334) 649-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 01:10:34',0,NULL,3,1,1,1,NULL,'yaboy1956'),(1078,566745545013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 01:48:45',0,NULL,3,0,3,1,NULL,'update_marcelo\rWWSI005\r\rRA117710599CN\r\\'),(1079,566768672013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','grisho69','grisho69@hotmail.com','Grigor Georgiev','61 DELLBROOK CRES.','TORONTO','ON','CANADA','M9L 1E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:45:00',0,NULL,3,0,2,1,NULL,'grisho69\r\\'),(1080,764614653012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','bettiesbaby','misscreek@sbcglobal.net','Nicole Creek','1440 S Curson Ave','Los Angeles','CA','UNITED STATES','90019-3804','(323) 692-9298','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 04:13:20',0,NULL,3,0,1,1,NULL,'bettiesbaby\r\\'),(1081,688117516011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','konstk_2009','konstk@yandex.ru','Konstantin Krivonogov','Samarskaya oblast\'<br>Sverdlova 14 - 99','Togliatti','','RUSSIAN FEDERATION','445039','79272167459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:17:22',0,NULL,3,0,2,1,NULL,'konstk_2009\r\\'),(1082,764614838012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',69.9,'eastar4','qebex','jazzaddict@gmail.com','CHENG PENG YU','16/170 High Street','Northcote','Victoria','AUSTRALIA','3070','0433641085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:17:22',0,NULL,3,1,3,1,NULL,'qebex\rWWOT002\rRA117710418CN\r\r'),(1083,764623557012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',3,'SCLO002',16.5,'eastar4','vjreeves1','vernon.reeves@att.net','Vernon Reeves','910 Willow Brook Dr','Allen','TX','UNITED STATES','75002-2317','(214) 240-6088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 05:00:24',0,NULL,3,0,1,1,NULL,'vjreeves1\r\\'),(1084,566789790013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','luckyluckyoye','rattan3000@gmail.com','Jagdeep Rattan','28 Giraffe Ave.','Brampton','ON','CANADA','L6R1Y9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:22:15',0,NULL,3,0,2,1,NULL,'luckyluckyoye\r\\'),(1085,764642857012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','demaupassant','jbiggs@userealsugar.com','Josh Biggs','2901 McIntosh Dr','Longmont','CO','UNITED STATES','80503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 06:39:24',0,NULL,3,1,1,1,NULL,'demaupassant\r美标\r\\'),(1086,764643534012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','2009firebull77','agsanchez@live.com','Andrés García','monasterio de yuste n10','valladolid','Castilla y León','SPAIN','47015','667289115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:48:27',0,NULL,3,1,2,1,NULL,'2009firebull77\r\\'),(1087,566791731013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',12.88,'eastar4','grayeagle097','grayeagle@rnsmte.com','Bill Davis','234 FR 512','Young','AZ','UNITED STATES','85554','(928) 462-3886','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 06:48:49',0,NULL,3,1,1,1,NULL,'grayeagle097\r华硕 8pin 1.0 6cm\r\\'),(1088,566800380013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ericlansky','erickamsky@gmail.com','Eric Vladimirsky','2700 Cahuenga Blvd E<br>Apt 3109','Los Angeles','CA','UNITED STATES','90068-2103','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 07:34:43',0,NULL,3,1,1,1,NULL,'ericlansky\r\\'),(1089,759216196012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bachta_cz','jbachtik@seznam.cz','Stepan Bachtik','Jircharska 46','Zelezny Brod','','CZECH REPUBLIC','46822','+420775706593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 08:46:42',0,NULL,3,1,2,1,NULL,'bachta_cz\\'),(1090,688176554011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',14.49,'eastar4','petobalazs1975','petobalazs@citromail.hu','Balazs Petö','Forggensee str. 78','Schwangau','','GERMANY','87645','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:15:58',0,NULL,3,0,2,1,NULL,'petobalazs1975\racer 4pin1.25 15cm\\ '),(1091,566818309013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','tooqayer','mulenkov@gmail.com','Il\'ya Mulenkov','10 Grodnenskaya Str. App.20','Moscow','RU','RUSSIAN FEDERATION','121471','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:26:59',0,NULL,3,1,2,1,NULL,'tooqayer\\'),(1092,688186219011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeff3yan3','jeff3yan@gmail.com','Jeffrey Yan','50 Wilmay avenue<br>Papatoetoe','Auckland','','NEW ZEALAND','2025','+64211589611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 09:54:59',0,NULL,3,1,2,1,NULL,'jeff3yan3\r\\'),(1093,688193629011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','peccator1988','peccatorr@gmail.com','Сергей Кузнецов','ул. Стельмаха, дом №40<br>Stelmaha street, house № 40','Одесса','','UKRAINE','65006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:25:05',0,NULL,3,1,2,1,NULL,'peccator1988\r\\'),(1094,764705830012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',10,'HSMO011',99.9,'eastar4','nanjopas','pgarceau@sogetel.net','Pascal Garceau- Dist Toiture Mauricienne','555 St-Malo','Trois-Rivieres','QC','CANADA','G8V 0A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:53:08',0,NULL,3,1,3,1,NULL,'nanjopas\rHSMO011\rRA117710554CN\r、'),(1095,688206684011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','celery_crunch','bluecontour@gmail.com','Joy H.','26 Raymond St<br>Eastwood','Sydney','New South Wales','AUSTRALIA','2122','0298763214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:11:58',0,NULL,3,1,2,1,NULL,'celery_crunch\r\\'),(1096,688207187011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','erik_fra_oslo','erikjahren1@hotmail.com','Erik Jahren','Hallings Gate 5','Oslo','','NORWAY','0170','004797041597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:13:29',0,NULL,3,1,2,1,NULL,'erik_fra_oslo\r\\'),(1097,764714227012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','kittychow','sonshines14@gmail.com','Shirley Ann Loomis','5729 Main St<br># 181','Springfield','OR','UNITED STATES','97478-5426','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 11:22:45',0,NULL,3,1,1,1,NULL,'kittychow\r、'),(1098,515606422003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',3,'HSPL005',40.74,'cnfaner','*****power','huseyincelik-25@hotmail.com','MERYEM ÇELİK','NAMIK KEMAL MAH.CENGIZ TOPEL CD<br>TURBEDAR SOKAK.NO:12-3','ÜMRANİYE-STANBUL','','TURKEY','34765','5359872000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 11:26:59',0,NULL,3,1,3,1,NULL,'*****power\r欧标\rHSPL005\rRA117710642CN\r\\'),(1099,521423929004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.76,'cnfaner','imranabid2010','imranabids@yahoo.com','imranabid safi','84 frank towell court,<br>glebelands road','london','Middlesex','UNITED KINGDOM','tw14 9bw','07946853716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:05:50',0,NULL,3,1,3,1,NULL,'imranabid2010\rHSPL001\rRA117710625CN\r\\'),(1100,688219663011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',29.99,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','+380674097000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:15:55',0,NULL,3,1,2,1,NULL,'germanskynet\rHP 5pin1.0 20cm\r\\'),(1101,688226547011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','kubik106','nosleeep@gmail.com','Jakub Nespala','AGEM Computers s.r.o.<br>Panonska 42','Bratislava','','SLOVAK REPUBLIC','85101','00421903850370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:18:52',0,NULL,3,1,2,1,NULL,'kubik106\r\\'),(1102,566863518013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','modestadt2010','ted.gaier@gmx.de','Karsten Etz','Karolinger Str. 23','Düsseldorf','','GERMANY','40223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:08:42',0,NULL,3,1,2,1,NULL,'modestadt2010\r\\'),(1103,764758376012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','madmax71470','cralling@thework-shop.com','Craig Alling','22 Sherwood Ave','Derby','CT','UNITED STATES','06418','(203) 732-1055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 13:34:01',0,NULL,3,1,1,1,NULL,'madmax71470\r、'),(1104,688266167011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',4,'RELO002',51.96,'eastar4','crayon1226','peteryick@hotmail.com ','Peter Yick','76 Windsor Ave<br>Croydon Park','Sydney','New South Wales','AUSTRALIA','2133','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:27:15',0,NULL,3,1,3,1,NULL,'crayon1226\rRELO002\rRA117710639CN\r\\'),(1105,521455756004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','jjrbvba','info@jjr.be','John Vande Kerckhove','Wespelaarsebaan 126B','Boortmeerbeek','','BELGIUM','3190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:31:14',0,NULL,3,1,3,1,NULL,'jjrbvba\rANYA001\rRA117713136CN\r\\'),(1106,566893299013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','mlo2012','tu_padre_yo_2009@hotmail.com','Mario Lopez','137 Shirley ave<br>Apt 2','Revere','MA','UNITED STATES','02151-3240','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 15:05:22',0,NULL,3,1,1,1,NULL,'mlo2012\racer 4pin1.25 15cm\r、'),(1107,688278411011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','yerachmiel70','neal.fridman@gmail.com','Neal Fridman','4602 Beaconsfield Ct','Toledo','OH','UNITED STATES','43623-3205','(419) 407-7607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 14:55:25',0,NULL,3,1,1,1,NULL,'yerachmiel70\rapple USB 猫 旧 2针 旧的\r\\'),(1108,521472872004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:32:56',0,NULL,8,1,17,0,NULL,'jaggapan2533'),(1109,521475709004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:43:32',0,NULL,8,1,17,0,NULL,'jaggapan2533'),(1110,521476388004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','jaggapan2533','juggapanke@gmail.com','jaggapan panyosaranya','59/269 Moo. 16 Srinakarin Road,<br>Tombon Bangkaew','Bangplee','Samutprakan','THAILAND','10540','(66)817507855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:45:33',0,NULL,3,1,3,1,NULL,'jaggapan2533\r再发两个New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET\rHSPL011+HSPL001*2\rRA117710611CN\r\\'),(1111,764813769012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','tigerwgn','jballenger@hkaa.com','John Ballenger','PO Box 860<br>337 Spartangreen Blvd.','Duncan','SC','UNITED STATES','29334','(864) 617-1412','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 15:52:05',0,NULL,3,1,1,1,NULL,'tigerwgn\r、'),(1112,521477061004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','conniejesse','connie_rodriguez79@yahoo.com','Connie Rodriguez','20101 Hamilton Ave<br>Ste 200','Torrance','CA','UNITED STATES','90502-1371','(310) 800-9251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 15:52:55',0,NULL,8,1,17,0,NULL,'conniejesse'),(1113,515672242003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','barujy','barujcohen@gmail.com','Baruch Cohen','Harav Uziel 9/7<br>Bait Vagan','Jerusalem','DC','ISRAEL','96423','972-54-7893198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 16:10:09',0,NULL,3,1,3,1,NULL,'barujy\rHSPL005\rRA117710483CN\r\\'),(1114,686316975011,320676244896,'New Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','paul-567','paul_saper@hotmail.com','Paul Saper','Osloer Straße 5','Köln','','GERMANY','50765','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 16:27:18',0,NULL,3,1,2,1,NULL,'paul-567\r\\'),(1115,521510676004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','nenadprenenad','nenadpre@gmail.com','Nenad Preradovic','Dolgovaske gorice 242 a','Lendava','','SLOVENIA','9220','0038640818531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 17:40:18',0,NULL,3,0,3,1,NULL,'nenadprenenad\rOTCR001\rRA117710545CN\r、'),(1116,521516296004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','conniejesse','connie_rodriguez79@yahoo.com','Connie Rodriguez','20101 Hamilton Ave<br>Ste 200','Torrance','CA','UNITED STATES','90502-1371','(310) 800-9251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 17:57:02',0,NULL,3,1,1,1,NULL,'conniejesse\r一共买了两个\r\\'),(1117,764898498012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','mattbakerdesigns','mattbakerdesigns@hotmail.com','matt baker','2837 NW 6th Ter','cape coral','FL','UNITED STATES','33993','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 18:32:35',0,NULL,3,1,1,1,NULL,'mattbakerdesigns\r、'),(1118,764902326012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','tocutenva09','tocutenva@aol.com','CRYSTAL SIMMONS','751 BRAKE RD','ELLISTON','VA','UNITED STATES','24087-4429','(540) 588-4423','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 18:39:31',0,NULL,3,1,1,1,NULL,'tocutenva09\r、'),(1119,521463920004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','danielandkristitoms1002','danielandkristitoms@yahoo.com','Kristi Toms','409 Jey Dr','Elizabethtown','KY','UNITED STATES','42701-4207','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 18:45:16',0,NULL,3,1,1,1,NULL,'danielandkristitoms1002\r、'),(1120,521542486004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','bradleys112200','angel@inn-serve.com','Angel Bradley','512 22nd Ave<br>Citizens National Bank Building Ste 513','Meridian','MS','UNITED STATES','39301-5800','(601) 686-0208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 19:05:31',0,NULL,3,1,1,1,NULL,'bradleys112200\r、'),(1121,688405444011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','robantsto','robstorino@yahoo.com','Robert Storino','19121 Allison Square','West Windsor','NJ','UNITED STATES','08550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:19:56',0,NULL,3,1,1,1,NULL,'robantsto\r、'),(1122,764944947012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','music4ever22','unlcornhusker4life@yahoo.com','Erica Bell','13091 Potter st','omaha','NE','UNITED STATES','68142-1528','(402) 502-5205','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:43:59',0,NULL,3,1,1,1,NULL,'music4ever22'),(1123,764949750012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','gerard3380','gerard_lynott@hotmail.com','Gerard Lynott','15084 Jupiter Hills Ln','Haymarket','VA','UNITED STATES','20169-3133','(703) 472-8269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:52:28',0,NULL,3,1,1,1,NULL,'gerard3380\r、'),(1124,521562005004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','vtbog','morfar@mail.ru','Valery Bogdanov','Leninskij pr. 93-2-322','Saint-Petersburg','','RUSSIAN FEDERATION','198330','+7-911-967-18-93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 19:53:20',0,NULL,3,1,3,1,NULL,'vtbog\r欧标   HSNO022\rRA117710537CN\r\\'),(1125,764955356012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','caja7558','caja7558@aol.com','RICHARD FAYSON','29 E Constitution Dr','SMYRNA','DE','UNITED STATES','19977-4061','(302) 494-0144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 19:59:51',0,NULL,3,1,1,1,NULL,'caja7558\r、'),(1126,567025164013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wasatch84103','pleo84103@yahoo.com','Paul Leo','26 Juego Rd','Santa Fe','NM','UNITED STATES','87508-4298','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 21:00:12',0,NULL,3,1,1,1,NULL,'wasatch84103\r、'),(1127,567036636013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ni_mohr','kiar_mohr@ukr.net','Oleksiy Onyshchenko','27, Kopernyka str., ap. 22','Kyiv','','UKRAINE','04116','+380 (50) 4499092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 21:33:22',0,NULL,3,1,2,1,NULL,'ni_mohr\r\\'),(1128,765011255012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 21:36:50',0,NULL,3,1,2,1,NULL,'vasileioslos\r欧标\r\\'),(1129,688483915011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',8,'CASS003',69.6,'eastar4','m660xyg','huwdw@hotmail.com','Mr Huw Watkins','Old Post Office<br>LLangawsai','Aberystwyth','Ceredigion','UNITED KINGDOM','sy231HD','01970627769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 21:44:59',0,NULL,3,1,3,1,NULL,'m660xyg\rCASS003\rRA117710656CN\r\\'),(1130,765027572012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','csl-racer','csl-racer@gmx.de','Eric Tierling','In der Meffert 37','Leichlingen','','GERMANY','42799','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:13:12',0,NULL,3,1,2,1,NULL,'csl-racer\r欧标\r\\'),(1131,684176622011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jfbimkiii','jfbimkiii@hotmail.com','JF Bienvenu','2190 Gertrude','Carignan','QC','CANADA','j3l4h1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:16:58',0,NULL,3,1,2,1,NULL,'jfbimkiii\r\\'),(1132,567049766013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','ahmed873','abdel._@msn.com','Abdelhak Hamrioui','De Terp 19','Veenendaal','Utrecht','NETHERLANDS','3905AK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:19:57',0,NULL,3,1,2,1,NULL,'ahmed873\racer 4pin1.25 15cm\r\\'),(1133,765029799012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','jjjmac75','jjjmac75@aol.com','James J McGuire','1923 Limestone Dr','Hummelstown','PA','UNITED STATES','17036-7073','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 22:33:11',0,NULL,3,1,1,1,NULL,'jjjmac75\racer 6pin1.25 23cm \r、'),(1134,567060058013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',21.98,'eastar4','ranbito26','ranbito26@yahoo.com','Arsenia','304 Smith st','New BedFord','MA','UNITED STATES','02740','(508) 525-2636','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 23:08:37',0,NULL,3,1,1,1,NULL,'ranbito26\r、'),(1135,765050338012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','revkelley','revkelley1@yahoo.com','Adam Kelley','261 Parker Farms Rd','wallingford','CT','UNITED STATES','06492-2858','(203) 823-3969','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 23:20:47',0,NULL,3,1,1,1,NULL,'revkelley\r、'),(1136,567073697013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','phaoost','phaoost@gmail.com','Yevgeny Kosarzhevsky','111-41, vul. Lynkova','Minsk','N/A','BELARUS','220124','+375296700352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:05:40',0,NULL,3,1,2,1,NULL,'phaoost\r\\'),(1137,521636433004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','sssei2000','stevearhino@hotmail.com','Steve Lush','485 Grays rd. unit B','hamilton','ON','CANADA','L8E 2Z5','(905) 296-5834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:34:03',0,NULL,3,1,3,1,NULL,'sssei2000\rBALO007\rRA117710523CN\r\\'),(1138,521638684004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','087kappen','aljamol@rocketmail.com','SOPHY KURIAKOSE','APPT-61,MERRION VILLAGE<br>MERRION ROAD','BALLSBRIDGE','DUBLIN','IRELAND','4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:40:17',0,NULL,5,0,18,1,NULL,'087kappen\rHSNO017   英标  HSNO017\r黑色的  '),(1139,688549224011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','toxskitz1988','timlarsen@iprimus.com.au','Tim Larsen','3 Harman Close, Doncaster East','Melbourne','Victoria','AUSTRALIA','3109','0398464421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:21:41',0,NULL,3,1,2,1,NULL,'toxskitz1988\r\\'),(1140,688552036011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.8,'eastar4','xbadboy17','nigga4ever17@msn.com','marco duarte','newcomen rd<br>140','Bedworth','West Midlands','UNITED KINGDOM','CV12 0ep','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:30:21',0,NULL,3,1,2,1,NULL,'xbadboy17\rHP 8pin 0.8 3cm\r\\'),(1141,567092721013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','sbeivides','beividesb@yahoo.com','Benjamin Beivides','11907 Lesser St','Norwalk','CA','UNITED STATES','90650-4052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 01:36:48',0,NULL,3,1,1,1,NULL,'sbeivides\r、'),(1142,763538924012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',23.35,'eastar4uk','patg999','patg999@hotmail.com','Patrice Gagné','100 pie xii','chicoutimi','QC','CANADA','g7g 5h1','(418) 696-9550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 02:25:16',0,NULL,3,0,3,1,NULL,'patg999\rRA117710608CN\r\\'),(1143,567107505013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','swoosh1392','swoosh1325@yahoo.com','Kim Bussey','6415 Buckhead Ct','wesley chapel','FL','UNITED STATES','33545','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 02:41:44',0,NULL,3,1,1,1,NULL,'swoosh1392\r、'),(1144,567107694013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','applejpapple','691599206@qq.com','ping ji','22-1225 ouimet','montreal','QC','CANADA','h4l3p8','(514) 518-8876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 02:44:28',0,NULL,3,1,2,1,NULL,'applejpapple\r\\'),(1145,765126533012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','v.nowords','vkrylov@gmail.com','Volodymyr Krylov','#400-1632 Dickson Avenue','Kelowna','BC','CANADA','V1Y 7T2','(250) 859-9217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 03:51:10',0,NULL,3,1,3,1,NULL,'v.nowords\rWLIN012\rRA117710497CN\r\\'),(1146,688588720011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chrissena','chris_sena87@hotmail.com','Christopher Sena','1F2<br>12 Antigua Street','Edinburgh','City of Edinburgh','UNITED KINGDOM','EH1 3NH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 04:05:30',0,NULL,3,1,2,1,NULL,'chrissena\r\\'),(1147,567129875013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','yan011','yanivr@012.net','yaniv ramon','ehad haam 138/5','TEL AVIV','','ISRAEL','64253','+97256333521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 05:11:10',0,NULL,3,1,3,1,NULL,'yan011\rMOSA002\rRA117710470CN\r、'),(1148,688601221011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','preetdhillon84','ebay84@ymail.com','Preet Dhillon','78 McMahon Road','Reservoir','Victoria','AUSTRALIA','3073','0394021775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 05:15:34',0,NULL,3,1,2,1,NULL,'preetdhillon84\r澳标\r\\'),(1149,688612059011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','gospodin','gregs_mail@cox.net','Gregory S Davis','8617 E PIERCE ST','SCOTTSDALE','AZ','UNITED STATES','85257','(480) 941-9022','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 06:19:46',0,NULL,3,1,1,1,NULL,'gospodin\racer 4pin1.25 6cm\rLK035216515CN\r、'),(1150,765166337012,220501825899,'2.1 Acer Aspire 4720 4720G 4720Z Bluetooth Module+cable',1,'BTAC2115',12.8,'eastar4','evgeniy_simonov','seanet1@yandex.ru','Evgeniy Simonov','Morskaya nab. 35-3-17','Sankt-Petersburg','Sankt-Petersburg','RUSSIAN FEDERATION','199155','(931)2933748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:17:06',0,NULL,3,1,2,1,NULL,'evgeniy_simonov\racer 5pin1.25 20cm \r\\'),(1151,567148266013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','cdaccuphasee','cdaccuphase@yahoo.com.vn','Chau Sang Kinh','685/30/63 Xo Viet Nghe Tinh P26 Binh thanh','Ho chi minh','Ho chi minh','VIET NAM','70000','+84908196044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:35:17',0,NULL,3,1,2,1,NULL,'cdaccuphasee\r\\'),(1152,521359148004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','khoidt','doantrankhoi@gmail.com','Khoi Doan Tran','P701-702 Tungshing Square, 02 Ngo Quyen str.','Hanoi','Hanoi','VIET NAM','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:41:56',0,NULL,3,1,3,1,NULL,'khoidt\rRA117713119CN\r\\ '),(1153,515898290003,130490963194,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',5,'WLIN009+ANTY002',114.75,'cnfaner','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:28:59',0,NULL,3,1,3,1,NULL,'saiajin77\rWLIN009+ANTY002\rRA117710687CN\r\\'),(1154,765185708012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY001*3',17.9,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:43:40',0,NULL,3,0,2,1,NULL,'saiajin77\r\\'),(1155,688642912011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','joelskitchen7120joel','joelskitchen71@yahoo.com','Joel Manriquez','21 Hazel Park Terrace<br>08-12 Hazel Park Condominium','default','','SINGAPORE','678946','+65 9858 6695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:58:26',0,NULL,3,1,2,1,NULL,'joelskitchen7120joel\r\\'),(1156,567164579013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','arnepors84','arnepors@vip.cybercity.dk','Visma - Arne Pors','Hørkær 26','Herlev','','DENMARK','2730','004528518364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:20:31',0,NULL,3,1,3,1,NULL,'arnepors84\rMOSA002\rRA117710695CN\r\\'),(1157,688653734011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','2010logan1700','okurylyshyn@gmail.com','Oleh Kurylyshyn','Oleny Stepanyvny str. 33/16','Lviv','','UKRAINE','79016','+380936746204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:38:45',0,NULL,3,1,2,1,NULL,'2010logan1700\r欧标\r\\'),(1158,765201538012,220705174844,'New  Motorola H500 Bluetooth Wireless Headset pink',3,'HSMO006',27.78,'eastar4uk','spacestar8811','i.72.j@wp.pl','JOLA JAROS','88 PANCROFT','ABRIDGE,ROMFORD','Essex','UNITED KINGDOM','RM4 1DA','07916611568','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 09:45:59',0,NULL,3,1,3,1,NULL,'spacestar8811\r英标   HSMO006\rRA117713989CN\r\\'),(1159,688652202011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','cngdnh','cngdnh@gmail.com','Cuong Dinh','USS MASON DDG-87<br>SUPPLY DEPARTMENT','FPO','AE','AA','09578-1302','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 09:50:11',0,NULL,3,1,1,1,NULL,'cngdnh\r、'),(1160,765207686012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',16.5,'eastar4','kobicna','kobicna@gmail.com','kobi cnaany','300 Antibes Drive,<br>1511 apartment','toronto','ON','CANADA','M2R 3N8','(972) 508-6586 ext.: 85','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:09:45',0,NULL,3,1,2,1,NULL,'kobicna\r再发一个罗技CRADLE   旧的\r\\'),(1162,765218659012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','dearos','pauldear@exemail.com.au','Paul DEAR','PO Box 2001','Dangar','New South Wales','AUSTRALIA','2309','61412112587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:49:11',0,NULL,3,1,2,1,NULL,'dearos\r\\'),(1161,515917588003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','staskhod','stas1073@gmail.com','Stanislav Khodakovsky','Dikla,47','En Absor','South','ISRAEL','85405','+972547915995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:31:22',0,NULL,3,1,3,1,NULL,'staskhod\rHSMO011\rRA117710801CN\r\\'),(1163,765218587012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','fastfist','van.williams@swbell.net','Van V. Williams','125 W Chapel Downs Dr','Southlake','TX','UNITED STATES','76092-6109','(817) 442-8672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 10:50:15',0,NULL,3,1,1,1,NULL,'fastfist\r、'),(1164,521730569004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','sturchikhin','tursom@gmail.com','Semen Turchikhin','Bataysky proyezd, 51, 88','Moscow','Moscow','RUSSIAN FEDERATION','109144','+79169235104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 11:00:16',0,NULL,3,1,3,1,NULL,'sturchikhin\rWLIN010+ANTY002\rRA117710660CN\r\\'),(1165,521609468004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','la_bela','attila.laszlo@iconsulting.hu','László Attila','Fehérvári út 24<br>4.em. 3.','Budapest','PEST','HUNGARY','1117','+36302315604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:38:06',0,NULL,3,0,3,1,NULL,'la_bela\rWLAT008\rRA117710758CN\r\\'),(1166,567213944013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',3,'CRLO002',29.7,'eastar4','ghan7513','jdh329@comcast.net','Gwen Hanuscin','1341 Bradford Ln','Bensalem','PA','UNITED STATES','19020-3845','(215) 639-6401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 13:31:18',0,NULL,3,1,1,1,NULL,'ghan7513\r、'),(1167,521427086004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','keyvan.akrami','keyvanakrami@yahoo.com','keyvan akrami','5055 w hacienda ave<br>Unit 1017','Las Vegas','NV','UNITED STATES','89118-0324','(702) 409-2342','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'keyvan.akrami'),(1168,515961273003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','starbucksplanet','starbucksplanet@hotmail.com','ken yee','Compassvale Lane<br>Apt Blk205B #02-01 Singapore 542205','Singapore','none','SINGAPORE','542205','98180226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:19:12',0,NULL,3,1,3,1,NULL,'starbucksplanet\rWWSI002+ANCN001\rRA117710744CN\r\\'),(1169,521777558004,140428317924,'2.1 Acer Aspire 6930 bluetooth module we offer track#',1,'',13.99,'cnfaner','sturmlicht1','pronschke@alice-dsl.net','Peter Ronschke','Bahnhofstr. 120','Steinhagen','','GERMANY','33803','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:49:28',0,NULL,3,0,3,1,NULL,'sturmlicht1\racer 5pin1.25 6cm \rBTAC2113\rRA117710735CN\r\\'),(1170,0,230601700749,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',33.5,'eastar4','rodrigl69','ebay2@astormentas.com','Luis Rodrigues','R Lusiadas 131','Lisboa','','PORTUGAL','1300-369','351960000686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:54:21',0,NULL,3,1,3,1,NULL,'rodrigl69\rOTRA002\rRA117710727CN\r\\'),(1171,567242610013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','bet1039','bjftaz@cox.net','Betty Farmer','5956 Highway 392 W','harrison','AR','UNITED STATES','72601-6375','(870) 577-1039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 15:25:21',0,NULL,3,1,1,1,NULL,'bet1039\r、'),(1172,765317828012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','rrhernandez02','rrhernandezii@gmail.com','Richard Hernandez','1004 Tennant St','Amarillo','TX','UNITED STATES','79104-3312','(806) 220-7693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 15:39:33',0,NULL,3,1,1,1,NULL,'rrhernandez02\r、'),(1173,567252249013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','prug30','jonathan.grenier@isg.ca','Jonathan Grenier','14856 Rue Jean-Simon','Mirabel','QC','CANADA','J7N1V2','(514) 667-1432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:59:10',0,NULL,3,1,3,1,NULL,'prug30\rWWSI005\rRA117710713CN\r\\'),(1174,764610379012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','selonromice','chennian.cn@gmail.com','NIAN CHEN','9309 Kittansett Dr<br>APT E','CHARLOTTE','NC','UNITED STATES','28262-7475','(704) 488-4228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 16:55:16',0,NULL,3,1,1,1,NULL,'selonromice\r、'),(1175,765358884012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','aalj4220','aamax@stpetershigh.essex.sch.uk','AA ALJEBAIY','48 BRITANNIA ROAD<br>WARLEY','BRENTWOOD','Essex','UNITED KINGDOM','CM14 5LG','01621787863','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 17:15:27',0,NULL,3,1,3,1,NULL,'aalj4220\rOTCN003\r\\\rRA117710673CN\r'),(1176,567283335013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','sajken704','sajken@gmail.com','Aleksandr Logvinenko','2-ой проезд Бабушкина 13','Луганск','Луганск','UKRAINE','91025','+380508533461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:40:15',0,NULL,3,1,2,1,NULL,'sajken704\r\\'),(1177,688823788011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sgrnapalm','guillaumegoudreault@gmail.com','Guillaume Goudreault','825 app102 rue wolfe','Montréal','QC','CANADA','h2l5g1','(514) 572-5480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:04:26',0,NULL,3,1,2,1,NULL,'sgrnapalm\r\\'),(1178,516021264003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','kischbrazil','kisch@bol.com.br','Altamaiel Kisch','r: Washington Luiz n° 10<br>Bairro: Labate','Lins','São Paulo','BRAZIL','16400550','551491512195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:11:50',0,NULL,3,1,3,1,NULL,'kischbrazil\rHSNO005+CCNO001\r\\\rRA117710846CN\r'),(1179,516028629003,130458358283,'New  NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'HSNO006+CCNO001',16.95,'cnfaner','lovell-sera','lovell01@mcsnet.ca','Lovell Untereiner','Po Box 7835 Stn Main','Bonnyville','AB','CANADA','T9N 2J1','(780) 826-8919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 18:13:15',0,NULL,3,1,3,1,NULL,'lovell-sera\rHSNO006+CCNO001\rRA117710850CN\r\\'),(1180,567306831013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','2009global6','chaimmeron@gmail.com','chaim schwartz','4 Meron Dr<br>Unit 302','monroe','NY','UNITED STATES','10950-5700','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 18:42:02',0,NULL,3,1,1,1,NULL,'2009global6\r、'),(1181,567307823013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','aper8463','perezabraham2010@yahoo.com','Simon Perez','306 S Mclin ST','Rome','GA','UNITED STATES','30161','(706) 409-5469','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 18:46:14',0,NULL,3,1,1,1,NULL,'aper8463\r、'),(1182,688823556011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','kohcg','geoffreykoh@comcast.net','CHIKGUAN KOH','1068 Turquoise Ter','UNION CITY','CA','UNITED STATES','94587-8523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 19:13:29',0,NULL,3,1,1,1,NULL,'kohcg\r、'),(1183,688869699011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','ogami.itto.2007','docrash@gmail.com','102910811 Andre Almeida, Sc Liquidations','612 Devine St<br>Unit Y','Columbia','SC','UNITED STATES','29201-5214','(803) 601-3204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 19:53:30',0,NULL,3,1,1,1,NULL,'ogami.itto.2007\r、'),(1184,765459085012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',3,'CASS002',26.1,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:06:46',0,NULL,3,1,2,1,NULL,'bolocz\r\\'),(1185,0,220760436654,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jeffe503','eddysx6@hotmail.com','Jeff Eddy','6625 SW 207th Ave','Aloha','OR','UNITED STATES','97007-4140','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-31 20:18:32',0,NULL,3,1,1,1,NULL,'jeffe503\r、'),(1186,765453345012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','robnme2010','eroman@alloypolymers.com','ELIZABETH ROMAN','3310 Deepwater Terminal Rd','RICHMOND','VA','UNITED STATES','23234-1828','(804) 334-6030','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 20:31:37',0,NULL,3,1,1,1,NULL,'robnme2010\r、'),(1187,516080558003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',41.99,'cnfaner','badih234','thebigboss_badi3@hotmail.com','badih el moghrbai','al goz','sharjah','sharjah','UNITED ARAB EMIRATES','22446','0502027678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:35:14',0,NULL,3,0,3,1,NULL,'badih234\rHSNO019\rRA117710775CN\r\\'),(1188,516087571003,130498781630,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','m_fotis','mfotis71@gmail.com','Fotis Mandalis','Saranta Ekklision 52<br>Nea Smyrni','Athens','Greece','GREECE','17124','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-31 20:53:30',0,NULL,3,0,3,1,NULL,'m_fotis\rRA117713326CN\r\\'),(1189,688922146011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','moir5345','michel-rault2@wanadoo.fr','Michel RAULT','20 rue des friches','NANTES','Pays de la Loire','FRANCE','44300','02.40.59.52.02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 21:11:30',0,NULL,3,1,2,1,NULL,'moir5345\racer 4pin1.25 6cm\r\\'),(1190,566895112013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','snell1884','ssnell@selbys.com','steve snell','1914 North Ave W','missoula','MT','UNITED STATES','59801-5534','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 21:29:27',0,NULL,3,1,1,1,NULL,'snell1884\r\\'),(1191,516099394003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','airplusairplus1','simon.lou@genesysamerica.com','Simon Lou','5005 Cedar Oak Ter','fremont','CA','UNITED STATES','94536-6527','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:31:03',0,NULL,3,0,1,1,NULL,'airplusairplus1\r\\'),(1192,521912090004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','noiszl','fabio_mian@yahoo.com.br','Fábio Mian','RUA MAJOR DIOGO, 801 AP. 64<br>BELA VISTA','SAO PAULO','São Paulo','BRAZIL','01324-001','55.11.91916577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:10:58',0,NULL,3,1,3,1,NULL,'noiszl\rOTCR001\rRA117710761CN\r\\'),(1193,765526817012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:40:57',0,NULL,8,1,17,0,NULL,'noirmarginal'),(1194,765531741012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:43:25',0,NULL,3,1,3,1,NULL,'noirmarginal\rHSPL001+CCPL001\r一共买了两个\rRA117710789CN\r\\'),(1195,688961190011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','sytzedebok','sytze@sytzedebok.nl','Sytze de Bok','Korfakker 78','Eindhoven','','NETHERLANDS','5625 SP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:56:19',0,NULL,3,1,2,1,NULL,'sytzedebok\r\\'),(1196,521922516004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','xorxorxorxor','xorxorxorxorxor@gmail.com','Sangha Im','2070 University Ave<br>Apt 109','Berkeley','CA','UNITED STATES','94704-5302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 22:58:04',0,NULL,3,1,1,1,NULL,'xorxorxorxor\r、'),(1197,765540056012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.9,'eastar4','chris1eet','chris1eet@ameritech.net','Chris Miller','8016 S Pulaski Rd<br>Apt 3W','Chicago','IL','UNITED STATES','60652-2333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 23:09:55',0,NULL,3,1,1,1,NULL,'chris1eet\r、'),(1198,688976711011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',2,'RCLO006',99.98,'eastar4','rddc1998','ramdc98@yahoo.com','Romeo De Claro','9410 Old Georgetown Rd','Bethesda','MD','UNITED STATES','20814-1722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-31 23:54:30',0,NULL,3,1,1,1,NULL,'rddc1998\r、'),(1199,765560298012,220759953524,'New APPLE iMac G6  Bluetooth Wireless Keyboard',1,'KBAP003',77,'eastar4','cuico','leobruce59@hotmail.com','Leo Bruce','Bustos 2410 Dpto 504<br>Providencia','Santiago','','CHILE','999','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 00:19:21',0,NULL,3,1,3,1,NULL,'cuico\rKBAP003\rRA117713312CN\r\\'),(1200,516141974003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','user7110690g7h','julia0000@charter.net','KENDALL H. MEAD JR.','4412 CHAPPELL ST.','MOLINE','MI','UNITED STATES','49335','(616) 877-4285','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 00:54:57',0,NULL,3,1,1,1,NULL,'user7110690g7h\r、'),(1201,567423890013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',2,'HSMO006',23.8,'eastar4','9491sts','kb0nai@sbcglobal.net','steven stuckey','1541 del rosa way','sparks','NV','UNITED STATES','89434','(775) 359-0373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 01:19:08',0,NULL,3,1,1,1,NULL,'9491sts\r、\r'),(1202,521949871004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','johannawu','johannawu@gmail.com','Johanna Wu','722 Bexley Road','West Lafayette','IN','UNITED STATES','47906','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 01:22:51',0,NULL,3,1,1,1,NULL,'johannawu\r、'),(1203,567412717013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',75.6,'eastar4','legacytime','jon@legacytime.com','Jon Schneider','5397 Carmel Knolls Dr','San Diego','CA','UNITED STATES','92130-3207','(619) 884-6577','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 01:47:44',0,NULL,3,1,1,1,NULL,'legacytime\r、'),(1204,765599501012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','scott801','scopix@aol.com','Scott Saunders','800 Hampton Dr<br>Ste F','Venice','CA','UNITED STATES','90291-6009','(646) 298-5257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 02:32:48',0,NULL,3,1,1,1,NULL,'scott801\r、'),(1205,765605060012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ironkun','trbetachf@gmail.com','Elon Suen','5585 Dumfries St','Vancouver','BC','CANADA','v5p3a5','(604) 739-3071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 02:50:14',0,NULL,3,1,2,1,NULL,'ironkun\r\\'),(1206,516162121003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','d.gouriou','dgouriou@videotron.ca','Josée Laberge','22 Des saules','Austin','QC','CANADA','J0B1B0','(450) 699-0575','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 02:55:01',0,NULL,3,1,3,1,NULL,'d.gouriou\rOTJE001\rRA117710832CN\r\\  '),(1207,567450213013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','bonsaymaker','omamiralles@gmail.com','Omar Miralles','4200 Medallion Ct<br>Apt 307','louisville','KY','UNITED STATES','40219-1669','(502) 714-3059','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 03:24:52',0,NULL,3,1,1,1,NULL,'bonsaymaker\r、'),(1208,567456473013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','quickonlinebuyer','yasir-hasan@hotmail.com','Yasir Hasan','6980 Dunnview court','Mississauga','ON','CANADA','L5N 7E4','(647) 881-4511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:06:57',0,NULL,3,0,2,1,NULL,'quickonlinebuyer\r\\'),(1209,765624231012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ahmedali5439','ahmed_ali5439@yahoo.com','ahmed shuaibi','1215 Mission 66<br>vicksburg','vicksburg','MS','UNITED STATES','39183-3136','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 04:11:53',0,NULL,3,1,1,1,NULL,'ahmedali5439\r、'),(1210,689045964011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','der023va','deriter.toby@gmail.com','Toby de Riter','38 outlook drive','berwick','Victoria','AUSTRALIA','3806','0397961584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:38:45',0,NULL,3,1,2,1,NULL,'der023va\r\\'),(1211,689045707011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','ziegfrid13','volga019@yahoo.com','Olga Aimanova','2107 - 5 Massey Sq','Toronto','ON','CANADA','M4C 5L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:42:18',0,NULL,3,1,2,1,NULL,'ziegfrid13\r\\'),(1212,689066744011,320519280803,'New Altec Lansing T612 Multimedia Speaker System',1,'SPAL002',180,'eastar4','sboo6712','steveski_@hotmail.com','Steven Paul Boomsma','61 Scorpio Drive<br>Mckail','Albany','Western Australia','AUSTRALIA','6330','0439953423','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 06:39:20',0,NULL,3,1,4,1,NULL,'sboo6712\rSPAL002\rYW864488631CN\r'),(1213,567485446013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','tipmen999','wts32@msstate.edu','Demetri Pappas','1144 Glasgow Cv','Starkville','MS','UNITED STATES','39759-7135','(662) 322-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 07:50:47',0,NULL,3,1,1,1,NULL,'tipmen999\r\\'),(1214,689088484011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',2,'HSNO017',37.8,'eastar4','zelduh','hope@business-affairs.tv','M. Hope Aguilar','10515 Woodbine St','Los Angeles','CA','UNITED STATES','90034','(310) 496-6525','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-01 08:28:02',0,NULL,3,1,1,1,NULL,'zelduh\r\\'),(1215,765691841012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','zima78-1','sasha_lena@bk.ru','Святослав Иванов','Аллея Поликарпова д. 5 кв.556','Санкт Петербург','','RUSSIAN FEDERATION','197341','+79213067864','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 09:46:55',0,NULL,3,1,2,1,NULL,'zima78-1\r欧标\r\\'),(1216,689112993011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','lucianomario47','lisarowmountaineering@yahoo.com','Lou Zamberlan','31 Ourimbah Street','LISAROW','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 10:11:54',0,NULL,3,1,3,1,NULL,'lucianomario47\rWLAP009\rRA117710863CN\r\\'),(1217,689119485011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','fbarini','fabianobarini@hotmail.com','Fabiano Barini','Av. Rio Branco, 217 / 227','Franca ','Sao Paulo','BRAZIL','14405-080','(16) 3721-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 10:38:40',0,NULL,3,1,2,1,NULL,'fbarini\r\\'),(1218,567532153013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','dactasam','evgeny@samoyloff.net','Evgeny Samoylov','Startovaya 3 - 57','Novosibirsk','','RUSSIAN FEDERATION','630073','79133777076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 12:19:40',0,NULL,3,1,2,1,NULL,'dactasam\r\\'),(1219,689153176011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','andrewc1957','info@architype.biz','Andrew Cronin','Unit 11, 155 Mt Alexander Road','Flemington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 12:38:47',0,NULL,3,1,2,1,NULL,'andrewc1957\r\\'),(1220,689171554011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','asica1111','fredconstruction@yahoo.com','Magdalena Sobczak','630 Arlene Dr','Wood Dale','IL','UNITED STATES','60191-1704','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 13:37:09',0,NULL,3,1,1,1,NULL,'asica1111\racer 8pin1.00 8cm \r\\'),(1221,522074305004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','royiz-972','royi.zigler@gmail.com','Royi Zigler','Royi Zigler, Broadcom<br>Dune Networks, Industial park','Yakum','','ISRAEL','60972','(972) 52-337440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:18:45',0,NULL,3,1,3,1,NULL,'royiz-972\rHSMO007\rRA117710877CN\r\\'),(1222,689188788011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','the.aquitaine','the.aquitaine@yahoo.com','Jimmy McCelvey','1840 County Road 4545','Kennard','TX','UNITED STATES','75847','(972) 207-3924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 14:40:35',0,NULL,3,1,1,1,NULL,'the.aquitaine\r\\'),(1223,765788300012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','woosle97','amos0@hotmail.com','Amos Park','9946 Keele St.','Maple','ON','CANADA','L6A 3Y4','(416) 937-3312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:53:40',0,NULL,3,1,2,1,NULL,'woosle97\r\\'),(1224,689205050011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jerry.vos','jerry.vos@gmail.com','Richie Vos','1000 N Lasalle Blvd, Apt 310','Chicago','IL','UNITED STATES','60610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 15:20:00',0,NULL,3,1,1,1,NULL,'jerry.vos\r\\'),(1225,765814505012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bayern.hymne','bayern.hymne@gmx.de','Ulrich Kern','Lindenstrasse 82','Holzkirchen','','GERMANY','83607','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:56:47',0,NULL,3,1,2,1,NULL,'bayern.hymne\r\\'),(1226,567584734013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','lucaternes','lucatern@hotmail.com','luis carlos ternes','capitao cruz - 2319','montenegro','rio grande do sul','BRAZIL','95780-000','55 51 3632-2790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:56:54',0,NULL,3,1,2,1,NULL,'lucaternes\r\\'),(1227,765820586012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',15,'eastar4uk','d13ark','deanobarker@hotmail.com','Dean Barker','10 Farm Close','Crowthorne','Berkshire','UNITED KINGDOM','RG45 6SE','01344775006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 16:12:27',0,NULL,3,1,3,1,NULL,'d13ark\r英标\rHSMO017\rRA117710996CN\r\\'),(1228,516300347003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','antti_ast','anttiast@gmail.com','Antti Åström','Norkkotie 1 G 23','Oulu','Pohjois-Pohjanmaa','FINLAND','90540','+358456717700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 16:20:03',0,NULL,3,1,3,1,NULL,'antti_ast\rWWOT003\rRA117710885CN\r\\'),(1229,765826961012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','popsoul89','lilken601@hotmail.com','Kenneth McLaurin','510 N 38th Ave<br>Apt 39','Hattiesburg','MS','UNITED STATES','39401-5727','(601) 323-1853','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 16:27:59',0,NULL,3,1,1,1,NULL,'popsoul89\r\\'),(1230,765844916012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 17:07:31',0,NULL,3,1,3,1,NULL,'avextra-co-uk\rOTCN004*10\rRA117710894CN\r\\'),(1231,0,220762610888,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',18.98,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:24:10',0,NULL,3,1,1,1,NULL,'4278dennis\r再发一个 罗技保护屏\r\\'),(1232,689216542011,320391125338,'New 2.0 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2001',12.5,'eastar4','atomant-124','apadgett1@nyc.rr.com','anthony padgett','30 Bush Street, Apt. 4B<br>please deliver by 1pm','Brooklyn','NY','UNITED STATES','11231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:32:21',0,NULL,3,1,1,1,NULL,'atomant-124\r\\'),(1233,516341812003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','cesarcandido','cesarhc@gmail.com','Cesar Candido','Rua Julio Rodrigues Mendes, 23 apto - 32','São Paulo','São Paulo','BRAZIL','02245080','55-11-2983-4450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:38:20',0,NULL,3,1,3,1,NULL,'cesarcandido\rHSMO018\rRA117710903CN\r\\'),(1234,567638132013,230601299524,'New Leather Case Built-in Bluetooth Keyboard For iPad',1,'KBAP001',39.8,'eastar4','hek1185','hkluber@yahoo.com','Heidi Kluber','268 Hometown Pkwy','Kyle','TX','UNITED STATES','78640-5711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 18:51:47',0,NULL,5,0,18,0,NULL,'hek1185'),(1235,689301980011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',1,'BTHP2010',12.5,'eastar4','amel1641','info@crowncitycomputer.com','Ara Melkizian','2061 N Los Robles Ave<br>Ste 206','Pasadena','CA','UNITED STATES','91104-1167','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 19:10:05',0,NULL,3,1,1,1,NULL,'amel1641\rHP 8pin 1.25 18cm \r\\'),(1236,522160537004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','chrischixxx','maackralf@wtnet.de','Ralf Maack','Rechnung<br>Poppenbütteler Str. 266a','Norderstedt','','GERMANY','22851','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:26:38',0,NULL,3,1,3,1,NULL,'chrischixxx\rWWSI005\rRA117710948CN\r\\'),(1237,516366445003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jonaslemos','lemos.jonas@gmail.com','Jonas Lemos','Rua Maritin Carvalho,Number 144','Diadema','São Paulo','BRAZIL','09950-040','055-011-89633879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:52:37',0,NULL,3,0,2,1,NULL,'jonaslemos\r\\'),(1238,522169302004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','angelo*andrzej','andrew1863@poczta.fm','Andrzej Tkacz','Gajowa 1/11','Częstochowa','śląskie','POLAND','42200','34 3662202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 20:13:28',0,NULL,3,1,3,1,NULL,'angelo*andrzej\rHSNO022   欧标\rRA117710925CN\r\\'),(1239,689344500011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jeremiahjdclinton','jeremiahjoshuadeanclinton@gmail.com','SirGerald Clinton','921 Old Marion Rd NE<br>Apt 121','Cedar Rapids','IA','UNITED STATES','52402-5757','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 20:34:48',0,NULL,3,1,1,1,NULL,'jeremiahjdclinton\r\\'),(1240,0,220762610770,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',31.99,'eastar4','alex02au','alex01au@hotmail.com','Alan Au','1 Gower St','Hurlstone Park','New South Wales','AUSTRALIA','2193','0414867689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 20:50:23',0,NULL,3,1,3,1,NULL,'alex02au\rOTRA002\rRA117710934CN\r、'),(1241,522189622004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','traderdny','dundeetrader@m-mfg.info','Javan Martin','4898 John Green Rd','Dundee','NY','UNITED STATES','14837-9422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 20:58:46',0,NULL,3,1,1,1,NULL,'traderdny\r\\'),(1242,522202008004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',43.9,'cnfaner','rahrig7','jakemissions@yahoo.com','Jacob Rahrig','509 W Marshall St','Marshall','MN','UNITED STATES','56258-1320','(918) 853-3738','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 21:42:39',0,NULL,3,1,1,1,NULL,'rahrig7\r\\'),(1243,0,320679119415,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6,'eastar4','bears6963','kconover66@gmail.com','Keith T. Conover','518 Lum ave','Kalamazoo','MI','UNITED STATES','49048-2139','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 21:46:29',0,NULL,3,1,1,1,NULL,'bears6963\r\\'),(1244,522207949004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','ratio1974','h_escalonag@yahoo.com','Hugo Escalona','Martin de Zamora 5695, D504<br>Las Condes','Santiago','Santiago / RM','CHILE','7580216','5623797578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 22:09:04',0,NULL,3,0,3,1,NULL,'ratio1974\rHSPL001\rRA117710829CN\r\\'),(1245,765989809012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','shctuh','hutchsuc@yahoo.com','Alvin Hutchinson','849 Leisure Land Dr','Big Cabin','OK','UNITED STATES','74332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 22:10:43',0,NULL,3,1,1,1,NULL,'shctuh\r\\'),(1246,567707538013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.8,'eastar4','tilchi','claudia.tilch@gmx.de','Claudia Tilch','Veielbrunnenweg 58','Stuttgart','','GERMANY','70372','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 22:21:31',0,NULL,3,1,2,1,NULL,'tilchi\r欧标\r\\'),(1247,766005694012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',12.5,'eastar4','bmelabguy','sqwong01@hotmail.com','Stan  Wong','214 Avocet Ct','Foster City','CA','UNITED STATES','94404-1424','(650) 345-8903','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 23:02:22',0,NULL,3,0,1,1,NULL,'bmelabguy\r改发acer 5pin 1.25 3cm\rAspire Timeline 1810 1410 1410T\rBTAC2010\\\r'),(1248,516425087003,130490260658,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.99,'cnfaner','happy_shopper100','magclark@telus.net','Magda Clark','52 Windermere Rd Sw','Calgary','AB','CANADA','T3C 3K5','(403) 240-0319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 23:51:29',0,NULL,3,1,3,1,NULL,'happy_shopper100\rWLAP001\rRA117710815CN\r\\'),(1249,689407122011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','otterscout','davismad1@yahoo.com','Marianne Davis','826 Elm St','El Cerrito','CA','UNITED STATES','94530-2921','(510) 525-7772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 23:51:35',0,NULL,3,1,1,1,NULL,'otterscout\r\\\r'),(1250,522231292004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','jardel-ce','jardel_ce@hotmail.com','Jardel Magalhaes Sa / Maria Edneida','RUA VILEBALDO AGUIAR 2220<br>APT 703','Fortaleza','Ceara','BRAZIL','60190780','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:16:57',0,NULL,3,1,3,1,NULL,'jardel-ce\rOTCR001\rRA117710982CN\r\\'),(1251,766028878012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',39.75,'eastar4','dreamw41','dreamw88@hotmail.com','Lee Weaver','5420 Eagle Cloud Trl<br>Apt 302','Raleigh','NC','UNITED STATES','27606-3789','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 00:25:07',0,NULL,3,1,1,1,NULL,'dreamw41\r\\'),(1252,689419339011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','katherine7562','kannelisti@gmail.com','Katherine Listi','5627 Vickery Blvd','Dallas','TX','UNITED STATES','75206-6234','(214) 557-7974','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 00:39:11',0,NULL,3,1,1,1,NULL,'katherine7562\r\\'),(1253,567739020013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','robdam1001','robdam@comcast.net','rob damiani','363 mountainside west<br>aka Main Street','farmington','CT','UNITED STATES','06032','(860) 677-0407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 01:02:07',0,NULL,3,1,1,1,NULL,'robdam1001\r\\'),(1254,516435745003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','vacuum_guy','stanleysystems@gmail.com','Igor Smoter','Box 57, Site 228, RR2','Dryden','ON','CANADA','P8N 2Y5','(807) 755-1654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 01:04:48',0,NULL,3,1,3,1,NULL,'vacuum_guy\rPOLO001\rRA117711002CN\r\\'),(1255,689425427011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','alvoonline','josealves2010@gmail.com','José Alves de Andrade Filho','Rua Praia de Boa Viagem, 2245<br>Ponta Negra','Natal','RN','BRAZIL','59094-320','+55 84 8816 2705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 01:08:00',0,NULL,3,1,2,1,NULL,'alvoonline\r\\'),(1256,567752119013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rphbeach','rphbeach@msn.com','Russell  Hayman','10118 North Ave','Ocean City','MD','UNITED STATES','21842-9708','(410) 213-1948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 02:12:37',0,NULL,3,1,1,1,NULL,'rphbeach\r\\'),(1257,522249163004,140481827924,'New Plantronics Explorer 220 BLUETOOTH HEADSE+carcharge',1,'HSPL001+CCPL001',15.88,'cnfaner','divine_1','divine_bb@yahoo.com','Adebayo Majolagbe','2807 Coronella Ct','Upper Marlboro','MD','UNITED STATES','20774','(240) 481-8787','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 02:17:29',0,NULL,3,1,1,1,NULL,'divine_1\r\\'),(1258,766053669012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.95,'eastar4','10001th_maniac','alexeisenhut@gmail.com','Alex Eisenhut','450 St-Pierre<br>suite 300','Montreal','QC','CANADA','H2Y2M9','(514) 284-5252 ext.: 37','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 02:21:12',0,NULL,3,1,2,1,NULL,'10001th_maniac\r\\'),(1259,516449581003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','skyking5431josh','skyking5431@yahoo.com','Josh King','14239 N Lewis Rd','Clio','MI','UNITED STATES','48420-8837','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 02:27:00',0,NULL,3,1,1,1,NULL,'skyking5431josh\r\\'),(1260,567735149013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','caye416','carl_md@hotmail.com','Carlito B. Sta.Ana','12 Inocencia st., tugatog','Malabon City','METRO MANILA','PHILIPPINES','1470','639944887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:40:26',0,NULL,3,1,2,1,NULL,'caye416\r\\'),(1261,567767113013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','globalbuyer','mrinal@hotmail.co.uk','Mrinal Kumar','Jetset Journeys Pvt. Ltd., D-82 Amar Colony (Basement)<br>Lajpat Nagar IV','New Delhi','Delhi','INDIA','110024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:47:09',0,NULL,3,1,2,1,NULL,'globalbuyer\r\\'),(1262,689459634011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.8,'eastar4','ctajiuh','vovka8686@mail.ru','Vladimir Ahryukov','st. Archedinskaya, 50','Frolovo','Volgograd Region','RUSSIAN FEDERATION','403531','(917)725-8710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:55:23',0,NULL,3,1,2,1,NULL,'ctajiuh\racer 8pin1.00 15cm\r\\'),(1263,522265909004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','i699045','imustapha@hotmail.com','ibrahim Mustapha','12143 rue l\'archeveque','montreal','QC','CANADA','h1h3c2','(514) 582-2829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 04:07:42',0,NULL,3,1,3,1,NULL,'i699045\rHSPL001\rRA117710979CN\r\\'),(1264,567776797013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','franksagid','frank_sagid@hotmail.com','Frank Feijoo','Sector Quitumbe calle Amauta lote 13 y calle 5','Quito','Pichincha','ECUADOR','EC170146','593 22677 842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 05:03:44',0,NULL,3,1,2,1,NULL,'franksagid\r\\'),(1265,766096292012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','skovgard3','chrisskovgard@gmail.com','Chris Skovgard','1 Grand Ave<br>Santa Lucia 235','San Luis Obispo','CA','UNITED STATES','93407-9000','(562) 355-7367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 05:40:27',0,NULL,3,1,1,1,NULL,'skovgard3\r\\'),(1266,567784608013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','morejesper','morejesse@gmail.com','Jesse More','814 Johns Close','Edmonton','AB','CANADA','T6L6P2','(780) 884-3345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:09:54',0,NULL,3,1,2,1,NULL,'morejesper\r\\'),(1267,689486593011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','lui_0209','lui_0209@yahoo.com.sg','Lui Kwok Heng','Blk 239 Compassvale Walk #10-562','Singapore','Singapore','SINGAPORE','540239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:42:36',0,NULL,3,1,11,1,NULL,'lui_0209\r、'),(1268,567801026013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','zumbamel','zumbamelly@aol.com','Melanie Smith','6688 Golden Star Cv','Bartlett','TN','UNITED STATES','38134-1800','(901) 217-3115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 08:06:48',0,NULL,3,1,1,1,NULL,'zumbamel\r\\'),(1269,766130785012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','atillaaslan09','atilla_aslan_01@hotmail.com','atilla aslan','merkez mah. erdemoglu bulvari  151/b  ERDEMLI/MERSIN','mersin','turkey','TURKEY','33740','905446693564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 08:21:29',0,NULL,3,1,2,1,NULL,'atillaaslan09\r\\'),(1270,689508919011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','shiney19','stormy19@btinternet.com','Pam Swan C/o Modern Bookbinders Limited','Pringle Street','Blackburn','Lancashire','UNITED KINGDOM','BB1 1SA','01254265483','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 08:24:22',0,NULL,3,1,3,1,NULL,'shiney19\rMOAP001\rRA117713935CN\r\\'),(1271,766179271012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','khsw_be','kenhuysmans@gmail.com','Ken Huysmans','Varenstraat 9','Moerbeke-Waas','Oost-Vlaanderen','BELGIUM','9180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:20:43',0,NULL,3,1,2,1,NULL,'khsw_be\r\\'),(1272,567836794013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','vitesa','chento.ts@gmail.com','Vicente M. Terrada Sara','Avda. de Andalucia, 25','El Puerto de Santa María (Cádiz)','Andalucía Ceuta y Melilla','SPAIN','11500','630016505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:34:32',0,NULL,3,1,2,1,NULL,'vitesa\r\\'),(1273,766184352012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','ppistik6','ppistik@gmail.com','Stefan Laso','Borova 31','Zilina','SK','SLOVAK REPUBLIC','01007','0948506098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:37:51',0,NULL,3,1,2,1,NULL,'ppistik6\r欧标\r\\'),(1274,766188208012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','f64098','fscheffski@sf-mail.de','Frank Scheffski','Waldheimer Straße 56','Nossen','','GERMANY','01683','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 11:50:42',0,NULL,3,1,2,1,NULL,'f64098\racer 5pin1.25 6cm\r\\'),(1275,766202028012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.69,'eastar4uk','miickeyy2010','meekaaeel_nawaz@hotmail.com','Miickeyy Nawaz','43 oxford road<br>acocks green','birmingham','West Midlands','UNITED KINGDOM','b276ds','01217076151','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 12:35:15',0,NULL,3,1,3,1,NULL,'miickeyy2010\rHSNO023\r英标 \rRA117711271CN\r\\'),(1276,766218632012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','ejbrent','johnbrent@live.co.uk','E.J.Brent','21, Byron Road<br>Rustington','Littlehampton','West Sussex','UNITED KINGDOM','BN16 2NZ','01903776849','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 13:24:55',0,NULL,3,1,3,1,NULL,'ejbrent\rOTCN003\rRA117711268CN\r\\'),(1277,689589459011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','huubear87','roach_knight87@hotmail.com','Huu Nguyen','66 Monks park ave,horfield','Bristol','Bristol','UNITED KINGDOM','BS70UH','01179236405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:25:06',0,NULL,3,1,2,1,NULL,'huubear87\r\\'),(1278,522358610004,140482633217,'New NOKIA BH-600 BLUETOOTH HEADSET+Carcharger track#',1,'HSNO016+CCNO001',21.9,'cnfaner','carlisha2','lashawnserrano@yahoo.com','carlisha serrano','1805 McClure St','Homestead','PA','UNITED STATES','15120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 13:59:39',0,NULL,3,1,1,1,NULL,'carlisha2\r\\'),(1279,766254830012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','postalbiskit','postalbiskit@aol.com','Ruben Martinez','4986 Auburn Dr<br>Apt A','San Diego','CA','UNITED STATES','92105-3643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 15:04:19',0,NULL,3,1,1,1,NULL,'postalbiskit\r\\'),(1280,516582394003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','ranieri.nando','nando.ranieri@libero.it','BRATTA GIUSEPPE','GUIDO DORSO 30/B','BARI','BA','ITALY','70125','3387762605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 15:34:39',0,NULL,3,1,3,1,NULL,'ranieri.nando\rHSMO006\r欧标\rRA117711299CN\r\\'),(1281,766269901012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','tgilbert2112','tgilbertmm@yahoo.com','Tim Gilbert','1139 Reservoir Rd','New Holland','PA','UNITED STATES','17557-9553','(610) 563-7181','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 15:40:45',0,NULL,3,1,1,1,NULL,'tgilbert2112\r\\'),(1282,567901417013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','jameslowz28','dcorbitt@neo.rr.com','James L Corbitt','3389 State Route 39','Shelby','OH','UNITED STATES','44875-9470','(567) 216-2248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 16:04:05',0,NULL,3,1,1,1,NULL,'jameslowz28\\'),(1283,567904310013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','jojojox2','i__23@hotmail.com','Iván Díaz Carrera','c/ Doctor Ayela 16, 4to IZQ','Alicante','Comunidad Valenciana','SPAIN','03013','651467704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:13:58',0,NULL,3,1,2,1,NULL,'jojojox2\racer 5pin1.25 6cm  \r\\'),(1284,689653761011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','rafalbos','azzazz@hotmail.co.uk','Rafal Bos','118 Piggot St.','London','London','UNITED KINGDOM','E14 7DW','07871830364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:24:21',0,NULL,3,1,2,1,NULL,'rafalbos\racer 8pin1.00 8cm\r\\'),(1285,766297728012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','daviddgibbons','davidgibbons1234@comcast.net','david gibbons','11009 Rosemont dr','rockville','MD','UNITED STATES','20852','(301) 231-8612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 16:46:58',0,NULL,3,1,1,1,NULL,'daviddgibbons\r\\'),(1286,689697491011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','gremlin48230','ugottahaveit@gmail.com','Bill Youngblood','35400 Bob Hope Dr<br>Ste 109','Rancho Mirage','CA','UNITED STATES','92270','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 18:01:22',0,NULL,3,1,1,1,NULL,'gremlin48230\r\\'),(1287,689698835011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',25.9,'eastar4uk','behc-7','tsc.behc@gmail.com','Evgeny Chorpita','55-18 Vosstaniya str<br>+7 911 712 9060','Saint-Peterburg','RU','RUSSIAN FEDERATION','191123','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-02 18:07:17',0,NULL,3,1,3,1,NULL,'behc-7\rWWSI004\r\\\rRA117711325CN\r'),(1288,516632300003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','miqbal494','miqbal20170@yahoo.com','mohammad iqbal','518 Early Fall Ct','herndon','VA','UNITED STATES','20170-4202','(703) 435-1566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 18:21:43',0,NULL,3,1,1,1,NULL,'miqbal494\r\\'),(1289,689741486011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',75.98,'eastar4','gyros4free','thomas.tsiakalakis@gmail.com','Thomas Tsiakalakis','Freudenthalstraße 19','Augsburg','','GERMANY','86179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 19:26:49',0,NULL,3,0,3,1,NULL,'gyros4free\rUDAP001   \rRA117716234CN\r\\'),(1290,567989957013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','477marc1','marcvanoppen@live.be','Marie-Josee Corstjens','Bergerstraat 91','Neeroeteren','','BELGIUM','3680','0477957644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:18:29',0,NULL,3,1,3,1,NULL,'477marc1\rWWSI004+ANCN001\rRA117711342CN\r\\'),(1291,567997579013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','whitefoxwr','kuzoku@gmx.de','Andre Haberle','Koblenzer Straße 8','Braunschweig','','GERMANY','38116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:39:56',0,NULL,3,1,2,1,NULL,'whitefoxwr\r\\'),(1292,766431368012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','zekezgilpin','zekezg21@gmail.com','Zeke Gilpin','2141 Patterson Mill Rd','yadkinville','NC','UNITED STATES','27055-5347','(336) 679-9105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 21:02:13',0,NULL,3,1,1,1,NULL,'zekezgilpin\r\\'),(1293,766461600012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','lutontown1979','darran_mcevoy@yahoo.co.uk','Darran','Harveys, Portfield Retail Park<br>Portfield Way','Chichester','West Sussex','UNITED KINGDOM','PO19 7YH','07702139625','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 22:09:36',0,NULL,3,1,3,1,NULL,'lutontown1979\rOTRA002\rRA117711285CN\r\\'),(1294,766416993012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','drewchristianhill','drewhill87@ymail.com','Andrew Hill','31441 paseo riobo','San Juan capistrano','CA','UNITED STATES','92675-5524','(949) 887-7379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 22:19:32',0,NULL,3,1,1,1,NULL,'drewchristianhill\r\\'),(1295,0,320676728747,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','garytl57','gleonard@neo.rr.com','Gary Leonard','12155 Marlboro Ave NE','Alliance','OH','UNITED STATES','44601','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-02 22:39:27',0,NULL,3,1,1,1,NULL,'garytl57\r\\'),(1296,766485600012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','kremnant','remnant@comcast.net','Karen Remolino','1831 Ludlow St','Rahway','NJ','UNITED STATES','07065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 23:18:11',0,NULL,3,1,1,1,NULL,'kremnant\\'),(1297,766485993012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','nestor729','eric71911@comcast.net','Eric Hoffmann','1035 W Huron St<br>Unit 504','Chicago','IL','UNITED STATES','60642','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-02 23:18:59',0,NULL,3,1,1,1,NULL,'nestor729\r\\'),(1298,568058367013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','wulfy19','dave.dewulf@gmail.com','Dave Dewulf','409 Gilpin Dr','Newmarket','ON','CANADA','L3X3H3','(289) 221-5333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 00:51:34',0,NULL,3,1,3,1,NULL,'wulfy19\rRCLO003\r\rRA117716279CN\r\\'),(1299,766517102012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',42.76,'eastar4','2011efrank','frank_brasilia@yahoo.com.br','FRANK JOSE MACHADO DA SILVA','QN 122 CONJ 01 LT 3<br>SAMAMBAIA NORTE','BRASILIA','Distrito Federal','BRAZIL','72304-101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 01:07:21',0,NULL,3,1,3,1,NULL,'2011efrank\rOTAP001\rRA117711308CN\r\\'),(1300,766536778012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','d-mashi75','mashima@xj.commufa.jp','daisuke mashima','69-7<br>yatsurugicho gou','iwakura','Aichi','JAPAN','4820031','(0587)38-2454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 02:23:24',0,NULL,3,1,3,1,NULL,'d-mashi75\rOTGR001+OTGR002\rRA117716248CN\r\\\r'),(1301,516568930003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','kakashisama25','diego_rodolfo@yahoo.com.br','Diego Freitas','Rua Bacabal, 708<br>casa 2','São José dos Campos','São Paulo','BRAZIL','12235680','551239335357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 02:35:44',0,NULL,3,1,3,1,NULL,'kakashisama25\rHSAO018\rRA117716251CN\r\\'),(1302,522559353004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','luiz_neto','luizlou@yahoo.com.br','Luiz Louzada Neto','Rua Serra da Saudade nº 347','Americana','São Paulo','BRAZIL','13470-412','19 92799259','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 03:11:38',0,NULL,3,1,3,1,NULL,'luiz_neto\rOTRA002\rRA117711210CN\r\\'),(1303,766555066012,220762109483,'New Sennheiser CX280 CX-280 In-Ear Headphones Earphones',1,'',35.99,'eastar4','ts_dante117','tsong117@hotmail.com','Hak song','2208 Haggin Oaks Blvd','Bakersfield','CA','UNITED STATES','93311-1511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 03:32:41',0,NULL,3,0,1,1,NULL,'ts_dante117\r\\'),(1304,766564942012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','gc.','gcoon@mindspring.com','George Coon','8971 Western Pines Dr','Douglasville','GA','UNITED STATES','30134-1783','(770) 949-5836','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 04:19:35',0,NULL,3,0,1,1,NULL,'gc.\\'),(1305,766563822012,220455473916,'HP DV2000 DV2100 DV2200  Bluetooth Module 2.0+ cable',1,'BTHP2003',12.5,'eastar4','meesa.velazquez','melissa.velazquez@q.com','Melissa Velazquez','4724 S 2675 W','Roy','UT','UNITED STATES','84067-1800','(801) 698-3753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 04:58:22',0,NULL,3,1,1,1,NULL,'meesa.velazquez\rHP 8pin 1.0 12cm \r\\'),(1306,568108752013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','regismarques2009','regis_marques@hotmail.com','Reginaldo Marques de Oliveira','Rua: Icatu Nº 2030<br>Conjunto Residencial 31 de Marco','Sao Jose dos Campos','Sao Paulo','BRAZIL','12237010','55-12-91782051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 05:44:47',0,NULL,3,1,2,1,NULL,'regismarques2009\r\\'),(1307,689816191011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',43.95,'eastar4','horowitz_dan','horowitzdan1@gmail.com','Dan Horowitz','Heil Hayam 7','Rishon Lezion','','ISRAEL','75702','0502288425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 05:58:45',0,NULL,3,1,3,1,NULL,'horowitz_dan\r送螺丝  WWOP003\rRA117713670CN\r\\'),(1308,689944140011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hro-u5299','nichtschonwieder@weinenvorglueck.de','Lautenschläger','Adolf-Becker-Straße 15','Rostock','','GERMANY','18057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 07:36:39',0,NULL,3,1,2,1,NULL,'hro-u5299\r\\'),(1309,689494580011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','chocalate.lover2011','chocolate.lover2011@hotmail.com','J A QI','1/14 Vanderbilt Avenue','Truganina','Victoria','AUSTRALIA','3029','03836087290432441316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 07:46:33',0,NULL,3,1,2,1,NULL,'chocalate.lover2011\r\\'),(1310,766627786012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',102.73,'eastar4','huszar.adam','oregonlogos@gmail.com','Ádám Huszár','István 41','Gyöngyöstarján','Heves','HUNGARY','3036','+36204474046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:43:24',0,NULL,3,1,3,1,NULL,'huszar.adam\r再发一个New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card\rUnlocked\r\r 两个NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna\rWLAT009+WWSI005+ANCN001+WLAT005  \rRA117716217CN\r\\\r'),(1311,690010076011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','javel10','johan93@lyse.net','Johan Vika Waage','Nordstrandveien 65','Stavanger','vassøy','NORWAY','4076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 10:39:09',0,NULL,3,1,2,1,NULL,'javel10\r\\'),(1312,0,230603572046,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',12.99,'eastar4','gweilo88','willquinn@fastmail.fm','Caroline Driscoll','Flat 9H, Block 5, Tung Chung Crescent<br>Tung Chung, Hong Kong','default','','HONG KONG','default','+852 94871930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 10:57:47',0,NULL,3,1,2,1,NULL,'gweilo88\r\\'),(1313,690021374011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','s.harald','ebay@eye-of-the-tiger.com','Harald   Löffler','Lenaustraße 1','Ostfildern','','GERMANY','73760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 11:06:53',0,NULL,3,1,2,1,NULL,'s.harald\r\\'),(1314,766698900012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','toyaman','hirok@mx35.tiki.ne.jp','Hiroki Hasegawa','Kuboki 111<br>Okayama Kenritsu Daigaku, Design Gakubu','Soja-shi','Okayama','JAPAN','719-1197','(0866) 94-2067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 11:33:42',0,NULL,3,1,2,1,NULL,'toyaman\r\\'),(1315,522656600004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','022593065','eliezer.hazout@zoran.com','eliezer Hazout','Mali Yaakov Moshe 4-4 Qiryaat shmuel','Haifa','ID','ISRAEL','26385','+972-4-8418464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:02:36',0,NULL,3,1,3,1,NULL,'022593065\rOMHJ001\rRA117711223CN\r\\'),(1316,766717382012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.8,'eastar4','a.alitkin','tlkn@rambler.ru','Anatoliy Alitkin','Naberejnaya, 71','Esik','KZ','KAZAKHSTAN','040400','+7-705-184-35-27','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:17:27',0,NULL,3,1,2,1,NULL,'a.alitkin\r\\'),(1317,766740551012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','stefan_georgiev_popov','stefan.popov@gmail.com','Stefan Popov','Beim Weisenstein 14<br>Ap. 6','Saarbruecken','','GERMANY','66125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:08:40',0,NULL,3,0,3,1,NULL,'stefan_georgiev_popov\rMOMI001\rRA117716265CN\r\\'),(1318,568217434013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ouioui2821','yann.jacques@ouioui-online.fr','yann jacques','8 rue des oiseaux','Savigny le temple','Île-de-France','FRANCE','77176','0679132040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:22:11',0,NULL,3,1,2,1,NULL,'ouioui2821\r\\'),(1319,522691430004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','megaredrider','rrefom@gmail.com','Sergey Shurupov','Leninskiy prospekt, dom.44, kv.158','Moscow','RU','RUSSIAN FEDERATION','119334','8-905-557-90-32','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 13:56:17',0,NULL,3,1,3,1,NULL,'megaredrider\rWLIN010+ANTY002\rRA117711237CN\r\\'),(1320,766779861012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','jhkingsr','jhkingsr@northstate.net','Jeffery King','2566 Peppertree Ridge Rd','Randleman','NC','UNITED STATES','27317','(336) 495-5835','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-03 14:24:59',0,NULL,3,1,1,1,NULL,'jhkingsr\r\\'),(1321,689515149011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','druffkappell','denstedter@web.de','Gerd Wiegand','Steinweg 19 a','Dieburg','','GERMANY','64807','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:47:00',0,NULL,3,1,2,1,NULL,'druffkappell\r\\'),(1322,690121736011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','speedster200413','rav.panesar@gmail.com','Ravinder Panesar','27 Rectory Road','Southall','London','UNITED KINGDOM','UB24EN','07879493568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:49:38',0,NULL,3,1,2,1,NULL,'speedster200413\r\\'),(1323,516915107003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','ciobanash','eciobanu@mountaincable.net','Edward Ciobanu','15 Brantdale Avenue','Hamilton','ON','CANADA','L9C 1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 14:52:43',0,NULL,3,1,3,1,NULL,'ciobanash\rHSSE004\rRA117711245CN\r\\'),(1324,568256901013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','bluelightcrafts','heatherprusse@hotmail.com','Heather Prusse','663 E Elgin St','Gilbert','AZ','UNITED STATES','85295-1579','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 15:08:17',0,NULL,3,1,1,1,NULL,'bluelightcrafts\r\\'),(1325,690134000011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','powerdbycosworth','escort_rsturbo427@hotmail.com','andy akkermans','woeringenstraat 17','berchem','antwerpen','BELGIUM','2600','0473867606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:16:41',0,NULL,3,1,2,1,NULL,'powerdbycosworth\r\\'),(1326,690138750011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','emilsigandersen','emilsig@hotmail.com','Emil Sig Andersen','gammelstrupvej 22','brædstrup','standard','DENMARK','8740','75752675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:28:38',0,NULL,3,1,2,1,NULL,'emilsigandersen\r\\'),(1327,690179519011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','pat_realtor','pat_realtor@yahoo.ca','Petcharart Thangamornrart','12 Catherwood Crt','Scarborough','ON','CANADA','M1W 1S1','(416) 833-3984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 16:19:10',0,NULL,3,1,2,1,NULL,'pat_realtor\r\\'),(1328,766887445012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','wagnergung','mirko.wagner79@gmail.com','Mirko Wagner','Grießbacher Haupstraße 56','Drebach OT Grießbach','','GERMANY','09430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 16:59:45',0,NULL,3,1,2,1,NULL,'wagnergung\rHP 6pin 1.0 12cm \r\\'),(1329,568324340013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','nachete_r','irivaspreciados@yahoo.es','IGNACIO RIVAS PRECIADOS','SAN FERNANDO Nº2 10ºA','SANTANDER','Cantabria','SPAIN','39010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 17:28:13',0,NULL,3,1,3,1,NULL,'nachete_r\rMOSA002\rRA117711427CN\r\\'),(1330,766913927012,220681549405,'New SAMSUNG WMN1000A ULTRA SLIM WALL-MOUNT LED 26\"-37\" ',1,'MOSA001',46,'eastar4uk','max-munki','diethardkuehl@alice-dsl.net','Diethard Kühl','Lohmannweg 3','25436','','GERMANY','Tornesch','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 17:29:28',0,NULL,3,1,3,1,NULL,'max-munki\rMOSA001\rRA117716075CN\r\\'),(1331,568351127013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',2,'BAZA001',151.2,'eastar4','cloudancer972','rdfoutch@att.net','Rick Foutch','4416 Seville Ln','McKinney','TX','UNITED STATES','75070-4438','(972) 529-0528','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cloudancer972'),(1332,568358550013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','tr_superstore','superstoretr@windowslive.com','Serdar Keles','Ortaklar C. Ünsal Sk. No:5/5 Mecidiyeköy','Istanbul','','TURKEY','34394','+902129999999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:04:54',0,NULL,3,1,2,1,NULL,'tr_superstore\r欧标\r\\'),(1333,568375506013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ktracid','stefan.zafiratos@gmail.com','Stefan Zafiratos','302-5900 Olive Ave<br>Buzzer 43','Burnaby','BC','CANADA','V5H 2P6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:24:10',0,NULL,3,1,2,1,NULL,'ktracid\r\\'),(1334,522834887004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','nickk9','nickk@oracle.ntt.ru','Nick Kolosov','p.o. box 97','Moscow','Moscow','RUSSIAN FEDERATION','129090','(7919)1061184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:33:16',0,NULL,3,1,3,1,NULL,'nickk9\rWLAT002  发新的\rRA117716203CN\r\\'),(1335,568381803013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','alicelockhartkitty','lockhartkitty@yahoo.com','Alice Lockhart','1304 Stacie Dr','Elizabeth City','NC','UNITED STATES','27909-9281','(252) 264-1305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 18:33:43',0,NULL,3,1,1,1,NULL,'alicelockhartkitty\r\\'),(1336,766991828012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','tcnra','c.lochmuller@frontier.com','charles lochmuller','2819 mcdowell rd','durham','NC','UNITED STATES','27705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 18:37:50',0,NULL,3,1,1,1,NULL,'tcnra'),(1337,568388284013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','lembergaviation','jpl@lembergaviation.com','Jani Lemberg','Bergkullantie 33','KIRKKONUMMI','-','FINLAND','02400','00358407779449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 18:41:25',0,NULL,3,1,2,1,NULL,'lembergaviation\r\\'),(1338,690358477011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','k2intimidator8','adam.winker@cellnet.com','Adam Winker','7780 Pinto Ln','Lino Lakes','MN','UNITED STATES','55014','(612) 578-2050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 19:24:38',0,NULL,3,1,1,1,NULL,'k2intimidator8\r\\'),(1339,767071476012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.99,'eastar4uk','runeandre2009','ra.fr@hotmail.com','Rune Andre Frøyen','Plassen 7','Florø','sogn og fjordane','NORWAY','6900','004791356439','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 19:48:30',0,NULL,3,1,2,1,NULL,'runeandre2009\r\\'),(1340,568438219013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','comic_collectable_toyz','dbmitchell@blueyonder.co.uk','David Mitchell','11 Wallington Avenue, Cullercoats','North Shields','Tyne and Wear','UNITED KINGDOM','NE30 3SH','07779347045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 19:55:21',0,NULL,3,1,2,1,NULL,'comic_collectable_toyz\r\\'),(1341,522914129004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','macjag1999','allenpchan@yahoo.com','A. Chan','2425 Ortega St','San Francisco','CA','UNITED STATES','94122-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 20:46:59',0,NULL,3,1,1,1,NULL,'macjag1999\r\\'),(1342,767187561012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','nikkostuff','rpsna70@aol.com','Rudy Pantun Soaloon Napitupulu','Jl. Beton No: 90 (D/h No: 1), Kampung - Ambon','Jakarta - Timur','DKI Jakarta','INDONESIA','13210','0214896284','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 23:12:05',0,NULL,3,1,3,1,NULL,'nikkostuff\rHSPL010\rRA117711206CN\r\\'),(1343,517169387003,130458358014,'Genuine Motorola H710  Bluetooth Headset offer track#',1,'HSMO014',26.59,'cnfaner','krvtradingco','hunneydoo@yahoo.com','Lyle Crawford','2219 Rembach Ave','Bodfish','CA','UNITED STATES','93205-9668','(760) 417-9011','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 23:33:07',0,NULL,3,1,1,1,NULL,'krvtradingco\r\\'),(1344,766371351012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','gabr','olegbrov@yahoo.com','Oleg Brovender','1333 Greeby St','Philadelphia','PA','UNITED STATES','19111-5526','(215) 288-5307','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 23:48:56',0,NULL,3,1,1,1,NULL,'gabr\r\\'),(1345,568526149013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','calvineng','calvineng@usa.net','Calvin Eng','No. 10 Lorong 1 Jalan Mendu','Kuching','Sarawak','MALAYSIA','93200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 23:52:09',0,NULL,3,1,2,1,NULL,'calvineng\r\\'),(1346,767204441012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','rmhua','ryanmcloud@gmail.com','Yuran Hua','1066 S SUGAR MAPLE PL','BLOOMINGTON','IN','UNITED STATES','47403-4574','(810) 335-2611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-03 23:54:02',0,NULL,3,1,1,1,NULL,'rmhua\rHP 6pin 1.0 12cm \r\\'),(1347,767207839012,220502334400,'2.1 HP V3000 V3100 V3400 V3600 Bluetooth Module+ cable',1,'BTHP2103',12.8,'eastar4','compupiojo','chermozalawyer@gmail.com','Cesar Augusto Hermoza Gonzales','Jr. Santiago Rodriguez 254 Zona B San Juan de Miraflores','Lima','Lima','PERU','L 29','4663114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:00:36',0,NULL,3,1,2,1,NULL,'compupiojo\rHP 8pin 1.0 12cm \r\\'),(1348,568532902013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','diga_tururu','diga_tururu@hotmail.com','Fco Javier Valero Martinez','Avda. Andalucia Nº3, 4ºC','San Sebastian de los Reyes','Madrid','SPAIN','28702','619718842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:18:01',0,NULL,3,1,2,1,NULL,'diga_tururu\r\\'),(1349,517189826003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','samantha18nj','samanthareed1992@hotmail.com','samantha reed','120 Centre St','nutley','NJ','UNITED STATES','07110-2828','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 00:53:25',0,NULL,3,1,1,1,NULL,'samantha18nj\r\\'),(1350,568553998013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',2,'HSMO012',35.8,'eastar4','luciagormazmunoz','igormazmz@gmail.com','LUCIA  GORMAZ    .   rut  5.595.866-1','PAUL CLAUDEL 1490  depto  24<br>VITACURA','SANTIAGO','METROPOLITANA','CHILE','7630000','56  02  4185601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 01:28:57',0,NULL,3,1,3,1,NULL,'luciagormazmunoz\rHSMO012\rRA117711651CN\r\\'),(1351,767248845012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','art1saf','art1saf@yahoo.com','arthur safalow','137 willis ave','mineola','NY','UNITED STATES','11501','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:38:50',0,NULL,3,1,1,1,NULL,'art1saf\r\\'),(1352,690545098011,320676254425,'Slim Bluetooth Wireless Keyboard for iPad iPhone iPod',1,'KBAP002',28.99,'eastar4','nlar5931','nlargavista@gmail.com','Nova Largavista','5253 Monroe Ave<br>Apt. #3','San Diego','CA','UNITED STATES','92115-4705','(619) 889-4568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:56:47',0,NULL,3,1,1,1,NULL,'nlar5931\\'),(1353,767255618012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','bjamesedw','bbjamesed@aol.com','Emmett Barnes','1508 Shady Oaks Rd','Terry','MS','UNITED STATES','39170-9290','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 01:57:06',0,NULL,3,1,1,1,NULL,'bjamesedw\r\\'),(1354,767259770012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dsieme01','dsieme01@hotmail.com','Daniel Siemens','225 SE Country Ln','Lees Summit','MO','UNITED STATES','64063-6025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 02:08:29',0,NULL,3,1,1,1,NULL,'dsieme01\r\\'),(1355,690554397011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','thespiders2','chris-garten@hotmail.de','Christian Ott','Matenzeile 16','Berlin','','GERMANY','13053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 02:22:54',0,NULL,3,1,2,1,NULL,'thespiders2\r\\'),(1356,568571909013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',3,'OMHJ001',41.97,'eastar4','classicscooterparts','worldrareitems2008@gmail.com','Howard Ngo','3071 Centerwood Way','San Jose','CA','UNITED STATES','95148-2656','(408) 417-5296','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-04 02:31:26',0,NULL,3,1,1,1,NULL,'classicscooterparts\r\\'),(1357,690561434011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fivos_k','fkanellis@gmail.com','Foivos Kanellis','133 Peterborough St<br>Apt 8a','Boston','MA','UNITED STATES','02215','(857) 294-4179','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 02:46:51',0,NULL,3,1,1,1,NULL,'fivos_k\\'),(1358,767278386012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','jmichaelreynolds','michael.reynolds@comcast.net','Michael Reynolds','60 Montgomery St','Cambridge','MA','UNITED STATES','02140','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:04:00',0,NULL,3,1,1,1,NULL,'jmichaelreynolds\r\\'),(1359,522726961004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','onedieseldoctor','fourfriends@msn.com','William E. Friend','1259 N Church St<br>Power Equipment Company Bldg 2','Moorestown','NJ','UNITED STATES','08057','(856) 316-8808','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 03:07:59',0,NULL,3,1,1,1,NULL,'onedieseldoctor\r\\'),(1360,767279333012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:09:00',0,NULL,8,1,17,0,NULL,'apisitpornpimol1'),(1361,690568513011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 03:16:15',0,NULL,3,1,1,1,NULL,'apisitpornpimol1\r再发一个NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg\r\\'),(1362,767320341012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 06:18:19',0,NULL,3,1,3,1,NULL,'bolocz\rCASS003\rRA117711515CN\r\\'),(1363,690610112011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','schweich777','schweich1991@gmail.com','Paul Schäfer','Brunnenstraße 5','Schweich','','GERMANY','54338','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 06:43:48',0,NULL,3,1,2,1,NULL,'schweich777\r\\'),(1364,568616354013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ezio1914','ezio1914@yahoo.com','ED  DeBatte','59 Drew Rd','Holmes','NY','UNITED STATES','12531-4505','(845) 536-1774','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-04 07:09:52',0,NULL,3,1,1,1,NULL,'ezio1914\\'),(1365,568620435013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','tampromise2010','tampromise@gmail.com','Diskov Igor','Diskov Igor<br>Shershneva 28-1','Belgorod','','RUSSIAN FEDERATION','308007','+79626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:35:19',0,NULL,3,1,2,1,NULL,'tampromise2010\r\\'),(1366,767341072012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','107okp','djrowell@bigpond.net.au','Dudley  R Rowell','18 Cosette Street','Bracken Ridge','Queensland','AUSTRALIA','4017','0732617161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:54:07',0,NULL,3,1,2,1,NULL,'107okp\r\\'),(1367,523060791004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','darkkevind','darkkevind@hotmail.com','Kevin Dark','Easier2move<br>4 Walls Yard','Rochford','Essex','UNITED KINGDOM','SS4 1GR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:28:34',0,NULL,3,1,3,1,NULL,'darkkevind\rWWSI005\rRA117711705CN\r\\'),(1368,767357879012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','kyeongjang','kyeongjinjang@empal.com','kyeongjin jang','5831 amapola dr','san jose','ca','UNITED STATES','95129-3056','(408) 777-9826','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 09:04:09',0,NULL,3,1,1,1,NULL,'kyeongjang\r\\'),(1369,690645839011,320394934550,'Acer Aspire 6920 6920G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',12.5,'eastar4','1979bfs','bfs1979@hotmail.com','Benjamin Fernández Santana','C/ TECEN 143','LAS PALMAS DE G.C.','Canarias','SPAIN','35009','606103656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:20:20',0,NULL,3,1,2,1,NULL,'1979bfs\racer 8pin0.8 16cm  \r\\'),(1370,568637074013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','hailingonme','dnaumoff@internode.on.net','David Naumoff','2 Macalpine Retreat Kinross','Perth','Western Australia','AUSTRALIA','6028','0407470759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:24:38',0,NULL,3,1,3,1,NULL,'hailingonme\rMOSA001\rRA117716129CN\r\\'),(1371,767370606012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','tara_1964','bluecatnl@gmx.net','Marleen van den Haak','Grimberg-Huijserstraat 3','Rotterdam','','NETHERLANDS','3066 JD','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 09:45:38',0,NULL,3,1,2,1,NULL,'tara_1964\r\\'),(1372,690671163011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','readydigital','readydigital@hotmail.com','Chon Han','2 Jalan Mutiara<br>#12-02 Mutiara Crest','Singapore','','SINGAPORE','249183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 10:52:29',0,NULL,3,1,11,1,NULL,'readydigital\r\\'),(1373,767398417012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.9,'eastar4','zholeynik','bhbl@mail.ru','Bobylev Andrei','pereulok Maikopski 12/2','Tuapse','Krasnodarski krai','RUSSIAN FEDERATION','352802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 11:34:22',0,NULL,3,1,2,1,NULL,'zholeynik\r\\'),(1374,517301920003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','crawl78','marco.mengotto@libero.it','Dell Italia - Marco Mengotto','Via Piero e Alberto Pirelli, 6, 2° Piano','Milano','MI','ITALY','20126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 11:41:52',0,NULL,3,1,3,1,NULL,'crawl78\rWLIN010\rRA117716194CN\r\\'),(1375,767421027012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','watsonct21','watsonct21@comcast.net','Chad Watson','17795 Idawood Path','Lakeville','MN','UNITED STATES','55044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 12:29:33',0,NULL,3,1,1,1,NULL,'watsonct21\r美标\r\\'),(1376,523104548004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','kafkasmurat','mmehtap@gelirler.gov.tr','Murat Mehtap','T.C. Maliye Bakanligi Gelir Idaresi Baskanligi Ek Hizmet Binasi<br>Yeni Ziraat Mah. Etlik Cad. No:16 Diskapi (Dahili:1220)','Ankara','TÜRKİYE','TURKEY','06110','+905334935701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 12:36:11',0,NULL,3,1,3,1,NULL,'kafkasmurat\rHSJA002欧标\rRA117711634CN\r\\'),(1377,523106934004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','racquetguys','twrussell1974@gmail.com','RCS Racquet Sports','31 Passmore Ave., Unit 3','Toronto','ON','CANADA','M1V 3H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 12:42:11',0,NULL,3,1,3,1,NULL,'racquetguys\rHSPL010\rRA117711625CN\r\\'),(1378,690708908011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','red.star.670','silviotaube@web.de','Silvio Taube','Akazienweg 12','Emmerich am Rhein','','GERMANY','46446','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 12:56:08',0,NULL,3,1,3,1,NULL,'red.star.670\r欧标HSJA002\rRA117711603CN\r\\'),(1379,568696544013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','phukk','phukk@bolina.hsb.se','Emil Janstad','Ellstorpsgatan 1A','Malmö','Skåne','SWEDEN','21217','0737-441007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 13:53:41',0,NULL,3,1,2,1,NULL,'phukk\r\\'),(1380,767437906012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','mu96ut99','nspiros@yahoo.com','NICOLE TUORI','8796 Jimson Ct','SYLVANIA','OH','UNITED STATES','43560-9828','(419) 517-3522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 14:04:55',0,NULL,3,1,1,1,NULL,'mu96ut99\r\\'),(1381,568696547013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mike-calitae','mike.kosovo@hotmail.co.uk','Michael MARDON','3 Cotterell Road<br>Broadclyst','EXETER','Devon','UNITED KINGDOM','EX5 3RZ','07854849867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:08:35',0,NULL,3,1,2,1,NULL,'mike-calitae\r\\'),(1382,767460823012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','ericjosefsson','eric.josefsson@gmail.com','Eric Josefsson','Ringgatan 5','Skänninge','','SWEDEN','59632','+46702705174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:20:38',0,NULL,3,1,2,1,NULL,'ericjosefsson\r欧标\r\\'),(1383,690741222011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','blueboyindy','billy.sexton@gmail.com','Bill Sexton','7055 Sandalwood Dr','Indianapolis','IN','UNITED STATES','46217-4141','(317) 313-8050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 14:29:56',0,NULL,3,1,1,1,NULL,'blueboyindy\rHP 8pin 1.25 25cm\r\\'),(1384,517346984003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','arthurreis','arthurrs@ig.com.br','Arthur Reis Santos','Rua Otto Bender, 137<br>Mandaqui','São Paulo','SP','BRAZIL','02418-030','(5511) 8119-6120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:01:37',0,NULL,3,1,3,1,NULL,'arthurreis\rMOSA002\rRA117716089CN\r\\'),(1385,767485203012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',31.3,'eastar4uk','rossash2008','colinaauchnie@hotmail.co.uk','COLIN AUCHNIE','7 WOODLANDS TURRIFF','TURRIFF','Aberdeenshire','UNITED KINGDOM','AB53 4BR','01888563836','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 15:25:41',0,NULL,3,1,3,1,NULL,'rossash2008\r英标  一共买了两个\rHSPL010\rRA117716163CN\r\\'),(1386,690764019011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','7tt','ttokio@gmx.net','Sayaka KIRA','Anzengruberstrasse 8/1','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:30:18',0,NULL,3,1,2,1,NULL,'7tt\racer 8pin1.00 8cm \r\\'),(1387,562931196013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',3,'OTCN001',11.97,'eastar4','montreal-pos','info@montreal-pos.com','Parvane - Laser Clinic','8381 Old Courthouse Rd<br>Ste 300','Vienna','VA','UNITED STATES','22182-3818','(514) 671-0346','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 16:49:18',0,NULL,3,1,1,1,NULL,'montreal-pos\r\\'),(1388,523179873004,140516095525,'New Logitech Rechargeable battery 890 880 950mA+charger',10,'BALO001+BAIN002',159.9,'cnfaner','bellobelli','mttoksoylu@live.com','Erkin Canoglu','330 College st','Amherst','MA','UNITED STATES','01002-2331','(401) 688-9025','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 17:17:57',0,NULL,3,1,1,1,NULL,'bellobelli\r\\'),(1389,690740044011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','anthonytjandra','anthony.tjandra@gmail.com','Sumahdi Jap','Blk 370G, Alexandra Rd, The Anchorage #15-10','default','','SINGAPORE','159960','6564726404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:30:27',0,NULL,3,1,11,1,NULL,'anthonytjandra\r\\'),(1390,767551600012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.69,'eastar4uk','hank2997','martyn.moore2@btopenworld.com','martyn moore','8 forest crescent<br>barncourt','omagh','tyrone','UNITED KINGDOM','bt784hs','07768671236','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 17:33:47',0,NULL,3,1,3,1,NULL,'hank2997\r英标   HSNO023\rRA117711475CN\r\\'),(1391,690823147011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','hughdale','aitalaakso@hotmail.com','Hannu Aitalaakso','Artemisgatan 5 B','Stockholm','','SWEDEN','11542','08-6640572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:39:09',0,NULL,3,1,2,1,NULL,'hughdale\r\\'),(1392,567545189013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',41.9,'eastar4','msadati','marcelo_adati@yahoo.com.br','Marcelo Suenaga Adati','Rua Ibituruna, 241<br>Apto 82','São Paulo','São Paulo','BRAZIL','04302-051','55 11 8115-4566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 17:54:31',0,NULL,3,1,3,1,NULL,'msadati\rHSNO019\rRA117716115CN\r\\'),(1393,523209562004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','eitanc57','eitan579@walla.co.il','eitan cohen','ein ganim 57','petah-tikva','','ISRAEL','49444','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 18:28:56',0,NULL,3,1,3,1,NULL,'eitanc57\rHSSA001\rRA117716061CN\r\\'),(1394,690838964011,320679562348,'New Sennheiser MX680i Adidas Sports Earphones for iPod',1,'HSSS004',29.59,'eastar4uk','glinn88','linn_rolland@hotmail.com','Linn Rolland','Kronstadveien 5E','Bergen','Bergen','NORWAY','5053','+4748116749','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 18:49:37',0,NULL,3,1,3,1,NULL,'glinn88\rHSSS004\rRA117711373CN\r\\'),(1395,690870363011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','airplay912','radovan.kukutsch@centrum.cz','Ivan Kana','Hobzikova 34','Opava','','CZECH REPUBLIC','74601','+420775698099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:13:10',0,NULL,3,1,2,1,NULL,'airplay912\r\\'),(1396,690877827011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','airplay912','radovan.kukutsch@centrum.cz','Radovan Kukutsch','P. Bezruce 1650','Petrvald u Karvine','','CZECH REPUBLIC','73541','+420775698099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:24:28',0,NULL,3,1,2,1,NULL,'airplay912\r\\'),(1397,568815384013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','oggiebackup','threads@gmail.com','Peter Ogborn','Flat 1<br>10 Shelley Close','Bournemouth','Dorset','UNITED KINGDOM','BH1 4JP','01202398861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:28:04',0,NULL,3,1,2,1,NULL,'oggiebackup\r\\'),(1398,767642297012,220594851730,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',9,'ANTY001*3',32.22,'eastar4','mattzank','mzank@att.net','Matthew J Zank','W229 N591 Foster Ct.','Waukesha','WI','UNITED STATES','53186','(262) 548-6235 ext.: 111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 19:50:09',0,NULL,3,0,1,1,NULL,'mattzank\r\\'),(1399,517454228003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','petrx1','jancax1@gmail.com','Petr Ludvík','Národní 1010','Prachatice','','CZECH REPUBLIC','38301','+420608982650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:51:41',0,NULL,3,1,3,1,NULL,'petrx1\rHSMO018\r欧标\rRA117716150CN\r\\'),(1400,523280807004,140516076074,'Logitech MX518 MX 518 Gaming Optical USB Mouse track#',1,'MOLO003',32.9,'cnfaner','danielquelha','daniel.quelha@gmail.com','Daniel Souza','Rua Hildebrando Cordeiro<br>30 - Casa','Curitiba','Paraná','BRAZIL','80740-350','(55) 41 3301-3818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 21:47:00',0,NULL,3,1,3,1,NULL,'danielquelha\rMOLO003\rRA117711435CN\r\\'),(1401,690956187011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','mightysmallballs','xayide@bredband.net','Henrik Sigfrid','Bäckalyckevägen 33E','Jönköping','','SWEDEN','55313','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:04:04',0,NULL,3,1,2,1,NULL,'mightysmallballs\r\\\r\r'),(1402,523287127004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',2,'HSMO008',27.98,'cnfaner','kururu_brazil','yonekura@terra.com.br','Marcos Yonekura','Rua Gomes Pedrosa, 70<br>Interlagos','São Paulo','São Paulo','BRAZIL','04805-340','8782-0686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:06:59',0,NULL,3,1,3,1,NULL,'kururu_brazil\rHSMO008\rRA117711360CN\r\\'),(1403,568875441013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','debcris1','sxcgal75@gmail.com','Debbie Connolly','87 Tindle st','Redbank Plains','Queensland','AUSTRALIA','4301','0400690792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:16:42',0,NULL,3,1,2,1,NULL,'debcris1\r澳标\r\\'),(1404,517499685003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 22:23:24',0,NULL,3,1,1,1,NULL,'crazystargrl\r\\'),(1405,767694204012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',35.88,'eastar4','dorothy2942','jywelborn@sbcglobal.net','dorothy welborn','840 redbud dr','redding','CA','UNITED STATES','96001-0141','(530) 243-7887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 22:25:47',0,NULL,3,1,1,1,NULL,'dorothy2942\r\\'),(1406,568884592013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','flobeetle','flolavillat@gmail.com','LAVILLAT FLORIAN','25 chemin de la bourdaine','SILLINGY','Rhône-Alpes','FRANCE','74330','06.18.89.84.05','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:54:17',0,NULL,3,1,3,1,NULL,'flobeetle\rMOSA002\rRA117711458CN\r\\'),(1407,767737186012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','guylaine2553','guylaine_duval@hotmail.com','guylaine duval','1041 ch. des sables','Ascot Corner','QC','CANADA','j0b1a0','(819) 829-0174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 23:14:28',0,NULL,3,1,2,1,NULL,'guylaine2553\r\\'),(1408,767738105012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',4,'HSSH001',143.96,'eastar4','imdelaw1','shirankochavi@yahoo.com','NRG Energy, Inc.    Attn: Shiran Kochavi','211 Carnegie Ctr','Princeton','NJ','UNITED STATES','08540-6213','(609) 240-7838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 23:20:36',0,NULL,3,1,1,1,NULL,'imdelaw1\r\\'),(1409,767736350012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','jazz3303','userco9863@aol.com','Barry R Cook','316 RUTLEDGE AVENUE','EAST ORANGE','NJ','UNITED STATES','07017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 23:20:50',0,NULL,3,1,1,1,NULL,'jazz3303\r\\'),(1410,568900856013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','wittaya.r','wittaya_r@msn.com','WITTAYA ROCHKITTICHAROEN','91/511 Ramintra 44 Ramintra road','Buengkum','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:07:58',0,NULL,3,1,2,1,NULL,'wittaya.r\r\\'),(1411,517523284003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','elci_rbr','elayaraja.kasirajan@gmail.com','Elayaraja Kasirajan','250 Main St<br>Apt 524','Hartford','CT','UNITED STATES','06106-1872','(860) 816-0754','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 00:12:36',0,NULL,3,1,1,1,NULL,'elci_rbr\r\\'),(1412,691015937011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bls851','brandi_lee22@hotmail.com','Brandi Swystun','36 Howell Avenue','Saskatoon','SK','CANADA','S7L 3S8','(306) 370-8008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:52:58',0,NULL,3,1,2,1,NULL,'bls851\r\\'),(1413,767771361012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','johnnyray59','raydeb2007@intrstar.net','Johnny Daughtry','599 Bernice Rd','Clinton','NC','UNITED STATES','28328','(910) 533-2058','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 01:04:30',0,NULL,3,1,1,1,NULL,'johnnyray59\\'),(1414,568912661013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','marinaside0','lmmrogers@hotmail.com','lesley rogers','501-1560 homer mews','vancouver','BC','CANADA','v6z 0a5','(604) 648-2114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:05:03',0,NULL,3,1,2,1,NULL,'marinaside0\r\\'),(1415,691022682011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','electricbug2007','electricbug@gmail.com','Matt Tibold','25 Neltner Drive','St. Andrews','MB','CANADA','R1A 3A4','(204) 338-9438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:18:35',0,NULL,3,1,2,1,NULL,'electricbug2007\r\\'),(1416,568921329013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',2,'WLDL001',16.7,'eastar4','amehanna-50','ahmed.mehanna@mcphs.edu','ahmed mehanna','6 Fairhaven Cir','Sudbury','MA','UNITED STATES','01776-2041','(978) 443-1474','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 01:41:39',0,NULL,3,1,1,1,NULL,'amehanna-50\r÷'),(1417,523334666004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',13.99,'cnfaner','ftho7291','galalica@aol.com','Frankie Thomas','1733 N E 4th AVE.','Gainesville','FL','UNITED STATES','32641','(352) 376-0160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 01:57:10',0,NULL,3,1,1,1,NULL,'ftho7291\r\\'),(1418,568928999013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','adrianevale','adrianevale@hotmail.com','Gerson Silva','CAVP, Chacara 03 Casa 18 - Rua do Joquey<br>Colonia Agricola Vicente Pires,','BRASÍLIA','DISTRITO FEDERAL','BRAZIL','72005115','55 61 84740000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 02:13:31',0,NULL,3,1,3,1,NULL,'adrianevale\rOTRA002\rRA117711413CN\r\\'),(1419,568941581013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','dogarr','dogarr@hotmail.com','James Diggs','301 advance stage tabata<br>1-27-12 tabata shinmachi, Kita-Ku','Tokyo','Tokyo','JAPAN','1140012','09091079603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 03:17:54',0,NULL,3,0,3,1,' ','dogarr\rMOLO003\rRA117711395CN\r\\'),(1420,767837351012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',6,'TRMX003',47.7,'eastar4','adeptmaster','rokeeffe@twcny.rr.com','Robert OKeeffe','7664 1/2 Thompson Rd','North Syracuse','NY','UNITED STATES','13212-1853','(315) 263-8544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 05:28:44',0,NULL,3,1,1,1,NULL,'adeptmaster\r\\'),(1421,691088217011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gunm83','jimmy.gallet@laposte.net','GALLET Jimmy','Rés. Coletto Bat A3, 2e etage porte droite','Cogolin','Provence-Alpes-Côte d\'Azur','FRANCE','83310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 06:25:54',0,NULL,3,1,2,1,NULL,'gunm83\r\\'),(1422,767865900012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hawkeyeru','hawkeye@rbcmail.ru','Alexander Paramonov','22 Partsjezda, 173a-66<br>173a-66','Samara','Samara region','RUSSIAN FEDERATION','443081','8-919-800-2473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 07:46:55',0,NULL,3,1,2,1,NULL,'hawkeyeru\r\\'),(1423,568984209013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','wmkarelia','mikolaptz@mail.ru','Nikolay Suykonen','Baltiyskaya 65, flat 33','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185026','+7 911-400-32-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 08:30:54',0,NULL,3,1,2,1,NULL,'wmkarelia\r\\'),(1424,767877733012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','stephens1105','stephen1105@yahoo.com','Stephen Steeneck','2676 Old Yorktown Rd','Yorktown Heights','NY','UNITED STATES','10598-3139','(914) 302-6965','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 08:38:50',0,NULL,3,1,1,1,NULL,'stephens1105\r\\'),(1425,691133541011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','fanchheiz','fanchheiz@hotmail.fr','francois graindorge','kerascoet','treouergat','Bretagne','FRANCE','29290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 09:57:33',0,NULL,3,1,2,1,NULL,'fanchheiz\r\\'),(1426,569000156013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',50.64,'eastar4','murzilich','chip_set@inbox.ru','Ks\'onzenko Sergey','Geroiv Dnipra street, 18','Petrivske village','Kiev','UKRAINE','08141','+380505974862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:07:00',0,NULL,3,1,3,1,' ','murzilich\rCACN004\rRA117711356CN\r\\'),(1427,691135791011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','ian.chapman','ian.chapman@amiga-hardware.com','Ian Chapman','Woodside Plaza<br>240 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','0405841783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:08:02',0,NULL,3,0,2,1,NULL,'ian.chapman\r\\'),(1428,691139053011,320598677665,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card not IBM',1,'WLIN012',50.3,'eastar4','terra_operative','jaredcabot@live.com.au','Jared Cabot','37 Condamine Street','Runcorn','Queensland','AUSTRALIA','4113','0412556660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:19:54',0,NULL,3,1,3,1,NULL,'terra_operative\rWLIN012\rRA117711339CN\r\\'),(1429,517624216003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','555linas','lalminas@hotmail.com','Leandras Alminas','Debreceno 34-50','Klaipeda','','LITHUANIA','94147','+37068256018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 10:57:32',0,NULL,3,1,3,1,NULL,'555linas\rHSNO008   欧标\rRA117711311CN\r\\'),(1430,767929856012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','borilt','borilt@gmail.com','Tomas Boril','Vackova 378','Liberec 23','','CZECH REPUBLIC','46312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 11:54:30',0,NULL,3,1,2,1,NULL,'borilt\r\\'),(1431,767942829012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',59.99,'eastar4','taimou','taimou@gmail.com','Richard Chuck','Level 3, 2 Dawn Fraser Avenue<br>Sydney Olympic Park','Sydney','New South Wales','AUSTRALIA','2127','0424159107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 12:40:07',0,NULL,3,1,3,1,NULL,'taimou\rKBLO001\rRA117713564CN\r\\'),(1432,767951408012,220653561343,'New Atheros DualBand AR9287 Wireless  Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','42galli','guellenstern@ifdnet.com','Markus Güllenstern','Riemekestr. 107','Paderborn','','GERMANY','33102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:01:00',0,NULL,3,1,2,1,NULL,'42galli\r\\'),(1433,767951660012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','norlo21','norlo_21@hotmail.com','NORBERTO LOPEZ','laguna de la magdalena 261<br>ventura puente','morelia','michoacan','MEXICO','58020','443-312-13-24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:02:58',0,NULL,3,1,2,1,NULL,'norlo21\r\\'),(1434,517649322003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','jamesallmond','jamesallmond@cox.net','James Allmond','640 Forest Lake Dr N','Macon','GA','UNITED STATES','31210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 13:03:56',0,NULL,3,0,1,1,NULL,'jamesallmond\r\\'),(1435,767955049012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wuestenwirt5','pe-ge@web.de','Gehring Peter','Balingerstrasse 52','Balingen-Frommern','','GERMANY','72336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:11:36',0,NULL,3,1,2,1,NULL,'wuestenwirt5\r\\'),(1436,691201843011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','alligator626','alligator626ge@yahoo.com','Anton Ivanov','Obuhovskoy Oborony prospekt, 21-47<br>+7(905)209-2509','St.Petersburg','','RUSSIAN FEDERATION','192019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 14:00:21',0,NULL,3,1,2,1,NULL,'alligator626\r\\'),(1437,691241847011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','hugo7098','hgermain@cablovision.com','Hugo Germain','5 rue perrault','warwick','QC','CANADA','j0a1m0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:51:26',0,NULL,3,1,3,1,NULL,'hugo7098\rRCLO006\rRA117711387CN\r\\'),(1438,691247683011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','ur2sirius','chwatd@verizon.net','Dennis Chwat','1613 9th St','Manhattan Beach','CA','UNITED STATES','90266-6128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 16:05:43',0,NULL,3,1,1,1,NULL,'ur2sirius\rHP 8pin 1.0 3cm\\'),(1439,517694918003,130489927197,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'cnfaner','corp2k','multi2k@hotmail.com','SeungJae Lee','111-705 Hankang APT Kayang1-Dong<br>Kangseo-Gu Seoul','default','','KOREA,REPUBLIC OF','157-752','+821020425207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:17:18',0,NULL,3,1,3,1,NULL,'corp2k\rOTHP003\rRA117711648CN\r\\'),(1440,521427086004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','keyvan.akrami','keyvanakrami@yahoo.com','keyvan akrami','5055 w hacienda ave<br>Unit 1017','Las Vegas','NV','UNITED STATES','89118-0324','(702) 409-2342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 16:44:42',0,NULL,3,1,1,1,NULL,'keyvan.akrami\r\\'),(1441,691276975011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','doron-se','doronse@hotmail.com','Doron Senger','Orlanskey 21/9','Petach Tikva','','ISRAEL','49571','972-54-7444217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:14:47',0,NULL,3,1,2,1,NULL,'doron-se\r\\'),(1442,517720841003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','yorgovan*','yohann@desygn.fr','Yohann GILLES','1465, avenue de Maurin<br>Cité fleurie - D7','MONTPELLIER','Languedoc-Roussillon','FRANCE','34000','0467693390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:38:20',0,NULL,3,1,3,1,NULL,'yorgovan*\rHSMO011   欧标\rRA117716132CN\r\\'),(1443,691290431011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','mountduke2004','dirk.ermert@t-online.de','Dirk Ermert','Eichenweg 1','Bergheim','','GERMANY','50126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:47:46',0,NULL,3,1,2,1,NULL,'mountduke2004\r\\'),(1444,768069087012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:49:44',0,NULL,3,1,2,1,NULL,'annaandythai\r\\'),(1445,768075533012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',5,'CASS002',43.5,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:58:05',0,NULL,3,1,3,1,NULL,'newdimension2011\rCASS002\rRA117711461CN\r\\'),(1446,569119122013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','ladean6562','dietblkchic@yahoo.com','ladean graham','1010 Hunterstone Dr<br>Apt 203','leland','NC','UNITED STATES','28451','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 18:06:07',0,NULL,3,1,1,1,NULL,'ladean6562\r\\'),(1447,517736295003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','mccragger1337','mccragger@web.de','Christoph Neikes','Weseler Straße 139','Oberhausen','','GERMANY','46149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:19:29',0,NULL,3,1,3,1,NULL,'mccragger1337\rHSUE004\rRA117716146CN\r\\'),(1448,691311094011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','felipeveiga','felipeveigapedreiro@hotmail.com','Felipe Veiga Pedreiro','Setor Oeste, Rua 9, N° 1000, Ed. Quarup, Apto 701','Goiânia','Goiás','BRAZIL','74120010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:22:05',0,NULL,3,0,3,1,NULL,'felipeveiga\rUDAP001\rRA117711563CN\r\\'),(1449,768089821012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','wheaton-2001','asalmon@salmonfamily.com','andrew salmon','85 Beaumont Dr','northbridge','MA','UNITED STATES','01534-1093','(617) 835-2225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 18:22:54',0,NULL,3,1,1,1,NULL,'wheaton-2001\r\\'),(1450,768091016012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',42.76,'eastar4','gadgetsthestreak','ismith000@sympatico.ca','Ian Smith','6 Willowdale Crescent','Port Dover','ON','CANADA','N0A 1N5','(519) 583-0751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:26:43',0,NULL,3,1,3,1,NULL,'gadgetsthestreak\rOTAP001\rRA117711501CN\r\\'),(1451,768095580012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',2,'WLDL001',11.5,'eastar4uk','erwepero','chapy_1969@hotmail.com','jaume sanchez rincon','avd. catalunya 123','la granada del penedes','Cataluña','SPAIN','08792','938975009','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 18:33:14',0,NULL,3,1,2,1,NULL,'erwepero\r\\'),(1452,517743438003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',32.49,'cnfaner','singingfrogscom','stremayne@sbcglobal.net','Scott Tremayne','539 Thistle Circle','Martinez','CA','UNITED STATES','94553','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 18:40:00',0,NULL,3,1,1,1,NULL,'singingfrogscom\r再发一个新的蓝电池\r\\'),(1453,768112780012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','techiebulldog','chanh@thao.ca','chanh thao','5055 Heatherleigh Ave, unit #100','Mississauga','ON','CANADA','L5V2R8','(905) 502-1999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 19:01:23',0,NULL,3,1,2,1,NULL,'techiebulldog\r\\'),(1454,768020569012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',41.75,'eastar4','bigbadtxwolf','other@bthomas.us','William Thomas','1500 Plantation Oaks Dr<br>Apt 104','Trophy Club','TX','UNITED STATES','76262-5551','(682) 502-4768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 19:10:06',0,NULL,3,0,1,1,NULL,'bigbadtxwolf\r一共买了五个\r\\'),(1455,516876153003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','gio-manou','gioman13@gmail.com','GIORGOS MANOUSOPOULOS','IATROPOULOU 1','KALAMATA','MESSINIA','GREECE','24100','27210-93563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 19:22:01',0,NULL,3,1,3,1,NULL,'gio-manou\r欧标  HSMO006\rRA117711546CN\r\\'),(1456,691359080011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','al8983h','kimyun@aol.com','ALLAN HEW','18231 Barroso St','Rowland Heights','CA','UNITED STATES','91748-4404','(626) 965-2723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 19:48:23',0,NULL,3,1,1,1,NULL,'al8983h'),(1457,768163801012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','robert_david','robert.david.public@gmail.com','Robert David','Kobyliska 24','Prague 8','Czech','CZECH REPUBLIC','18400','+420602343607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:30:18',0,NULL,3,1,2,1,NULL,'robert_david\r\\'),(1458,569180290013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','giroudf','francois.giroud@che.dupont.com','francois GIROUD','14 ch des Marais','Cointrin','GENEVA','SWITZERLAND','1216','41227175058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:41:08',0,NULL,3,1,3,1,NULL,'giroudf\rOTRA002\rRA117711585CN\r\\'),(1459,523570899004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sagibit1','rinatt14@walla.com','Rinat Biton','Mor 5','Arad','Israel','ISRAEL','89066','972506437518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 20:42:24',0,NULL,3,1,3,1,NULL,'sagibit1\rOMHJ001\rRA117711532CN\r\\'),(1460,768180745012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','markcata','mcatalanot@aol.com','Mark Catalanotti','313 N Broadway<br>Apt 2','Redondo Beach','CA','UNITED STATES','90277-2800','(310) 798-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 21:03:54',0,NULL,3,1,1,1,NULL,'markcata\r\\'),(1461,569197214013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','819gary','grailer1@telus.net','Gary Railer','480 Mount Belcher Hts','Salt Spring Island','BC','CANADA','V8K 2J6','(250) 537-4207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:33:41',0,NULL,3,1,2,1,NULL,'819gary\r\\'),(1462,768196958012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','saitay1133','saitay@btinternet.com','sait ay','35 guernsey house<br>clifton road','lodon','London','UNITED KINGDOM','n1 2tr','07917441963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:37:42',0,NULL,3,1,2,1,NULL,'saitay1133\r\\'),(1463,691417546011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.8,'eastar4','kbechr','kyrib80-eshops@yahoo.gr','Bechrakis Kyriakos','26 Aristeidoy Street Cholargos','Athens, Greece','','GREECE','15562','00306972922291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:53:03',0,NULL,3,1,3,1,NULL,'kbechr\rMOSA001\rRA117711594CN\r\\'),(1464,569204384013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','spirow590046','spirow59@hotmail.com','Agne Mattsson','Ostra Storgatan 41','Gnesta','','SWEDEN','64632','0046705617098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 21:59:56',0,NULL,3,1,2,1,NULL,'spirow590046\r\\'),(1465,517811560003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','has.hc','haspel@gmx.at','Mathias Haspel','Bonygasse 37/1<br>Krautgartner z.Hd Haspel','Vienna','Wien','AUSTRIA','1120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:03:25',0,NULL,3,1,3,1,NULL,'has.hc\rWWSI002+ANCN001\rRA117711489CN\r\\'),(1466,517814167003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','emrahsteel','emrahcelik@msn.com','EMRAH CELIK','ALTINTEPE MAH.GALIPBEY CD. DEFNE SOK. MELTEM APT. 8/19 MALTEPE','ISTANBUL','','TURKEY','34840','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:16:56',0,NULL,3,1,3,1,NULL,'emrahsteel\rHSNO008  欧标\rRA117711492CN\r\\'),(1467,691426114011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sybercy','dersarasi@hotmail.com','Sinan Can Ertanhan','Basak Sok. Selen Apt. No:36 B-Blok D:B1 Yesilyurt','Istanbul','','TURKEY','34149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:17:13',0,NULL,3,1,2,1,NULL,'sybercy\r\\'),(1468,768220458012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','chub_21','jchan_21@hotmail.com','Jason Chan','605 West Kent Avenue<br>Mattson Technology Canada','Vancouver','BC','CANADA','V6P6T7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 22:39:31',0,NULL,3,1,2,1,NULL,'chub_21\r\\'),(1469,569225676013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','bigal1016','ans1050@verizon.net','Allen Strauss','50 Vender lane','Mays Landing','NJ','UNITED STATES','08330','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-05 23:32:38',0,NULL,3,1,1,1,NULL,'bigal1016\r\\'),(1470,691454616011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',67.9,'eastar4','half-mvsa','dragonbooster_93@hotmail.com','Marinalva Assunção','Av. Professor Plínio Bastos, bairro: Olaria<br>Casa nº: 530','Rio de Janeiro','Rio de Janeiro','BRAZIL','21021-350','55 (21) 22600131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:57:22',0,NULL,3,1,3,1,NULL,'half-mvsa\rHSSE006\rRA117711550CN\r\\'),(1471,569234866013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'',40.99,'eastar4','resnos','kenny.befus@gmail.com','Kenny Befus','6500 Champion Grandview Way<br>#35104','Austin','TX','UNITED STATES','78750','(512) 904-9989','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 00:18:13',0,NULL,3,0,1,1,NULL,'resnos\r\\'),(1472,569241005013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','jlondon141','jlondon141@insightbb.com','Jonathan A London','826 Fern Hill St','Bowling Green','KY','UNITED STATES','42101-4450','(270) 991-8904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 00:48:43',0,NULL,3,1,1,1,NULL,'jlondon141\racer 4pin1.25 15cm\r\\'),(1473,768275741012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','policebrat58','walterjbrown@yahoo.com','Walter  J Brown','562 Roark Trce','Montgomery','AL','UNITED STATES','36116-6327','(334) 284-1443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 01:46:49',0,NULL,3,1,1,1,NULL,'policebrat58\r\\'),(1474,767265405012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','flakeyfriend','melan1e@embarqmail.com','Melanie A. Huffnagle/Peters','160 W Railroad St','Reedsville','PA','UNITED STATES','17084-9120','(717) 667-9804','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:36:26',0,NULL,3,1,1,1,NULL,'flakeyfriend\r\\'),(1475,517866456003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','vira509','dennisvira@msn.com','Vira Garbisch','16434 N Sunrise Dr','Nine Mile falls','WA','UNITED STATES','99026-9464','(509) 468-2283','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:48:03',0,NULL,3,1,1,1,NULL,'vira509\r\\'),(1476,569272468013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','3cardtrick','deuce@mouseheaddesign.com','Andrew Dickinson','186 Wellington Street<br>Unit 1','Kingston','ON','CANADA','K4L 3E4','(613) 583-5221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:21:31',0,NULL,3,1,2,1,NULL,'3cardtrick\r\\'),(1477,517873579003,130504141009,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','shakeydddd','shakey4d@yahoo.com.au','Matt Ford - Fire Unit','Level 1, 10 Valentine Ave','Parramatta','New South Wales','AUSTRALIA','2150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:43:38',0,NULL,3,0,3,1,NULL,'shakeydddd\r红色的\rRA117712095CN\r、'),(1478,569277531013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','spallumcheen','hythrax@hotmail.com','sameer harji','212 Alfred Paterson Dr','Markham','ON','CANADA','L6E 2E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:54:59',0,NULL,3,1,3,1,NULL,'spallumcheen\rMOSA002\r\rRA117711166CN\r\\'),(1479,768309126012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',37.45,'eastar4','saccin76','habbaji@gmail.com','Tae-Kwang, Youn','BITEK SYSTEM INC. Rm.719 Doosan Venture Digm, 126-1<br>Pyengchon-dong','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-070','82-10-9289-5389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 03:56:02',0,NULL,3,1,3,1,NULL,'saccin76\rWWSI002\rRA117711197CN\r\\'),(1480,0,320674543349,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 04:50:57',0,NULL,3,0,1,1,NULL,'michael2289xd\r一共要发四个  都是 细头的\rLK037352629CN \r\\'),(1481,768324560012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','guntastic','jgunty@nd.edu','Joshua Gunty','5459 S Cornell Ave<br>1-RR #104','Chicago','IL','UNITED STATES','60615-5769','(574) 309-2844','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:10:02',0,NULL,3,1,1,1,NULL,'guntastic\r\\'),(1482,768326973012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','andrewg105','andyg105@hotmail.co.uk','Andrew George','105 Trent Road<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 05:23:17',0,NULL,3,1,3,1,NULL,'andrewg105\r英标  银色带花的 HSSE005\rRA117716282CN\r\\'),(1483,569290079013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','waoma4jc','waoma@naver.com','Dong Hyun Kwon','156 Point DR Apt 60','Lynchburg','VA','UNITED STATES','24502','(434) 851-6066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:25:42',0,NULL,3,1,1,1,NULL,'waoma4jc\r\\'),(1484,569291218013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','danval82','snowball122782@yahoo.com','Daniel A Valencia Jr.','11449 Rancho La Brea Dr.','Riverside','CA','UNITED STATES','92505','(951) 809-1713','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 05:36:32',0,NULL,3,1,1,1,NULL,'danval82\r\\'),(1485,523679191004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',22.28,'cnfaner','shopdrop247','fx1@tx.rr.com','GORDON DUNKIN','1105 Green Meadow Dr','RICHARDSON','TX','UNITED STATES','75081','(972) 249-5333','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 06:44:53',0,NULL,3,1,1,1,NULL,'shopdrop247\r再发一个New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh\r\\'),(1486,523683840004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','kochegin87','kochegin@gmail.com','Mikhail Kochegin','mkr. Aksai-2, d.7, kv.19','Almaty','KZ','KAZAKHSTAN','050031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 07:31:53',0,NULL,3,1,3,1,NULL,'kochegin87\r\\\rRA117711183CN\r'),(1487,768365720012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','zagorskasa','azagorskas@gmail.com','Nomeda Zagorskiene','Didlaukio 58-58','Vilnius','Lietuva','LITHUANIA','LT-08328','+370 655 45454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:27:28',0,NULL,3,1,2,1,NULL,'zagorskasa\r欧标\\'),(1488,768366777012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',15,'TRMX003',125.25,'eastar4','osi-network','osinetworks@orange.fr','COM 2 NETWORKS SAS','10 rue des Gaudines<br>Strategy Center - Bat D','SAINT-GERMAIN-EN-LAYE','Ile-de-France','FRANCE','78100','0139040221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:32:09',0,NULL,3,0,3,1,NULL,'osi-network\r发210T\rTRTT002*15\r\rRA117716835CN\r\\'),(1489,569315977013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','vearutop','nanopeni@gmail.com','Vyacheslav Poturaev','per. Novyi, 1 kv. 97','Tomsk','Tomskaya','RUSSIAN FEDERATION','634006','9039148918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:33:11',0,NULL,3,1,2,1,NULL,'vearutop\\'),(1490,517913155003,130458644390,'New GENUINE NOKIA BH-300 BLUETOOTH HEADSET track#',1,'HSNO013',15.6,'cnfaner','lvelikov','llv@mail.bg','Lyubomir Velikov','Kubrat 14 str.','Samuilovo','Sliven','BULGARIA','8865','+359899572010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:36:44',0,NULL,3,1,3,1,NULL,'lvelikov\r欧标  HSNO013\rRA117716296CN\r\\'),(1491,569316264013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','thegabber007','louis.vanlancker@hotmail.com','Louis Van Lancker','Rue de Cayoit 58','Leuze-en-Hainaut','','BELGIUM','7903','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:37:42',0,NULL,3,1,2,1,NULL,'thegabber007\\'),(1492,517914332003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','yousef.elaiwat','yousef66@gmail.com','Yousef Elaiwat','Mob: +966503834834<br>P.O.Box 13215','Qatif','Eastren','SAUDI ARABIA','31911','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 08:42:33',0,NULL,3,1,3,1,NULL,'yousef.elaiwat\rRCLO002\rRA117716225CN\r\\'),(1493,523704937004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sicabe1','capraro@pacific.net.sg','Silvana Hobcraft-Capraro','Via della Pace 20A','Locarno','','SWITZERLAND','6600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 09:32:23',0,NULL,3,1,3,1,NULL,'sicabe1\rOMHJ001\rRA117713649CN\r\\'),(1494,768384469012,220763389217,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',15,'WWSI006',555,'eastar4uk','sjh34','c4steve@gmail.com','Stephen Hall (Icomera)','Innovation Centre Medway<br>Maidstone Road','Chatham','Kent','UNITED KINGDOM','ME5 9FD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 09:43:00',0,NULL,3,1,12,1,NULL,'sjh34\r\r2182244820\r'),(1495,569109370013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','prasangaperera2010','ebayprasanga@gmail.com','K L O Prasanga Perera','222-14-B Warahanthuduwa Road,<br>7th Lane Mihindu Mawatha,mahara,','Kadawatha','Western','SRI LANKA','11850','094773471320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 09:52:05',0,NULL,3,1,2,1,NULL,'prasangaperera2010\r、'),(1496,768394279012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','delchicharro','delchicharro@hotmail.com','Juan P. Jiménez Rodríguez','C/ Verode, 27   (Urbaniz. GUAJARA)<br>La Laguna','Santa Cruz de Tenerife','Canarias','SPAIN','C.P.38296','629986246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:22:37',0,NULL,3,1,2,1,NULL,'delchicharro\r、'),(1497,569335828013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','troedel-jan','a.lexow@web.de','A. Lexow','Geschwister - Scholl - Strasse  04','Schöneiche','','GERMANY','15566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:36:17',0,NULL,3,1,2,1,NULL,'troedel-jan\r\\'),(1498,765215428012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','greg34gilles','ben1966@live.ca','gilles jutras','385 marquis','st-celestin','QC','CANADA','j0c 1g0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 10:50:25',0,NULL,3,1,2,1,NULL,'greg34gilles\r\\'),(1499,691601055011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',15,'eastar4','hell-20','aktasmami@hotmail.com','muhammet aktaş','karşıyaka mah. 2439/1 sokak no:27','denizli','türkiye / denizli / merkez','TURKEY','20200','05363708578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:53:24',0,NULL,3,1,2,1,NULL,'hell-20\r欧标\r\\'),(1500,761868269012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','frs_709','frs709@gmail.com','Haotian Wu','Snapphanevägen 6B,lgh 86','Karlskrona','Blekinge','SWEDEN','37140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:12:58',0,NULL,3,1,2,1,NULL,'frs_709\r\\'),(1501,691613204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','eabrahams10','eabrahams_07@hotmail.com','Enrique Romero','PO BOx 742','Culebra','PR','UNITED STATES','00775-0742','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eabrahams10'),(1502,768418259012,220448682374,'Acer Aspire 4720 4720G 4720Z Bluetooth Module 2.0+cable',1,'BTAC2014',12.5,'eastar4','juliaf1949julia','juliaf1949@hotmail.com','Julia Fernandez','K31 Calle 9<br>La Monserrate','Hormigueros','PR','UNITED STATES','00660-1600','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 11:45:54',0,NULL,3,1,1,1,NULL,'juliaf1949julia\racer 5pin1.25 20cm \r\\'),(1503,691617095011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','efs.com','zefel@rogers.com','Efraim Fishman','ACCURA CANADA<br>25 Curity Avenue, Unit 2A','Toronto','ON','CANADA','M4B 3M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:54:03',0,NULL,3,1,2,1,NULL,'efs.com\r\\'),(1504,768425598012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','hengtip','thadanabathptyltd@hotmail.com','Late Night Chemist Ryde','Shop 1/46-48 Blaxland Rd','Ryde','New South Wales','AUSTRALIA','2112','0298093928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 12:14:42',0,NULL,3,1,3,1,NULL,'hengtip\rOTGR001+OTGR002\rRA117713652CN\r\\'),(1505,768449353012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','jdpetrov69','jdpetrov@yahoo.com','Jovica Petrovski','14553 Barton Dr','Washington Township','MI','UNITED STATES','48094-3240','(586) 786-0275','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:23:01',0,NULL,3,1,1,1,NULL,'jdpetrov69\r\\'),(1506,0,320681209046,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11.5,'eastar4','mexavon','mexavon@twcny.rr.com','Chet  Hains','84 Ames St','Mexico','NY','UNITED STATES','13114-3217','(315) 963-7357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:40:15',0,NULL,3,1,1,1,NULL,'mexavon\r\\'),(1507,0,220765092420,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.49,'eastar4','mpsketch','paypal@mpsketch.com','Matt Proctor','2749 Ella Rae Ct','Lexington','KY','UNITED STATES','40511-8609','(859) 533-6555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:42:08',0,NULL,3,1,1,1,NULL,'mpsketch\r\\'),(1508,0,320681208154,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','ghondo2000','ghondo@optonline.net','Gary Parlotto','30 Smokey Ridge Rd','Ringwood','NJ','UNITED STATES','07456-1930','(973) 831-7628','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 13:45:39',0,NULL,3,1,1,1,NULL,'ghondo2000\r\\'),(1509,517974571003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',34.68,'cnfaner','1805erika','erikaperniah@gmail.com','Erika Belinda Pernia Hernandez','Via Fonte Casella, 15','Montegranaro','Ascoli Piceno','ITALY','63014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:09:15',0,NULL,3,1,3,1,NULL,'1805erika \r欧标 HSMO006+HSMO016\r再发一个New Motorola H800 Bluetooth Wireless Headset \rRA117713618CN\r\\'),(1510,768471588012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','rabbitsfoot01','ltlowen@lowen.net','Lawrence T. Lowen','2 Executive Dr<br>Ste 560','Fort Lee','NJ','UNITED STATES','07024-3307','(201) 592-1700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 14:27:34',0,NULL,3,1,1,1,NULL,'rabbitsfoot01\r\\'),(1511,569387971013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','chacacy','xdahermes@yahoo.co.jp','Kazuyuki Matsuo','5,22,19,202 Kitazawa Setagaya','Tokyo','Tokyo','JAPAN','1550031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:38:49',0,NULL,3,1,2,1,NULL,'chacacy\r\\'),(1512,569395570013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','platerb','platerb@gmail.com','Berl Stein','15 Ryder Cup Cir','Pittsford','NY','UNITED STATES','14534-1083','(585) 576-0977','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 15:10:55',0,NULL,3,1,1,1,NULL,'platerb\r\\'),(1513,768490437012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','jasambond','vedran_radonic@yahoo.com','Vedran Radonić','Milana Rešetara 12','Zagreb','','CROATIA','10090','0922055172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 15:17:03',0,NULL,3,1,11,1,NULL,'jasambond\r\\'),(1514,518004836003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','easyleads','nlpbc@optonline.net','Mike J Lofrano','32 N Boston Rd','Jackson','NJ','UNITED STATES','08527-2452','(732) 240-9017','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 16:15:53',0,NULL,3,0,1,1,NULL,'easyleads\r\\'),(1515,0,320674798969,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',5.99,'eastar4','michael2289xd','ms_luckyman@hotmail.com','Michael Song','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 17:16:36',0,NULL,5,0,18,0,NULL,'michael2289xd'),(1516,768571951012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','ogaefumadr','sng@eircom.net','Stephen Graham','17 Devenish Road<br>Kimmage','Dublin','Dublin','IRELAND','12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 18:14:25',0,NULL,3,1,3,1,NULL,'ogaefumadr\rRELO002\rRA117713621CN\r\\'),(1517,768575731012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','teal157','mauricefermoy@lineone.net','Maurice Fermoy','Handywater Farm<br>Sibford Gower','Banbury','Oxon','UNITED KINGDOM','OX15 5AE','07974303058','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 18:21:00',0,NULL,3,1,3,1,NULL,'teal157\rHSNO005  英标\rRA117713706CN\r\\ '),(1518,691765629011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','marcelobeltrame','marcelotrame@gmail.com','Marcelo BELTRAME','R. JOAQUIM ANTUNES, 852 AP22B<br>PINHEIROS','São Paulo','SP','BRAZIL','05415-001','55 11 94953331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 18:31:30',0,NULL,3,1,3,1,NULL,'marcelobeltrame\rUDAP001\r\rRA117716866CN\r\\'),(1519,569476528013,230576481551,'10 pcs AUI Ethernet 10Base-T RJ45 Transceiver track#',5,'TRMX003*10',375,'eastar4','tnetusa','ebay@tnetus.com','T-NET TECHNOLOGY INC.','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(718) 369-3828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 19:15:54',0,NULL,3,0,4,1,NULL,'tnetusa\rYW864489110CN\r'),(1520,518061862003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'',31.98,'cnfaner','darradserv','david@darrad.com','DARRAD Services','4457 Main St','Waitsfield','VT','UNITED STATES','05673-6028','(802) 496-2772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 19:16:58',0,NULL,3,1,1,1,NULL,'darradserv\r\\'),(1521,569486896013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',12.5,'eastar4','pascal2be','pascalvanpraet@hotmail.com','pascal vanpraet','kleine klijtstraat 48','deerlijk','','BELGIUM','8540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:41:37',0,NULL,3,1,2,1,NULL,'pascal2be\r\\'),(1522,518072578003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',4,'OTJE001',63.6,'cnfaner','negraesimports','cesarnegraes@gmail.com','CESAR LUIZ NEGRAES','RUA DAS PALMEIRAS, 283 AP. 58<br>SANTA CECILIA','SÃO PAULO','São Paulo','BRAZIL','01226-010','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-06 19:45:28',0,NULL,3,1,3,1,NULL,'negraesimports\rOTJE001\rRA117713697CN\r\\'),(1523,768630616012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:56:14',0,NULL,3,1,3,1,NULL,'solopo2009\rHSPL010  只发耳机  不给电源\rRA117713666CN\r\\'),(1524,569496974013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','talie1708','talie17@hotmail.com','nathalie beaumard','16 allee antoine sartori','alfortville','Île-de-France','FRANCE','94140','0663060575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:07:17',0,NULL,3,1,2,1,NULL,'talie1708\r欧标\r\\'),(1525,569496268013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','wupzank','kunzerne@gmail.com','Paw Kunz','ID: 29938666<br>Døgnposten 2662','2660 Brøndby','','DENMARK','2660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:07:42',0,NULL,3,1,2,1,NULL,'wupzank\r银色的欧标\r\\'),(1526,569505285013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rozner2606','r2606@zahav.net.il','Ofer Rozner','Israel Galili 15/2','Bear Sheva','','ISRAEL','84712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:34:53',0,NULL,3,1,2,1,NULL,'rozner2606\r\\'),(1527,691832076011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','algahaim','t.piechota@interia.pl','Tomasz Piechota','218 The New Hardwicke<br>Catherines Lane, Church St.','Dublin','Dublin','IRELAND','7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:36:32',0,NULL,3,1,2,1,NULL,'algahaim\r\\'),(1528,768668251012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',44,'eastar4','hershey101pr','malvarez248@aol.com','Mitchell Alvarez','95 Delmar St','Rochester','NY','UNITED STATES','14606-2512','(585) 802-0659','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 21:09:56',0,NULL,3,1,1,1,NULL,'hershey101pr\r\\'),(1529,768682445012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','chucksangel21777','chucksangel21777@yahoo.com','Chuck Evatt','901 E Kiehl Ave','sherwood','AR','UNITED STATES','72120-3031','(501) 902-8832','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'chucksangel21777'),(1530,691861402011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','mapel88','mapelboim@gmail.com','Maayan Apelboim','Itzhak sade 48','Ramat Hasharon','','ISRAEL','47259','050-5988287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:45:12',0,NULL,3,1,3,1,NULL,'mapel88\rRCLO006\rRA117716177CN\r\\'),(1531,568351127013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',2,'BAZA001',151.2,'eastar4','cloudancer972','rdfoutch@att.net','Rick Foutch','4416 Seville Ln','McKinney','TX','UNITED STATES','75070-4438','(972) 529-0528','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 22:57:56',0,NULL,3,1,1,1,NULL,'cloudancer972\r\\'),(1532,768706089012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',3,'BALO008',19.8,'eastar4','offensivestudio','offensivesoundstudio@hotmail.com','Joey Jermer','375 Clark St','Batavia','OH','UNITED STATES','45103-2814','(513) 260-9627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:00:23',0,NULL,3,1,1,1,NULL,'offensivestudio\r\\'),(1533,768716645012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ernest01810','ernestmays@msn.com','Ernest mays','1627 E Shamwood St','West Covina','CA','UNITED STATES','91791-1321','(626) 523-5848','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:25:39',0,NULL,3,1,1,1,NULL,'ernest01810\r\\'),(1534,768718253012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','sheldonblue77','chris.sheldon@gmail.com','chris sheldon','3 gehrman ct','petrie','Queensland','AUSTRALIA','4502','0732855921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 23:30:45',0,NULL,3,0,2,1,NULL,'sheldonblue77\r发210TS\r\\'),(1535,0,220765091535,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','pizzageek420','flybynht@gmail.com','Kevin Liesch','908 Eden Ave','Kaukauna','WI','UNITED STATES','54130-2658','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:56:08',0,NULL,3,1,1,1,NULL,'pizzageek420\r\\'),(1536,523941118004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','lilas0425','christine.huot@hotmail.com','Christine Huot','3135 Stornoway Circle','Oakville','ON','CANADA','L6M5H9','(647) 267-2028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 01:54:35',0,NULL,3,1,3,1,NULL,'lilas0425\rHSPL011\rRA117713683CN\r\\'),(1537,569586823013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','panchoavendano','favendan@gmail.com','FRANCISCO AVENDAÑO MORALES','AV. LAS FLORES 30, PIEDRA ROJA, CHICUREO, COLINA<br>SANTIAGO DE CHILE','SANTIAGO DE CHILE','','CHILE','9340713','56996090662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:24:58',0,NULL,3,1,3,1,NULL,'panchoavendano\rOTRA002\rRA117713635CN\r\\'),(1538,569587149013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','bittenbybug','l.bui@gmx.de','Bui, Tuan Linh','Apartment 8<br>90 Customhouse Street','Gisborne','','NEW ZEALAND','4040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:27:25',0,NULL,3,1,2,1,NULL,'bittenbybug\r\\'),(1539,691939264011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','cheyenne39cs','aleymau.ebay@gmail.com','Claudia Cisneros','Genaro Garcia Ret. 29 Edif. 1 Int. 138<br>Col. Jardin Balbuena Del. Venustiano Carranza','Mexico, D.F.','Distrito Federal','MEXICO','15900','(52) 55-55712722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 02:28:52',0,NULL,3,0,2,1,NULL,'cheyenne39cs\rHP 8pin 1.25 18cm \r\\'),(1540,768776989012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE003',27.98,'eastar4','mr2-cool','gadzooks33-buystuff@yahoo.com','Warren Douglass','1237 SW Kalyca Way','Aloha','OR','UNITED STATES','97006','(503) 349-0207','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 02:58:40',0,NULL,3,1,1,1,NULL,'mr2-cool\r\\'),(1541,569596869013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','red_staw','red.stawberry@gmail.com','Renny','6 Kiora st','Canley Heights','New South Wales','AUSTRALIA','2166','0412011063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 03:21:12',0,NULL,3,1,2,1,NULL,'red_staw\r\\'),(1542,656999124001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','android-red','gsk66@comcast.net','Andy Kraska','18710 Archers Dr','Monument','CO','UNITED STATES','80132','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 03:38:30',0,NULL,3,1,1,1,NULL,'android-red\rLK037251917CN\r\\'),(1543,0,230605717592,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.5,'eastar4','slaphappie','erikbrandon@hotmail.com','Erik Brandon','2300 Loma Vista St','Pasadena','CA','UNITED STATES','91104-3401','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 04:16:46',0,NULL,3,1,1,1,NULL,'slaphappie\r\\'),(1544,569622230013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','elizabeth841410','elizabeth.buitrago@gmail.com','Elizabeth Buitrago','Rue du village 43','Lutry','','SWITZERLAND','1095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:43:04',0,NULL,3,1,2,1,NULL,'elizabeth841410\r\\'),(1545,768822872012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.4,'eastar4','yiotayk_cy','yiotayk@yahoo.gr','Yiota Kyriacou','4, Marcou Dracou<br>Ayios Amvrosios','Lemesos','','CYPRUS','4710','35797779437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:43:17',0,NULL,3,1,2,1,NULL,'yiotayk_cy\r欧标\r\\'),(1546,768824885012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','danart66','artdan@list.ru','Bogdanov Rafael','Pervomayskaya 43a - 9','Ufa','Bashkortostan','RUSSIAN FEDERATION','450112','+79373633360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:53:05',0,NULL,3,0,2,1,NULL,'danart66\r\\'),(1547,691992209011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','k.tarrant','a.tarrant@leetbaka.com','Kevin Tarrant','108 Elk ST','Buffalo','NY','UNITED STATES','14210-1420','(716) 390-5829','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 06:56:45',0,NULL,3,0,1,1,NULL,'k.tarrant\rHP 8pin 1.25 18cm \r\\'),(1548,569633277013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','cormann23','christophcormann@web.de','Cormann, Christoph','Adalbertsteinweg 175a','Aachen','','GERMANY','52066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:44:06',0,NULL,3,1,2,1,NULL,'cormann23\r\\\r'),(1549,569634101013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','hamikavag','hmayak.avagyan@gmail.com','Hmayak Avagyan','Qajaznuni Str. bld 2, Apt. 20','Yerevan','','ARMENIA','0070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:51:04',0,NULL,3,1,2,1,NULL,'hamikavag\r\\'),(1550,523992798004,140393734505,'%%% NEW Lowepro ROVER PLUS AW Photo Camera Bag Backpack',1,'',107.99,'cnfaner','stianmhell','stianmhell@hotmail.com','Stian M. Helland','Havnahagen','Fitjar','Fitjar','NORWAY','5419','41654541','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-07 08:09:09',0,NULL,3,0,5,1,NULL,'stianmhell\rCP226344539CN\r'),(1551,691926028011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','limbehexpert','limbehexpert@hotmail.com','Ang Marc','21 How Sun Walk','Singapore','','SINGAPORE','538443','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 08:21:21',0,NULL,3,1,11,1,NULL,'limbehexpert'),(1552,569650403013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rosch1972','ebay@schreiber.co.at','Roland Schreiber','C/O Raiffeisenbank Leibnitz<br>Bahnhofstraße 2','Leibnitz','','AUSTRIA','8430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:36:52',0,NULL,3,1,3,1,NULL,'rosch1972\rMOSA002 \r\r\\潘'),(1553,569653533013,230563830400,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','3dmultimedia','andribanez@terra.es','ANDRES IBAÑEZ MULLOR (3DMULTIMEDIA)','C/ F.SOLER I PUIGDOLLERS, 117 BJ6','SANT VICENÇ DE CASTELLET','Cataluña','SPAIN','08295','658796301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:58:41',0,NULL,3,1,2,1,NULL,'3dmultimedia\r\\'),(1554,569665728013,230412690655,'2.0 New ASUS Bluetooth Module +cable for EEEPC1101HA',1,'BTHU2001',12.5,'eastar4','briscosdad','stroeer@versanet.de','Armin Ströer','Alter Dortmunder Weg 21','Schwerte','','GERMANY','58239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:05:07',0,NULL,3,1,2,1,NULL,'briscosdad\r华硕10pin 0.8 6cm \r、'),(1555,569669838013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',2,'BTDE2100',17.98,'eastar4','zard98','wineapple@gmail.com','jun soo Ko','601ho-201dong, Samsung Raemian 2-Cha Apt.<br>Banwol-dong','Hwaseong Si, Gyeonggi-Do','','KOREA,REPUBLIC OF','None.US','010-3230-0083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:28:51',0,NULL,3,1,2,1,NULL,'zard98\r\\'),(1556,569690276013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','rui.mannuel','rui.ariana@gmail.com','Rui Teixeira','Rua dos Emigrantes 9','Velas','S Jorge - Açores','PORTUGAL','9800-564','295098149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:07:12',0,NULL,3,1,2,1,NULL,'rui.mannuel\r\\'),(1557,768938893012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',59.99,'eastar4','souichiros','yshuto@nifty.com','Yasuhiro Shuto','6-1-16-803<br>Togoshi','Shinagawa-ku','Tokyo','JAPAN','1420041','819093073406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:55:35',0,NULL,3,1,3,1,NULL,'souichiros\rKBLO001\rRA117712060CN\r\\'),(1558,518279011003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','sega_vs','sega1984@gmail.com','Sergey Vasiliev','Engelsa 74-89','Verkhnaya Salda','Sverdlovskaya oblast','RUSSIAN FEDERATION','624766','+7 909 0171040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:28:44',0,NULL,3,1,3,1,NULL,'sega_vs\rHSNO008欧标\rRA117716818CN\r\\'),(1559,692111783011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','crazyquay','fgatien@gmail.com','Frank Gatien','1240 Roland-Gagnon','Chambly','QC','CANADA','J3L 5N4','(450) 658-2438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:39:20',0,NULL,3,1,2,1,NULL,'crazyquay\r\\'),(1560,0,320682118806,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11,'eastar4','santuar','diego281975@yahoo.com','Diego Munoz','7980 NW 50th St<br>Apt 207','Lauderhill','FL','UNITED STATES','33351','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:52:49',0,NULL,3,1,1,1,NULL,'santuar\r\\'),(1561,0,220765570782,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','jeb48','jim@bollman.com','Jim Bollman','3323 Eaton Rd','Williamson','NY','UNITED STATES','14589-9524','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 15:20:31',0,NULL,3,1,1,1,NULL,'jeb48\r\\'),(1562,0,320681689951,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','janebecker','buyhomes@charter.net','Jane Becker','67 Moscow Rd.','Jefferson','MA','UNITED STATES','01522','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 15:43:15',0,NULL,3,1,1,1,NULL,'janebecker\r\\'),(1563,768986071012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','snipes86','flaming-frets@sbcglobal.net','Jason Tamplin','7301 Kary Lynn Dr E','Watauga','TX','UNITED STATES','76148-1768','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:04:38',0,NULL,3,1,1,1,NULL,'snipes86\r\\'),(1564,518302886003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','merverine','merv_sy@hotmail.com','Mervin Sy','2 Hiram Johnson Road','Stouffville','ON','CANADA','L4A 0H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:08:27',0,NULL,3,1,3,1,NULL,'merverine\rRCLO002\rRA117716821CN\r\\'),(1565,692141782011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','joemcallister1968','joe@mcallisterdesign.com','Joe McAllister','15 Beaufort Drive<br>Knightsbridge','Londonderry','Londonderry','UNITED KINGDOM','BT47 6FG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:09:45',0,NULL,3,1,3,1,NULL,'joemcallister1968\rMOAP001\rRA117716906CN\r\\'),(1566,0,220765570780,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','minhsnguyen','msnguyen@portigent.com','Minh Nguyen','2677 Sequoia Creek Dr','San Jose','CA','UNITED STATES','95121-3207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:12:42',0,NULL,3,1,1,1,NULL,'minhsnguyen\r\\'),(1567,524085141004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','dhyounker','don@cabridal.com','Donald Younker','1095 Riverwoods Dr','Akron','OH','UNITED STATES','44313-5953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 16:18:38',0,NULL,3,1,1,1,NULL,'dhyounker\r\\'),(1568,569740053013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','jamescheung97','jamescheung98@hotmail.com','James Cheung','Flat 2107 Block D<br>Mei Chung Court','Tai Wai','NT','HONG KONG','0','96516004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:30:11',0,NULL,3,1,2,1,NULL,'jamescheung97\r\\'),(1569,692154459011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT003',31.9,'eastar4','bobertlo','bobertlo@gmail.com','robert lowry','9516 Penn Cir','bloomington','MN','UNITED STATES','55431-2425','(952) 884-6127','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 16:36:51',0,NULL,3,1,1,1,NULL,'bobertlo\r\\'),(1570,692158814011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mansuang','mansuang@gmail.com','Mansuang Pawong','iTech Mobile Shop<br>140/362 Soi Kangsadan, Saereesamphan Rd. Moo 14 Tambol Nai Muang','Muang Khon Kaen','Khon Kaen','THAILAND','40000','+66868555543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 16:46:09',0,NULL,3,1,2,1,NULL,'mansuang\r\\'),(1571,769007829012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','kuciniera','racizammit@yahoo.com','Simon Zammit','28 Amaryllis<br>st. magaret street','San Gwann','Europe','MALTA','sgn 1671','+35679421154','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:56:18',0,NULL,3,1,2,1,NULL,'kuciniera\r\r欧标\r\\'),(1572,769033295012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','erod55car','rodrac0609@aol.com','Carlos Rodriguez','10003 nw 130 st','Hialeah','FL','UNITED STATES','33018','(786) 553-9098','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:03:07',0,NULL,3,1,1,1,NULL,'erod55car\r\\'),(1573,524122200004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','jovinceto','fagotne@mail.ru','Evgeny Tamarovsky','Vorovskogo 21A - 31','Chelyabinsk','Chelyabinsk','RUSSIAN FEDERATION','454092','+79026141839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:24:16',0,NULL,3,1,3,1,NULL,'jovinceto\rHSPL010\rRA117716897CN\r\\'),(1574,569777838013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','oukkan','2easy4me@gmail.com','Silvia Hernandez Rodriguez','Jose Manuel Riquelme #4, Poblacion Buenos Amigos Sur, Forestal Alto','Vina del Mar','Vina del Mar','CHILE','2520000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:24:36',0,NULL,3,1,2,1,NULL,'oukkan\r\\'),(1575,657232130001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','domcal61','dcalabrese@wje.com','Dominic Calabrese','13581 Pond Springs Rd<br>Ste 107','Austin','TX','UNITED STATES','78729-4423','(512) 787-0549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:27:58',0,NULL,3,1,1,1,NULL,'domcal61\r\\'),(1576,769071910012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','dalios1964','dalio@delfi.lv','Jurijs Ivanovs','Slavu 23a-10','Riga','','LATVIA','LV-1035','37129247420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:18:04',0,NULL,3,1,2,1,NULL,'dalios1964\r\\'),(1577,569797152013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','zeveimaxim','a1980h@mail.ru','Maxim Filkin','rotshild 98/4','rishon lezion','','ISRAEL','75208','0547615250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:19:13',0,NULL,3,1,2,1,NULL,'zeveimaxim\r\\'),(1578,657256613001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','acru7851','crztwtms@aol.com','alexander cruz','1500 E 63rd St','long beach','CA','UNITED STATES','90805-3114','(562) 428-7420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:22:45',0,NULL,3,1,1,1,NULL,'acru7851\r\\'),(1579,769090809012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','trantuancuong','quocbao.do@gmail.com','Bao Do','Hebelstr. 16','Hirschberg-Leutershausen','','GERMANY','69493','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:30:25',0,NULL,3,1,2,1,NULL,'trantuancuong\r\\'),(1580,692240774011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','ronaldbparks','ronaldbparks@hotmail.com','Ronald B Parks','5259 Zurich Pl NE','Albuquerque','NM','UNITED STATES','87111','(505) 296-6801','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:33:37',0,NULL,3,1,1,1,NULL,'ronaldbparks\r\\'),(1581,769093741012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','alik_31','alik31@hotmail.com','Alexander Alexeev','149 26th St NW<br>Apt 1619','Atlanta','GA','UNITED STATES','30309-2074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:38:22',0,NULL,3,1,1,1,NULL,'alik_31\r\\'),(1582,692244323011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','trudofobique','trudofobic@gmail.com','Anton  Kostrzhevsky','Usievicha dom 23, kv 257','Moscow','Moscow','RUSSIAN FEDERATION','125315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 19:41:18',0,NULL,3,1,2,1,NULL,'trudofobique\r\\'),(1583,0,320682118747,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10,'eastar4','johannadt','johanna.tuballes@gmail.com','Johanna Tuballes','8447 Homelawn St','Jamaica','NY','UNITED STATES','11432-2154','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-07 19:53:58',0,NULL,3,1,1,1,NULL,'johannadt\r\\'),(1584,769110482012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','vasileioslos','bacilis_los@hotmail.com','VASILIS LOS','IOUSTINIANI 40','chios','CHIOS','GREECE','82100','00302271029707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 20:07:15',0,NULL,3,0,2,1,NULL,'vasileioslos\r\\'),(1585,569750459013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','jesse008','jroq@dslextreme.com','Jesse Rock','20555 Devonshire Street<br>Unit #206','Chatsworth','CA','UNITED STATES','91311-1123','(818) 209-9191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 20:23:47',0,NULL,3,1,1,1,NULL,'jesse008\r\\'),(1586,569817320013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','polarb1957','polarb1957@bellsouth.net','David W. Hodgens','31 Stonecreek Dr SW','Cartersville','GA','UNITED STATES','30120','(770) 547-9190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 20:08:39',0,NULL,3,1,1,1,NULL,'polarb1957\r\\'),(1587,569830805013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','sergietgr','sergiogarcia82@hotmail.com','sergio garcia rodriguez','maestro chapi 1-18','massamagrell','Comunidad Valenciana','SPAIN','46130','619841876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 20:49:41',0,NULL,3,1,2,1,NULL,'sergietgr\r\\'),(1588,769142390012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','medina2532','medina2532@msn.com','Mildred Medina','2532 Shadybranch Dr','Orlando','FL','UNITED STATES','32822-4171','(407) 399-6433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 21:10:51',0,NULL,3,1,1,1,NULL,'medina2532\r\\'),(1589,769143414012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','ppen111','petruspen@suomi24.fi','Petrus Pennanen','Pengerkatu 25 c 72','Helsinki','','FINLAND','00500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:12:41',0,NULL,3,1,2,1,NULL,'ppen111\r\\'),(1590,569844676013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'HSSS001',40.99,'eastar4','sic6ixandrew','sic6ix@gmail.com','Andrew Gealy','124 Linden St','Ravenna','OH','UNITED STATES','44266-2519','(330) 842-2854','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 21:37:10',0,NULL,3,1,1,1,NULL,'sic6ixandrew\r\\'),(1591,769160421012,220765484379,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',37,'eastar4uk','ajk1337','arjan.koopen@xs4all.nl','Arjan Koopen','Blomikkers 9','Workum','','NETHERLANDS','8711DA','0515-541312','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:55:01',0,NULL,3,1,3,1,NULL,'ajk1337\rWWSI006\rRA117716870CN\r\\'),(1592,0,220765570781,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11.49,'eastar4','d8veecroc8','sltrhl0710@aol.com','David Lee','408 S Curtis Ave<br>Apt 5','Alhambra','CA','UNITED STATES','91803-1722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:21:10',0,NULL,3,1,1,1,NULL,'d8veecroc8\r\\'),(1593,569864023013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','gkin7416','g_dog_2@msn.com','Geoffrey Kinson','4524 Wolf Grove Rd','Lanark','ON','CANADA','k0g1k0','(613) 259-2440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 22:52:05',0,NULL,3,1,2,1,NULL,'gkin7416\r\\'),(1594,569864358013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ishy','isarmientocom@gmail.com','Ismael Sarmiento','5842 SW 5th Ter','Miami','FL','UNITED STATES','33144-3908','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:54:18',0,NULL,3,1,1,1,NULL,'ishy\r\\'),(1595,657338988001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','johnr1934john','johnobnr@aol.com','John Obenauer','37 Carrie Ct','Nutley','NJ','UNITED STATES','07110-3003','(973) 667-2522','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'johnr1934john'),(1596,657338988001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.99,'buysia','johnr1934john','johnobnr@aol.com','John Obenauer','37 Carrie Ct','Nutley','NJ','UNITED STATES','07110-3003','(973) 667-2522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 22:55:15',0,NULL,3,1,1,1,NULL,'johnr1934john\r\\'),(1597,569868985013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','mikestv','mikestvd@hotmail.com','mike lankuts','4 catts place','gilmore','Australian Capital Territory','AUSTRALIA','2905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 23:17:05',0,NULL,3,1,2,1,NULL,'mikestv\r\\'),(1598,769194017012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','krypticdeath','contact.alexchavez@gmail.com','Alex Chavez','870 W 232nd St','Torrance','CA','UNITED STATES','90502-2584','(310) 367-9519','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 23:48:11',0,NULL,3,1,1,1,NULL,'krypticdeath\\'),(1599,692342718011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','kburris1960','kburris3@sbcglobal.net','Kelly Burris','1163 Halloran St','Cahokia','IL','UNITED STATES','62206-2107','(618) 337-4087','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 00:17:06',0,NULL,3,1,1,1,NULL,'kburris1960\r\\'),(1600,518446250003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','stankokaishev','stankokaishev@yahoo.com','Kaishev Stanko','3017 Hollow Valley Dr','Fort Worth','TX','UNITED STATES','76244-5534','(817) 262-8651','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-08 00:55:40',0,NULL,3,1,1,1,NULL,'stankokaishev\r\\'),(1601,692355092011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','mini2138','benb@tsn.cc','ben burg','369 high st','maitland','New South Wales','AUSTRALIA','2320','0417292515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:05:36',0,NULL,3,1,2,1,NULL,'mini2138\r\\'),(1602,769226776012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','arthurmota','arthursmota@gmail.com','Arthur Mota','Jonas Guerra Street, 67<br>Ap. 401','Recife','Pernambuco','BRAZIL','52040-253','55-81-96104358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:51:07',0,NULL,3,1,2,1,NULL,'arthurmota\r\\'),(1603,692370035011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','aleksandrazorkin','alexzorkin@gmail.com','Aleksandr Zorkin','Sibrevkoma str. 6-56','Novosibirsk','','RUSSIAN FEDERATION','630007','+7-383-2911-573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:01:42',0,NULL,3,1,2,1,NULL,'aleksandrazorkin\r\\'),(1604,569579326013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','klusiris','ksj0408@gmail.com','Seongju Kim','Hansin Hyu-Plus 1 Cha Apt. 103-1701, Gaeun-dong','Wonju-si','Gangwon-do','KOREA,REPUBLIC OF','220110','01094004453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:15:45',0,NULL,3,1,2,1,NULL,'klusiris\r\\'),(1605,569906223013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',14.99,'eastar4','electrobay11','info.electrobay@gmail.com','Bhartendu Thakur','X-86, Bharat Vihar, Prem Nagar - II<br>Nangloi','New Delhi','Delhi','INDIA','110086','9999801444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 02:19:23',0,NULL,3,1,2,1,NULL,'electrobay11\r\\\r'),(1606,518467176003,130493270294,'New Sony Ericsson HBH-608 BLUETOOTH HEADSET track#',1,'HSSE007',19.9,'cnfaner','briannguyenq','briannguyenq@yahoo.com','Tuong Nguyen','2357 KILAUEA AVE','HILO','HI','UNITED STATES','96720','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 02:47:34',0,NULL,3,1,1,1,NULL,'briannguyenq\r\\'),(1607,518469407003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','mrsmaldonado05','mrsmaldonado05@hotmail.com','TAMARA MALDONADO','7631 S OGLESBY AVE','CHICAGO','IL','UNITED STATES','60649-4120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 03:00:48',0,NULL,3,1,1,1,NULL,'mrsmaldonado05\r\\'),(1608,524254501004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','llebpmacp','llebpmacp@hotmail.com','Paul Campbell','108 Stonewall Dr','Carrollton','GA','UNITED STATES','30117-3515','(478) 456-7755','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 03:43:54',0,NULL,3,1,1,1,NULL,'llebpmacp\r\\'),(1609,569930361013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','darioribas','dario_ribas@yahoo.com.br','Dário Ribas','Rua NS-03, 117, Cidade dos Funcionarios','Fortaleza','Ceará','BRAZIL','60823-670','0-55-85-32758520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 04:45:48',0,NULL,3,1,3,1,NULL,'darioribas\rMOSA002\rRA117716883CN\r\\'),(1610,692417603011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 05:54:19',0,NULL,8,1,17,0,NULL,'mick42101\racer 6pin1.25 23cm '),(1611,769165821012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',20,'TRMX003',167,'eastar4','etonishar','zycon3@comcast.net','Diamond Communications','11706 Garrison Forest Rd','Owings Mills','MD','UNITED STATES','21117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 06:02:24',0,NULL,3,1,4,1,NULL,'etonishar\rmx20t   \rYW864941972CN'),(1612,569945631013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','etc_films','studioetc@gmail.com','Joel C K Chu','Flat 2, 19 New Compton Street','London','London','UNITED KINGDOM','WC2H 8DS','07883185163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 06:42:15',0,NULL,3,1,2,1,NULL,'etc_films\r\\'),(1613,691680336011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','bustedboy','bsteeer@gmail.com','Tomáš Míka','Nerudova 294/II','Soběslav','South Bohemia','CZECH REPUBLIC','392 01','728718731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 06:46:42',0,NULL,3,0,2,1,NULL,'bustedboy\r\\'),(1614,692420139011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:00:58',0,NULL,3,1,2,1,NULL,'mick42101\racer 8pin1.00 8cm \r再发一个2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable\racer 6pin1.25 23cm \r\\'),(1615,518499741003,130458644382,'New inBox GENUINE NOKIA BH-207 BLUETOOTH HEADSET track#',6,'HSNO010',137.94,'cnfaner','tele-stop','tele-stop@t-online.de','Thomas Groß','Poststr. 4','Beckingen','','GERMANY','66701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:03:46',0,NULL,3,1,3,1,NULL,'tele-stop\rHSNO010\r欧标  \rRA117716676CN\r、'),(1616,692430507011,320422591058,'NEW AKE Expresscard express to Four USB 2.0 Ports BC268',2,'ADAK003',21.8,'eastar4','pixelparadise','wolfgang@winne.de','Wolfgang Winne','Birkenhof 5','Achim-Uphusen','','GERMANY','28832','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:05:41',0,NULL,3,1,2,1,NULL,'pixelparadise\r\\'),(1617,692440020011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','lilphillyboy','lilphillyboy@gmail.com','Harry Williamson','11411 Middleburgh Dr','Tomball','TX','UNITED STATES','77377-8612','(512) 659-5061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 07:49:24',0,NULL,3,1,1,1,NULL,'lilphillyboy\r\\'),(1618,524285027004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','hansi-hand-enkel','m_roeller@gmx.de','Michael Röller','Otto-Dix-Ring 66','Dresden','','GERMANY','01219','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:56:15',0,NULL,3,1,3,1,NULL,'hansi-hand-enkel\rWLAT002\r\rRA117712405CN\r\\'),(1619,692460799011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fmcduijn','frederik@duijn.net','Frederik Duijn','Postbus 24047','Den Haag','','NETHERLANDS','2490AA','0642089311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 09:25:08',0,NULL,3,1,2,1,NULL,'fmcduijn\r、'),(1620,692466816011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',35.45,'eastar4','wolfg72','wolfman31@gmx.de','Wolfgang Kriebel','Kreuzlach 13a','Neuendettelsau','','GERMANY','91564','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 09:56:27',0,NULL,3,1,3,1,NULL,'wolfg72\racer 5pin 1.25 3cm\r再发一个New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna\rRA117717005CN\r\\\r'),(1621,569979821013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','szomorcsabi','szomorcsaba@hotmail.com','Szomor Csaba','Beregszász street 6. F/1<br>Menedékes street 1. F/1','Budapest','','HUNGARY','1118','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 10:21:17',0,NULL,3,1,2,1,NULL,'szomorcsabi\\'),(1622,769347395012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','ragnarjonny','s.ragnar@yahoo.no','Ragnar Sundsås','Bleikenveien 173','Brandbu','','NORWAY','2760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-08 10:23:23',0,NULL,3,1,2,1,NULL,'ragnarjonny\r欧标\\'),(1623,518536232003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',28.99,'cnfaner','arielm2828','rel.mta@gmail.com','Ariel Motola','wingate 55<br>apartment 9','beer sheva','','ISRAEL','84428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:00:13',0,NULL,3,1,3,1,NULL,'arielm2828\rHSUE003\rRA117716662CN\r、'),(1624,692494422011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','paultje0070','paul.dingenouts@freeler.nl','Paul Dingenouts','Stinzenlaan Zuid 268','Breukelen','','NETHERLANDS','3621TJ','(0346) 265730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:38:31',0,NULL,3,1,2,1,NULL,'paultje0070\r\\'),(1625,524333792004,140482241394,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',13.99,'cnfaner','chardo1983','chardo2002@yahoo.com','Richard Bonessi','65 City Brook Rd','Naugatuck','CT','UNITED STATES','06770-3156','(203) 558-8545','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 12:49:34',0,NULL,3,1,1,1,NULL,'chardo1983\r÷'),(1626,692528911011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',2,'TRTS001*10',166,'eastar4','phil5841','philippe.olivi@laposte.net','OLIVI Philippe','98 bd Virgile BAREL','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06300','0679221901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 13:35:36',0,NULL,3,1,4,1,NULL,'phil5841\rYW864941880CN\r'),(1627,518573003003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','caroleichler70pk','caroleichler@yahoo.com','william eichler','1250 Thornton Dr','sequim','WA','UNITED STATES','98382','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 14:06:41',0,NULL,3,1,1,1,NULL,'caroleichler70pk\\'),(1628,0,220766021687,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',10.99,'eastar4','ne14me07166','ne14me7166@yahoo.com','Tina Smith','3050 Shady Oak Dr','Saint Charles','MO','UNITED STATES','63301-5004','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 14:37:36',0,NULL,3,1,1,1,NULL,'ne14me07166\\'),(1629,769423945012,220653561343,'New Atheros DualBand AR9287 Wireless  Half Card+antenna',2,'WLAT007+ANTY001',50.75,'eastar4','smorton39','ebay@boundlesss.com','Steve Morton','39 Old Good Hill Rd<br>Boundless Security Systems','Oxford','CT','UNITED STATES','06478-1508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 14:45:49',0,NULL,3,1,1,1,NULL,'smorton39\\\r再发一个NEW Atheros AR5B93 Half Height Wireless WiFi card 300M'),(1630,524360009004,140515704012,'New GENUINE NOKIA HS-36W  BLUETOOTH HEADSET track#',1,'HSNO026',15.5,'cnfaner','gaglianogia','giagagliano@yahoo.it','giacomo gagliano','via n. martoglio, 5','Niscemi','CL','ITALY','93015','3383235241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 14:50:46',0,NULL,3,1,3,1,NULL,'gaglianogia\rHSNO026\r欧标\rRA117712626CN\r\\'),(1631,0,320682117454,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.5,'eastar4','hotrod5071','af30@sbcglobal.net','Melvin Jenkins','7518 Kleberg','San Antonio','TX','UNITED STATES','78250','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 15:48:46',0,NULL,3,1,1,1,NULL,'hotrod5071\r÷'),(1632,769457081012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',71.98,'eastar4','kylekirch18','kizkracker30@sbcglobal.net','Kyle Kirchenbauer','224 Saint Paul Dr','Fremont','OH','UNITED STATES','43420-9291','(419) 307-7472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 15:57:53',0,NULL,3,1,1,1,NULL,'kylekirch18\\'),(1633,0,220766022740,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','harborbikes','wifiskeens@gmail.com','Clarence Skeens','22618 Cuyama Ct','Apple Valley','CA','UNITED STATES','92307','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 16:18:30',0,NULL,3,1,1,1,NULL,'harborbikes\r÷'),(1634,692587409011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.9,'eastar4uk','morozhenoye74','jason@squodge.com','Mr. Wai Hung Jason Yip','46 Maple House<br>Idonia Street','Deptford','London','UNITED KINGDOM','SE8 4LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 16:24:54',0,NULL,3,1,3,1,NULL,'morozhenoye74\rWLAP002\rRA117712348CN\r\\'),(1635,769484657012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','d13ark','deanobarker@hotmail.com','Dean Barker','10 Farm Close','Crowthorne','Berkshire','UNITED KINGDOM','RG45 6SE','01344775006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 17:03:23',0,NULL,3,1,3,1,NULL,'d13ark\rHSMO017\r英标\rRA117712705CN\r\\'),(1636,570080107013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','barbusps','barbusps@catt.com','Barbara Hickman','344 Sutton Dr','Ringgold','GA','UNITED STATES','30736-7264','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 17:30:18',0,NULL,3,1,1,1,NULL,'barbusps\r\\'),(1637,769503240012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',16.7,'eastar4','chilidogmtl','gabeko77@gmail.com','Gabriel Ko','19 Stayner  Apt #5','Westmount','QC','CANADA','H3Z 1W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:42:27',0,NULL,3,1,2,1,NULL,'chilidogmtl\r\\'),(1638,769506981012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','lachman9311','michael.lachman@gmail.com','Michael Lachman','Loa Haari 9','Migdal Haemek','','ISRAEL','23505','+972-54-6215638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:51:20',0,NULL,3,1,2,1,NULL,'lachman9311\r\\'),(1639,769513528012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','juzt-me','the_puter_nut@yahoo.com','Jessica Langdeaux','4826  Wade Stedman Rd.','Wade','NC','UNITED STATES','28395-8550','(605) 881-5623','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 18:05:43',0,NULL,3,1,1,1,NULL,'juzt-me\r÷'),(1640,692634369011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','melisasouth','randmsouth@gmail.com','MELISA SOUTH','133 MEDITERRANEAN','AMHERSTBURG','ON','CANADA','N9V3X7','(519) 736-0905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:16:59',0,NULL,3,1,3,1,NULL,'melisasouth\rRCLO006\rRA117712643CN\r\\'),(1641,769527000012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',12.5,'eastar4','pjotrd','pm_dekker@live.nl','Piet Dekker','Tom Mandersstraat 74','Hengelo','The Netherlands','NETHERLANDS','7558 MR','+31 74 2483476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:30:49',0,NULL,3,1,2,1,NULL,'pjotrd\racer 5pin1.25 15cm \r\\'),(1642,570106116013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',33.76,'eastar4','theigas','igasgeek@me.com','Igor Kapkov','Stachek, 88, 39','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','198096','7-921-640-8585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 18:42:48',0,NULL,3,1,3,1,NULL,'theigas\rCACN004\rRA117712657CN\r\\'),(1643,524435086004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','hagar.cohen','hagarcohenil@gmail.com','hagar cohen','3 stern street<br>apartment 7','kiryat ono','kiryat ono','ISRAEL','55602','+972503004728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:16:49',0,NULL,3,1,3,1,' ','hagar.cohen\rHSNO009\rRA117712630CN\r\\'),(1644,524435019004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',2,'HSJA002',43,'cnfaner','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:23:44',0,NULL,3,1,3,1,NULL,'vjendrisvelimir\rHSJA002  欧标\rRA117712731CN\r\\'),(1645,692674208011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','jenia_t','jenia11@hotmail.com','Evgeny Teplits','Liber Zeev 10/31','Natanya','','ISRAEL','42524','0546221244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 19:39:18',0,NULL,3,1,3,1,NULL,'jenia_t\rRCLO006\rRA117716954CN\r\\'),(1646,692671210011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','bc-nj','carscadden@gmail.com','Brian K. Carscadden','117 Thackeray Rd','Oakland','NJ','UNITED STATES','07436','(201) 786-8847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 19:39:57',0,NULL,3,1,1,1,NULL,'bc-nj\\'),(1647,769593940012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','neilmaggi','neil.maggi@sky.com','Neil Hutchinson','2 Kingfisher Court','Normanton','West Yorkshire','UNITED KINGDOM','WF6 1ZW','01924894372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 20:42:02',0,NULL,3,1,3,1,NULL,'neilmaggi\r英标 \rHSNO017\rRA117712422CN\r\\'),(1648,769604593012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'eastar4','strel','strel@mindspring.com','David P. Strelinger','3306 Horsehead Bay Dr NW','Gig Harbor','WA','UNITED STATES','98335-5841','(253) 509-4447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 21:06:10',0,NULL,3,1,1,1,NULL,'strel\r÷'),(1649,692728870011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','manmohan','pnjpatel@yahoo.com','Punjabhai K. Patel','16209 Mount Baden Powell St','Fountain Valley','CA','UNITED STATES','92708','(714) 839-8637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 21:55:05',0,NULL,3,1,1,1,NULL,'manmohan\r÷'),(1650,0,230606151421,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','custom-mugs4u','kevinwc@cox.net','Kevin Crowley','4020 Arville St<br>Apt 136','LAS VEGAS','NV','UNITED STATES','89103-5917','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-08 22:23:11',0,NULL,3,1,1,1,NULL,'custom-mugs4u\\'),(1651,692754821011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.95,'eastar4uk','thinkpad.parts','bingobargains3@googlemail.com','Chris Gates','22 Millbank','Cam','Gloucestershire','UNITED KINGDOM','GL11 5PT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 23:23:22',0,NULL,3,1,3,1,NULL,'thinkpad.parts\rWLAP001\rRA117712436CN\r\\'),(1652,524507988004,140429366442,'2.1 HP Pavilion DV1000 DV1100 bluetooth module track#',1,'BTHP2109',13.99,'cnfaner','asesor_en_digitales','rodrygo@chateando.tv','Rodrigo Pacheco','Sucua Oe1-49 y Gral. Urdaneta<br>Sector San Bartolo','Quito','Pichincha','ECUADOR','EC170148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 00:30:34',0,NULL,3,1,3,1,NULL,'asesor_en_digitales\rHP 8pin 1.25 3cm \rBTHP2109\rRA117712396CN\r\\'),(1653,570202792013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','randarichardson','randyr@mchsi.com','Randy Richardson','28785 Alicia Pl','Grand Rapids','MN','UNITED STATES','55744','(218) 326-3949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 00:53:31',0,NULL,3,1,1,1,NULL,'randarichardson\\'),(1654,769694122012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',3,'MOLO002',116.7,'eastar4','kkbasol','kerimbasol@gmail.com','Kerim BASOL','Bostanci Cami Sk. Cesur Apt. No:13 D:3<br>Kadikoy','Istanbul','Istanbul','TURKEY','34744','+902164101810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 02:13:04',0,NULL,3,1,3,1,NULL,'kkbasol\rMOLO002\\'),(1655,524528299004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',15.55,'cnfaner','autkosearch','koper123@hotmail.com','Dariusz Koper','155 Lower Notch Road','Little Falls','NJ','UNITED STATES','07424','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 02:35:57',0,NULL,3,1,1,1,NULL,'autkosearch\\'),(1656,570222117013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','jase4984','jase_4984@yahoo.com','Jason Moore','16 N Main St','York New Salem','PA','UNITED STATES','17371-2007','(717) 357-9787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 02:41:24',0,NULL,3,1,1,1,NULL,'jase4984\\'),(1657,692804524011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','barryk76','barry@rochester.rr.com','barry kennedy','76 raines park','rochester','NY','UNITED STATES','14613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 02:59:04',0,NULL,3,1,1,1,NULL,'barryk76\racer 6pin1.25 23cm \\'),(1658,570226880013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','the_real_seekad','bob.badr@gmail.com','bob badr','465 larente','Gatineau','QC','CANADA','j8p 5b3','(819) 669-6211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 03:13:44',0,NULL,3,1,2,1,NULL,'the_real_seekad\r\\'),(1659,769734007012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','jozsef1957','787779@gmail.com','Jozsef Banhidi','Szent Korona utca 198','Budapest','','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 05:21:51',0,NULL,3,1,2,1,NULL,'jozsef1957\r\\'),(1660,570250991013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','billyfooksheung','billyfooksheung@hotmail.com','Billy Fook Sheung','60 Raoul Rivet Street','Port Louis','','MAURITIUS','','(230)2125369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:09:53',0,NULL,3,1,2,1,NULL,'billyfooksheung\r\\'),(1661,570252361013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','beef4love','jaepark79@gmail.com','Jae Hong Park','151 Soon-wha dong<br>Posco the # A-2401','Seoul','Jung-gu','KOREA,REPUBLIC OF','100130','(010) 355-1914 ext.: 3','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:21:17',0,NULL,3,1,3,1,NULL,'beef4love\rRCLO003\rRA117712524CN\r\\'),(1662,692845795011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','msmith36','emsmith@gol.com','Marvin Smith','374-4 Oya<br>Minuma-ku','Saitama-shi','Saitama','JAPAN','337-0014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:50:44',0,NULL,3,1,2,1,NULL,'msmith36\r\\'),(1663,769754288012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','razor_05','jozef_golias@yahoo.co.uk','Jozef Golias','66<br>Lopuchov','Raslavice','','SLOVAK REPUBLIC','08641','00421908952858','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 07:10:21',0,NULL,3,1,2,1,NULL,'razor_05\r只发耳机不给电源\r棕色的\r\\'),(1664,524564494004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','flhansen_dk','flemming.hansen@svendbo.dk','Flemming Hansen','Gammel Skaarupvaenge 16','Svendborg','','DENMARK','5700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 07:18:24',0,NULL,3,1,3,1,NULL,'flhansen_dk\rBALO007\rRA117712317CN\r\\'),(1665,769765190012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','thedan1','d_treadway@comcast.net','Danny Treadway','205 S Fairway Ave','Sherwood','AR','UNITED STATES','72120-5442','(501) 259-6730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 07:49:54',0,NULL,3,1,1,1,NULL,'thedan1\r÷'),(1666,524583645004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','19071994','tempting89@mail.ru','Aliaksei Burshtyn','Street of Yankee Kupaly 74/57 ','Brest','Brest region','BELARUS','224020','80292073040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:18:54',0,NULL,3,1,3,1,NULL,'19071994\rHSNO022\r欧标\rRA117712612CN\r\\'),(1667,769797966012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','s11verdragon','silverdragon@gmail.com','Chris Bell','26 Lunn Ave<br>Mt Wellington','Auckland','','NEW ZEALAND','1047','064095277470','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 09:55:37',0,NULL,3,1,2,1,NULL,'s11verdragon\r\\'),(1668,692899233011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',9.99,'eastar4','steve73091','themadpeon@gmail.com','Stephen Donaldson','63 Dudley Street','Mansfield Park','South Australia','AUSTRALIA','5012','0402933013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:26:56',0,NULL,3,1,2,1,NULL,'steve73091\r\\'),(1669,692899779011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','kentellingsen','kent@radiosystemer.com','Kent Ellingsen','Olastien 5','Tromsø','Troms','NORWAY','9012','004799331213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:27:50',0,NULL,3,1,3,1,NULL,'kentellingsen\rWWSI005+ANCN001\rRA117712334CN\r\\'),(1670,769813628012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','hallti.y01','timhall030290@hotmail.com','tim hall','31 southdown crescent<br>cheadle hulme','stockport','cheshire','UNITED KINGDOM','sk8 6eq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 10:50:12',0,NULL,3,1,3,1,NULL,'hallti.y01\r英标 \rHSPL011\rRA117712538CN\r\\'),(1671,769814853012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','123eturs','eturs@zahav.net.il','Etur Shani','moran 415','barkan','','ISRAEL','44820','97239060952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:53:50',0,NULL,3,1,2,1,NULL,'123eturs\r\\'),(1672,692908817011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','cedarsrus','andrew.guy@cedarsupport.co.uk','Andrew Guy','3 Cornflower Close','Cardiff','Cardiff','UNITED KINGDOM','CF140BD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 11:02:17',0,NULL,3,1,2,1,NULL,'cedarsrus\r\\'),(1673,692933818011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 12:39:57',0,NULL,3,1,2,1,NULL,'hue_bui\r、'),(1674,769854412012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','lotusmach10','paulandkay1993@sbcglobal.net','Paul Pakizer','3747 Deer Springs Dr','Rochester Hills','MI','UNITED STATES','48306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 13:01:43',0,NULL,3,1,1,1,NULL,'lotusmach10\r÷'),(1675,518848818003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',2,'HSUE002',53.9,'cnfaner','samurai_jumpo','samuraijumpo@gmail.com','Anton Prygunov','Novocherkasskiy bulvar, dom 14, kv. 244','Moscow','','RUSSIAN FEDERATION','109651','+7-962-970-8975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 13:01:50',0,NULL,3,1,3,1,NULL,'samurai_jumpo\rHSUE002\rRA117712970CN\r\\'),(1676,769864180012,220749207909,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.99,'eastar4uk','trevorg4823','avengertj@yahoo.co.uk','Trevor Gocan','FLAT, A1 ODHAMS WALK, LONG ACRE,','LONDON','COVENT GARDEN','UNITED KINGDOM','WC2H 9SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 13:28:44',0,NULL,3,1,3,1,NULL,'trevorg4823\rRELE001\rRA117712351CN\r\\'),(1677,570337099013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','juanhein20','juanhein@vodamail.co.za','Juan van der westhuizen','PO BOX 1061','Grabouw','Western Cape','SOUTH AFRICA','7180','+27829245930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 13:49:51',0,NULL,3,1,3,1,NULL,'juanhein20\rOTRA002\rRA117716937CN\r\\'),(1678,657947894001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','lpage_11','lowry_11@yahoo.com','Lowry Page','721 Kingston Ct','Apollo Beach','FL','UNITED STATES','33572-2428','(813) 785-3804','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'lpage_11'),(1679,657947894001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','lpage_11','lowry_11@yahoo.com','Lowry Page','721 Kingston Ct','Apollo Beach','FL','UNITED STATES','33572-2428','(813) 785-3804','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 14:26:14',0,NULL,3,1,1,1,NULL,'lpage_11\rLK038166676CN\r÷'),(1680,570364290013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','penible93','penible13@hotmail.fr','didier houssin','quartier siege','simiane','Provence-Alpes-Côte d\'Azur','FRANCE','13109','06.80.75.58.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:34:57',0,NULL,3,1,2,1,NULL,'penible93\rHP 8pin 1.0 23cm \r、'),(1681,692993677011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mexicanos69as','stephane.abadie@gmail.com','Stéphane Abadie','87 rue du 1er Mars 1943','Villeurbanne','Rhône-Alpes','FRANCE','69100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:39:29',0,NULL,3,1,2,1,NULL,'mexicanos69as\r\\'),(1682,570368663013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','sebasgomez','sebastiangomez55@yahoo.es','Juan Ignacio Pérez Martínez','Av. Autopista del Saler, 4 - Bloque 1<br>Esc. C - 11º - Pta. 73','Valencia','Comunidad Valenciana','SPAIN','46013','609530200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:50:40',0,NULL,3,1,2,1,NULL,'sebasgomez\r欧标\r\\'),(1683,570370108013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','alangoto14','alangoto@adinet.com.uy','Alvaro Gonzalez','Michigan 1361/4','Montevideo','Montevideo','URUGUAY','11400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:57:27',0,NULL,3,1,3,1,NULL,'alangoto14\rOTRA002\rRA117712541CN\r\\'),(1684,570376700013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',34.89,'eastar4','extra_bits_uk','jason.fell@hotmail.co.uk','Jason Fell','2 Beckley Cottages','Great Bookham','Surrey','UNITED KINGDOM','KT23 4RW','07522686855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 16:17:56',0,NULL,3,0,3,1,NULL,'extra_bits_uk\r再发一个优联\rOTHP003+RELO002\rRA117712665CN\r\\'),(1685,693013920011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','eesundin','eesu42@comcast.net','Eric E. Sundin','2058 Carillon Dr','Grayslake','IL','UNITED STATES','60030-4426','(847) 543-6717','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:20:33',0,NULL,3,1,1,1,NULL,'eesundin\r÷'),(1686,570379516013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mtzapgar','lbrown1626@hotmail.com','Lorie Brown','PO Box 4344','Hot Springs National Park','AR','UNITED STATES','71914-4344','(501) 762-2855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:27:36',0,NULL,3,1,1,1,NULL,'mtzapgar\r÷'),(1687,693017262011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',18.85,'eastar4','bilcat01','billyrichards@tesco.net','Billy Richards','94 Main Street','Winchburgh','West Lothian','UNITED KINGDOM','EH526RE','1506890532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 16:27:47',0,NULL,3,1,2,1,NULL,'bilcat01\r\\'),(1688,570382924013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','jdavis6217','jdavis6217@juno.com','J & K SERVICE','891 STREETMAN RD','ROYSE CITY','TX','UNITED STATES','75189-6317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 16:38:02',0,NULL,3,1,1,1,NULL,'jdavis6217\\'),(1689,768642065012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',3,'HSPL011',66,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 17:03:07',0,NULL,3,1,3,1,NULL,'solopo2009\r只发耳机不给电源 \rHSPL011\rRA117712453CN\r\\'),(1690,769967547012,220620856337,'Dell 1520 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE003',13.99,'eastar4','jag-k150-j6c','genemc@cavemen.net','Eugene McGough','1009 S Country Club Cir','CARLSBAD','NM','UNITED STATES','88220-4616','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-09 17:33:03',0,NULL,3,1,1,1,NULL,'jag-k150-j6c 改发一个1510\r÷'),(1691,524703050004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',2,'MOSA001',143.8,'cnfaner','chavisatelnet','javier@satelnet.es','JAVIER FERNÁNDEZ GÓMEZ','C/MATA JOVE, Nº2 6ºC','GIJÓN','Asturias','SPAIN','33213','606116784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 18:06:54',0,NULL,3,1,3,1,NULL,'chavisatelnet\rMOSA001\rRA117712674CN\r\\'),(1692,769995654012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','martin_j1','martin_j1@hotmail.com','M Jannat','701/6<br>LACHLAN STREET','WATERLOO','New South Wales','AUSTRALIA','2017','0400887264','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 18:26:38',0,NULL,3,1,3,1,NULL,'martin_j1\rOTRA002\rRA117712382CN\r\\'),(1693,570433425013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','dumdidom','dumdidom@hotmail.com','Carole St-Jean','154 Rue Desjardins','Magog','QC','CANADA','J1X 5R9','(514) 962-5810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 19:03:40',0,NULL,3,1,2,1,NULL,'dumdidom\r\\'),(1694,518957291003,130490915279,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'cnfaner','sweet_pete73','kobe_bryant20@hotmail.com','Peter Nemec','321 Lonsdale Road<br>Suite E','Toronto','ON','CANADA','M4V 1X3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 19:23:31',0,NULL,3,1,3,1,NULL,'sweet_pete73\rCACN003\rRA117712572CN\r\\'),(1695,770029679012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','lban1828','lajessica252@hotmail.com','lajessica banks','105 grant street','garysburg','NC','UNITED STATES','27831','(252) 945-4354','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 19:26:45',0,NULL,3,1,1,1,NULL,'lban1828\\'),(1696,570452414013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','nsizov81','ngrechko@rambler.ru','Sizov Nikolay','25 Walpole Park S<br>Ste 4-EB103990','Walpole','MA','UNITED STATES','02081-2522','903 221 0637','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-09 19:56:18',0,NULL,3,1,2,1,NULL,'nsizov81  新地址Nikolay Sizov\rAviatorov St., 2, 150\rMoscow Moscow 119619\rRussian Federation\r\\\r'),(1697,570452835013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','pocoali','nfgriffin@verizon.net','Nancy Griffin','2651 Aspen Ct','Palm Harbor','FL','UNITED STATES','34684-1947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 19:57:30',0,NULL,8,1,17,0,NULL,'pocoali'),(1698,518972491003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','nikojof','niko_jof@abv.bg','Nikolay Yosifov','h.k. Serdika, block 16, flat 14, ap. 53','Sofia','Sofia','BULGARIA','1330','+359888607561','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-09 20:07:53',0,NULL,3,1,3,1,NULL,'nikojof\rOTJE001\rRA117712691CN\r\\'),(1699,524746645004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','sgoldstien','sgoldstien@comcast.net','Stuart Goldstien','4682 White Rock Cir<br>Apt 3','Boulder','CO','UNITED STATES','80301-6712','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 20:12:20',0,NULL,3,1,1,1,NULL,'sgoldstien\r\\'),(1700,693130155011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:30:18',0,NULL,3,1,2,1,NULL,'masteroll2010\r\\'),(1701,570470348013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',10.99,'eastar4','harry_momo','shakedown@deadlegs.com','aron black','4686 Hingston','montreal','QC','CANADA','h4a2k1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:52:55',0,NULL,3,1,2,1,NULL,'harry_momo\r\\'),(1702,570473500013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','nohpipa','apiphon@hotmail.com','Apiphon Likasitthananon','12/6 Mooban Patchaya Home<br>Paholyothin 48 Bangkean','Bangkok','Bangkok','THAILAND','10220','66813154533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 21:05:53',0,NULL,3,1,2,1,NULL,'nohpipa\r\\'),(1703,770084122012,220759518727,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',24.9,'eastar4uk','synchronic29','keith_falzon@hotmail.com','keith falzon','16 bella vista court<br>rudolf street sliema','sliema','','MALTA','slm02','00356 79408180','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-09 21:17:28',0,NULL,3,1,3,1,NULL,'synchronic29\rMOLO002\rRA117712759CN\r\\'),(1704,570479012013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',3,'HSPL001',35.4,'eastar4','aroman6215','aroman6216@aol.com','Anthony Romano Jr.','6 Magnolia Ln','Colts Neck','NJ','UNITED STATES','07722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 21:22:07',0,NULL,3,1,1,1,NULL,'aroman6215\\'),(1705,693189468011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','dhimitris2009','jimntan@gmail.com','Dhimitris Danis','Grammu 60','Igumenitsa','Thesprotia','GREECE','46100','2665028535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:03:29',0,NULL,3,1,2,1,NULL,'dhimitris2009\r欧标\r\\'),(1706,570508172013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','simez1234','simez@sky.com','Jonathan Simon Richmond','44 High Street','Upton','West Yorkshire','UNITED KINGDOM','WF9 1HQ','07791877102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:27:16',0,NULL,3,1,2,1,NULL,'simez1234\r\\'),(1707,770135532012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',21.98,'eastar4','qkrekdnf','dup@sfu.ca','da ur park','1580 taylor way','west vancouver','BC','CANADA','v7s 1n4','(604) 805-1913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 23:50:01',0,NULL,3,1,2,1,NULL,'qkrekdnf\r\\'),(1708,768110243012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','satelight_man34237','chokman143669@aol.com','jerrett oakes','10230 Waterford Ave','englewood','FL','UNITED STATES','34224-7915','(941) 914-2510','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 23:57:07',0,NULL,3,1,1,1,NULL,'satelight_man34237\r÷'),(1709,693218265011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mal-ward','mal-ward@usa.net','Malcolm Ward','102/14 Orchards Ave','Breakfast Point','New South Wales','AUSTRALIA','2137','0405244875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 00:56:40',0,NULL,3,1,2,1,NULL,'mal-ward\r\\'),(1710,524808419004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','aytlakhder','ilakhder@gmail.com','Ismail Lakhder','98 Cottage St','Franklin','MA','UNITED STATES','02038-2207','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 01:02:15',0,NULL,3,1,1,1,NULL,'aytlakhder\\'),(1711,570525748013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','vieras04','vieras@sbcglobal.net','David Viera','1639 Harlan Dr','Danville','CA','UNITED STATES','94526','(925) 855-8957','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 01:03:47',0,NULL,3,1,1,1,NULL,'vieras04\\'),(1712,519040160003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','nierobek','jniebud@yahoo.com','Jan Niebudek','3 Fern Rd','Andover','MA','UNITED STATES','01810','(978) 470-0455','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 01:16:57',0,NULL,3,1,1,1,NULL,'nierobek\\'),(1713,693224556011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',2,'HSPL002',31,'eastar4','wildeliz98','wilbertom@gmail.com','Wilberto Moczo','Villa Carolina<br>216-15 Calle 505','Carolina','PR','UNITED STATES','00985','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 01:20:43',0,NULL,3,1,1,1,NULL,'wildeliz98\r\\'),(1714,524822378004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','beneathshadows1313','beneathshadows13@aim.com','Joann Stamatopoulos','6715 N River Dr','Middle River','MD','UNITED STATES','21220-1033','(443) 604-1677','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 02:10:59',0,NULL,3,1,1,1,NULL,'beneathshadows1313\r÷'),(1715,693282754011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',14.9,'eastar4uk','robert_ludwig','weineger@gmx.de','Weigelt Gero','Grimmaische Str. 39','Mutzschen','','GERMANY','04688','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 06:00:32',0,NULL,3,1,2,1,NULL,'robert_ludwig\r欧标\r\\'),(1716,570577736013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','whkee','whkee@mac.com','Mike Wong Hong Kee','Singapore Polytechnic, School of EEE<br>500 Dover Road, Blk 12, 5 Floor','default','','SINGAPORE','139651','96620996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 06:38:12',0,NULL,3,1,11,1,NULL,'whkee\r\\'),(1717,693294378011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','anelasxintus','ericchuah@gmail.com','Eric Chuah','52, Jalan tempua 4','Puchong Jaya','Selangor','MALAYSIA','47100','0123214253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 06:51:05',0,NULL,3,1,2,1,NULL,'anelasxintus'),(1718,693329809011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','gerry2rs','ebayonic@netspace.net.au','Gerald Genikas','13 Cowra Crescent','Park Holme','South Australia','AUSTRALIA','5043','0882771317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 08:49:47',0,NULL,3,1,3,1,NULL,'gerry2rs\rRCLO006\rRA117712569CN\r\\'),(1719,770277825012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',19.8,'eastar4','nagisaian','nice_boy_nz@hotmail.com','Ian green','1 Topliss Drive<br>torbay','Auckland','northshore','NEW ZEALAND','0632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 09:05:01',0,NULL,3,0,2,1,NULL,'nagisaian\r再发一个\rApple Airmac/Airport Wireless WiFi Card iMac iBook eMac\r\\'),(1720,770294058012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',2,'HSNO023',19.38,'eastar4uk','achoroshav77','achoroshav@yahoo.co.uk','aydan zekrie','111 sheviot gardens','london','London','UNITED KINGDOM','nw2 1qd','02082099510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 09:41:05',0,NULL,3,1,3,1,NULL,'achoroshav77\r英标 HSNO023\rRA117712745CN\r\\'),(1721,570629055013,230603109640,'New CX680 Sennheiser Adidas Sports Earphones Earbuds',1,'HSSS001',40.99,'eastar4','anttibanana','antti.lehmusalho@iki.fi','Antti Lehmusalho','Sammonkatu 9 B 49','Tampere','','FINLAND','33540','+358584004274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 10:17:19',0,NULL,3,1,3,1,NULL,'anttibanana\rHSSS001\rRA117712590CN\r\\'),(1722,570645675013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',149.6,'eastar4','mrmotorcross','scommons@tpg.com.au','S Commons','17 Harcus Close','Bonython','Australian Capital Territory','AUSTRALIA','2905','0414665319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:20:07',0,NULL,3,1,3,1,NULL,'mrmotorcross\rMOSA002\rRA117712688CN\r\\'),(1723,770336112012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','nikovas','nikovas@yahoo.com','Prigouri Adamantia','KASTALIAS 69','NEA KYPSELI','ATHENS','GREECE','11363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:24:01',0,NULL,3,1,2,1,NULL,'nikovas\r欧标\r\\'),(1724,693389887011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','stk1917','malatin@inbox.ru','Kirill Malatin','16/31 Barrikadnaya St., apt. 5','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198099','+79218719778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 11:29:35',0,NULL,3,1,3,1,NULL,'stk1917\rWWSI006\rRA117712515CN\r\\\r\r'),(1725,770355936012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','floyd-94','moumen94@gmail.com','Moumen','113 rue Gambetta','Villeneuve saint georges','Île-de-France','FRANCE','94190','01.43.82.84.49.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 12:11:55',0,NULL,3,1,2,1,NULL,'floyd-94\racer 4pin1.25 8cm \r\\'),(1726,570685590013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','emanuel333','efogl@yahoo.com','Emanuel Fogl','Lanište 17b','Zagreb','Zagreb','CROATIA','10000','0998460071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 13:36:20',0,NULL,3,1,2,1,NULL,'emanuel333\r\\'),(1727,693449860011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tedkaz','kaz9ted@yahoo.com','Ted J Kazanski','27111 SEA BREEZE WAY','WESLEY CHAPEL','FL','UNITED STATES','33544-6620','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 13:52:31',0,NULL,3,1,1,1,NULL,'tedkaz\r÷'),(1728,770409992012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tibidubi','pro@solointernet.com','Lluís  Solà i Llinàs','Campins 13, 1r','Santa Maria de Palautordera','Cataluña','SPAIN','08460','933637668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 14:08:19',0,NULL,3,1,2,1,NULL,'tibidubi\r\\'),(1729,0,220767084265,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','amocogas','amocogas@aol.com','Bob Heligman','15151 Harrison St','Livonia','MI','UNITED STATES','48154-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 14:44:42',0,NULL,3,1,1,1,NULL,'amocogas\\'),(1730,570714009013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','arbat-2008','francisco.diaza.46432c@correos.es','Francisco Diaz Alameda','Calle Tridente 15, 6','Alicante','Comunidad Valenciana','SPAIN','03540','630119685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:00:14',0,NULL,3,1,2,1,NULL,'arbat-2008\r\\'),(1731,0,320683130383,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','pocoali','nfgriffin@verizon.net','Nancy Griffin','2651 Aspen Ct','Palm Harbor','FL','UNITED STATES','34684-1947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 15:09:59',0,NULL,3,1,1,1,NULL,'pocoali\r一共买了两个\\'),(1732,693495028011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','thmmax','maxi.hoeller@hotmail.com','Maximilian Höller','Fanggasse 2a','Absam','','AUSTRIA','6067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:26:02',0,NULL,3,1,3,1,NULL,'thmmax\rUDAP001\rRA117712714CN\r\\'),(1733,0,220767081738,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','buntyboss007','sachinmore08@gmail.com','Sachin More','7722 Lucerne Dr<br>Middleburg Hts Apt N26','Cleveland','OH','UNITED STATES','44130-6581','(216) 544-2379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 16:08:20',0,NULL,3,1,1,1,NULL,'buntyboss007\r÷'),(1734,0,230607375028,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','erniemase37','erniemase@yahoo.com','Ernie Mase','31 Ann St','East Haven','CT','UNITED STATES','06513','(203) 469-7391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 16:24:47',0,NULL,3,1,1,1,NULL,'erniemase37\\'),(1735,693576833011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','siamdee08','timothyearl58@gmail.com','Tim Sawatzky','4932 48th Street<br>Box 561','Redwater','AB','CANADA','T0A2W0','(780) 919-3597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:21:24',0,NULL,3,1,2,1,NULL,'siamdee08\r\\'),(1736,770580054012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','kelnerk07','kelnerk@list.ru','Kirill Kelner','Yana Raynisa blvd. 47-1-320','Moscow','Moscow','RUSSIAN FEDERATION','125373','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 17:55:53',0,NULL,3,1,3,1,NULL,'kelnerk07\rOTRA002\rRA117712365CN\r\\'),(1737,519309660003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','n_sasa','sasa@breeze.design.co.jp','Naoto Sasaki','Casa Omori B412, 2-18-23<br>omori-nishi','Ota-ku','Tokyo','JAPAN','1430015','090-7259-8280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:56:56',0,NULL,3,1,3,1,NULL,'n_sasa\rWWOT003\rRA117712263CN\r\\'),(1738,770587265012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','famidosi76','paul.ordi@hotmail.fr','Leroy Dominique','49 rue d\'Alincourt','Lillebonne','Haute-Normandie','FRANCE','76170','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 18:03:17',0,NULL,3,1,3,1,NULL,'famidosi76\rHSSE006\rRA117712802CN\r\\'),(1739,770200162012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','0846016','kulsidee@gmail.com','KULSIDEE SEELACHAROEN','Room 203A Ratchamakka MANSION<br>Soi Yasoob Ratchamakka road','Muang Nakornprathom','Nakornprathom','THAILAND','73000','662 645 6665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:33:33',0,NULL,5,1,18,0,NULL,'0846016  paypal 付款有问题'),(1740,693675807011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','itccc','joe_ching@yahoo.com','Joe Ching','1923 N Tyra Ave','Boise','ID','UNITED STATES','83713-5801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 18:56:51',0,NULL,3,1,1,1,NULL,'itccc\\'),(1741,525138569004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','dave_emmette','dcemmette@gmail.com','David Emmette','14135 Covered Bridge Rd','Lowell','MI','UNITED STATES','49331-9315','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 19:32:12',0,NULL,3,1,1,1,NULL,'dave_emmette\r÷'),(1742,693713964011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','bellhost','admin@bellhost.ru','Dmitry Lezhnin','Lenin Aw. 48-5','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424002','(904) 724-0330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:38:01',0,NULL,8,0,17,0,NULL,'bellhost'),(1743,570883213013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','bellhost','admin@bellhost.ru','Dmitry Lezhnin','Lenin Aw. 48-5','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424002','(904) 724-0330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:40:55',0,NULL,3,1,2,1,NULL,'bellhost\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r\\'),(1744,693714894011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','solomongt','selegash@gmail.com','Solomon Gashaw Tadese','OLAV M TROVIKS VEI 48, H0306','OSLO','Oslo','NORWAY','0864','+4796841678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:45:18',0,NULL,3,1,2,1,NULL,'solomongt\r\\'),(1745,767278912012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','apisitpornpimol1','michiko_us@hotmail.com','APISIT GARPTIP','2216 49th Way N','West Palm Beach','FL','UNITED STATES','33417-3924','(561) 693-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 19:53:39',0,NULL,3,1,1,1,NULL,'apisitpornpimol1\r÷'),(1746,570891712013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','rsoeting','robert@soeting.net','Robert Soeting','Peppelstraat 11','Vianen','','NETHERLANDS','4131 BG','0615599639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:55:25',0,NULL,3,1,2,1,NULL,'rsoeting\r\\'),(1747,570893310013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','docdz1976','docdz1976@gmail.com','Dmitry Zamansky','Uziel 10/8','Bat Yam','','ISRAEL','59463','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 19:59:29',0,NULL,3,1,2,1,NULL,'docdz1976\r\\'),(1748,570900310013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','mabahok','karlwisse@gmx.ch','Karl Wisse','26525886<br>Packstation 137','Koeln','','GERMANY','50935','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 20:11:05',0,NULL,3,1,3,1,NULL,'mabahok\rMOSA001\rRA117712277CN\r\\'),(1749,519402034003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','714501365','manuelbaez@sbcglobal.net','MANUEL BAEZ','723 S RESH ST','ANAHEIM','CA','UNITED STATES','92805-4408','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 20:21:13',0,NULL,3,1,1,1,NULL,'714501365\r÷'),(1750,519400731003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'cnfaner','professorv','gv@trace.wisc.edu','Gregg Vanderheiden','5825 Tree Line Dr<br>NO SIGNATURE REQUIRED','Fitchburg','WI','UNITED STATES','53711-5827','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 20:22:59',0,NULL,3,1,1,1,NULL,'professorv\r\\'),(1751,570909752013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','alexander5437','alex1702@gmx.de','Alexander  Finkhäuser','Schirrmannweg 20','Haan-Gruiten','','GERMANY','42781','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 20:29:30',0,NULL,3,1,2,1,NULL,'alexander5437\racer 4pin1.25 15cm\r\\'),(1752,0,230606818812,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',11,'eastar4','soupy3185','soupy3185@aol.com','Brian  DiPALMO','1063 Oaks Dr','Franklin Square','NY','UNITED STATES','11010-1937','(516) 352-2113','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 20:36:17',0,NULL,3,1,1,1,NULL,'soupy3185\r÷'),(1753,570916523013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','suzannet1957','htea316@yahoo.com','Suzanne Beasley','2 Elkhart ct','rosedale','MD','UNITED STATES','21237-1417','(433) 845-3222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 20:46:18',0,NULL,3,1,1,1,NULL,'suzannet1957\r\\'),(1754,770783740012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','frdavidgreen','califda2005@yahoo.com','david guillouche','13047 Hubbard St<br>Unit 1','Sylmar','CA','UNITED STATES','91342-3353','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 22:26:48',0,NULL,3,1,1,1,NULL,'frdavidgreen\r\\'),(1755,525209322004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'cnfaner','silver_1976','concordia@ole.com','Francisco Vela Ledesma','c/ Veremundo perera nº 20  1ºdcha','Santa Cruz de Tenerife','Canarias','SPAIN','38006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:36:48',0,NULL,3,1,3,1,NULL,'silver_1976\rANYA001\rRA117712586CN\r\\'),(1756,693815473011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','seth7783','lambert7783@yahoo.com','Seth Lambert','1125 Mote Rd','Carrollton','GA','UNITED STATES','30117-6763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 22:49:31',0,NULL,3,1,1,1,NULL,'seth7783\r÷'),(1757,570956863013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','pmask919','pkpbmaskell@gmail.com','Paul Maskell','5 Drysdale St','Kanata','ON','CANADA','K2K3L3','(613) 599-6915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:50:51',0,NULL,3,1,2,1,NULL,'pmask919\r\\'),(1758,570971745013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','jobanekpaul','pjnelson22@yahoo.com',' Paul   Nelson','88715 Faulhaber RD','Elmira','OR','UNITED STATES','97437','(541) 935-9556','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-10 23:51:07',0,NULL,3,1,1,1,NULL,'jobanekpaul\\'),(1759,693840318011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','btaconazo1','btaconazo@aol.com','harnold barbosa','5303 SE 99th Ave','portland','OR','UNITED STATES','97266-3711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:05:07',0,NULL,3,1,1,1,NULL,'btaconazo1\\'),(1760,770831108012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','shctuh','hutchsuc@yahoo.com','Alvin Hutchinson','849 Leisure Land Dr','Big Cabin','OK','UNITED STATES','74332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:05:41',0,NULL,3,1,1,1,NULL,'shctuh\r\\'),(1761,770836259012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','octinium','dduffy@gmail.com','William Duffy','1935 Flushing Ave','Ridgewood','NY','UNITED STATES','11385-1042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:24:47',0,NULL,3,1,1,1,NULL,'octinium\r÷'),(1762,525233918004,140427937126,'2.1 Acer Aspire D250 bluetooth module we offer track#',1,'',13.99,'cnfaner','jfcosta.br','jflavio.br@gmail.com','Jorge Flavio Costa','Rua Tomas Soares de Souza, 675, Ap. 202<br>Res. Buganville, Catolé','Campina Grande','Paraíba','BRAZIL','58410235','+55 83 88892510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 00:25:02',0,NULL,3,0,3,1,NULL,'jfcosta.br\rAcer 4pin 1.25 15cm\rBTAC2107\rRA117712325CN\r\\'),(1763,570984309013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','negritoyankee','el-negrito-de-magas@hotmail.com','Luis M Morales Torres','Hc 2 Box 6373','Guayanilla','PR','UNITED STATES','00656-9713','(787) 585-9485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:35:05',0,NULL,3,1,1,1,NULL,'negritoyankee\r÷'),(1764,770847463012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','charlesh2107','charlesharvey@msn.com','Charles Harvey','2025 Forest Glen Ct','Tallahassee','FL','UNITED STATES','32303-5137','(850) 544-4650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 00:49:50',0,NULL,3,1,1,1,NULL,'charlesh2107\r\\'),(1765,770870421012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','referinta','chesoherrera@hotmail.com','David Herrera','10400 Larose, app. 1','Montreal','QC','CANADA','H2B 2Z2','(514) 825-9747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 01:52:11',0,NULL,3,1,2,1,NULL,'referinta\r\\'),(1766,770869978012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','festivill','festivill@gmail.com','Federico Gustavo Estivill','El Condor 338','Dina Huapi','Rio Negro','ARGENTINA','R8406ASH','+541140402653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 01:54:38',0,NULL,3,1,2,1,NULL,'festivill\r\\'),(1767,519494647003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',22,'cnfaner','rtil7963','tillmanrobert56@yahoo.com','Robert Tillman','2605 SW Joshua Ave','Bentonville','AR','UNITED STATES','72712-8323','(479) 659-2161','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 01:55:56',0,NULL,3,1,1,1,NULL,'rtil7963\r÷'),(1768,521332034004,140429365212,'2.1 HP Pavilion DV4 DV7 bluetooth module has track#',1,'BTHP2107',16.59,'cnfaner','lincolnsm250','lincoln_mil@yahoo.com.br','Daniele de Almeida dos Santos Amaro','Rua Francisco Lopes, S/N, Bloco 10, Ap 201 - PNR 1 da ESAO<br>Vila Militar','Rio de Janeiro','Rio de Janeiro','BRAZIL','21615-080','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 02:14:22',0,NULL,3,1,3,1,NULL,'lincolnsm250\rHP 8pin 1.0 23cm \rBTHP2107\rRA117716680CN\r、'),(1769,770892356012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 02:51:12',0,NULL,3,0,2,1,NULL,'annaandythai\r\\'),(1770,693901037011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','bootucke','bootucker@cfl.rr.com','Michelle Tucker','2746 Whistler St','Melbourne','FL','UNITED STATES','32904-7496','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 03:09:51',0,NULL,3,1,1,1,NULL,'bootucke\\'),(1771,770899203012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','kkbasol','kerimbasol@gmail.com','Kerim BASOL','Bostanci Cami Sk. Cesur Apt. No:13 D:3<br>Kadikoy','Istanbul','Istanbul','TURKEY','34744','+902164101810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:15:28',0,NULL,3,1,3,1,NULL,'kkbasol\rMOLO002\\\r潘'),(1772,770910114012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','huimingr7dex','huimingr@msn.com','Ming Ruan','9762 Innisbrook Blvd','Carmel','IN','UNITED STATES','46032','(317) 879-9488','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 04:01:01',0,NULL,3,1,1,1,NULL,'huimingr7dex\\'),(1773,693925022011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','bla_it','infosys@bla.com.au','Alan Wright','45 Aquarium Avenue','Hemmant','Queensland','AUSTRALIA','4174','0733900138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:07:11',0,NULL,3,1,2,1,NULL,'bla_it\r\\'),(1774,693925830011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','lawkoot','ykoot@hotmail.com','Y. Koot','Dignaland 88','Den Haag','','NETHERLANDS','2591CD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:12:12',0,NULL,3,1,2,1,NULL,'lawkoot\r\\'),(1775,571048971013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','mrman012','mrman012@telus.net','Dan DenHollander','43525 Lumsden Rd','Chilliwack','BC','CANADA','V2R 4R4','(604) 823-4494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:40:20',0,NULL,3,1,2,1,NULL,'mrman012\r\\'),(1776,525293873004,140516874343,'Atheros AR5008 802.11N 300M Wireless Mini PCI-E Card',1,'WLAT002',14.49,'cnfaner','cabcbentsai','cabcben@hotmail.com','Tsai I-Ping','1320 Flynn Crescent','Coquitlam','BC','CANADA','V3E 1Y2','(604) 800-2301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 05:43:31',0,NULL,3,1,3,1,NULL,'cabcbentsai\rWLAT002\rRA117712728CN\r\\'),(1777,571053529013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','upsdude73','jani.ebay@gmail.com','Jani Lustig','Kaskihakkio 4 B 5','ESPOO','','FINLAND','02340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 06:15:54',0,NULL,3,1,2,1,NULL,'upsdude73\r、'),(1778,770941895012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','wolk3d','wolk3d@gmail.com','verlan Iulian','1927 31st Ave','SAN FRANCISCO','CA','UNITED STATES','94116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 06:41:22',0,NULL,3,1,1,1,NULL,'wolk3d\r\\'),(1779,571060198013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','mantik','mantas.bystautas@gmail.com','Mantas Bystautas','Verdelupio 19-27','Ariogala','Lithuania','LITHUANIA','60266','0037067952086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:05:10',0,NULL,3,1,2,1,NULL,'mantik\r\\'),(1780,571060955013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','wuka2oo2','wuka2002@o2.pl','Wojciech Kaczorowski','Kmicica 8a/2','Grodzisk Mazowiecki','mazowieckie','POLAND','05825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:21:54',0,NULL,3,1,2,1,NULL,'wuka2oo2\r\\'),(1781,525306179004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','ilkayde','ilkaydemirhan@hotmail.com','ilkay demirhan','Lalahan Livestock Central Research Institute','Lalahan-Mamak','Ankara-TURKEY','TURKEY','06852','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:38:07',0,NULL,3,1,3,1,NULL,'ilkayde\rOTCR001\rRA117716910CN\r\\'),(1782,770965545012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','d.yousufi','d.yousufi@hotmail.com','David Yousufi','Legerland 30','Koog aan de Zaan','','NETHERLANDS','1541 NE','0614537086','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 08:23:15',0,NULL,3,1,3,1,NULL,'d.yousufi\rOTRA002\rRA117716923CN\r\\'),(1783,524312643004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','fingerin2000','gregory.depienne@yahoo.com','Gregory Depienne','9 Rue Victor Rogelet','Reims','Champagne-Ardenne','FRANCE','51100','06.62.39.64.69','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 08:59:00',0,NULL,3,1,3,1,NULL,'fingerin2000\rWLIN010+ANTY002\rRA117712952CN\r\\'),(1784,571080487013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','dankaholic256','ultimateplaya256@gmail.com','Daniel Kasal','74 Taylor St','Amherst','MA','UNITED STATES','01002-2135','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 09:17:09',0,NULL,3,1,1,1,NULL,'dankaholic256\r、'),(1785,693983584011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','tal_78360','tal.goldberg@gmail.com','Itzhak Goldberg','1 Meonot Bracha','Rishon Le\'zion','','ISRAEL','75315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:42:25',0,NULL,3,1,2,1,NULL,'tal_78360\r\\'),(1786,571087967013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',84.9,'eastar4','ozziede','tsum@hutchison.com.au','Tony Sum / CO- Vodafone Hutchison Australia','Level 4<br>12 Help St','Chatswood','New South Wales','AUSTRALIA','2067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:59:19',0,NULL,3,1,3,1,NULL,'ozziede\rMOSA003\rRA117716764CN\r、'),(1787,771000604012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 10:34:31',0,NULL,3,1,3,1,NULL,'avextra-co-uk\rOTCN004*10\r\rRA022493506CN\r\\'),(1788,694014343011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','artyrod1','artyrod@hotmail.com','Arturo Rodriguez','174 Burgess Pl','Passaic','NJ','UNITED STATES','07055','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 11:37:52',0,NULL,3,1,1,1,NULL,'artyrod1\racer 6pin1.25 23cm\r、'),(1789,771029892012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','robomatt101','mattjag@aol.com','Matthew Cardenas','2308 62nd St<br>Apt B','Lubbock','TX','UNITED STATES','79412-3306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 12:10:25',0,NULL,3,1,1,1,NULL,'robomatt101\r÷'),(1790,694029665011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',2,'HSSE007',39.8,'eastar4','estevaojrr1','estevaojrr@ig.com.br','Alan Antunes Rosendo','Cond. vert paradiso, Qd-J, lote-19<br>serraria','Maceió','Alagoas','BRAZIL','57048-375','8233288120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 12:33:48',0,NULL,3,1,3,1,NULL,'estevaojrr1\rHSSE007\rRA117716733CN、'),(1791,693954160011,320679575591,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',34,'eastar4uk','aleksey1979','3332961@gmail.com','Aleksey Rusin','Butlerova st. 24/258','Moscow','','RUSSIAN FEDERATION','117342','(495)333-2961','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 13:22:23',0,NULL,3,1,3,1,NULL,'aleksey1979\rWWOT001+ANCN001\rRA117716781CN\r、'),(1792,525370935004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','jonp1625','kjkpaul@yahoo.com','Kimberly Paul','1625 Cape May Rd','Baltimore','MD','UNITED STATES','21221-1612','(410) 391-6449','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 13:25:46',0,NULL,3,1,1,1,NULL,'jonp1625\r、'),(1793,525390179004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','myginny','silpheed@gmail.com','Jeewon Yu','NeutiMaeul 3 Danji APT 307-302<br>Jeongja-dong, Bundang-gu','Seongnam-si','Gyeonggi-do','KOREA,REPUBLIC OF','463-744','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 14:50:44',0,NULL,3,1,3,1,NULL,'myginny\rWWSI005\rRA117716778CN\r、'),(1794,0,230607783830,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',11.5,'eastar4','aeioumom','vowell58@yahoo.com','Josephine Vowell','47611 West Dry Creek Road','Halfway','OR','UNITED STATES','97834','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-11 14:58:43',0,NULL,3,1,1,1,NULL,'aeioumom\r、'),(1795,0,220767574721,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','greeneyedjoker420','supemecable@yahoo.com','Juan Padilla','2281 SW 81ST AVE<br>APT 128','DAVIE','FL','UNITED STATES','33324-5556','(786) 333-9471','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 15:12:04',0,NULL,3,1,1,1,NULL,'greeneyedjoker420\r÷'),(1796,525390611004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','farm29girl','mlinden@localnet.com','Marjorie Linden','402 Deerfield Ct','Hendersonville','NC','UNITED STATES','28792-8522','(828) 698-4957','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:19:19',0,NULL,3,1,1,1,NULL,'farm29girl\r、'),(1797,571165624013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','mosij0','dmosimann@sasktel.net','Jim Mosimann','Box 250','Edam','SK','CANADA','S0M0V0','(306) 397-2849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:41:07',0,NULL,3,1,2,1,NULL,'mosij0\r、'),(1798,694094308011,320602601396,'2.1 Acer Aspire 5580 5570 5570Z Bluetooth Module +cable',1,'BTAC2116',12.8,'eastar4','sysconindo','sammy@sysconindo.com','Samuel Budimartono','Jln.Pangeran Jayakarta 117 - B1<br>Jakarta Pusat','Jakarta','DKI','INDONESIA','10730','+62216599660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:47:33',0,NULL,3,1,2,1,NULL,'sysconindo\racer 6pin1.25 23cm\r、'),(1799,771109741012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.8,'eastar4','geogain','geogain@yahoo.gr','Georgios Kainourgios','Paramythias 1','Thesprotikon','','GREECE','48300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 15:53:10',0,NULL,3,1,2,1,NULL,'geogain\r8pin 1.0 8cm \r、'),(1800,0,320683601720,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',14,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 16:38:07',0,NULL,3,1,1,1,NULL,'4278dennis\r÷'),(1801,694114454011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'',21.9,'eastar4','eaalle','lizzygriffin@yahoo.com','Elizabeth Griffin','4225 Botanical Ave<br>Fl 1','Saint Louis','MO','UNITED STATES','63110-3520','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 16:43:37',0,NULL,3,0,1,1,NULL,'eaalle\r÷'),(1802,771137295012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','murfhit','murfhit@hotmail.co.uk','Danny Walsh','59 Bryson Stret','Belfast','Antrim','UNITED KINGDOM','BT5 4ET','07765990712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:52:21',0,NULL,3,1,3,1,NULL,'murfhit\rHSSE005\r英标\rRA117716720CN\r、'),(1803,771140363012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','nadavharel','nadav0harel@gmail.com','nadav harel','mapiley egoz 12','beit shemesh','israel','ISRAEL','99547','972029991204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:06:47',0,NULL,3,1,2,1,NULL,'nadavharel\r、'),(1804,771213399012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','asiatradeinc-gmail','asiatradeinc@gmail.com','Varga Sandor','264/43 Rachadamnom Rd.  Thawang Muang','Nakhon si thammarat','Nakhon Si Thammarat','THAILAND','80000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:02:37',0,NULL,3,1,11,1,NULL,'asiatradeinc-gmail\rANYA002\r、'),(1805,771235087012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',2,'OTHP003',29.8,'eastar4uk','jpayton77','james.payton@gmail.com','James Payton','163 Spixworth Road<br>Old Catton','Norwich','Norfolk','UNITED KINGDOM','nr6 7dy','01603403407','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 19:35:51',0,NULL,3,1,3,1,NULL,'jpayton77\rOTHP003\rRA117716747CN\r、'),(1806,571256935013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',4,'HSMO018',43.96,'eastar4','haim2210','haimoked@bezeqint.net','Haim Oked','Hanakar 1','Beer Yaaqov','Israel','ISRAEL','70300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:51:28',0,NULL,3,1,3,1,NULL,'haim2210\rHSMO018\rRA117716755CN\r、'),(1807,519732506003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','ziggy404','kendrickking@hotmail.com','Kendrick King','302 nw 17th ave','Fort lauderdale','FL','UNITED STATES','33311-8712','(954) 588-9337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 19:55:39',0,NULL,3,1,1,1,NULL,'ziggy404\r、'),(1808,694229652011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','goldjohnny1220','arizzona@hotmail.com','John Izzo','6601 E Ironwood Dr','Paradise Valley','AZ','UNITED STATES','85253-2621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 20:12:30',0,NULL,3,1,1,1,NULL,'goldjohnny1220\r、'),(1809,694231023011,320679575680,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',21,'eastar4uk','sjonny.d1','sjonny.d@gmail.com','Evgeny Dobrushin','Motzkin 21/24','Netaniya','','ISRAEL','42460','+972578120248','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 20:14:33',0,NULL,3,1,3,1,NULL,'sjonny.d1\rWWSI005\rRA117716795CN\r、'),(1810,694244028011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','rocketer9','erick_ballard@yahoo.com','Erick Ballard','3374 S 137th East Ave','Tulsa','OK','UNITED STATES','74134-4208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 20:48:12',0,NULL,3,1,1,1,NULL,'rocketer9\r÷'),(1811,571282086013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','ziggyboy.417','ziggyboy3d@juno.com','Ryan Ziegler','5549 S Aaron Ave','Springfield','MO','UNITED STATES','65810-2045','(417) 234-9586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 21:01:47',0,NULL,3,1,1,1,NULL,'ziggyboy.417\r、'),(1812,694256705011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','yana21x','yana21x@yahoo.com','Jana Strautane','24 Paget Road','Great Yarmouth','Norfolk','UNITED KINGDOM','NR30 2DN','07704410182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 21:11:48',0,NULL,3,1,2,1,NULL,'yana21x\r、'),(1813,571286930013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','jorge23r','jorge23r@hotmail.com','Jorge Ribeiro','5540 Rhodes Street','Vancouver','BC','CANADA','V5R3N9','(604) 831-5764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 21:18:01',0,NULL,3,1,2,1,NULL,'jorge23r\r、'),(1814,571300025013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','smr-tec','ebay@smr-tec.com','Sven Moreiko','Birkenweg 14','Bad Lauchstädt OT Schafstädt','','GERMANY','06246','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:10:50',0,NULL,3,1,3,1,NULL,'smr-tec\rMOSA002\rRA117716852CN\r.、'),(1815,569963278013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','bejaia06hamaoui','elkseur06@free.fr','hamaoui','13 rue kleber','drancy','Ile-de-France','FRANCE','93700','0665658462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:19:14',0,NULL,3,1,3,1,NULL,'bejaia06hamaoui\rWWOT001+ANCN001\rRA117716716CN\r、'),(1816,571294783013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 22:24:58',0,NULL,3,1,2,1,NULL,'321tocsin\r、'),(1817,771331698012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','avi300','avi10@live.com','A Tripathi','2009 Greene St<br>Apt 507','Columbia','SC','UNITED STATES','29205','(806) 470-2752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 23:22:18',0,NULL,3,1,1,1,NULL,'avi300\r÷'),(1818,694305922011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','orsani','sanimail@gmail.com','Or Sani','Ha\'oren 60','Oranit','','ISRAEL','44813','+972506503148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 23:53:23',0,NULL,3,1,2,1,NULL,'orsani\r、'),(1819,771342534012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','publiur','caldera55@gmail.com','Carlos Sancho  Caldera','C/ Pedro teixeira 9','Madrid','Madrid','SPAIN','28020','680459344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 23:55:29',0,NULL,3,1,2,1,NULL,'publiur\r欧标\r、'),(1820,694317115011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','horns21','jwhite@planview.com','White Jason','3909 Coopers Hawk Cv','Austin','TX','UNITED STATES','78738-6526','(512) 423-8077','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 00:36:19',0,NULL,3,1,1,1,NULL,'horns21\r÷'),(1821,0,220767084369,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','dg006','dg006@yahoo.com','Diana Gonzalez','1129 N Marshall St<br>Apt 22','Milwaukee','WI','UNITED STATES','53202-3314','(414) 364-3870','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-12 01:08:28',0,NULL,3,1,1,1,NULL,'dg006\r、'),(1822,691613204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','eabrahams10','eabrahams_07@hotmail.com','Enrique Romero','PO BOx 742','Culebra','PR','UNITED STATES','00775-0742','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:16:51',0,NULL,3,1,1,1,NULL,'eabrahams10\r÷'),(1823,659225570001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','ptagau','crmeyer2003@comcast.net','Charles R. Meyer','210 NE 41st St<br>Apt 104','Ankeny','IA','UNITED STATES','50021','(847) 903-8271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:21:02',0,NULL,3,1,1,1,NULL,'ptagau\rLK038985619CN\r÷'),(1824,768682445012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','chucksangel21777','chucksangel21777@yahoo.com','Chuck Evatt','901 E Kiehl Ave','sherwood','AR','UNITED STATES','72120-3031','(501) 902-8832','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:21:39',0,NULL,3,1,1,1,NULL,'chucksangel21777\r、'),(1825,694333868011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jvilla742','jvilla321@gmail.com','Jeff Villanueva','1930 Decelles','Montreal','QC','CANADA','H4M1A8','(514) 692-0069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:42:08',0,NULL,3,1,2,1,NULL,'jvilla742\r、'),(1826,694337890011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ldimas26','gladib@cwpanama.net','Luis Dimas','8619 NW 68th St<br>Pty S0264','Miami','FL','UNITED STATES','33166-2667','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 01:52:16',0,NULL,3,1,1,1,NULL,'ldimas26\r÷'),(1827,571366899013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','mchinand','chinander@gmail.com','Michael Chinander','5009 S Dorchester Ave<br>Apt Bsmnt','Chicago','IL','UNITED STATES','60615-2928','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 03:27:31',0,NULL,3,1,1,1,NULL,'mchinand\r÷'),(1828,571371539013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','satellite-gt','glidden@caribe.net','Glidden A Torres','RR 1 Box 2232','Anasco','PR','PUERTO RICO','00610-9656','7877170335','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 03:59:41',0,NULL,3,1,1,1,NULL,'satellite-gt\r÷'),(1829,771413451012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','dolphinhawaii','branto@hawaii.rr.com','Brant Oshiro','1802 Hoohulu St.','Pearl City','HI','UNITED STATES','96782','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 04:11:46',0,NULL,3,1,1,1,NULL,'dolphinhawaii\r、'),(1830,771430484012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','tkjoseph','tkjoseph@yahoo.com.tw','LIU KUAN LIN','Rm. 3, 5F., No.172, Changchun Rd.,','Jungshan Chiu, Taipei,10485','Taiwan','TAIWAN','R.O.C.','(093)589-8081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 05:43:31',0,NULL,3,1,2,1,NULL,'tkjoseph\r、'),(1831,571385888013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','shiron1972','shiron@yellow.plala.or.jp','YUICHIRO KANEDA','shimasaki 1-16-20<br>CIMA-206','Kumamoto','Kumamoto','JAPAN','8600073','0962004873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 05:47:49',0,NULL,3,1,2,1,NULL,'shiron1972\r、'),(1832,571407509013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','masmaster','mshtephan@gmail.com','Maxim Shtephan','Kozatska st., 3<br>ZAT Chumak','Kakhovka','Kherson reg','UKRAINE','74800','380-504422022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:30:10',0,NULL,3,1,2,1,NULL,'masmaster\r、'),(1833,519872067003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','suprememaster1990','eloyvanschaik@gmail.com','Eloy van Schaik','Harmoniestraat 73','Helmond','','NETHERLANDS','5702 JD','020-7043-5364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:44:28',0,NULL,3,1,3,1,NULL,'suprememaster1990\rHSUE004\rRA117716353CN\r、'),(1834,525631719004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.97,'cnfaner','never6910','malaspinapietro@alice.it','PIETRO MALASPINA','VIA S. AGATA AL FIUME, 36','REGGIO CALABRIA','RC','ITALY','89131','3339293127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 08:50:18',0,NULL,3,0,3,1,NULL,'never6910\rWWSI005\rRA117716702CN\r、'),(1835,694426250011,320679575605,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',30,'eastar4uk','microsaci','info@microsaci.com','alberto prado mazagato','llul 102 bajos<br>MICROSACI','barcelona','Cataluña','SPAIN','08005','933001555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 09:00:08',0,NULL,8,1,17,0,NULL,'microsaci\rWWOP003'),(1836,694427456011,320679575605,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',30,'eastar4uk','microsaci','info@microsaci.com','alberto prado mazagato','llul 102 bajos<br>MICROSACI','barcelona','Cataluña','SPAIN','08005','933001555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 09:04:17',0,NULL,3,1,3,1,NULL,'microsaci\rWWOP003\r一共买了两个\r\rRA117729374CN'),(1837,571417790013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','toxicated101','matthew.wheatley1@ntlworld.com','Matthew Wheatley','27a<br>Sansome Place','Worcester','Worcestershire','UNITED KINGDOM','WR1 1UA','0190522316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:23:30',0,NULL,3,1,2,1,NULL,'toxicated101\r\\'),(1838,571421213013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','ogattaz','olivier@gattaz.com','isandlaTech, Mr Olivier Gattaz','255 chemin des arriots','montbonnot saint martin','Rhône-Alpes','FRANCE','38330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:47:54',0,NULL,3,1,2,1,NULL,'ogattaz\r\\'),(1839,771496871012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','eubookings','webmaster@eubookings.com','EU Bookings LTD.','Waterford City Enterprise Ctr, Waterford Bus. Pk.<br>Cork Road','Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 10:23:05',0,NULL,3,1,3,1,NULL,'eubookings\rOTGR001\rRA117729119CN\r\\'),(1840,694450241011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','redbaron137','marsnine@optusnet.com.au','Chak Ng','5 Lewis Grove','Mt Waverley','Victoria','AUSTRALIA','3149','0414539014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 10:34:02',0,NULL,3,0,2,1,NULL,'redbaron137\r÷'),(1841,694454332011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.8,'eastar4','mrazicek92','crims@zoznam.sk','Jakub Mrazik','Tranovskeho 111/3','Liptovsky Mikulas','Zilinsky Kraj','SLOVAK REPUBLIC','03101','0907440447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 10:50:41',0,NULL,3,1,2,1,NULL,'mrazicek92\racer 4pin1.25 6cm \r÷'),(1842,771518030012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','bluecrew72','jamiebeckf@gmail.com','Jamie Feldman','45 Sunbird Crescent','Carrum Downs','Victoria','AUSTRALIA','3201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 11:34:14',0,NULL,3,1,2,1,NULL,'bluecrew72\r÷'),(1843,694471813011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','hbitton','hananko@gmail.com','Hanan Bitton','Hazait 75 / 12','Oranit','Israel','ISRAEL','44813','972543007580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:00:17',0,NULL,3,1,3,1,NULL,'hbitton\rRCLO006\rRA117729136CN\r、'),(1844,694480269011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mr_bigtoe','steven-james@bigpond.com','Steve James','34 Warner Drive','Padbury','Western Australia','AUSTRALIA','6025','0894027501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:21:19',0,NULL,3,1,2,1,NULL,'mr_bigtoe\r÷'),(1845,694480899011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',37.8,'eastar4','i9wolf','stonehum@hotmail.com','Nik Wolf','P.O Box 824','Glenorchy','Tasmania','AUSTRALIA','7010','0487387851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:25:18',0,NULL,3,1,3,1,NULL,'i9wolf\rWLAP002\rRA117729207CN\r\\'),(1846,525672286004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','kysa2','bokas@comcast.net','Edmundas Rainys','6036 Sherman Dr','Woodridge','IL','UNITED STATES','60517','(630) 362-2251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 12:34:02',0,NULL,8,1,17,0,NULL,'kysa2'),(1847,519914384003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','kysa2','bokas@comcast.net','Edmundas Rainys','6036 Sherman Dr','Woodridge','IL','UNITED STATES','60517','(630) 362-2251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 12:37:37',0,NULL,3,1,1,1,NULL,'kysa2\r一共买了一个水管一个花洒\r、'),(1848,771540743012,220705197816,'New in box  Motorola H700 Bluetooth Wireless Headset',1,'HSMO013',16.9,'eastar4uk','pbry2421','bryanandkirby@sky.com','peter bryan','114 high garrett,<br>braintree,','braintree','Essex','UNITED KINGDOM','cm75nt','01376326960','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 12:44:21',0,NULL,3,1,3,1,NULL,'pbry2421\rHSMO013\r英标\rRA117729737CN\r、'),(1849,694468576011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',32.9,'eastar4','zolee7','stargame.zolee@maffia.hu','Pusztaszeri Zoltán','Hobiart Basa st. 8','Szeged','HI','HUNGARY','6723','+36304413958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:00:07',0,NULL,3,1,3,1,NULL,'zolee7\r欧标  HSNO003\rRA117729175CN\r、'),(1850,694496562011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ryanverdana','massicotte_charles@yahoo.ca','Charles Massicotte','195, Sainte Cécile','Le Bic','QC','CANADA','G0L1B0','(418) 736-4797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:14:16',0,NULL,3,1,2,1,NULL,'ryanverdana\r÷'),(1851,525686814004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','maxwell-58','maxwell-58@hotmail.com','brad smith','11 cherry rd eleebana','newcastle','New South Wales','AUSTRALIA','2282','0402308547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 13:41:53',0,NULL,3,0,3,1,NULL,'maxwell-58\rTOIN002+BAIN002+BAIN001\rRA117729445CN\r\\'),(1852,694519110011,320679575403,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.5,'eastar4uk','timgiles','tim@giles.my-bulldog.com','Timothy Giles','Kungsgatan 19b','Umeå','','SWEDEN','90321','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 14:24:32',0,NULL,3,1,2,1,NULL,'timgiles\r÷'),(1853,571483038013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','pdslab','tertrd@yahoo.com.sg','Terence Lee','Block 12 #07-07/08<br>Lorong Bakar Batu','Singapore','','SINGAPORE','348745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:30:59',0,NULL,3,1,3,1,NULL,'pdslab\rMOSA002\rRA117716340CN\r、'),(1854,771582221012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','mal8721','djmalwilliams@gmail.com','Mal Williams','29 Gladstone road, Sholing','Southampton','Hampshire','UNITED KINGDOM','SO19 8GU','02380320931','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 14:40:08',0,NULL,3,1,3,1,NULL,'mal8721\rHSPL011\rRA117729198CN\r、'),(1855,771584072012,220741050719,'NEW GENUINE NOKIA BH-205 BLUETOOTH HEADSET BH 205',1,'HSNO009',15.5,'eastar4','6525moon6525','joaojmoura@gmail.com','João Moura (Ext.3311)','Rua Xavier Araujo,<br>Edificio Estação Laranjeiras','Lisboa','','PORTUGAL','1600-226','00351968355630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:47:04',0,NULL,3,1,2,1,NULL,'6525moon6525\r补一个欧标\r÷'),(1856,525722359004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','sonysen12345','sonysen8@gmail.com','sevtian agus prasetyo','jalan gergaji 3 no 27 rt04 rw 05 kelurahan mugassari','semarang','jawa tengah','INDONESIA','50243','(085) 641-3215 ext.: 50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 16:06:56',0,NULL,5,1,18,1,' ','sonysen12345\rHSSA001\rpaypal有问题\r潘'),(1857,694573533011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','darshini1984','darshi.dalal@gmail.com','Darshini Dalal','4323 Colden St<br>Apt 20A','Flushing','NY','UNITED STATES','11355-5926','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 16:50:48',0,NULL,3,1,1,1,NULL,'darshini1984\r\\'),(1858,571531481013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','sigor220972','sigor72@mail.ru','Igor Selyutin','Kutuzova 6/1 kv 49','Pavlodar','','KAZAKHSTAN','140000','87182550675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 17:19:46',0,NULL,3,1,2,1,NULL,'sigor220972\r÷'),(1859,0,220767084472,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',26.99,'eastar4','rsdixon','scott_dixon@ccountry.net','Scott R. Dixon','838 Blackberry Ln','Ashland','OR','UNITED STATES','97520','(541) 482-0701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 17:21:21',0,NULL,3,1,1,1,NULL,'rsdixon\r\\'),(1860,519985894003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','galewaves506','glick.eliot@gmail.com','Gudiya Ale','Mantri Elegance, Suite B-506<br>(Next to Shoppers Stop)','Bangalore','KA','INDIA','560076','9945575575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 17:21:39',0,NULL,3,1,3,1,NULL,'galewaves506\rBAZA001\rRA117729184CN\r\\'),(1861,525761318004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','a3_customize','atm.82@mail.ru','Alexandr Antonov','Fedorovskaya 5-188','Saratov','Saratov','RUSSIAN FEDERATION','410018','+79083770881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 18:13:35',0,NULL,3,1,3,1,NULL,'a3_customize\rOTGR001+OTGR002\r\rRA117729618CN'),(1862,694616680011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','chadlandwehr','thebob1911@gmail.com','chad landwehr','850 Chalfont Pl','coppell','TX','UNITED STATES','75019-2876','(972) 304-0124','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 18:16:46',0,NULL,3,1,1,1,NULL,'chadlandwehr\r\\'),(1863,694655691011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','trueduck2000','etn@free.fr','Etienne MERIAUX','81bis route de Clisson','St-SEBASTIEN sur LOIRE','Pays de la Loire','FRANCE','44230','02.28.21.03.46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:29:38',0,NULL,3,1,2,1,NULL,'trueduck2000\r欧标\r÷'),(1864,771730850012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',2,'CRLO001+POLO001',35.8,'eastar4','lmaier9','lmaier@sio.midco.net','Larry Maier','2901 S Hidden Pl<br>Apt 14','Sioux Falls','SD','UNITED STATES','57106-7248','(605) 338-3020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 19:39:26',0,NULL,3,1,1,1,NULL,'lmaier9\r\\'),(1865,694670239011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','mathers5','matters55@hotmail.com','A v/d Lei','Oud Ambacht 225','DRACHTEN','','NETHERLANDS','9201 VT','0642111055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:57:36',0,NULL,3,1,2,1,NULL,'mathers5\r÷'),(1866,571596338013,230606464789,'Apple Airport Extreme WIFI PCI-E 802.11n + 2 Antenna',1,'WLAP005+ANAP001',21.98,'eastar4','pprauken','patpe527@gmail.com','Patrik Persson','Lugna Gatan 52','Malmö','','SWEDEN','211 59','+46703032181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:27:40',0,NULL,3,1,2,1,NULL,'pprauken\r÷'),(1867,520057803003,130490187857,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'cnfaner','risto.cvetkovski','risto@cvetkovski.mk','Risto Cvetkovski','Joakim Krocovski no.14','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','38971322122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:47:25',0,NULL,3,1,3,1,NULL,'risto.cvetkovski\rMOLO002\rRA117729140CN\r、'),(1868,771785813012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','dogdude62','dogdude62@hotmail.com','William Perkins','115 Bragdon Rd','Freeport','ME','UNITED STATES','04032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 21:25:38',0,NULL,3,1,1,1,NULL,'dogdude62\r、'),(1869,769892037012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',18.4,'eastar4uk','shanghaixiaoniucathy','cathy.yinjiazhen@gmail.com','Cathy Yin','RM3102, 3 Pan Peninsula Square','London','London','UNITED KINGDOM','E14 9HQ','07553013640','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 21:56:15',0,NULL,3,1,3,1,NULL,'shanghaixiaoniucathy\rHSPL001\r新地址\rEva X Zhang\rLevel 41, 8 Canada Square\rCanary Wharf\rE14 5HQ\rUnited Kingdom\rTel: +44 (0)7827356773,  +44(0)7760684447\rRA117729873CN\r、\r'),(1870,694747799011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','fchgs','fchgds@gmail.com','Fernando Chavez','Av. La Salle Calle Franz Tamayo 6','Santa Cruz de la Sierra','Santa Cruz','BOLIVIA','00000','(591)72669555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 23:29:20',0,NULL,3,0,2,1,NULL,'fchgs\r÷'),(1871,771834123012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','adonay_es','adonay_juan@hotmail.com','Juan CRUZ CALERO','c/ cantos 5 7d','Alcorcon (Madrid)','Madrid','SPAIN','28922','650884349','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 23:55:36',0,NULL,3,1,3,1,NULL,'adonay_es\rOTRA002\rRA117729860CN\r、'),(1872,520090963003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.99,'cnfaner','gnudarve','buck@wisewerks.com','Walter McGibbony','4008 1/2 Monroe St','Los Angeles','CA','UNITED STATES','90029-2906','(323) 304-4497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 00:00:37',0,NULL,3,1,1,1,NULL,'gnudarve\r\\'),(1873,771806797012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','grata1m','behanzin.reid.bills@gmail.com','Behanzin Reid','3716 Dyre Ave','Bronx','NY','UNITED STATES','10466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 00:44:16',0,NULL,3,1,1,1,NULL,'grata1m\r\\'),(1874,525744822004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.98,'cnfaner','zahaini','zahainihamzah@gmail.com','LUQMANUL HAKIM BIN ABD. RAHIM','17-1B PUTRI APARTMENT,<br>JALAN SETIAWANGSA 21, TAMAN SETIAWANGSA,','KUALA LUMPUR','WP','MALAYSIA','54200','017-3308263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 00:59:05',0,NULL,3,1,3,1,NULL,'zahaini\rWWSI005\rRA117729153CN\r、'),(1875,571668919013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','classicscooterparts','worldrareitems2008@gmail.com','Howard Ngo','3071 Centerwood Way','San Jose','CA','UNITED STATES','95148-2656','(408) 417-5296','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-13 01:14:18',0,NULL,3,1,1,1,NULL,'classicscooterparts\r\\'),(1876,771855334012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','bastos5776','bastosfamily@msn.com','frank bastos','738 Dennis Pl<br>linden','Linden','NJ','UNITED STATES','07036-1231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 01:15:24',0,NULL,3,1,1,1,NULL,'bastos5776\r\\'),(1877,694626279011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','anirodgers42','anirodgers@yahoo.com','Anita Rodgers','1999 Burdett Ave<br>White 3004','Troy','NY','UNITED STATES','12180-3743','(908) 319-9973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 01:49:48',0,NULL,3,1,1,1,NULL,'anirodgers42\r\\'),(1878,694785067011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','zsectsz','sects@naver.com','Joon Lee','12918 SE Foster Rd<br>Bc Food Store','Portland','OR','UNITED STATES','97236-4524','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 02:00:56',0,NULL,3,1,1,1,NULL,'zsectsz\r\\'),(1879,525793978004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','tdrahrhe','ilehrhardts@yahoo.com','Dirk Ehrhardt','6271 N Celery Pl','Tucson','AZ','UNITED STATES','85741-3319','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 02:14:53',0,NULL,3,1,1,1,NULL,'tdrahrhe\r\\'),(1880,571681531013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','jimmysu26','wanqing111@gmail.com','can qiang su','9603 hwy 11 north rr2','Washago','ON','CANADA','L0k2b0','(416) 828-0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 02:19:37',0,NULL,3,1,2,1,NULL,'jimmysu26\r黄色的\r÷'),(1881,771901492012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','robertorgp','gasperaltarobert@live.com','Roberto gaspar','2201 Lane St SE<br>Apt 3','wilson','NC','UNITED STATES','27893-6570','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 04:14:07',0,NULL,3,1,1,1,NULL,'robertorgp\r、'),(1882,694818559011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','togo30','antogo@aon.at','Antonio Gossner','Hallersdorf 49','Krottendorf','','AUSTRIA','8564','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 04:25:55',0,NULL,3,1,2,1,NULL,'togo30\racer 4pin1.25 6cm \r、'),(1883,571711235013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','vliscotile123','vlisco@telus.net','nico van der vlis','7469 banford rd.','chilliwack','BC','CANADA','v4z1c6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 05:21:02',0,NULL,3,1,2,1,NULL,'vliscotile123\r、'),(1884,694845887011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ssrankin','steve@serenitysys.com','Steve Rankin','1366 W Sequim Bay Rd','Sequim','WA','UNITED STATES','98382-8411','(360) 683-7229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 06:56:33',0,NULL,3,1,1,1,NULL,'ssrankin\r、'),(1885,771935015012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','pcukoo','naijing.luo@nokia.com','naijing luo','174 Weyland Cir','north andover','MA','UNITED STATES','01845-4935','(978) 930-9090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 07:06:33',0,NULL,3,1,1,1,NULL,'pcukoo\r、'),(1886,771939362012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',22,'eastar4','luca.razvan','razvan.luca@siemens.com','RAZVAN DANUT LUCA','C. Cosminului nr. 16, bl. 404b, sc.A, ap.3','Brasov','Brasov','ROMANIA','500147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:24:06',0,NULL,3,1,2,1,NULL,'luca.razvan\r欧标\r、'),(1887,771940428012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','tiben105','hwyben105@hotmail.com','benoit soulieres','270 des gentianes','ste-sophie','QC','CANADA','J5J2X3','(450) 436-4389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:27:40',0,NULL,3,1,2,1,NULL,'tiben105\r、'),(1888,694858506011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',19.9,'eastar4','ashantib1984','ashanti1984@yahoo.de','Joanna Badera','Laubigstrasse 7','Kämpfelbach-Ersingen','','GERMANY','75236','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 07:55:06',0,NULL,3,1,2,1,NULL,'ashantib1984\r欧标、'),(1889,694858599011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','oliverjany','oliverjany@netcologne.de','Oliver Jany','Bahnhofstrasse 93','Niederkassel - Rheidt','','GERMANY','53859','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:01:10',0,NULL,3,1,2,1,NULL,'oliverjany\r、'),(1890,694866008011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','s1ns','sindoro.lin@hotmail.com','Sindoro Lin','55/569 George St','Sydney','New South Wales','AUSTRALIA','2000','0413810876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:28:45',0,NULL,3,1,3,1,NULL,'s1ns\rUDAP001\r\rRA117729238CN'),(1891,694367966011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','sunrayrabbit','flemij@rpi.edu','John Fleming','Po Box 3424','Eureka','CA','UNITED STATES','95502-3424','(781) 983-6384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 08:52:42',0,NULL,3,1,1,1,NULL,'sunrayrabbit\r\\'),(1892,525938792004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','kruno09','kruno.skaro@vip.hr','Krunoslav Škaro','Šetalište Pape Ivana Pavla II 29','Split','Croatia','CROATIA','21000','+385911620579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:00:35',0,NULL,3,1,3,1,NULL,'kruno09\rOTCR001\rRA117729520CN'),(1893,571460459013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','verytolik','slimp@list.ru','Anatoliy Epifanov','Shelepihinskoe shosse, 15-50','Moscow','RU','RUSSIAN FEDERATION','123290','79265660330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:42:28',0,NULL,3,1,2,1,NULL,'verytolik\r\\'),(1894,571754021013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','namuni2k','namuni@gmail.com','Namhoon Kim','Lotte Apt. 112-2002<br>408, Bisan2-dong, Dongan-gu','Anyang-si','Kyounggi-do','KOREA,REPUBLIC OF','431-762','+82-10-2980-1231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:08:12',0,NULL,3,1,2,1,NULL,'namuni2k\r\\'),(1895,520196472003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',83.99,'cnfaner','devriye69','yasarakko@gmail.com','Yaşar AKKO','Perpa Ticaret Merkezi B Blok Kat:2 No:69<br>Okmeydanı-ŞİŞLİ','İSTANBUL','','TURKEY','34385','00902122215700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:32:32',0,NULL,3,1,3,1,NULL,'devriye69\rWWOT003\rRA117729652CN'),(1896,771985454012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','izmael53iz','izmael53@windowslive.com','RECEP KULAKSIZ','ATMEYDANI MAHALLESİ AVCILAR SOK.KULAKSIZ APT. NO.36 KAT 2','RİZE','RİZE / TURKİYE','TURKEY','530100','0464 2281902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:23:13',0,NULL,3,1,2,1,NULL,'izmael53iz\r欧标\r\\'),(1897,571764122013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','lbromain','lbromain@hotmail.com','Romain LADAN-BOCKAIRY','86 rue François Mitterrand','AMFREVILLE LA MIVOIE','','FRANCE','76920','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:00:40',0,NULL,3,1,2,1,NULL,'lbromain\r\\'),(1898,520203119003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','onchal62','opolat62@yahoo.com','ONUR POLAT','Gumruk Mustesarligi, Muhabere ve Elektronik Dairesi<br>Anafartalar caddesi No:6 Kat:14 Yuksek blok, Ulus','ANKARA','ALTINDAG','TURKEY','06100','903123067931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:02:13',0,NULL,3,1,3,1,NULL,'onchal62\rHSNO008\r欧标\rRA117729578CN'),(1899,772004456012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','pekra76','mail@peter-kraut.de','Peter Kraut','Hauptstraße 7','Buchhofen','','GERMANY','94533','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:27:02',0,NULL,3,1,2,1,NULL,'pekra76\r\\'),(1900,770965480012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',4.69,'eastar4uk','rasyte1988','rasyte88@gmail.com','Liudas Navickas','Vyturiu 12, Garliava<br>Teleiciu km.','Kauno r.','','LITHUANIA','LT53273','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 12:27:38',0,NULL,3,1,2,1,NULL,'rasyte1988\r欧标\\'),(1901,525978067004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','ededsen','edwinovermars@yahoo.com','Edwin Overmars','Lloydstraat 26e','Rotterdam','','NETHERLANDS','3024 EA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:36:16',0,NULL,3,1,3,1,NULL,'ededsen\rWLIN010+ANTY002\rRA117729649CN'),(1902,772051003012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','satanabduljabar','tpbennion@tesco.net','Terry Bennion','21 Grosvenor Street<br>Longton','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST3 2LR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 13:44:12',0,NULL,3,1,2,1,NULL,'satanabduljabar\racer 4pin1.25 8cm\r\\'),(1903,772055448012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','orchard_tractor2','mike@heritageorchard.com','Mike EBAY Mintz','45 Westcott Rd','Harvard','MA','UNITED STATES','01451-1820','(508) 577-2855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 13:56:40',0,NULL,3,1,1,1,NULL,'orchard_tractor2\rMX20T\r\\'),(1904,659815970001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','rys_store','ryan@rollinjunk.com','3D Mobile creations','933 E Crosstown pkwy','kalamazoo','MI','UNITED STATES','49001-2507','(269) 998-6597','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,' ','rys_store \rLK043483053CN  改的地址\r\\'),(1905,525988487004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','antoxa_2010','anton7712@yandex.ru','Vasyl Malyy','RUA DO BOSQUE, 510<br>BARRA FUNDA','SAO PAULO','SP','BRAZIL','01136-000','80938583602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:27:35',0,NULL,3,1,3,1,NULL,'antoxa_2010\rWWSI005\rRA117729581CN'),(1906,526004274004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','mdelachaise','mdyck1@gmail.com','Michael Dyck','10-300 River Ave','Winnipeg','MB','CANADA','r3l0b9','(204) 887-7081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:35:43',0,NULL,3,1,3,1,NULL,'mdelachaise\rHSMO007\rRA117729621CN'),(1907,0,220768669878,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13.5,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 14:37:08',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(1908,0,230608645307,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','cryspal123','crystalpaller@yahoo.com','Crystal Paller','398 Cary Jay Blvd','Richmond Heights','OH','UNITED STATES','44143-1726','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-13 14:38:46',0,NULL,3,1,1,1,NULL,'cryspal123\r\\'),(1909,571814747013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:41:39',0,NULL,3,1,2,1,NULL,'vjendrisvelimir\r欧标\r\\'),(1910,772093671012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','spooky4131','mtizzy@cox.net','vicky tisdale','700 Pioneer Ln','gentry','AR','UNITED STATES','72734-8741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 15:35:06',0,NULL,3,1,1,1,NULL,'spooky4131\r\\'),(1911,772104936012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','glendalahoz','astridglenn@yahoo.com','GLENDA LA HOZ','2557 97th St<br>Apt 1','EAST ELMHURST','NY','UNITED STATES','11369-1603','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 16:02:20',0,NULL,3,1,1,1,NULL,'glendalahoz\r\\'),(1912,571838685013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','choonghp88','hpchoong88@yahoo.com','Peng_Choong Ho','33 Jalan Damai Kasih 7<br>Alam Damai, Cheras','Kuala Lumpur','','MALAYSIA','56000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:05:35',0,NULL,3,1,2,1,NULL,'choonghp88\r\\'),(1913,571848289013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',2,'ADAK001',25.4,'eastar4','suc2151','trans21a@naver.com','SEONG DEOK, HWANG','HANYOUNG NUX CORPORATION<br>1381-3 JUAN-DONG, NAM-GU','INCHEON','','KOREA,REPUBLIC OF','402853','(821) 191-5401 ext.: 00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:38:41',0,NULL,3,1,2,1,NULL,'suc2151\r\\\r\r'),(1914,526038234004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','uskudar-bilisim','ahmet@kantoglu.com','Ahmet KANTOGLU - USKUDAR BILISIM VE INTERNET HIZMETLERI','Icadiye Mahallesi  Cumhuriyet Caddesi No:47/E Buro: 6','ISTANBUL','USKUDAR','TURKEY','34674','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:43:06',0,NULL,3,1,3,1,NULL,'uskudar-bilisim\rBALO007\rRA117729516CN'),(1915,694969118011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'',21.9,'eastar4','mustang-farm','ratler5.0@gmail.com','jon shaub','77 hogate blvd','salem','NJ','UNITED STATES','08079','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 16:57:54',0,NULL,3,0,1,1,NULL,'mustang-farm\r\\'),(1916,526045468004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','bluemurphy4','esthermnewman@gmail.com','Esther Newman','3701 Calle Joaquin','Calabasas','CA','UNITED STATES','91302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:06:21',0,NULL,3,1,1,1,NULL,'bluemurphy4\r\\'),(1917,520290440003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'',14.99,'cnfaner','jah-trading','jahebay@gmail.com','Salstein Steven','6250 NW 35th Ave','Miami','FL','UNITED STATES','33147-7502','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:11:57',0,NULL,3,0,1,1,NULL,'jah-trading\r\\'),(1918,525351446004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','agente30302','faalvarez30302@yahoo.com','francis a. alvarez rosario','hc 9 box 2099','ponce','puerto rico','PUERTO RICO','00731-9700','(787) 433-6247','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 17:40:00',0,NULL,3,1,1,1,NULL,'agente30302\r\\'),(1919,695053428011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','hrabcakm_2009','hrabcakm@gmail.com','Miroslav Hrabcak','Cerneho 10','Brno','Bystrc','CZECH REPUBLIC','63500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 17:48:16',0,NULL,3,1,2,1,NULL,'hrabcakm_2009\r、'),(1920,571882984013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','telz_87','tommygirl_2_87@yahoo.com','Shantel Schroeder','36450 Hwy 71','Windom','MN','UNITED STATES','56101','(507) 831-2039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 18:14:02',0,NULL,3,1,1,1,NULL,'telz_87\r\\'),(1921,772212259012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',16.7,'eastar4','vikasmanda','mandavikas@yahoo.com','Vikas Manda','2024 E 74th pl South Apt 101','Tulsa','OK','UNITED STATES','74136','(918) 902-6249','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 19:22:25',0,NULL,3,1,1,1,NULL,'vikasmanda\r\\'),(1922,695106847011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ksiepel','ksiepel@cleantechnow.com','Keith Siepel','526 Topfield Dr','Cincinnati','OH','UNITED STATES','45255-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 19:26:02',0,NULL,3,1,1,1,NULL,'ksiepel\r\\'),(1923,772223540012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','erezkaplan','erez_kaplan@talktalk.net','erez kaplan','5 Wykeham Road, Merrow','Guildford','Surrey','UNITED KINGDOM','GU12SE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 19:39:08',0,NULL,3,1,3,1,NULL,'erezkaplan\rHSMO017\r英标\rRA117729604CN'),(1924,772236478012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','crealiz-2007','contact@crealiz.com','JONATHAN BOUJO','18 RUE DE LA LIBERTE','BISCHHEIM','Alsace','FRANCE','67800','0626044170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:08:11',0,NULL,3,1,2,1,NULL,'crealiz-2007\r\\'),(1925,772242377012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','plombier48','tourigny.marcel@cgocable.ca','Marcel Tourigny','1095 Rue Cartier','Trois-Rivières','QC','CANADA','G8Z 1L5','(819) 384-8118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:11:13',0,NULL,3,1,2,1,NULL,'plombier48\r\\'),(1926,772242569012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','keitten','keiten@post.cz','Jitka Zinke, vedoucí OKP','Ústřední vojenská nemocnice<br>U Vojenské nemocnice 1200','Prague 6','Czech Republic','CZECH REPUBLIC','169 02','723943234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:12:25',0,NULL,3,1,2,1,NULL,'keitten\r\\'),(1927,772246621012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',17.4,'eastar4','the.q.family','qfamily@hotmail.co.uk','Jamal Qureashi','28 Victoria Road','Mitcham','Surrey','UNITED KINGDOM','CR4 3JA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:17:34',0,NULL,3,1,3,1,NULL,'the.q.family\r再发一个CAB-6060\rCASS002+CASS003\r'),(1928,571933951013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','livinonprayer','favamama@yahoo.com','Sheri Fava','469 Bicentennial Trl','Rock Spring','GA','UNITED STATES','30739-2309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 20:25:48',0,NULL,3,1,1,1,NULL,'livinonprayer\r\\'),(1929,571934215013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','smiggy69mark','msmith-rufc@hotmail.co.uk','Mark Smith','32 Cambridge Crescent<br>East Dene','Rotherham','South Yorkshire','UNITED KINGDOM','S65 2RB','07720525438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 20:29:26',0,NULL,3,1,2,1,NULL,'smiggy69mark\r\\'),(1930,772300169012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN002+BAIN002+TOIN002',49.9,'eastar4','bumpa2k1','prodsecman@verizon.net','Keith Nicholas','PO Box 1565<br>10 Lombard St','Warren','MA','UNITED STATES','01083','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 22:22:50',0,NULL,3,1,1,1,NULL,'bumpa2k1\rBAIN002+BAIN001+TOIN002\r\\'),(1931,571974811013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','gso102087','george.ct.so@gmail.com','George So','359 Stockbridge Ave','Atherton','CA','UNITED STATES','94027-6442','(650) 862-6306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 22:55:15',0,NULL,3,1,1,1,NULL,'gso102087\r\\'),(1932,772312362012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','mranario','m_ranario@hotmail.com','Mark Ranario','1908 N Tucker Dr','Tucson','AZ','UNITED STATES','85716-3031','(832) 443-5585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 23:02:31',0,NULL,3,1,1,1,NULL,'mranario\r\\'),(1933,772325424012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','seamartech','seamartech@comcast.net','Seamartech Marine Electronics','17 Irene st','New Bedford','MA','UNITED STATES','02745-1109','(508) 995-1563','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 23:50:41',0,NULL,3,1,1,1,NULL,'seamartech\r\\'),(1934,772332162012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','moscovita69','69moscovita@hotmail.es','ADOLFO GONZALEZ ALIAGA','Calle Ponzano Nº 16 Local MBE B148','Zaragoza','Zaragoza','SPAIN','50004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 00:14:51',0,NULL,3,1,2,1,NULL,'moscovita69\r\\'),(1935,571991096013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','bigcedharris24','bigcedharris@bellsouth.net','cedric harris','2100 Tuck Dr','Conyers','GA','UNITED STATES','30012','(404) 551-7650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 00:19:50',0,NULL,3,1,1,1,NULL,'bigcedharris24\r\\'),(1936,571991726013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','tremblayphilippe','tremblay518@hotmail.com','Philippe Tremblay','912 Avenue Bouchard App 3','Amos','QC','CANADA','J9T2W2','(819) 727-4122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 00:21:42',0,NULL,3,1,2,1,NULL,'tremblayphilippe\r\\'),(1937,571992586013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',2,'HSPL005',27,'eastar4','sbeivides','beividesb@yahoo.com','Benjamin Beivides','11907 Lesser St','Norwalk','CA','UNITED STATES','90650-4052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 00:25:45',0,NULL,3,1,1,1,NULL,'sbeivides\r\\'),(1938,772347023012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','rana009','rana009@yahoo.com','sabir ali rana','77 Delawana Dr<br>App#  508','Hamilton','ON','CANADA','L8E1G5','(905) 297-8949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 01:09:59',0,NULL,3,1,2,1,NULL,'rana009\r\\'),(1939,572000983013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','m7508','malberts@pol.net','Monica Wood','12612 NE 187th St<br>Apt 2402','Bothell','WA','UNITED STATES','98011-9341','(414) 326-0605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 01:10:36',0,NULL,3,1,1,1,NULL,'m7508\r\\'),(1940,772237432012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','jdr_wiredrat','jdr@wiredrat.net','John Robertson','123 Rock Bridge Rd','Batesville','AR','UNITED STATES','72501-7676','(870) 613-8615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 02:12:09',0,NULL,3,1,1,1,NULL,'jdr_wiredrat\rMX20T\r\\'),(1941,572029788013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',4,'HSJA002',86,'eastar4','barrychickenman','shakey_ghost@yahoo.com','Barry Parker','24457 Mary N Smith, rd','Accomac','VA','UNITED STATES','23301','(757) 710-0737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 03:42:49',0,NULL,3,1,1,1,NULL,'barrychickenman\r\\'),(1942,0,230609261115,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13,'eastar4','suddu','sudershang@hotmail.com','SUDERSHAN GUPTA','119 zanca turn','yorktown','va','UNITED STATES','23693-2449','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 04:21:35',0,NULL,3,1,1,1,NULL,'suddu\r\\'),(1943,772395632012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',37.45,'eastar4','saccin76','habbaji@gmail.com','Tae-Kwang, Youn','BITEK SYSTEM INC. Rm.719 Doosan Venture Digm, 126-1<br>Pyengchon-dong','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-070','82-10-9289-5389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:26:07',0,NULL,3,1,3,1,NULL,'saccin76\rWWSI002\rRA117729241CN'),(1944,695273841011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','pppthe_first','douphol@free.fr','SCHBATH pierre','21 avenue Georges','Colombes','Île-de-France','FRANCE','92700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:40:21',0,NULL,3,1,3,1,NULL,'pppthe_first\rRCLO006\rRA117729167CN'),(1945,572044807013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','paralaz','2sw@list.ru','Vladimir Scherbakov','Ushakova 4-14','Volgograd','','RUSSIAN FEDERATION','400017','+79064068605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:31:37',0,NULL,3,1,3,1,NULL,'paralaz\rOTRA002\rRA117729224CN'),(1946,520458953003,130489931130,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',75.6,'cnfaner','ryanbastian','ryan.bastian@hotmail.com','Ryan Bastian','Jl. Kopo Jaya No. 17','Bandung','Jawa Barat','INDONESIA','40224','62816611285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:33:50',0,NULL,3,1,3,1,NULL,'ryanbastian\rBAZA001\rRA117729255CN'),(1947,772412634012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','roulis222','yiannakis222@hotmail.com','John Dialektakis','Unit 815 / 10 Brodie Spark Drive','Wolli Creek','New South Wales','AUSTRALIA','2205','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 05:59:58',0,NULL,3,1,3,1,NULL,'roulis222\rHSSE006\r澳标\rRA117729215CN\r'),(1948,572049628013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',50.64,'eastar4','via4in1via4in1','killa_bee@mail.ru','Sergey Slobodenyuk','Kronshtadtskiy bulvar<br>House 23 Building 1 Flat 47','Moscow','','RUSSIAN FEDERATION','125493','+79647637482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 06:10:26',0,NULL,3,1,3,1,NULL,'via4in1via4in1\rCACN004\rRA117729547CN'),(1949,572047653013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','j_siebenga','jason@bigsteelbox.com','Jason Siebenga','1670 Dilworth Dr','Kelowna','BC','CANADA','V1Y 7V3','(250) 212-8000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:53:55',0,NULL,3,1,3,1,NULL,'j_siebenga\rMOSA002\rRA117729555CN'),(1950,772416949012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','deeznutz2377','deeznutz@internode.on.net','Brad Kyaw','28 Heatherdale Street','Amaroo','Australian Capital Territory','AUSTRALIA','2914','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 06:25:54',0,NULL,3,1,3,1,NULL,'deeznutz2377\rOTGR001+OTGR002\rRA117729309CN'),(1951,772430671012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','nozdk01','nozdk1999@yahoo.co.jp','Daisuke Nozawa','5-30-16 S-202 Megurohoncho<br>Meguro-ku','Tokyo','Tokyo','JAPAN','152-0002','+81 3 5876 5090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:28:42',0,NULL,3,1,2,1,NULL,'nozdk01\r\\'),(1952,772444052012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','bebert90','hubert_maisonneuve@hotmail.com','maisonneuve hubert','19 rue des francs bourgeois','Strasbourg','','FRANCE','67000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 08:28:40',0,NULL,3,1,2,1,NULL,'bebert90\r\\'),(1953,572069827013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nesthaegchen','s.jeanrichard@googlemail.com','Samuel Jeanrichard','Schweriner Ring 18<br>3. Etage','Berlin, Wartenberg','','GERMANY','13059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 08:33:40',0,NULL,3,1,2,1,NULL,'nesthaegchen\r\\'),(1954,772208722012,220504387390,'2.1 Acer Timeline 4810 5810 Bluetooth Module EDR+ cable',1,'BTAC2101',12.8,'eastar4','crazy_rock','crazy_rock274@hotmail.com','mehmet KAYACIK','yildirim beyazit mh. ozbilen sk. kartas apt. b1 blok no:1','KUTAHYA','MERKEZ','TURKEY','43020','5556635744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 09:41:55',0,NULL,3,0,2,1,NULL,'crazy_rock\racer 4pin1.25 3cm \\'),(1955,572096306013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:13:12',0,NULL,3,1,3,1,NULL,'flashy69\rMOSA002\rRA117729272CN'),(1956,572096327013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',33.76,'eastar4','balage001','speed.limit@freemail.hu','Tözser Balazs','Etele ter 3. fszt. 2.','Budapest','','HUNGARY','1115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:17:17',0,NULL,3,1,3,1,NULL,'balage001\rCACN004\rRA117729391CN'),(1957,772488747012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','truck2807','mcautos@hotmail.com','michael clarke','31 Sheelin Park','Derry','Londonderry','UNITED KINGDOM','bt480pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 11:24:05',0,NULL,3,1,3,1,NULL,'truck2807\rHSPL011\r英标\rRA117729330CN'),(1958,526263892004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','vovaharitonov','flurry.ebay@gmail.com','Volodymyr Kharytonov','Kravchuka Street 19, Appartment 103','Lutsk','Volyn','UKRAINE','43026','+380936114444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:25:36',0,NULL,3,1,3,1,NULL,'vovaharitonov\r送螺丝 \rWWSI005\rRA117728453CN\r'),(1959,695364471011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','stoni1999','m-kaufmann@web.de','Michael Kaufmann','Schulberg 3','Unterwürschnitz','','GERMANY','08626','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:53:30',0,NULL,3,1,2,1,NULL,'stoni1999\\'),(1960,526270816004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','karind2008','danek@iprimus.com.au','Karin Danek','Unit 5, 53 Biscayne Way','Jandakot','Western Australia','AUSTRALIA','6164','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 11:58:30',0,NULL,3,1,3,1,NULL,'karind2008\rBALO007\rRA117729343CN'),(1961,695368265011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',3,'TRMX002',25.65,'eastar4','ivsindustrialsurplus','dolesuk@ivsincorporated.com','John Morris','35572 Veronica St','LIVONIA','MI','UNITED STATES','48150-1204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 12:02:43',0,NULL,3,0,1,1,NULL,'ivsindustrialsurplus\r\\'),(1962,526271998004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','shaharbv','shaharbv@walla.co.il','Shahar Ben-Varon','Savion 21','Petah-Tikva','','ISRAEL','49542','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 12:08:47',0,NULL,3,1,3,1,NULL,'shaharbv\rHSPL001\rRA117729357CN'),(1963,526279639004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','bobbertobobberto','bobberto@libero.it','roberto carracciuolo','strada torino 90 fornaci','beinasco','TO','ITALY','10092','3358495202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 12:42:50',0,NULL,3,1,3,1,NULL,'bobbertobobberto\rANYA001\rRA117728100CN'),(1964,572122404013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.8,'eastar4','goetzahr','hermannsoares@gmail.com','Aldir','Rua do Álamo, Quadra 30, Lote 47<br>Bairro Goiânia 2','Goiânia','Goiás','BRAZIL','74663040','55(62)3205-6465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:22:47',0,NULL,3,1,2,1,NULL,'goetzahr\racer 8pin1.00 10cm\\'),(1965,772533526012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','trekeeboy2','trekeeboy@comcast.net','Spencer Burke','8300 W 31st Street<br>Apt 304','Minneapolis','MN','UNITED STATES','55426','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 13:44:58',0,NULL,3,1,1,1,NULL,'trekeeboy2\r\\'),(1966,572127313013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','invaderoz','serendipity_dragon@hotmail.com','Ashli Neese','Unit 1<br>90 Grey Street','St Kilda','Victoria','AUSTRALIA','3182','610405060743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:48:16',0,NULL,3,1,2,1,NULL,'invaderoz\\'),(1967,695400971011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','neoplaz','alan@hyde.net.au','Alan Hyde','Unit 21, 1029 Manly Road','Tingalpa','Queensland','AUSTRALIA','4173','0418879461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:59:55',0,NULL,3,1,2,1,NULL,'neoplaz\rRELO002\\'),(1968,772545369012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','bekawillms','bekawillms@yahoo.com','Rebekah Williams','3 Winland Ct','Gillette','WY','UNITED STATES','82718-6941','(307) 299-7366','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:18:57',0,NULL,3,1,1,1,NULL,'bekawillms\r\\'),(1969,0,320685158781,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','beaztyb','beaztybee@aol.com','JACOB DESJARDINS','4143 BAIN PKWY','BLASDELL','NY','UNITED STATES','14219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:21:43',0,NULL,8,1,17,1,NULL,'beaztyb'),(1970,526303481004,140429366892,'2.1 HP Compaq Presario V2000 V2100 bluetooth module ',1,'BTHP2109',13.99,'cnfaner','nakiz2010','nakiz@globomail.com','leo zikan ferri','rua joao pessoa n74 centro','itatiaia','rio de janeiro','BRAZIL','27580-000','02499992832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:39:12',0,NULL,3,1,3,1,NULL,'nakiz2010\rHP 8pin 1.25 3cm \rRA117729365CN'),(1971,0,220769182825,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','philaz','phil_ellsworth@yahoo.com','Phil Ellsworth','11745 Mobile St','Commerce City','CO','UNITED STATES','80022-6218','(602) 361-3374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:40:58',0,NULL,3,1,1,1,NULL,'philaz\r\\'),(1972,695418757011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','45bluesky135','acewolf69@gmail.com','Yongdon Shin','Dorim1dong 137-17 3rd floor<br>Youngdeungpogu','Seoul','','KOREA,REPUBLIC OF','150081','01063807446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:50:44',0,NULL,3,1,2,1,NULL,'45bluesky135\rHP 8pin 1.0 3cm\\'),(1973,526306666004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 14:52:37',0,NULL,3,1,3,1,NULL,'turquoise-web\rHSNO022 银色的\r欧标\rRA117729269CN'),(1974,695424045011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','azbrizer2010','alexander.zbrizer@numonyx.com','Zbrizer Alexander','Eli Cohen 10/9','Holon','','ISRAEL','58370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:02:14',0,NULL,3,0,2,1,NULL,'azbrizer2010\racer 8pin1.00 15cm\\'),(1975,0,230609028105,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',13.49,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 15:17:23',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(1976,695434127011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','ghartz2009','georgehartzoulakis@hotmail.com','george hartzoulakis','ioanninon 23<br>ilion','athens','','GREECE','13123','00302102636880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:31:19',0,NULL,3,1,3,1,NULL,'ghartz2009\rRCLO006\rRA117729405CN'),(1977,772581731012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sniper_iv','lpanzini@rogers.com','Lui Panzini','7 Giltspur Drive','North York','ON','CANADA','M3L 1M4','(416) 744-8707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 15:55:16',0,NULL,3,1,2,1,NULL,'sniper_iv\\'),(1978,772593735012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','blackcountach','functionalbiceps@aol.com','Tory Simmons','44 N Rural St','Indianapolis','IN','UNITED STATES','46201-3208','(317) 717-9864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:34:27',0,NULL,3,1,1,1,NULL,'blackcountach\r\\'),(1979,572172336013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nous.dim','petrovdim@gmail.com','Leo Steinberg (c/o D.Petrov)','119 Mackenzie St','Brooklyn','NY','UNITED STATES','11235-2303','(718) 496-0075','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:36:53',0,NULL,3,1,1,1,NULL,'nous.dim\r\\'),(1980,772616337012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','cad1225','ted@nwbuzz.net','Ted Isaac','17201 N Meadowview Ct','Nine Mile Falls','WA','UNITED STATES','99026-9333','(360) 910-9119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 17:15:37',0,NULL,3,1,1,1,NULL,'cad1225\r\\'),(1981,526344975004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','digimoney','karlheinzmeese@web.de','Karl-Heinz Meese','Weikenweg 61','Paderborn','','GERMANY','33106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 17:22:22',0,NULL,3,1,3,1,NULL,'digimoney\r欧标\rHSPL010\rRA117728039CN'),(1982,572196172013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','jmmc9000','joaniemc@me.com','Joan McCutcheon','4910 Joni Way','Richmond','TX','UNITED STATES','77407-7921','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 17:52:15',0,NULL,3,1,1,1,NULL,'jmmc9000\r\\'),(1983,660317741001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','516gene','gene@kenclaire.com','Kenclaire Electric','714 Old Country Rd','Westbury','NY','UNITED STATES','11590-4504','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'516gene  \r改的地址\rLK043485068CN\r\\\r'),(1984,772654078012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','khehra4400','doordie@live.ca','GURINDERPAL KHEHRA','52 BLAZINGSTAR DR','BRAMPTON','ON','CANADA','L6R3E7','(905) 782-4400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 18:27:06',0,NULL,3,1,2,1,NULL,'khehra4400\\'),(1985,772655216012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',99,'eastar4','bumark','compras@bct.com.ar','BCT SAR','6993 NW 82nd Ave<br>Ste 28','Miami','FL','UNITED STATES','33166-2782','(305) 648-8404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 18:30:31',0,NULL,3,1,1,1,NULL,'bumark\r新地址\r6993nw 82Ave. Suite 28 Miami Florida, zip 33166, USA. Name: BCT BUMARK - Sar Express (JUAN), 305 468 8404 \r\\'),(1986,695512780011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','soldatii','gadyoo@yahoo.com','grigorescu alexandru daniel','str.soldat lazar florea nr1 bl 8c ap43','bucharest','bucharest','ROMANIA','7000','0040767118822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 18:35:02',0,NULL,3,1,2,1,NULL,'soldatii\r欧标\\'),(1987,772662031012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','orion1-2008','apintech@aol.com','stan byrd','4525 N Road 68<br>Ste F','Pasco','WA','UNITED STATES','99301-9595','(509) 628-7613','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 18:41:15',0,NULL,3,1,1,1,NULL,'orion1-2008\r\\'),(1988,572223601013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','bolo99999','bolo9999@wanadoo.fr','Christian GREZES','43 rue Henri Tariel','Issy les Moulineaux','Île-de-France','FRANCE','92130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:06:01',0,NULL,3,1,2,1,NULL,'bolo99999\r新优联红边的\\'),(1989,519112304003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','puritanstuff','nigel_beaumont@yahoo.com','LaDonna Beaumont','2040 E Mountain Vista Dr','Coeur D Alene','ID','UNITED STATES','83815','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 19:13:32',0,NULL,3,1,1,1,NULL,'puritanstuff\r\\'),(1990,695544240011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',2,'HSNO019',89.98,'eastar4','metropol0_1','mehti_yazici@yahoo.de','Mehti yazici','Karl-marx-str.175 a','Berlin','','GERMANY','12043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:35:30',0,NULL,3,1,3,1,NULL,'metropol0_1\r欧标   HSNO019\rRA117728042CN'),(1991,695547247011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','sportsfz','bestpeople1@earthlink.net','vito  desantis','1187 richmond ave','staten island','NY','UNITED STATES','10314-7428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:47:01',0,NULL,3,1,1,1,NULL,'sportsfz\r\\'),(1992,660367342001,110672308283,'New 3M Particulate Respirator with valve 9332 N99 FFP3',1,'OT3M001',13.99,'buysia','eshipsides','liz@thompsonpatentlaw.com','Elizabeth Shipsides','4205 Lancaster Ln N<br>Ste 104','Plymouth','MN','UNITED STATES','55441-1702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:50:39',0,NULL,3,1,1,1,NULL,'eshipsides\r\\LK039789315CN'),(1993,695552418011,320441946742,'2.1 HP NX7300 NX7400 Bluetooth Module EDR + cable',1,'BTHP2101',12.8,'eastar4','liudmil13','lcolov@abv.bg','Liudmil Tsolov','JK 3, bl 13, vh-G, ap-65','Kozloduj','Vratsa','BULGARIA','3320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 19:50:52',0,NULL,3,1,2,1,NULL,'liudmil13\rHP 8pin 1.0 3cm \\'),(1994,772703127012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','gwar2230','gwward61@yahoo.com','Glenn Ward','4229 Parkside Dr','Orlando','FL','UNITED STATES','32812','(407) 857-7985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 19:58:55',0,NULL,3,1,1,1,NULL,'gwar2230\r\\'),(1995,695555694011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','weissernir','wiesser_nir@yahoo.com','Nir Weisser','Tarad 1/b','Ramat Gan','','ISRAEL','52503','+972549363040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:01:58',0,NULL,3,1,3,1,NULL,'weissernir\rHSPL009\rRA117729326CN'),(1996,695560262011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','sorgaebi','ecoplace@hotmail.com','Changhee Lee','810A Reid Rd','Saskatoon','SK','CANADA','S7N 3C2','(306) 978-2942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:05:59',0,NULL,3,1,3,1,NULL,'sorgaebi\rUDAP001\rRA117728011CN'),(1997,660380043001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','tpkusa','tpkusa@aol.com','TOSHIO AKIMOTO','340 E 2nd St<br>Ste 307','LOS ANGELES','CA','UNITED STATES','90012-4249','(213) 626-0603','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 20:17:37',0,NULL,3,1,1,1,NULL,'tpkusa\r\\LK039787929CN '),(1998,695574486011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','inspiration1977','carlos.roka@gmail.com','Carlos de los reyes  Roka Bopabo','c/ anzuelo nº11 local 9-b','tias','Canarias','SPAIN','35510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:35:27',0,NULL,3,1,2,1,NULL,'inspiration1977\r欧标\\'),(1999,572253438013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','bibil0_0','bibib1@free.fr','franck barthelemy','49 avenue joliot curie<br>appt 45, 1er etage','nanterre','Ile-de-France','FRANCE','92000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:37:17',0,NULL,3,1,3,1,NULL,'bibil0_0\rMOSA001\rRA117729286CN'),(2000,695581668011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dugalex','ebay@dugalex.com.au','Aleksandar Dugalic','797A The Horsley Drive','Smithfield','New South Wales','AUSTRALIA','2164','0423765047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:52:13',0,NULL,3,1,2,1,NULL,'dugalex\\'),(2001,695593404011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','rafaeljfriasjr','rafaeldejesusfriasjr@yahoo.com','Rafael D. Frias Jr','44107 Paget Ter','Ashburn','VA','UNITED STATES','20147-3847','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 21:21:41',0,NULL,3,1,1,1,NULL,'rafaeljfriasjr\r\\'),(2002,526428624004,140516104473,'Logitech Charging Cradle L-LG7 for Harmony 880 890 pro',1,'CRLO002',9.99,'cnfaner','radar224','mconos@gmail.com','Marinus Onos','224 Sunterra Ridge Place','Cochrane','AB','CANADA','T4C 1W9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 21:44:51',0,NULL,3,1,3,1,NULL,'radar224\rCRLO002\rRA117729312CN'),(2003,0,230609028229,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','dapoch','dapoluch@hotmail.com','Anthony Poluch','25 Timber Ridge rd','morgantown','PA','UNITED STATES','19543','(484) 288-8310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 22:00:02',0,NULL,3,1,1,1,NULL,'dapoch\r\\'),(2004,772771102012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','digitalsaraiva','saraivadigital@terra.com.br','Evandro Ricardo Saraiva','Rua, Augusto Duó 2138<br>Vila América','Votuporanga','São Paulo','BRAZIL','15502-107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 22:29:25',0,NULL,3,1,2,1,NULL,'digitalsaraiva\\'),(2005,772773412012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','lrdsouza','lance-d@windowslive.com','Lance D Souza','2010 Peach Orchard Dr<br>Apt 34','Falls Church','VA','UNITED STATES','22043-2038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 22:37:37',0,NULL,3,1,1,1,NULL,'lrdsouza\r\\'),(2006,772776124012,220449147548,'Samsung R18 R20 R25 Bluetooth Module 2.0 EDR+cable',1,'BTSA2003',12.5,'eastar4','the_fifer','ww51ky49rh@talktalk.net','Willam Wilson','51, Greenbank drive,','Cowdenbeath','Fife','UNITED KINGDOM','KY4-9RH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 22:46:46',0,NULL,3,1,2,1,NULL,'the_fifer\\'),(2007,772780002012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',27.99,'eastar4uk','ratnesh4u','anchor2ratnesh@yahoo.co.in','ratnesh kumar tripathi','Flat -6/11,<br>240,core A, Wallace street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G5 8AU','07411252528','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 23:00:21',0,NULL,3,1,3,1,NULL,'ratnesh4u\r英标  HSNO019\rRA117728056CN\r'),(2008,695628346011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jb2direcway','smjack@comcast.net','John Bailey','5965 Oak Valley Ct','Santa Maria','CA','UNITED STATES','93455-6006','(805) 934-4422','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 23:17:08',0,NULL,3,1,1,1,NULL,'jb2direcway\r\\'),(2009,772791200012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','drhadlock','drhadlock@magiclink.com','David Hadlock','496 Shoup Ave W<br>Ste C','Twin Falls','ID','UNITED STATES','83301-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 23:39:46',0,NULL,3,1,1,1,NULL,'drhadlock\r\\'),(2010,572301912013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 23:43:44',0,NULL,3,1,2,1,NULL,'noirmarginal\\'),(2011,520705693003,130458644539,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET track#',1,'HSNO021',14.9,'cnfaner','rrbdxb','hibz21@hotmail.com','Raheel Rana','21 - 22 Boutique Villas<br>Dubai Media City','Dubai','Dubai - UAE','UNITED ARAB EMIRATES','500585','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 00:22:42',0,NULL,3,1,3,1,NULL,'rrbdxb\rHSNO021\rRA117728025CN'),(2012,772806239012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','ranemoney1','buckjones1011@aol.com','BRIAN PEARSON','868 n 50th st','philadelphia','PA','UNITED STATES','19139','(267) 312-3041','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 00:41:19',0,NULL,3,1,1,1,NULL,'ranemoney1\r\\'),(2013,572317150013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','mimosamom','cassie.koz@gmail.com','Candy Koslowsky','21 Pontiac Dr','Medford','NJ','UNITED STATES','08055-8146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 01:01:00',0,NULL,3,1,1,1,NULL,'mimosamom\r\\'),(2014,772813918012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','im_top','project.top@gmail.com','Mr. Tridti Taechavorawongsa','67/45 Soi 35 Latphrao Rd.<br>Jankasem','Jatujak','Bangkok','THAILAND','10900','(668)1567-6470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:03:41',0,NULL,3,1,2,1,NULL,'im_top\\'),(2015,695665576011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','soulful_scentsations','kylegibbons@hotmail.com','Kyle Gibbons','24 GORDON DR.','WOODBRIDGE','ON','CANADA','L4L 1R5','(647) 393-8380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:45:37',0,NULL,3,1,2,1,NULL,'soulful_scentsations\\'),(2016,695681556011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','nslax5','nslax5@yahoo.com','Khristopher Tolbert','7101 Runnymede Trl','Fredericksburg','VA','UNITED STATES','22407-7486','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:50:07',0,NULL,3,1,1,1,NULL,'nslax5\r\\'),(2017,772849388012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','resendewilson','wresende@rocketmail.com','wilson resende','Rua Silveira Martins 164<br>apto. 103','Rio de Janeiro','RJ','BRAZIL','22221000','+55-21-9281-0592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 03:11:40',0,NULL,3,1,3,1,NULL,'resendewilson\r\rOTCR001\r\rRA117728935CN'),(2018,520740281003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','medikosakosala','dkctennakoon@gmail.com','Kosala Tennkoon','NO95, Katupilamukalana,Kirimetiyana/west,Lunuwl','Lunuwila','','SRI LANKA','PX  61150','+940718068794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 03:40:58',0,NULL,3,1,3,1,NULL,'medikosakosala\rHSNO008\rRA117729388CN'),(2019,772856297012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',10.99,'eastar4','beaztyb','beaztybee@aol.com','JACOB DESJARDINS','4143 BAIN PKWY','BLASDELL','NY','UNITED STATES','14219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 03:42:08',0,NULL,3,1,1,1,NULL,'beaztyb\r一共买了两个\r\\'),(2020,772828408012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','t3chnoeagle','akreagle@gmail.com','Austin Russell','1979 Port Trinity Cir','Newport Beach','CA','UNITED STATES','92660-7125','(949) 759-0742','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 04:59:06',0,NULL,3,1,1,1,NULL,'t3chnoeagle\\'),(2021,695713324011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','hernitam','henryt@gazillo.com','Henry Tam','19/11 Rose Street','Chippendale','New South Wales','AUSTRALIA','2008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:41:30',0,NULL,3,1,2,1,NULL,'hernitam\\'),(2022,0,230609028207,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','mayfly39','mayfly39@yahoo.co.kr','Woonghan Kim','264-437 SAMICK TOWN22 EMUN2DONG DONGDAEMUN','SEOUL','','KOREA,REPUBLIC OF','130-082','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-15 05:45:54',0,NULL,3,1,2,1,NULL,'mayfly39\\'),(2023,572364780013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','seichkin','t256ao@mail.ru','Eliseev Sergey','Bataiskiy proezd 13-240','Moscow','Moscow','RUSSIAN FEDERATION','109651','(499)3560586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:47:54',0,NULL,3,1,3,1,NULL,'seichkin\rOTRA002\rRA117728970CN\r'),(2024,695718708011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',113.97,'eastar4','creaty4','danny444@hanmail.net','Yeonsu Lee','805 Leavenworth St<br>Apt 910','San Francisco','CA','UNITED STATES','94109-6128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 06:12:02',0,NULL,3,1,1,1,NULL,'creaty4\\'),(2025,520759601003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','fausto1230_4','giacrafax@libero.it','Fausto Rafanelli','Via Elsa Morante, 27','Agliana','PT','ITALY','51031','0574-751251','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-15 06:22:56',0,NULL,3,1,3,1,NULL,'fausto1230_4\rOTJE001  申报10美金\rRA117728997CN\r'),(2026,695745345011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',4,'ANCN001',19.6,'eastar4','magnus.magus','magus@magus.org.ua','Oleksandr Chykysh','Grabyanki 5/31','Lviv','Lviv','UKRAINE','79053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 08:52:48',0,NULL,3,1,2,1,NULL,'magnus.magus\\\r'),(2027,772926060012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',22.5,'eastar4uk','magnusafzelius','magnus.afzelius@gmail.com','Magnus Afzelius','Utflyktsvägen 27','Bromma','','SWEDEN','16841','08-6183022','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 09:35:52',0,NULL,3,1,3,1,NULL,'magnusafzelius\rWWSI005+ANCN001\rRA022493072CN'),(2028,520786520003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','d94pam','peraxel@gmail.com','Per-Axel Mansson','Rolsberga 127','Löberöd','','SWEDEN','24033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:45:51',0,NULL,3,1,3,1,NULL,'d94pam\rMOSA002\rRA117728820CN\r\\'),(2029,572307199013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','fabricefuhrer','fabricefuhrer@hotmail.com','Fabrice Alain Fuhrer','Rua Rio Grande n°50 apto 71<br>Vila Mariana','São Paulo','SP','BRAZIL','04018-000','(011) 8482-2299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:02:56',0,NULL,3,1,2,1,NULL,'fabricefuhrer\r\\'),(2030,572409042013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',74.8,'eastar4','pudovkinsex','mpud@mail.ru','Maxim Pudovkin','Sibirskay 11A, 15<br>Sibirskay 11a, 15','Surgut','Tuymen region','RUSSIAN FEDERATION','628403','+79222536707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:50:24',0,NULL,3,1,3,1,NULL,'pudovkinsex\rMOSA002\rRA117728776CN\r\\'),(2031,695769939011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',75.98,'eastar4','shaaka777','kennethuga@gmail.com','Kenneth Shaaka','Plot 2 Nasser Lane<br>P.O. Box 11743','Kampala','Kampala','UGANDA','11743','+256793111777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:53:10',0,NULL,3,1,3,1,NULL,'shaaka777\rUDAP001\rRA022493537CN'),(2032,695780371011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','jimakoc88','dtrakas88@hotmail.com','Dimitrios Trakas','Skoufa 71','Volos','','GREECE','38334','6945488658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:17:25',0,NULL,3,1,2,1,NULL,'jimakoc88\rHP 8pin 1.25 25cm '),(2033,772960780012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','andyvolp','andyvolp@hotmail.com','Andy Volp','P O Box 19292<br>Courtenay Place, Te Aro','Wellington','Wellington','NEW ZEALAND','6149','0212547912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:40:26',0,NULL,8,1,17,0,NULL,'andyvolp'),(2034,695788383011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','andyvolp','andyvolp@hotmail.com','Andy Volp','P O Box 19292<br>Courtenay Place, Te Aro','Wellington','Wellington','NEW ZEALAND','6149','0212547912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 11:46:39',0,NULL,3,0,3,1,NULL,'andyvolp\r再发一个New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer\rWLIN012+ANTY001*3\r\rRA022493660CN\r\\'),(2035,695792946011,320570842137,'NIB new PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL003',17.5,'eastar4','pb8champ','pb8champ@twcny.rr.com','Hider El-Hage II','PO Box 622','Fulton','NY','UNITED STATES','13069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 12:02:32',0,NULL,3,1,1,1,NULL,'pb8champ\r、'),(2036,526569310004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','natavor','natavor@mail.ru','Nataly Voronova','Molodogvardeiskaya str. 8-29','Moscow','','RUSSIAN FEDERATION','121467','(925)822-7850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 12:49:16',0,NULL,3,1,3,1,NULL,'natavor\rWLAT008\rRA117728762CN\r\r\\'),(2037,572454720013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','sirsalomon','wolfgang.westermann@yahoo.ca','Wolfgang Westermann','Markt 3','Recke','','GERMANY','49509','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:21:22',0,NULL,3,1,2,1,NULL,'sirsalomon\r\\'),(2038,692924329011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','koytroy','ergatikeskoytroy@hotmail.com','koutrouvelis vasilis','agiou Ioannou 4A','PAFOS','CYPRUS','CYPRUS','8021','0035796661780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:28:13',0,NULL,8,0,17,0,NULL,'koytroy'),(2039,695838964011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','koytroy','ergatikeskoytroy@hotmail.com','koutrouvelis vasilis','agiou Ioannou 4A','PAFOS','CYPRUS','CYPRUS','8021','0035796661780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:31:11',0,NULL,3,1,3,1,NULL,'koytroy\rHSNO004\r一共买了两个\rRA022493109CN'),(2040,695849013011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','weeelman2010','nyborg_93@hotmail.com','Jonathan Nyborg','Vedvik','Raudeberg','Sogn og Fjordane','NORWAY','6710','97097937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:00:38',0,NULL,3,1,2,1,NULL,'weeelman2010\r\\'),(2041,569695381013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','mikhail_medvedev','ebay.com@tmp.medvedev.com.ru','Mikhail Medvedev','KYIV-80 abonentska skrynka 73<br>KYIV-80 a/c 73','KIEV','KYIV','UKRAINE','04080','+380636066062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:00:48',0,NULL,3,1,2,1,NULL,'mikhail_medvedev\r\\'),(2042,520856796003,130490976171,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',15.99,'cnfaner','mootoo-eb','piyachaic@gmail.com','Piyachai Chu-Ame','Bangkok Mass Transit System PCL.<br>BTS Bldg. 1000. Phaholyothin Rd.','Chatuchak, Bangkok','Thailand','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:33:36',0,NULL,3,1,3,1,NULL,'mootoo-eb\rWLAT001\rRA117728855CN\r\\'),(2043,772990002012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','mr.locksmith2007','mr.locksmith@yahoo.com','michael nelson','PO Box 264<br>3 Bullis Way','nassau','NY','UNITED STATES','12123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 15:35:50',0,NULL,3,1,1,1,NULL,'mr.locksmith2007\r 一共买了三个\r\\'),(2044,695870814011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mred_cali','dedmister@hotmail.com','William Edmister','107 Sycamore Ave','Mill Valley','CA','UNITED STATES','94941-2807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 16:04:48',0,NULL,5,0,18,0,NULL,'mred_cali\rpaypal 已经退款'),(2045,772858238012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sun-light108','lequanghai@gmx.de','Giamy Le (Tou Chia Mei)','167 / F7 Dayou Rd','Taoyuan','','TAIWAN','330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 16:31:41',0,NULL,3,1,2,1,NULL,'sun-light108\r\\'),(2046,695889044011,320679617626,'New Genuine Sony Ericsson HBH-608 Bluetooth headset',1,'HSSE007',19.9,'eastar4uk','andrewg105','andyg105@hotmail.co.uk','Andrew George','105 Trent Road<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 16:50:26',0,NULL,3,1,3,1,NULL,'andrewg105\rHSSE007\r英标  \rRA117739093CN\r\\'),(2047,695893860011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ravusaedes','aegely@telusplanet.net','Aaron Egely','2008E 920 9th Ave SW','Calgary','AB','CANADA','T2P 2T9','(403) 284-5503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:02:36',0,NULL,3,1,2,1,NULL,'ravusaedes\\'),(2048,695521902011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','mtnmon','melt99@comcast.net','Mel Cooper','14130 Montauk Ln','Fort Myers','FL','UNITED STATES','33919','(239) 466-9463','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:03:54',0,NULL,3,1,1,1,NULL,'mtnmon\r\\'),(2049,695898448011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zlayde','rich@basement.org','Richard Ziade','747 3rd Ave<br>Fl 30','new york','NY','UNITED STATES','10017-2830','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 17:14:15',0,NULL,3,1,1,1,NULL,'zlayde\r\\'),(2050,572514429013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','stefpineault','stef.pineault@gmail.com','stef pineault','541 Legrand','chicoutimi','QC','CANADA','g7j3l9','(418) 817-8244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:53:39',0,NULL,3,1,2,1,NULL,'stefpineault\r\\'),(2051,773104525012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','bolocz','bola_orisajinmi@yahoo.co.uk','akinbola orisajinmi','6 hawkins drive','grays','Essex','UNITED KINGDOM','rm16 6gg','01375481007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:53:46',0,NULL,3,1,2,1,NULL,'bolocz\r\\'),(2052,773104613012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','ann.geo.bg','ann.geo@abv.bg','Aneliya Gergieva','Kitka 7b','Razgrad','Razgrad','BULGARIA','7200','00359888917196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:56:30',0,NULL,3,0,2,1,NULL,'ann.geo.bg\r欧标\r\\'),(2053,526668512004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.9,'cnfaner','ivstrom','ivastrom@broadpark.no','Ivar Stroem','Tokerudberget 35','Oslo','','NORWAY','0986','+4790677752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:13:59',0,NULL,3,1,3,1,NULL,'ivstrom\rMOSA001\rRA022493090CN\r'),(2054,695958806011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','jofryday','davidfry7@hotmail.co.uk','David Fry','93 Hillside Avenue<br>Midsomer Norton','Radstock','Somerset','UNITED KINGDOM','BA3 2LU','01761412532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:25:25',0,NULL,3,1,2,1,NULL,'jofryday\r\\'),(2055,695961882011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','jmiller62','jmiller55@carolina.rr.com','Jeff Miller','804 Broad St.','Shelby','NC','UNITED STATES','28152','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 19:32:02',0,NULL,3,1,1,1,NULL,'jmiller62\racer 8pin1.00 8cm\r\\'),(2056,572550305013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','mark.barzak1989','mark.barzak@gmail.com','mark barzak','Vaitzman 22','Yahud','','ISRAEL','56238','+972544931355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:38:41',0,NULL,3,1,2,1,NULL,'mark.barzak1989\r\\'),(2057,773165119012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','felixmxr','felixpaulmeixner@gmail.com','Felix Meixner','Brockmanngasse 114<br>1. stock tür 4','Graz','','AUSTRIA','8010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:50:44',0,NULL,3,1,2,1,NULL,'felixmxr\r\\'),(2058,526698256004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',129,'cnfaner','angelucien','distar@wanadoo.fr','Xavier THOMAS','Route de Sofaia','SAINTE-ROSE','','GUADELOUPE','97115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 20:54:55',0,NULL,3,1,3,1,NULL,'angelucien\rRCMA001\rRA022493642CN'),(2059,695999355011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','northbaytow','mikegeiskopf@hotmail.com','milton bell','799 orange dr<br>suie 301','vacaville','CA','UNITED STATES','95687-3103','(707) 301-2378','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:01:52',0,NULL,3,1,1,1,NULL,'northbaytow  换成半高5300卡+antenna\r\\'),(2060,520953170003,130458358078,'New  Motorola H500 Bluetooth Wireless Headset track#',1,'HSMO006',11.99,'cnfaner','scouttrooper2010','ctprva2007@gmail.com','ben fernandez','6 1st st','east windsor','CT','UNITED STATES','06088-9728','(860) 623-0789','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 21:09:47',0,NULL,3,1,1,1,NULL,'scouttrooper2010\r\\'),(2061,526706139004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','creaktion','ebay@creamedial.de','Norbert Bluhm','C.-Hainmüller-Str. 6','Waren (Müritz)','','GERMANY','17192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:26:26',0,NULL,3,1,3,1,NULL,'creaktion\rWWSI005\rRA022493585CN'),(2062,696013939011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','nickd_101','nickg.drew@googlemail.com','Nick Drew','48 Sandhills Crescent','Solihull','West Midlands','UNITED KINGDOM','B91 3UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:39:31',0,NULL,3,1,2,1,NULL,'nickd_101\r\\'),(2063,572590838013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','stereoshopthe','stereo@minot.com','Terry R Kongelf','304 Burdick Expy W','Minot','ND','UNITED STATES','58701-4323','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:54:50',0,NULL,3,1,1,1,NULL,'stereoshopthe\r\\'),(2064,696019425011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','rch-phkr','dclair@cwhloans.com','David Clair','5318 Moonlight Way','Parker','CO','UNITED STATES','80134-4535','(407) 448-8484','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 21:56:45',0,NULL,3,1,1,1,NULL,'rch-phkr\r\\'),(2065,572597789013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','barahonaju','juanbarahona@gmail.com','Juan Barahona','Fernandez Concha 105','Santiago','Nunoa','CHILE','7750048 ','56-2-7171660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 22:24:30',0,NULL,3,1,2,1,NULL,'barahonaju\r'),(2066,520977653003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','alleksssa','alleks.ssa@gmail.com','Aleksandr Tarachev','Aerodromnaya 125 kv 52','Samara','Samarskaja oblast\'','RUSSIAN FEDERATION','443117','(917) 164-2692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 22:59:59',0,NULL,3,1,3,1,NULL,'alleksssa\rRELO002\rRA022493024CN\r'),(2067,572629121013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','sirvic_42','sirvic_42@hotmail.com','Trevor Thompson','16626 6th Ave W<br>Apt B304','Lynnwood','WA','UNITED STATES','98037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 01:11:53',0,NULL,3,1,1,1,NULL,'sirvic_42\racer 5pin1.25 6cm\r\\'),(2068,572626528013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',3,'HSNO022',44.7,'eastar4','denisdeoliveira','denis.oliveira.salvador@hotmail.com','Denis Oliveira','Rua Caieiras, 124<br>Vila São Paulo','Jundiaí','São Paulo','BRAZIL','13203513','+551196556969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 01:21:31',0,NULL,3,1,3,1,NULL,'denisdeoliveira\rHSNO022\rRA022493470CN\r'),(2069,773294412012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','round2tires','mariano2go@gmail.com','KEVIN MARIANO','3015 Trolley Bridge Cir','QUAKERTOWN','PA','UNITED STATES','18951-1800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 02:36:34',0,NULL,3,1,1,1,NULL,'round2tires\racer 8pin1.00 15cm\r\\'),(2070,773298817012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','megamulpha','terrencewalters@consultant.com','Terrence Walters','1219-18Ave NW','Calgary','AB','CANADA','T2M 0W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 03:03:23',0,NULL,3,1,3,1,NULL,'megamulpha\rOTSO002\rRA022493421CN\r'),(2071,572650466013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','cooljayjie','cool_jay@live.cn','Jie Li','82 Washington ST','Long Branch','NJ','UNITED STATES','07740-5941','(732) 216-7540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:20:16',0,NULL,3,1,1,1,NULL,'cooljayjie\r\\'),(2072,772630844012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','pauleo1214','pauleliasson@gmail.com','Paul Eliasson','3925 Beech Ave<br>APT 213','Baltimore','MD','UNITED STATES','21211-2254','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:51:56',0,NULL,3,1,1,1,NULL,'pauleo1214\r\\'),(2073,572655666013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','dobbin-1247','eugene.peoples@yahoo.com','eugene peoples','7415 Sandpiper Dr','houston','TX','UNITED STATES','77074-4807','(713) 774-1247','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 03:57:07',0,NULL,3,1,1,1,NULL,'dobbin-1247\r\\'),(2074,572693626013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','sisiniacom1','serokull5@hotmail.com','Marcelino Parrado Lera','C/Jazmin n4 2F','Trobajo del Camino (LEON)','Castilla y León','SPAIN','24010','606730935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 08:29:01',0,NULL,3,1,2,1,NULL,'sisiniacom1\r欧标\r\\'),(2075,696158096011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','thebigmacs','hufriedy@gmail.com','Derek McConnell','1120 N. 14th Street<br>RD Apartment','Lincoln','NE','UNITED STATES','68508','(402) 432-5457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 08:40:09',0,NULL,3,1,1,1,NULL,'thebigmacs\r\\'),(2076,572698726013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','marios_p','mariospast@yahoo.com','Marios Pastellas','5, Agias Irinis str, Aglantzia','Nicosia','CY','CYPRUS','2102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 08:58:27',0,NULL,3,1,2,1,NULL,'marios_p\\'),(2077,696194465011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',10,'BTHP2112',128,'eastar4','batman44410','bruce6777@aol.com','Bruce L Wayne','6777 State Route 46','Cortland','OH','UNITED STATES','44410-9668','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 11:02:38',0,NULL,3,1,1,1,NULL,'batman44410\rHP 8pin 0.8 3cm\r\\'),(2078,773449830012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','mgoularts','mgoularts@yahoo.com.br','Marcelo Goulart da Silva','Alameda Campista, 215.<br>Arsenal','São Gonçalo','Rio de Janeiro','BRAZIL','24751-520','+552192921321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:04:37',0,NULL,3,1,2,1,NULL,'mgoularts\r\\'),(2079,572739797013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','vicky20jak','vicky20jak@gmail.com','VIVEK GUPTA','SUNRAYS<br>KACHI GHATI, PO TARADEVI','SHIMLA','Himachal Pradesh','INDIA','171001','9418044690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:06:53',0,NULL,3,1,2,1,NULL,'vicky20jak\r\\'),(2080,572751684013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','luckybbts','bennitz@juno.com','Bob Bennitz','23 Flaherty Dr','Guelph','ON','CANADA','N1H8K3','(519) 763-0036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:25:00',0,NULL,3,1,2,1,NULL,'luckybbts\\'),(2081,773466479012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','saab914','saab914@aol.com','Peter J Ortiz','6928 Fox Haven Pl','Raleigh','NC','UNITED STATES','27616','(919) 647-4016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 13:48:28',0,NULL,3,1,1,1,NULL,'saab914\\'),(2082,526868692004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','2010taz368','tazgrondin@videotron.ca','bruno grondin','774 frechette','granby','QC','CANADA','j2h2m2','(450) 777-6632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:10:09',0,NULL,3,1,3,1,NULL,'2010taz368\rOMHJ001\rRA022493483CN\r'),(2083,696259403011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','snastos','steve.nastos@gmail.com','Steve Nastos','138 Melrose Ave','Toronto','ON','CANADA','M5M 1Y7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:29:48',0,NULL,3,1,2,1,NULL,'snastos\r\\'),(2084,773487089012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','ba_ronen','ba_ronen@hotmail.com','Ronen Ben-Aaron','1881 Steeles Ave. West Suit #337','Toronto','ON','CANADA','M3H 0A1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:40:57',0,NULL,3,1,3,1,NULL,'ba_ronen\rOTCN004*10\rRA022493523CN'),(2085,572771405013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','tundrwd1257','tim@underwoodfamily.org','Tim Underwood','5114 SW 96th St','Augusta','KS','UNITED STATES','67010-7746','(316) 778-0405','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 14:44:34',0,NULL,3,1,1,1,NULL,'tundrwd1257\r\\'),(2086,696270536011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','rebear01','rebear@comcast.net','karen wright','534 east grand blvd','ypsilanti','MI','UNITED STATES','48198','(734) 660-9304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 14:58:47',0,NULL,3,1,1,1,NULL,'rebear01\r\\'),(2087,0,230609824619,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','redalf20','surfplus920@yahoo.com','ALFREDO S. ISABEL','909 N Frederic St','Burbank','CA','UNITED STATES','91505-2620','(818) 726-0911','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 15:11:01',0,NULL,3,1,1,1,NULL,'redalf20\r\\'),(2088,0,230609824618,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tbwilsongolf4u','tbwilson@wildblue.net','Bev Wilson','1868 Highway W','Bonnots Mill','MO','UNITED STATES','65016-2408','(573) 897-2606','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-16 16:06:07',0,NULL,3,1,1,1,NULL,'tbwilsongolf4u\r\\'),(2089,696302829011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jobie4020','joannhunter@fuse.net','Joann Hunter','4020 Haverstraw Dr','Cincinnati','OH','UNITED STATES','45241','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 16:20:16',0,NULL,3,1,1,1,NULL,'jobie4020\r\\'),(2090,773304067012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','csy922','wilson121869@yahoo.com','Wilson Lee','70 Irenemount Crescent','Markham','ON','CANADA','L3S3C4','(416) 618-2093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:38:18',0,NULL,3,1,2,1,NULL,'csy922\r\\'),(2091,696313171011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','astefane','anthony.stefanelli@rogers.com','Anthony Stefanelli','1 Good\'s Lane','Brantford','ON','CANADA','n3v1c7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:41:37',0,NULL,3,1,2,1,NULL,'astefane\\'),(2092,572809683013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','th_psarrakos','thpsarrakos@hotmail.com','Thanos Psarrakos','Koridallou st 19','Pireaus','','GREECE','18540','0030210 4110101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:50:26',0,NULL,3,1,2,1,NULL,'th_psarrakos\\'),(2093,526915290004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',2,'HSPL011',46,'cnfaner','ilusha101','ilusha23@gmail.com','Eli Berezovsky','Ashuach 6/38','Nazareth Illit','ME','ISRAEL','17094','972547801410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:05:17',0,NULL,3,1,3,1,NULL,'ilusha101\rHSPL011\rRA022493069CN\r'),(2094,695598302011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','rfriskes','robfriskes@hotmail.com','rob friskes','grote beerstraat 78','hengelo','','NETHERLANDS','7557 wl','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:34:31',0,NULL,3,1,2,1,NULL,'rfriskes\\'),(2095,526930915004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','helidaniel','danielowen@sympatico.ca','daniel owen','71 Roxborough St. West','Toronto','ON','CANADA','M5R1T9','(416) 961-4300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:49:38',0,NULL,3,1,3,1,NULL,'helidaniel\rOMHJ001\rRA022493130CN\r'),(2096,521189032003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',42,'cnfaner','vkp','steven@microsystem.hu','Istvan Gyula Viragos Kis','Lencses 5/a','Nagykoros','Pest','HUNGARY','2750','36203696550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 17:51:09',0,NULL,3,1,3,1,NULL,'vkp\rWWSI002+ANCN001\r潘\r'),(2097,572831768013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','kaeigor_nn','kaeigor@ya.ru','IGOR KRAEV','Appartment 91, 29 6-microrayon Street','Nizhniy Novgorod','RU','RUSSIAN FEDERATION','603147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 18:17:22',0,NULL,3,1,2,1,NULL,'kaeigor_nn\r新优联'),(2098,521193599003,130498755181,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.99,'cnfaner','autaylor73','autaylor@gmail.com','Austin Taylor','10755 Norchester Village Dr.','Houston','TX','UNITED STATES','77070','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 18:17:46',0,NULL,3,1,1,1,NULL,'autaylor73\\'),(2099,521198596003,130508877560,'100% Lowepro Mini Trekker AW Photo Camera Bag Backpacks',1,'',64,'cnfaner','jimnatsam','atcah@aol.com','James C Moore','PO Box 1586','Kingston','WA','UNITED STATES','98346-1586','','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-16 18:21:21',0,NULL,3,0,3,1,NULL,'jimnatsam\rRA022493157CN'),(2100,696369347011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','federicoengland','fede@englandoptical.com.ar','england Federico','Barrio los Troncos S/N<br>Casilla de correo N° 46','Saladillo','Buenos Aires','ARGENTINA','7260','02344-454832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 18:35:07',0,NULL,3,1,2,1,NULL,'federicoengland\r\\'),(2101,0,220770230159,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','2289xd','ms_luckyman@hotmail.com','Weimin Chen','23 Winterfield Rd','Irvine','CA','UNITED STATES','92602-0714','(626) 524-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 18:50:16',0,NULL,3,1,1,1,NULL,'2289xd\r\\'),(2102,773618927012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','999.michael','999.michael@gmail.com','Mike Darling','Churchill College','Cambridge','Cambridgeshire','UNITED KINGDOM','CB3 0DS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 19:07:27',0,NULL,3,1,2,1,NULL,'999.michael'),(2103,773623488012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','tonyandshirleyp','tonyandshirleyp@hotmail.co.uk','anthony pepper','marts marsh<br>bulkington road shilton','coventry','West Midlands','UNITED KINGDOM','cv7 9jt','02476610900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 19:13:57',0,NULL,3,1,3,1,NULL,'tonyandshirleyp\rWLDL001\rRA022493126CN'),(2104,696387748011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',3,'WLAP001',44.43,'eastar4','jamesb2077','jboland@netpenny.net','James Boland','2884 134th Ave','Hopkins','MI','UNITED STATES','49328-9748','(616) 893-7316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 19:18:29',0,NULL,3,1,1,1,NULL,'jamesb2077\r\\'),(2105,773655466012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',12.5,'eastar4','igormeshkoff','diamond__69@mail.ru','Igor Meshkov','Zorge 43a/16','Novoshahtinsk','Rostov-on-Don','RUSSIAN FEDERATION','346900','+7(928)7799161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:18:22',0,NULL,3,1,2,1,NULL,'igormeshkoff\racer 5pin1.25 6cm \r\\'),(2106,572891493013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','nuclearfloyd','nuclearfloyd@gmx.de','Florian Manteuffel','Feldkirchener Straße 14b','Ingolstadt','','GERMANY','85055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:41:08',0,NULL,3,1,2,1,NULL,'nuclearfloyd\r\\'),(2107,773685009012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','anthonygroves1623','anthonygroves16@yahoo.com','Danny Cano','12240 Sago Ave','Jacksonville','FL','UNITED STATES','32218-2653','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 21:19:43',0,NULL,3,1,1,1,NULL,'anthonygroves1623\r\\'),(2108,521258959003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',15.29,'cnfaner','crazystargrl','movetheneedlecreations@yahoo.com','Anna Leehey','819 N Euclid Ave','Oak Park','IL','UNITED STATES','60302-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 21:34:50',0,NULL,3,1,1,1,NULL,'crazystargrl\r\\'),(2109,773695870012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','cougarjft08','jeanf3008@hotmail.com','Jean Theriault','4465 de bellechasse app-410','montreal','QC','CANADA','H1T3R8','(514) 729-7334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:47:38',0,NULL,3,1,2,1,NULL,'cougarjft08\r\\'),(2110,773696168012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','omicronpie','bremer.family1@btinternet.com','Grant Bremer','The Chase<br>Badger\'s Ridge','Newbury','Berkshire','UNITED KINGDOM','RG20 0LQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 21:49:03',0,NULL,3,1,3,1,NULL,'omicronpie\r英标\rHSSE005\rRA022493316CN\r'),(2111,696458729011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','rumiware','rumiware@gmail.com','Rui Esteves','Rua José Carlos Ary dos Santos nº 45, Bairro Flor do Minho','Caneças','Caneças','PORTUGAL','1685-441','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:58:17',0,NULL,3,1,2,1,NULL,'rumiware\\\r'),(2112,696474988011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:50:35',0,NULL,3,1,3,1,NULL,'321tocsin\rADAK002+CACN001+CACN003\r再发一个IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy\rRA022493608CN'),(2113,773726782012,220769088294,'NIB Visenta I0 wireless mouse w/ nano USB receiver',1,'MOVI001',21.99,'eastar4','kiboys','zechang_li@hotmail.com','Zechang Li','5905 DIAL WAY','San Jose','CA','UNITED STATES','95129-4710','(408) 391-7666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-16 23:19:49',0,NULL,3,1,1,1,NULL,'kiboys\r白色绿底边\r、'),(2114,527027283004,140429368087,'2.1 HP Pavilion DV6400 DV6500 bluetooth module track#',1,'BTHP2110',13.99,'cnfaner','1940rob','cmf@powerup.com.au','Phillip Holst','47 Station Road','Loganlea','Queensland','AUSTRALIA','4131','0738056156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 23:44:52',0,NULL,3,1,3,1,NULL,'1940rob\rBTHP2110\rHP 8pin 1.25 18cm \rRA022493112CN'),(2115,773740236012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','jrenterprise1','jrenterprise1@netzero.net','jack wood jr','50151 Mile End Dr','Shelby Township','MI','UNITED STATES','48317-1148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:07:13',0,NULL,3,1,1,1,NULL,'jrenterprise1\r\\'),(2116,773742389012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','ptd0sss','simon_suen@hotmail.com','Simon Suen','7 Rebecca Rd','Newton','MA','UNITED STATES','02465','(617) 332-9545','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:13:09',0,NULL,3,1,1,1,NULL,'ptd0sss\rAcer 5pin1.25 3cm \r\\'),(2117,773749179012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','jarm113','kmather@att.net','kim mather','139 bailey woods rd','brooklyn','CT','UNITED STATES','06234-2407','(860) 779-8643','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:39:22',0,NULL,3,1,1,1,NULL,'jarm113\r\\'),(2118,572948959013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','bakerbarry143','brry143@aol.com','Barry Lamb','1350 Bonnie Cove Ave','Glendora','CA','UNITED STATES','91740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 00:46:36',0,NULL,3,1,1,1,NULL,'bakerbarry143\r\\'),(2119,773757678012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','mike_mckenzy','mikemckenzy@gmail.com','Mike McKenzy','3538 E. Kerry Ln.','Phoenix','AZ','UNITED STATES','85050','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 01:09:07',0,NULL,3,1,1,1,NULL,'mike_mckenzy\r\\'),(2120,696515802011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','vinc07011986','vinc07011986@yahoo.fr','Gandoulas Vincent','32 rue bernard ortet','Toulouse','Midi-Pyrénées','FRANCE','31500','0659456073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 01:28:10',0,NULL,3,1,2,1,NULL,'vinc07011986\\'),(2121,572981611013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',2,'RCLO003',277.98,'eastar4','markviolette','mark@d-bug.org','Mark Violette','1565 Verchere St.','Orleans','ON','CANADA','k1c6b8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 03:59:33',0,NULL,3,1,3,1,NULL,'markviolette\rRCLO003\rRA022493174CN\r、'),(2122,773808301012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','reza4200','r_khademy@hotmail.com','reza khademy','668 Rue De Gaspe App.101 code 156','Montreal','QC','CANADA','H3E1H9','(514) 944-8712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 04:44:12',0,NULL,3,1,2,1,NULL,'reza4200\r\\'),(2123,696559819011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tazsoft','fmatte@gmail.com','Frédéric Matte','585 Charest Est, suite 900','Québec','QC','CANADA','G1K3J2','(418) 529-9697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 04:59:07',0,NULL,3,1,2,1,NULL,'tazsoft\r\\'),(2124,696561718011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','bogiemon','djgoding@gmail.com','David J. Goding','23 Cherrywood Dr','Palos Park','IL','UNITED STATES','60464-1576','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 05:08:15',0,NULL,3,1,1,1,NULL,'bogiemon\r\\'),(2125,773817578012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','abuamuslim','yusufaina@yahoo.com','Yusuf Aina','Yanbu Industrial College, P. O. Box 30436,','Yanbu','','SAUDI ARABIA','21477','+966508266121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 05:40:06',0,NULL,3,1,2,1,NULL,'abuamuslim\r\\'),(2126,773848929012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','07oscar07','jpoppy@tpg.com.au','Joseph Poppelock','30 BISDEE STREET','CORAL COVE','Queensland','AUSTRALIA','4670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 07:45:54',0,NULL,3,1,3,1,NULL,'07oscar07\rOTGR001+OTGR002\rRA022493038CN\r'),(2127,527103634004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','abdfarae2009','abdfarae@hotmail.com','abdulla salih mohd','al-madra<br>gsm 92955775','Samail','oman','OMAN','219/620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 07:50:26',0,NULL,3,1,3,1,NULL,'abdfarae2009\rWWSI005\rRA022493055CN'),(2128,773860345012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jurica1976','jurica.stojkovic1@zg.t-com.hr','Jurica Stojkovic','Skolska 6','Novoselec','','CROATIA','10315','0912385194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:22:21',0,NULL,3,1,2,1,NULL,'jurica1976\r欧标\r\\'),(2129,696602670011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','yech1927','ykurtz@hotmail.com','Yechiel Kurtz','13 Givat Downes St.','Haifa','','ISRAEL','34345','(972) 544-3088 ext.: 86','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:32:48',0,NULL,3,1,2,1,NULL,'yech1927'),(2130,573036941013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','nadezhda1960','nadezhda1900@gmail.com','Ilja Kozevnikov','Urban str.101 (Vorderhs Etage 2)','Berlin','','GERMANY','10967','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 09:22:57',0,NULL,3,1,2,1,NULL,'nadezhda1960\rIlja Kozevnikov\rUrban str.101 (Vorderhs Etage 2)\r10967 Berlin\rDeutschland\rmob.tel. +49 17694636480\r\\\r\r\r'),(2131,773893428012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','uwe_guth','uwe.guth@t-online.de','Uwe Guth','MSC Vertriebs GmbH<br>Zeppelinstrasse 1a','Neufahrn','','GERMANY','85375','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 09:47:54',0,NULL,3,1,3,1,NULL,'uwe_guth\rHSSH002\rRA022493015CN\r'),(2132,773900482012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','kathschofield','kath.schofield@ntlworld.com','Kath Schofield','38 Westlea Crescent,Yeadon','Leeds','West Yorkshire','UNITED KINGDOM','LS197EE','01132192621','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 10:04:07',0,NULL,3,0,3,1,NULL,'kathschofield\rRA117728881CN\r\\'),(2133,696645066011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jasonadaniels','jason.daniels@hotmail.com','Jason Daniels','PO Box 7388','Southport Park','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jasonadaniels'),(2134,773912065012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hyperbytesaustralia','hyperbytesaustralia@gmail.com','John Kostakis','12 Forrester Street','Kingsgrove','New South Wales','AUSTRALIA','2208','0293708401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:36:51',0,NULL,3,1,2,1,NULL,'hyperbytesaustralia\r\\'),(2135,773941514012,220704730539,'New in Box Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL004',15.5,'eastar4uk','suedave1066','davesue@chercott.com','MR D CAMBLE','UNIT 3<br>JEFFERSON WAY','THAME','Oxfordshire','UNITED KINGDOM','OX9 3SZ','01844217192','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 11:43:11',0,NULL,3,1,3,1,NULL,'suedave1066\rHSPL004  英标\rMR D CAMBLE\r5 brookside\rthame Oxon ox9 3de\rUnited Kingdom\r01844217192\rRA117728949CN'),(2136,696693870011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','atcnaked','fred.gotpub@gmail.com','Frédéric   Gautier','40, rue des Alouettes','Cournon','Auvergne','FRANCE','63800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:21:09',0,NULL,3,1,2,1,NULL,'atcnaked\rHP 8pin 1.25 18cm \r\\'),(2137,773965439012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',50.3,'eastar4','tauruz.abc','x-and@yandex.ru','Alexander Stepanov','Smel\'chak, 8, 71','Zheleznodorozhny','Moscow region','RUSSIAN FEDERATION','143982','79035764716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:36:57',0,NULL,3,1,3,1,NULL,'tauruz.abc\rWLIN012\r\rRA117728229CN\r\\'),(2138,696711031011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','sold1976a11','soldatenkoass11@rambler.ru','ANDREI SALDATSENKA','rechitskoe shosse str. 63/1/35','gomel','','BELARUS','246012','80232431224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:03:31',0,NULL,3,1,2,1,NULL,'sold1976a11\r欧标\r\\'),(2139,696730108011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fx-tools2009','alius.baranauskas@gmail.com','Alius Baranauskas','Mads Klokkersveg 6c','Fjerdingby','Akershus','NORWAY','2008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:49:46',0,NULL,3,1,2,1,NULL,'fx-tools2009'),(2140,573113227013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','rsacal-kurokuma','osamu_t@rc4.so-net.ne.jp','OSAMU TAKENOSHITA','2-15-1-402<br>ENGYO','FUJISAWA-SHI','Kanagawa','JAPAN','252-0805','(0466)47-6974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:50:09',0,NULL,3,1,3,1,NULL,'rsacal-kurokuma\rWWOT001+ANCN001\rRA117728952CN\r\\'),(2141,774006666012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','mr.locksmith2007','mr.locksmith@yahoo.com','michael nelson','PO Box 264<br>3 Bullis Way','nassau','NY','UNITED STATES','12123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 14:06:00',0,NULL,8,0,17,0,NULL,'mr.locksmith2007'),(2142,573126821013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','tcone_de','f.emden@yahoo.de','Friedrich Emden','Voigtstr. 41','Berlin','','GERMANY','10247','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 14:30:32',0,NULL,3,1,3,1,NULL,'tcone_de\rWLAP008\rRA117728864CN'),(2143,696740377011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.95,'eastar4uk','5solas5','adaly@sierraresearch.com','Allan Daly','Ballygarraun South','Athenry','Galway','IRELAND','default','091875780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 14:41:27',0,NULL,3,1,3,1,NULL,'5solas5\rWLAP001\rRA117728816CN\r\\'),(2144,521484945003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','edgaras9','baneviciuse@gmail.com','Edgaras Banevicius','Senoliu 6','Vilnius','Vilnius','LITHUANIA','LT-08400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 15:29:21',0,NULL,3,0,3,1,NULL,'edgaras9\rHSNO008\r欧标\rRA117728918CN\r\\\r'),(2145,774053241012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','kden2543','katherine.dennison@sadprt.org','Katherine Dennison','6832 Granero Dr','El Paso','TX','UNITED STATES','79912','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 15:32:02',0,NULL,3,1,1,1,NULL,'kden2543\r\\'),(2146,527251345004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','bwrftrt','rla5@dawgfans.net','Raymond Altman','4158 US Highway 17<br>Southern Biker Gear','Richmond Hill','GA','UNITED STATES','31324-3306','(912) 228-5252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 16:27:50',0,NULL,3,1,1,1,NULL,'bwrftrt\r\\'),(2147,774085710012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','compasist','compasist@hotmail.com','Deniz TAHTALI','Istanbul Bilgi Iletisim Sistemleri Ticaret ve Sanayi A.S.<br>Istanbul Teknik Universitesi Teknokent Ari 1 Binasi No:6 Maslak','Istanbul','Turkey','TURKEY','34469','+905332696118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 16:31:44',0,NULL,3,1,3,1,NULL,'compasist\rOTSO002\r\rRA117739102CN\r\\'),(2148,521516382003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-17 16:42:07',0,NULL,3,1,3,1,NULL,'anyquilmes10\rOTJE001\rRA117728847CN\r\\\r'),(2149,696854194011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:20:26',0,NULL,8,1,17,0,NULL,'321tocsin'),(2150,774144119012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','**enigma**','pknaus@gmail.com','Paul Knaus','708B W Gibson St','Austin','TX','UNITED STATES','78704-2344','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 17:28:53',0,NULL,3,1,1,1,NULL,'**enigma**\r\\'),(2151,573217655013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:40:10',0,NULL,8,1,17,0,NULL,'small.mac'),(2152,573228695013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','trendanizer','mail2@sloboda.de','Elvira Lipp','Welterpfad 41','Berlin','','GERMANY','12277','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:54:24',0,NULL,3,1,2,1,NULL,'trendanizer\r\\'),(2153,573228470013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','denapalermo7','denapalermo@att.net','Dena Palermo','514 Ripple Creek Dr','Houston','TX','UNITED STATES','77024','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 17:56:10',0,NULL,3,1,1,1,NULL,'denapalermo7\r\\'),(2154,521563535003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','2004ohad','ohadshtr@tau.ac.il','Ohad Shtark','Shoshanat Hacarmel 62','Haifa','','ISRAEL','34322','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 18:00:47',0,NULL,3,1,3,1,NULL,'2004ohad\rOTGR001\rRA022493041CN'),(2155,774196704012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',12.5,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 18:16:03',0,NULL,3,1,3,1,NULL,'small.mac\racer 8pin1.0 3cm\r再发两个NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp\rBTAC2017+WLAP008\rRA022493599CN'),(2156,774265274012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',2,'BALO008',13.2,'eastar4','ra92253','ralvarez92201@hotmail.com','Raul Alvarez','52535 Avenida Navarro','La Quinta','CA','UNITED STATES','92253-3395','(760) 412-9534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:20:48',0,NULL,3,1,1,1,NULL,'ra92253\\'),(2157,696979213011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','rcritter235','rcritter235@yahoo.com',' regina crittendon','235 Box Rd','darden','TN','UNITED STATES','38328-2810','(731) 845-9862','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:28:35',0,NULL,3,1,1,1,NULL,'rcritter235\r\\'),(2158,774282106012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','andrew.svenson','andrewpsvenson@gmail.com','Andrew Svenson','366 Island Green Ln','Inman','SC','UNITED STATES','29349-7097','(864) 216-5226','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:38:30',0,NULL,3,1,1,1,NULL,'andrew.svenson\r\\'),(2159,774284933012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','jmcc1104','vjmccabe@verizon.net','James McCabe','417 Carmichael Drive','North Wales','PA','UNITED STATES','19454','(215) 699-5498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 19:40:49',0,NULL,3,1,1,1,NULL,'jmcc1104\r\\'),(2160,527384944004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','jp_rm250','mel_jean16@hotmail.com','jean-pierre houle','223 rue des bouleaux','gatineau','QC','CANADA','J8M2B1','(819) 918-5124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 19:59:08',0,NULL,3,1,3,1,NULL,'jp_rm250\rHSNO005\rRA117728833CN'),(2161,774300674012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','bobhillx','bobhilla@aol.com','Robert Hill','210 West 150th Street<br>Apt 2A','New York','NY','UNITED STATES','10039-2511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:00:29',0,NULL,3,1,1,1,NULL,'bobhillx\r\\'),(2162,527388700004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','knite77','b_kirchev@yahoo.com','Bozhidar Kirchev','Jolio Kurie street, bl.89, entr.1,ap.8','Sofia','Sofia district','BULGARIA','1113','+359878799105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 20:07:03',0,NULL,3,0,3,1,NULL,'knite77\rHSPL011\r欧标\rRA117728904CN'),(2163,774319606012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','juds1958','juds58@gmail.com','Judith Shisler','2003 Windcrest Ln','Joliet','IL','UNITED STATES','60431-8795','(815) 272-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:32:27',0,NULL,5,0,18,0,NULL,'juds1958\rpayapl 撤款'),(2164,774330495012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','maverickicx','weissre@muohio.edu','Ron Weiss','103 Shotwell St','San Francisco','CA','UNITED STATES','94103-3621','(502) 599-5931','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 20:48:01',0,NULL,3,1,1,1,NULL,'maverickicx\r\\'),(2165,573353512013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','kimberlydawnsexy','kimdawn1970@hotmail.com','kimberly williams','2033 S Main St<br>Lot 27','madisonville','KY','UNITED STATES','42431','(270) 875-9859','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 21:42:45',0,NULL,3,1,1,1,NULL,'kimberlydawnsexy\r\\'),(2166,697091539011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','textbookhuman','slaseret@yahoo.com','Teresa Schlosser','2983 Altamahaw Union Ridge Road','Burlington','NC','UNITED STATES','27217','(919) 636-0305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 23:11:25',0,NULL,3,1,1,1,NULL,'textbookhuman\r\\'),(2167,774400598012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','tartanworrior','eddieb1@hotmail.co.uk','edward boswell','8 Swisscot Walk<br>Woodhead','Hamilton','Scotland','UNITED KINGDOM','ML3 8DX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 23:21:57',0,NULL,3,1,3,1,NULL,'tartanworrior\rOTCN001\rRA117728895CN\r\\\r'),(2168,774405610012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 23:37:51',0,NULL,3,1,2,1,NULL,'avextra-co-uk\r\\'),(2169,773984596012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','mikey-will-eat-it','sawdustorbust@aol.com','Mike Beesley','3324 W University Ave<br># 152','Gainesville','FL','UNITED STATES','32607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-17 23:53:32',0,NULL,3,1,1,1,NULL,'mikey-will-eat-it\r\\'),(2170,774430422012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','comeagainsundor','sundor.rujina@yahoo.com','sundor ali','6 pinefield road townhill park','southampton','Hampshire','UNITED KINGDOM','so18 2gd','02380555273','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 00:48:49',0,NULL,3,1,3,1,NULL,'comeagainsundor\rHSNO005+CCNO001\rRA117728878CN'),(2171,573397338013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','123elra','massey4070@insightbb.com','Elra Massey','4070 Summer Time Pkwy','Louisville','KY','UNITED STATES','40272-4861','(502) 933-0959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 00:51:16',0,NULL,3,1,1,1,NULL,'123elra\r\\'),(2172,573405811013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','danilaloginov','loginovdanila@gmail.com','Danila Loginov','ulitsa Yakovleva, dom 35, kvartira 149','Tomsk','Tomskaya oblast','RUSSIAN FEDERATION','634003','9131002029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 00:56:56',0,NULL,3,1,2,1,NULL,'danilaloginov\racer 4pin1.25 15cm\r\\'),(2173,573407298013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','godotxd97','dah@us.ibm.com','David Hoffman','5136 Bartons Enclave Ln','Raleigh','NC','UNITED STATES','27613-6164','(919) 870-0978','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:03:47',0,NULL,3,1,1,1,NULL,'godotxd97\r\r\\'),(2174,573408357013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',1,'BTHP2102',12.8,'eastar4','hoo340340','randallhoo374@msn.com','RANDALL HOO','2207 Apache St','ADELPHI','MD','UNITED STATES','20783-1617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:04:36',0,NULL,3,1,1,1,NULL,'hoo340340\rHP 8pin 1.0 3cm 线序反\r\\'),(2175,573411293013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rollingscott','nealhively@comcast.net','Dr. Neal O. Hively','255 Opal Dr','Chambersburg','PA','UNITED STATES','17202','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-18 01:11:15',0,NULL,3,1,1,1,NULL,'rollingscott\r\\'),(2176,661841229001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','cabda01','danielcabrera_18@hotmail.com','Mario Cabrera','170 Orient st','Worcester','MA','UNITED STATES','01604','(508) 424-4304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:21:05',0,NULL,3,1,1,1,NULL,'cabda01\rLK041370495CN\r\\'),(2177,774444681012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','philloper24euk','already_dead@msn.com','phil loper','PO Box 204<br>307 E. Orchard St.','West Manchester','OH','UNITED STATES','45382-0204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 01:24:06',0,NULL,3,1,1,1,NULL,'philloper24euk\r\\'),(2178,774454608012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',2,'HSPL010',31.3,'eastar4uk','mamasports','whitleymiles@bellsouth.net','TERRESSIA MILES','90cr5260','BOONEVILLE','MS','UNITED STATES','38829','(662) 728-7136','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 01:50:42',0,NULL,3,1,1,1,NULL,'mamasports\\'),(2179,573428836013,230544190510,'NEW original Motorola H700 Gold DG Bluetooth Headset',1,'HSMO012',17.9,'eastar4','ktrinh0808','kt41387@yahoo.com','Kim Trinh','1840 Lake Dr','Lebanon','PA','UNITED STATES','17046','(717) 813-1042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 02:14:44',0,NULL,3,1,1,1,NULL,'ktrinh0808\r\\'),(2180,527491256004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','kimball719','dudlydewright@hotmail.com','kimball ballard','841 circle rd','palmer lake','CO','UNITED STATES','80133','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 02:19:16',0,NULL,3,1,1,1,NULL,'kimball719\r\\'),(2181,527492742004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'cnfaner','brenni13','brenton.f.wong@gmail.com','Brenton Wong','67 Maritime Tce<br>Birkenhead','North Shore City','Auckland','NEW ZEALAND','0626','6421399304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 02:24:30',0,NULL,3,1,3,1,NULL,'brenni13\rWLDE002\rRA022493086CN'),(2182,573437118013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','mateusz39','mateusz@mts.net','Mateusz Labuda','39 Taunus Dr.','Winnipeg','MB','CANADA','R2G3Y5','(204) 668-8745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 02:47:47',0,NULL,3,1,2,1,NULL,'mateusz39\r\\'),(2183,774475925012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','snorkeljim','snorkeljim@yahoo.com','Jimmy Pho','3612 Lindhaven Dr','Pearland','TX','UNITED STATES','77584','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 02:49:54',0,NULL,3,1,1,1,NULL,'snorkeljim\r\\'),(2184,527503182004,140490658519,'New HuaWei EM660 3G WWAN Mini PCI-E Card CDMA EV-DO Mod',1,'WWHU001',71.9,'cnfaner','minersc','minersc@execulink.com','Corey Miners','1411-3700 Kaneff Crescent','Mississauga','ON','CANADA','L5A4B8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 03:24:22',0,NULL,3,1,3,1,NULL,'minersc\rWWHU001\rRA117728921CN'),(2185,573448810013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','ben251067','elekhakia@gmail.com','dr. benedict itsuokor','15, cherry road','newport pagnell','Buckinghamshire','UNITED KINGDOM','mk16 0ar','02032393316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 03:52:53',0,NULL,3,1,2,1,NULL,'ben251067\r\\'),(2186,774497621012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','waterbolt','randomfire@gmail.com','David Young','408 N ORCUTT DR','MONTEBELLO','CA','UNITED STATES','90640','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 04:18:47',0,NULL,3,1,1,1,NULL,'waterbolt\r\\'),(2187,527511641004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','italiano89rus','lucifer-mk5@yandex.ru','Artem Pypa','Magistralnaya 117/30','Noyabrsk','Tumenskaya obl','RUSSIAN FEDERATION','629803','79824080010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:26:29',0,NULL,3,0,3,1,NULL,'italiano89rus\r欧标  HSNO017\rRA022493466CN'),(2188,697190424011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','craptologist','edmund.sepikit@gmail.com','Edmund Sepikit','P.O, Box 21569<br>Luyang','Kota Kinabalu','Sabah','MALAYSIA','88773','0128338475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 05:02:52',0,NULL,3,1,2,1,NULL,'craptologist\r\\'),(2189,774515365012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ladiva411','ladiva411@msn.com','Latavia Barnes','132 Dupuy Circle','Byram','MS','UNITED STATES','39272-4489','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 05:54:42',0,NULL,3,1,1,1,NULL,'ladiva411\r\\'),(2190,774528712012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','magdalena416','rus416@googlemail.com','Magdalena Czajkowska','48 Saunders road','Uxbridge','Middlesex','UNITED KINGDOM','UB10 0rl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 06:59:31',0,NULL,3,1,3,1,NULL,'magdalena416\rOTCN004*10\rRA022493510CN'),(2191,774531991012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','blassberg','blassberg@email.com','Charles   Blassberg','19 Best Avenue','Kenilworth','Warwickshire','UNITED KINGDOM','CV82TN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 07:14:51',0,NULL,3,1,3,1,NULL,'blassberg\rOTRA002\rRA022493554CN'),(2192,573486886013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',18,'eastar4','yzsd1','ysatwork@msn.com','Yunsheng Zhao','16552 Manassas St','San Diego','CA','UNITED STATES','92127-4410','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-18 08:28:52',0,NULL,3,1,1,1,NULL,'yzsd1\r\\'),(2193,527549941004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','v.kushnir','vkushnir@gmail.com','Vladimir Kushnir','7-30A<br>WestGate','Aktau','Mangystau','KAZAKHSTAN','130000','+77771933351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:20:39',0,NULL,3,1,3,1,NULL,'v.kushnir\rOTCR001\rRA022493571CN'),(2322,574140003013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','globalbuyer','mrinal@hotmail.co.uk','Mrinal Kumar','Jetset Journeys Pvt. Ltd., D-82 Amar Colony (Basement)<br>Lajpat Nagar IV','New Delhi','Delhi','INDIA','110024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:04:10',0,NULL,3,1,2,1,NULL,'globalbuyer\r、'),(2194,774568640012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:44:46',0,NULL,3,1,2,1,NULL,'avextra-co-uk\r、'),(2195,774587832012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',18.69,'eastar4uk','mal102010','michael.lloyd@kpmg.ie','Michael Lloyd','KPMG, Stokes Place<br>HARCOURT ST','dublin','Dublin','IRELAND','2','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 10:56:12',0,NULL,3,1,3,1,NULL,'mal102010\rHSUE002\rRA022493355CN\r\\'),(2196,694451851011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',9.99,'eastar4','lslh1975','srilalitha37@gmail.com','LSLH LALITA','PLOT NO.87 LIG<br>MAYURINAGER,MIYAPUR POST','HYDERABAD (Andhra Pradesh)','AP','INDIA','500050','919395139768919391668269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 10:57:13',0,NULL,3,1,2,1,NULL,'lslh1975\r\\'),(2197,573525990013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.8,'eastar4','camphreluche','franck.flichy@orange.fr','Franck FLICHY','Le Plessis HUDELOR','LOUTEHEL','Bretagne','FRANCE','35330','0685458274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:08:22',0,NULL,3,1,2,1,NULL,'camphreluche\r\\'),(2198,774611175012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','guard.69.angel','piglet.7@btinternet.com','Joanna Briggs','7,Emmery close','Broughton','Lincolnshire','UNITED KINGDOM','DN20 0SN','01652658984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:19:39',0,NULL,3,1,2,1,NULL,'guard.69.angel\r\\'),(2199,573530777013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','dudeboy66','sime01@videotron.ca','leonce sime','823 de l\'harmonie','laval','QC','CANADA','h7a 3z3','(514) 718-5354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:31:36',0,NULL,3,1,3,1,NULL,'dudeboy66\rOTRA002\rRA022493347CN\r\\'),(2200,774631092012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','andlil73','anders@liljeberg.nu','Anders Liljeberg','Sturzen-Beckers gata 5','Helsingborg','SE','SWEDEN','25227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:15:48',0,NULL,3,1,2,1,NULL,'andlil73\rMX20T\r\\'),(2201,773007409012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','paulogentil10','paulogentil@hotmail.com','Paulo Gentil','SQN 216 bl.A apt.223','Brasilia','DF','BRAZIL','70875-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:19:43',0,NULL,3,1,2,1,NULL,'paulogentil10\r\\'),(2202,697320337011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','littletug04','littletug_11@hotmail.com','Jamere wilson','19070 NW 57th Ave<br>Apt 306','Hialeah','FL','UNITED STATES','33015-5085','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:07:29',0,NULL,3,1,1,1,NULL,'littletug04\r\\'),(2203,697323092011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','geobra','info@klickyworld.com','Andreas Männer','Romaneistr. 2c','Emmendingen','','GERMANY','79312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:17:32',0,NULL,3,1,2,1,NULL,'geobra\r\\'),(2204,697328440011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',8.55,'eastar4','edyurco','edyurco@yahoo.com','Edward Yurco','3250 N Hamlin Ave','Chicago','IL','UNITED STATES','60618-5208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:34:35',0,NULL,3,0,1,1,NULL,'edyurco\r\\'),(2205,527611006004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','555linas','lalminas@hotmail.com','Leandras Alminas','Debreceno 34-50','Klaipeda','','LITHUANIA','94147','+37068256018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:48:01',0,NULL,3,1,3,1,NULL,'555linas\rHSNO005\r欧标\rRA022493280CN\r\\'),(2206,573562739013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.98,'eastar4','emir2828','azeemirza@msn.com','Eli Mirza','41 Middlesex Ave','Edison','NJ','UNITED STATES','08820-3525','(917) 681-0568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 14:50:51',0,NULL,3,1,1,1,NULL,'emir2828\r\\'),(2207,573579975013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','skaterkater','info@appartement-messe.com','Weisse Flotte','Frings Str. 11a<br>z.H. Herr Gantenberg','Düsseldorf','','GERMANY','40221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:55:27',0,NULL,3,1,2,1,NULL,'skaterkater\r\\'),(2208,774688532012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maxito24','maksymiukmarek@gmail.com','Marek Maksymiuk','Suwalska 36','Gizycko','','POLAND','11-500','004 874284','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:56:32',0,NULL,3,1,2,1,NULL,'maxito24\r\\'),(2209,521886896003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','olimasoft','badstorm@gmail.com','Marco Olimpi (OPS Activity)','S.S 13 Pontebbana, 81','Basiliano','Udine','ITALY','33031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:04:16',0,NULL,3,1,3,1,NULL,'olimasoft\rHSMO016\r欧标  黑色\rRA117739014CN\r、'),(2210,697378691011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','woohooben','woohooben@hotmail.com','Ben Hawthorn','3 (3f1) Bernard Terrace','Edinburgh','Midlothian','UNITED KINGDOM','EH8 9NU','07841978736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:53:36',0,NULL,3,1,2,1,NULL,'woohooben\r\\'),(2211,662073208001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','sportingood','oliver@goumas.us','Oliver Goumas','2655 s moore dr<br>Unit c','Lakewood','CO','UNITED STATES','80227-6502','(303) 995-3506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 16:53:46',0,NULL,3,1,1,1,NULL,'sportingood\rLK041624456CN \r\\'),(2212,573597638013,230608888246,'Brand new LOGITECH VX NANO USB RECEIVER VX V450 V550',1,'RELO003',16.9,'eastar4','adkinson12','nadkinson12@yahoo.com','Nick Adkinson','8000 York Rd<br>Unit 14','Towson','MD','UNITED STATES','21252-0001','(301) 676-2419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 16:55:33',0,NULL,3,1,1,1,NULL,'adkinson12\r新优联\r\\'),(2213,573599537013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','abdulrahim79','lucky_3abdu@hotmail.com','Abdulrahim alharthi','oman<br>P.O BOX NO:74 , P.CODE:122  MABELLAH,SEEB','seeb','MUSCAT','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:01:56',0,NULL,3,1,2,1,NULL,'abdulrahim79\r\\'),(2214,697393496011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',49.99,'eastar4','fan0416hk','fan0416@me.com','Cheuk Fan Li','Flat 39, 24/F, Block D, Metropole Building<br>North Point','default','','HONG KONG','default','60808403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:27:02',0,NULL,3,1,14,1,NULL,'fan0416hk\r010976544300'),(2215,573617867013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27,'eastar4','marcosadrianodia2008','marcosadrianodias@yahoo.com.br','marcos adriano','R; Scorpius N:1259<br>Jardim Satelite','Sao jose dos Campos','sao Paulo','BRAZIL','12230-570','012 34314819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:03:52',0,NULL,3,1,2,1,NULL,'marcosadrianodia2008\r\\'),(2216,774750215012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',17.2,'eastar4','gegemnpt','jtredez@gmail.com','Coronis (Jérôme Tredez)','Espace Concorde – Bât. B<br>120 impasse JB Say','Perols','Languedoc-Roussillon','FRANCE','34470','0687285784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:05:18',0,NULL,3,1,2,1,NULL,'gegemnpt\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000\r\\'),(2217,527668547004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','g0lduck','eliteground@yandex.ru','Artem Zabirohin','ul. Kamishovai 32/1/30','Saint Petersburg','','RUSSIAN FEDERATION','197372','89627127928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:10:21',0,NULL,3,1,3,1,NULL,'g0lduck\r欧标 HSPL011\rRA022493262CN\r\\'),(2218,521927320003,130490592974,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',59.9,'cnfaner','stascebanu','stasdinvorniceni@rambler.ru','Stanislav Cebanu','RUA ALVARO GOMES lote 4 8eq','Armaçao de Pera','Armaçao de Pera','PORTUGAL','8365-111','964046753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:18:17',0,NULL,3,1,3,1,NULL,'stascebanu\rANWI001\rRA022493293CN\r\\'),(2219,774779961012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','kris13514','spam71@wp.pl','Krzysztof Tucholski','Panewnicka 363/3','40-773 Katowice','śląskie','POLAND','40773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 18:58:45',0,NULL,3,1,2,1,NULL,'kris13514\r\\'),(2220,520906318003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','remolato','maciremo@alice.it','Massimiliano Remolato','Contrada Ghiotti 18','Montecchio Maggiore','Vicenza','ITALY','36075','3207096189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 19:22:38',0,NULL,3,1,3,1,NULL,'remolato\rHSMO016\rRA022493276CN\r\\'),(2221,573659292013,230412690655,'2.0 New ASUS Bluetooth Module +cable for EEEPC1101HA',1,'BTHU2001',12.5,'eastar4','eviz1989','eric.viseur@gmail.com','Eric Viseur','Avenue Reine Astrid 20/2','Mons','','BELGIUM','7000','0497923680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 19:34:50',0,NULL,3,1,2,1,NULL,'eviz1989\r华硕10pin 0.8 6cm\r\\'),(2222,774809045012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','mgm_cards','dvcamero.n@gmail.com','david cameron','248 tom hill sr blvd<br>pmb 192','MACON','GA','UNITED STATES','31210-1815','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 19:44:04',0,NULL,3,1,1,1,NULL,'mgm_cards\\'),(2223,773692870012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','drwsalvador','davegeoffrey@hotmail.com','Dave Veenhuizen','Debussystraat 4','Spijkenisse','','NETHERLANDS','3208CH','+31 181-630996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:11:28',0,NULL,3,1,2,1,NULL,'drwsalvador\r\\'),(2224,527720426004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','skylaptopstore','skylaptop@yahoo.com','xiaohui wang','151 E Garvey Ave','Monterey Park','CA','UNITED STATES','91755-2905','(626) 626-3942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 20:33:36',0,NULL,3,1,1,1,NULL,'skylaptopstore\r\\'),(2225,774823757012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','hcktds','tidus199193@hotmail.com','Imanol  Barba Sabariego','Abat Escarré, 20, 2º 1ª','Sabadell','Cataluña','SPAIN','08206','649090877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:36:19',0,NULL,3,1,2,1,NULL,'hcktds\r\\'),(2226,774847302012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','cisco_racks','marca_alexander@yahoo.com','Marc Alexander','5980 Folkstone Ln','Orlando','FL','UNITED STATES','32822-9423','(407) 489-4672','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cisco_racks'),(2227,697514917011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','avro91','z.5389@yahoo.com','Abraham Greenman','11811 Dandelion Ln','Houston','TX','UNITED STATES','77071-2608','(281) 881-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 21:32:04',0,NULL,3,1,1,1,NULL,'avro91\r\\'),(2228,697517042011,320394905464,'Acer Aspire 9410 9411 Bluetooth Module 2.0 EDR+cable',1,'BTAC2008',12.5,'eastar4','estherjj','esthertichelaar@hotmail.com','Esther Tichelaar - van der Pijl','Heerenacker 88','Gorredijk','','NETHERLANDS','8401 VJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 21:39:50',0,NULL,3,1,2,1,NULL,'estherjj\racer 4pin1.25 18cm \r\\'),(2229,774874927012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','butz_klauser','butz666@hotmail.com','Florentin BERROD','67 boulevard Pierre Joannon','SAINT CHAMOND','Rhône-Alpes','FRANCE','42400','0664954296','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 22:03:48',0,NULL,3,0,3,1,NULL,'butz_klauser\rOTCR001\rRA022493302CN\r\\'),(2230,774877110012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','techandgolf','techtraderonline@gmail.com','Stephen Rice','2521 Mosswood Drive','Carrollton','TX','UNITED STATES','75010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 22:08:13',0,NULL,3,1,1,1,NULL,'techandgolf\r\\'),(2231,573707995013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','mikipro','sales@mikipro.com','Milutin Ilic','3/770 Beach Rd<br>Browns Bay','Auckland','','NEW ZEALAND','0630','021886854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 22:08:17',0,NULL,3,1,2,1,NULL,'mikipro\r\\'),(2232,774910848012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','johnie89pp','johnie89paypal@gmail.com','Jonathan McDonnell','50 The Priory','Donabate','Co Dublin','IRELAND','0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 23:55:23',0,NULL,3,1,2,1,NULL,'johnie89pp\r\\'),(2233,774919582012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','olive33','tltotzke@gmail.com','Terri Totzke','161 Young Oak Rd','Salt Lake City','UT','UNITED STATES','84108','(435) 659-1131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 00:25:52',0,NULL,3,1,1,1,NULL,'olive33\r\\'),(2234,697569336011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','louiselarson1826','louiselarson1@gmail.com','Louise Larson','636 Londonberry Ln','Bolingbrook','IL','UNITED STATES','60440-1017','(630) 985-3235','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 00:38:32',0,NULL,3,1,1,1,NULL,'louiselarson1826\r\\'),(2235,573733821013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.8,'eastar4','italoleite11','italoreboucas@yahoo.com.br','Ítalo Rebouças','Rua João Paulino Barros Leal, Nº: 2470<br>Bairro: São João do Tauape','Fortaleza','Ceará','BRAZIL','60120-060','+558586311350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 00:40:36',0,NULL,3,1,3,1,NULL,'italoleite11\rMOSA001\rRA022493333CN\r\\'),(2236,774925440012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','levelkro','levelkro@yahoo.ca','Mathieu Légaré','13900 Sherbrooke Est Apt. 25','Montréal','QC','CANADA','h1a 1c4','(514) 642-8748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 00:45:08',0,NULL,3,1,2,1,NULL,'levelkro\racer 6pin1.25 23cm\r、'),(2308,574093716013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','cale_dunbar','caledunbar@gmail.com','Cale Dunbar','150 Saskatchewan Ave.<br>Box 693','Gladstone','MB','CANADA','R0J 0T0','(204) 483-0301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 04:33:06',0,NULL,3,1,2,1,NULL,'cale_dunbar\r、'),(2237,697607796011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','colossus202006','colossus856@hotmail.com','LUIS VARGAS','208 ROSLYN AVE','CARLE PLACE','NY','UNITED STATES','11514-1623','(516) 869-4806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:09:18',0,NULL,3,1,1,1,NULL,'colossus202006\r\\'),(2238,697608156011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dynastywes','dragod@gmail.com','Jay Chao','5200 Canyon Crest Dr<br>Apt 78','Riverside','CA','UNITED STATES','92507-6311','(909) 972-5937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:12:01',0,NULL,3,1,1,1,NULL,'dynastywes\r\\'),(2239,774970468012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','9985samuel','the_warmonger@hotmail.com','Samuel Kerr','#207-831 Ellery St.','Victoria','BC','CANADA','V9A 4R6','(778) 440-1094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 03:23:08',0,NULL,3,1,2,1,NULL,'9985samuel\r\\'),(2240,697612129011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','knickers','quentin5@me.com','Keith Nickerson','1043 Ashland St<br>Apt 2','Houston','TX','UNITED STATES','77008','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 03:28:48',0,NULL,3,1,1,1,NULL,'knickers\r\\'),(2241,774985085012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','jburn116','jburn116@hotmail.com','Jared Burney','54 Larbonya Crescent<br>Capalaba','Brisbane','Queensland','AUSTRALIA','4157','0738231971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:32:19',0,NULL,3,1,3,1,NULL,'jburn116\rHSSH002\rRA022493449CN\r\\'),(2242,774986183012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','speedy570-half','rayrosado@comcast.net','Ray Rosado','7590 S Jackson St','Centennial','CO','UNITED STATES','80122-3542','(303) 316-4119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 04:37:29',0,NULL,3,1,1,1,NULL,'speedy570-half\r\\'),(2243,774988192012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','hungq_pham','joe7pham@gmail.com','Hung Pham/CORNERSTONE PHARMACY LTD.','1,5102 Rundlehorn Drive N.E.','Calgary','AB','CANADA','T1Y1C1','(403) 280-0305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:48:16',0,NULL,3,1,2,1,NULL,'hungq_pham\r\\'),(2244,770919666012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','vinny16jet','vinny16jet@yahoo.com','Tim Gagnier','11401 Dr Martin Luther King Jr St N<br>Apt 715','Saint Petersburg','FL','UNITED STATES','33716-2312','(813) 334-3416','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 05:15:49',0,NULL,3,1,1,1,NULL,'vinny16jet\r\\'),(2245,697634884011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','des.maughan','desmond_maughan@hotmail.com','Desmond Maughan','The Compass Centre (M.2.S)<br>London Heathrow Airport','Hounslow','Middlesex','UNITED KINGDOM','TW6 2GW','07967032077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 05:38:07',0,NULL,3,1,2,1,NULL,'des.maughan\r\\'),(2246,697648938011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','okilinuk','jaberroa@telefonica.net','Javier Alonso Berroa','C/ Legia 42 1º A','Bera','Navarra','SPAIN','31780','948630896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 06:58:03',0,NULL,3,1,2,1,NULL,'okilinuk\r\\'),(2247,527832441004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',15.5,'cnfaner','gt_szamu','kantaluprd@gmail.com','Gabor Szabo','Gardonyi str 15/1','Maklar','Heves','HUNGARY','3397','+3636203551255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 07:10:16',0,NULL,3,1,3,1,NULL,'gt_szamu\r欧标 \rHSNO009\rRA022493435CN\r\\'),(2248,775023114012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',12.5,'eastar4','fratzscher','daniel.fratzscher@gmx.de','Daniel Fratzscher','Schönebecker Weg 50A','Woltersdorf','','GERMANY','15569','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 07:51:01',0,NULL,3,1,2,1,NULL,'fratzscher\r、'),(2249,775024992012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','495283486','ddc443@telenet.be','Dirk De Croes','Royal Museum for Central Africa<br>Leuvensesteenweg 13','Tervuren','','BELGIUM','3080','027695244','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 07:54:58',0,NULL,3,1,3,1,NULL,'495283486\rOTCR001\rRA022493228CN\r\\'),(2250,775034122012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',29.99,'eastar4uk','algirdas_suris','algirdassurgautas@gmail.com','Algirdas Surgautas','Navarsoniu km.<br>Panevezio sen.','Panevezio raj.','LT','LITHUANIA','38365','0037061221808','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 08:35:17',0,NULL,3,1,3,1,NULL,'algirdas_suris\rHSNO019+CCNO001\rRA022493231CN\r\\'),(2251,775054362012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',12.5,'eastar4','itishwang','djhwanghdj@naver.com','Hwang Dojung','10-16 Pil-dong 3-ga, Jung-gu','seoul','','KOREA,REPUBLIC OF','100-273','82-10-4721-5302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 09:59:59',0,NULL,3,1,2,1,NULL,'itishwang\rHP 8pin 1.0 23cm '),(2252,775077008012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',2,'OTIN002',140,'eastar4','qingyuau','sunflower.qingyu@gmail.com','Qing Yu','40/129B Park Road','Rydalmere','New South Wales','AUSTRALIA','2116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:28:09',0,NULL,3,1,3,1,NULL,'qingyuau\rOTIN002\rRA022493673CN\r\\'),(2253,573845296013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','nekromanths','nekromanths@yahoo.gr','george anastasopoylos','MHTROPOLEOS 134','EGIO','AIGIO','GREECE','25100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:37:35',0,NULL,3,1,2,1,NULL,'nekromanths\r欧标\r\\'),(2254,697713289011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','netdl016','vh_nguyen@bigpond.com','Van Nguyen','17 Drake street','Panania','New South Wales','AUSTRALIA','2213','61407007381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:42:59',0,NULL,3,1,2,1,NULL,'netdl016\r\\'),(2255,697714246011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','spaark','v9bahl@gmail.com','Vikram Bahl','2nd Floor, MERLIN HOUSE<br>BELMONT TERRACE','London','Middlesex','UNITED KINGDOM','W4 5UG','07525711976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:45:53',0,NULL,3,1,2,1,NULL,'spaark'),(2256,522132349003,130490915279,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'cnfaner','dancekilkenny','benoghre@hotmail.com','Benjamin Oghre','57B Exning Road','London','London','UNITED KINGDOM','E16 4NE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:59:24',0,NULL,3,1,3,1,NULL,'dancekilkenny\rCACN003\rRA022493775CN\r\\'),(2257,775099515012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','getdoc','gwyntull@hotmail.com','Gwyn Tull','26 Roman Road','Northallerton','North Yorks','UNITED KINGDOM','DL7 9SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 12:46:00',0,NULL,3,1,3,1,NULL,'getdoc\rOTCN003\rRA022493903CN\r\\'),(2258,775112935012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','hennawee','kjtownsend@q.com','Kristie Townsend','170 Joes Way','Bozeman','MT','UNITED STATES','59718-9140','(406) 587-0584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 13:29:00',0,NULL,3,1,1,1,NULL,'hennawee\r\\'),(2259,775120237012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','jeffncsu2002','jeffwatson@hammerpatent.com','Jeff Watson','4684 Dabney Vigor Dr','Charlotte','NC','UNITED STATES','28209-2838','(704) 222-1184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 13:53:57',0,NULL,3,1,1,1,NULL,'jeffncsu2002\r\\'),(2260,775124800012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','yago_project','gerd@justmueller.com','Gerd Müller','Kossuth lajos U 143','Dunabogdany','','HUNGARY','2023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:08:24',0,NULL,3,1,2,1,NULL,'yago_project\r\\'),(2261,697745919011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','posevik','posevik@yandex.ru','Sergey Popov','Igralnaya str. 10, apt. 31','Moscow','','RUSSIAN FEDERATION','107258','(965)416-6006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:33:30',0,NULL,3,1,3,1,NULL,'posevik\rRELO002\rRA022493832CN\r\\'),(2262,775135694012,220743499505,'NEW Genuine Motorola S9 Bluetooth Stereo Headset',1,'HSMO002',31,'eastar4uk','crayonyes','rusmin.wijaya@gmail.com','Rusmin Wijaya','Perum Kosambi Baru Jl. Janur Kuning II FEX 8 No. 7<br>RT.07/15 Duri Kosambi, Cengkareng','Jakarta Barat','DKI Jakarta','INDONESIA','11750','(62)817-805822','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 14:41:55',0,NULL,3,1,3,1,NULL,'crayonyes\rHSMO002\r红色的   挑个好点的\rRA022493687CN\r\\'),(2263,522166728003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','ebrucia74','emanuele@specialimpianti.it','Bruciaferri Emanuele','Via delle Campanelle n.24','Casal Borsetti','RA','ITALY','48123','0544445394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:52:34',0,NULL,3,0,3,1,NULL,'ebrucia74\rHSNO016\r欧标\rRA022493801CN\r、'),(2264,697769760011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','mb_6297','mb_629@hotmail.com','Mary Susong','77 state route 145','Corydon','KY','UNITED STATES','42406-9200','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:01:01',0,NULL,3,1,1,1,NULL,'mb_6297\r\\'),(2265,697770945011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','b-w-matt','info@bwmphoto.com','Brian Matthews','100 Dunbar Road','Hartlepool','Cleveland','UNITED KINGDOM','TS25 5DX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 15:07:44',0,NULL,3,1,2,1,NULL,'b-w-matt\r\\'),(2266,0,220771754733,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','sinhasunil465','sinha.sunil465@gmail.com','sunil sinha','450th CA BN<br>Buld 13, Camp Gibson','APO','AE','AA','09356','0798696601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:22:26',0,NULL,3,1,1,1,NULL,'sinhasunil465\r\\'),(2267,0,230610979551,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.55,'eastar4','ru_battleship','tonywadsworth1@gmail.com','Ann Wadsworth','211 N Kent St','Winchester','VA','UNITED STATES','22601','(540) 667-5131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:23:39',0,NULL,3,1,1,1,NULL,'ru_battleship\r\\'),(2268,0,230610978950,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',8.99,'eastar4','sammydad','pv49erfan@yahoo.com','Darin Nishimura','29610 Stonecrest Rd','Rancho Palos Verdes','CA','UNITED STATES','90275-5714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:36:58',0,NULL,3,1,1,1,NULL,'sammydad\r\\'),(2269,0,220771754732,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',26.99,'eastar4','iluvts','galleonbrian@juno.com','Mark Talbot','384 Howe Ave<br>Unit 3A','Shelton','CT','UNITED STATES','06484-3167','(203) 924-6760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 15:41:14',0,NULL,3,1,1,1,NULL,'iluvts\r\\'),(2270,0,220771754085,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','ckfenterprises','ckfmd@comcast.net','Curtis K Fisher','3261 CYPRESS MARSH DR','FORT MYERS','FL','UNITED STATES','33905-6251','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-19 16:08:50',0,NULL,3,1,1,1,NULL,'ckfenterprises\r\\'),(2271,697802047011,320444514309,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem 3G + antenna',1,'WWOP003+ANCN001',47.95,'eastar4','corsariodance','corsariodance@yahoo.com.ar','Maximiliano Garcia','Ameghino 550','Buenos Aires','Vicente Lopez','ARGENTINA','1603','541147091074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 16:32:09',0,NULL,3,1,3,1,NULL,'corsariodance\rWWOP003+ANCN001\rRA022493846CN\r\\'),(2272,775198501012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','khamaamayama','drakenragendrag@gmail.com','Alexandr Doroshin','14 Filevsky bulvar  App.114','Moscow','Moscow','RUSSIAN FEDERATION','121601','+79269404748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:03:54',0,NULL,3,1,2,1,NULL,'khamaamayama'),(2273,573948761013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','sunshinexeclipse1010011010','sunshinexeclipse@hotmail.com','Kenny Ballou','2041 S Cobalt Point Way<br>POWER Engineers Inc.','Meridian','ID','UNITED STATES','83642-4443','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 18:30:55',0,NULL,3,1,1,1,NULL,'sunshinexeclipse1010011010\r\\'),(2274,697865416011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','gtopinka','topinka@shaw.ca','Greg Topinka','45 Lafleur Drive','St. Albert','AB','CANADA','T8N 7N1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:56:54',0,NULL,3,1,3,1,NULL,'gtopinka\rRELO002\rRA022493850CN\r\\'),(2275,697876174011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','rayrodriguez1976','kriko@aol.com','Raymond  Rodriguez','7201 NW 36th St','Miami','FL','UNITED STATES','33166-6702','(305) 593-0585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:19:00',0,NULL,3,1,1,1,NULL,'rayrodriguez1976\r\\'),(2276,573962753013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','rob_janae','rthomas@weber.k12.ut.us','Robert Thomas','4438 S 1630 W','Roy','UT','UNITED STATES','84067-3010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:09:09',0,NULL,3,1,1,1,NULL,'rob_janae\r\\'),(2277,697883679011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','nieto2007','umpireandrew@hotmail.com','Andrew Nieto','312 Avenue G','Grandview','WA','UNITED STATES','98930-1246','(509) 882-2952','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 19:32:42',0,NULL,3,1,1,1,NULL,'nieto2007\r\\'),(2278,697887062011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','rnbworld','rnb69@yandex.ru','Anton Ilzheev','Novo-Sadovaya<br>house 33 ap. 109','Samara','Samarskay','RUSSIAN FEDERATION','443110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:39:27',0,NULL,3,1,3,1,NULL,'rnbworld\rUDAP001\rRA022493761CN\r\\'),(2279,573974869013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','edwardphantom','edwardphantom@oi.com.br','Eduardo Fernandes Larrubia','Street one, home 310 conjunto campinho, campo grande<br>Rua 1 casa 310 conjunto campinho, Campo grande','Rio de Janeiro','Rio de janeiro','BRAZIL','23067-160','+5521 3407-4026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:42:59',0,NULL,3,1,2,1,NULL,'edwardphantom'),(2280,697894339011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','ardalon11','ardal.okok@gmail.com','mohammadhassan foroughbakhshfasaei','nagytemplom utca 34 b410','budapest','pest','HUNGARY','1082','0036302018230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 19:54:55',0,NULL,3,1,3,1,NULL,'ardalon11\rUDAP001\rRA022493829CN\r\\'),(2281,697904469011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','lienesilovaliene','jurok3@inbox.lv','liene silova','progresa iela 4-32','Riga','','LATVIA','lv-1067','29649881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:17:28',0,NULL,3,1,2,1,NULL,'lienesilovaliene\racer 5pin1.25 4cm \r\\'),(2282,775293817012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','paquette450','andrepaquette60@videotron.ca','André Paquette','322 Clifton','Otterburn Park','QC','CANADA','J3H 1X3','(450) 467-7288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:24:43',0,NULL,3,1,3,1,NULL,'paquette450\rHSPL010\rRA022493789CN\r\\'),(2283,522268319003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','milan28maggio2003','niceforo75@gmail.com','Nicola Niceforo','via orti ovest 4/1','chioggia','VE','ITALY','30015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:35:16',0,NULL,5,0,18,1,NULL,'milan28maggio2003\rRA117739059CN\r、客户嫌慢  已退款'),(2284,697920237011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','longmouse011','longmouse@naver.com','Hansuk Seo','605 W LANIKAULA ST<br>HALE KANILEHUA Rm #202','Hilo','HI','UNITED STATES','96720','808 238 9703','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 20:49:19',0,NULL,3,1,1,1,NULL,'longmouse011\r\\'),(2285,522279592003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','amityes2010','amit.yes@gmail.com','Amit Yeshurun','Echad Ha\'am 18','Akko','','ISRAEL','24706','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 21:10:42',0,NULL,3,1,3,1,NULL,'amityes2010\rHSMO011\rRA022493815CN\r\\'),(2286,574013358013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','ntech12','nickh747@gmail.com','Nicholas Hong','955 Easton Rd<br>Apt G77','Warrington','PA','UNITED STATES','18976','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 21:40:51',0,NULL,3,1,1,1,NULL,'ntech12\r\\'),(2287,775335143012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',2,'HSNO006',59.7,'eastar4','tilchi','claudia.tilch@gmx.de','Claudia Tilch','Veielbrunnenweg 58','Stuttgart','','GERMANY','70372','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 21:55:35',0,NULL,3,1,3,1,NULL,'tilchi\r欧标\r再发两个New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W\rHSNO006+HSNO022\rRA022493792CN\r、'),(2288,522293177003,130490194854,'Genuine Logitech Harmony 880 Universal Remote Control',1,'RCLO002',75.99,'cnfaner','jamesmeeks21','jamesmeeks21@yahoo.com','James Meeks','1009 Sunset Dr','Macon','MO','UNITED STATES','63552-1066','(660) 651-2016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 22:05:35',0,NULL,3,1,1,1,NULL,'jamesmeeks21\r\\'),(2289,574021564013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','lloydr4437','lloyd2you@sc.rr.com','Lloyd Rivers','6816 Valleybrook Rd','Columbia','SC','UNITED STATES','29206-1057','(803) 738-2653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 22:13:20',0,NULL,3,1,1,1,NULL,'lloydr4437 '),(2290,697961484011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','462370','flackandsonltd@hotmail.co.uk','adam flack','56 FORTUNA CLOSE','STEVENAGE','Hertfordshire','UNITED KINGDOM','SG1 5TD','01438214721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 22:44:24',0,NULL,3,1,3,1,NULL,'462370\rHSJA002\r英标\rRA022493713CN\r\\'),(2291,522306748003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','greatstuff4sale2u','yesmayhem@hotmail.com','alecia hill','207 Brighton Ave','east orange','NJ','UNITED STATES','07017','(973) 870-1171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 23:14:35',0,NULL,3,1,1,1,NULL,'greatstuff4sale2u\r\\'),(2292,697985976011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','evaldas777','ed7777@gmail.com','Shalini Nagaraj','2 CRANBERRY CLOSE','LONDON','London','UNITED KINGDOM','UB5 5PS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 00:15:17',0,NULL,3,1,2,1,NULL,'evaldas777\r英标'),(2293,528062665004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','fay54321','kiran.mir@live.lagcc.cuny.edu','Faiza Mir','30 Horizon Hill Rd','Newington','CT','UNITED STATES','06111-5115','(860) 518-7504','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 00:34:14',0,NULL,3,0,1,1,NULL,'fay54321\r\\'),(2294,697991541011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',2,'HSMO017',41.98,'eastar4','abbynormal2','abbynormal79@yahoo.com','Abby Cline','1191 Old Stage Rd','Decorah','IA','UNITED STATES','52101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 00:45:36',0,NULL,3,1,1,1,NULL,'abbynormal2\r\\'),(2295,775386642012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','reefvan','reefvan@hotmail.com','L.A Van Vlaardingen','7031 des Glaieuls','Saint Hubert','QC','CANADA','J3Y8R9','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 00:46:55',0,NULL,3,0,2,1,NULL,'reefvan\r\\'),(2296,574055742013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','nala290586','c-crites@hotmail.com','Christine L Crites','PO BOX 731','Bushell Park','SK','CANADA','S0H 0N0','(306) 631-2759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 01:03:41',0,NULL,3,1,2,1,NULL,'nala290586'),(2297,574059864013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','pennyjbrown66','prwoodard70@aol.com','Penny Woodard','6300 Brownsville Rd','Lithia Springs','GA','UNITED STATES','30122-1001','(678) 472-6071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 01:26:02',0,NULL,3,1,1,1,NULL,'pennyjbrown66\\'),(2298,698010710011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','jawn_619','jawn619@gmail.com','John Chen','559 Carlton Ave','Bethlehem','PA','UNITED STATES','18015-2945','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 01:50:49',0,NULL,3,1,1,1,NULL,'jawn_619\r\\'),(2299,698014625011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','codywilson36','annwilson@frontiernet.net','Mike Wilson','Po box 399','McArthur','CA','UNITED STATES','96056-0399','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 02:06:12',0,NULL,3,1,1,1,NULL,'codywilson36\r\\'),(2300,574072797013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','oakbending52','jwking4@yahoo.com','j king','23508 Bending Oak Ct','murrieta','CA','UNITED STATES','92562-3304','(951) 304-2037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 02:23:38',0,NULL,3,1,1,1,NULL,'oakbending52\r\\'),(2301,522341707003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','ericsewnsew','eheikell@msn.com','Mary Rathbun','11405 E Stoughton Rd','Valleyford','WA','UNITED STATES','99036-8536','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 02:28:55',0,NULL,3,1,1,1,NULL,'ericsewnsew\r\\'),(2302,775418942012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','victor57889','vicrxs@hotmail.com','Victor Xavier da Silveira','Rua Benjamin Constant, 26 bloco 13/303','Niterói','Rio de Janeiro','BRAZIL','24110002','552182360965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 02:40:07',0,NULL,3,1,3,1,NULL,'victor57889\r美标 \rMOMI001\rRA117739045CN\r\\'),(2303,775420365012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','davebee100','dkb100@hotmail.co.uk','DAVE BARRETT','53/10 MOO 7, SOI THEPNIMIT, NONGPLALAI','BANGLAMUNG','CHONBURI','THAILAND','20150','006638170816','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 02:44:28',0,NULL,3,1,3,1,NULL,'davebee100\rOTRA002\rRA117739028CN\r、'),(2304,698025807011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','andriy.t','andriy_bmw@yahoo.com','Andriy Tytarenko','28 Riverwood Prky. Apt.# 703','Toronto','ON','CANADA','M8Y 4E2','(416) 357-5054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 02:53:49',0,NULL,3,1,2,1,NULL,'andriy.t'),(2305,0,220771754086,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','hotrod5071','af30@sbcglobal.net','Melvin Jenkins','7518 Kleberg','San Antonio','TX','UNITED STATES','78250','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 03:22:25',0,NULL,3,1,1,1,NULL,'hotrod5071\r\\'),(2306,528096132004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','krazzyoutlaw69','krazzyoutlaw@hotmail.com','Duane Jackson','18240 N 400 W','Wheatfield','IN','UNITED STATES','46392-8941','(219) 996-7569','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 03:37:25',0,NULL,3,1,1,1,NULL,'krazzyoutlaw69\r\\'),(2307,698040782011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','mobiles_and_extras','dthompson@mobileextras.com.au','Yaqum Pty. Ltd.','P.O. Box 1057','Osborne Park','Western Australia','AUSTRALIA','6917','0892424511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 04:07:15',0,NULL,3,1,2,1,NULL,'mobiles_and_extras\r澳标'),(2309,775450508012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','capriscanmalaysia','marco.muehlemann@gmail.com','Marco Muehlemann','Stoppani Malaysia Sdn. Bhd.<br>Plot 12 & 13, Phase 4, FIZ Hilir Sg. Keluang 3','Bayan Lepas','Penang','MALAYSIA','11900','0123101105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 05:06:01',0,NULL,3,1,3,1,NULL,'capriscanmalaysia\rMOMI001\r美标\rRA117739969CN\r、'),(2310,528107685004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','ka6zzl','mtosch@verizon.net','Mike Tosch','1089 Waverly Heights Dr','Thousand Oaks','CA','UNITED STATES','91360-5052','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 05:11:46',0,NULL,3,1,1,1,NULL,'ka6zzl\r、'),(2311,698061216011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','t3r3e3y','terlegy@gmail.com','Trey Gomes','8340 Wickham Rd','Springfield','VA','UNITED STATES','22152-1739','(804) 266-5419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 06:02:50',0,NULL,3,1,1,1,NULL,'t3r3e3y\\'),(2312,574104205013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',6,'HSPL001',70.8,'eastar4','lamplady327','elainefhayes327@yahoo.com','Jymmie Siebert','2250 N. Rock Rd<br>Suite # 118-186','Wichita','KS','UNITED STATES','67226-2331','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 06:10:41',0,NULL,3,1,1,1,NULL,'lamplady327\r、'),(2313,522374497003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','octow1983','octow83@hotmail.com','octavio blanco','1333 s briar cir','mesa','AZ','UNITED STATES','85204-6144','(480) 248-0041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 06:27:44',0,NULL,3,1,1,1,NULL,'octow1983\r、'),(2314,573033321013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','der.fisch','arctanh@gmail.com','Zimmermann Hannes','Trottenstrasse 73','Zürich','','SWITZERLAND','8037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:53:12',0,NULL,3,1,2,1,NULL,'der.fisch\r、'),(2315,775471175012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','skatpul','nicottscole@gmail.com','Scott Poole','610-1483 Lamey\'s Mill Road<br>(Buzzer 175 or leave at office)','Vancouver','BC','CANADA','V6H 3Y7','(604) 732-0302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:54:03',0,NULL,3,1,2,1,NULL,'skatpul\r\\'),(2316,775469274012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','mantoh','vhm1206@zoho.com','Henky Mantophani','VIPAC Engineers<br>2 Sirius Road','Lane Cove','New South Wales','AUSTRALIA','2066','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 06:57:05',0,NULL,3,1,2,1,NULL,'mantoh\r澳标  \r\\'),(2317,697776376011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',29.8,'eastar4uk','kippschein','uwe.brehm@gmx.de','Uwe Brehm','Brehm\'s Containerservice<br>Siedlung 3','Liebenwalde','','GERMANY','16559','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 07:16:46',0,NULL,3,1,3,1,NULL,'kippschein\r欧标 \rHSJA002\rRA117739972CN\r、'),(2318,775482383012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','drcharleslee','charleslee2006@fastmail.fm','Charles Lee','527 Stuyvesant Ave<br>Fl 1','Lyndhurst','NJ','UNITED STATES','07071-2627','(201) 765-0552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 07:44:26',0,NULL,3,1,1,1,NULL,'drcharleslee\r、'),(2319,698090599011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','trentnewton','trent@truclean.com.au','Trent Newton','Unit 2, 659 Boundary Road','Richlands','Queensland','AUSTRALIA','4077','61733755415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:33:38',0,NULL,3,1,2,1,NULL,'trentnewton\r、'),(2320,528135378004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','u4studio','stasufo@gmail.com','Prokhodtsev Stanislav','pr. Molodezhniy 9-329','Kemerovo','Kemerovo','RUSSIAN FEDERATION','650070','+79236104422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:44:49',0,NULL,3,1,3,1,NULL,'u4studio\rOTRA002\r\rRA117716407CN\r\\'),(2321,574128358013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','n2odnb','n2odnb@hot.ee','Vadim Knut','Ilmatsalu 8-8','Tartu','Tartumaa','ESTONIA','50408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 08:50:42',0,NULL,3,1,2,1,NULL,'n2odnb\r、'),(2323,574139799013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.48,'eastar4','tundrurat','deepgaze@mail.ru','Rustem Zakirov','Lenina<br>Dom 28, Kv. 32','Pervomayskiy','Kirovskaya oblast','RUSSIAN FEDERATION','613648','+79127098749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:05:27',0,NULL,3,1,2,1,NULL,'tundrurat\r欧标\r、'),(2324,528154079004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','hong1983','wai_hongwong@hotmail.com','Wai  Wong','Statistics House,<br>The Boulevard, Harbour Quays','Wellington','','NEW ZEALAND','6140','006444782162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:49:33',0,NULL,3,1,3,1,NULL,'hong1983\rBALO007\rRA117728189CN\r\\'),(2325,775526564012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','pawansher2002','pawansher2002@gmail.com','PAWAN SEHRAWAT','Voltas Ltd, (UPBG)<br>Plot no 2 to 5, sector -8, SIDCUL - Pantnagar','Rudrapur','UL','INDIA','263153','919760695285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:50:41',0,NULL,3,1,2,1,NULL,'pawansher2002\r\\'),(2326,775527913012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','helenamayo','helenaredwalsh@yahoo.com','Helena Walsh','7 Tower View','Ballinrobe','Mayo','IRELAND','0','0861034748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:55:40',0,NULL,3,1,2,1,NULL,'helenamayo\r英标\r、'),(2327,574151761013,230510752651,'NEW GENUINE NOKIA BH-209 BLUETOOTH HEADSET BH 209',1,'HSNO011',19.99,'eastar4','braxos21-2009','braxos21@hotmail.com','Charitakis Stavros','L. Dimokratias 153','Pireus','Perama','GREECE','18863','6947093593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 11:15:21',0,NULL,3,1,2,1,NULL,'braxos21-2009\r欧标\r\\'),(2328,775552002012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','usasig1','usasig@hotmail.com','Sinan Asig','400 E 85th St<br>Apt 9K','New York','NY','UNITED STATES','10028-6319','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 12:22:39',0,NULL,3,1,1,1,NULL,'usasig1\rMX20T\r、'),(2329,775552278012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','iam732','cute732@daum.net','Jeon, Cheol-sang','3F Computer Information Division,<br>Eunpyeong-gu Office, 84, Nokbeon-dong,','Eunpyeong-gu,','Seoul','KOREA,REPUBLIC OF','122-702','010-2361-7325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:24:28',0,NULL,3,1,2,1,NULL,'iam732\r\\'),(2330,662497762001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','hczabala625','hczabala@gmail.com','HONG-CHAU ZABALA','6715 Vinevale Ave','BELL','CA','UNITED STATES','90201-2642','(714) 943-6978','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 12:29:19',0,NULL,3,1,1,1,NULL,'hczabala625\rLK042164711CN\r、'),(2331,698154259011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','markrowantree','markrowantree@hotmail.com','mark rowantree','139 bellahouston drive<br>mosspark','glasgow','scotland','UNITED KINGDOM','g52 1hl','01418838207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:51:37',0,NULL,3,1,2,1,NULL,'markrowantree\r、'),(2332,698153720011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',18.99,'eastar4','lokydm','dsmolyakow@gmail.com','Dmitriy Smolyakow','Revytsky st. 17b, appartment 26','Kiev','','UKRAINE','02091','380674474576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 12:53:51',0,NULL,3,1,2,1,NULL,'lokydm\r\\'),(2333,698153617011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',3,'CASS001',26.1,'eastar4','szhu0618','sam.junzhu@gmail.com','Jun Zhu','123 George Street','Scoresby','Victoria','AUSTRALIA','3179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 13:00:18',0,NULL,3,1,2,1,NULL,'szhu0618\r、'),(2334,696505741011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tunnelinghorror','msweetser87@hotmail.com','Michael sweetser','3814 Calibre Bend Ln<br>Apt 1412','winter park','FL','UNITED STATES','32792-8674','(402) 613-7821 ext.: 4026137821','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 13:04:56',0,NULL,3,1,1,1,NULL,'tunnelinghorror\r、'),(2335,574182900013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',35.94,'eastar4','scobako','junior4430@gmail.com','Alexandr Danilov','Zakrevskogo street, 35A, Apt (kvart) 134','Kiev','UA','UKRAINE','02217','+ 38 050 440 30 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 13:52:28',0,NULL,3,1,3,1,NULL,'scobako\rWLAT001+WLIN010\r再发一个New Intel 5300 AGN Wireless Network Mini PCI-E Card\rRA117728175CN\r、'),(2336,698177942011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','shualf','shaulfl@gmail.com','shaul fellah','haroe 275','ramat gan','Israel','ISRAEL','52292','036782899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 14:14:47',0,NULL,3,1,2,1,NULL,'shualf\r、'),(2337,775587058012,220448688645,'Acer Aspire 4730 4930 Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','lexnem1','lex_nem@mailbolt.com','Alexei Nemov','Alpiyskiy pereulok 19 kor 1 kv 56','Saint-Petersburg','','RUSSIAN FEDERATION','192239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 14:17:22',0,NULL,3,1,2,1,NULL,'lexnem1\racer 8pin1.00 6cm\r\\'),(2338,574191080013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','203samiriss23','samiriss29@hotmail.com','samira bouderka','17 Fairfield Ave<br>Apt 31','norwalk','CT','UNITED STATES','06854-2156','(203) 551-0003','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-20 14:26:09',0,NULL,3,1,1,1,NULL,'203samiriss23\r、'),(2339,698187276011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','jjgncmg','jeff@jeffnclaudette.com','Jeffrey J. Gerdjunis','440 Michigan St','Ronkonkoma','NY','UNITED STATES','11779','(516) 408-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 14:46:49',0,NULL,3,1,1,1,NULL,'jjgncmg\r、'),(2340,574200308013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','alain930','alain.rioux@live.ca','Alain Rioux','945 des Cimes','Ste-Adele','QC','CANADA','J8B1M7','(450) 229-2410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 15:06:04',0,NULL,3,1,2,1,NULL,'alain930\r、'),(2341,574201057013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','63_sergio','pokelon3@hotmail.com','Sergio Flores V','Juan Jose Baz # 168 Colonia Chapultepec Oriente<br>Esquina Anastacio Cerezero','Morelia','Michoacánl','MEXICO','58260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 15:09:28',0,NULL,3,1,2,1,NULL,'63_sergio\r、'),(2342,698202479011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.7,'eastar4','earweed','irvinearweed@hotmail.com','William Ware','9850 Kalae St','Diamondhead','MS','UNITED STATES','39525-4425','(205) 237-4782','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-20 15:32:35',0,NULL,3,1,1,1,NULL,'earweed\r、'),(2343,0,230611726958,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',15.05,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 15:43:10',0,NULL,3,1,1,1,NULL,'4278dennis\r、'),(2344,775625129012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',2,'MOLO002',77.8,'eastar4','kebekbutcher','mykeldumasdemers@hotmail.com','Mykel Dumas Demers','57 des Quatre-Vents','Asbestos','QC','CANADA','J1T 4N6','(819) 879-5643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:05:48',0,NULL,3,1,3,1,NULL,'kebekbutcher\rMOLO002\rRA117728351CN\r\\'),(2345,698222778011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.8,'eastar4','rbar2385','r.barnett01@rogers.com','Robert Barnett','155 Arundel Ave','Toronto','ON','CANADA','M4K 3A7','(416) 423-1515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:29:18',0,NULL,3,1,2,1,NULL,'rbar2385\racer 8pin1.00 8cm \r\\'),(2346,522468214003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','iggypla','plaig@musc.edu','Ignacio Pla','1216 Walleye Cor','Charleston','SC','UNITED STATES','29414-9129','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 16:51:35',0,NULL,3,1,1,1,NULL,'iggypla\r、'),(2347,775644296012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',29.99,'eastar4uk','kanareika_artem','avtor_fr@mail.ru','Artem Skripalschikov','yl. S.Lazo, d. 15, kv. 85','Orenburg','Orenburg region','RUSSIAN FEDERATION','460044','+79225306773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 16:57:19',0,NULL,3,1,3,1,NULL,'kanareika_artem\rHSNO019+CCNO001\rRA022493727CN\r\\'),(2348,775672786012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','8518steven','howatssw@yahoo.com','Steven Howatson','224- 95 Highfield Park Drive','Dartmouth','NS','CANADA','B3A4V1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:56:04',0,NULL,3,1,2,1,NULL,'8518steven\r\\'),(2349,698257686011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','loizos88','harusloizos@gmail.com','Loizos Charous','gravias 31 aradippou<br>kapellos court 002','Larnaka','','CYPRUS','7102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:56:54',0,NULL,3,1,2,1,NULL,'loizos88\r\\'),(2350,775673713012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',4,'HSPL011',92,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:58:10',0,NULL,3,1,3,1,NULL,'solopo2009\rHSPL011  \r只发耳机和USB cable不给adapter\rRA117728161CN\r\\'),(2351,775676488012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','dnsnetworks','shawn.ebbs@dnsnetworks.ca','Shawn Ebbs','1122 Wellington St West','Ottawa','ON','CANADA','K1Y2Y7','(819) 664-8895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:01:02',0,NULL,3,1,3,1,NULL,'dnsnetworks\rHSSH002\rRA117728250CN\r'),(2352,574259259013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','elestor','nestor.zuleta.l@gmail.com','Nestor Zuleta Lopez','Blas Segundo Tellez  0246<br>Villa Carlos Condell','Tocopilla','Tocopilla / Provincia Tocopilla / II Region','CHILE','1340000 ','055-819402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:27:13',0,NULL,8,1,17,1,NULL,'elestor'),(2353,522515068003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',2,'HSSE004',43.8,'cnfaner','elestor','nestor.zuleta.l@gmail.com','Nestor Zuleta Lopez','Blas Segundo Tellez  0246<br>Villa Carlos Condell','Tocopilla','Tocopilla / Provincia Tocopilla / II Region','CHILE','1340000 ','055-819402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:28:25',0,NULL,3,1,3,1,NULL,'elestor\rHSSE004\r再发一个New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W\r潘'),(2354,698283958011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','jonnytii','jon.taylor@jba.aero','Jonathan Taylor','2119 Woodstream Dr','Kingwood','TX','UNITED STATES','77339-3332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 18:51:07',0,NULL,3,1,1,1,NULL,'jonnytii\r、'),(2355,698288419011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','bule777','linda.tamplin@googlemail.com','Linda   Tamplin','High Carston, Ochiltree','Cumnock','East Ayrshire','UNITED KINGDOM','KA18 2RY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 19:00:01',0,NULL,3,1,3,1,NULL,'bule777\rRA117728232CN\r\\'),(2356,522533981003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','johnniejldjr98','jldjr98@yahoo.com','JOHNNIE DAVIS','7837 Carrie St','DETROIT','MI','UNITED STATES','48211-1701','(313) 778-9961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 19:27:45',0,NULL,3,1,1,1,NULL,'johnniejldjr98\r、'),(2357,698319881011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.8,'eastar4','andre-cz','andrecz@seznam.cz','Bohumil Polák','M. Malého 164','Hradec Králové','Czech republic','CZECH REPUBLIC','503 01','+420602110593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:05:00',0,NULL,3,1,2,1,NULL,'andre-cz\rHP 8pin 1.25 18cm \r\\'),(2358,698326550011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','biasicabral','biasicabral@gmail.com','Marcelo Biasi Cabral','SHN Quadra 02 Bloco H, S/N - AP 1701<br>Setor Hoteleiro Norte','Brasilia','Distrito Federal','BRAZIL','70702-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:23:03',0,NULL,3,1,3,1,NULL,'biasicabral\rOTRA002\rRA117716322CN\r\\'),(2359,574307062013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','freezed23','pys2314@naver.com','Young Soo Park','Buyeong 6 Danji Apt., Hwasun-eup<br>603-906','Hwasun-gun','Jeollanam-do','KOREA,REPUBLIC OF','519-756','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 20:42:12',0,NULL,3,1,2,1,NULL,'freezed23\r\\'),(2360,775762438012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','rwoo6629','randy@graass.com','Randall Woodum','8926 Pitner','Houston','TX','UNITED STATES','77080','(713) 554-3755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 20:48:25',0,NULL,3,1,1,1,' ','rwoo6629\r、'),(2361,698348358011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',12.5,'eastar4','techconsignments','es.mpyre@gmail.com','TechConsignments','23502 Earlmist Dr','Spring','TX','UNITED STATES','77373-6251','(561) 541-8028','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:12:39',0,NULL,3,1,1,1,NULL,'techconsignments\rHP 8pin 1.0 23cm \r、'),(2362,0,320687956849,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','brandon0404','brandonknox4@yahoo.com','Brandon D. Knox','9008 Topperwind Ct','Fort Worth','TX','UNITED STATES','76134-5501','(817) 703-8468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:47:09',0,NULL,3,1,1,1,NULL,'brandon0404\r、'),(2363,775787525012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',31.98,'eastar4','soulovey','tsv83@mail.ru','Vasili Tsoukanov','Prospekt Vernadskogo, 89-199','Moscow','','RUSSIAN FEDERATION','119526','+7-910-4003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 21:54:01',0,NULL,3,1,3,1,NULL,'soulovey\rWLIN004\rRA117728348CN\r\\'),(2364,698364032011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bergkamp2','bergkamp1414@hotmail.com','Je Hyun Park','550 S Camino Seco<br>Apt 2206','Tucson','AZ','UNITED STATES','85710-4061','(520) 334-9243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 21:59:45',0,NULL,3,1,1,1,NULL,'bergkamp2\r、'),(2365,775795590012,220713846376,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+carcharger',1,'HSNO016+CCNO001',13.9,'eastar4uk','mmaounn','info@autostern.at','Mohammed Aoun','Erzherzog-Karlstrasse 33-3-21','Wien, AUSTRIA','','AUSTRIA','1220','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 22:17:28',0,NULL,3,1,2,1,NULL,'mmaounn\r、'),(2366,775808848012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','rgie1851','giese@versacall.com','Robert Giese','14031 Recuerdo Dr.','Del Mar','CA','UNITED STATES','92014','(858) 677-6766 ext.: 100','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 22:59:22',0,NULL,3,1,1,1,NULL,'rgie1851\r、'),(2367,698385164011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','hoangtrunghieu','hoang8@marshall.edu','Hieu Hoang','209 19TH ST<br>Apt 2','huntington','WV','UNITED STATES','25703-1144','(304) 972-1987','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:11:35',0,NULL,3,1,1,1,NULL,'hoangtrunghieu\r、'),(2368,574346910013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','vasupplies','vasupplies@hotmail.com','Rolando Barbosa','5300 NW 33rd Ave<br>Ste 218','Fort Lauderdale','FL','UNITED STATES','33309-6356','(954) 485-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:31:17',0,NULL,3,1,1,1,NULL,'vasupplies\r、'),(2369,574347344013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',3,'HSPL005',40.5,'eastar4','kirolos_emad2003','kirolos_emad2003@yahoo.com','emad ghobiral','1960 srobertson blvd #4','los angeles','CA','UNITED STATES','90034','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-20 23:33:32',0,NULL,3,1,1,1,NULL,'kirolos_emad2003\r、'),(2370,698405156011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','atillat2007','atitaskan@aol.com','Atilla Taskan','20 Beachside court','Victoria Point','Queensland','AUSTRALIA','4165','0732078617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 00:33:29',0,NULL,3,1,2,1,NULL,'atillat2007\r澳标\\'),(2371,775837085012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',35.99,'eastar4','andesigns','anhayes27@gmail.com','Mulberry Cottage/Ashley Hayes','46 main st','Nashville','IN','UNITED STATES','47448','(812) 325-3824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 00:46:51',0,NULL,3,1,1,1,NULL,'andesigns\r、'),(2372,528351341004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',3,'HSPL010',74.97,'cnfaner','scarlettsewing','scarlettsm0m@aol.com','Dana Hallock','537 Silver Canyon Way','Brea','CA','UNITED STATES','92821','(714) 671-2067','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 00:50:34',0,NULL,3,1,1,1,NULL,'scarlettsewing\r、'),(2373,698419288011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','2131morgan','mdminor@sympatico.ca','Morgan Minor','229 Sugarloaf Street','Port Colborne','ON','CANADA','L3K 2N9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 01:29:54',0,NULL,3,1,2,1,NULL,'2131morgan\r\\'),(2374,574376101013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','ibgoodok','ibgoodok@yahoo.com','John Dicks','1018 Huggins Bottom Rd','Guys','TN','UNITED STATES','38339','(731) 645-0907','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:09:44',0,NULL,3,1,1,1,NULL,'ibgoodok\rHP 8pin 1.0 23cm \r、'),(2375,663058265001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','princarl4','tprince68028@yahoo.com','Tricia Prince','10701 S 210th St','Gretna','NE','UNITED STATES','68028-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:30:12',0,NULL,3,1,1,1,NULL,'princarl4\rLK042164075CN \r、'),(2376,775867998012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','vangofar','kadams1015@hotmail.com','KENNETH ADAMS','1027 Mabry Mill Rd','HOUSTON','TX','UNITED STATES','77062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 02:30:55',0,NULL,3,1,1,1,NULL,'vangofar\r、'),(2377,698442241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','m3t4lh34d_6','kyleswentowsky@hotmail.com','Kyle Swentowsky','8231 Phasis Ct','Elverta','CA','UNITED STATES','95626-9697','(916) 991-1888','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','m3t4lh34d_6'),(2378,573718729013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','eatsumcheese','amaznw@gmail.com','Nathan Waxman','4142 Verona Rd','South Euclid','OH','UNITED STATES','44121-3110','(216) 688-6568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:25:40',0,NULL,3,1,1,1,NULL,'eatsumcheese\r、'),(2379,574394806013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','meka80hood','shood1980@yahoo.com','Shameka Hood','2242 Avalon Trce','Winder','GA','UNITED STATES','30680-7810','(678) 963-2747','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:51:51',0,NULL,3,1,1,1,NULL,'meka80hood\r、'),(2380,574396469013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','arendsii','yanyanw@gmail.com','Yan Yan Wang','2335 Branner Dr','Menlo Park','CA','UNITED STATES','94025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 03:56:26',0,NULL,3,1,1,1,NULL,'arendsii\r、'),(2381,574322869013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','robbie5354','robert.may1984@yahoo.com.au','Robert Mayne','20 Langley Street','Warrnambool','Victoria','AUSTRALIA','3280','0355005254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 03:58:32',0,NULL,3,1,2,1,NULL,'robbie5354\r\\'),(2382,775889108012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','jackrbmac','jdmcdowell@verizon.net','John McDowell','28504 Robinview Ln','Rancho Palos Verdes','CA','UNITED STATES','90275-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 04:05:22',0,NULL,3,1,1,1,NULL,'jackrbmac\r蓝牙版的\r、'),(2383,528386264004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','akvara','akvara@gmail.com','Andrius Kvaraciejus','Paribio 28-37','Vilnius','','LITHUANIA','LT08103','(370) 685 55031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 04:27:59',0,NULL,3,1,3,1,NULL,'akvara\r欧标  \rHSNO005\rRA117728303CN\r\\'),(2384,698458964011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','maxzx123','maxzx@bk.ru','Maxim Mukhin','1-st Kommunisticheckaya, 37-47','Domodedovo','','RUSSIAN FEDERATION','142000','+79263740458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 04:36:38',0,NULL,3,1,2,1,NULL,'maxzx123\r、'),(2385,775657769012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','avedana01','olsan@gmx.de','Olaf Sandelmann','Richard-Münch-Str. 7','Berlin','','GERMANY','13591','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:06:27',0,NULL,3,1,2,1,NULL,'avedana01\racer 4pin1.25 8cm\r、'),(2386,574417712013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','visionmax333','corey@baudinette.com','Corey Baudinette','2/297 Wellington St','Collingwood','Victoria','AUSTRALIA','3066','0412345246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:45:36',0,NULL,3,1,3,1,NULL,'visionmax333\rMOSA002\rRA022493744CN\r、'),(2387,775919470012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',4,'OTSO002',303.6,'eastar4','banaszysko','piotr@progress.com.pl','Piotr Banach','Al. Mickiewicza 27','Kraków','małopolskie','POLAND','31120','662 035272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:49:44',0,NULL,3,1,12,1,NULL,'banaszysko\r潘\\'),(2388,698488976011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','ablindman','kirbymaster6@gmail.com','George Turba','601 W 10th St<br>202 Mcanerney Hall','Rolla','MO','UNITED STATES','65401-2966','(815) 630-0173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 07:31:33',0,NULL,3,1,1,1,NULL,'ablindman\r、'),(2389,574429564013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',2,'MOSA001',143.6,'eastar4','quellenfeuer','quellenfeuer@gmx.de','Stephan Boes','Passauer Str. 48','Wegscheid','','GERMANY','94110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 08:11:37',0,NULL,3,1,3,1,NULL,'quellenfeuer\rMOSA001\r\rRA117716543CN\r\\'),(2390,698516540011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','arnisg123','arnis@specialsolutions.lv','Arnis Glaznieks','Volguntes 38-2','Riga','Vidzeme','LATVIA','LV1046','+37126517859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 09:46:26',0,NULL,3,1,2,1,NULL,'arnisg123\r、'),(2391,775963068012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','grlgf','graham_langford@btinternet.com','Graham Langford','69 Grove Rd','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 1EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 10:10:35',0,NULL,3,1,3,1,NULL,'grlgf\rOTRA002\rRA117716398CN\r\\'),(2392,574449301013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','miker1804','michael.rogovin@gmail.com','Michael Rogovin','5 Ha’Solelim Street','Tel Aviv','','ISRAEL','67897','052-6402514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:25:19',0,NULL,3,1,2,1,NULL,'miker1804\r\\'),(2393,775968300012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',3,'WLDL001',17.25,'eastar4uk','philo69us','philwells@screaming.net','philip wells','11 south rise<br>north walsham','norwich','Norfolk','UNITED KINGDOM','nr280ee','01692409877','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 10:34:10',0,NULL,3,1,3,1,NULL,'philo69us\rWLDL001\rRA117716438CN\r\\'),(2394,698530088011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',20,'eastar4','dodgly','ebay@lyledodge.com','Lyle E. Dodge','1000 SE Everett Mall Way<br>Suite 301','Everett','WA','UNITED STATES','98208-2814','(425) 355-7223 ext.: 119','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-21 10:47:05',0,NULL,3,1,1,1,NULL,'dodgly\r\\'),(2395,528435131004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',13.99,'cnfaner','magdavlad1987','magdavlad@yahoo.gr','Magdalini Vladeni','Papadiamanti 3','Thessaloniki','Thessaloniki','GREECE','55133','6973640704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:52:12',0,NULL,3,1,3,1,NULL,'magdavlad1987\rBTAC2104\racer 4pin1.25 6cm\rRA117716441CN\r\\'),(2396,698533418011,320679610517,'New GENUINE NOKIA BH-106 BLUETOOTH HEADSET',2,'HSNO004',26.7,'eastar4uk','sotnats2682','snatsios@yahoo.gr','sotiris natsios','kuprou 64 A','Preveza','Preveza','GREECE','48100','2682046209','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 10:59:57',0,NULL,3,1,3,1,NULL,'sotnats2682\rHSNO004\r欧标\rRA117716490CN\r\\'),(2397,775980986012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',35,'eastar4','curtb','curtbebay@embarqmail.com','Curt Boyles','1231 Whitewood Way','Clermont','FL','UNITED STATES','34714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 11:24:39',0,NULL,3,1,1,1,NULL,'curtb\r\\'),(2398,528442432004,140516076074,'Logitech MX518 MX 518 Gaming Optical USB Mouse track#',1,'MOLO003',32.9,'cnfaner','manal0_0','regnarga001@hotmail.com','AlainGranger','950 Samoisette','St-Jean sur Richelieu','QC','CANADA','J3B2J4','(450) 348-4403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:41:45',0,NULL,3,1,3,1,NULL,'manal0_0\rMOLO003\rRA117716375CN\r\\'),(2399,775986248012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','cozpyro','colinnolan1975@hotmail.com','Colin Nolan','12 Lower Hatch Street','Dublin 2','Dublin','IRELAND','D2','0872705866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:43:45',0,NULL,3,1,3,1,NULL,'cozpyro\rHSSH002\rRA117716455CN\r\\'),(2400,528443560004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','andrey1771','auto4u2005@yahoo.com','Andrey Prokhorov','1707 Scotchbrook Dr<br># A','Philadelphia','PA','UNITED STATES','19115-4286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 11:47:19',0,NULL,3,1,1,1,NULL,'andrey1771\r\\'),(2401,574465655013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','claus_74','claus.herholz@gmx.de','Claus Herholz','G-v-Mevissen-Str. 108','Siegen','','GERMANY','57072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:58:44',0,NULL,3,1,2,1,NULL,'claus_74\r\\'),(2402,774847302012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.05,'eastar4','cisco_racks','marca_alexander@yahoo.com','Marc Alexander','5980 Folkstone Ln','Orlando','FL','UNITED STATES','32822-9423','(407) 489-4672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 13:28:52',0,NULL,3,1,1,1,NULL,'cisco_racks\r\\'),(2403,776018808012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','jakeyboi19942010','jakey-boi1994@live.co.uk','Jake king','2 Hathaway court<br>rainham','Gillingham','Kent','UNITED KINGDOM','me8 0es','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 13:40:21',0,NULL,3,1,3,1,NULL,'jakeyboi19942010\rWLDL001\rRA117716367CN\r\\'),(2404,0,230611726649,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','tylerssmile','lara20226@gmail.com','Lara M Ocasio','2695 Cedar Ct','OCEANSIDE','NY','UNITED STATES','11572','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-21 13:57:50',0,NULL,3,1,1,1,' ','tylerssmile\r\\'),(2405,776029593012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','booooster2009','h.kl@live.com','hafez alam','8 hilbre walk','reading','Berkshire','UNITED KINGDOM','rg2 0gd','07966675244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 14:14:29',0,NULL,3,1,3,1,NULL,'booooster2009\r英标\rHSPL011\rRA117716384CN\r\\'),(2406,698587638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','karhotom','karhotom@gmail.com','Kar Ho Tom','4075 rue Laubia','Brossard','QC','CANADA','J4Y 0H3','(514) 884-3088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 14:26:20',0,NULL,3,1,2,1,NULL,'karhotom\r\\'),(2407,574500437013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','jplasater','jklasater@centurytel.net','John Lasater','22707 W Spring Harbor Rd','Siloam Springs','AR','UNITED STATES','72761','(479) 549-7271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 14:53:59',0,NULL,3,1,1,1,NULL,'jplasater\r\\'),(2408,698603377011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',43.9,'eastar4','mario_murillo2002','mario_murillo2002@yahoo.com','mario murillo','625 w market st','salinas','CA','UNITED STATES','93901','(831) 229-5621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 15:17:49',0,NULL,3,1,1,1,NULL,'mario_murillo2002\r\\'),(2409,698606546011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',24.59,'eastar4uk','valbuena_62','myaudi@hotmail.fr','Antoine Rault','25 rue des Haguettes<br>Raventhun','Ambleteuse','Nord-Pas-de-Calais','FRANCE','62164','03.21.32.60.04','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:29:50',0,NULL,3,1,3,1,NULL,'valbuena_62\rUDAP001\rRA117716424CN\r\\'),(2410,698610069011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gmaragoudlfc','gmaragoud@gmail.com','George Maragoudakis','K.Gerakari 8','Rethymno','Creta','GREECE','74100','283-107-2962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:38:43',0,NULL,3,1,2,1,NULL,'gmaragoudlfc\r、'),(2411,574469827013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.99,'eastar4','vstaran','vtipok89@gmail.com','Victor Staranchuk','ul. Vishneva 135 kv. 123','Khmelnytsky','','UKRAINE','29025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:53:10',0,NULL,3,1,2,1,NULL,'vstaran\r\\'),(2412,0,320687522885,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','lilfelacamacho440','davidcamachojr61@gmail.com','david camacho','7810 ackley rd','cleveland','OH','UNITED STATES','44129-4910','(216) 324-7218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 16:10:40',0,NULL,3,1,1,1,NULL,'lilfelacamacho440\r\\'),(2413,776098633012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','jozsef1957','787779@gmail.com','Jozsef Banhidi','Szent Korona utca 198','Budapest','','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:28:50',0,NULL,3,1,2,1,NULL,'jozsef1957\r\\'),(2414,698661367011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','agent_leprechaun','rom.velasquez@gmail.com','Romulo Velasquez','220 Keele St.','Toronto','ON','CANADA','M6P 2K2','(647) 205-5508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:01:14',0,NULL,3,1,2,1,NULL,'agent_leprechaun\r\\'),(2415,528529848004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',2,'HSPL011',46,'cnfaner','gd_n','gd_n2@yahoo.com','Georgi Nalbantov','Slavianska 85','Plovdiv','Plovdiv','BULGARIA','4000','+359878440198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:31:21',0,NULL,3,1,3,1,NULL,'gd_n\rHSPL011\r欧标\rRA117716472CN\r\\'),(2416,528536059004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','bodewallace','wallacejose@gmail.com','Wallace Santos','Rua Quirino nº 830, Condominio Vila Oriente, Bloco 13, Ap.102<br>Bairro: Inacio Barbosa - Atras do Rei dos Colchoes','Aracaju','Sergipe','BRAZIL','49040-700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:52:32',0,NULL,3,1,3,1,NULL,'bodewallace\rHSNO022\rRA117716415CN\r\\'),(2417,0,230611726304,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',17.89,'eastar4','richengel','richengel@snet.net','Richard L. Engelhardt','770 Saybrook Rd','Middletown','CT','UNITED STATES','06457','(860) 343-6644','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 19:13:42',0,NULL,3,1,1,1,NULL,'richengel\r再发一个 8V AC Adapter Charger Power Supply Logitech Harmony 880 \r\\\r '),(2418,574580228013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','hgfazel','hfazel@hotmail.com','Hesham Fazel','11 Whalers Cove','Winnipeg','MB','CANADA','R3T 5H1','(204) 509-9917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 19:37:43',0,NULL,3,1,2,1,NULL,'hgfazel\r\\'),(2419,574588984013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','cjones985charles','safetyfrist20@yahoo.com','charles jones','3001 Essex Ave','La Place','LA','UNITED STATES','70068-2244','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 20:07:54',0,NULL,3,1,1,1,NULL,'cjones985charles\r、'),(2420,698724962011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','julien245','jgandoulas@gmail.com','julien gandoulas','11, Grande rue St Michel, apt. 42','Toulouse','Midi-Pyrénées','FRANCE','31400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:31:02',0,NULL,3,1,2,1,NULL,'julien245\r\\'),(2421,574601442013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','kriszta0806','korosi.dudas@gmail.com','Krisztina Kőrösi Dudás','Hiúz utca 5 1/6.','Szeged','','HUNGARY','6725','+36209346445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:48:44',0,NULL,3,1,2,1,NULL,'kriszta0806\r\\'),(2422,574615403013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','el_dib','lechac@free.fr','CHALABI Habib','19 place du Salin','Toulouse','Midi-Pyrénées','FRANCE','31000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 21:42:31',0,NULL,3,1,2,1,NULL,'el_dib\r\\'),(2423,574619527013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',29.8,'eastar4','rokbosina2010','rokbosina@yahoo.com','rok bosina','veliki obrež 2b<br>8257','dobova','dobova','SLOVENIA','8257','0038640500008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 22:02:08',0,NULL,3,1,2,1,NULL,'rokbosina2010\r一共买了两个\r欧标\r\\'),(2424,776218537012,220759518349,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12,'eastar4uk','mr.ht','hmeehan2@comcast.net','Harold Meehan','106 Harvest Hills Dr','North Bennington','VT','UNITED STATES','05257','(802) 442-6350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 22:27:08',0,NULL,3,1,1,1,NULL,'mr.ht\r\\'),(2425,776241664012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','cdibenga','chris@dibenga.com','Chris di Benga','XL Windows<br>9 Dunlop Road','Hadleigh Rd Ind Estate','Ipswich','UNITED KINGDOM','IP2 0UG','01473253595','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117718941CN\r\\ ','cdibenga\rOTHP003'),(2426,0,220772223307,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','derekefarmer11','derekefarmer@gmail.com','Derek Farmer','2485 Chestnut St','Hanford','CA','UNITED STATES','93230-1212','(559) 917-3581','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 00:36:47',0,NULL,3,1,1,1,NULL,'derekefarmer11\r\\'),(2427,776264287012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','sff1559x','vicang1987@hotmail.com','Christopher Phang Jun Rong','Blk 423 Choa Chu Kang Ave 4 #07-244','default','','SINGAPORE','680423','+65 91814836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 00:50:22',0,NULL,3,1,11,1,NULL,'sff1559x\rHSPL011\r英标\r\\'),(2428,776267284012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',104,'eastar4','thongngom','thongngom2001@yahoo.com','Udom Thongngom','6/15 Deering ST','Westminster','Western Australia','AUSTRALIA','6061','0417931410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:00:55',0,NULL,3,1,3,1,NULL,'thongngom\rOTIN005\rRA117716469CN\r\\'),(2429,528621784004,140516092415,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'cnfaner','jimi403','jmartens70@shaw.ca','Jim Martens','331 Falshire Drive N.E.','Calgary','AB','CANADA','T3J 1T8','(403) 827-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:24:02',0,NULL,3,1,3,1,NULL,'jimi403\rBALO001\rRA117716509CN\r\\'),(2430,776275667012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',2,'WLAT007+ANTY001',33.9,'eastar4','mixrgb','prinipio@hanmail.net','Park Gyeong-Hwan','304Ho 101Dong Daerim 1Danji Apt.<br>Yangji-ri Onam-eup','Namyangju-si','Gyeonggi-do','KOREA,REPUBLIC OF','472-940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:31:34',0,NULL,3,1,3,1,NULL,'mixrgb\r+011-9038-1171\rWLAT007+ANTY001\rRA117716486CN\r\\'),(2431,776277304012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','cspencer_2k5','cspencer@slingshot.co.nz','Cassandra Spencer','16 Camp Road<br>Mt Wellington','Auckland','','NEW ZEALAND','1006','6492767808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:36:25',0,NULL,3,1,2,1,NULL,'cspencer_2k5\r\\'),(2432,663410217001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','entertainmentpls','entertainmentpls@comcast.net','chris fuller','17840 146th Ave NE','woodinville','WA','UNITED STATES','98072-6228','(206) 227-3918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 01:42:11',0,NULL,3,1,1,1,NULL,'entertainmentpls\rLK042393056CN\r\\'),(2433,698587138011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','care20061','pirelli2006@yandex.ru','Pavel Gushchin','bakalinskaya 66 str. app. 65','Ufa','Bashkortostan','RUSSIAN FEDERATION','450022','89196020001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 02:13:57',0,NULL,3,1,2,1,NULL,'care20061\r\\'),(2434,776296042012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','marlers2010','raikou2222000@yahoo.com','Justin Marler','12 1/2 Harper St','The Plains','OH','UNITED STATES','45780-1042','(573) 330-3138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 02:47:48',0,NULL,3,1,1,1,NULL,'marlers2010\racer 6pin1.25 23cm\r\\'),(2435,528631148004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','martin9061','lmhastings@sbcglobal.net','Martin Piekos','8222 W Oakton St','Niles','IL','UNITED STATES','60714-2723','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 03:40:54',0,NULL,3,1,1,1,NULL,'martin9061\r、'),(2436,698847458011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','michelleschembri','mattschembri@gmail.com','Matthew Schembri','403 peel st nth','black hill','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 04:30:14',0,NULL,3,1,2,1,NULL,'michelleschembri\r、'),(2437,574697009013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','theninja2000','dave.millican@gmail.com','David Millican','Anixter Components, Unit A Nimrod Way<br>East Dorset Trade Park','Wimborne','Dorset','UNITED KINGDOM','BH21 7HY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 05:02:06',0,NULL,3,1,2,1,NULL,'theninja2000\r\\'),(2438,776338335012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.8,'eastar4','ma63niek','ma63niek@poczta.onet.pl','Arkadiusz Borodeńko','Okólna 35/42','Konin','wielkopolskie','POLAND','62510','601 966960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 06:21:01',0,NULL,3,1,2,1,NULL,'ma63niek\rHP 8pin 1.0 18cm 4线连 \r、'),(2439,776339764012,220705174904,'New Genuine Motorola H555 Bluetooth Wireless Headset',1,'HSMO008',8.99,'eastar4uk','grigorakiandroniki','niki.grigor@gmail.com','Androniki Grigoraki','Karaiskaki 46<br>N Alikarnasos','Heraklion','Crete','GREECE','71601','+30.6974398406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 06:27:58',0,NULL,3,1,2,1,NULL,'grigorakiandroniki\r欧标\r、'),(2440,776346444012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','jgcarpenter7oq1','jgcarpenter@comcast.net','DEBORAH CARPENTER','1171 Lions Dr','BURNS HARBOR','IN','UNITED STATES','46304','(219) 787-1040 ext.: 129','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 07:04:32',0,NULL,3,1,1,1,NULL,'jgcarpenter7oq1\r、'),(2441,776346218012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','fk100','frank.kretz@web.de','Frank Kretz','Im Etzel 21','Bexbach','','GERMANY','66450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:08:10',0,NULL,3,1,2,1,NULL,'fk100\r欧标\r、'),(2442,698882806011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ramon314','ramon314@skynet.be','Raphaël Montulet','Rue des Alliés n° 1','Grâce-Hollogne','','BELGIUM','4460','0487110665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:48:52',0,NULL,3,1,2,1,NULL,'ramon314\r\\'),(2443,698902165011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',2,'HSUE003',56.98,'eastar4','cobusvwielligh','cobi_vw@hotmail.com','Cobus von Wielligh','20 Protea Street','Paarl','Western Cape','SOUTH AFRICA','7646','0218723036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:16:47',0,NULL,3,1,3,1,' RA117716530CN\r','cobusvwielligh\rHSUE003'),(2444,698906659011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.9,'eastar4uk','jollylands','jholland@telecomconsult.net','John Holland','Ericsson Main building<br>Clonskeagh','Dublin','Dublin','IRELAND','D18','0868331908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 09:29:56',0,NULL,3,1,3,1,' RA117718062CN\r','jollylands\rWLAP002'),(2445,574735622013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','mustafa_veysalov_1986','mustafa_veysalov@yahoo.com','Mustafa Veysalov','city Khirdalan, home 9, flat 33, district 27<br>Azerbaijan','Baku','Azerbaijan','AZERBAIJAN','0100','0123422035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:34:28',0,NULL,3,1,2,1,NULL,'mustafa_veysalov_1986\r\\'),(2446,698953761011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',23.9,'eastar4','john2_k','kimidis@hol.gr','john kimidis','mitropolitou nikolaou 13','Chalkida','προεπιλογή','GREECE','34100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 12:35:03',0,NULL,3,1,2,1,' ','john2_k   是大个大remote 新产品\r\\'),(2447,776441717012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','avianamerican','talkylot@hotmail.com','Rebecca Wells','14 Shammall Court, Greenwith','Adelaide','South Australia','AUSTRALIA','5125','0882898894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:04:32',0,NULL,3,1,2,1,NULL,'avianamerican\r\\\r'),(2448,698967724011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','albserfid','alsefi@bigfoot.com','Alberto SERRADILLA FIDALGO','Av.Camino de Santiago 7, B, 4, D','Madrid','Madrid','SPAIN','28050','607750488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:24:20',0,NULL,3,1,3,1,' RA117718102CN\r','albserfid\rUDAP001'),(2449,776457613012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',4,'HSPL010',95.6,'eastar4','prettydog37072','larrywreese@bellsouth.net','Larry Reese','540 Utley Dr','Goodlettsville','TN','UNITED STATES','37072','(615) 859-8846','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 13:52:52',0,NULL,3,1,1,1,NULL,'prettydog37072\r、'),(2450,776031275012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',23.98,'eastar4','yoonking08','aceykc08@gmail.com','YK Choong','217-D, Jalan Kenanga 3/31,<br>Taman Kenanga Sek 3,','Melaka','Melaka','MALAYSIA','75200','0126802918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:35:29',0,NULL,3,1,2,1,NULL,'yoonking08\r\\'),(2451,698986724011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','nielsenalmeida','nielsenalmeida@gmail.com','Nielsen Almeida','Rua Dr. Fernando Bustamant, 289 - Centro','Açu','RN','BRAZIL','59650-000','+55 (84) 8116-1616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:38:08',0,NULL,3,0,3,1,' RA117718031CN\r','nielsenalmeida\rOTSO001'),(2452,776478356012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',6,'TRMX003',50.1,'eastar4','kulisra','gunpai@multisys.co.th','Attn:Gunpai Chiramanaphan','MultiSys Computer and Network Co.,Ltd.<br>13 Soi Soonvijai 14, Newpetchburi Road, Bangkapi, Huaykwang,','Bangkok','','THAILAND','10320','662 318 1390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:55:16',0,NULL,3,1,3,1,' RA117718204CN\r','kulisra\rTRMX003\rMX20T'),(2453,574829710013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',6,'OMHJ001',83.94,'eastar4','krlhrtmn1','karilou58@yahoo.com','Kari Hartman','719 E Pearl St','Lanark','IL','UNITED STATES','61046-1330','(815) 493-2827','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-22 16:48:40',0,NULL,3,1,1,1,NULL,'krlhrtmn1\r、'),(2454,574831837013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','philipp845','philipp_erber@yahoo.de','Philipp Erber','Mollardgasse /16 Zi.301','Wien','','AUSTRIA','1060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:56:43',0,NULL,3,1,2,1,NULL,'philipp845\r\\'),(2455,699066384011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','plasticheaven','plastic@s180100082.websitehome.co.uk','Chris Hampele','80 Frances Road','Windsor','Berkshire','UNITED KINGDOM','SL4 3AJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 18:03:56',0,NULL,3,1,2,1,' ','plasticheaven\r\\'),(2456,0,230612114645,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','valerier2009','kanyinglin@yahoo.com','Bobby Carter','1255 Pennsylvania Ave<br>Apt 14E','Brooklyn','NY','UNITED STATES','11239-1101','(917) 499-6735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 18:57:56',0,NULL,3,1,1,1,NULL,'valerier2009\r、'),(2457,0,320688404833,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','chargersbasketball3','chargersbasketball7@yahoo.com','brian teiell','2006 crazy horse','stillwater','OK','UNITED STATES','74075-6159','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-22 19:52:57',0,NULL,3,1,1,1,NULL,'chargersbasketball3\r、'),(2458,776620492012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','itbracknell','simon@sodit.net','Simon Simpson','20 Staveley Grove','Keighley','West Yorkshire','UNITED KINGDOM','BD227DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 20:22:20',0,NULL,3,1,3,1,' RA117718028CN\r','itbracknell\rOTHP003'),(2459,528849451004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 21:14:24',0,NULL,3,0,3,1,'RA117718425CN\r ','misiom1\r把8781改换成\r8780\rBTAC2104+WWSI004\r再发一个2.1 Acer Aspire 7738G bluetooth module acer 4pin1.25 6cm\r'),(2460,528850566004,140427917560,'2.1 Acer Aspire 7738G bluetooth module we offer track#',1,'BTAC2104',13.99,'cnfaner','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 21:18:55',0,NULL,8,1,17,0,NULL,'misiom1'),(2461,776660203012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','digo_pe','pedrosa.rodrigo@gmail.com','RODRIGO PEDROSA','RUA OUREM N.227 BL.C AP.604','RECIFE','PERNAMBUCO','BRAZIL','50761340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 22:12:31',0,NULL,3,1,2,1,NULL,'digo_pe\rAcer 5pin1.25 3cm\r\\'),(2462,776660098012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','fearshogun','sharpprecision@hotmail.com','Francis Bernard Kwegyir-Afful','16 Marden House<br>Bodney Road','Hackney','London','UNITED KINGDOM','E8 1AZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 22:14:58',0,NULL,3,1,2,1,NULL,'fearshogun\r英标\r\\'),(2463,574941319013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','itso1970','itso@t-2.net','Hristo Grancharov','Naselje J. Kerencica 30','Murska Sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:36:41',0,NULL,3,1,2,1,NULL,'itso1970\r\\'),(2464,574942969013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','aura222222','aura222222@naver.com','Hunjoo Lee (tel 010-3056-6560)','Hansol Central Park 2 CHA 1706 HO<br>Gwanyang-dong ,Dongan-gu,','Anyang-si,','Gyeonggi-do, South Korea (Republic of Korea)','KOREA,REPUBLIC OF','431-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:45:22',0,NULL,3,1,2,1,NULL,'aura222222\r\\'),(2465,523145000003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',48.98,'cnfaner','vinodmadadi','vinodmadadi@yahoo.com','Vinod R. Madadi','31 Weller Pl','Holmdel','NJ','UNITED STATES','07733-3119','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 23:52:55',0,NULL,3,1,1,1,NULL,'vinodmadadi\r、'),(2466,776718338012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','b1indsquirre1','mbosveld@yahoo.com','Michael D Bosveld','11041 Harrison Ave S','Bloomington','MN','UNITED STATES','55437','(952) 884-0982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 01:56:37',0,NULL,3,1,1,1,NULL,'b1indsquirre1\r、'),(2467,776728616012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','marlheykdt','marlheygsi@yahoo.com.br','marlhey barros','rua graciano neves ,99(ap.901)<br>Centro','vitoria','Espirito Santo','BRAZIL','29015-330','55 27 99916166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 02:33:24',0,NULL,3,1,2,1,NULL,'marlheykdt\r\\'),(2468,574974762013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','nemunasmano','zitas@clear.net','Zita Sabaliauskiene','2317 Beverly Way','Las Vegas','NV','UNITED STATES','89104-2763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 02:50:22',0,NULL,3,1,1,1,NULL,'nemunasmano\rHP 8pin 1.0 23cm\r、'),(2469,523175123003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',21.99,'cnfaner','alex_dav','surgutalex@gmail.com','Dmitrieva Marianna','per. Nahimova 14/1 - 55','Tomsk','','RUSSIAN FEDERATION','634012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:12:59',0,NULL,3,1,3,1,' RA117718093CN\r','alex_dav\rWLIN010'),(2470,574988097013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','sung.kim.73','shk773@hotmail.com','Sung Kim','8 Essex St','Lexington','MA','UNITED STATES','02421','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 04:26:48',0,NULL,3,1,1,1,NULL,'sung.kim.73\r、'),(2471,523186417003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'cnfaner','dr_lliam','lliam.bicsak@gmail.com','LLiam J.T. Bicsak','1090 25th St<br>Apt 1','Des Moines','IA','UNITED STATES','50311-4274','(440) 714-2862','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-04-23 04:45:41',0,NULL,3,1,1,1,NULL,'dr_lliam\r、'),(2472,776763955012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',16.98,'eastar4','titus123ka','titus-ka1@t-online.de','Dietmar Sieg','Kleinabenberg A11','Abenberg','','GERMANY','91183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 05:38:06',0,NULL,3,1,2,1,NULL,'titus123ka\r\\'),(2473,699258890011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','mikenmary1955','magar@bigpond.net.au','Michael Agar','2 palpera Terrace','Greensborough','Victoria','AUSTRALIA','3088','0394345811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 05:38:39',0,NULL,3,0,3,1,' RA117718080CN\r','mikenmary1955\rOTSO001'),(2474,776782882012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','itaymedstud84','itay.aspis@gmail.com','Itay Aspis','24 Alexandroni st.','Ramat Gan','','ISRAEL','52225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:17:25',0,NULL,3,1,3,1,' RA117718116CN\r','itaymedstud84\rHSSH002'),(2475,699285145011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','nilak_bg','nilak@agencyprintsoft.com','Kalin Kalinkov','51, Oborishte str.','Sofia','Bulgaria / Sofia-grad','BULGARIA','1504','359878682049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:59:51',0,NULL,3,1,2,1,NULL,'nilak_bg\r\\'),(2476,699311613011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','hoppy100hp','hoppy@clysbarton.freeserve.co.uk','Mike Hopwood','13 Clysbarton Court','stockport','Cheshire','UNITED KINGDOM','SK73NP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 09:58:28',0,NULL,3,1,2,1,NULL,'hoppy100hp\r\\'),(2477,699313226011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTRA002',75.99,'eastar4','alexander.webster','alexander.webster@gmail.com','Alex Webster','c/o SMEC<br>Level 1, 154 Melbourne St','South Brisbane','Queensland','AUSTRALIA','4101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 10:05:23',0,NULL,3,0,3,1,' RA117716565CN\r','alexander.webster\rOTSO001\r'),(2478,575035571013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'eastar4','sqas4','anze.tomic@gmail.com','Anze Tomic','trnovski pristan 10','Ljubljana','','SLOVENIA','1000','+38641334205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 10:13:59',0,NULL,3,1,2,1,NULL,'sqas4\r\\'),(2479,699333241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tschemex','stefan.tschemernig@gmx.net','Stefan Tschemernig','Rot-Kreuzstrasse 4','Sankt Veit an der Glan','','AUSTRIA','9300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:29:22',0,NULL,3,1,2,1,NULL,'tschemex\r\\'),(2480,575052477013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','miki--1987','mikolasl@seznam.cz','Mikolas Lebeda','Ckalovova 879/11','Ostrava','Czech Republic','CZECH REPUBLIC','70800','+420775087967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:54:55',0,NULL,3,1,2,1,NULL,'miki--1987\r银色的 欧标\r\\'),(2481,663913376001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','hamiltj16','a-and-j-hamilton@hotmail.com','Janet Hamilton','17 Larner St.','St. John\'s','NL','CANADA','A1A 5S9','(709) 754-3345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 12:55:31',0,NULL,3,1,3,1,' RA117716574CN\r','hamiltj16\rOTSO001'),(2482,575074287013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','co.2.fire','sparky.co1@me.com','Brian Dispenza','1046 Jedburg Rd','Summerville','SC','UNITED STATES','29483-6908','(843) 817-8547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 13:40:07',0,NULL,3,1,1,1,NULL,'co.2.fire\r、'),(2483,699375209011,320394905605,'Acer Travelmate 5620 7510 Bluetooth Module2.0 EDR+cable',1,'BTAC2008',12.5,'eastar4','kerekes.robert','djrobbyy@gmail.com','Robert Kerekes','Dózsa György út 17.','Nagyecsed','','HUNGARY','4355','+36709784373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:00:09',0,NULL,3,1,2,1,NULL,'kerekes.robert\racer 4pin1.25 18cm\r\\'),(2484,776896748012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','dacmarques','dacmarques@gmail.com','Daniel  Marques','Rua Nazaret, 43<br>Santa Lucia','Belo Horizonte','Minas Gerais','BRAZIL','30360-720','553132861885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:22:07',0,NULL,3,1,2,1,NULL,'dacmarques\racer 8pin1.00 6cm \r\\'),(2485,529014040004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','redline_555','great_dog@mail.ru','Petr Senichkin','Sudoremontnikov 52/2','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','+79183711503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:57:44',0,NULL,3,1,3,1,' RA117739204CN\r','redline_555\rANYA001'),(2486,699398538011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.8,'eastar4','raponchito','jc.naranjo@terra.es','Jair Naranjo','C/ Leon y Castillo, 128 - Local Comercial','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 15:11:47',0,NULL,3,1,2,1,NULL,'raponchito\racer 8pin1.00 15cm\\\r'),(2487,776927761012,220759518727,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',24.9,'eastar4uk','jakeruthers','jake_ruthers@live.co.uk','Jake Rutherford','Flat 10 Room 3 Eden Hall<br>11 Victoria Street','Preston','Lancashire','UNITED KINGDOM','PR1 7QS','01617948533','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 15:44:35',0,NULL,3,1,3,1,' RA117716512CN\r','jakeruthers\rMOLO002'),(2488,699428486011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','will8050','will8050@aol.com','William Sanders','905 taylor ave','Bellevue','KY','UNITED STATES','41073-1671','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 16:34:47',0,NULL,3,1,1,1,NULL,'will8050\r、'),(2489,699459696011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','golf_f00l','jknight304@charter.net','Jack M Knight','304 Kaplan Ct','Simpsonville','SC','UNITED STATES','29681-1969','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 17:55:08',0,NULL,3,1,1,1,NULL,'golf_f00l\r、'),(2490,575156269013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','aris_balagas','abalagas@gmail.com','Aris Balagas','12 Kanari st','Maroussi','Athens','GREECE','15126','+30 6937 275765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:40:28',0,NULL,3,1,2,1,NULL,'aris_balagas\r欧标\r\\'),(2491,664040631001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','u2desire','fordfanatics@mindspring.com','Daniel Bond','1882 Everglade Ave','Clovis','CA','UNITED STATES','93619-2852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 19:10:29',0,NULL,3,1,1,1,NULL,'u2desire\rLK043125453CN \r、\r'),(2492,777028723012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','shmuelyaniv23','shmuelyaniv@gmail.com','Yaniv Shmuel','Shraga refaeli 12/44','Petach tikva','Israel','ISRAEL','49064','972-50-9060224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 19:38:09',0,NULL,3,1,3,1,' RA117716645CN\r','shmuelyaniv23\rOTGR001+OTGR002\r'),(2493,777053316012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',8.7,'eastar4','santfox','yinongwu2007@gmail.com','Yinong Wu','3414 Redpath circle','Mississauga','ON','CANADA','L5N 8R7','(647) 403-8826','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'、 ','santfox\rCAB-SS-2660'),(2494,777053174012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','esdrascavalcanti','esdrascavalcanti@hotmail.com','Esdras Cavalcanti','Rua da Graça, n°120, bairro Graça, SSA-BA Brasil','Salvador','Bahia-Brazil','BRAZIL','40150060','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:31:43',0,NULL,3,1,3,1,' RA117716526CN\r','esdrascavalcanti\rOTRA002'),(2495,699524996011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','uninik','nik.slabkovsky@mail.ru','Nikita Slabkovsky','Tuleneva st., 31-1-25','Moscow','Moscow','RUSSIAN FEDERATION','117465','(903)7277782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:38:05',0,NULL,3,1,2,1,NULL,'uninik\r\\'),(2496,777064876012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','xiehaiwei868819','xiehaiwei86881995@hotmail.com','haiwei xie','39 searles close,parkgate road<br>battersea','London','London','UNITED KINGDOM','SW11 4RG','07598799528','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 21:02:01',0,NULL,3,1,3,1,' RA117716628CN\r','xiehaiwei868819\rRELO002'),(2497,699549922011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','the_zw3rg','plbeck@t-online.de','Alexander Beck','Schulweg 4','Eberbach','','GERMANY','69412','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 21:42:14',0,NULL,3,1,2,1,NULL,'the_zw3rg\r\\'),(2498,777091149012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','calebhewitt','calebohewitt@gmail.com','Caleb Hewitt','3405 Monaghan St','Dublin','CA','UNITED STATES','94568-4569','(951) 236-4784','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 22:14:27',0,NULL,3,1,1,1,NULL,'calebhewitt\r、'),(2499,575224687013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.2,'eastar4','red_dragon_uk','adam.lee2@virgin.net','Adam Lee','Flat 20 Athena Court<br>Spicewood','Fareham','Hampshire','UNITED KINGDOM','po155ds','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 22:59:33',0,NULL,3,1,3,1,' RA117716631CN\r','red_dragon_uk\rCASS001'),(2500,575233587013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','kepferle','diana@kepferle.com','Diana Kepferle','5421 Woodstock St','Shawnee','KS','UNITED STATES','66218','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-23 23:50:30',0,NULL,3,1,1,1,NULL,'kepferle\r、'),(2501,575234245013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','julianocorleta','jcorleta@gmail.com','Juliano Marquardt Corleta','Av. Mato Grosso, 1215 (Delegacia de Polícia Federal)<br>centro','Naviraí','Mato Grosso do Sul','BRAZIL','79950-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:53:09',0,NULL,3,1,2,1,NULL,'julianocorleta\rHP 8pin 1.0 23cm \r\\'),(2502,529145866004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','clerget-2009','hstleger@aliceadsl.fr','HENRI DE ST LEGER','88 RUE ARMAND SILVESTRE<br>BOITE 177','COURBEVOIE','Île-de-France','FRANCE','92400','01.47.89.28.79.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:04:31',0,NULL,3,1,3,1,' RA117718120CN\r','clerget-2009\rHSNO003\r欧标'),(2503,575236974013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','coupebolt','s.fradette@globetrotter.net','Sylvain Fradette','22 rue Fradette<br>optional','St-Damien','QC','CANADA','G0R 2Y0','(418) 789-0097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:09:25',0,NULL,3,1,3,1,' RA117739513CN\r','coupebolt\rRCLO003'),(2504,575239571013,230393481897,'2.1 HP NC6220 NC6230 Bluetooth Module EDR +cable',1,'BTHP2105',12.8,'eastar4','vlad0057','ttttt29@yandex.ru','Vladislav Sysoev','Myasnickaya ulitca, dom26 (GlavPochtamt)','Moscow','Moscow','RUSSIAN FEDERATION','101000','+7-926-199-27-93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 00:21:34',0,NULL,3,1,2,1,NULL,'vlad0057\rHP 8pin 1.0 20cm \r\\'),(2505,575251699013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','rangefinder2008','panuraj1983@gmail.com','Panurach Jirawanich','17 Prachanivej 2, Soi Samakki 58/12,<br>Samakki Rd., Tah Sai,','Muang','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 01:30:24',0,NULL,3,1,2,1,NULL,'rangefinder2008\r\\'),(2506,575247072013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 01:57:13',0,NULL,3,1,2,1,NULL,'dcwholesale\r\\'),(2507,699618251011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','888petia','gintariuska@yahoo.com','kestutis petraitis','1233 Wyndham Ct<br>Apt 105','palatine','IL','UNITED STATES','60074-7921','(224) 595-9925','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:15:24',0,NULL,3,1,1,1,NULL,'888petia\r、'),(2508,777154950012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dogrock246','trocky2001@aol.com','Elizabeth Thomas','4250 Suitland Rd<br>Apt 101','Suitland','MD','UNITED STATES','20746-2057','(301) 420-5429','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:19:58',0,NULL,3,1,1,1,NULL,'dogrock246\r、'),(2509,0,320688647118,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.25,'eastar4','edwinsingh78664','edwinsingh@gmail.com','Edwin Singh','610 Greenhill Dr. Apt. 9201','Round Rock','TX','UNITED STATES','78665','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:34:18',0,NULL,3,1,1,1,NULL,'edwinsingh78664'),(2510,777161000012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','salvanica_8385','lanica040507@hotmail.com','Annes Arana','13230 Delaney Rd','Woodbridge','VA','UNITED STATES','22193','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 02:40:05',0,NULL,3,1,1,1,NULL,'salvanica_8385\r、'),(2511,0,220772713200,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',15,'eastar4','jerald29168','jerald29168@yahoo.com','jerald Tindal','84 James Haskell Rd','wedgefield','SC','UNITED STATES','29168-9769','(803) 494-4133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:03:42',0,NULL,3,1,1,1,NULL,'jerald29168\r、'),(2512,699631076011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','zaipasta','xail_alucard@hotmail.com','Yi-Fan Chu','1616 Melrose Park Ct<br>Apt 1713','Urbana','IL','UNITED STATES','61801-0830','217 974 0266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:17:01',0,NULL,3,1,1,1,NULL,'zaipasta\r、'),(2513,529176002004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','razz2u2','hami9357@zoominternet.net','Todd Hamilton','143 N Hills Dr','Rising Sun','MD','UNITED STATES','21911-1670','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 03:18:16',0,NULL,3,1,1,1,NULL,'razz2u2\r、'),(2514,575273511013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','swatchdog76','knicholls@mac.com','Kevin Nicholls','969 PANORAMA DR','MILFORD','MI','UNITED STATES','48381','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:36:14',0,NULL,3,1,1,1,NULL,'swatchdog76\r、'),(2515,699634555011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',49.99,'eastar4','steinynyc','jms3494@aol.com','Richard Steinberg','350 E 79th St','New York','NY','UNITED STATES','10075-9202','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:36:37',0,NULL,3,1,1,1,NULL,'steinynyc\r、'),(2516,773715623012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','raleymic3','raleymic@msu.edu','June Raley','2355 Rolling Meadow Dr NE','Belmont','MI','UNITED STATES','49306-9322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 03:51:22',0,NULL,3,1,1,1,NULL,'raleymic3\r、'),(2517,777177544012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','sillyppl','sillyppl76@hotmail.com','Austin Sharp','PO Box 502<br>103 West South St.','Anna','OH','UNITED STATES','45302-0502','(937) 394-8217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 04:06:30',0,NULL,3,1,1,1,NULL,'sillyppl\r、'),(2518,575279709013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','elecgeon','mradulsahani@msn.com','Harsh Sahani','129 Upper Humber Dr','Etobicoke','ON','CANADA','M9W 7B7','(416) 913-3312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 04:20:43',0,NULL,3,1,2,1,NULL,'elecgeon\r\\'),(2519,699646779011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','coreripper','queenmetroid@gmail.com','Seth Barrial','22715 Gierson Ave','Wildomar','CA','UNITED STATES','92595','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 04:45:44',0,NULL,3,1,1,1,NULL,'coreripper\rHP 8pin 1.25 25cm \r、'),(2520,664193138001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','ronnietoys','rnj1@aol.com','Ronald Joseph','116 Stagecoach Cir','Milford','CT','UNITED STATES','06460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 05:52:16',0,NULL,3,1,1,1,NULL,'ronnietoys\rLK043124909CN \r、'),(2521,699666847011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','j***gol','jgolangco@gmail.com','Jeffrey Golangco','155 Spinks Canyon Rd','Bradbury','CA','UNITED STATES','91008-1244','(626) 203-3042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 06:42:05',0,NULL,3,1,1,1,NULL,'j***gol\r、'),(2522,777209738012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tongzhengxin','thegopackstore@gmail.com','Zhengxin Tong','2816 Avent Ferry Rd<br>Apt 301','Raleigh','NC','UNITED STATES','27606-3126','(919) 760-0277','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 06:52:54',0,NULL,3,1,1,1,NULL,'tongzhengxin\r、'),(2523,699670395011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','m0iseenkoav','moiseenkoav@gmail.com','Aleksey Moiseenko','Sankt-Petersburg, Kronshtadt<br>st.Urija Inge, 8/12, fl.22','Kronshtadt','Sankt-Petersburg','RUSSIAN FEDERATION','197760','(812)915-1529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:00:33',0,NULL,3,1,2,1,NULL,'m0iseenkoav\r\\'),(2524,777213067012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','womancareer17','sederhanabeauty@gmail.com','Darmiana Pulungan (MIA)','AKBAR FINANCIAL CHECK UP<br>GEDUNG DARMA BAKTI WANITA LT. 2, JALAN SENOPATI NO. 74','JAKARTA SELATAN','DKI JAKARTA','INDONESIA','12110','628567014857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:36:21',0,NULL,3,1,3,1,' RA117716659CN\r','womancareer17\rOTSO002'),(2525,528928918004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.95,'cnfaner','dugarmitul2000','dugarmitul@gmail.com','Mitul Dugar','Dugar Building 1st Floor<br>M.I. Road','Jaipur','RJ','INDIA','302001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 08:19:19',0,NULL,3,1,3,1,' RA117716588CN\r','dugarmitul2000\rHSNO006\r'),(2526,575320366013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',16.88,'eastar4','the7111401','2oilrg@gmail.com','Boris Braoude','str. Abba Hillel Silver, 27/13','Haifa','','ISRAEL','32693','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 09:02:32',0,NULL,3,1,2,1,NULL,'the7111401\r\\'),(2527,777285468012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','2398u_bon','chalita.phanmuang@hotmail.com','Chalita Mortensen','Birkevaenge 46','Hanstholm','','DENMARK','7730','23981319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:09:13',0,NULL,3,1,2,1,NULL,'2398u_bon\r\\'),(2528,699738531011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',16.75,'eastar4','delababa','godeshan@gmail.com','Deshan Perera','NO 25 Cypress Garden<br>Weragama Road','Wadduwa','Westen','SRI LANKA','12500','+94777352650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:17:33',0,NULL,3,1,2,1,NULL,'delababa\r\\'),(2529,575355040013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','miketrigger29','arikov29@meta.ua','Arikov Roman Filippovich','Bereznyakovskaya 20 fl.98','KIEV','','UKRAINE','02152','+380975604149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 11:48:35',0,NULL,3,1,2,1,NULL,'miketrigger29\r\\'),(2530,777359635012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','talmihail','aronov_d@mail.ru','Daniel Aronov','kohen eli 24/28','Bat yam','','ISRAEL','59644','0507631952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:35:06',0,NULL,3,1,2,1,NULL,'talmihail\r\\'),(2531,575396904013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','avasanji','adilvasanji@gmail.com','Adil Vasanji','4343 115 Street','Edmonton','AB','CANADA','T6J 1P5','(780) 233-2308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:35:14',0,NULL,3,1,2,1,NULL,'avasanji\r银色的\r\\'),(2532,777362733012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','kirill77rez','kirilrez@mail.tau.ac.il','Kirill Reznikovski','Elazar David 9/4 ST.','Raanana','Raanana','ISRAEL','Israel','972-546886814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:45:09',0,NULL,3,1,3,1,' RA117718045CN\r','kirill77rez\rHSLO002'),(2533,529297504004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','dkylove1004','inzone@nate.com','Ki-Young Dong','Korea University, 5-1, Anam-dong, Seongbuk-Gu, Seoul, 136-713<br>Republic of Korea, Innovation Hall, Room 701(EEE)','Seoul','','KOREA,REPUBLIC OF','136-713','01088989567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 14:56:43',0,NULL,3,1,3,1,' RA117716614CN\r','dkylove1004\rWWSI005'),(2534,777380061012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',5.98,'eastar4uk','ncsageil','ncsamel@hotmail.com','Neil Skiffington','P.O. Box 5085<br>Sth Melbourne','Melbourne','Victoria','AUSTRALIA','3205','0449105088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 15:21:49',0,NULL,3,1,2,1,NULL,'ncsageil\r\\'),(2535,529308554004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','ebfi99','maurih@gmail.com','Mauri Hamalainen','Luotsikatu 3 A 2','HELSINKI','Fi','FINLAND','00160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:29:48',0,NULL,3,1,3,1,' RA117716591CN\r','ebfi99\rCACN001'),(2536,699831226011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.99,'eastar4','franciscojos3222','perezfj@movistar.es','Francisco José Pérez Hernández','plaza Antonio Martinez Nº7, Alumbres Cartagena','Murcia','Murcia','SPAIN','30351','968552220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:36:19',0,NULL,3,1,3,1,'RA117716605CN\r ','franciscojos3222\rOTSO001\r'),(2537,777399498012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','marasboss','sztaba29@interia.pl','Marek Sztabinski','70 Elder Road','Bisley Woking','Surrey','UNITED KINGDOM','gu24 9sa','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 16:00:48',0,NULL,3,1,3,1,' ','marasboss\r英标\rHSNO006\r潘\r'),(2538,777404974012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','shorl2','shorl2@yahoo.com','Sharon Hardman','29 Church Meadows<br>Sholden','Deal','Kent','UNITED KINGDOM','CT14 9QZ','01304362708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 16:11:20',0,NULL,3,1,3,1,'RA117718147CN\r ','shorl2\rOTCN002'),(2539,777414250012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','simo007_berkani','moha_power@hotmail.com','Simo Ayadi','Grondherenstraat 115','Rotterdam','Zuid-Holland','NETHERLANDS','3087CK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:29:07',0,NULL,3,1,2,1,NULL,'simo007_berkani\r\\'),(2540,777415561012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',21.5,'eastar4uk','benzaibenoit','benhur@megaquebec.net','benoit poitras','309 route 269','quebec','QC','CANADA','g0s2p0','(418) 888-1205','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 16:34:00',0,NULL,3,1,3,1,' RA117718014CN\r','benzaibenoit\rWLAP009'),(2541,699860182011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',17.4,'eastar4','pauluz66','meneer.rietbroek@gmail.com','Paul Rietbroek','Lisztstraat 109','\'S-GRAVENHAGE','','NETHERLANDS','2551TC','+31645766898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:34:27',0,NULL,3,1,2,1,NULL,'pauluz66\r\\'),(2542,699867732011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','raven1234crow','raven123crow@bellsouth.net','okechukwu anyanwu','9848 buncome rd','jacksonville','FL','UNITED STATES','32246-4714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 16:49:14',0,NULL,3,1,1,1,NULL,'raven1234crow\r、'),(2543,777442556012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','raghavendra1','kr_p@yahoo.com','raghavendra P krishnamurthy','1402 E Braymore Cir','Naperville','IL','UNITED STATES','60564','(630) 236-0768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 17:16:02',0,NULL,3,1,1,1,NULL,'raghavendra1\r、'),(2544,664406700001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','garry5125','garrytower@hotmail.com','Garry Tower','177 Weldon Street','Moncton','NB','CANADA','E1C 5W5','(506) 204-5755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:21:41',0,NULL,3,1,3,1,' RA117718076CN\r','garry5125\rOTSO001'),(2545,777453087012,220578466424,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',19.99,'eastar4','manilana','thozip@web.de','Vilma Zipser','Trockenkamp 11','Winsen/ Luhe','','GERMANY','21423','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:32:14',0,NULL,3,1,2,1,NULL,'manilana\r欧标\r\\\r'),(2546,777465212012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',29.99,'eastar4uk','baccaratdupont','cashcity@sfr.fr','Christophe RAIMBAULT','21, rue d\'Amsterdam','PARIS','Ile-de-France','FRANCE','75008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 17:49:14',0,NULL,3,1,3,1,' RA117718235CN\r','baccaratdupont'),(2547,575469205013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-24 17:55:10',0,NULL,3,1,1,1,NULL,'edpsychdoc\r、'),(2548,664501360001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','sena505','elitegs18@yahoo.com','Michelle Sena','831 W Manana Blvd','Clovis','NM','UNITED STATES','88101','(505) 762-4293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 20:03:06',0,NULL,3,1,1,1,NULL,'sena505\rLK043123320CN\r、'),(2549,700003370011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','soude1164','soudez@hotmail.fr','ELBAKKALI ABDELAZIZ','45 STROMBEEKLINDE','GRIMBERGEN','','BELGIUM','1853','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:30:22',0,NULL,3,1,2,1,NULL,'soude1164\r\\'),(2550,523697319003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','auggust_70','yury.tsyganov@emerson.com','Yury Tsyganov','Tsurupy str. 12-3-48','Moscow','','RUSSIAN FEDERATION','117418','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:45:12',0,NULL,3,1,3,1,' RA117718155CN\r','auggust_70\rOTGR001'),(2551,777588010012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',3,'MOLO002',116.7,'eastar4','psj59','psj59@hotmail.com','sung Joon Park','245 BAY STREET','OTTAWA','ON','CANADA','K1R 5Z4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 20:54:43',0,NULL,3,1,3,1,' RA117718195CN\r','psj59\rMOLO002'),(2552,700019994011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','kerccolaro','michel.cachia@sfr.fr','Michel Cachia','la valeriane apt 2','val thorens','Rhône-Alpes','FRANCE','73440','+33668916865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 21:08:01',0,NULL,3,1,2,1,NULL,'kerccolaro\r\\'),(2553,0,230611943742,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',1.4,'eastar4','davecarter3','carterdavid@verizon.net','David J Carter','7974 Castle Hedge Dell','Glen Burnie','MD','UNITED STATES','21061','(410) 760-0307','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 22:06:07',0,NULL,3,1,1,1,NULL,'davecarter3\r一共买了两条\r、'),(2554,777622933012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','razal999','zazix@2xsnet.nl','L.I. Klaassens','Diakenhuisweg 83','Haarlem','','NETHERLANDS','2033AP','(023) 5405529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:19:24',0,NULL,3,1,2,1,NULL,'razal999\r\\'),(2555,529459073004,140516498562,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'cnfaner','vinicius.sperandio','vmsperandio@yahoo.com.br','Vinicius Martinelli Sperandio','Rua Aluysio Simões, 730 Casa 02<br>Ilha de Monte Belo','Vitória','Espirito Santo','BRAZIL','29053-264','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:41:58',0,NULL,3,1,3,1,'RA117739195CN\r ','vinicius.sperandio\rANYA001'),(2556,777633526012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','savages9r','aaronjsavage@yahoo.com','Aaron Frederick','3208 New England St','Rapid City','SD','UNITED STATES','57703-4727','(605) 390-1552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 22:48:24',0,NULL,3,1,1,1,NULL,'savages9r\r、'),(2557,575490653013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','sillygrapes86','agordon813@gmail.com','Carrie Gordon','1221 Meadowridge Trl','goshen','KY','UNITED STATES','40026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 23:00:45',0,NULL,3,1,1,1,NULL,'sillygrapes86\r、'),(2558,777633544012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','aoa110','yakovlevbogdan@yandex.ru','Bogdan Yakovlev','Nagatinkaya naberezhnaya<br>dom 54 kv. 643','Moscow','Moscow','RUSSIAN FEDERATION','115407','+7 9165878707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 23:07:46',0,NULL,3,1,2,1,NULL,'aoa110\r\\'),(2559,777640164012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','mario972s','mmcmagnum@hotmail.com','mario martin casado','calle peñarredonda 2 (correos)','aranjuez','Madrid','SPAIN','28300','678787421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 23:07:53',0,NULL,3,1,2,1,NULL,'mario972s\r\\'),(2560,700066653011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','tarynfrank','blfrank@gmail.com','Brian Frank','13090 Pierce Rd','Saratoga','CA','UNITED STATES','95070','(408) 666-0518','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-24 23:27:05',0,NULL,3,1,1,1,NULL,'tarynfrank\r、'),(2561,529469339004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','sobersusie','pofqal1@sbcglobal.net','Susan Sauer','1544 Hickory Road','Woodstock','IL','UNITED STATES','60098','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 23:30:15',0,NULL,3,1,1,1,NULL,'sobersusie\r、'),(2562,700081157011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','barrmaley','barrmaley@gmail.com','Artem Solovyov','7/2 Tankernaya str.','Odessa','Odessa region','UKRAINE','65010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 00:16:18',0,NULL,3,1,2,1,NULL,'barrmaley\r\\'),(2563,575620813013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','nanrspm1970','nanrspm@hotmail.com','Sergeant Tanan Rangseeprom','592 Charoennakorn 14<br>Khlongtonsai Khlongsan','Bangkok','Thailand','THAILAND','10600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 01:24:01',0,NULL,3,1,2,1,NULL,'nanrspm1970\r\\\r\r\r'),(2564,777694536012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dcol2803','d.colebank@yahoo.com','david colebank','2517 walbrook dr','louisville','KY','UNITED STATES','40222','(502) 426-4664','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 01:40:18',0,NULL,3,1,1,1,NULL,'dcol2803\r、'),(2565,575628379013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',2,'RCLO003',277.98,'eastar4','sawoodturner','gurley@swbell.net','Randall Gurley','400 S 14th ST<br>Apt 1018','Saint Louis','MO','UNITED STATES','63103-2720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 01:52:41',0,NULL,3,1,12,1,' 2182315494 \r','sawoodturner\r\\'),(2566,777701994012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',2,'ANYA001',28.9,'eastar4','jakeofarabia','opp11@yahoo.com','tony Jimenez','8069 Garvey Ave<br>box 42 Trlr #45','Rosemead','CA','UNITED STATES','91770-2466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 02:03:27',0,NULL,3,1,3,1,' RA117739527CN\r','jakeofarabia'),(2567,777704860012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','drew306','alsdiner306@charter.net','ANDREW GUZMAN','2620 RAINBOW DR','PLOVER','WI','UNITED STATES','54467','(715) 347-4225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 02:10:51',0,NULL,3,1,1,1,NULL,'drew306\r、'),(2568,777745083012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','ttommy.ufo','ufo.nyva4x4@gmail.com','Tomas Nikitinas','Naumiescio 5','Kaunas','','LITHUANIA','46342','(0370)68972642','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 05:02:50',0,NULL,3,1,2,1,NULL,'ttommy.ufo\r欧标\r\\'),(2569,529532977004,140516109270,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',12.99,'cnfaner','mrminas10','theonlybiggreek@hotmail.com','minas grigoratos','box 985','DAWSON','YT','CANADA','Y0B 1G0','(867) 993-5868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 05:03:05',0,NULL,3,1,3,1,' RA117718164CN\r','mrminas10\rRELE001'),(2570,777757234012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jhap_panis','jhap101@yahoo.com','Jeremy Philip Arceo','26 Bundagul','Mabalacat','Pampanga','PHILIPPINES','2010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:19:51',0,NULL,3,1,2,1,' ','jhap_panis\r\\'),(2571,700169533011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','steedboy','lukesteed@aol.com','LUKE STEED','SMITH INT. SDN BHD KG SG KELING<br>LORONG SK 32,SK 32,SK0786 JLN RANCHA RANCHA','WP LABUAN','MALAYSIA','MALAYSIA','87000','0198250696','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 08:24:45',0,NULL,3,1,3,1,' RA117739460CN\r','steedboy\rOMHJ001\r'),(2572,700209689011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','andrsjkb','jakobimon@aol.com','Andreas Jakobi','Industriestrasse 51','Stolberg','','GERMANY','52224','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 09:20:50',0,NULL,3,1,2,1,NULL,'andrsjkb\r\\'),(2573,529571843004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',2,'BALO008',13.2,'cnfaner','akrachai123','akrachai@truemail.co.th','AKRACHAI HENG','148 TROK ISSRANUPHAP JA-LEARN-KRUNG RD.SUMPUNTAWONG','BANGKOK','','THAILAND','10100','0016626230091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 09:39:40',0,NULL,3,1,3,1,' RA117718283CN\r','akrachai123\rBALO008'),(2574,575709446013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',9,'CASS003',78.3,'eastar4','crsutton31','crsutton_personal@yahoo.co.uk','Christopher Sutton','26 Claymoor Close','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 5RS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 10:20:56',0,NULL,3,1,3,1,' RA117718411CN\r','crsutton31\rCASS003'),(2575,776733178012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','computer615','ryanbirk@gmail.com','Ryan Birk','10101 Pendula Dr','Indianapolis','IN','UNITED STATES','46236-7365','(317) 650-3310 ext.: 0','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'computer615'),(2576,777831937012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','phil14570','p.musgrove1@ntlworld.com','Philip musgrove','14 Poachers Way','Northampton','Northamptonshire','UNITED KINGDOM','NN28AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 10:56:52',0,NULL,3,1,3,1,' RA117718270CN\r','phil14570\r英标   HSNO006'),(2577,575726794013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',5,'WLIN010',104.75,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 12:19:45',0,NULL,3,1,3,1,' RA117718266CN\r','saiajin77\rWLIN010'),(2578,777858039012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','wilogen','willrogers1995@hotmail.co.uk','William Rogers','26<br>Castle Street','Hereford','Herefordshire','UNITED KINGDOM','HR1 4LB','01432350521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 13:17:23',0,NULL,3,1,3,1,' RA117718354CN\r','wilogen\rWLDL001'),(2579,0,230613185024,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.99,'eastar4','bmorebullet','jstones08@verizon.net','jared stones','2415 E Hoffman St','BALTIMORE','MD','UNITED STATES','21213-3634','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 13:17:23',0,NULL,3,1,1,1,NULL,'bmorebullet\r\\'),(2580,0,320690016510,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10.5,'eastar4','cake207','cmarek207@hotmail.com','Carol Marek','301 Linden St W','Frederic','WI','UNITED STATES','54837-8931','(715) 327-5550','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-25 13:18:45',0,NULL,3,1,1,1,NULL,'cake207\r\\'),(2581,700287821011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','garc4991','gwyn.arch@ukgateway.net','Gwyn Arch','15 Grove Rd<br>Sonning Common','Reading','Berkshire','UNITED KINGDOM','RG4 9RH','01189723474','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 13:53:12',0,NULL,3,1,3,1,' RA117718345CN\r','garc4991\rOMHJ001'),(2582,777889174012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ratchetjawes','dhunt@newwavecomm.net','Debbie Hunt','501 E Karen St','Rector','AR','UNITED STATES','72461-1435','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:02:33',0,NULL,3,1,1,1,' \\','ratchetjawes'),(2583,0,320688646214,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',9.09,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:27',0,NULL,5,0,18,0,NULL,'blue8sky'),(2584,0,220772970829,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',16.27,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:26',0,NULL,3,0,1,1,NULL,'blue8sky\r发两个3G天线\rANCN001\rLK043472815CN\r\\'),(2585,0,230611941726,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',17.64,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:16:34',0,NULL,5,0,18,0,NULL,'blue8sky'),(2586,777898597012,220704730634,'New Plantronics Explorer220 BLUETOOTH HEADSET+carcharge',1,'HSPL001+CCPL001',11.2,'eastar4uk','2005dickman','shyboi2@btinternet.com','Henry Dickman','18 William Morris Terrace<br>Shotton Colliery','Durham','Durham','UNITED KINGDOM','DH6 2PL','07771813201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 14:22:53',0,NULL,3,1,3,1,' RA117718221CN\r','2005dickman\rHSPL001+CCPL001'),(2587,700301831011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','eby01821','vermontloghome@yahoo.com','Tom Rezucha, C/O Raybeam, Inc','175 Great Rd<br>Ste 110','Bedford','MA','UNITED STATES','01730','(978) 618-5854','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:36:15',0,NULL,3,1,4,1,'YW864488970CN ','eby01821'),(2588,0,320690016094,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',28.5,'eastar4','gildroyracing','zcamaro@zoominternet.net','Shawn Gildroy','1349 Mount Pleasant Road','Mount Pleasant','PA','UNITED STATES','15666','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 14:37:57',0,NULL,3,1,1,1,NULL,'gildroyracing\r\\'),(2589,575797531013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','kia_22','ilkkakautto@gmail.com','Ilkka  Kautto','Kärkikuja 2 C 76','Tampere','Tampere','FINLAND','33720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:28:38',0,NULL,3,1,3,1,' RA117716185CN\r','kia_22\rWWSI004+ANCN001'),(2590,575797721013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mathurageethan2010','mathurageethan@gmail.com','Mathurageethan Mounasamy','395/11B1, Banadaranayaka Mw','Anuradhapura','','SRI LANKA','00094','+94772071091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:41:23',0,NULL,8,1,17,0,NULL,'mathurageethan2010'),(2591,700352995011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','lance8022','bgbfbg@comcast.net','Lance Lewis','2588 Hawthorne Rd','Ann Arbor','MI','UNITED STATES','48104-4032','(734) 995-1726','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 16:47:57',0,NULL,3,1,1,1,'\\ ','lance8022'),(2592,777960129012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','isuru.senadheera','freestyler830@yahoo.com','Isuru Senadheera','77, Senani, Madurawala<br>Anguruwathota','Anguruwathota','Western','SRI LANKA','12320','+94777562095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 16:48:26',0,NULL,3,1,2,1,NULL,'isuru.senadheera\r\\'),(2593,0,220774817164,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',28,'eastar4','urmeannate','tran.nate@gmail.com','Nathan Tran','2302 falling leaf ave','rosemead','CA','UNITED STATES','91770','(626) 512-9465','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 16:50:13',0,NULL,3,1,1,1,NULL,'urmeannate\r\\'),(2594,777966859012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','rainbow.7064','rainbow.70@mail.ru','oleg vlasov','histadrut 41-16','ashqelon','','ISRAEL','78251','+10 972 504204743','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 17:01:25',0,NULL,3,1,3,1,' RA117718297CN\r','rainbow.7064\rOTCR001'),(2595,575812600013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','zkalwar2000','zahid_kalwar2000@yahoo.com','Zahid Kalwar','2nd Floor, 70 Grace Church Street<br>London','London','London','UNITED KINGDOM','EC3V 0XL','02079654452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 17:15:41',0,NULL,3,1,2,1,NULL,'zkalwar2000\r\\'),(2596,575811503013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','neil042','neilhart@comcast.net','Neil Everhart','43775 Nansa Ct','Fremont','CA','UNITED STATES','94539','(510) 579-1593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 17:22:22',0,NULL,3,1,1,1,NULL,'neil042\r\\'),(2597,575842024013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','snax_007','mrsnax07@yahoo.com','Harry Bond','831 Snohan Rd','ayden','NC','UNITED STATES','28513-9792','(252) 717-7614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 18:28:47',0,NULL,3,1,1,1,NULL,'snax_007\r\\'),(2598,700428697011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','20bef','cassiman.joeri@pandora.be','Joeri Cassiman','Borgeleien 48','Geel','','BELGIUM','2440','0486262191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:11:49',0,NULL,3,1,2,1,NULL,'20bef\r\\'),(2599,0,230613185379,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12.99,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 318-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 19:23:04',0,NULL,3,1,1,1,NULL,'4278dennis\r\\'),(2600,575865590013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','mathurageethan2010','mathurageethan@gmail.com','Mathurageethan Mounasamy','395/11B1, Banadaranayaka Mw','Anuradhapura','','SRI LANKA','00094','+94772071091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:26:17',0,NULL,3,1,2,1,NULL,'mathurageethan2010\r再发一个New GENUINE NOKIA HS-4W BLUETOOTH\r银色的\r\\'),(2601,700434871011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','krskst','krastyo@stanchev.info','Krastyo Stanchev','ul. Probuda 57','Bourgas','Bourgas','BULGARIA','8000','+359885132299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 19:28:07',0,NULL,3,1,2,1,NULL,'krskst\r\\'),(2602,575889809013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',2,'RELE001',18.9,'eastar4','technologyoutlet','sales@balancelogic.com','Bill Campbell','3995 Hanson Rd','White Plains','MD','UNITED STATES','20695','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 20:27:51',0,NULL,3,1,1,1,NULL,'technologyoutlet\r\\'),(2603,700469143011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','rhaleuk','mr.rich@gmail.com','Richard Hale','81 White Hill','Kinver','Staffordshire','UNITED KINGDOM','DY76AR','07535440440','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 20:28:42',0,NULL,3,1,3,1,' RA117718306CN\r','rhaleuk\rUDAP001'),(2604,700480236011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20.99,'eastar4','terryinwales','terry@pantypwll.co.uk','Terry O\'Brien','Pant y Pwll','KIDWELLY','Carmarthenshire','UNITED KINGDOM','SA17 5LW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 20:48:53',0,NULL,3,0,2,1,NULL,'terryinwales\r\\'),(2605,575893954013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','cano278','escamill_patricia@sbcglobal.net','patricia cano','2525 San Gabriel Blvd','Rosemead','CA','UNITED STATES','91770','(626) 374-0291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 20:50:13',0,NULL,3,1,1,1,' \\\r','cano278'),(2606,529756051004,140428315663,'2.1 Acer Aspire Timeline 1810TZ bluetooth module track#',1,'BTAC2111',13.99,'cnfaner','mih75','p.florin@alice.it','Florin Petru Pop','Caduti del lavoro 8','Coccaglio','BS','ITALY','25030','3475931791','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 21:00:50',0,NULL,3,1,3,1,' RA117718218CN\r','mih75\rAcer 5pin1.25 3cm\r'),(2607,778114788012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','okeeffet92','okeeffet@verizon.net','Tom O\'Keeffe','1019 S Hollow Dr','Southlake','TX','UNITED STATES','76092-8831','(214) 529-0885','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 21:30:43',0,NULL,3,1,1,1,'\\ ','okeeffet92\r美标'),(2608,700504579011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','titty101','little_tit@hotmail.com','kyle tytler','23708-54a AVE.','Langley','BC','CANADA','v2z2p2','(604) 534-6369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 21:52:18',0,NULL,3,1,2,1,NULL,'titty101\r\\'),(2609,778143797012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.35,'eastar4','brickpig3','thebrickpig@bellsouth.net','David Pfeiffer','1216 W Woodlawn Ave','Louisville','KY','UNITED STATES','40215-2357','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 22:52:59',0,NULL,3,1,1,1,NULL,'brickpig3\r\\'),(2610,575931177013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','jab_joe','si12volt1@cox.net','Alfred Gray','130 Avenida De La Grulla<br>Apt A','San Clemente','CA','UNITED STATES','92672-9110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 23:02:57',0,NULL,3,1,1,1,NULL,'jab_joe\r\\'),(2611,575944287013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','rhtran','rick_tran@hotmail.com','Rick Tran','8225 Lampson Ave','Garden Grove','CA','UNITED STATES','92841-3115','(714) 590-1473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 00:07:12',0,NULL,3,1,1,1,NULL,'rhtran\r\\'),(2612,778202541012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',59.99,'eastar4','rocket3k','sfausch@hotmail.com','Stefan C. Fausch','509A S Al Davis Rd','New Orleans','LA','UNITED STATES','70123-7300','(504) 460-4200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 02:11:30',0,NULL,3,1,1,1,NULL,'rocket3k\r美标\r\\'),(2613,575967365013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','rodrigo30031980','rigo032@hotmail.com','Abarca Lara Rodrigo','Jacaranda 834','Valparaiso','Casablanca','CHILE','2480505','0560322743368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 02:21:59',0,NULL,3,1,2,1,NULL,'rodrigo30031980\r、'),(2614,575975446013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','xxdestiny','annie.ta.tran@gmail.com','Annie Tran','68 Westforest Trail','Kitchener','ON','CANADA','n2n3a8','(519) 496-7380','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'xxdestiny'),(2615,778213981012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','labossarte','labossarte@verizon.net','Larry Bossarte','118 E Stuart Ave','Lake Wales','FL','UNITED STATES','33853-4128','(863) 679-1850','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 02:50:31',0,NULL,3,1,1,1,NULL,'labossarte\r\\'),(2616,700593235011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','fuffiopl','fufflon@yahoo.com','Manfred Brueggemeier','19177 W Harbour Village Dr','Northville','MI','UNITED STATES','48167-3145','(248) 982-2732','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 03:23:19',0,NULL,3,1,1,1,NULL,'fuffiopl\r\\'),(2617,0,320690460140,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',10,'eastar4','dncfaeri','debnarasaki@comcast.net','deb narasaki','250 Parkside Dr','palo alto','CA','UNITED STATES','94306','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-26 03:57:09',0,NULL,3,1,1,1,NULL,'dncfaeri\r、'),(2618,778235037012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','victorgraur','victorgraur@hotmail.com','Victor Graur','13030 122nd PL','South Ozone Park','NY','UNITED STATES','11420-2710','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 04:24:36',0,NULL,3,1,1,1,NULL,'victorgraur\r、'),(2619,700605717011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',3,'RELO002',38.97,'eastar4','aa_speedy11','huot.max@gmail.com','Maxime Huot','127 Pueblo cr.','Whitehorse','YT','CANADA','y1a 6v3','(867) 667-6667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 04:27:24',0,NULL,3,1,3,1,NULL,'aa_speedy11\rRELO002\rRA117718399CN'),(2620,700618237011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dijerydo100','michael_clamp@hotmail.com','Michael Clamp','18 Bedford Avenue','Wyton on the Hill','Cambridgeshire','UNITED KINGDOM','PE28 2HJ','01480700523','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 05:43:32',0,NULL,3,1,3,1,'RA117741808CN','dijerydo100\rMOAP001\r'),(2621,529191436004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','digitaljockey','mhenriquealmeida@gmail.com','Marcelo Almeida','Rua Barao Do Triunfo,1282 apt. 61','Sao Paulo','SP','BRAZIL','04602-005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:08:29',0,NULL,3,1,3,1,NULL,'digitaljockey\rHSMO007\rRA117718371CN\r'),(2622,778255274012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','richievee','richard.vivian@tesco.net','R.Vivian','9 Osbert Road','Witham','Essex','UNITED KINGDOM','CM8 1PE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 06:13:48',0,NULL,3,0,3,1,NULL,'richievee\rOTRA002\rRA117718385CN\r、'),(2623,576009537013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',75,'eastar4','angelgarciaguillen','agarciaguillen@hotmail.com','angel garcia guillen','C/Barcelona nº1 LOCAL','Zaragoza','Aragón','SPAIN','50017','600491623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:27:51',0,NULL,3,1,3,1,NULL,'angelgarciaguillen\rOTIN003\rRA117718310CN'),(2624,700646872011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','mattereza','mattereza44@mail.ru','Maxim Kadomtsev','Korolenko 8 /post box 133','Moscow','','RUSSIAN FEDERATION','107014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 08:18:31',0,NULL,3,1,3,1,'RA117718955CN\r\\ ','mattereza\rUDAP001\r'),(2625,576036077013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','frsm11','franxi_7@hotmail.com','Fco Rafael Sabariego Menjibar','Pasaje Pintor Ramirez n 3','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','605038849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:32:52',0,NULL,3,1,2,1,NULL,'frsm11\r欧标'),(2626,700663148011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ordor2k','or_dor@hotmail.com','or dor','Zablodovitch 5','Petach Tiqva','Kiryat Alon','ISRAEL','49389','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:33:19',0,NULL,3,1,2,1,NULL,'ordor2k'),(2627,700675667011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','thierry170764','tcostes@wanadoo.fr','Thierry COSTES','22, rue de Perpeigneux, SAULCHERY','CHARLY','Picardie','FRANCE','02310','0323700341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:26:45',0,NULL,3,1,2,1,NULL,'thierry170764\r\\'),(2628,778317856012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maki_na','maki_na@telefonica.net','Bienvenido Frutos','Mestre Tonet nº 30 4º 3ª','lleida','Cataluña','SPAIN','25003','973267197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:51:08',0,NULL,3,1,2,1,NULL,'maki_na\r\\'),(2629,576055629013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','lukitishna','knyazz@inbox.ru','EVGENY SMIRNOV','Rossiysky Prospekt, 14-282','Saint Petersburg','','RUSSIAN FEDERATION','193231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 11:22:39',0,NULL,3,1,2,1,NULL,'lukitishna\r\\'),(2630,700697619011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','petunia1953','cmtophat@msn.com','Crystal Miller','424 Swope Ave','Colorado Springs','CO','UNITED STATES','80909','(719) 661-1918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 11:52:40',0,NULL,3,1,1,1,NULL,'petunia1953\r\\'),(2631,700725353011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','magie1992','francois2007@globetrotter.net','Francois   Pelletier','29-7e rue ouest','Ste-Anne-des-Monts','QC','CANADA','G4V2K4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:29:31',0,NULL,3,1,2,1,NULL,'magie1992\r\\'),(2632,576086025013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','mikshir','denisbot@rambler.ru','Dzianis Mikrukou','Internationalnaya str. 43 18','Bobrujsk','Mogilevskaya obl','BELARUS','213819','+375-29-3248340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:49:47',0,NULL,3,1,2,1,NULL,'mikshir\r欧标\r\\'),(2633,700731836011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gilphnx','gilphnx@hotmail.com','Gilfredo Adames','1020 Plover Ave','Miami Springs','FL','UNITED STATES','33166-4349','(305) 772-7622','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 13:50:19',0,NULL,3,1,1,1,NULL,'gilphnx\r\\'),(2634,576089131013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','meanmange','magnus@gata.se','Magnus Lindén','Spångatan 27 E','Malmö','-','SWEDEN','21153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:00:35',0,NULL,3,1,2,1,NULL,'meanmange\r\\'),(2635,700530063011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','bcshutterbug','autosmith@lakecable.ca','Tim Smith','PO Box 296','Sorrento','BC','CANADA','V0E 2W0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:01:40',0,NULL,3,1,2,1,NULL,'bcshutterbug\r\\'),(2636,778379368012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:11:21',0,NULL,8,1,17,0,NULL,'avextra-co-uk'),(2637,778381164012,220759518116,'Genuine Logitech Harmony LED 525 Remote Control',1,'RCLO005',43,'eastar4uk','hugogypsy','torview@btopenworld.com','Clare Hugo','Corgee Farm,','Bodmin','Cornwall','UNITED KINGDOM','PL305DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 14:17:00',0,NULL,3,1,3,1,' RA117718972CN\r\\','hugogypsy\rRCLO005'),(2638,700740021011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','rodrces','crodriguez@its-laredo.com','Cesar Rodriguez','10612 Cabo Wabo','Laredo','TX','UNITED STATES','78045-6558','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:19:10',0,NULL,3,1,4,1,' YW864488874CN\r、','rodrces'),(2639,576094552013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','thulakshan','terrothulakshan@yahoo.com','Vettivelu Thulakshan','49/8, 4th lane , Anuradhapura road,','Puttalam','North western','SRI LANKA','61300','0094770767807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:25:39',0,NULL,3,1,2,1,NULL,'thulakshan\r\\'),(2640,698442241011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','m3t4lh34d_6','kyleswentowsky@hotmail.com','Kyle Swentowsky','8231 Phasis Ct','Elverta','CA','UNITED STATES','95626-9697','(916) 991-1888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:25:58',0,NULL,3,1,1,1,NULL,'m3t4lh34d_6\r新地址\rKyle Swentowsky\rSan Nicolas Hall, Room 6340\rSanta Barbara, CA 93106\r\\\r\r'),(2641,778385270012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','jgollner','jgollner@bea.net','John M. Gollner','5887 Glenridge Dr NE<br>Ste 130','Atlanta','GA','UNITED STATES','30328-6191','(404) 256-9640','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:28:57',0,NULL,3,1,1,1,NULL,'jgollner\r\\'),(2642,778391021012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','candies69','drtongue96@yahoo.com','Jim Chabai','1011 Dudley Avenue','Winnipeg','MB','CANADA','R3M 1R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 14:46:02',0,NULL,3,1,2,1,NULL,'candies69\r\\'),(2643,0,320690461122,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',10.99,'eastar4','apontmi','mikea331@optonline.net','mike aponte','138 Kings Hwy','warwick','NY','UNITED STATES','10990-3115','(914) 582-9282','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:52:13',0,NULL,3,1,1,1,NULL,'apontmi\r\\'),(2644,777317178012,220581067419,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2002',12.5,'eastar4','nanes64','nanes64@comcast.net','Nestor Rosario','101 NW 187th Ave','Pembroke Pines','FL','UNITED STATES','33029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 14:56:42',0,NULL,3,1,1,1,' ','nanes64\r8pin 1.0 8cm 五线连接'),(2645,778403699012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','cole9nyc','nycole@gmail.com','C Nicole Phipps','860 Dekalb Ave<br>Apt 5','Brooklyn','NY','UNITED STATES','11221-2496','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:20:38',0,NULL,3,1,1,1,NULL,'cole9nyc\r\\'),(2646,699098578011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','wsf08262s','waltersflores@yahoo.com','walter flores','po box 2418','Jenkintown','PA','UNITED STATES','19046-8418','(215) 459-5520','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:42:47',0,NULL,3,1,1,1,NULL,'wsf08262s\r\\'),(2647,700770491011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.8,'eastar4','michael.ketchel','kaboomi2@yahoo.com','Michael Ketchel','800 Martinsburg Rd','Mount Vernon','OH','UNITED STATES','43050-9509','(740) 392-8707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 15:49:39',0,NULL,3,1,1,1,NULL,'michael.ketchel\rHP 8pin 1.25 25cm \r\\'),(2648,778420520012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','accessories2you','ebay@accessories2you.net','Sohail Hayat','21 Moss Street','Paisley','Renfrewshire','UNITED KINGDOM','PA1 1BE','08700278330','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 16:01:37',0,NULL,3,1,3,1,' RA117718442CN\r\\','accessories2you\rHSMO017\r英标'),(2649,778430669012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','suzanne_72','suzannewolny@hotmail.co.uk','Suzanne Wolny','5 Ford Crescent','Thornton','Fife','UNITED KINGDOM','KY1 4EB','01592572205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 16:26:22',0,NULL,3,1,3,1,' RA117718439CN\r\\','suzanne_72\rHSNO017\r英标'),(2650,700786803011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','ketenik','kete@freemail.gr','Nikolaos Ketetzidis','Karaoli Dimitriou 45','Drama','','GREECE','66100','00306946993356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:32:15',0,NULL,3,1,2,1,NULL,'ketenik\r欧标\r\\'),(2651,700787165011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.75,'eastar4','robertrabuf1','rjasr55@sbcglobal.net','ROBERT ANDERSON','6029 W 64TH STREET','CHICAGO','IL','UNITED STATES','60638','(773) 331-2687','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 16:35:35',0,NULL,3,1,1,1,NULL,'robertrabuf1\r\\'),(2652,700788747011,320631786282,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',15.5,'eastar4','goodnewsnutrition','sunshine496@bellsouth.net','Patrica Nasci','496 Fleming St','Sebastian','FL','UNITED STATES','32958-4212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 16:37:21',0,NULL,3,1,1,1,NULL,'goodnewsnutrition\r\\'),(2653,700789167011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','maxjazz123','chrithanner@gmx.at','Christian Thanner','Garnisonstraße 15<br>Zimmer 73B','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:38:10',0,NULL,3,1,2,1,NULL,'maxjazz123\r\\'),(2654,576132081013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','evilknight911','cmwong999@gmail.com','NG KIN CHI','ROOM 2302, CHEUNG SHUN HOUSE<br>CHEUNG WAH ESTATE, FANLING','default','','HONG KONG','default','96304037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 16:45:04',0,NULL,3,1,2,1,NULL,'evilknight911\r\\'),(2655,778456678012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','zjonesz','zjonesz@lyse.net','Bjørn Vidar Jones','Tuånå 20','Jørpeland','Rogaland','NORWAY','4100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 17:26:20',0,NULL,3,1,2,1,NULL,'zjonesz\r\r\\'),(2656,778417476012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',29.9,'eastar4','micha964','michael.wahl@t-online.de','Michael Wahl','Augustenstr.4','Stuttgart','','GERMANY','70178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:32:38',0,NULL,3,1,2,1,NULL,'micha964\r\\'),(2657,529981365004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','2010nsxv10','k20honda08@hotmail.com','Albert Kando','104 sugarcane ave','brampton','ON','CANADA','l6r0g5','(647) 801-4449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:36:19',0,NULL,8,1,17,0,NULL,'2010nsxv10'),(2658,529983857004,140482241274,'New in box SAMSUNG WEP200 Bluetooth Headset track#',1,'HSSA001',15.9,'cnfaner','2010nsxv10','k20honda08@hotmail.com','Albert Kando','104 sugarcane ave','brampton','ON','CANADA','l6r0g5','(647) 801-4449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 17:44:41',0,NULL,3,1,3,1,' RA117718986CN','2010nsxv10\rHSSA001\r一共买了两个'),(2659,700586519011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','nshtx561','nshtx@hotmail.com','luis espinoza','4525 21st St SW','lehigh acres','FL','UNITED STATES','33973','(561) 452-1332','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 17:44:59',0,NULL,3,1,1,1,NULL,'nshtx561\r\\'),(2660,576167851013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','jayceline_quek','jayceline.quek@gmail.com','Quek Jayceline','Blk 267 Tampines street 21 #08-33','Singapore','','SINGAPORE','520267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 18:28:28',0,NULL,3,1,11,1,NULL,'jayceline_quek\rHSPL001'),(2661,778514335012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','s.pancho.90023','mrfrank2402@yahoo.com','francisco gallegos','2743 Guirado St','Los Angeles','CA','UNITED STATES','90023-1434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:12:57',0,NULL,3,1,1,1,NULL,'s.pancho.90023\r\\'),(2662,530023377004,140516805344,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'cnfaner','semi_kimo','semikimo@gmail.com','samyon shayayev','bar yehuda 54','bat yam','','ISRAEL','59576','+972-544-311231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:39:37',0,NULL,3,1,3,1,'RA117718969CN\r\\ ','semi_kimo\rCACN001\r'),(2663,700875363011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','janesht','janesht@yandex.ru','Yaroslav Shturman','ul.Schapova<br>12-41','Yaroslavl','','RUSSIAN FEDERATION','150054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:40:58',0,NULL,3,1,2,1,'\\ ','janesht'),(2664,778537984012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','mtekiela','mtekiela@hotmail.com','Mike Tekiela','130 Stephens Road','London','London','UNITED KINGDOM','E15 3JL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 19:54:32',0,NULL,3,1,3,1,'RA117718456CN\r\\] ','mtekiela\rRELO002'),(2665,700882519011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',158.99,'eastar4','kaosbandit','adamsowens@gmail.com','Adam Owens','361 Castleton Cir','Boiling Springs','SC','UNITED STATES','29316','(864) 266-1965','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:55:06',0,NULL,3,1,1,1,NULL,'kaosbandit'),(2666,576203259013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','ruppel2854','kisel@gmx.net','Alexander Ruppel','Zur Sonnenhöhe 103','Iserlohn','','GERMANY','58636','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:01:21',0,NULL,3,1,2,1,NULL,'ruppel2854\r\\'),(2667,700885163011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','fredohdez','fredo@origen.com.mx','fredo hernandez balmaceda','Jojutla 93-3<br>Tlalpan centro','México','Distrito Federal','MEXICO','14000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:01:25',0,NULL,3,1,2,1,NULL,'fredohdez\r\\'),(2668,778550533012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','01514748365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:18:01',0,NULL,3,1,3,1,'RA117718924CN\r\\ ','avextra-co-uk\r一共买了4件\rOTCN004*10'),(2669,576210405013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','giannimiguel','g.miguel5@gmail.com','miguel gautier','la caudierie, route de lengronne','cerences','Basse-Normandie','FRANCE','50510','0659721041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:20:31',0,NULL,3,0,2,1,NULL,'giannimiguel\r欧标\r\\'),(2670,665362404001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','saulzamora1979','saulzamora1951@yahoo.com','saul zamora','4340 Ming Ave<br>Ste A','bakersfield','CA','UNITED STATES','93309-4885','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 20:42:38',0,NULL,3,1,1,1,NULL,'saulzamora1979\r\\'),(2671,700918447011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','giorgos3347','vlachos_g@hotmail.com','giorgos vlachos','stratoula<br>1','athens','nkosmos','GREECE','11744','210 9332374','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 21:13:37',0,NULL,3,1,2,1,NULL,'giorgos3347\r\\'),(2672,576232071013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','shoval1971','shovaal@hotmail.com','Shoval  Shimon','Haalonim 5','Beer yaakov','Israel','ISRAEL','70300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 21:28:13',0,NULL,3,1,2,1,NULL,'shoval1971\r\\'),(2673,576215740013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','12313alfred','autoaltima@hotmail.com','mohamed karout','12313<br>Alfred','Montreal','QC','CANADA','H1G5C8','(514) 835-9235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 21:51:29',0,NULL,3,1,2,1,NULL,'12313alfred\r\\'),(2674,576243070013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','maristel02','kristelraider@yahoo.com','marian  webster','3426 Merkner Dr','glen allen','VA','UNITED STATES','23060-3206','(804) 868-8666','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'maristel02'),(2675,778599081012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','burn1234567','burn2@comcast.net','Dragan Dimitrijevic','26710 w orchard ave','antioch','IL','UNITED STATES','60002-9133','(847) 589-0578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 22:10:08',0,NULL,3,1,1,1,NULL,'burn1234567\racer 8pin1.00 6cm \r\\'),(2676,576246798013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',158.99,'eastar4','bigshanon','bigshanon@gmail.com','Shanon Newson','po box 119','rye','Victoria','AUSTRALIA','3941','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:27:18',0,NULL,3,1,3,1,'RA117714030CN\r\\ ','bigshanon\rRCLO003'),(2677,778613233012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','nomel28','gangamartial@aol.com','Martial GANGA','210 ufton court<br>Canberra Drive','Northolt Middesex','Middlesex','UNITED KINGDOM','UB5 6JQ','07933934488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:55:00',0,NULL,3,1,2,1,NULL,'nomel28\r\\'),(2678,0,230613619088,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4','lriasnady','lriasnady1@wmconnect.com','RANDALL FOSTER','1875 Highway 907','MONTEREY','LA','UNITED STATES','71354','(318) 421-0106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 22:57:29',0,NULL,3,1,1,1,NULL,'lriasnady\r\\'),(2679,778637524012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','marioenr','mario@marsyl.ca','Mario Faucher','563 des pins','Ste-Brigide d\'iberville','QC','CANADA','j0j 1x0','(450) 577-1869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 00:20:09',0,NULL,3,1,3,1,'RA117718368CN\r\\ ','marioenr\rHSSH002\r'),(2680,576272467013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bdgold','asubhan175@yahoo.com','Abdus Subhan','C/ Carretes 34, 01º 01ª','Barcelona','Cataluña','SPAIN','08001','634273405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 00:34:39',0,NULL,3,1,2,1,NULL,'bdgold\r\\'),(2681,0,230613618490,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',9.99,'eastar4','dncfaeri','debnarasaki@comcast.net','deb narasaki','250 Parkside Dr','palo alto','CA','UNITED STATES','94306','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-27 00:35:36',0,NULL,3,1,1,1,NULL,'dncfaeri\r\\'),(2682,576288936013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','zensun-half','psunjar@yahoo.com','Peter Susnjar','7871 112A st','Delta','BC','CANADA','v4c4y4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 01:51:45',0,NULL,3,1,2,1,NULL,'zensun-half\r\\'),(2683,778679273012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.99,'eastar4','jtargosz1','jk@targosz.com','Jacek Targosz','12250 Milly Dr','doylestown','OH','UNITED STATES','44230-9328','(330) 606-8902','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 02:48:36',0,NULL,3,1,1,1,NULL,'jtargosz1\\'),(2684,778681037012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','ansel128','pauler@aei.ca','Bruno Bourgeois','2521 Chapleau','Montreal','QC','CANADA','H2K 3H5','(514) 521-8433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 02:53:22',0,NULL,3,1,2,1,NULL,'ansel128\r\\'),(2685,778683919012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','greathammadur','hammadurb@gmail.com','Hammadur Bhandari','18009 Cozumel Isle Dr','Tampa','FL','UNITED STATES','33647-3374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 03:04:22',0,NULL,3,1,1,1,NULL,'greathammadur\r\\'),(2686,774991163012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','goldhair78','goldhair8@hotmail.com','Phong Nguyen Ha','Körsbärsvägen 6','Hässleholm','Skåne','SWEDEN','28140','+46732020188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 04:03:16',0,NULL,3,0,2,1,NULL,'goldhair78'),(2687,778719175012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',3,'HSMO011',38.97,'eastar4','jtor7278','torresilla@hotmail.com','jose torres','3131 W Wapato Dr<br>Unit 61','moses lake','WA','UNITED STATES','98837-2955','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 06:04:01',0,NULL,3,1,1,1,' ','jtor7278'),(2688,778720869012,220747230960,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',10.5,'eastar4uk','kelvintse','kelvint2@hotmail.co.uk','Kelvin Tse','The Palace<br>The Close','Lichfield','Staffordshire','UNITED KINGDOM','WS13 7LH','07917110289','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 06:12:09',0,NULL,3,1,3,1,'RA117719006CN\r\\ ','kelvintse\rHSUE004'),(2689,701049653011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',4,'OTCN002',15.96,'eastar4','reggie.ferguson','jeremy@biasboating.co','Jeremy Hill','304 Manns rd','West Gosford','New South Wales','AUSTRALIA','2250','0243236273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 06:19:11',0,NULL,3,1,2,1,NULL,'reggie.ferguson'),(2690,524422780003,130490590870,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'cnfaner','rizabozaci','rizabozaci@gmail.com','riza bozaci','Serap Cad. Köroglu sok. Kursunlu Apt.<br>no:3 Daire:5 Adatepe','ISTANBUL','','TURKEY','34843','+905333898789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 08:32:20',0,NULL,3,1,3,1,' RA117718495CN','rizabozaci\rTRTT002*10\r把发票放在包装盒里'),(2691,778751386012,220704730766,'New Plantronics Voyager 855 Bluetooth Headset+carcharge',1,'HSPL009+CCPL001',25,'eastar4uk','suharoid','ilyin.viktor@gmail.com','Viktor Ilyin','4-1 Gzhatskaya Str. App. 39','Moscow','RU','RUSSIAN FEDERATION','121471','(7903)5684444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:38:56',0,NULL,3,1,3,1,'RA117718558CN ','suharoid\r\rHSPL009+CCPL001'),(2692,574063673013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','itishwang','djhwanghdj@naver.com','Hwang Dojung','10-16 Pil-dong 3-ga, Jung-gu','seoul','','KOREA,REPUBLIC OF','100-273','82-10-4721-5302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 08:48:21',0,NULL,3,1,3,1,' RA117718544CN','itishwang\rWWSI005'),(2693,576353316013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','aleksanderpap','a.poteev@gmail.com','Alexander Poteev','Rokossovsky aveniu 145-426','Minsk','','BELARUS','220085','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:05:22',0,NULL,3,1,2,1,NULL,'aleksanderpap'),(2694,778761657012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','sanson16','csac@misco.es','Carlos Sánchez Escudero','C/ de la Granja nº 20','Daganzo de Arriba','Madrid','SPAIN','28814','656595686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:17:48',0,NULL,3,1,2,1,NULL,'sanson16'),(2695,701098530011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.8,'eastar4','conodi','info@conodi.com','Conodi limited','Willibaldstrasse 27','München','','GERMANY','80689','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 10:13:06',0,NULL,3,1,2,1,' 、','conodi\racer 5pin1.25 4cm'),(2696,701111147011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mrcavad','premier5565@gmx.fr','Cavad Mamedov','Balabala Mecidov 56','Baku','','AZERBAIJAN','az1009','0707455565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:10:23',0,NULL,3,1,2,1,'、 ','mrcavad'),(2697,778793852012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','kheder1234','m.khodr@live.com.au','moe khodr','29 glengyle st','melbourne','Victoria','AUSTRALIA','3058','0422406253','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'kheder1234'),(2698,701122558011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','martunia0407','martusiek0407@o2.pl','Marta Bednarczyk','109 Gladstone st','west bromwich','West Midlands','UNITED KINGDOM','b71 1et','07597711266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:45:02',0,NULL,5,0,18,0,NULL,'martunia0407\r客户想撤单'),(2699,701136856011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','tecking_singapore','tecking_mail@yahoo.co.uk','Low Teck Ing','Block 234 Bukit Batok East Ave 5<br>#04-115','default','','SINGAPORE','650234','82820852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 12:36:34',0,NULL,3,1,11,1,NULL,'tecking_singapore\rADAK002'),(2700,776453581012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','ayannami','paulamontenegrodias@gmail.com','Paula Montenegro Dias','AVENIDA PREFEITO DULCIDIO CARDOSO<br>2920, AP 1601, BARRA DA TIJUCA','Rio de Janeiro','RJ','BRAZIL','22631-052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 13:36:48',0,NULL,3,1,3,1,' RA117718513CN','ayannami\rOTSO002'),(2701,778844082012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',27.99,'eastar4uk','jc.auctioneer','johnchen.yc@gmail.com','John Chen','25 Brickworks Drive','Brunswick','Victoria','AUSTRALIA','3056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 14:03:53',0,NULL,3,1,3,1,'RA117718487CN ','jc.auctioneer\rCMLO001'),(2702,701164985011,320684990784,'New Sony Ericsson HBH-DS200 Stereo Bluetooth  Headset',1,'HSSE009',39.85,'eastar4','discreetred7','heather.ustick@gmail.com','Heather Ustick','Unit 34/11 Fawkner Street','Braddon','Australian Capital Territory','AUSTRALIA','2612','0262759247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 14:14:24',0,NULL,3,1,3,1,' RA117718601CN','discreetred7\rHSSE009\r澳标'),(2703,576416693013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','444xc','j46w2005@aol.com','jimmy wright','102 Noble Ave NE<br>Apt B','roanoke','VA','UNITED STATES','24012-4733','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:33:50',0,NULL,3,1,1,1,NULL,'444xc\r\\'),(2704,701173913011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','raswalker','ebay@theoldjas.com','Petar Oldja III','2518 Madison St','Paducah','KY','UNITED STATES','42001','(732) 947-4122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:39:29',0,NULL,3,1,1,1,NULL,'raswalker\r\\'),(2705,701178589011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mannimondeo','meyer-remlingen@t-online.de','Manfred Meyer','Dorfstraße 4','Klein Biewende','','GERMANY','38319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 14:54:51',0,NULL,3,1,2,1,'、 ','mannimondeo'),(2706,701179158011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','1926chelsea','martin4fran@hotmail.com','martin green','2 rockfort est','wallingford','oxon','UNITED KINGDOM','ox10 9da','01491836282','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 14:55:30',0,NULL,3,1,3,1,'RA117718535CN ','1926chelsea\rMOAP001'),(2707,0,320690016092,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',2.9,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-27 14:57:56',0,NULL,5,0,18,0,NULL,'blue8sky'),(2708,0,220774366874,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',22.3,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:57:59',0,NULL,5,0,18,0,NULL,'blue8sky'),(2709,0,230613185007,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',12.9,'eastar4','blue8sky','coolstuffyouwant1@gmail.com','qi zhao, Panphil Realty','1025 S 8th St','Phila','PA','UNITED STATES','19147-4718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 14:58:06',0,NULL,5,0,18,0,NULL,'blue8sky'),(2710,701188162011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','verabatgirl','verabatgirl@telia.com','Veronica Carlsson','Brittgården 123','Tibro','','SWEDEN','54337','+46706944026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:21:16',0,NULL,3,1,2,1,' 、','verabatgirl'),(2711,778877249012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','transformersandgsmphones','labbek@gmail.com','Overseas Electronics','2457 W Devon Ave','Chicago','IL','UNITED STATES','60659-1914','(773) 274-3764','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 15:27:34',0,NULL,3,1,1,1,NULL,'transformersandgsmphones\r\\'),(2712,530256696004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','matute682','crespo_matias@hotmail.com','Matias Crespo','Aldo della rosa<br>5779','Villa Bosch','Buenos Aires','ARGENTINA','1682','+5491151101641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 16:32:59',0,NULL,3,1,3,1,' RA117718527CN','matute682\rHSMO007'),(2713,576452245013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',12.5,'eastar4','bazwebb','barry@essexboy.us','Barry Webb','285 Turkey Ridge Rd','Charlottesville','VA','UNITED STATES','22903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 16:40:58',0,NULL,3,1,1,1,NULL,'bazwebb\r\\'),(2714,701223587011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.8,'eastar4','bekir.ushcs','bekir.tuncer@ushcs.net','Bekir TUNÇER','4343 Shallowford Rd<br>Ste H4B','Marietta','GA','UNITED STATES','30062-5008','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 16:54:01',0,NULL,3,1,1,1,NULL,'bekir.ushcs\racer 4pin1.25 6cm \r\\'),(2715,778925306012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.8,'eastar4','lucianosobue','lucianosobue@gmail.com','Luciano Sobue','Av. Americo Dezorgi, 455<br>Jd. Bela Vista','Barrinha','São Paulo','BRAZIL','14860-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 17:22:28',0,NULL,3,1,2,1,'、 ','lucianosobue\rAcer 5pin1.25 3cm '),(2716,701252870011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','istencsaszar','ezittaz@vipmail.hu','Peter Stefkovics','Ludvigh u. 34.','Bekescsaba','','HUNGARY','5600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:00:08',0,NULL,3,1,2,1,'\\ ','istencsaszar\r'),(2717,576478722013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','crossxc','crosscountryci@gmail.com','Mikal Applewhite','1201 Wheeler St S','Tacoma','WA','UNITED STATES','98444-3843','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 18:03:54',0,NULL,3,1,1,1,NULL,'crossxc\r\\'),(2718,576480021013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','cesargoza','cesargoza@yahoo.com','Cesar Gonzalez','Alangasi Calle Juan Montalvo 431 y Abdón Calderon<br>Valle de los Chillos','Quito','Pichincha','ECUADOR','EC170151','593 97322242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:07:04',0,NULL,3,1,2,1,' 、','cesargoza'),(2719,778950272012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','madiazs','mads.mads@gmail.com','MAURICIO ALFONSO DIAZ SUAREZ','AVENIDA CONSISTORIAL 2320-33<br>PEÑALOLÉN','SANTIAGO','METROPOLITANA','CHILE','794-1137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:16:58',0,NULL,3,1,2,1,' 、','madiazs'),(2720,701265163011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',12.5,'eastar4','mfocker87','kaneymarta@hotmail.com','marta de juan romero','calle corral de cantos n 6 1-c','puente de vallecas','Madrid','SPAIN','28053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:24:26',0,NULL,3,1,2,1,' 、','mfocker87\rHP 8pin 1.0 23cm'),(2721,576485211013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','ecle7855','eduardo.clerigues@gmail.com','Eduardo Clerigues Martínez','Avda. Dr. J.J. Dominez 18 - 46','Valencia','Valencia','SPAIN','46011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 18:24:34',0,NULL,3,1,2,1,'、 ','ecle7855'),(2722,778962389012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','fac_clayton','clayton.luis@gmail.com','Clayton Luis Rodrigues','Rua Oswaldo Andrelli Silva, 41<br>Bloco B AP 24 Vila União, Campinas','Brazil','São Paulo','BRAZIL','13060774','55 19 81132048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 18:37:23',0,NULL,3,1,3,1,'RA117718500CN ','fac_clayton\rOTRA002'),(2723,701275457011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','evolv4ever','rnadal@hotmail.com','ray nadal','611 e blair st','west chicago','IL','UNITED STATES','60185','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 18:45:23',0,NULL,3,1,1,1,NULL,'evolv4ever\r\\'),(2724,701299923011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','positionx','robert@viascript.ca','Robert Brunet','257 Lepage','Dorval','QC','CANADA','H9S 3E7','(514) 631-1911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 19:33:24',0,NULL,3,1,2,1,'、 ','positionx'),(2725,779009242012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','fjr_07','fjr_gaviao@hotmail.com','Fernando Jose Ribeiro','Rua Embu-Guaçu  13-C<br>Vila Menck','Osasco','São Paulo','BRAZIL','06270250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 20:02:43',0,NULL,3,1,2,1,'、 ','fjr_07'),(2726,701331278011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',50,'TRMX002',427.5,'eastar4','usedrouters','purchasing@cablesandkits.com','AtlanTech Resellers, Inc.','4555 Atwater Ct<br>Ste A','Buford','GA','UNITED STATES','30518-3498','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 20:42:37',0,NULL,3,0,4,1,'YW866011382CN ','usedrouters\r'),(2727,530347871004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','lilas0425','christine.huot@hotmail.com','Christine Huot','3135 Stornoway Circle','Oakville','ON','CANADA','L6M5H9','(647) 267-2028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:30:50',0,NULL,3,1,3,1,' RA117718473CN','lilas0425\rHSPL011'),(2728,701358647011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','jaems8282','james8282@hanmail.net','JUNGBYUNG PARK','Block A, Flat 034, Room D, Piccadilly Point,<br>23 Berry Street,','Manchester','Greater Manchester','UNITED KINGDOM','M1 2AD','07749412439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:47:48',0,NULL,3,1,3,1,'RA117718561CN ','jaems8282\rUDAP001'),(2729,701360056011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','ruvvo','fareastern@gmail.com','YAN BOKALDER','Gamarnika street, 12-B, 30','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:51:39',0,NULL,3,1,3,1,'RA117718460CN ','ruvvo\rRCLO006\r'),(2730,576561989013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','bmeyer1888','bmeyer1888@msn.com','DIVE BAR','3035 White Bear Ave N<br>Ste 12','maplewood','MN','UNITED STATES','55109-1321','(612) 701-9896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 22:09:49',0,NULL,3,1,1,1,NULL,'bmeyer1888\r\\'),(2731,530358377004,140428313198,'2.1 Acer Travelmate 5520 bluetooth module offer track#',1,'BTAC2109',13.99,'cnfaner','snarf264','franshjj264@aol.com','Frans Beuvink','1194 Ute Pass','San Angelo','TX','UNITED STATES','76901','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:17:02',0,NULL,3,1,1,1,NULL,'snarf264\racer 4pin1.25 20cm\r\\'),(2732,701370955011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','kromulis4hys','kromulis@optonline.net','Kevin Facal','5 Oak Haven Pl','East Northport','NY','UNITED STATES','11731-6516','(631) 486-8700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-27 22:24:36',0,NULL,3,1,1,1,NULL,'kromulis4hys\r\\'),(2733,779092497012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','lorddc','gazza89@gmail.com','gary glover jr','10 palmstead road','sunderland','Tyne and Wear','UNITED KINGDOM','sr48ew','07961602267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 23:38:06',0,NULL,3,1,3,1,' RA117718575CN','lorddc\rOTCN003\r'),(2734,665820127001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','melons37','stnow@charter.net','Stephen Nowaskie','4817 N Camp Arthur Rd','Bruceville','IN','UNITED STATES','47516','(812) 882-0402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 00:10:53',0,NULL,3,1,1,1,NULL,'melons37\rLK044033648CN \r\\'),(2735,530379972004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',16.88,'cnfaner','segmentor','segmentor@terra.es','SAMUEL RAMOS ORIHUELA','C/ ITALIA, 21 - 2ºPISO','LAS PALMAS','Canarias','SPAIN','35006','928241484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 00:18:19',0,NULL,3,1,3,1,'RA117718589CN ','segmentor\rWLAT008\r'),(2736,575639598013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','syou1306','lookout21@optonline.net','Susan Young','21 Lookout Dr','Ledgewood','NJ','UNITED STATES','07852','(973) 445-0263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 00:20:12',0,NULL,3,1,1,1,NULL,'syou1306\r\\'),(2737,701438609011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',24.9,'eastar4','utru6083','chepa56@hotmail.com','URIEL TRUJILLO','93 PRINCETON AVE','DOVER','NJ','UNITED STATES','07801-2528','(973) 343-7808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 02:59:58',0,NULL,3,1,1,1,NULL,'utru6083\r\\'),(2738,665865643001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','panelsky2011kothwala','panelsky2011@gmail.com','KOTHWALA HERATH','453, VILLA REGINA<br>HEERASSAGALA','KANDY','CENTRAL','SRI LANKA','24000','0094716859686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 03:39:37',0,NULL,3,1,3,1,' RA117718748CN','panelsky2011kothwala\rOTSO001'),(2739,779169763012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','crystalccl','maria@crystalclean.com','Con Schultz','223 - 12 St B N','Lethbridge','AB','CANADA','T1H 2K8','(403) 381-0015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 04:36:38',0,NULL,3,1,2,1,'、 ','crystalccl'),(2740,530421479004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','kykla','y.kagan@yahoo.com','Yelena Kagan','9810 Juniper Hill Rd','Rockville','MD','UNITED STATES','20850','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 04:38:54',0,NULL,3,1,1,1,NULL,'kykla'),(2741,701474827011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','driver342933','brent.dunn@gmail.com','Brent Dunn','1177 Rockingham, Unit #3','Ottawa','ON','CANADA','K1H 8A6','(613) 907-1198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 06:09:39',0,NULL,3,1,2,1,'、 ','driver342933'),(2742,576670415013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','k3n610','kengio@gmail.com','Suppaseth Charoenkarnka','9/56 Vista Park Prachachuen<br>Samakkee Road, Bangtalad','Pakkred','Nonthaburi','THAILAND','11120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:05:59',0,NULL,3,1,2,1,NULL,'k3n610'),(2743,779224633012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','10roneno12','roneno12@bezeqint.net','ronen oren','lebar zaav  15','natanya','','ISRAEL','42524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:10:07',0,NULL,3,1,2,1,NULL,'10roneno12'),(2744,779230547012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',17.73,'eastar4','hardl0ck','hardlock@bk.ru','Yuriy Filippenko','Pobeda 87, 113','Zaporozhje','ZP','UKRAINE','69000','+380676147252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:36:30',0,NULL,3,1,2,1,NULL,'hardl0ck\r再发一个NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET \r欧标'),(2745,576677701013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','drumsrme','rick.retiredtech@gmail.com','Rick Berthiaume','595 iowa ave e','Saint Paul','MN','UNITED STATES','55130-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 09:51:32',0,NULL,3,1,1,1,'、 ','drumsrme'),(2746,576682177013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',189.9,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+79057183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:17:09',0,NULL,3,1,3,1,'RA117718853CN\r\\ ','michel_egorov\rWLAP008'),(2747,701527131011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','hozudogru','hozudogru@gmail.com','Hasim Ozudogru','GAZI UNIVERSITESI<br>ENDUSTRIYEL SANATLAR EGITIM FAKULTESI Bahçelievler Mah.','ANKARA','GOLBASI','TURKEY','06830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:21:42',0,NULL,3,1,2,1,NULL,'hozudogru\r欧标'),(2748,530467617004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','milanocarvalho','milanogc@gmail.com','Aurélio Carvalho','R. Gonçalves Ledo, 660. Apto. 502<br>Centro','Fortaleza','CE','BRAZIL','60110260','+558597192263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:33:20',0,NULL,3,1,3,1,'RA117718840CN\r\\ ','milanocarvalho\rOTRA002\r'),(2749,701532031011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','filet-crochet-designs','info@filet-crochet-designs.com','TATYANA  KARAMAGIAS','3, Viktor Hugo Str.','Thessaloniki','','GREECE','546 25','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:43:38',0,NULL,3,1,2,1,NULL,'filet-crochet-designs\r欧标\r\\'),(2750,574637924013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',74.8,'eastar4','vaggoz','vaggozpay@gmail.com','Evangelos Kalaitzakis','Apeiranthou 4','Galatsi','Athens','GREECE','11147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:43:39',0,NULL,3,1,3,1,'RA117718782CN\r\\ ','vaggoz\rMOSA002'),(2751,524727840003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','king3995','onlocation2005@sbcglobal.net','Carlos King','652 Albrook Dr','ALLEN','TX','UNITED STATES','75002-4701','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 10:44:51',0,NULL,3,1,1,1,'、 ','king3995'),(2752,779248798012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','visvaldas2010','letkauskasvisvaldas4@gmail.com','Visvaldas Letkauskas','Vapsvu 24<br>Karsakiskio sen. Naujiku k.','Panevezio raj.','Panevezio raj','LITHUANIA','38464','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 10:46:48',0,NULL,3,1,2,1,'\\ ','visvaldas2010\r欧标\r'),(2753,701340224011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',14.99,'eastar4','ps8jn','ps7jn@hotmail.com','Joaquim das Virgens Neto','Rua Goias 312-sul<br>Ilhotas','Teresina','Piaui','BRAZIL','64001-620','(86) 94339839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:43:02',0,NULL,3,1,2,1,'\\ ','ps8jn\r'),(2754,576699292013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','samuelgideon','samuelgid@gmail.com','gideon samuel','sokolov 126<br>frishman 2','holon','Israel','ISRAEL','58351','0548190169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:50:31',0,NULL,3,1,2,1,'\\ ','samuelgideon'),(2755,779278839012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','jerryjose_90','mangalathjerry@yahoo.com','jerry anto','3<br>Eynsford st','carindale','Queensland','AUSTRALIA','4152','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 12:35:32',0,NULL,5,0,18,1,NULL,'jerryjose_90\r\r已经退款'),(2756,530492930004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','cnay0','hiddent@swbell.net','Charlie Nay','542 N Main St','Duncanville','TX','UNITED STATES','75116-3655','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 12:51:39',0,NULL,3,1,1,1,'、 ','cnay0'),(2757,779284522012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','ibaie1990','noe.mage@gmail.com','Noé Mage c/o Manigley','14 route du crépis','Ballaison','Rhône-Alpes','FRANCE','74140','0041787147316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 12:52:46',0,NULL,3,1,2,1,'\\ ','ibaie1990'),(2758,779276600012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','yakkon39rus','yakkon@yandex.ru','Konstantin Yakunin','pt.Leninsky 94-14','Kaliningrad','Kaliningradskaya obl','RUSSIAN FEDERATION','236039','89114810481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:02:18',0,NULL,3,1,2,1,'\\ ','yakkon39rus'),(2759,576714634013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','mmenti','mame@bug.ch','Marco Menti','Bergstrasse 20','Stäfa','','SWITZERLAND','8712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:07:07',0,NULL,3,1,3,1,'RA117718836CN\r\\ ','mmenti\rWWSI004+ANCN001'),(2760,576720331013,230393147201,'2.1 Acer TM 2400 3210 3220 3230 Bluetooth Module +cable',1,'BTAC2122',12.8,'eastar4','treadmill537','john.gibson47@ntlworld.com','John Gibson','6 Glaramara Close<br>Brownsover','Rugby','Warwickshire','UNITED KINGDOM','CV21 1JE','07724850498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:32:31',0,NULL,3,1,2,1,'\\ ','treadmill537\racer 8pin1.00 8cm '),(2761,701578912011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','smint1986','ruslanass@gmail.com','Ruslanas Sobolevas','Alsėdžių 1-31','Kaunas','','LITHUANIA','LT-44456','+37065130390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:33:21',0,NULL,3,1,2,1,'\\ ','smint1986'),(2762,776733178012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','computer615','ryanbirk@gmail.com','Ryan Birk','10101 Pendula Dr','Indianapolis','IN','UNITED STATES','46236-7365','(317) 650-3310 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 13:36:49',0,NULL,3,1,1,1,'、 ','computer615'),(2763,779307056012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',4,'HSSH002',143.96,'eastar4','arkangel-hz3','foued@arkan.fr','foued moukid','24 allee de penthievre','livry gargan','Ile-de-France','FRANCE','93190','0682045368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:12:08',0,NULL,3,1,3,1,'RA117718819CN\r\\ ','arkangel-hz3\rHSSH002'),(2764,701591600011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','robantsto','robstorino@yahoo.com','Robert Storino','19121 Allison Square','West Windsor','NJ','UNITED STATES','08550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 14:19:58',0,NULL,3,1,1,1,'、 ','robantsto'),(2765,779316296012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tournataka0646','vriens.jurre@gmail.com','Jurre Vriens','Gerard Walschaplaan 48','Roosendaal','','NETHERLANDS','4707CS','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'tournataka0646'),(2766,701549092011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',2,'CACN003',27,'eastar4','321tocsin','post@tocsin.de','Manfred Bock','Frankenstr. 20','Remshalden','','GERMANY','73630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:41:34',0,NULL,3,1,2,1,'\\ ','321tocsin'),(2767,701613657011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',10,'HSPL009',439,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 15:27:39',0,NULL,3,1,4,1,'YW866011371CN ','gogo-buyers\r'),(2768,779338152012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maksym1378','max1378@ukr.net','Shaposhnykov Maksym','14 Ozernaya str.  App 16','Kiev','','UKRAINE','04209','0679023440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:36:30',0,NULL,3,1,2,1,'\\ ','maksym1378'),(2769,576753800013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','hawg_rider_2112','johnb5403@gmail.com','John Bayer','214-84 Oakville Ave.','London','ON','CANADA','N5V 2S5','(519) 455-6376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:51:17',0,NULL,3,1,3,1,'RA117718751CN ','hawg_rider_2112\rMOLO004\r华硕版的'),(2770,779353367012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','chooter50','chooter3@msn.com','ed Harris ATTN RuthMartin','1502 S Mildred St<br>Apt 204','Tacoma','WA','UNITED STATES','98465-1609','(253) 327-3871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 16:16:54',0,NULL,3,1,11,1,' RA117714366CN','chooter50\rANYA002'),(2771,779395388012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',2,'HSSE003',43.8,'eastar4','skylightindustries','saveholm@telia.com','Patrik  Säveholm','Forsbrovägen 4','Arbrå','none','SWEDEN','82010','070-2333167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 17:53:36',0,NULL,3,1,3,1,'RA117718907CN\r ','skylightindustries\rHSSE003\r欧标\r\\'),(2772,701672737011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','midnight1337','iambadkarma0@aim.com','Adam Batchelor','PO Box 553','Midland City','AL','UNITED STATES','36350-0553','(334) 797-4807','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 17:58:28',0,NULL,3,1,1,1,'、 ','midnight1337'),(2773,779408965012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','zaferzarar226','zaferzarar@gmail.com','ZAFER YAPICIOGLU','mumtaz apt.no:4<br>ismet inonu bulvari','GAZIMAGUSA','KIBRIS','TURKEY','MERSIN 10','00905338700018','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 18:21:27',0,NULL,3,1,2,1,NULL,'zaferzarar226\r欧标\r\\'),(2774,701689345011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','adonis.bunn','adonis.bunn@gmail.com','adonis bunn','825, José Tomasi','Curitiba','Paraná','BRAZIL','82015-630','55 41 33726746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 18:34:53',0,NULL,3,1,3,1,'RA117718822CN\r\\ ','adonis.bunn\r再发两个CAB-2626\rCASS003+CASS001'),(2775,779418454012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','tornadord','tornado1@mail.ru','Roman Dmitrievich','Tarhova st. 14b - 5','Saratov','Saratov','RUSSIAN FEDERATION','410064','+79033805555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 18:41:04',0,NULL,3,1,2,1,'\\ ','tornadord\r欧标'),(2776,576823040013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',60,'eastar4','trainergs1','cbrauning@goodwillakron.org','Chris Brauning','109 Karns Dr','Dover','OH','UNITED STATES','44622-9428','(330) 343-0612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 19:27:10',0,NULL,3,1,1,1,' ','trainergs1');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (2777,779453561012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',2,'HSSE003',43.8,'eastar4','shtimpee','shtimpee@yahoo.com.au','CIA Services Att Steve','PO Box 49','Seville','Victoria','AUSTRALIA','3139','61411334344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 19:46:04',0,NULL,3,1,3,1,'RA117718805CN\r\\ ','shtimpee\rHSSE003\r澳标'),(2778,779455205012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bobybravo','bobybravo@abv.bg','Boris Vasilev','Mednikarska 21','Veliko Tarnovo','Veliko Tarnovo','BULGARIA','5000','00359885223621','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 19:48:47',0,NULL,3,1,2,1,'\\ ','bobybravo'),(2779,576837067013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','goldengemini1981','goldengemini81@gmail.com','Jun Hoe Chow','18 Leschen Way','Darlington','Western Australia','AUSTRALIA','6070','0434410020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:09:46',0,NULL,3,1,2,1,'\\ ','goldengemini1981'),(2780,701738784011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','virtualsudip','f66459092@gmail.com','Manoj Rami (C/o Sabre Machinery Pvt. Ltd.)','B 21 Neelamber Apts., Near Bank Of Baroda<br>HL College -  Xaviers Corner, Navrangpura,','Ahmedabad','GJ','INDIA','380009','66059550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:18:01',0,NULL,3,1,3,1,' RA117718646CN','virtualsudip\rEXLO001'),(2781,576845484013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','adonis.bunn','adonis.bunn@gmail.com','adonis bunn','825, José Tomasi','Curitiba','Paraná','BRAZIL','82015-630','55 41 33726746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:33:46',0,NULL,8,1,17,0,NULL,'adonis.bunn'),(2782,576848594013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','jdboily','jdboily@gmail.com','Jean-Daniel Boily','123 laurie','Les coteaux','QC','CANADA','j7x0a3','(514) 467-5407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:43:18',0,NULL,3,1,3,1,'RA117718765CN\r\\ ','jdboily\rOTRA002'),(2783,701763936011,320684990784,'New Sony Ericsson HBH-DS200 Stereo Bluetooth  Headset',1,'HSSE009',39.85,'eastar4','niton_007','niton007@hotmail.com','nazrul islam chowdhury','stora sällskapets vag 24','stockholm','Skärholmen','SWEDEN','12731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:17:47',0,NULL,3,1,3,1,'RA117718632CN ','niton_007\rHSSE009\r'),(2784,779513105012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','msspencer-dassau','sonia.spencer10@yahoo.com','Sonia Spencer','4437 Mullens Ford Rd<br>Apt L','Charlotte','NC','UNITED STATES','28226-4015','(704) 277-6291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 21:59:34',0,NULL,3,1,1,1,'、 ','msspencer-dassau'),(2785,701777340011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','jayjaee2000','jason.saunders@comcast.net','Jason Saunders','700 E Prosperity Ave<br>APT 29','Tulare','CA','UNITED STATES','93274','(559) 302-7558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 22:01:20',0,NULL,3,1,1,1,'、 ','jayjaee2000'),(2786,779514791012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','rudykedem','rudy@rudy.org.il','Nemrod Kedem','3/3 Ha\'Imahot St.<br>POB 514','Nes-Ziona','','ISRAEL','74025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 22:03:08',0,NULL,3,1,2,1,'\\ ','rudykedem\r欧标'),(2787,779524840012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','gaz_mac','garymccreadie@supanet.com','Gary Mccreadie','Focus 31, East Wing<br>Ground Floor, Mark Road','HEMEL HEMPSTEAD','Hertfordshire','UNITED KINGDOM','HP2 7BW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 22:33:49',0,NULL,3,1,3,1,'RA117718779CN\r\\ ','gaz_mac\rOTRA002\r'),(2788,701797907011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','hags978','hagshollow1@gmail.com','David Haggarty','7341  9th  line<br>RR #3','Thornton','ON','CANADA','L0L2N0','(705) 424-1497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:08:57',0,NULL,3,1,2,1,'\\ ','hags978'),(2789,779545072012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gunzo90','gunzo.90@videotron.ca','frederic kleinbaum','1632 des bouvreuils','terrebonne','QC','CANADA','j7m1x3','(514) 867-1002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:43:28',0,NULL,3,1,2,1,'\\ ','gunzo90'),(2790,701814240011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','arec4328','amyrechner@live.com','amy rechner','2418 ravens crest dr','plainsboro','NJ','UNITED STATES','08536-2457','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:11:09',0,NULL,3,1,1,1,'、 ','arec4328'),(2791,576900452013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','funkrew','funkrewdotcom@yahoo.com','Patrick Lee','Barco, Inc.<br>11101 Trade Center Drive','Rancho Cordova','CA','UNITED STATES','95670','(916) 281-8114','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:19:30',0,NULL,3,1,1,1,'、 ','funkrew'),(2792,779558196012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','grune7','grune@localnetplus.com','Kevin Grubb','5715 Highfreeland Rd','Chandlersville','OH','UNITED STATES','43727','(740) 638-4740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:36:54',0,NULL,3,1,1,1,'、 ','grune7'),(2793,701823947011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dovewing2000','shunwu@mindspring.com','Shunwing Wu','6138 San Vicente Blvd','Los Angeles','CA','UNITED STATES','90048','(323) 936-4709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:50:04',0,NULL,3,1,1,1,NULL,'dovewing2000'),(2794,701824361011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mamarracho19','oscarzapata69@gmail.com','Oscar Zapata','27455 S Dixie Hwy','Homestead','FL','UNITED STATES','33032','(305) 336-3967','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 00:51:46',0,NULL,3,1,1,1,NULL,'mamarracho19'),(2795,576925899013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.7,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 02:22:21',0,NULL,3,1,3,1,'RA117718796CN\r\\ ','update_marcelo\rWWSI005'),(2796,666240416001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','don-halley','dehalley@ca.rr.com','Donald Halley','402 E Clarion Dr','Carson','CA','UNITED STATES','90745-1317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 02:47:28',0,NULL,3,1,1,1,'、 ','don-halley'),(2797,701856586011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','h.guzella','h.guzella@gmail.com','Henrique Guzella','Av. Queiros Filho 442<br>Pq. Industriário','Santo André','São Paulo','BRAZIL','09110-260','(55 11) 75140010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 03:03:06',0,NULL,3,1,2,1,'\\ ','h.guzella\r欧标'),(2798,779601947012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','apatten','allanpatten@hotmail.com','Allan Patten','A. Harvey<br>60 Water St','St. John\'s','NL','CANADA','A1C 5V6','(709) 687-4493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 03:03:56',0,NULL,3,1,2,1,'\\ ','apatten'),(2799,701859652011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','saab914','saab914@aol.com','Peter J Ortiz','6928 Fox Haven Pl','Raleigh','NC','UNITED STATES','27616','(919) 647-4016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 03:16:47',0,NULL,3,1,1,1,'、 ','saab914'),(2800,701866484011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','king_of_misc','c.g.beadles@gmail.com','cory beadles','208 N 24th Ave','Hattiesburg','MS','UNITED STATES','39401-5938','(601) 341-9170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 03:50:29',0,NULL,3,1,1,1,'\\ ','king_of_misc'),(2801,576953714013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','fjelltun','e.aure@hotmail.com','Eivind Aure','Klungrebakken','Skodje','Skodje','NORWAY','6260','90094036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 05:24:34',0,NULL,3,1,2,1,' \\','fjelltun'),(2802,701885205011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','victorasieduyoung','victor.asieduyoung51@gmail.com','Victor Asiedu-Young','71 Nightstar Drive','Richmond Hill','ON','CANADA','L4C 8H5','(647) 701-5952','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'victorasieduyoung'),(2803,701894695011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','kevinlouie','kevinlouie@hotmail.com','Kevin Louie','215 Park Row<br>Apt. 6E','New York','NY','UNITED STATES','10038','(917) 836-1810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 06:35:21',0,NULL,3,1,1,1,'\\ ','kevinlouie'),(2804,779646594012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'eastar4','deeznutz2377','deeznutz@internode.on.net','Brad Kyaw','28 Heatherdale Street','Amaroo','Australian Capital Territory','AUSTRALIA','2614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 06:52:52',0,NULL,3,1,3,1,' RA117718650CN','deeznutz2377\rOTGR001+OTGR002\r'),(2805,576985752013,230545855021,'2.1 Acer TM 3000 3020 /AS5760 Bluetooth Module+cable',1,'BTAC2126',12.8,'eastar4','kw9_greece','kw9@mail.ru','Yuri Nikolaidis','Papafeofilou 9','KILKIS','KILKIS','GREECE','61100','030 6972961100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:15:56',0,NULL,3,1,2,1,NULL,'kw9_greece\racer 8pin1.25 10cm'),(2806,574373343013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','poshk2009','poshkevin@gmail.com','POSH Poon','21b<br>yelverton st','st peters','New South Wales','AUSTRALIA','2044','0403743886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:01:16',0,NULL,3,1,2,1,NULL,'poshk2009\r澳标'),(2807,701942529011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','richb0','richard.boulding@ntlworld.com','Richard boulding','18, Baldocks lane','Melton Mowbray','Leicestershire','UNITED KINGDOM','LE131EN','07773559487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:29:27',0,NULL,3,1,2,1,'\\ ','richb0'),(2808,530751957004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','jsnider1970','jsnider1970@yahoo.com','Joe Snider','2267 Ravenwood Trl','Marietta','GA','UNITED STATES','30066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 10:58:08',0,NULL,3,1,1,1,'\\ ','jsnider1970'),(2809,779689458012,220713846354,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET+carcharger',1,'HSNO006+CCNO001',11.49,'eastar4uk','joaosimas','joaosousasimas@hotmail.com','João Simas','Rua Dos Canos Verdes N.º 10<br>Angra do Heroismo','Angra do Heroismo','açores','PORTUGAL','9700-040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 10:59:08',0,NULL,3,1,2,1,' \\','joaosimas'),(2810,779702417012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','jaras_cro','josiparas@gmail.com','Josip Aras','Obala palih omladinaca 11','Šibenik','Croatia','CROATIA','22000','+38598816414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 10:59:34',0,NULL,3,1,3,1,'RA117732095CN\r ','jaras_cro\rOTCN004*10\r'),(2811,576430039013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','thing2397','siewthing2397@hotmail.com','soh siew thing','10E, Jalan Muar','Segamat','Johor','MALAYSIA','85000','0167172566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:48:02',0,NULL,3,1,2,1,'\\ ','thing2397'),(2812,701964695011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','j5robert','j5robert@alumni.uwaterloo.ca','Jon Robertson','223 High Park Ave<br>bsmt','Toronto','ON','CANADA','M6P2S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:00:49',0,NULL,3,1,2,1,'\\ ','j5robert'),(2813,701967983011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zetlaw','zetlawi@bezeqint.net','Idan Zetlawi','Bialik 121/2','Beer-sheva','','ISRAEL','84308','972544910895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:14:18',0,NULL,3,1,2,1,'\\ ','zetlaw'),(2814,779732551012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','route66_oldie','holjoh1@yahoo.com','John Holman','PO Box 445','kingman','AZ','UNITED STATES','86402-0445','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 12:49:35',0,NULL,3,1,1,1,NULL,'route66_oldie\\'),(2815,701977092011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','tobiasherzog12121212','tobias@herzog.hk','Patrick Herzog','1/F U-C Court<br>25 Stanley Market Road','default','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 12:50:34',0,NULL,3,1,2,1,'\\ ','tobiasherzog12121212'),(2816,576243070013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','maristel02','kristelraider@yahoo.com','marian  webster','3426 Merkner Dr','glen allen','VA','UNITED STATES','23060-3206','(804) 868-8666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 14:10:07',0,NULL,3,1,1,1,'\\ ','maristel02'),(2817,702006571011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.7,'eastar4','froggyluv1981','melissa.cottew@gmail.com','Melissa Cottew','4721 Avery St','Columbus','GA','UNITED STATES','31907','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-29 14:27:18',0,NULL,3,1,1,1,'\\ ','froggyluv1981'),(2818,779772497012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','4klx','a.allen@orange.net','Alexander Allen','16 Crowhurst Road,<br>Borough Green','Sevenoaks','Kent','UNITED KINGDOM','TN15 8SJ','07974665202','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 14:52:36',0,NULL,3,1,3,1,'RA117732016CN\r ','4klx\rOTCN004*10'),(2819,779779166012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','cracksloth','michaelmoore@fastmail.fm','michael moore','2411 Antler Point Dr','Henderson','NV','UNITED STATES','89074-6257','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 15:14:20',0,NULL,3,1,1,1,'\\ ','cracksloth'),(2820,666414373001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','pr0pet','rcrrob@hotmail.com','Rob Hepburn','33 Vereyken Cres','Petawawa','ON','CANADA','k8h 3m3','(613) 440-1784 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 16:10:44',0,NULL,3,1,3,1,'RA117732055CN\r ','pr0pet\rOTSO001'),(2821,702048958011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','73mark1','marklang8@hotmail.co.uk','Mark Lang','C/O Mullions Hotel<br>51 High Street','STREET','Somerset','UNITED KINGDOM','BA16 0EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 16:40:02',0,NULL,3,1,3,1,'RA117732104CN\r ','73mark1\rMOAP001'),(2822,779815711012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','heatherann25','autoknow@rogers.com','Heather A. Gouchie','3538 Route 106','Salisbury West','NB','CANADA','E4J 3J2','(506) 372-5492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 16:50:29',0,NULL,3,1,2,1,'\\ ','heatherann25'),(2823,577084111013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','soos.viktor','soos.vitya@gmail.com','Soós Viktor','Csengeri utca 13/A','Isaszeg','','HUNGARY','2117','+36-30-491-5076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:15:05',0,NULL,8,1,2,1,NULL,'soos.viktor'),(2824,702066384011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','rafaelws','rafaelws@globo.com','Rafael Wilson','Rua Cisplatina 660 apt12','Sao Paulo','SP','BRAZIL','04211040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:25:06',0,NULL,3,1,2,1,'\\ ','rafaelws'),(2825,577092037013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','sereshe','seresheorg@gmail.com','Sereshe Kariyawasam','No : 70/1A, Colombo Road, Rathanapitiya,<br>Boralesgamuwa.','Boralesgamuwa - Colombo','Western Province - Colombo','SRI LANKA','10290','0094-777-591-561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:30:57',0,NULL,3,1,2,1,'\\ ','sereshe  送欧标头\r'),(2826,779832184012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','arenosetella','sonmezserdar@gmail.com','serdar sönmez','balikesir üniversitesi fen edebiyat fakültesi<br>biyoloji bölümü','balıkesir','balıkesir','TURKEY','10145','+905303447184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 17:31:48',0,NULL,3,1,3,1,'RA117732020CN\r ','arenosetella\rOTSO002'),(2827,779854623012,220704209256,'NEW PLANTRONICS EXPLORER 340 headset E340 w/charger',1,'HSPL007',18.9,'eastar4','lriska1','iralspb@yandex.ru','Irina Lushnikova','Irinovskij pr., 31/48, kv. 178','Saint-Petersburg','','RUSSIAN FEDERATION','195279','+79052657323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:19:05',0,NULL,3,1,2,1,'\\ ','lriska1\r欧标'),(2828,577107927013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','matt2005matt','mathol2005@hotmail.com','Matt McGarrah','599 Madison 1516','Huntsville','AR','UNITED STATES','72740-7088','(479) 325-0808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 18:25:06',0,NULL,3,1,1,1,'\\ ','matt2005matt'),(2829,525125997003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',14.99,'cnfaner','tycho72','thorsten-sommer@versanet.de','Thorsten Sommer','Senftenberger Ring 83','Berlin','','GERMANY','13435','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:44:17',0,NULL,3,1,3,1,'RA117732064CN\r ','tycho72\rHSNO007\r欧标'),(2830,778852118012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',27.8,'eastar4uk','v-yellow','vardikos@yellowroom.gr','Nektarios Vardikos','Aristotelous 10','Thessaloniki','Greece','GREECE','54623','+30 2310947271','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 20:23:50',0,NULL,3,1,3,1,'RA117732550CN\r ','v-yellow\rHSSE005+HSSE003\r欧标\r再发一个NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset\r'),(2831,779932138012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','iort8587','rplufkil2011@hotmail.com','Ivonne Ortiz','5220 Reed Dr','The Colony','TX','UNITED STATES','75056','(469) 384-5472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-29 21:11:46',0,NULL,3,1,1,1,NULL,'iort8587\\'),(2832,779939044012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',4,'BALO008',26.4,'eastar4','sethos.x','sethosx@t-online.de','Matthias Quester','Buckower Damm 255a','Berlin','','GERMANY','12349','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 21:32:09',0,NULL,3,1,2,1,'\\ ','sethos.x'),(2833,779964478012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',2,'ANYA002',39,'eastar4','knetphils','ebay@deanwestbury.com','Dean Westbury','Sitio Centro<br>Barangay Dulangan','Puerto Galera','Oriental Mindoro','PHILIPPINES','5203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 22:52:11',0,NULL,3,1,3,1,'RA117715021CN ','knetphils\rANYA002\r'),(2834,779967080012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','mrbricolage123456','a.lejal@ficam.com','Alexandre LEJAL','14 rue du clos de la montespan','saint jean de la ruelle','Centre','FRANCE','45140','02.38.45.77.73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:00:43',0,NULL,3,1,2,1,'\\ ','mrbricolage123456'),(2835,702193082011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','ragnarjonny','s.ragnar@yahoo.no','Ragnar Sundsås','Bleikenveien 173','Brandbu','','NORWAY','2760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 23:11:29',0,NULL,3,1,2,1,'\\ ','ragnarjonny'),(2836,577190787013,230576095186,'Logitech MX518 MX 518 Gaming Optical USB Mouse 90% new',1,'MOLO003',32.9,'eastar4','dragoniade','dragoniade0@gmail.com','Philippe Busque','5-81 Louise','Longueuil','QC','CANADA','J4J 2T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:47:15',0,NULL,3,1,3,1,'RA117733011CN\r ','dragoniade\rMOLO003'),(2837,702202750011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','tomersh','tomer@shiri.info','Tomer Shiri','Sufit 1','Lehavim','','ISRAEL','85338','+97286518833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:54:24',0,NULL,3,1,2,1,'\\ ','tomersh'),(2838,779984497012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','txsr','ramos_thiago@hotmail.com','Thiago Xible Salles Ramos','Avenida Dante Micheline, numero 1545, apartamento 501, Mata da Praia','Vitória','Espírito Santo','BRAZIL','29066-430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 00:10:49',0,NULL,3,1,2,1,'\\ ','txsr'),(2839,702206535011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','leonardodiaz','ljosediaz.r@gmail.com','Leonardo Diaz','7 / 85-87 Wyrallah Road','East Lismore','New South Wales','AUSTRALIA','2480','0401076908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 00:22:29',0,NULL,3,1,2,1,'\\ ','leonardodiaz'),(2840,577203215013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',92.7,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 01:03:14',0,NULL,3,1,3,1,' RA117732444CN','update_marcelo\rWWSI005\\'),(2841,780020530012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','skinnyjeep','bfreyman@gmail.com','Brett Freyman','po box 132','Fairfield','PA','UNITED STATES','17320-0132','(717) 504-3506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 02:40:55',0,NULL,3,1,1,1,NULL,'skinnyjeep\\'),(2842,780020674012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','tigge811','tigge811@gmail.com','victor chong','5301 McFarren Blvd','Mississauga','ON','CANADA','L5M 6C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 02:45:31',0,NULL,3,1,2,1,'\\ ','tigge811'),(2843,577232111013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',5,'HSPL005',67.5,'eastar4','quydautu','quydautu.vn@gmail.com','AAAHR blue','510 Parrott St<br>Ste 2','San Jose','CA','UNITED STATES','95112-4117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 04:06:42',0,NULL,3,1,1,1,'\\ ','quydautu'),(2844,577237374013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','luizcahue','luizcahue@gmail.com','Luiz Cahue','Rua Cajuru nº140<br>Casacadura','Rio de Janeiro','RIO DE JANEIRO','BRAZIL','21311040','55 21 9119-7255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 04:50:36',0,NULL,3,1,2,1,'\\ ','luizcahue'),(2845,780047445012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','huttnutt42','huttnutt42@aol.com','Johnie Hudson','19701 Freeland St','Detroit','MI','UNITED STATES','48235-1512','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 05:07:56',0,NULL,3,1,1,1,NULL,'huttnutt42\\'),(2846,780049813012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',14.99,'eastar4','107okp','djrowell@bigpond.net.au','Dudley  R Rowell','18 Cosette Street','Bracken Ridge','Queensland','AUSTRALIA','4017','0732617161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 05:14:44',0,NULL,3,1,2,1,'\\ ','107okp'),(2847,702266398011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','illdevilinc','illdevilinc@gmail.com','Justin Ledoux','1761 Boxwood ave.','san leandro','CA','UNITED STATES','94579','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 05:25:35',0,NULL,3,1,1,1,'\\ ','illdevilinc'),(2848,780058457012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','jkranjc1968','s52jk@lea.hamradio.si','JOZE KRANJC','Dorfarje 45','Zabnica','','SLOVENIA','SI-4209','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 06:05:06',0,NULL,3,1,2,1,'\\ ','jkranjc1968'),(2849,577271961013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','dinoefthimios','mikey.revival@yahoo.com','efthimios katsonis','el.venizelou 29-ilion<br>ilion','athens','athens','GREECE','13121','00306972259333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:08:23',0,NULL,3,1,2,1,'\\ ','dinoefthimios\r欧标'),(2850,577274310013,230412690731,'2.0 New ASUS Bluetooth Module+cable A8/Z99/F8/N80/U5/U6',1,'BTHU2001',12.5,'eastar4','beikeland','beikeland@gmail.com','Bjørn Eikeland','Strømgaten 18','Bergen','','NORWAY','5008','004793439020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:21:18',0,NULL,3,1,2,1,'\\ ','beikeland\r华硕10pin 0.8 6cm '),(2851,780109257012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',23.8,'eastar4uk','bebo500','sales@bsl-cctv.com','Hugh  Boyne','269 Boundary Road','Walthamstow','London','UNITED KINGDOM','E178NE','02085098000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 09:51:19',0,NULL,3,1,3,1,' RA117733100CN\r','bebo500\rOTCN004*10'),(2852,780124979012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',26,'eastar4uk','nonye.atueyi','atueyi_emma@yahoo.com','Emmanuel Atueyi','73 Hinchley Wood Grove','BRAMPTON','ON','CANADA','L6V4B1','(905) 452-9184','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 10:52:52',0,NULL,3,1,3,1,'RA117733025CN\r ','nonye.atueyi\rWWSI002+ANCN001'),(2853,779369274012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',5,'HSSE005',69.5,'eastar4uk','bogunovic46','zulee46@yahoo.com','Milos Djuric','Balkanska 12','Belgrade','Serbia','SERBIA','11000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 10:54:27',0,NULL,3,1,3,1,' RA117718915CN','bogunovic46\rHSSE005\r欧标'),(2854,702336203011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','lorna.sawyers','lorna.sawyers@yahoo.com','Lorna Sawyers','19 Coopers Road, Handsworth Wood','Brmingham','West Midlands','UNITED KINGDOM','B20 2JS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 10:59:13',0,NULL,3,1,3,1,'RA117732081CN\r ','lorna.sawyers\rMOAP001'),(2855,702349734011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','nonamenlsubs','noname.nlsubs@gmail.com','Johnny Berben','Hubert Goffinstraat 1','Genk','','BELGIUM','3600','0486376726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 11:51:45',0,NULL,3,1,2,1,'\\ ','nonamenlsubs\r欧标'),(2856,577308280013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',104.1,'eastar4','dam11gh','damien.lozach@free.fr','Damien LOZAC\'H','6 rue de la Fonderie','Trémuson','Bretagne','FRANCE','22440','06 85 62 01 72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 12:27:36',0,NULL,3,1,4,1,'YW866010822CN ','dam11gh\rCASS003+TRTS001\r再发两个 AT-210TS '),(2857,780155865012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.8,'eastar4','proedrosdk','chlisnick@hotmail.com','nick chlis','chora andros','andros','kuklades','GREECE','84500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 12:34:44',0,NULL,3,1,2,1,'\\ ','proedrosdk\racer 5pin1.25 15cm'),(2858,780160469012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','jwoodyard07','angel16221@nycap.rr.com','Jessica Woodyard','430 Route 146<br>Lot 162','Clifton Park','NY','UNITED STATES','12065','(518) 383-8212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 12:49:08',0,NULL,3,1,1,1,'\\ ','jwoodyard07'),(2859,525298060003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-30 13:23:55',0,NULL,3,1,3,1,'RA117718694CN\r ','anyquilmes10\rOTJE001'),(2860,780190133012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','jpportier4122','jppor@bluewin.ch','Jean Pierre Portier','Chemin des Bois 101','Veyrier','','SWITZERLAND','1255','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 14:18:30',0,NULL,3,1,3,1,'RA117732529CN\r ','jpportier4122\rHSLO002'),(2861,577334613013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',71.97,'eastar4','theburkey','theburkey@cox.net','Jarret Burkey','400 SW 8th Ave<br>Hill\'s Pet Nutrition, Inc','Topeka','KS','UNITED STATES','66603-3925','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 14:24:31',0,NULL,3,1,1,1,NULL,'theburkey\\'),(2862,702420381011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','at22987','ebay@erber.biz','Marcus Erber','Embelgasse 39/27','Wien','','AUSTRIA','1050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:39:10',0,NULL,3,1,3,1,'RA117732475CN\r ','at22987\rEXLO001'),(2863,702429405011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','akatamaxitoss','sschizas@msn.com','savvas schizas','kyriakou kakouli<br>4 geri','nicosia','00357','CYPRUS','2200','99531293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 16:04:40',0,NULL,3,1,2,1,'\\ ','akatamaxitoss\r英标\r银色的'),(2864,577361035013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','kei-1','jackiesfridge@hotmail.com','Brett Hiorns','3094 Cty Hwy X','Stevens Point','WI','UNITED STATES','54482','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 16:06:31',0,NULL,3,1,1,1,NULL,'kei-1\\'),(2865,702257405011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','computer_parts_direct_2_u','gossbn@msn.com','Brad Goss','2045 Hickory Ln','Oak Harbor','WA','UNITED STATES','98277-3408','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 16:48:00',0,NULL,3,1,1,1,'\\ ','computer_parts_direct_2_u'),(2866,780259059012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ebjim99','gmjim99@gmail.com','Dimitris Koumoutsos','SP. LAMPROU 44<br>PIRAEUS - KALLIPOLI','PIRAEUS','','GREECE','185 38','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:10:41',0,NULL,3,1,2,1,'\\ ','ebjim99'),(2867,531096821004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','realsqueezy','sven@speedproject.de','Sven Ritter','Otto-Lilienthal-Strasse 11b','Varel','','GERMANY','26316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:18:34',0,NULL,3,1,3,1,'RA117731276CN\r ','realsqueezy\rMOLO001'),(2868,577389139013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','liljabj','alvena_jones@yahoo.com','Alvena Jones','2105 Ridge Park Dr','Little Rock','AR','UNITED STATES','72204-3548','(501) 416-0000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 17:41:04',0,NULL,3,1,1,1,'\\ ','liljabj'),(2869,702474613011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',5,'BTAC2022',62.5,'eastar4','azelzo','korpassyz@gmail.com','Ferenc Vajda','Kiss József utca 102.','Kerepes','Pest','HUNGARY','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 17:58:46',0,NULL,3,1,3,1,' RA117732489CN','azelzo\racer 8pin1.00 15cm \rBTAC2022\\'),(2870,780290323012,220726309168,'New in box Logitech H530 USB Headset ear-cup 981-000195',1,'HSLO002',46.5,'eastar4','mse65$','mscorpe@gmail.com','Ehud Cohen','Sheftel 12','Rishon le zion','israel','ISRAEL','75234','0545-847277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:17:24',0,NULL,3,1,3,1,'RA117732532CN\r ','mse65$\rHSLO002'),(2871,577409053013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','vic_f','victor@vipnetworks.com','Victor Feng','43532 OCASO CORTE','FREMONT','CA','UNITED STATES','94539','(510) 226-7572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 18:45:38',0,NULL,3,1,1,1,'\\ ','vic_f'),(2872,700438082011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',24.59,'eastar4uk','nickscottjones','nicksj93@me.com','Nick Scott-Jones','19 Greenfield Avenue<br>Kippax','Leeds','West Yorkshire','UNITED KINGDOM','LS25 7PS','07926547564','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 18:55:18',0,NULL,3,1,3,1,NULL,'nickscottjones\rUDAP001潘\\'),(2873,780309833012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','kf_2002_kf','karsten@bank24.net','Karsten Fillmer','1145 Spanish Lace Ln','Vero Beach','FL','UNITED STATES','32963-2351','(772) 231-1173','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 18:57:11',0,NULL,3,1,1,1,NULL,'kf_2002_kf\\'),(2874,702501866011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','kruzz-74','andy_phuakh@yahoo.co.uk','Andy Phua','5 Solok Sulam 2,<br>Taman Maznah','Klang','Selangor','MALAYSIA','41000','012-6616664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:59:40',0,NULL,3,0,2,1,'\\ ','kruzz-74'),(2875,702533204011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','leopolregpor','leopolreg@ono.com','Leopoldo Regidor Portero','Urb. Verdeluz, Nº 22 ,1º C<br>Huelva','Huelva','Andalucía Ceuta y Melilla','SPAIN','21005','654141788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:15:24',0,NULL,3,0,3,1,'RA117731302CN\r ','leopolregpor\rGLSG001'),(2876,577442007013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','dudushka','demia-75@hotmail.com','Petimat Demilhanova','Sjøvollvegen 8','selbu','selbu','NORWAY','7580','004793676928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:28:42',0,NULL,3,1,3,1,NULL,'dudushka\rHSNO019\r欧标潘\\'),(2877,780406327012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','nickz_de','robert.zednik@web.de','Robert Zednik','Am Fuchsbau 7A','Pfungstadt','','GERMANY','64319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 22:59:53',0,NULL,3,1,2,1,'\\ ','nickz_de'),(2878,702603961011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'MOSA005',203.97,'eastar4','srrman','thebibbsmail@comcast.net','Alan Bibb','51 Saint Roberts Dr','Stafford','VA','UNITED STATES','22556-3632','(540) 659-6638','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 00:05:00',0,NULL,3,0,1,1,'\\ ','srrman\rGLSG001'),(2879,577500087013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.9,'eastar4','leodwd','leodwd@yahoo.com','donald doyle','po box 1204','Klamath Falls','OR','UNITED STATES','97601','(503) 750-1881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:01:44',0,NULL,3,1,1,1,'\\ ','leodwd'),(2880,780339694012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','valauch','lauchjr2@aol.com','Lauch Bennett','912 Patrick Dr','West Palm Beach','FL','UNITED STATES','33406-4438','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:18:50',0,NULL,3,1,1,1,'\\ ','valauch'),(2881,702556146011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','billyjpatton','billyjpattonesq@verizon.net','Bill Patton Esq.','1428 N 2nd St<br>1st Floor','Harrisburg','PA','UNITED STATES','17102-2635','(717) 230-9310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 01:19:00',0,NULL,3,1,1,1,NULL,'billyjpatton\\'),(2882,780460564012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','armzzz','armzzz@hotmail.com','Wasan Sinswang','53/317 Maungthongthani  Tiwanon Rd.<br>Bangpood','Pakkred','Nonthaburi','THAILAND','11120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 02:26:08',0,NULL,3,1,3,1,' RA117732206CN','armzzz\rOTRA002\r\\'),(2883,780468068012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','sylbar84','sylbar84@videotron.ca','Nicolas Sylvestre','2150 des intendants app 1','quebec','QC','CANADA','g1j2k3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 02:56:09',0,NULL,3,1,2,1,'\\ ','sylbar84'),(2884,702644462011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','newtemps','wiredtorch@hotmail.com','Jonathan Ridley','6240 Westdale Dr','Grand Blanc','MI','UNITED STATES','48439-8509','(810) 624-4051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:03:20',0,NULL,3,1,1,1,'\\ ','newtemps'),(2885,780470230012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',2,'HSMO007',23.8,'eastar4','divedeep100','smeadowsjr@live.com','steve meadows jr','1215 fennimore st','fairmont','WV','UNITED STATES','26554','(304) 692-5828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 03:06:38',0,NULL,3,1,1,1,'\\ ','divedeep100'),(2886,780472156012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','like2buy-like2sell','acer1@aol.com','Marcos Peixoto','1090 E River Pkwy','Santa Clara','CA','UNITED STATES','95054-4188','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:14:01',0,NULL,3,1,1,1,'\\ ','like2buy-like2sell'),(2887,531237387004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','zohar_yd','zohar_yd@bezeqint.net','Zohar Yehuda','P.O. Box 1268','Kfar Saba','','ISRAEL','44111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 04:44:51',0,NULL,3,1,3,1,' RA117732118CN','zohar_yd\rOMHJ001\\'),(2888,666954616001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','kurdtcobain316','philghazal@shaw.ca','Phil Ghazal','12071 21st Ave SW','Edmonton','AB','CANADA','T6W 0C7','(780) 757-0737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 04:57:29',0,NULL,3,1,3,1,' RA117732501CN','kurdtcobain316\rOTSO001\\\r'),(2889,780522726012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','esile_audio','ebay@esile.de','iStereo, Hr. Christian Blechinger','Pöllatstr. 14','München','','GERMANY','81539','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 07:30:41',0,NULL,3,1,3,1,' RA117732360CN','esile_audio\rHSSH002\r\\'),(2890,780379415012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN001+BAIN002+TOIN002',49.9,'eastar4','3rmila707','whereami707@gmail.com','Mark  Callejo','1156 Legend Cir','VALLEJO','CA','UNITED STATES','94591-8688','(707) 334-7397','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 09:02:46',0,NULL,3,1,1,1,'\\ ','3rmila707'),(2891,780558200012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','richardhiggins79','richardhiggins79@aol.com','Richard  Higgins','810 Oriole Cv','lafayette','CO','UNITED STATES','80026-2122','(303) 604-4486','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 09:31:15',0,NULL,3,1,1,1,'\\ ','richardhiggins79'),(2892,780587860012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','rzaev','ruslan.rzaev@hotmail.com','Руслан Рзаев','ул. Труда дом 10 кв 15','Калуга','','RUSSIAN FEDERATION','248030','79208759292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 10:54:59',0,NULL,3,1,2,1,'\\ ','rzaev\racer 6pin1.25 23cm '),(2893,780324201012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','davidcapaguti','davidcapaguti@yahoo.es','DAVID CAPARROS GUTIERREZ','C / RECIFE 11, 4ºD','CARTAGENA','MURCIA','SPAIN','30394','655543645','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 11:17:59',0,NULL,3,1,3,1,'RA117718629CN\r ','davidcapaguti\rOTRA002'),(2894,577612908013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.8,'eastar4','ecofino','ecofino@terra.es','Eduardo Cofiño Jorrín','C/ Puerto Príncipe, 16, 1º C','Barcelona','Cataluña','SPAIN','08027','610488404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 11:57:58',0,NULL,3,1,2,1,'\\ ','ecofino\racer 4pin1.25 15cm '),(2895,780611464012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','pilot_a1','pilot_a@mail.ru','Aleksey Malyshev','Marshala Vasilevskogo 17, apt. 136 Moscow, RUSSIA','Moscow','','RUSSIAN FEDERATION','123182','89637231932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 12:01:18',0,NULL,3,1,2,1,'\\ ','pilot_a1'),(2896,702785160011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','eumicro','eugenlange@online.de','Eugen Lange','Otto-Suhr-Str.15','Oldenburg','','GERMANY','26131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 12:25:00',0,NULL,5,0,18,0,NULL,'eumicro\r撤单 款已经退了'),(2897,780649187012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','funkymunki','monkey_magic692003@yahoo.co.uk','matthew rowe','1 cole close<br>cotford st. luke','taunton','somerset','UNITED KINGDOM','ta4 1nz','01823430905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 13:38:37',0,NULL,3,1,3,1,'RA117718685CN\r ','funkymunki\rOTRA002'),(2898,577647965013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',19.9,'eastar4','palkan','brestmail@gmail.com','Natal\'ja Nikolaeva','ul.Oktjabrskoj Revoljucii, dom.17,kv.7','Brest','','BELARUS','224011','+375297912945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:00:36',0,NULL,3,1,2,1,'\\ ','palkan\r欧标'),(2899,577652497013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','kroro100','r.kronenwetter@t-online.de','Robert Kronenwetter','Forstenrieder Allee 203','München','','GERMANY','81476','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:09:14',0,NULL,3,1,2,1,'\\ ','kroro100\r欧标'),(2900,780656387012,220704730389,'New GENUINE Plantronics Explorer 340 BLUETOOTH HEADSET',1,'HSPL007',14.9,'eastar4uk','igor_kremin','other@flint.lutsk.ua','Igor Kremin','Senatora<br>15a','Luts\'k','Volyn','UKRAINE','43000','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-05-01 14:13:28',0,NULL,3,1,2,1,'\\ ','igor_kremin\r欧标'),(2901,780669982012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','skytt2000','cyho930@gmail.com','Chin Yan Ho','No. 26, Jalan Sungai Congkak 32/44<br>Bukit Rimau','Shah Alam','Selangor','MALAYSIA','40460','0122831343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:35:13',0,NULL,3,1,2,1,'\\ ','skytt2000'),(2902,780671938012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','tohon301','creapon301@yahoo.co.jp','Hiroshi Sasaki','6-7-8-301, HigashiKasai<br>Edogawa-Ku','Edogawa-Ku','Tokyo','JAPAN','134-0084','03-5605-0282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:37:46',0,NULL,3,1,2,1,NULL,'tohon301\\'),(2903,780683025012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','rocky75000','supersteel45@yahoo.com','kenneth payton','914 Assembly Rd','Jeffersonville','IN','UNITED STATES','47130-5743','(812) 989-6508','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 14:55:10',0,NULL,3,1,1,1,'\\ ','rocky75000'),(2904,702868812011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','emiel.h','emielch@gmail.com','Emiel Harmsen','Hoofdstraat 39','ZENDEREN','','NETHERLANDS','7625PA','0742660237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 15:49:40',0,NULL,3,1,2,1,'\\ ','emiel.h'),(2905,780719228012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','arnie-75','spindelndreher@googlemail.com','Alexander Spindelndreher','Wolthuser Dorfstr. 5','Emden','','GERMANY','26725','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:05:49',0,NULL,3,1,2,1,'\\ ','arnie-75'),(2906,576390158013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','unaimg91','unimg@hotmail.com','Unai Márquez González','Mare de deu del port 385, 8o 12','Barcelona','Cataluña','SPAIN','08038','609526097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:16:50',0,NULL,3,1,2,1,'\\ ','unaimg91'),(2907,577701554013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.5,'eastar4','drgee514','david.richard@videotron.qc.ca','David Richard','1617 Sicard','Montréal','QC','CANADA','H1V 2X7','(514) 232-7548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:30:41',0,NULL,3,1,2,1,'\\ ','drgee514'),(2908,667217388001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','fishbone8910','claudiafisher7@hotmail.com','Jason Fisher','2001 41st St N','saint petersburg','FL','UNITED STATES','33713-4735','(727) 327-9384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 16:32:16',0,NULL,3,1,1,1,NULL,'fishbone8910\rLK045265569CN\\'),(2909,780737237012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','deckpi','deckpi@hotmail.com','Roderick Pena','35270 Lucia St','Fremont','CA','UNITED STATES','94536-5474','(510) 859-5532','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 16:35:30',0,NULL,3,1,1,1,NULL,'deckpi\\'),(2910,577715257013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','aprilandjada','aprilandjada@yahoo.com','Jada Suttle','9013 Villanova Dr','Shreveport','LA','UNITED STATES','71118-2437','(318) 426-4388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 17:01:05',0,NULL,3,1,1,1,' \\','aprilandjada'),(2911,780753919012,220761694645,'New Logitech IO Digital Notebook for IO/ IO2 pen',1,'NTLO001',17.35,'eastar4','frech2003','dougfrech@hotmail.com','Doug Frech','78 Lake St','Sault Ste. Marie','ON','CANADA','p6a4a7','(705) 541-9847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:02:11',0,NULL,3,1,2,1,'\\ ','frech2003'),(2912,702912757011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','automattic716','matt20606@aol.com','Matthew Weiskopff','7649 Fallswood Way','Lorton','VA','UNITED STATES','22079-1730','(716) 604-4586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 17:06:37',0,NULL,3,1,1,1,'\\ ','automattic716'),(2913,702916995011,320613191693,'NEW Motorola H700 Gold DG Bluetooth Headset+car charger',1,'HSMO012+CCMO001',19.9,'eastar4','lion-arm','liongev@yahoo.com','Gevorg Ayvazyan','Jrvezh, Mayak bld.8 apt.21','Yerevan','Yerevan','ARMENIA','0089','+374 77 504455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:12:12',0,NULL,3,0,2,1,'\\ ','lion-arm  客户改发花洒一个\r'),(2914,702946866011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','realitynick','jsynick@gmail.com','Nicholas Arnold','4 Clement Court<br>Ann Street, St Helier','Jersey, Channel Islands','Channel Islands','UNITED KINGDOM','JE2 4AS','07797813841','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 17:50:51',0,NULL,3,1,3,1,'RA117718677CN\r ','realitynick\rUDAP001'),(2915,577767678013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','crb_rr','lesniak@rochester.rr.com','Mark Lesniak','90 Mickens Bnd','West Henrietta','NY','UNITED STATES','14586-9561','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 18:34:20',0,NULL,3,1,1,1,'\\ ','crb_rr'),(2916,702997362011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','trialgun','lkesten@bhpklaw.com','Leonard Kesten','14 Elm St','Wellesley','MA','UNITED STATES','02481-3107','(781) 237-0904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 18:56:37',0,NULL,3,1,1,1,NULL,'trialgun\\'),(2917,577782564013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','mykmyk86','soul@ukr.net','Mykola Gladchenko','Symerenko st,<br>22b, 13','Kyiv','UA','UKRAINE','03134','(380) 936-7697 ext.: 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 19:02:34',0,NULL,3,1,2,1,'\\ ','mykmyk86'),(2918,702997324011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','nightstalkeraj','andrewgjones86@googlemail.com','Andrew Jones','19 Pether Avenue','Brackley','Northamptonshire','UNITED KINGDOM','NN13 6NJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 19:10:11',0,NULL,3,1,3,1,'RA117732078CN\r ','nightstalkeraj\rMOAP001\r'),(2919,780881721012,220713846504,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET',3,'HSNO025',107.7,'eastar4uk','rynke08','vicky.mancini@mail.dk','vicky mancini','rich. granholms alle 16','kastrup','','DENMARK','2770','(0045) 61914112','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 19:37:43',0,NULL,3,1,3,1,'RA117732461CN\r ','rynke08\rHSNO025\r欧标\r'),(2920,703035822011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','mrnine324','dodgeman324@yahoo.com','Brandon Turley','4966 Hawk Meadow Dr','Colorado Springs','CO','UNITED STATES','80916-5719','(918) 949-1608','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 19:48:57',0,NULL,3,0,1,1,'\\ ','mrnine324\rGLSG001'),(2921,667359482001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','k0135','simon.desbiens.1@videotron.ca','Simon Desbiens','286, rue Lafontaine','Rivière-du-Loup','QC','CANADA','G5R 3A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:04:26',0,NULL,3,1,3,1,'RA117718615CN\r ','k0135\rOTSO001'),(2922,577818096013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','tinahopper','tinahopper@web.de','Susanne Terheyden','Ronshauser Str. 17','Recklinghausen','','GERMANY','45663','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:18:29',0,NULL,3,1,2,1,'\\ ','tinahopper'),(2923,577827132013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','tesha_rae','tesha_rae@hotmail.com','Tesha-Rae Cole','673 Linden Ave','Winnipeg','MB','CANADA','R2K0P1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:31:56',0,NULL,3,1,2,1,'\\ ','tesha_rae'),(2924,577832689013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','eddieo020','eddieandliz@sympatico.ca','Eddie Oliveira','11 Beaverbrook Crescent','Cambridge','ON','CANADA','N1P 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:45:56',0,NULL,3,1,2,1,'\\\r ','eddieo020'),(2925,703046403011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','redmohawk','svenclausen@sbcglobal.net','Sven H Clausen','1553 Palm Ave','Chico','CA','UNITED STATES','95926-2605','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 20:54:35',0,NULL,3,1,1,1,'\\ ','redmohawk'),(2926,703077547011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','rfondon','rubenfondon@hotmail.com','Ruben Fondon Alcalde','C/San Francisco 72','Villaviciosa de Odón','Madrid','SPAIN','28670','672397378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 21:08:16',0,NULL,3,1,2,1,'\\ ','rfondon'),(2927,703090646011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','valc240','valcatrazz@gmail.com','Brian Vorst','76 Danbury Dr','Springfield','IL','UNITED STATES','62704-5438','(217) 415-9916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 21:30:44',0,NULL,3,1,1,1,NULL,'valc240\\'),(2928,703103190011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','exodiak','exodiak@verizon.net','David Rodriguez','155 East 4th St.<br>Apt 2D','New york','NY','UNITED STATES','10009','(212) 228-5763','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 22:01:29',0,NULL,3,0,1,1,'\\ ','exodiak\rGLSG001'),(2929,577863858013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','bli2007','bli194@hotmail.com','pablo lorenzana alvarez','c/ peña santa, 194 urb. las lomas','valdefresno- león','Castilla y León','SPAIN','24227','626927209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 22:24:22',0,NULL,3,1,2,1,'\\ ','bli2007\r欧标'),(2930,577870500013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','drparasite','dangreenhaus+onlineorders@gmail.com','Dan Greenhaus','1106 Harbor Club Dr','Parlin','NJ','UNITED STATES','08859','(732) 735-3682','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 22:48:22',0,NULL,3,1,1,1,'\\ ','drparasite'),(2931,703125445011,320692106584,'New in box genuine SONY 3D Active Glasses TDG-BR100',4,'OTSO003',416,'eastar4','5.0-mustangs','devinandchristy@sbcglobal.net','Devin Wagner','5873 Echo Bluff Dr','Haltom City','TX','UNITED STATES','76137-5807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 23:06:14',0,NULL,3,1,6,1,'EE456353954CN','5.0-mustangs\r'),(2932,703147861011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ghostboy814','gorensteinay@aol.com','Alex Gorenstein','191 Tweed Blvd','Nyack','NY','UNITED STATES','10960-4913','(845) 729-9938','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 00:15:43',0,NULL,3,1,1,1,'\\ ','ghostboy814'),(2933,577894442013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','pedricb','briankpedrick@comcast.net','Brian Pedrick','115 Silver Birch rd','Williamstown','NJ','UNITED STATES','08094-2027','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\ ','pedricb\rLK046599152CN '),(2934,703168349011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','husmun','munir2000@hotmail.com','Pritchard Francis (Hussain Munir)','Level 1, 430 Roberts Road','Subiaco','Western Australia','AUSTRALIA','6008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 01:14:51',0,NULL,3,0,2,1,'\\ ','husmun'),(2935,781046951012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','njtrader01','nrewari@yahoo.com','Naresh Rewari','14 Jamesworthy Ct','Marlboro','NJ','UNITED STATES','07746-2714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 01:40:09',0,NULL,3,1,1,1,NULL,'njtrader01\\'),(2936,577916894013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','pointsan','pointsan@yahoo.com','Bussarin Sinnung','PTT Phenol Co.,Ltd. 555/1 4th Floor Energy Complex Building,<br>Vibhavadi Rangsit Rd., Jatuchak','Bangkok','Bangkok','THAILAND','10900','66891357725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 01:43:02',0,NULL,3,1,2,1,'\\ ','pointsan'),(2937,703185954011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','melissam934','mmorse3@partners.org','Armand chery','42 Royal Crest Dr<br>Apt 7','Nashua','NH','UNITED STATES','03060-6633','(978) 985-7789','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 02:09:38',0,NULL,3,1,1,1,'\\ ','melissam934'),(2938,703200491011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005*2',134.99,'eastar4','nunyone2','douglas.heredia@yahoo.com','Nerime Pervizaj','75 Rockefeller Plz<br>C/O Warner Music Group Fl 12','New York','NY','UNITED STATES','10019-6908','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 02:57:19',0,NULL,3,0,1,1,'\\ ','nunyone2\rGLSG001*2'),(2939,703213936011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','reg_at_capio','reg@capiogroup.com','SEO Web Sales','1 Blackfield Dr<br># 134','Tiburon','CA','UNITED STATES','94920-2053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 03:54:45',0,NULL,3,1,1,1,'\\ ','reg_at_capio'),(2940,703254222011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',3,'RELO002',38.97,'eastar4','sawty','jimmy.latham@gmail.com','James Latham','6 Mary St<br>Longueville','Sydney','New South Wales','AUSTRALIA','2066','0435776144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 07:35:17',0,NULL,3,1,3,1,'RA117718663CN\r ','sawty\rRELO002'),(2941,703252132011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','don_24_7','don_24_7@hotmail.com','Don Roberts','41 Cathnor Road, Shepherd\'s Bush','London','London','UNITED KINGDOM','W12 9JB','02087620758','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 07:35:33',0,NULL,3,1,3,1,'RA117732047CN\r ','don_24_7\rMOAP001'),(2942,703258398011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.2,'eastar4','petersruh','w.petersen-s.p.o@t-online.de','Walter Petersen','Zum Leuchtturm 5','St. Peter-Ording','','GERMANY','25826','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 07:53:14',0,NULL,3,1,3,1,' RA117732458CN','petersruh\rWWSI004\\'),(2943,577979685013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','agouder','gouderadrian@yahoo.co.uk','Adrian Gouder','136, Sunshine Flats 2.,<br>Potters Str.,','Birkirkara','Malta (EU - Europe)','MALTA','BKR 1201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:04:26',0,NULL,3,1,2,1,'\\ ','agouder\r欧标'),(2944,577984210013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','titanium_ten','vestitor@me.com','chris taylor','Building 29Q<br>Airfeild Camp','Netheravon','Wiltshire','UNITED KINGDOM','SP4 9SF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:34:19',0,NULL,3,1,2,1,'\\ ','titanium_ten'),(2945,577986796013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','rodri333','rodri@eureka.es','Rodrigo Marcos','Seneca, 10 - Bjos. 2','Barcelona','Barcelona','SPAIN','08006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:46:11',0,NULL,3,1,2,1,'\\ ','rodri333'),(2946,703269692011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','soos.viktor','soos.vitya@gmail.com','Soós Viktor','Csengeri utca 13/A','Isaszeg','','HUNGARY','2117','+36-30-491-5076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:53:57',0,NULL,3,1,2,1,NULL,'soos.viktor\\'),(2947,703277740011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','zup2sky2','jhk9@sfu.ca','Jin Kim','16861 85A Ave','SURREY','BC','CANADA','V4N 5A4','(604) 575-7123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 09:14:01',0,NULL,3,1,2,1,'\\ ','zup2sky2'),(2948,781189685012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','tontonchris31180','toff31@gmail.com','Monique Rualta','175 CHEMIN DE GARENNE','mirepoix  sur tarn','31','FRANCE','31340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 10:52:27',0,NULL,3,1,2,1,'\\ ','tontonchris31180'),(2949,781197982012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','rudi-dakota','denisefossey@hotmail.com','Denise Fossey','940 Georgianna St','Hobart','IN','UNITED STATES','46342-4508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 11:19:29',0,NULL,3,1,1,1,'\\ ','rudi-dakota'),(2950,525952343003,130490976552,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',3,'WLAT006',52.47,'cnfaner','lizika_zlikovski','offroad.lobor@gmail.com','Ivan Hleb','Zagrebačka<br>64','Zlatar','Hrvatsko Zagorje','CROATIA','49250','+385959121267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 12:19:07',0,NULL,3,1,3,1,'RA117732546CN\r ','lizika_zlikovski\rWLAT006'),(2951,578043340013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','in-shades','bobk@fremontind.com','Bob Krosnowski','14695 Trotters Trl NE','Prior Lake','MN','UNITED STATES','55372-4104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 13:18:54',0,NULL,3,1,1,1,'\\ ','in-shades'),(2952,703351088011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','shasmani1','steve@hasmanis.net','steve hasmanis','1342 Crown Ridge Dr','Fort Mill','SC','UNITED STATES','29708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 13:25:34',0,NULL,3,1,1,1,NULL,'shasmani1\\'),(2953,0,220774366905,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',0.43,'eastar4','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-02 13:28:12',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(2954,781251939012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',5,'HSPL010',119.5,'eastar4','uuu-pb','postmaster@ullner.de','Ullner u. Ullner GmbH','zu Hd. H. Bücker<br>Grüner Weg 25','Paderborn','','GERMANY','33098','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 13:57:57',0,NULL,3,1,3,1,'RA117718703CN\r ','uuu-pb\r欧标\rHSPL010'),(2955,525980386003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','guido88au','archieaparicio@iinet.net.au','Archimedes Aparicio','913/3 HERBERT ST','ST LEONARDS','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 14:28:36',0,NULL,3,1,3,1,'RA117733039CN\r ','guido88au\rOTGR001'),(2956,531733221004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','behind_the_eyes','enrico.ghirardo@gmail.com','enrico ghirardo','piazza marconi 45','vigonovo','VE','ITALY','30030','0499830060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 15:24:53',0,NULL,3,1,3,1,'RA117732033CN\r ','behind_the_eyes\rWWSI005'),(2957,781292594012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','markcata','mcatalanot@aol.com','Mark Catalanotti','313 N Broadway<br>Apt 2','Redondo Beach','CA','UNITED STATES','90277-2800','(310) 798-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 15:36:30',0,NULL,3,1,1,1,NULL,'markcata\\'),(2958,781318299012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','abbott1999','michael.abbott@inenco.com','Michael Abbott','Inenco Group Ltd<br>Petros House, St Andrews Rd North','Lytham St Annes','Lancashire','UNITED KINGDOM','FY8 2NF','01253785000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 16:31:55',0,NULL,3,1,3,1,'RA117732356CN\r ','abbott1999\r英标\rHSPL014\r'),(2959,526021554003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','cecoanny','ebayca@abv.bg','Ani Ganeva','10, Venera Str<br>1st floor ','Gabrovo','Gabrovo','BULGARIA','5300','00359878917249','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 16:55:51',0,NULL,3,1,3,1,' RA117733042CN\r','cecoanny\rHSNO016\r欧标'),(2960,703457698011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',28.49,'eastar4','suwannawech2009','suwannawech@gmail.com','Suwannawech natasha','146/106 Soi Sang U-Thai tip<br>Dindeang','Dindaeng','Bangkok','THAILAND','10400','668 1 7011929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 17:44:55',0,NULL,3,1,2,1,'\\ ','suwannawech2009'),(2961,703465210011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005*2',134.99,'eastar4','senor56','f.villasenor@hotmail.com','Fatima Villasenor','2508 Canyon Dr','Modesto','CA','UNITED STATES','95351-4851','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 17:58:52',0,NULL,3,0,1,1,'\\ ','senor56\rGLSG001*2'),(2962,578136093013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','pmj1979','paulmjob@yahoo.co.uk','Paul Job','Jee Ltd, 2 Abercrombie Court<br>Arnhall Business Park, Prospect Rd','Westhill','Aberdeenshire','UNITED KINGDOM','AB32 6FE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:14:43',0,NULL,3,1,3,1,'RA117733056CN\r ','pmj1979\rMOSA002'),(2963,578146786013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','adammoriarty123','mo18_33@yahoo.com','Adam Moriarty','2450 Hamilton St','Oshkosh','WI','UNITED STATES','54901-1544','(608) 751-0839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 18:38:47',0,NULL,3,1,1,1,NULL,'adammoriarty123\\'),(2964,781392117012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','metalfirebladesw','metalfireblade@hotmail.com','Sergio Martinez Ciruelos','Avda. Fermina Sevillano 40B','Madrid','Madrid','SPAIN','28022','666341285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:39:20',0,NULL,3,1,2,1,NULL,'metalfirebladesw\\'),(2965,703532797011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','greyman46','grahamsfineart@googlemail.com','graham clarke','6<br>humphreys road','wellington','Somerset','UNITED KINGDOM','ta219es','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 19:52:18',0,NULL,3,1,3,1,' RA117732413CN','greyman46\rMOAP001\\'),(2966,531829936004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','jimgoepel','jgoepel@jegconsulting.com','James Goepel','Unisys Corp., Office of the General Counsel<br>801 Lakeview Drive, Suite 100; Mail Stop 2NW','Blue Bell','PA','UNITED STATES','19422','(703) 593-5460','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 19:58:21',0,NULL,3,1,1,1,NULL,'jimgoepel\\'),(2967,703539807011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','petr.drugak','petr.drugak@gmail.com','Peter Drugak','Borochov 12 apartment 16','Netanya','','ISRAEL','42266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:06:48',0,NULL,3,1,2,1,'\\ ','petr.drugak'),(2968,781450303012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','dig453','george.fryer@gmail.com','George D Fryer','13 Park Avenue','Bath','Avon','UNITED KINGDOM','BA24QD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:08:55',0,NULL,3,1,3,1,'RA117732342CN\r ','dig453\rHSSH002\r'),(2969,703549691011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','elgrancomercial','mhergon@hotmail.com','Marc Hervera Gonzalez','C/ Santa Marcelina 13 B Bajos 1ª','Cerdanyola del Valles','Cataluña/Barcelona','SPAIN','08290','647493793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:24:32',0,NULL,3,0,3,1,'RA117731293CN\r ','elgrancomercial\rGLSG001'),(2970,703569042011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','jfjodoin00','jfjodoin@megaquebec.net','Jean-Francois Jodoin','40, rue Kamouraska','Sainte-Catherine-de-la-Jacques-Cartier','QC','CANADA','G3N 0Y9','(418) 875-4141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:07:04',0,NULL,3,1,2,1,'\\ ','jfjodoin00'),(2971,703576656011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',37.68,'eastar4','jjcriado','jjcriado@telefonica.net','Jose Javier Criado Fernandez','Barrio Castanedo 70-A Chalet 12','Villanueva de Villaescusa','Cantabria','SPAIN','39690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:25:14',0,NULL,3,1,3,1,' RA117732435CN','jjcriado\rBALO007+RELO002\r再发两个优联\\'),(2972,578216095013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','kfan1tp4','kfan@cisco.com','Kyle Fan','6405 Prospect Rd','San Jose','CA','UNITED STATES','95129-3840','(408) 527-2607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 21:43:24',0,NULL,3,1,1,1,'\\ ','kfan1tp4'),(2973,703585627011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'MOSA005',67.99,'eastar4','sirhavz','havril.taing@wanadoo.fr','Christophe TAING','cité du petit bois batiment O','Carrieres sur Seine','Île-de-France','FRANCE','78420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:50:40',0,NULL,3,0,3,1,'RA117731262CN\r ','sirhavz\rGLSG001\r'),(2974,781502345012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','wata.o','watao@yahoo.co.jp','Toshio Watanabe','Yasashido-cyo 1170-45<br>Midori-ku','Chiba-shi','Chiba','JAPAN','267-0062','+81-43-294-2385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 21:54:13',0,NULL,3,1,3,1,'RA117731280CN\r ','wata.o\r蓝牙版的\rMOLO005'),(2975,781504769012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','schnelllangsam','scottdaniel@arcor.de','Daniel Scott','Am Frauenberg 20A','Bad Hersfeld','','GERMANY','36251','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:00:45',0,NULL,3,1,2,1,'\\ ','schnelllangsam'),(2976,703596619011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','jmclark47','jmclark47@gmail.com','Jeffrey M Clark','12435 28 Avenue NW','Edmonton','AB','CANADA','T6J 4G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:25:31',0,NULL,3,1,2,1,'\\ ','jmclark47'),(2977,578235089013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','iwowdaily','djadamson12@hotmail.com','David Adamson','9802 NE 108TH CT','Vancouver','WA','UNITED STATES','98662-3387','(360) 718-2212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 23:06:41',0,NULL,3,1,1,1,'\\ ','iwowdaily\r华硕限量版'),(2978,578239863013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-02 23:32:09',0,NULL,3,1,1,1,'\\ ','edpsychdoc'),(2979,778793852012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','kheder1234','m.khodr@live.com.au','moe khodr','29 glengyle st','melbourne','Victoria','AUSTRALIA','3058','0422406253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 23:38:25',0,NULL,3,1,2,1,'\\ ','kheder1234\r澳标'),(2980,781321450012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','alvaromoroni','alv.moroni@gmail.com','Alvaro Moroni','Avenida Nossa Senhora de Copacabana 379<br>Apartamento 1204','Rio de Janeiro','RJ','BRAZIL','22020-002','(55) 21 8405-8494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 01:05:46',0,NULL,3,1,3,1,' RA117732121CN','alvaromoroni\rOTSO002\\\r'),(2981,703644434011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','mezrin','mezrin@hotmail.com','Vadim Mezrin','19 Skyline Dr','West Orange','NJ','UNITED STATES','07052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 01:27:25',0,NULL,3,1,1,1,'\\ ','mezrin'),(2982,578264378013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','troy.mcguinness','troymcguinness74@gmail.com','Troy McGuinness','11 Lavery Place','Attwood','Victoria','AUSTRALIA','3049','0393093613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 01:36:04',0,NULL,3,1,2,1,'\\ ','troy.mcguinness\rCAB-6060'),(2989,702651504011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','davidkbecker','davidkbecker@yahoo.com','David Becker','856 Church St','San Francisco','CA','UNITED STATES','94114-3031','(415) 401-8048','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:17:07',0,NULL,3,1,1,1,'\\ ','davidkbecker'),(2983,703659956011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','transamman1','mikelespike@hotmail.com','Mike Thompson','575 7th Avenue East N','Columbia Falls','MT','UNITED STATES','59912-3212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 02:23:19',0,NULL,3,1,1,1,'\\ ','transamman1'),(2984,781583409012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','nd4spd42','mrebony38@excite.com','Steven Rorie','5200 Butterfield Dr','Winston Salem','NC','UNITED STATES','27105-3251','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 02:24:07',0,NULL,3,1,1,1,NULL,'nd4spd42\\'),(2985,781587621012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',14.75,'eastar4','nikkoandfia','ralpaugh1@hotmail.com','rochelle mendez','123 W Hillcrest Dr','Greenville','SC','UNITED STATES','29609-4617','(828) 301-5698','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 02:39:12',0,NULL,3,1,1,1,NULL,'nikkoandfia\\'),(2986,578284176013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','heeinlee','lhi819@hotmail.com','HeeIn Lee','#5-3175 Baird Road','North Vancouver','BC','CANADA','V7K 2G5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 03:17:12',0,NULL,3,1,2,1,'\\ ','heeinlee'),(2987,703673128011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','repcoservices','rep-co@repairman.com','Ryan Casper','23809 5th Ave W','Bothell','WA','UNITED STATES','98021-8528','(206) 321-7044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 03:19:40',0,NULL,3,1,1,1,'\\ ','repcoservices'),(2988,781606468012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','brother_dugan','dougrodriguez81@hotmail.com','Douglas Rodriguez','2100 10th St<br>Ste 300','Plano','TX','UNITED STATES','75074-8022','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 04:05:32',0,NULL,3,1,1,1,'\\ ','brother_dugan'),(2990,703697376011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',2,'BTHP2111',25.6,'eastar4','gadzekpo','gadzekpo@yahoo.com','Leonard Gadzekpo','414 N Beadle Dr<br>Apt 4','Carbondale','IL','UNITED STATES','62901','(618) 351-7084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:36:48',0,NULL,3,1,1,1,' ','gadzekpo\rHP 8pin 1.25 25cm \\'),(2991,781625867012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','igvisualizations','bishaug@ieee.org','Brian Ishaug','4817 Funston Gate Ct','Pleasanton','CA','UNITED STATES','94566-4529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:42:41',0,NULL,3,1,1,1,'\\ ','igvisualizations'),(2992,781627689012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',35.99,'eastar4','marcandsteve','sunswimpool@yahoo.com','Steven e Ongman','6890 Highway 9','Felton','Ca','UNITED STATES','95018','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 05:51:35',0,NULL,3,1,1,1,' ','marcandsteve\\  bank reversal'),(2993,703704559011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','diesel6s7k','diesel@hitel.net','HAEYONG LEE','JUNG GUM SA 260-2 NAMSAN2DONG JUNG-GU','DAEGU','','KOREA,REPUBLIC OF','700-442','+82-11-501-3407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 06:24:48',0,NULL,3,1,2,1,'\\ ','diesel6s7k'),(2994,578313858013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','tridoc05','conkst@gmail.com','Cherie Onkst','5206 Dwire Ct','Tampa','FL','UNITED STATES','33647-1016','(813) 978-1614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 06:59:45',0,NULL,3,1,1,1,'\\ ','tridoc05'),(2995,781645394012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','castefan','stefanclaudiuadrian@hotmail.com','Claudiu Adrian STEFAN','48 Villa Park Gardens','Dublin','Dublin','IRELAND','D7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 07:18:05',0,NULL,3,1,3,1,'RA117732152CN\r ','castefan\rOTCN002'),(2996,578318862013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','alcom05','alcom@club-internet.fr','Alexandre COMBES','Appartement 17, 31 Rue de Cugnaux','TOULOUSE','Midi-Pyrénées','FRANCE','31300','06.89.95.21.30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 07:36:18',0,NULL,3,1,2,1,'\\ ','alcom05'),(2997,781662610012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','his047','f.pedersen@abdn.ac.uk','Frederik Pedersen','Inches Lodge<br>Inch Road','Newburgh','Aberdeenshire','UNITED KINGDOM','AB41 6BQ','01358789105','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 08:38:17',0,NULL,3,1,3,1,'RA117732585CN\r ','his047\rHSPL014\r英标'),(2998,526231933003,130458644390,'New GENUINE NOKIA BH-300 BLUETOOTH HEADSET track#',1,'HSNO013',15.6,'cnfaner','rwu3','salmor8@yahoo.ca','Buu Ngo','P.O.Box 40154','Ottawa','ON','CANADA','K1V 0W8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 08:59:56',0,NULL,3,1,3,1,'RA117732299CN\r ','rwu3\rHSNO013\r'),(2999,781670866012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','der_frauenversteher2','dkdruck@gmx.de','Druckerei Krause','Langenscheidtstrasse 9A','Berlin','','GERMANY','10827','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:08:51',0,NULL,3,1,2,1,'\\ ','der_frauenversteher2'),(3000,578339886013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',4,'CACN004',52,'eastar4','rampelstilskin_88','kommytator@gmail.com','Yuriy Popov','Shilkinskaia 6 - 15','Vladivostok','Primorsky','RUSSIAN FEDERATION','690066','+79502890608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:52:55',0,NULL,3,1,3,1,'RA117732594CN\r ','rampelstilskin_88\rCACN004'),(3001,526245167003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',2,'HSSE003',43.8,'cnfaner','gog7811','qudsia1@live.com.au','Qudsia chaudhry','11<br>scotney place','quakers hills','New South Wales','AUSTRALIA','2763','0296269312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 10:28:55',0,NULL,3,1,3,1,'RA117732237CN\r ','gog7811\rHSSE003\r澳标'),(3002,531993589004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','ckyrts','pentepedia@gmail.com','Christos Kyrtsakas','409 Beach Grove Drive','Tecumseh','ON','CANADA','N8N 1K6','(519) 257-9148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:05:28',0,NULL,3,1,3,1,'RA117732170CN\r ','ckyrts\rOTGR002'),(3003,524884889003,130493246602,'Logitech harmony Li-ion Rechargeable Battery 930mAh',1,'BALO002',10.5,'cnfaner','gux70','agarzon.licof@afiti.com','Agustin Garzon Cabrerizo','Camilo Jose Cela 22 P3 2C','Las Rozas','Madrid','SPAIN','28230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:09:15',0,NULL,3,1,3,1,'RA117732245CN\r ','gux70\rBALO002'),(3004,781701501012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','outsidebroadcast','outsideb@optusnet.com.au','Steve Wakely','12 Parraweena Ave','Baulkham Hills','New South Wales','AUSTRALIA','2153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:11:20',0,NULL,3,1,2,1,'\\ ','outsidebroadcast'),(3005,781707948012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','trueduck2000','etn@free.fr','Etienne MERIAUX','81bis route de Clisson','St-SEBASTIEN sur LOIRE','Pays de la Loire','FRANCE','44230','02.28.21.03.46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 11:29:57',0,NULL,3,1,2,1,'\\ ','trueduck2000\r欧标'),(3006,703783903011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','chtirlipimpon','laurent.gaudron@gmail.com','laurent gaudron','6 rue ronsard','chambourg sur indre','Centre','FRANCE','37310','06.30.51.28.64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:05:49',0,NULL,3,1,3,1,'RA117731347CN\r ','chtirlipimpon\rGLSG001'),(3007,578368066013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','massmike69','masmike1969@msn.com','Michael P Arsenault','2015 Bonisle Cir','Riviera Beach','FL','UNITED STATES','33418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 12:19:57',0,NULL,3,1,1,1,'\\ ','massmike69'),(3008,578367986013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',62.5,'eastar4','gregos13','greg.in.forest@gmail.com','Greg Sidorov','Garibaldi 14/1 flat 20','Moscow','Moscow','RUSSIAN FEDERATION','117393','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:26:39',0,NULL,3,1,3,1,'RA117733144CN\r ','gregos13\racer 8pin1.0 3cm \r再发两个 3G WWAN antenna\r 一个UNLOCKED ACER HS2300 SIERRA MC8775 WWAN 3G not HP\rBTAC2118+ANCN001+WWSI001\r\r'),(3009,578371696013,230545855042,'Acer TM 3000 3020 /AS5760 Bluetooth Module2.0+cable',1,'BTAC2024',12.5,'eastar4','megerald68','raymond.forghani@gmail.com','Raymond Forghani','Unit 2<br>45 Bangor Street','Guildford','New South Wales','AUSTRALIA','2161','0296322370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:38:18',0,NULL,3,1,2,1,'\\ ','megerald68\r\racer 8pin1.25 10cm'),(3010,781755761012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','linckgroup','e1-3snw-n31w-901c@aetm.us','Christian Bailey','85 Bolton St<br>Ligon Discovery','Cambridge','MA','UNITED STATES','02140-3310','(617) 326-7284','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 13:57:16',0,NULL,3,1,1,1,'\\ ','linckgroup\r红边优联'),(3011,578389634013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','marekfia','marek@dropzone.com','Marek Fiala','M.Pujmanove 4','Prostejov','','CZECH REPUBLIC','79811','776203170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 13:57:35',0,NULL,3,1,3,1,'RA117732563CN\r ','marekfia\rMOSA002'),(3012,668088896001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','bewe720','benoit.weiss@chimbio-ulp.u-strasbg.fr','Benoit weiss','9 rue des Cigognes','Weyersheim','Alsace','FRANCE','67720','0388513641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 14:17:05',0,NULL,3,1,3,1,'RA117732210CN\r ','bewe720\rOTSO001'),(3013,668089291001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','samitnk9900','samitnk@hotmail.com','Jitesh Khokhani','458 Ebony Tree Ave','Galloway','NJ','UNITED STATES','08205-4478','6096523347','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 14:19:56',0,NULL,3,1,1,1,'\\ LK045714673CN','samitnk9900'),(3014,578400804013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','quinnsrus','quinnsrus@yahoo.com','Anthony Quinn','4410 Highway 16','Elkins','AR','UNITED STATES','72727','(479) 643-2822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 14:44:41',0,NULL,3,1,1,1,'\\ ','quinnsrus'),(3015,703838184011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',66.4,'eastar4','jmyoon0815','blueguy@blueguy.sarang.net','Jongmin Yoon','WindRiver 5th fl. Sambo Bldg.<br>88 Samsung Dong','Kangnam Gu','Seoul','KOREA,REPUBLIC OF','135090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 15:07:45',0,NULL,3,1,3,1,'RA117732308CN\r ','jmyoon0815\rWWSI004'),(3016,781783547012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','darinh92','darinh@pobox.com','Darin Haugen','9165 Woodhill Ct','Savage','MN','UNITED STATES','55378-3149','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:15:32',0,NULL,3,1,1,1,'\\ ','darinh92'),(3017,781784695012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.8,'eastar4','sisley_111','mariestlouis@9bit.com','Martial Berthod','1435 Goupil','Drummondville','QC','CANADA','J2B5A1','(819) 478-6987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 15:19:35',0,NULL,3,1,2,1,'\\ ','sisley_111\racer 5pin1.25 6cm   '),(3018,781784711012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','jillybean775','jillnhagan@yahoo.com','Jillian White','9308 Lake Chase Island Way','Tampa','FL','UNITED STATES','33626-1932','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:20:21',0,NULL,3,1,1,1,'\\ ','jillybean775\r红边优联'),(3019,777988315012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',2,'HSSE005',27.8,'eastar4uk','arty271048','artybabs@yahoo.co.uk','Arthur Turnbull','53 Bracken Brae, Tulloch','Perth','Perthshire and Kinross','UNITED KINGDOM','PH12SF','01738620446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 15:20:50',0,NULL,3,1,3,1,'RA117733113CN\r ','arty271048\rHSSE005'),(3020,703842472011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','gah5140','smishara@alumni.upenn.edu','Scott Mishara','7 Jones Street, Apt 16','New York','NY','UNITED STATES','10014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 15:22:27',0,NULL,3,1,1,1,'\\ ','gah5140'),(3021,703873347011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','harry_harper','yorkproofreading@googlemail.com','Katherine James','35 Selborne Road','Bishop\'s Cleeve','Gloucestershire','UNITED KINGDOM','GL52 8BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 16:40:11',0,NULL,3,1,3,1,'RA117732166CN\r ','harry_harper\rMOAP001\r'),(3022,781822045012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','bitwaresales','mokuba@gmail.com','Gary Sparkes Jr.','2333 Pennington Rd','Bel Air','MD','UNITED STATES','21015-1203','(443) 617-0710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 16:51:54',0,NULL,3,1,1,1,'\\ ','bitwaresales'),(3023,578441013013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','corys20','corys34@yahoo.com','Corrin Sotala','710 Tower Hill Dr','Brookfield','WI','UNITED STATES','53045-6740','(414) 322-6012','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-03 17:10:56',0,NULL,3,1,1,1,'\\ ','corys20'),(3024,781646295012,220759518349,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12,'eastar4uk','ywd40','yoni74@gmail.com','yoni Jagel','62<br>Dingle Close','Radcliff','Lancashire','UNITED KINGDOM','M26 1UN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 17:27:02',0,NULL,3,1,3,1,'RA117732651CN ','ywd40\rSCLO001'),(3025,781839466012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','mekawendie','arierae@gmail.com','Alvaro Riera Elena','C/Martin Alonso Pedraz nº 14<br>Bloque 4 - 1ºA','Salamanca','Castilla y León','SPAIN','37007','650137202','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 17:27:28',0,NULL,3,1,3,1,'RA117732254CN\r ','mekawendie\rOTRA002'),(3026,703894613011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','azcjhons','joieh@aol.com','Joe A. Honsberger`','13770 W Van Buren St<br>Ste 100','Goodyear','AZ','UNITED STATES','85338-1292','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 17:32:02',0,NULL,3,1,1,1,'\\ ','azcjhons'),(3027,578450378013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','eugenekotlar','eugenekotlar@optonline.net','Yevgeny Kotlyar','251 W Dekalb Pike<br>Apt A105','King of Prussia','PA','UNITED STATES','19406-2445','(215) 798-0047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 17:38:08',0,NULL,3,1,1,1,'\\ ','eugenekotlar'),(3028,781841806012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','histla','kurnia2k3@yahoo.com.sg','Mochammad Kurniawan','Puskesmas Sukodadi<br>Jl. P. Sudirman 39 Sukodadi','Lamongan','Jawa timur','INDONESIA','62253','081553000301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:40:41',0,NULL,3,1,2,1,'\\ ','histla'),(3029,781869504012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ziphansen','tripzip@gmail.com','Zip Hansen','15232 SE 272nd St #107<br>Cascade Mobile Villa','Kent','WA','UNITED STATES','98042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 18:23:38',0,NULL,3,1,1,1,'\\ ','ziphansen\r红边优联'),(3030,703924962011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','luckypapa13','luc.thys1@telenet.be','Luc Thys','Deken J. Van Herckstraat 55','Kontich','','BELGIUM','2550','032890688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:32:45',0,NULL,3,1,2,1,'\\ ','luckypapa13'),(3031,781891711012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','sale10sale','elado.neked@gmail.com','Molnar Attila D. EMH-Bp','Gyomroi u. 120.<br>BOSCH','Budapest','Hungary','HUNGARY','1103','36703404853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:03:27',0,NULL,3,1,2,1,'\\ ','sale10sale'),(3032,578512082013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','princemanni','princemanni@gmx.de','Manfred Rutetzki','Am Mehrdrusch 27','Lahntal-Gossfelden','','GERMANY','35094','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:26:06',0,NULL,3,1,3,1,'RA117733127CN\r ','princemanni\rMOSA002'),(3033,781940432012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','masood75msn','masood75@msn.com','shaheen ahmed','2 vinters avenue','stevenage','Hertfordshire','UNITED KINGDOM','sg11qs','01438211767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 20:28:25',0,NULL,3,1,3,1,'RA117732223CN\r ','masood75msn\rHSMO017'),(3034,532146660004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','oizzo','mattias@hlo.se','Mattias Österberg','Lillebovägen 8','Saltsjö-Boo','','SWEDEN','13236','0046705090301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:38:38',0,NULL,3,0,3,1,'RA117732625CN ','oizzo\rTOIN002+BAIN002+BAIN001'),(3035,578519257013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:49:22',0,NULL,3,1,3,1,'RA117732285CN\r ','vjendrisvelimir\r欧标\rHSJA002'),(3036,781960734012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','cotelilllo','joberab@hotmail.com','Jose Antonio Bernal Abad','Juan Ramon Jimenez 55 Puerta 15<br>22577962N','Valencia','Comunidad Valenciana','SPAIN','46026','963258979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:09:43',0,NULL,3,1,2,1,'\\ ','cotelilllo'),(3037,578532160013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','dhos1659','deliah@homeschools.org','DELIA HOSU','1304 E WHITE WATER LANE','PALATINE','IL','UNITED STATES','60074','(847) 529-9752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 21:25:54',0,NULL,3,1,1,1,'\\ ','dhos1659'),(3038,704013318011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','djhughe','ebay@dnahughes.com','David Hughes','10 Cave Creek Ct','Bloomington','IL','UNITED STATES','61704','(309) 661-8129','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 21:43:40',0,NULL,3,1,1,1,'\\ ','djhughe'),(3039,578538488013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','krl0s_86','loscar14686@msn.com','CARLOS RAMOS NOTARIO','POLIGON RUTLLA ALTA NAU Nº 6<br>CALYGAS S.L.','PALAMÓS','Cataluña','SPAIN','17230','620677292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:56:14',0,NULL,3,1,3,1,'RA117733135CN\r ','krl0s_86\rMOSA002'),(3040,781991174012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','karaokeaustralia','ebaysales@1stchoicejukeboxes.com','Kayone Karaoke','PO Box 4164','Frankston Heights','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:25:46',0,NULL,3,1,2,1,'\\ ','karaokeaustralia'),(3041,526432098003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','ofra10','ofra555@gmail.com','OFRA YEMINI','KEREN  HAYESOD  25/37','BAT-YAM','ISRAEL','ISRAEL','59624','0544566435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:33:43',0,NULL,3,1,3,1,'RA117732603CN\r ','ofra10\rHSMO011'),(3042,781996504012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',4,'HSMO008',43.8,'eastar4','3447','fagan.otis@yahoo.com','Otis Fagan','2247 Scotland Dr','Dallas','TX','UNITED STATES','75216-6452','(214) 228-3447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:42:23',0,NULL,3,1,1,1,'\\ ','3447'),(3043,704025975011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','jive.talkin.robot','ebay@rockout.org','Adam Arseneau','860 Rymal Rd. E<br>Unit 11','Hamilton','ON','CANADA','L8W2X3','(905) 315-4305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:42:50',0,NULL,3,1,2,1,'\\ ','jive.talkin.robot'),(3044,668287333001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','valtkach6','poltava@earthlink.net','Valeriy Tkachenko','555 MAIN ST<br>APT 1407','NEW YORK','NY','UNITED STATES','10044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:43:20',0,NULL,3,1,1,1,' LK045713752CN\r\\','valtkach6\r'),(3045,578552955013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','kadrely','kadrelyp@gmail.com','yahe','12721 Lynn Rd<br>Lot 30','tampa','FL','UNITED STATES','33624-2863','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 22:57:02',0,NULL,3,1,1,1,'\\ ','kadrely'),(3046,704051877011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',18.9,'eastar4','importacionquito','ivanmarcelo27@hotmail.com','IVAN MARCELO QUINTANILLA','LORENZO ALDANA OE3-19 Y AVENIDA AMERICA','QUITO','PICHINCHA','ECUADOR','59301','3200576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 23:51:24',0,NULL,3,1,2,1,'\\ ','importacionquito'),(3047,531933695004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','chris_gupta','locomotivesteamerheisler@yahoo.com','Christian Gupta','523 Harvard Rd','San Mateo','CA','UNITED STATES','94402','(650) 823-5454','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 23:59:09',0,NULL,3,1,1,1,'\\ ','chris_gupta'),(3048,532193301004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','ecomtelecomunicaciones','ecom@ecomtelecomunicaciones.com','Ecom Telecomunicaciones','C/ San Blas, 14-A','Paterna (Valencia)','Comunidad Valenciana','SPAIN','46980','644500800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 00:14:33',0,NULL,3,1,3,1,'RA117732183CN\r ','ecomtelecomunicaciones\rHSNO017  欧标\r'),(3049,782014758012,220502333507,'2.1 HP DV2000 DV2100 DV2200  Bluetooth Module+ cable',1,'BTHP2103',12.8,'eastar4','texicanian','t_raley3@hotmail.com','Thomas Raley','3722 W Rochelle Rd','Irving','TX','UNITED STATES','75062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 00:21:31',0,NULL,3,1,1,1,'\\ ','texicanian\rHP 8pin 1.0 12cm '),(3050,578036145013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','vimalpaul2255','vimalpaul2006@yahoo.com','Vimal Paul','L&P Rubber Industries,<br>Rubber Park, Valayanchirangra P.O, Perumbavoor','Ernakulam','Kerala','INDIA','683556','9745929333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 01:16:04',0,NULL,3,1,3,1,'RA117732648CN RA117732577CN','vimalpaul2255\rHSNO019\r欧标\r申报10美金\rRA117732577CN\r\r'),(3051,782044386012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','casitatraveler','lkdavis.co@gmail.com','Lowell K Davis','PO Box 599<br>1341 County Road 85','Tabernash','CO','UNITED STATES','80478','(970) 887-2296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:37:56',0,NULL,3,1,1,1,'\\ ','casitatraveler'),(3052,0,220774366903,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.22,'eastar4','ptechiiiii','pdog70@msn.com','PEDRO RODRIGUEZ','12332 Floral Dr','WHITTIER','CA','UNITED STATES','90601-3021','(562) 699-5303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:54:29',0,NULL,3,1,1,1,'\\ ','ptechiiiii'),(3053,578586358013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','kpgmd','katepgarcia@yahoo.com','kate garcia','4 topaz street, millionaires village, novaliches','quezon city','','PHILIPPINES','1123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 01:55:10',0,NULL,3,1,2,1,'\\ ','kpgmd'),(3054,782049541012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','embexiu','ntpphong@yahoo.com','Phong T Nguyen','12631 Pleasant Pl<br>null','Garden Grove','CA','UNITED STATES','92841-4938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 01:57:19',0,NULL,3,1,1,1,'\\ ','embexiu\r红边优联'),(3055,782052745012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','annaandythai','thantai2002ca@yahoo.com','van hung thai','2747 rue benjamin - sulte.','montreal','QC','CANADA','h3m1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 02:07:49',0,NULL,3,1,2,1,'\\ ','annaandythai'),(3056,704089228011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','pdiddy56','peter22@sbcglobal.net','Pedro De La Cruz','2416 Houston St','Los Angeles','CA','UNITED STATES','90033-2520','(323) 485-0443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 02:22:22',0,NULL,3,1,1,1,'\\ ','pdiddy56'),(3057,577536202013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','denice202001','denice202001@yahoo.com','TASHONDRA D ROPER','8100 Winterwood Dr','Little Rock','AR','UNITED STATES','72209-7319','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'denice202001'),(3058,704115773011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','joserodriguezcuevas','jarcvs88@gmail.com','JOSE RODRIGUEZ','1131 Leahy RD','MONTEREY','CA','UNITED STATES','93940-7451','(831) 831-5572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 04:39:10',0,NULL,3,1,1,1,'\\ ','joserodriguezcuevas'),(3059,704116359011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','bomblekz','kuansien@hotmail.com','kuansien chiang','16 Mort Street','shortland','New South Wales','AUSTRALIA','2307','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:42:15',0,NULL,3,1,2,1,'\\ ','bomblekz'),(3060,578614730013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','nazauto','nazauto@aol.com','discount tir center c/o nazareth minassian','6817 van nuys blvd','van nuys','ca','UNITED STATES','91405-4626','(818) 421-5517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 04:48:26',0,NULL,3,1,1,1,'\\ ','nazauto'),(3061,578616459013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','gsmrepair_com','8727303@qip.ru','Vitaliy Alentev','Kusnecova str. 20-245','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 05:03:30',0,NULL,3,1,3,1,'RA117732515CN\r ','gsmrepair_com\rMOSA002\r'),(3062,782098076012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','chilaquil626','subaru2005_1@hotmail.com','agustin hernandez','17036 Broadvale Dr','la puente','CA','UNITED STATES','91744-4251','(626) 333-8893','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 05:42:47',0,NULL,3,1,1,1,'\\ ','chilaquil626'),(3063,578620096013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','tonyw36','tony.wong@au.viewsonic.com','Tony Wong','Unit 4, 44 Dickson Ave','Artarmon','New South Wales','AUSTRALIA','2064','0299066277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 05:32:59',0,NULL,3,1,2,1,'\\ ','tonyw36'),(3064,782107269012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',5,'CMLO001',249.95,'eastar4','risaasen','hjr@ebs-as.no','EBS AS v/Helge Risaasen','Peder Sletners vei 4','Kolbotn','Kolbotn','NORWAY','1415','004795052532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 06:42:37',0,NULL,3,0,4,1,'YW866010866CN ','risaasen'),(3065,782124772012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dyhr1973','asia_number1@hotmail.com','Daisuke Yuhara','2-19 Gakuonji','Yao','Osaka','JAPAN','581-0853','(50) 1555-2163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 07:52:05',0,NULL,3,1,2,1,'\\ ','dyhr1973'),(3066,703096670011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',32.5,'eastar4uk','ptru1955','pt@city.dk','Peter Truelsen','25 Magdelonevej','Copenhagen','','DENMARK','2400','(045) 29623930','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 07:59:53',0,NULL,3,1,3,1,'RA117732634CN ','ptru1955\rWWOT001\r'),(3067,578645035013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','rowdy1974','samantha.donovan@gmail.com','Byron Donovan','37 Union Road','Surrey Hills','Victoria','AUSTRALIA','3127','0398363999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:37:29',0,NULL,3,1,3,1,'RA117733073CN\r ','rowdy1974\rMOSA003'),(3068,782137330012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ramazzotti_totti','torsten263@web.de','Torsten Schmitt','Zum Wurmtal 8','Wuerselen','','GERMANY','52146','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:47:29',0,NULL,3,1,2,1,'\\ ','ramazzotti_totti'),(3069,704169288011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','elmyh1','chenhsiung@gmail.com','Chen Hsiung Wong','Level 13, Menara Park (Formerly KUB.com), Megan Avenue 2, Blk D<br>No. 12, Jalan Yap Kwan Seng','Kuala Lumpur','Kuala Lumpur','MALAYSIA','50450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 09:15:32',0,NULL,3,1,2,1,'\\ ','elmyh1'),(3070,578655018013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','de39ster','dirt444@gmail.com','Sándor Németh','iskola utca 73','Gomba','','HUNGARY','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 09:41:12',0,NULL,3,1,2,1,'\\ ','de39ster'),(3071,782163670012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','racer560surf','racer560@onlinehome.de','Berthold Rademacher','Reiger Weg 37','Velbert','','GERMANY','42553','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:32:47',0,NULL,3,1,2,1,'\\ ','racer560surf\r红边优联'),(3072,782168487012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mrandmrsgee','pat_dan@bigpond.com','Patrick and Danielle Gaut','90 Russell St','tumut','New South Wales','AUSTRALIA','2720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:55:14',0,NULL,3,1,2,1,'、 ','mrandmrsgee\r红边优联\r新地址\r\rPatrick and Danielle Gaut\rconner spicer 1/9 view st \rmarrackville 2720 nsw \rAustralia'),(3073,578670000013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','8kedc54','sterndani@yahoo.com','Dani Stern','PO BOX 3005','Ramat Hasharon','israel','ISRAEL','47130','+972-50-7599993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:04:24',0,NULL,3,1,3,1,'RA117732965CN\r ','8kedc54\rBAZA001'),(3074,782175065012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','skaska1000','skaska100@mail.ru','Natalia Nechaeva','Krasnogo Mayaka st. 4/2','Moscow','Moscow','RUSSIAN FEDERATION','117519','+74953136356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:15:10',0,NULL,3,1,2,1,'\\ ','skaska1000\r欧标'),(3075,577215050013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','thai_vy','joliedinh@gmail.com','Vy  Dinh Thao','C45 Cu Xa Vinh Hoi, Phuong 5, Quan 4','Ho Chi Minh','Ho Chi Minh','VIET NAM','054','(+84) 938206866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:16:49',0,NULL,3,1,2,1,'\\ ','thai_vy'),(3076,578672741013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','nfix_dj','master.qmail@gmail.com','Jiri Dejmek','Nadrazni 23','Novy Jicin','','CZECH REPUBLIC','741 01','(420) 774838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:21:44',0,NULL,3,1,2,1,'\\ ','nfix_dj'),(3077,704206996011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','lewis.1012','janehcleveland@yahoo.com','ROGER CLEVELAND','403 S Sycamore St','Palestine','TX','UNITED STATES','75801-3509','(903) 948-9088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 11:45:26',0,NULL,3,1,1,1,'\\ ','lewis.1012\r带电池'),(3078,578681434013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','axo78','ignacio.diaz.cortes@gmail.com','Ignacio Díaz Cortés','Alcala 44, 4º (Ashurst)','Madrid','Madrid','SPAIN','28014','629013805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:02:54',0,NULL,3,1,3,1,'RA117733158CN ','axo78\rOTRA002'),(3079,525602216003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','shruthi87','shruthi_paradise@yahoo.com','Mangay Samy Vellu','4281 Express Ln<br>Ste L5421','Sarasota','FL','UNITED STATES','34238-2602','941 538 6941','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 12:09:02',0,NULL,3,1,1,1,'\\ ','shruthi87'),(3080,578689970013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','twistedmind1974','mr.twist@gmx.de','Klaus Stürzenbecher','Nappenhorn 19','Barmstedt','','GERMANY','25355','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:42:47',0,NULL,3,1,2,1,'\\ ','twistedmind1974'),(3081,578692486013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','zivtsarfati14','digger18@gmail.com','Ziv Tsarfati','Hayarden 27','Moshav Tal Shahar','','ISRAEL','76805','972-54-7655544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:57:01',0,NULL,3,1,3,1,'RA117732974CN ','zivtsarfati14\rBAZA001'),(3082,704231240011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','benandtim','baj73@aol.com','Ben Johansen','511 Teakwood Dr','Altamonte Springs','FL','UNITED STATES','32714-7429','(407) 697-5034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 13:10:32',0,NULL,3,1,4,1,'YW866010855CN ','benandtim'),(3083,704235750011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','ckchoi73','ckchoi73@hotmail.com','Joshua Choi','Suite 5, Level 3,<br>33 Rowe Street','Eastwood','New South Wales','AUSTRALIA','2122','0298584977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 13:24:25',0,NULL,3,1,2,1,'\\ ','ckchoi73'),(3084,704243039011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','rumrumvoo','pictureoftime@hotmail.co.uk','David Thomas','8, Rolls ave, Forest Park est,<br>Penpedairheol','Hengoed','South Wales','UNITED KINGDOM','CF82 8HP','01443833149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 13:47:41',0,NULL,3,1,3,1,'RA117732912CN\r ','rumrumvoo\rMOAP001'),(3085,659815970001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','rys_store','ryan@rollinjunk.com','3D Mobile creations','933 E Crosstown pkwy','kalamazoo','MI','UNITED STATES','49001-2507','(269) 998-6597','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 14:03:59',0,NULL,5,0,18,0,NULL,'rys_store'),(3086,704258504011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','guatis','guatis@gmail.com','Benjamín Velasco','Albacete 4420<br>Depto 72','Santiago','Santiago','CHILE','7580287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 14:35:18',0,NULL,3,1,2,1,'\\ ','guatis'),(3087,704267691011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','poofs','poofsie@yahoo.com','Ronald Serafin','25202 Colgate St','Dearborn Heights','MI','UNITED STATES','48125-1643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 15:02:02',0,NULL,3,1,1,1,'\\ ','poofs'),(3088,782259563012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','sashoh','sashoh@gmail.com','Alexander Hristov','Kukush 1 street<br>Mtel M1 Building, Room A103','Sofia','Bulgaria','BULGARIA','1309','+359882204432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 15:29:13',0,NULL,3,1,3,1,'RA117732872CN ','sashoh\r蓝牙版的\rMOLO005'),(3089,782261807012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','a3vanderberg','emieljansen@hotmail.com','Emiel Jansen','Weideland 10','Den Hoorn','','NETHERLANDS','2635 JP','0151234567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 15:35:25',0,NULL,3,1,3,1,'RA117733008CN\r ','a3vanderberg\rOTCR001'),(3090,578734020013,230606052768,'New Leather Case Built-in Bluetooth Keyboard For iPad',1,'KBAP001',39.8,'eastar4','cgarrett31304','cgarret1@comcast.net','Charles Garrett','31304 Saunders Dr','Tavares','FL','UNITED STATES','32778-4921','(407) 310-4760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 15:49:16',0,NULL,3,1,1,1,'\\ ','cgarrett31304'),(3091,782283167012,220704730539,'New in Box Plantronics Explorer 330 BLUETOOTH HEADSET',2,'HSPL004',31,'eastar4uk','jtrunky','jaynelinfoot@gmx.com','Jayne Linfoot','150 galliard road','edmonton','london','UNITED KINGDOM','n9 7lp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 16:32:38',0,NULL,3,1,3,1,'RA117732930CN\r ','jtrunky\rHSPL004\r英标'),(3092,704302386011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','mike-mm','mihail.pashko@gmail.com','Mihail Pashko','lermontova 207 kv 7','Slavyansk-na-Kubani','Krasnodar','RUSSIAN FEDERATION','353560','918-454-86-67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:36:54',0,NULL,3,1,2,1,'\\ ','mike-mm\r欧标'),(3093,575975446013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',138.99,'eastar4','xxdestiny','annie.ta.tran@gmail.com','Annie Tran','68 Westforest Trail','Kitchener','ON','CANADA','n2n3a8','(519) 496-7380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:48:43',0,NULL,3,1,3,1,'RA117715106CN ','xxdestiny\rRCLO003'),(3094,782296309012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','salvanica_8385','lanica040507@hotmail.com','Annes Arana','13107 Kumar Ct','Woodbridge','VA','UNITED STATES','22193-5244','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 16:58:10',0,NULL,3,1,1,1,'\\ ','salvanica_8385'),(3095,704318907011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',4,'GLSG001',271.96,'eastar4','blpch','brian.heiser1@verizon.net','Brian M. Heiser','16562 Aquamarine Ct','Chino Hills','CA','UNITED STATES','91709-4644','(909) 597-0639','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 17:19:59',0,NULL,3,1,6,1,'EE520583304CN ','blpch\r带电池'),(3096,704324384011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',29.8,'eastar4','guard.69.angel','piglet.7@btinternet.com','Joanna Briggs','7,Emmery close','Broughton','Lincolnshire','UNITED KINGDOM','DN20 0SN','01652658984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:30:54',0,NULL,3,1,2,1,'\\ ','guard.69.angel'),(3097,578769843013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','cascademaxi12','doofkatze@gmx.de','Maxi  Behn','Kreuzlingerstr.9','Germering','','GERMANY','82110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:46:23',0,NULL,3,1,2,1,'\\ ','cascademaxi12'),(3098,704331949011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','dolbination','guntrash@gmail.com','Burdila Alexandru','str. Columna 121, ap. 35','Chisinau','','MOLDOVA, REPUBLIC OF','MD 2012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:47:56',0,NULL,3,1,3,1,'RA117733060CN\r ','dolbination\rWLAP009'),(3099,578771272013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','puzzybaer','puzzybaer@gmx.net','Dominik Berger','Theresienstr. 4','Augsburg','','GERMANY','86153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:49:17',0,NULL,3,1,2,1,'\\\r ','puzzybaer'),(3100,704331082011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','flash15*','tom-spencer4@hotmail.co.uk','Michael Spencer','Resipole House,<br>Gubberford Lane, Garstang','Preston','Lancashire','UNITED KINGDOM','PR3 1PS','01995604147','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 17:49:54',0,NULL,3,1,3,1,'RA117732991CN\r ','flash15*\rMOAP001'),(3101,526639661003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','jeep_ko-bk','jeep_ko@bk.ru','Dzhepko Vitaliy','Komsomolskaya<br>113-24','Rubtsovsk','Altayskiy kray','RUSSIAN FEDERATION','658207','+79133626243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:53:38',0,NULL,3,1,3,1,'RA117733087CN ','jeep_ko-bk\rHSMO018\r欧标'),(3102,578767197013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','andrerosso66','andrerossobr@gmail.com','Andre Schumann Rosso','SQS 104 Bloco D apto 504<br>ASA SUL','Brasilia','DISTRITO FEDERAL','BRAZIL','70343-040','+556138790202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:36:23',0,NULL,3,1,2,1,'\\ ','andrerosso66'),(3103,704330400011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','aynne08','jymmy1000@hotmail.com','tarcisio silva','praca da bandeira quadra 142 lote 14 setor jao','Goiania','Goias','BRAZIL','74674-040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 19:09:03',0,NULL,3,1,3,1,'RA117732869CN ','aynne08\rRCLO006'),(3104,782377782012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','chouette60','martinelaliberte@hotmail.com','martinelaliberte','436, rue bérubé','quebec','QC','CANADA','g1m 1c8','(418) 687-0770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 19:33:11',0,NULL,3,1,2,1,'\\ ','chouette60'),(3105,782382278012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','stkandrdr','steven.keith@comcast.net','Steven Keith','2690 Nevada Ct','Placerville','CA','UNITED STATES','95667-3837','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 19:37:54',0,NULL,3,1,1,1,'\\ ','stkandrdr'),(3106,704410835011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','lepoja11','raimo.aikas@gmail.com','raimo äikäs','päijänteentie 48','vilppula','Oletus','FINLAND','35700','0443137495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 20:26:43',0,NULL,3,1,2,1,'\\ ','lepoja11\r欧标'),(3107,704420779011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',12.5,'eastar4','jerki1py8','jerrylking@yahoo.com','Jerry King','916 Crescent Moon Dr','North Las Vegas','NV','UNITED STATES','89031-1493','(702) 639-6653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 20:46:10',0,NULL,3,1,1,1,'\\ ','jerki1py8\racer 4pin1.25 6cm'),(3108,704425065011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',14.9,'eastar4uk','ashe8741','sheps@talktalk.net','Andrew Shepherd','18 Woollards Lane<br>Great Shelford','Cambridge','Cambridgeshire','UNITED KINGDOM','CB22 5LZ','07860443856','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 20:54:27',0,NULL,3,1,3,1,'RA117732926CN ','ashe8741\rHSJA002\r英标'),(3109,782433019012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','tunney205','shawn.tunney@gmail.com','Shawn Tunney','PO Box 183','Roscoe','PA','UNITED STATES','15477','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 21:15:27',0,NULL,3,1,1,1,'\\ ','tunney205\r红边优联'),(3110,704438720011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',3,'HSJA002',44.7,'eastar4uk','manofbronze55','jerrysavagehd@msn.com','Jerry Savage','5073 Dyer Ln','Taylorsville','UT','UNITED STATES','84118-2913','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:34:17',0,NULL,3,1,1,1,'\\ ','manofbronze55'),(3111,578851856013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','buyer.md','redmax@rambler.ru','Maxim Vasik','str. Igor Vieru 14 apt. 96','Chisinau','MD','MOLDOVA, REPUBLIC OF','2075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 21:38:22',0,NULL,3,1,2,1,'\\ ','buyer.md'),(3112,782443449012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','drunk_f','dr_unk@msn.com','Florian Dranca','24 Bolton Gardens<br>flat 1, c.o. Carlo Casiraghi','London','London','UNITED KINGDOM','SW5 0AQ','2073701717','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:40:20',0,NULL,3,1,3,1,'RA117732943CN ','drunk_f\rANCN001'),(3113,578855338013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','navs44','navs21@gmail.com','Navjot Sandhu','25 pringle drive','Barrie','ON','CANADA','L4N0N9','(705) 792-0698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 21:47:42',0,NULL,3,1,2,1,'\\ ','navs44'),(3114,704450162011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','lacey0406','lmc8623@yahoo.com','Lacey Case','944 Sams Rd NW','Brookhaven','MS','UNITED STATES','39601-8696','(601) 757-8937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 22:06:51',0,NULL,3,1,1,1,'\\ ','lacey0406'),(3115,704453148011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',43.95,'eastar4','scunkaneli','scunkaneli@yahoo.de','Christian Hanke','Leipziger Straße 7','Zeitz OT Zangenberg','','GERMANY','06712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 22:11:15',0,NULL,3,1,3,1,'RA117732988CN\r ','scunkaneli\rWWOP003'),(3116,578862588013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','pierre0357','pierre.fridel@yahoo.fr','Pierre Fridel','24, rue Paul Simminger','Montigny-les-Metz','Lorraine','FRANCE','57950','06.61.86.97.48','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 22:19:55',0,NULL,3,1,2,1,'\\ ','pierre0357'),(3117,782470385012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','sbarsotti','sbarsotti@hotmail.com','Steve Barsotti','19255 SW 65th Ave<br>Suite 120','Tualatin','OR','UNITED STATES','97062-9712','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:04:34',0,NULL,3,1,1,1,'\\ ','sbarsotti'),(3118,782473027012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','cirruslx','gbrown69@gmail.com','Gaetan Brown','2255 du Neptune','Quebec','QC','CANADA','G2E 6A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:10:50',0,NULL,3,1,2,1,'\\ ','cirruslx'),(3119,578877413013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','dwallingham','dwallingham@hotmail.com','David Wallingham','3000 Olivet St.<br>Suite 105','Halifax','NS','CANADA','B3L3Z7','(902) 431-0045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:37:52',0,NULL,3,1,2,1,'\\ ','dwallingham'),(3120,782480509012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','kastlekolor','slaterlovesspam@yahoo.com','Greg Stieritz','2266 Hickory Creek Ln','New Richmond','OH','UNITED STATES','45157','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:39:26',0,NULL,3,1,1,1,'\\ ','kastlekolor'),(3121,702894119011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','clearwater-designs','ccperla@earthlink.net','Christine C Perla','13156 Seneca Dr','Waynesboro','PA','UNITED STATES','17268-8458','(717) 762-6460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 23:47:28',0,NULL,3,1,1,1,'\\ ','clearwater-designs'),(3122,782491098012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','kmcflow','kmcflow@pacbell.net','Kevin McCormick','810 Los Vallecitos Blvd<br>Ste 214','San Marcos','CA','UNITED STATES','92069-1451','(760) 471-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 00:19:22',0,NULL,3,1,1,1,'\\ ','kmcflow'),(3123,578896270013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','mare1383','smiley401816@yahoo.com','Maryann Maness','4198 Martin Rd','Festus','MO','UNITED STATES','63028-3459','(636) 337-7034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 01:19:23',0,NULL,3,1,1,1,'\\ ','mare1383'),(3124,704520968011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',83,'eastar4','plcab','plcoptions@bigpond.com.au','PLC Options Pty Ltd','Unit 12<br>37 Shipley Drive','Rutherford','New South Wales','AUSTRALIA','2320','0249337757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 02:46:01',0,NULL,3,1,3,1,'RA117732957CN ','plcab\rTRTS001*10'),(3125,782547615012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','lourdes1858','phil.n@mirjmj.com','Phil Stuckey','81 Chapel Road','Moorabbin','Victoria','AUSTRALIA','3189','0419525071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:06:26',0,NULL,3,1,2,1,'、 ','lourdes1858\r极动鲨鼠标'),(3126,532524688004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.99,'cnfaner','decha.t','bosslee2010@gmail.com','Decha Tharakulwattana','698/29 Ideomix Phaholyothin, Phaholyothin Road<br>Samsean Nai, Phayathai','Bangkok','','THAILAND','10400','+66843530111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:08:35',0,NULL,3,1,3,1,'RA117732841CN ','decha.t\rOTRA002'),(3127,578925307013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','elizabeth841410','elizabeth.buitrago@gmail.com','Elizabeth Buitrago','Rue du village 43','Lutry','','SWITZERLAND','1095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:10:52',0,NULL,3,1,2,1,'\\ ','elizabeth841410'),(3128,704544164011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','ginacopycatana','copycatana@gmail.com','Trent Montgomery','5 Delacy Court','Narre Warren South','Victoria','AUSTRALIA','3805','61400998880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:48:11',0,NULL,3,1,2,1,'、 ','ginacopycatana'),(3129,704545030011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 04:53:31',0,NULL,8,1,17,1,NULL,'ushakh\r无线蓝牙二合一'),(3130,578933423013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',75.99,'eastar4','niceaudio4less','av4less@aol.com','donald beale','13 Firedrake Terrace','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 05:14:04',0,NULL,3,1,1,1,'、 ','niceaudio4less'),(3131,578936441013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','citio','mikhail@arteev.com','Mikhail Arteev','Avenue du Moléson, 21','Fribourg','','SWITZERLAND','1700','0767000333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 05:40:42',0,NULL,3,1,3,1,'RA117732909CN ','citio\rHSNO019'),(3132,782205582012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','gsrerio','csrcs@bis.net.ua','Svjatoslav Gresuk','Zabyzzia I. Franka, 74','Sokal','Lviv region','UKRAINE','80028','380639760702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 06:56:45',0,NULL,3,1,2,1,'、 ','gsrerio'),(3133,578948744013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:14:01',0,NULL,3,1,3,1,'RA117732855CN ','ushakh\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r一个New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card'),(3134,704570680011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','ushakh','yushakov@mail.ru','Yuri Ushakov','Shosse Kosmonavtov 209-43','Perm','Permskiy krai','RUSSIAN FEDERATION','614065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:16:10',0,NULL,8,0,17,0,NULL,'ushakh'),(3135,704576884011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','bass_hunter69','ab_apple@me.com','Alex BAUD','9 rue Roger Bréchan','Lyon','Rhône-Alpes','FRANCE','69003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:47:50',0,NULL,3,1,3,1,'RA117732838CN ','bass_hunter69\rUDAP001 '),(3136,704463692011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','fixbeau','francois.xavier.beau@gmail.com','François-Xavier Beau','225 W 83rd St<br>Apt 20I','NEW YORK','NY','UNITED STATES','10024-4964','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 07:57:51',0,NULL,3,1,1,1,'\\ ','fixbeau'),(3137,526808676003,130490202395,'Genuine Logitech Harmony 525 Universal Remote Control',1,'RCLO005',74.99,'cnfaner','reinholdmichael','philip_hill@web.de','Philip Hill','Talstraße 45','Ockenfels','','GERMANY','53545','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 08:05:31',0,NULL,3,1,3,1,'RA117732767CN ','reinholdmichael\rRCLO005\r'),(3138,704591326011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','astchanuk','andrewstchan@gmail.com','AST Chan','12A Poplar Road','Herne Hill','London','UNITED KINGDOM','SE24 0BW','02077387804','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 08:54:26',0,NULL,3,1,3,1,'RA117715154CN ','astchanuk\rMOAP001'),(3139,578975922013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','ozimextrading','sales@ozimextrading.com.au','Ngoc Minh','45/4-10 Benedict Ct','HOLROYD','New South Wales','AUSTRALIA','2142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 10:11:46',0,NULL,3,1,2,1,'、 ','ozimextrading'),(3140,526840686003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',21.99,'cnfaner','isakovboris972','isakovboris@walla.com','boris isakov','P.O.Box 4332','Bait Arie','ID','ISRAEL','71947','972-50-6273355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:21:44',0,NULL,3,1,3,1,'RA117715260CN\r ','isakovboris972\rHSMO017'),(3141,782652677012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','lamdim','lamdimos@yahoo.com','LAMBROS DIMOS','MAIANDROY 12 CHALANDRI','ATHENS','CHALANDRI','GREECE','15233','6972119668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:48:14',0,NULL,3,1,2,1,'、 ','lamdim\racer 8pin1.00 8cm'),(3142,704098018011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',22.98,'eastar4','rq!','post2rq@gmail.com','R.A. Quinn','160 Lane Rd','Chester','NH','UNITED STATES','03036','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 11:57:53',0,NULL,3,1,1,1,'\\ ','rq!\r一共买了两个'),(3143,704644570011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','doctor_macintosh','sat@conserve.de','CONSERVE Computer','Im Mediapark 11','Köln','','GERMANY','50670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:22:04',0,NULL,3,1,3,1,'RA117715375CN\r ','doctor_macintosh\rWLAP009'),(3144,782668558012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','oksteine','oksteine@online.no','Ole Kristian Steine','Hvittingfossveien 362a','Holmestrand','','NORWAY','3080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:40:54',0,NULL,3,1,2,1,'、 ','oksteine\r红边优联'),(3145,579005907013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','timporium','ttalimon@mail.win.org','Tim Talimonchuk','1879 S Old Highway 94','Saint Charles','MO','UNITED STATES','63303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 12:46:34',0,NULL,3,1,1,1,'\\ ','timporium\r由于旧的缺货，发一个新的'),(3146,704673243011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','tmfitz2001','tmfitz2001@yahoo.com','Tom Fitzgerald','1827 S Madison St','Denver','CO','UNITED STATES','80210-3629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 13:57:20',0,NULL,3,1,1,1,'\\ ','tmfitz2001'),(3147,782695037012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','belle_riviere','oung.byun@sciences-po.org','Oung BYUN','1, Rue Maurice Arnoux<br>ENS B515','Montrouge','Ile-de-France','FRANCE','92120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 14:00:38',0,NULL,3,1,2,1,'\\ ','belle_riviere\r红边优联'),(3148,579023322013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','tiga_cat','frankg@vt.edu','Francis  Galligan','2521 Gloucester Dr','Blacksburg','VA','UNITED STATES','24060-8267','(540) 552-6663','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 14:04:42',0,NULL,3,1,1,1,' \\','tiga_cat'),(3149,782697546012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA002',22.59,'eastar4uk','jbra23163','paulnjohn@talktalk.net','John Atherall','176 Hadlow road','Tonbridge','Kent','UNITED KINGDOM','tn9 1pd','01732350335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:09:06',0,NULL,3,1,3,1,'RA117715389CN\r ','jbra23163\rOTRA002'),(3150,782705781012,220720533789,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',21.5,'eastar4uk','peregrine_took','rpnc_ebay@tiscali.co.uk','Russell Parker','118 Woodfield Drive','Barnet','Herts','UNITED KINGDOM','EN4 8PB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:31:58',0,NULL,3,1,3,1,'RA117715361CN\r ','peregrine_took\rSCLO001'),(3151,704234638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','978tomtom88','mccormick.t.p@gmail.com','Tom McCormick','1 Blue Ridge Rd','Westford','MA','UNITED STATES','01886-1909','(978) 407-6708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 15:23:30',0,NULL,3,1,1,1,'\\ ','978tomtom88'),(3152,526899895003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','johnnyjean','jgagne@cybernaute.com','Jean Gagne','157, rue Neree','Chicoutimi','QC','CANADA','G7G 4A5','(418) 543-5376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 16:04:05',0,NULL,3,1,3,1,'RA117715392CN\r ','johnnyjean\rOTGR001'),(3153,704715322011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','graffittimonster','winto1990@gmx.net','Andrea Winter','Augustastraße 38','Oranienburg','','GERMANY','16515','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 16:05:44',0,NULL,3,1,2,1,'、 ','graffittimonster'),(3154,704728197011,320679575403,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.5,'eastar4uk','squall25','squalldenis@gmail.com','DENIS SMIRNOV','Garibaldi 10-6-553','Moscow','Moscow','RUSSIAN FEDERATION','117393','7(926)2164450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 16:40:13',0,NULL,3,1,2,1,'、 ','squall25'),(3155,579073928013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',12.8,'eastar4','misiom1','misioallegro@gmail.com','Michał Mroczkowski','Dobrowolskiego 1c/12','Gdańsk','pomorskie','POLAND','80287','696 449750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:22:24',0,NULL,3,1,2,1,'、 ','misiom1\racer 8pin1.0 3cm\r'),(3156,660317741001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','516gene','gene@kenclaire.com','Kenclaire Electric','714 Old Country Rd','Westbury','NY','UNITED STATES','11590-4504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:10:24',0,NULL,5,0,18,0,NULL,'516gene'),(3157,782801021012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','acrouth','alanrouth@gmail.com','Alan C. Routh','82 Fairview Ave','Chatham','NJ','UNITED STATES','07928-1741','(973) 635-0906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:18:00',0,NULL,3,1,1,1,'\\ ','acrouth\r红边优联'),(3158,526952062003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','cafilisador','okokendi@gmail.com','Wellington Kendi Oko','Rua Dona Nina Zanotto, 155<br>Jardim Las Vegas','Santo André','São Paulo','BRAZIL','09182-410','(5511) 9263-4126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 18:59:01',0,NULL,3,1,3,1,'RA117715401CN\r ','cafilisador\rHSMO018'),(3159,782823843012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','lagunacyberguy','stevecanning@cox.net','Steve Canning','5 Carmel Court','Laguna Beach','CA','UNITED STATES','92651','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 18:59:18',0,NULL,3,1,1,1,'\\ ','lagunacyberguy'),(3160,579112818013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','khrisanov','khrisanovdmitrij@gmail.com','Дмитрий Хрисанов','Сурова 24-66','Ульяновск','Ульяновская область','RUSSIAN FEDERATION','432055','+79276330163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:13:22',0,NULL,3,1,2,1,'、 ','khrisanov'),(3161,579122437013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','rooms001','reolschool@yahoo.fr','emilie ringoir','16 rue housseroul','nalinnes','','BELGIUM','6120','071215862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:34:14',0,NULL,3,1,2,1,'、 ','rooms001'),(3162,782849410012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',25.96,'eastar4uk','jona8932','jon_askham@yahoo.com','Jon Askham','21 Dower Chase<br>Escrick','York','North Yorkshire','UNITED KINGDOM','YO19 6JF','07779859231','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 19:45:29',0,NULL,3,1,3,1,'RA117715415CN\r ','jona8932\rHSPL011\r英标'),(3163,704823355011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','aleksey1005','alekseygsm@mail.ru','Aleksey Shitov','Nastavnikov 15/2-140','Sankt-Peterburg','ru','RUSSIAN FEDERATION','195298','79119737296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 20:02:49',0,NULL,3,1,2,1,'、 ','aleksey1005'),(3164,782884378012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','sboer5','sander.boer@casema.nl','sander boer','Laan van Nieuw Oosteinde 362','VOORBURG','','NETHERLANDS','2274GH','070 3839979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 20:53:32',0,NULL,3,1,2,1,'、 ','sboer5'),(3165,579155490013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','havix_end','h_a_v_i_x@yahoo.com','Philip Johnson','182 Mount Marie Ave NW','Canton','OH','UNITED STATES','44708','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'havix_end'),(3166,579156129013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','mickg-man','nospamman@mac.com','Mick Guinn','313 Salida del Sol','Santa Barbara','CA','UNITED STATES','93109-2021','(805) 259-9584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 21:15:59',0,NULL,8,1,17,0,NULL,'mickg-man'),(3167,579157175013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',87.96,'eastar4','mickg-man','nospamman@mac.com','Mick Guinn','313 Salida del Sol','Santa Barbara','CA','UNITED STATES','93109-2021','(805) 259-9584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 21:17:40',0,NULL,3,1,1,1,'\\ ','mickg-man\r一共买了5个\r苹果鼠标'),(3168,704865760011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 21:42:54',0,NULL,3,1,3,1,'RA117715335CN\r ','update_marcelo\rWWSI006'),(3169,782910873012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','garym2475','gmorrison_30@yahoo.co.uk','Gary  Morrison','61 Holmhills Drive, Cambuslang','Glasgow','South Lanarkshire','UNITED KINGDOM','G72 8EN','01416417734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 21:59:48',0,NULL,3,1,3,1,'RA117715503CN\r ','garym2475\r英标\rHSPL010'),(3170,782914168012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','levraimisutsu','misutsu@live.fr','SCP TEISSONNIERE ET ASSOCIES','STEVE CHARTIER<br>5 RUE ST-GERMAIN L\'AUXERROIS','PARIS','Île-de-France','FRANCE','75001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 22:29:44',0,NULL,3,1,3,1,'RA117715344CN\r ','levraimisutsu\rOTSO002'),(3171,704888429011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.76,'eastar4','therntier','therntier@gmail.com','Travis Herntier','7122 105A Street','Edmonton','AB','CANADA','T6E4H9','(780) 633-5939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:01:30',0,NULL,3,1,3,1,'RA117715450CN\r ','therntier\rMOSA001\r新地址\rTravis Herntier\r127 Patterson Cres\rBrandon, Manitoba\rR7A 6T7\rCANADA\r'),(3172,782933565012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','justphishing','mrpierre@gmail.com','Mr Anthony Pierre','25 Anerley Grove<br>Anerley','London','London','UNITED KINGDOM','SE19 2HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 23:14:33',0,NULL,3,1,3,1,'RA117715313CN\r ','justphishing\rHSPL014\r英标'),(3173,579185923013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','arawilbur','shopping.ebay@xenway.com','Alex Wilbur','7 Kelly Farm Way','Burlington','MA','UNITED STATES','01803-5124','(978) 821-8101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-05 23:30:52',0,NULL,3,1,1,1,'\\ ','arawilbur'),(3174,579190447013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','scudworm','scudworm@rogers.com','John Giang','18 Dovehaven Court','North York','ON','CANADA','M3N2G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:53:30',0,NULL,3,1,2,1,'\\ ','scudworm'),(3175,782946794012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','roland-d-50','chris.mendoza87@yahoo.com','j carmen mendoza','1986 21st st sw','vero beach','FL','UNITED STATES','32962-7915','(772) 453-0387','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 00:00:31',0,NULL,3,1,1,1,'\\ ','roland-d-50'),(3176,527029337003,130490187857,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'cnfaner','elfreak11','angel_of_evil5@hotmail.com','leclair yoann','26 daigle','sept-iles','QC','CANADA','g4r 4g8','(418) 960-5095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:09:15',0,NULL,3,1,3,1,'RA117715429CN\r ','elfreak11\rMOLO002\r'),(3177,579195461013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','lidney_2005','lmaynart@hotmail.com','Lidney Freitas','Rua Ministro João Mendes, 237<br>Casa 02','Santos','São Paulo','BRAZIL','11040-261','55 11 9186 0730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:21:41',0,NULL,3,1,2,1,'、 ','lidney_2005'),(3178,579126540013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','dghn22','daniel.ghn@gmail.com','Daniel Hernandez PN 19510','10421 N.W 28th Street D-106<br>P.O.Box Air Internationals','Miami','FL','UNITED STATES','33172','(305) 477-8334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 00:48:43',0,NULL,3,1,1,1,'\\ ','dghn22\rHP 8pin 1.0 23cm '),(3179,579201490013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','locotics','topforce@hanmail.net','Sungdeok, Hwang','HANYOUNG NUX Inc. 1381-3,<br>Juan-Dong, Nam-gu','Incheon','Incheon','KOREA,REPUBLIC OF','402200','+82-17-319-8233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 00:56:58',0,NULL,3,1,2,1,'、 ','locotics'),(3180,579205066013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','lucidalvacantanheidebrito','lucidalvacantanheide@gmail.com','MARCOS CARNEIRO','RUA RIACHUELO 2434<br>VERMELHA','TERESINA','PIAUI','BRAZIL','64018060','558632181524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:14:27',0,NULL,3,1,3,1,'RA117715358CN\r ','lucidalvacantanheidebrito\rWWOT001+ANCN001'),(3181,579112770013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',38.95,'eastar4','eldio727','eladiohp@hotmail.com','Eladio Herrero','727 Mitchell','Mont-Royal','QC','CANADA','H4P 1C9','(514) 737-3856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:47:50',0,NULL,3,1,3,1,'RA117715273CN\r ','eldio727\rOTRA002'),(3182,704928049011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','conecty71','danielxhorvath@gmail.com','Daniel Horvath','Apt.No.91 Louisa Bridge<br>Station Road','Leixlip','Kildare','IRELAND','ROI','0877412642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:51:08',0,NULL,3,1,3,1,'RA117715327CN\r ','conecty71\rGLSG001'),(3183,782997610012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','y-vern','mike@oregoncamera.com','Richard W Danler','264 sw madison ave','Corvallis','OR','UNITED STATES','97333-4706','(541) 753-2653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 03:17:45',0,NULL,3,1,1,1,'\\ ','y-vern'),(3184,579233016013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','patrykr1','patrykjava@optusnet.com.au','patryk prudzienica','6/10<br>TINDALL AVE','LIVERPOOL','New South Wales','AUSTRALIA','2170','0422838335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 03:59:25',0,NULL,3,1,2,1,'、 ','patrykr1'),(3185,781205976012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','joaruch2011','joa.ruch@freenet.de','Joachim^ Ruch','Am Sportplatz 14','Neuried','','GERMANY','77743','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 04:16:50',0,NULL,3,1,2,1,'、 ','joaruch2011\r4pin 1.25'),(3186,783015875012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','lksamm','jsmith@4q9.com','Jeff Smith','16611 Se May Valley Rd','Newcastle','WA','UNITED STATES','98059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 04:52:55',0,NULL,3,1,1,1,'\\ ','lksamm'),(3187,704965429011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',45.98,'eastar4','getnjiggywitit','clearandshiny@hotmail.com','Jonathan M. Kirchner','202 Cherokee Ln','Victoria','TX','UNITED STATES','77901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 05:05:46',0,NULL,3,1,1,1,'\\ ','getnjiggywitit'),(3188,578671897013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','196128, Russia, St.-Petersburg, ulitsa Varshavskaya dom 19 korpus 1 kvartira 113','St.-Petersburg','','RUSSIAN FEDERATION','196128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 05:11:54',0,NULL,3,1,2,1,'、 ','levbarkan'),(3189,704974700011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','model466','model46@mac.com','Hoon Song','2316 S. Harbor Blvd. Anaheim, CA 92802','Anaheim','CA','UNITED STATES','92802','(951) 236-4410','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 05:59:21',0,NULL,3,1,1,1,'\\ ','model466'),(3190,783036428012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',6,'OTCR001',155.1,'eastar4','blueiphot','aliet_182@yahoo.co.id','Aliet Sutrisna','Jl Pedongkelan baru gg Timbul 1<br>RT 018/016 no.3 Kapuk Jak-Bar','default','JK','INDONESIA','11720','668174969729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 06:41:55',0,NULL,3,1,3,1,'RA117732722CN ','blueiphot\rOTCR001'),(3191,783042228012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',2,'MOMI001',119.98,'eastar4','datatony','rw@iqcircle.eu','Udo Wöckner','Häringen 26','Weilheim-Häringen','CO','GERMANY','73235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 07:08:29',0,NULL,3,1,3,1,'RA117715485CN ','datatony\rMOMI001\r'),(3192,705002534011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.9,'eastar4','activevorx','vorx@mail.ru','Sergey Pochatkov','Shipilovskiy pr-d, 59-2, 65','Moscow','','RUSSIAN FEDERATION','115582','+79260295046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 08:29:02',0,NULL,3,1,3,1,'RA117730307CN\r ','activevorx\rWWSI005+ANCN001'),(3193,579269878013,230412690573,'2.0 New ASUS Bluetooth Module +cable F5/Z53/F3/M51',1,'BTHU2003',12.5,'eastar4','mmikelsama','mmikelsama@hotmail.com','Mariano Miguel','c Santiago 1 4º','Sama de Langreo','Asturias','SPAIN','33900','985676734','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 08:30:08',0,NULL,3,1,2,1,NULL,'mmikelsama\r华硕 10pin 1.0 15cm \\'),(3194,705011320011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','lvn888','bargainedge@gmail.com','Tony Lu','927 s. 10th ave','arcadia','CA','UNITED STATES','91006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 09:01:00',0,NULL,3,1,1,1,'\\ ','lvn888'),(3195,783069746012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','kev-n-tru','ksdobbie@aol.com','Kevin Dobbie','8 Mablethorpe Close','Redcar','Cleveland','UNITED KINGDOM','TS10 4GW','01642490404','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 09:05:28',0,NULL,3,1,3,1,'RA117730545CN\r ','kev-n-tru\rOTCN003\r'),(3196,783065905012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','laster35soner','sonersaplak@hotmail.com','Serafettin YASA','Erler Mah. Dumlupinar Serpmeleri<br>Kume Evleri Hava Lojmanlari A2/1 Etimesgut','ANKARA','','TURKEY','06790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:07:41',0,NULL,3,1,3,1,'RA117730063CN ','laster35soner\r欧标\rHSMO008'),(3197,705013699011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','6516530','thstahlschmidt@alice-dsl.net','Thomas Stahlschmidt','Struenseestrasse 69','Hamburg','','GERMANY','22767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:11:49',0,NULL,3,1,2,1,NULL,'6516530\\'),(3198,705016395011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:23:20',0,NULL,3,1,3,1,'RA117715962CN ','tudijaidem\rANYA001'),(3199,783077555012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','kenny1003','kenny@killegray.fsnet.co.uk','Kenneth Campbell','17 Lomond Road<br>Bearsden','GLASGOW','East Dunbartonshire','UNITED KINGDOM','G61 1BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 09:38:44',0,NULL,3,1,3,1,'RA117730219CN\r ','kenny1003\rOTGR001'),(3200,705021262011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.98,'eastar4','1961budgie4','budgie4@bigpond.com.au','Tony Buhagiar','1529 York-Williams Road','Beverley','Western Australia','AUSTRALIA','6304','0417098809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 09:45:42',0,NULL,3,1,2,1,'、 ','1961budgie4'),(3201,532861944004,140520948944,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',13.99,'cnfaner','pasi5044','pasi.kauppinen@iki.fi','Pasi Kauppinen','Mattilanmäki 4as1','Tampere','','FINLAND','33610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 11:03:31',0,NULL,3,1,3,1,'RA117730077CN\r ','pasi5044\rOMHJ001'),(3202,577345084013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','spykon','psylom31@hotmail.com','TRISTAN LOMMEZ','1 RUE PIERRE DE RONSARD','BLAGNAC','Midi-Pyrénées','FRANCE','31700','0631822869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 11:31:51',0,NULL,3,1,2,1,NULL,'spykon\rHP 8pin 1.0 23cm '),(3203,579308972013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',48.95,'eastar4','batman3334','alainb33@gmail.com','BENOIT Alain','2811,route de Sommieres.D22<br>la bergerie du petit pont.','MONTPEZAT','Languedoc-Roussillon','FRANCE','30730','0673518755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 12:17:15',0,NULL,3,1,3,1,'RA117730085CN\r ','batman3334\rOTRA002'),(3204,579312470013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',8,'HSNO019',319.92,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 12:31:44',0,NULL,3,1,4,1,'YW865907513CN ','jape324\r欧标\r'),(3205,783142766012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',3,'BALO005',21.3,'eastar4','xatalan','oliver@lemling.de','Oliver Lemling','Else-Lasker-Schüler-Eck 15','Göttingen','','GERMANY','37085','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 13:25:19',0,NULL,3,1,2,1,NULL,'xatalan\\'),(3206,579332253013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','davedaloia','whynotme_17@hotmail.com','Dave D\'Aloia','560 Fullarton Road','Keilor Park','Victoria','AUSTRALIA','3042','0393367735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:04:13',0,NULL,3,1,2,1,'\\ ','davedaloia'),(3207,705104610011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','lg_medellin','luis@alphicgroup.com','Luis Medellin','Hacienda de torrecillas 5, Col. bosque de echegaray','Naucalpan de Juarez','Estado de Mexico','MEXICO','53310','5555082593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:44:01',0,NULL,3,1,3,1,'RA117730094CN\r ','lg_medellin\rRCLO006'),(3208,783170600012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',43.8,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:46:42',0,NULL,3,1,3,1,'RA117730253CN\r ','speedsterporsche\rOTGR002'),(3209,579348227013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','woodysca','motowoodys@gmail.com','Woody Sutherland','3526 Voyager Cir','San Diego','CA','UNITED STATES','92130','(858) 603-1860','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 15:14:20',0,NULL,3,1,1,1,'\\ ','woodysca'),(3210,705121581011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',33.98,'eastar4','murciamen','murciamen@hotmail.com','Pedro Parra Ibañez','Calle: Luisa Aledo, num 16. bajo C','Murcia','Murcia','SPAIN','30003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:39:44',0,NULL,3,1,3,1,'RA117730236CN\r ','murciamen\rWLAT001+ANTY002\r一共买了两个'),(3211,705128911011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','viclil96','victorsheinfeld@gmail.com','Victor Sheinfeld','Tishrei 2/1','Netanya','ID','ISRAEL','42524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 16:01:47',0,NULL,3,1,2,1,NULL,'viclil96\\'),(3212,705133734011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','ecuadorhomesonline','banking@ecuadorhomesonline.com','David Workman','3607 Lew Wallace St','Frederick','MD','UNITED STATES','21704-7872','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 16:11:07',0,NULL,3,1,1,1,'\\ ','ecuadorhomesonline'),(3213,532932901004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',24.99,'cnfaner','sisbeav','sisbeav@aol.com','Amanda Beaver','78903 38th Ave','Covert','MI','UNITED STATES','49043-9728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 16:42:48',0,NULL,3,1,1,1,'\\ ','sisbeav'),(3214,783242500012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','rfbatch','randfb@yahoo.com','Rand F Batchelder','238 Sienna Trl','Venetia','PA','UNITED STATES','15367-1316','(724) 260-0707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 17:50:04',0,NULL,3,1,1,1,'\\ ','rfbatch'),(3215,705171378011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','fredhound333','shapiro333@gmail.com','Jonathan M. Shapiro','205 W Plaza Dr','Mooresville','NC','UNITED STATES','28117-8063','(704) 663-4994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 17:51:32',0,NULL,3,1,1,1,'\\ ','fredhound333'),(3216,705177693011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','peter.milnrow','peterandi@gmail.com','Peter Walsh','4 Croft Head Drive<br>Milnrow','Rochdale','Greater Manchester','UNITED KINGDOM','OL16 3UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 18:03:32',0,NULL,3,1,2,1,NULL,'peter.milnrow\\'),(3217,783271515012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jamesl9369','jcleitzel@verizon.net','James Leitzel','104 N Broad St','Selinsgrove','PA','UNITED STATES','17870','(570) 374-0304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 18:48:31',0,NULL,3,1,1,1,'\\ ','jamesl9369'),(3218,783275598012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',86.25,'eastar4','kposkpos','kposyniak@gmail.com','Krzysztof Posyniak','Piotrkowska 15/16','Gdansk','pomorskie','POLAND','80180','600 948393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 18:55:47',0,NULL,3,1,3,1,'RA117730372CN\r ','kposkpos\r一共买了5个CAB-6060\r5个MX20T'),(3219,783278831012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','yo2435','yo2435us@yahoo.com','larry cruz','po box 6697','central falls','RI','UNITED STATES','02863-0661','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:10:00',0,NULL,3,1,1,1,'\\ ','yo2435'),(3220,705210102011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','alonradzi','alon@radzis.com','Alon Radzi','149 Emek Ayalon Ave.','Shoham','','ISRAEL','60850','(052) 552-2965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:18:46',0,NULL,3,1,2,1,'\\ ','alonradzi'),(3221,532981091004,140516157546,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'TOIN002+BAIN002+BAIN001',49.9,'cnfaner','fernandojaburu','jaburu69@hotmail.com','Fernando A M Morais','Rua 10, n.887 Apt.1103 Setor Oeste<br>Ed. Itanhagá Palace','Goiania','GO','BRAZIL','74120-020','(623) 215-9695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:29:34',0,NULL,3,0,3,1,'RA117715914CN\r ','fernandojaburu\rTOIN002+BAIN002+BAIN001'),(3222,705220195011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','khalidkhan3432','mr.__khan@hotmail.com','Khalid Khan','15-384 Driftwood Avenue','North York','ON','CANADA','M3N 2P5','(416) 886-6589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:39:08',0,NULL,3,1,2,1,'\\ ','khalidkhan3432'),(3223,783302966012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','guizhang','guizhang@hotmail.com','Gui Zhang (Tim)','6351 Loudon Ave<br>Unit A','Elkridge','MD','UNITED STATES','21075-5636','(410) 330-0796','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:52:24',0,NULL,3,1,1,1,'\\ ','guizhang\r红边优联'),(3224,705226373011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','c_hertling','chris@hertling.net','Chris Hertling','810 E 24th Ave','North Kansas City','MO','UNITED STATES','64116-3361','(816) 221-9269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 19:54:42',0,NULL,3,1,1,1,'\\ ','c_hertling'),(3225,705232717011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','jbabyadkins2009','jbabyadkins@yahoo.com','Jonathan Adkins','107 Santa Ana Pl','West Columbia','SC','UNITED STATES','29170-3050','(803) 261-2192','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:11:40',0,NULL,3,1,1,1,'\\ ','jbabyadkins2009'),(3226,783323523012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','n10aguy','n10aguy@cfl.rr.com','Brian Anderson','720 Armitage Ave','Apopka','FL','UNITED STATES','32703-5434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:43:44',0,NULL,3,1,1,1,'\\ ','n10aguy'),(3227,705250373011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',4,'GLSG001',271.96,'eastar4','mwetty1234','mattwetty@yahoo.com','Matthew Wetty','7 South Rd','Bronxville','NY','UNITED STATES','10708-1920','(914) 337-1790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 20:49:19',0,NULL,3,1,6,1,'EE442466457CN ','mwetty1234'),(3228,705250907011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','jlmar0123','marche.jeanlouis@orange.fr','Jean-Louis Marche','2 rue Rochet','Breurey Les Faverney','Franche-Comté','FRANCE','70160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:50:13',0,NULL,3,1,2,1,'\\ ','jlmar0123\racer 5pin1.25 4cm '),(3229,579461639013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','twistedmind1974','mr.twist@gmx.de','Klaus Stürzenbecher','Nappenhorn 19','Barmstedt','','GERMANY','25355','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:38:14',0,NULL,3,1,2,1,NULL,'twistedmind1974\\'),(3230,779316296012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','tournataka0646','vriens.jurre@gmail.com','Jurre Vriens','Gerard Walschaplaan 48','Roosendaal','','NETHERLANDS','4707CS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 22:16:36',0,NULL,3,1,2,1,NULL,'tournataka0646\\'),(3231,783367736012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','homehealthx3','julieharper@centurytel.net','Julie B Harper','161 Gober Rd','Hackleburg','AL','UNITED STATES','35564-4403','(205) 935-8526','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 22:34:03',0,NULL,3,1,1,1,'\\ ','homehealthx3'),(3232,533034719004,140516092374,'Logitech harmony Li-ion Rechargeable Battery 950mAh',1,'BALO008',6.6,'cnfaner','tomspeed62david','tomspeed62@yahoo.com','David Jobes','8023 E Evergreen St','Mesa','AZ','UNITED STATES','85207-4938','(480) 357-6732','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 23:15:43',0,NULL,3,1,1,1,'\\ ','tomspeed62david'),(3233,705298893011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',3,'HSNO017',56.7,'eastar4','darrylwash','dwash@ascendventures.com','Darryl E. Wash','3127 Corinth Avenue','Los Angeles','CA','UNITED STATES','90066','(212) 324-2225','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 23:29:21',0,NULL,3,1,1,1,'\\ ','darrylwash'),(3234,533042525004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','07oscar07','jpoppy@tpg.com.au','Joseph Poppelock','30 BISDEE STREET','CORAL COVE','Queensland','AUSTRALIA','4670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:09:56',0,NULL,3,1,3,1,'RA117730046CN ','07oscar07\rOTGR001+OTGR002'),(3235,783392552012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','kiranbiz','kiran.malineni@gmail.com','Kiran Malineni','261 Poplar Ave<br>Apt# R647','Devon','PA','UNITED STATES','19333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 00:13:03',0,NULL,3,1,1,1,'\\ ','kiranbiz\r红边优联'),(3236,705315631011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','jonaslieser','jonas.lieser@gmail.com','Jonas Lieser','Jernbanegade 6','Kopenhagen','V','DENMARK','1608','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:49:34',0,NULL,3,1,2,1,NULL,'jonaslieser\\'),(3237,705320868011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','steven5223063','steven52230@hotmail.com','steven bedard','694 rue hoggar<br>quebec','quebec','QC','CANADA','g1b3e4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:14:16',0,NULL,3,1,2,1,NULL,'steven5223063\\'),(3238,525297928003,130489932231,'New in box Jeep Multi-function Handy Saw Openner Pliers',2,'OTJE001',31.8,'cnfaner','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-07 01:34:25',0,NULL,3,1,3,1,'RA117730029CN ','anyquilmes10\rOTJE001'),(3239,783415967012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dariukel','robinetstella@hotmail.com','jimmy doucet','956 # 4 Rue Alexandre','Drummondville','QC','CANADA','j2c6c3','(819) 850-3301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:51:00',0,NULL,3,1,2,1,NULL,'dariukel\r红边优联\\'),(3240,783430395012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','greenbeans14','kevie_smithy@yahoo.com','Kevin Smith','815 Smith Hudson Rd','Siler City','NC','UNITED STATES','27344-6988','(919) 663-2271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 02:53:53',0,NULL,3,1,1,1,'\\ ','greenbeans14'),(3241,705349148011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','sydney88808','sydney880@gmail.com','Leo (SO23293)','Techoni.Mobile.Phones<br>Suite 214, 160 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 03:36:50',0,NULL,3,1,3,1,'RA117730222CN\r ','sydney88808\rHSNO019\r澳标'),(3242,783465687012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','wen-jiezheng','wenjie_zheng@yahoo.com','Wen-Jie Zheng','5123 72nd St','Woodside','NY','UNITED STATES','11377-7619','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 06:06:23',0,NULL,3,1,1,1,'\\ ','wen-jiezheng\r红边优联'),(3243,705391228011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',21.9,'eastar4','golfmester','hartyanyitibor@t-email.hu','Hartyányi Tibor','Dobó utca 12','Cegléd','','HUNGARY','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 07:39:07',0,NULL,3,1,2,1,NULL,'golfmester\r欧标\\'),(3244,705394386011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','jcstodd','jcstodd@yahoo.com','Jeffrey C. Stoddard','3 Tiara Ct','Burlingame','CA','UNITED STATES','94010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 07:52:51',0,NULL,3,1,1,1,'\\ ','jcstodd\r无线蓝牙二合一'),(3245,579560706013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','loupenz','petersquires@squiresmarine.com','Peter Squires','1259 Kaipara Coast Highway<br>RD4 Warkworth','Auckland','Auckland','NEW ZEALAND','0984','021 2518707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 08:19:47',0,NULL,3,1,3,1,'RA117730050CN\r ','loupenz\rMOSA003'),(3246,783520127012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','bohaben','jbohaben@gmail.com','Juan Carlos Vazquez','c/ Cueva de Santa Ana 14','Cáceres','Extremadura','SPAIN','10005','655450547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:52:01',0,NULL,3,1,2,1,NULL,'bohaben\\'),(3247,579577348013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','paul606455','paul.westpennine1@virginmedia.com','Paul Davison','41 Longworth Road, Egerton','Bolton','Lancashire','UNITED KINGDOM','BL79TS','01204594998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:53:10',0,NULL,3,1,2,1,' ','paul606455\\'),(3248,579578147013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','klyecptguy','klye.hay@gmail.com','Kyle Hay','5 Muratie Close<br>Richwood','Cape Town','Western Province','SOUTH AFRICA','7441','0845366797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:58:21',0,NULL,3,1,2,1,'\\ ','klyecptguy'),(3249,705438638011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','carpe.diem)','jfritsch1@gmx.net','Jens Fritsch','Voigtstr 18','Berlin','','GERMANY','10247','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 10:47:43',0,NULL,3,1,2,1,NULL,'carpe.diem)\\'),(3250,783565131012,220704730634,'New Plantronics Explorer220 BLUETOOTH HEADSET+carcharge',1,'HSPL001+CCPL001',11.2,'eastar4uk','sabynandha123','amit_sharma4350@yahoo.com','Saby Nandha','88-A<br>Roman road','luton','Bedfordshire','UNITED KINGDOM','Lu4 9se','07969128855','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 12:24:24',0,NULL,3,1,3,1,'RA117730267CN\r ','sabynandha123\rHSPL001+CCPL001'),(3251,579608862013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','kockjo','kockjo@gmx.de','Jörg Kock','Op de Wisch 30','Appen','','GERMANY','25482','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 12:26:53',0,NULL,3,1,2,1,'\\ ','kockjo'),(3252,533164712004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','brandonpheng','harddrive80gb@hotmail.com','Brandon Phengsavath','2 Tali Karng Close','Rowville','Victoria','AUSTRALIA','3178','0397634109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:20:08',0,NULL,3,1,3,1,'RA117730355CN\r ','brandonpheng\rWWOT001'),(3253,705485975011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','sercank06','sercan06@gmail.com','Sercan KILIÇKAYA','Tuzlucayir Mahallesi 592. Sokak Deniz Apt<br>1/5 Mamak','Ankara','TR','TURKEY','06590','+905552349058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:23:02',0,NULL,3,1,2,1,'\\ ','sercank06'),(3254,579621397013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','holaju6','juke_holappa_69@hotmail.com','Jukka-Pekka Holappa','Vartiokatu 14-16 B9<br>96100','Rovaniemi','Rovaniemi','FINLAND','96100','+358405160239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:37:47',0,NULL,3,1,3,1,'RA117730275CN\r ','holaju6\rHSNO019'),(3255,577059790013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','lourdeskert','manik247@maltanet.net','Lourdes Kert','46 fidele street','Hamrun','','MALTA','HMR06','+35699251930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:39:47',0,NULL,3,1,2,1,NULL,'lourdeskert\r\r欧标\\'),(3256,783592900012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','vlad_sh1971','v_shuvaev@mail.ru','Vladislav Shuvaev','11-ya Parkovaya street 9/35<br>Appartment 184','Moscow','RU','RUSSIAN FEDERATION','105554','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 13:41:26',0,NULL,3,1,2,1,'\\ ','vlad_sh1971\r红边优联'),(3257,705495622011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','burningchromezero','magatsu_08@yahoo.com','Michael Dan','1516 Snyder Ave. Apt. 2F','Philadelphia','PA','UNITED STATES','19145','(215) 559-1122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 13:51:49',0,NULL,3,1,1,1,'\\ ','burningchromezero'),(3258,783124734012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','3399771','sandrayan@yandex.ru','VORONIN BORIS','UNUSABAD STREET<br>19-4-9','TASHKENT','UZBEKISTAN','UZBEKISTAN','700114','+998712225805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:05:58',0,NULL,3,1,3,1,'RA117715976CN ','3399771\rGLSG002'),(3259,783609596012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','mbracciodieta1213','mbracciodieta@yahoo.com','matt bracciodieta','15 Samantha Dr','coram','NY','UNITED STATES','11727-3068','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 14:20:49',0,NULL,3,1,1,1,'\\ ','mbracciodieta1213'),(3260,783618180012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','the_lord_of_the_laptops','selcukatak@hotmail.com','Selcuk Atak','Yozgat Polis Meslek Yuksek Okulu','Yozgat','','TURKEY','66100','905068937090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:42:41',0,NULL,3,1,2,1,NULL,'the_lord_of_the_laptops\\'),(3261,705523390011,320679575498,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','applecatz09','applecatz@hotmail.co.uk','Tristan Figueroa','bs8,  34, Park St<br>Clifton','Bristol','Bristol','UNITED KINGDOM','BS1 5JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 15:11:21',0,NULL,3,1,3,1,'RA117730015CN\r ','applecatz09\rMOAP001'),(3262,705526708011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','laurenzos44','petiteau.laurent@wanadoo.fr','LAURENT PETITEAU','35 RUE PASTEUR','LA MONTAGNE','Pays de la Loire','FRANCE','44620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:22:15',0,NULL,3,1,2,1,NULL,'laurenzos44\r 无线蓝牙二合一\\'),(3263,783637144012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','caboqueen7','caboqueen7@hotmail.com','Carolyn D Taylor','15910 Palo Seco Dr','Corpus Christi','TX','UNITED STATES','78418-6617','(361) 949-8447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 15:30:39',0,NULL,3,1,1,1,'\\ ','caboqueen7'),(3264,579661330013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.9,'eastar4','fibrastick','c_guerra@telefonica.net','JOSE LUIS CARBALLO GUERRA','CL COMARCA RIBERA DEL TAJO 95','MERIDA','BADAJOZ','SPAIN','06800','924371677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:55:21',0,NULL,3,1,2,1,NULL,'fibrastick\\'),(3265,579662247013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','axquest','axquest@mac.com','Chanon Sarasuk','454/233, Wat Pai Ngoen Road, Soi Udee<br>Bangkhlo,  Bangkholame','Bangkok','Bangkok','THAILAND','10120','(+66)892118050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:58:19',0,NULL,3,1,2,1,NULL,'axquest\\'),(3266,705562077011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','514-july','july--@hotmail.com','julie lehoux','5000 des frenes','ste-catherine','QC','CANADA','j5C 1L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 16:56:10',0,NULL,3,1,3,1,'RA117715874CN ','514-july\rGLSG001*2'),(3267,579683692013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','dracoqc','dracoqc@hotmail.com','Jocelyne  Mongeau','2775 ave. Lebrun','Montréal','QC','CANADA','H1L 5E7','(514) 351-8932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:09:08',0,NULL,3,1,3,1,'RA117730032CN\r ','dracoqc\r华硕限量版\rMOLO004'),(3268,705578876011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','noblebest','johan@gedde-dahl.no','Johan Gedde-Dahl','Jongsaasveien 12a','Sandvika','Sandvika','NORWAY','1338','(047) 97138646','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 17:30:58',0,NULL,3,1,2,1,'\\ ','noblebest'),(3269,579693098013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','erigler','eduardorigler@hotmail.com','Eduardo Rigler','Rua do Semeador, 702<br>- Cidade Industrial','Curitiba','Paraná','BRAZIL','81270-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:40:00',0,NULL,3,1,2,1,NULL,'erigler\\'),(3270,783704608012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','canan1st','kanan1st@gmail.com','Kanan Bayramov','Y.Yasamal-1, ev 4, menzil 189','Baku','Yasamal','AZERBAIJAN','AZ1012','4341084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 18:01:55',0,NULL,3,1,2,1,NULL,'canan1st\\'),(3271,579700341013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',6,'HSMO010',89.94,'eastar4','paul90266','skolnick@newstrench.com','Paul Skolnick','10573 W Pico Blvd<br># 167','Los Angeles','CA','UNITED STATES','90064-2333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 18:04:02',0,NULL,3,1,1,1,'\\ ','paul90266'),(3272,783707280012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',28.9,'eastar4uk','niomimonty','mghduk@hotmail.com','MUNIR DHALECH','9 FRANCIS ROAD','LEYTON','London','UNITED KINGDOM','E10 6PN','02085589516','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 18:05:26',0,NULL,3,1,3,1,'RA117715888CN ','niomimonty\rOTGR001+OTGR002'),(3273,533246414004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',49.9,'cnfaner','s_bpridgeon','itismehereandnow@hotmail.com','Beronica Pridgeon','1219 Park Hill Drive','Conway','SC','UNITED STATES','29526','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 18:29:31',0,NULL,3,1,1,1,'\\ ','s_bpridgeon'),(3274,783740635012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','rjporter','rporter@thinkerworks.com','Ralph Porter','PO Box 616<br>191 East Center Street','Spring City','UT','UNITED STATES','84662-0616','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 19:11:49',0,NULL,3,1,1,1,'\\ ','rjporter'),(3275,783746736012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','doddybonnie','doddymanu@sky.com','robert white','2 sytch house green','wolverhampton','Shropshire','UNITED KINGDOM','wv5 7aj','01746710987','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 19:21:53',0,NULL,3,1,3,1,'RA117715786CN ','doddybonnie\rOTGR001'),(3276,705631813011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','pzipf','peter.zipfelmayer@gmx.com','Peter Zipfelmayer','Mozartgasse 7','Leobersdorf','','AUSTRIA','2544','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:26:36',0,NULL,3,1,2,1,'\\ ','pzipf'),(3277,579730393013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','shaggyrogers2','sfrancis31@yahoo.com','scott francis','26 Chillington Ln','mendon','NY','UNITED STATES','14506-9720','(585) 697-4958','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 19:31:32',0,NULL,3,1,1,1,'\\ ','shaggyrogers2'),(3278,705644818011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','danny13xrimer','danny.rimer@gmail.com','Danny Rimer','Olei Hagardom 63/9','Rishon Lezion','','ISRAEL','75235','(009) 725-0672 ext.: 2072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:55:37',0,NULL,3,1,2,1,NULL,'danny13xrimer\\'),(3279,783757651012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','psy_soul','azarovua@gmail.com','Anton Azarov','Lesya Kurbasa st. 4. App. 67.','Kiev','UA','UKRAINE','03148','380936844412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:02:28',0,NULL,3,1,2,1,NULL,'psy_soul\\'),(3280,783779052012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',21.9,'eastar4','elj77777','murermester.jensen@tdcadsl.dk','Erling Jensen','Johannesdalsvej 13','Lundforlund, Slagelse','','DENMARK','DK4200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:28:31',0,NULL,3,1,2,1,NULL,'elj77777\r欧标\\'),(3281,783780944012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','nancybraun28277','nancy@showcaserealty.net','nancy braun','10418 counts pl','charlotte','NC','UNITED STATES','28277-1743','(704) 488-3109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 20:45:09',0,NULL,3,1,1,1,'\\ ','nancybraun28277\r红边优联'),(3282,783792991012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','rikki4910','erika.rikki@gmail.com','Rikki Mosley','742 Cobble Hill Drive','ottawa','ON','CANADA','K2J 0C7','(613) 823-1123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 20:59:16',0,NULL,3,1,2,1,NULL,'rikki4910\\'),(3283,783799681012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',2.99,'eastar4uk','wonko_999','r_lowthian@yahoo.co.uk','Robert Lowthian','64 cleeve court<br>glebe','Washington','Tyne and Wear','UNITED KINGDOM','ne38 7qf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 21:14:28',0,NULL,3,1,3,1,'RA117715980CN\r ','wonko_999\rOTCN003'),(3284,579762878013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',3,'HSJA002',64.5,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 21:18:09',0,NULL,3,0,3,1,'RA117715945CN\r ','vjendrisvelimir\rHSJA002\r欧标'),(3285,783807578012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','aznervedoc','wlwdc@azchiro.net','William L. Wesselink, DC','4558 N 1st Ave<br>Ste 110','Tucson','AZ','UNITED STATES','85718-5687','(520) 888-2600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 21:34:45',0,NULL,3,1,1,1,'\\ ','aznervedoc'),(3286,533306951004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',2,'MOLO001',130,'cnfaner','freewaymotorcars','brian@freewaymotorcars.com','brian poirrier','2433 Cleveland Ave SW','canton','OH','UNITED STATES','44707-3642','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 21:57:47',0,NULL,3,1,4,1,'YW865907443CN ','freewaymotorcars'),(3287,705695194011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 22:05:58',0,NULL,3,1,3,1,'RA117715959CN\r ','update_marcelo\rWWSI006'),(3288,705704731011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','lcthunderbird','lcthunderbirds@yahoo.com','Constantine Gulgas','29694 Westminster Dr','North Olmsted','OH','UNITED STATES','44070-5074','(440) 242-7743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 22:43:01',0,NULL,3,1,1,1,'\\ ','lcthunderbird'),(3289,579790401013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','littlemcc','nancymccurry@cox.net','Nancy E. McCurry','19047 N 29th Pl','Phoenix','AZ','UNITED STATES','85050-2550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 23:18:18',0,NULL,3,1,1,1,'\\ ','littlemcc'),(3290,705729928011,320441946828,'2.1 HP TX1000 TX1000z TX1200 Bluetooth Module EDR+cable',2,'BTHP2112',25.6,'eastar4','bikeman30sh','babuji@msn.com','ABRAHAM ABRAHAM','714 Manor CT 1st Floor','Brooklyn','NY','UNITED STATES','11235','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 00:23:45',0,NULL,3,1,1,1,NULL,'bikeman30sh\rHP 8pin 0.8 3cm \\'),(3291,533347314004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','dscoop9977','dscoop9977@aol.com','Dawn C Hertzel','17D Lakeview Ave','Leonia','NJ','UNITED STATES','07605-3119','(201) 944-2361','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 01:54:53',0,NULL,3,1,1,1,'\\ ','dscoop9977'),(3292,705753484011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','curtisicampbell','curtisicampbellthe1st@gmail.com','Curtis Campbell','6085 Hazeldean Rd.<br>RBC Bank','Stittsville','ON','CANADA','K2S1B9','(613) 447-6078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:13:00',0,NULL,3,1,3,1,'RA117715928CN\r ','curtisicampbell\rHSPL009'),(3293,705754032011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','dreamchaser225','dreamchaser225@yahoo.com','Raymond Lee','23717 Southpoint Dr','Denham Springs','LA','UNITED STATES','70726','(225) 271-8261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 02:14:46',0,NULL,3,1,1,1,'\\ ','dreamchaser225'),(3294,533349675004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','sigor220972','sigor72@mail.ru','Igor Selyutin','Kutuzova 6/1 kv 49','Pavlodar','','KAZAKHSTAN','140000','87182550675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:14:52',0,NULL,3,1,3,1,'RA117715772CN\r ','sigor220972\rHSJA002\r欧标\r'),(3295,783889478012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','spectralcluster','zac.harland@googlemail.com','Zac Harland','12 / 79-81 Balgowlah Road<br>Fairlight','Sydney','New South Wales','AUSTRALIA','2094','61299491906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 02:28:25',0,NULL,3,1,2,1,' ','spectralcluster\r红边优联\\'),(3296,579823705013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','n2vjb','n2vjb@frontiernet.net','Kevin Popplewell','53 Squirrels Heath Rd','Fairport','NY','UNITED STATES','14450-9605','(585) 223-7478','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 02:30:31',0,NULL,3,1,1,1,'\\ ','n2vjb'),(3297,783937716012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',39.99,'eastar4','vachfolle','vachfolle@yahoo.com','gauchotte benoit','Résidence les Cyclamens<br>1 rue Voltaire','Champagnole','Franche-Comté','FRANCE','39300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:34:25',0,NULL,3,1,3,1,'RA117716000CN\r ','vachfolle\rOTHP001'),(3298,705818222011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','peebee56','pen3333@gmail.com','Penelope Feeney','PO Box 1129','Gibraltar','Gibraltar','GIBRALTAR','no code','+35056001222','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 07:44:36',0,NULL,3,1,2,1,NULL,'peebee56\\'),(3299,705822723011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',67.9,'eastar4','ivonini','igor.ivonin@gmail.com','Igor Ivonin','Parkovaya, 3-65','Yubileyny','Moscow region','RUSSIAN FEDERATION','141092','+79152023669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 08:07:11',0,NULL,3,1,3,1,'RA117715790CN ','ivonini\rHSSE006\r'),(3300,783140489012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','rau020202','wsrau02@mail.ru','Sandra Rau','Am Dorfplatz 43','Halen','','GERMANY','49685','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 08:20:42',0,NULL,3,1,2,1,NULL,'rau020202\r欧标\\'),(3301,579880249013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','rfernan4','ranga_fernando@hotmail.com','Ranga Fernando','1551 N Tustin Ave<br>Suite 200','Santa Ana','CA','UNITED STATES','92705-8693','(714) 598-7125','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 08:38:38',0,NULL,3,1,1,1,'\\ ','rfernan4\rCAB-6060'),(3302,783978888012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',59.9,'eastar4','yaanasip','ferhatildes@hotmail.com','ferhat ildes','uluanak mah. ulucami park sok. ekeler apt. 13/3','default','sivas','TURKEY','58070','05054822739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 09:45:46',0,NULL,3,1,3,1,'RA117715809CN\r ','yaanasip\r欧标\rHSNO025'),(3303,705864459011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.99,'eastar4','checkman81','checkman@list.ru','Nesterov Alexander','Batyuninskaya street, 8-21','Moscow','','RUSSIAN FEDERATION','109235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:06:34',0,NULL,3,1,2,1,'\\ ','checkman81'),(3304,705864039011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','the-ment','the_ment@mail.ru','Oleg Mishin','Krasnoarmeyskaya st,dom 22,kv.68','Vladimir','ru','RUSSIAN FEDERATION','600021','(910)775-3059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:20:25',0,NULL,3,1,2,1,NULL,'the-ment\r欧标\\'),(3305,705877456011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','zerostyle_2010','gatol@yahoo.co.jp','Junji Miyazaki','1-15-11<br>Deiki, Kanazawa-ku','Yokohama-shi','Kanagawa','JAPAN','236-0021','045-783-5505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 10:34:03',0,NULL,3,1,3,1,'RA117715931CN\r ','zerostyle_2010\rHSPL009'),(3306,705879463011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',6.55,'eastar4uk','stevev1187','svince146@hotmail.com','steve vince','gower waltham road<br>borehan','chelmsford','Essex','UNITED KINGDOM','cm3 3ax','01245469681','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 10:37:49',0,NULL,3,1,3,1,'RA117730284CN\r ','stevev1187\rBAIN001'),(3307,533457978004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',23.99,'cnfaner','slavicripper','xslavic@gmail.com','Veaceslav Condur','via della fornace 15','Zola Predosa','BO','ITALY','40069','3404820676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:05:58',0,NULL,3,0,3,1,'RA117730369CN\r ','slavicripper\r换成半高卡New Intel 5300 HALF Wireless Mini PCI-E Card+3 antenna\r\r'),(3308,705614281011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',21.9,'eastar4','kifferm2','kifferc2@yahoo.com','CHRIS BLANKENSHIP','3118 CREEK BANK LN','PEARLAND','TX','UNITED STATES','77581-4675','(713) 291-3106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:08:38',0,NULL,3,1,1,1,'\\ ','kifferm2'),(3309,705926201011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','etamme','etamme@optonline.net','Eric Tamme','255 Huguenot St<br>APT 1016','New Rochelle','NY','UNITED STATES','10801-6396','(203) 479-2949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:36:57',0,NULL,3,1,1,1,'\\ ','etamme'),(3310,705933093011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','rduke72','jjacksonpearce@gmail.com','Jordan Pearce','918 Algregg St','Houston','TX','UNITED STATES','77009-4401','(713) 417-2376','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 12:52:49',0,NULL,3,1,1,1,'\\ ','rduke72'),(3311,784084324012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','manic_and_depressive','bgawert@gmail.com','Benjamin Gawert','Warton Aerodrome<br>QinetiQ/Bldg W271','Warton, Preston','Lancashire','UNITED KINGDOM','PR4 1AX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 13:05:24',0,NULL,3,1,3,1,'RA117730298CN\r ','manic_and_depressive\rOTCN002'),(3312,784112486012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',51.98,'eastar4','denisemvargo','denisevargo@yahoo.com','Denise Vargo','2503 Northfork Ct','Pearland','TX','UNITED STATES','77584-5969','(713) 851-7696','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:07:41',0,NULL,3,1,1,1,'\\ ','denisemvargo'),(3313,784113767012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.8,'eastar4','jdelrie','jacobdelrie@aol.com','jacob h delrie','765 breeze way','cordova','TN','UNITED STATES','38018-1485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:11:34',0,NULL,3,1,1,1,'\\ ','jdelrie\racer 5pin1.25 15cm\r再发一个黄膜天线*2'),(3314,784116248012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','jdelrie','jacobdelrie@aol.com','jacob h delrie','765 breeze way','cordova','TN','UNITED STATES','38018-1485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 14:14:03',0,NULL,8,1,17,0,NULL,'jdelrie'),(3315,705971722011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',3,'HSNO008',45,'eastar4','mikrosgeros','mikros_geros@hotmail.com','George Douanoglou','Elassonos 7','Voula','Athens / Attiki','GREECE','16673','2108955133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:23:36',0,NULL,3,1,3,1,'RA117730341CN\r ','mikrosgeros\r欧标\rHSNO008'),(3316,706012030011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','justin_rao','justin.rao@gmail.com','Zhaohua Rao','45 Stavely Cres.','Etobicoke','ON','CANADA','M9W 2C2','(647) 928-0008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 15:42:13',0,NULL,3,1,2,1,'\\ ','justin_rao'),(3317,580024464013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',37.98,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 16:26:08',0,NULL,3,1,3,1,'RA117730338CN\r ','small.mac\rWLAP008'),(3318,580045017013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','blau_arni','a-johnen@gmx.de','Andrej Johnen','Kaiserstr. 34','Mönchengladbach','','GERMANY','41061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 17:07:08',0,NULL,3,1,3,1,'RA117730386CN\r ','blau_arni\rMOSA002\r新地址\rAndrej Johnen\rGrefrather Str. 18\r47669 Wachtendonk\rDeutschland\r'),(3319,784265610012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',14.9,'eastar4uk','hermiefive','piggylane@aol.com','Martin Roberts','Wildwood<br>Bullsland Lane','Chorleywood','Hertfordshire','UNITED KINGDOM','WD3 5BQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 17:56:08',0,NULL,3,1,3,1,'RA117715905CN\r ','hermiefive\rOTHP003'),(3320,784304477012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','educationpays','mitchellw@kih.net','Robert Wilkinson II','312 Bogey Dr<br>Apt 202','Lowell','AR','UNITED STATES','72745-8327','(859) 749-0384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 18:32:43',0,NULL,3,1,1,1,'\\ ','educationpays\rMX20T'),(3321,706175663011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','dgaguine','dgaguine@blueyonder.co.uk','David Gaguine','4 Bantree Court','Bradford','West Yorkshire','UNITED KINGDOM','BD10 0SG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:05:28',0,NULL,3,1,2,1,NULL,'dgaguine\\'),(3322,784342647012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.99,'eastar4','daosis','taoizm@gmail.com','Michael Reznikov','Hanerd 17','Jerusalem','','ISRAEL','96626','972545998198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:11:40',0,NULL,3,1,3,1,'RA117715891CN\r ','daosis\rHSMO020'),(3323,784353095012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','mosxakis1966','moshakis_michael@yahoo.gr','MOSCHAKIS MICHAEL','MARKOU MALLIARAKI 16<br>PERIOXI KOBA','RODOS','','GREECE','TK 85 100','+306937501800','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 19:24:19',0,NULL,3,1,2,1,NULL,'mosxakis1966\\'),(3324,706202778011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','evelyn004','satterfieldd@comcast.net','Don R Satterfield','PO Box 62','Harriman','TN','UNITED STATES','37748-0062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 19:37:13',0,NULL,3,1,1,1,'\\ ','evelyn004'),(3325,784373592012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','jamiecrackberryaddict','jamiesperling@hotmail.com','Jamie Spelring','18948-78 Ave','Edmonton','AB','CANADA','T5T 5H7','(780) 870-2040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:45:08',0,NULL,3,1,3,1,'RA117730409CN\r ','jamiecrackberryaddict\rGLSG002'),(3326,784382281012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','doszpy','adoszpy@gmail.com','Adam Doszpod','Új utca<br>119','Mélykút','','HUNGARY','6449','0036703135667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:55:57',0,NULL,3,1,2,1,NULL,'doszpy\\'),(3327,706240597011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','alan11963','troy14569@yahoo.com','Troy Rowe','50 S Maple St','Warsaw','NY','UNITED STATES','14569','(585) 786-5498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 20:29:24',0,NULL,3,1,1,1,'\\ ','alan11963'),(3328,784427400012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','topekadesi','eatbombayduck-buy@yahoo.com','Vijay Mhatre','3502 SW Alameda Dr','Topeka','KS','UNITED STATES','66614-5110','(785) 272-5882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 21:00:05',0,NULL,3,1,1,1,'\\ ','topekadesi'),(3329,706263656011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','ontime01','terryjane1@googlemail.com','Terry Harrison','30 Park Hill','Harpenden','Hertfordshire','UNITED KINGDOM','AL53AT','07775704042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:13:32',0,NULL,3,1,2,1,NULL,'ontime01\\'),(3330,706270129011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','yiri_ma','dss@mail.ru','Kirill Vasilyev','Molodezhnaya<br>3/336','Moscow','','RUSSIAN FEDERATION','119226','+79653081275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:27:44',0,NULL,3,1,2,1,NULL,'yiri_ma\\'),(3331,706271785011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',49.18,'eastar4uk','mbell7149','chattyartist@yahoo.co.uk','Mary Bell','12 McKenzie Terrace<br>Troqueer','Dumfries','Dumfries and Galloway','UNITED KINGDOM','DG2 7AR','01387250161','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 21:31:18',0,NULL,3,1,3,1,'RA117715865CN\r ','mbell7149\rUDAP001'),(3332,580198225013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','anubis_sg1','pabaezm@hotmail.com','Pablo Agustín Baez Miron','Calle Cañaveral 8, 5ºB','Granada','Andalucía Ceuta y Melilla','SPAIN','18003','630361728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:47:03',0,NULL,3,1,2,1,NULL,'anubis_sg1\\'),(3333,706294821011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',269.98,'eastar4','lturner3aft','lturner@brasfieldgorrie.com','Lynette Turner','10924 Haskell Dr','Clermont','FL','UNITED STATES','34711-7804','(352) 267-1217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-08 22:35:00',0,NULL,3,1,6,1,'EE442466443CN ','lturner3aft'),(3334,580212652013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','lo3795','lorenz_kleine-kalmer@t-online.de','Lorenz Kleine-Kalmer','Im Münsterfeld 16','Warendorf','','GERMANY','48231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 22:40:33',0,NULL,3,1,2,1,NULL,'lo3795\\'),(3335,784503043012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','stylewearbrazil','stylewearbrazil@yahoo.com','Nubia Salgado','57 Lantern Rd','Revere','MA','UNITED STATES','02151-5617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 00:14:14',0,NULL,3,1,1,1,'\\ ','stylewearbrazil\r红边优联'),(3336,784526082012,220633189995,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',19.4,'eastar4','conviqt','eric.ws.anderson@gmail.com','Eric Anderson   ATTN: HAPPY BIRTHDAY!! :)','160 Argyle Ave.<br>Unit 411','Ottawa','ON','CANADA','K2P0N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 01:22:16',0,NULL,3,1,2,1,NULL,'conviqt \\'),(3337,784531394012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','azarzag','azarzag01@gmail.com','Aldo Zarza','128 Rue Louis-Colin','Gatineau','QC','CANADA','J8V2T1','(613) 286-2098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 01:32:58',0,NULL,3,1,2,1,NULL,'azarzag\\'),(3338,580263532013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',20.95,'eastar4','shutupandshave1','james@shutupandshave.com','James Lawrence','West Berkshire Mencap<br>Enborne Gate, Enborne Road','Newbury','Berkshire','UNITED KINGDOM','RG14 6AT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 02:16:02',0,NULL,3,1,2,1,'\\ ','shutupandshave1'),(3339,706382092011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.99,'eastar4','scout_it_out_2','jcmaurer2@gmail.com','John C Maurer','9113 E Rocky Lake Dr','SUN LAKES','AZ','UNITED STATES','85248-7321','(602) 614-1660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 03:30:16',0,NULL,3,1,1,1,'\\ ','scout_it_out_2'),(3340,784572206012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','heitornfp','heitornf@gmail.com','Heitor Pinto','Rua Carlito, 716<br>Vila Formosa','São Paulo','São Paulo','BRAZIL','03378000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:47:04',0,NULL,3,1,2,1,'\\ ','heitornfp'),(3341,784572188012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ppmc135','peterpetrie@gmail.com','Peter Petrie','PO Box 58','Woodford','New South Wales','AUSTRALIA','2778','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:48:04',0,NULL,3,1,2,1,NULL,'ppmc135\r红边优联\\'),(3342,784573643012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','lemelendez','lemelendez@hotmail.com','LUIS MELENDEZ','917 Hyland Springs Dr','Ocoee','FL','UNITED STATES','34761','(407) 227-4623','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 04:01:57',0,NULL,3,1,1,1,'\\ ','lemelendez'),(3343,784584933012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','cptnnpkn','douglas.lathrop@earthlink.net','Douglas Lathrop','624 Orton Hall','Pullman','WA','UNITED STATES','99163-5567','(717) 440-6777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 04:53:10',0,NULL,3,1,1,1,'\\ ','cptnnpkn\r红边优联'),(3344,784592798012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',24.5,'eastar4uk','ry11siek','rysiek@data.pl','Ryszard Szyszkowski','os. Krakowiakow 11/16','Krakow','małopolskie','POLAND','31-962','501 943444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 05:33:58',0,NULL,3,1,3,1,'RA117730324CN\r ','ry11siek\rWWSI002'),(3345,580295670013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.8,'eastar4','wjmcakair','cakair@windstream.net','William J. Manning','234 Harrison Ct','Mount Washington','KY','UNITED STATES','40047-7748','(502) 538-8680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 05:45:21',0,NULL,3,1,1,1,'\\ ','wjmcakair\rHP 8pin 1.0 23cm '),(3346,784625873012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',3,'OTGR001+OTGR002',86.7,'eastar4uk','123leonja','leonjanorris@hotmail.com','Mrs. L.J.L. NORRIS','Peter Norris (Haulage) Limited<br>Station Approach','ST. MARY CRAY','Kent','UNITED KINGDOM','BR5 2NB','01689821417','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 08:12:47',0,NULL,3,1,4,1,' YW865907454CN\r','123leonja\rOTGR001+OTGR002\r'),(3347,706438371011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','schweinelendchen_mit_pilzen','mb2303@gmx.de','Martin Blass','Zellingerstraße 8','Erlabrunn','','GERMANY','97250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 08:27:20',0,NULL,3,1,2,1,'\\ ','schweinelendchen_mit_pilzen'),(3348,706453831011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','pete_from_nz','pete_hunt_jenkins@hotmail.com','Peter Jenkins','65 Fraser Street<br>Tauranga South','Tauranga','Bay of Plenty','NEW ZEALAND','3112','+6475776664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 09:34:14',0,NULL,3,1,3,1,'RA117730749CN ','pete_from_nz\rPOLO07+POLO001+RCLO008*4\r'),(3349,706454706011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','gendutzz','gendutzz@yahoo.com','Abraham Bobby','JL. Jembatan Dua No. 82. FA / FB<br>(Komplek Ruko Robinson)','Jakarta Utara','DKI Jakarta','INDONESIA','14450','62 81310303075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 09:38:08',0,NULL,3,1,2,1,'、 ','gendutzz'),(3350,784090786012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','powerdjpowermix','shanol8@yahoo.com','jose remache','19 State St<br>Apt 2L','danbury','CT','UNITED STATES','06810-3218','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 09:40:01',0,NULL,3,1,1,1,'、 ','powerdjpowermix\r美标'),(3351,706474956011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','zw0lsman','zw0lsman@hotmail.com','Floris Zwolsman','Rooseveltlaan 21-3','Amsterdam','Noord-Holland','NETHERLANDS','1079AB','+31611538685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:56:30',0,NULL,3,1,2,1,'、 ','zw0lsman'),(3352,784671179012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',21.9,'eastar4','sokoffdmitry','sokoff@inbox.ru','Dmitry Sokovyh','DZERZHINSKOGO 3-40','Samara','','RUSSIAN FEDERATION','443093','902-292-9256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:57:04',0,NULL,3,1,2,1,'、 ','sokoffdmitry\r欧标'),(3353,784671926012,220704730389,'New GENUINE Plantronics Explorer 340 BLUETOOTH HEADSET',1,'HSPL007',14.9,'eastar4uk','foneworxfoneworx','juliefoneworx@yahoo.co.uk','FONE-WORX','59 hill street<br>newry co.down','newry','nireland','UNITED KINGDOM','bt341af','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 10:59:10',0,NULL,3,1,3,1,'RA117733881CN ','foneworxfoneworx\rHSPL007\r英标'),(3354,580345549013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','hikkles','churchill962@btinternet.com','nichola barnes chihuahua world','the manor house<br>lewes rd','east sussex TN225RE','East Sussex','UNITED KINGDOM','tn225re','01825840760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 10:59:39',0,NULL,3,1,3,1,'RA117730593CN ','hikkles\rMOSA003'),(3355,533840819004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.9,'cnfaner','pak7155','pakjpg@gmail.com','pakorn tuwajit','57/33 serithai road<br>klongkum bungkum','bangkok','bangkok','THAILAND','10240','662 377 2820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:11:30',0,NULL,3,1,3,1,'RA117730620CN ','pak7155\rOTCR001\r'),(3356,706486709011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','proximitybuyer','jaco@squaremeter.co.za','FJDV Nel','Pobox 1645<br>Rosslyn','Pretoria','Gauteng','SOUTH AFRICA','0200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:36:56',0,NULL,3,1,2,1,'、 ','proximitybuyer'),(3357,706501626011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',24.9,'eastar4','jackslanin','jacks@bk.ru','Evgeniy Lanin','Energetikov d.43 kv.16','Kurchatov','Kurskaya','RUSSIAN FEDERATION','307250','(910)2102002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 12:29:02',0,NULL,3,1,2,1,'、 ','jackslanin\r欧标'),(3358,784703171012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',10.99,'eastar4uk','les4991','lescox1@btinternet.com','LES COX','6 HILLVIEW LANE, GREAT BILLINGTON','LEIGHTON BUZZARD','Bedfordshire','UNITED KINGDOM','LU79BH','01525852229','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 12:37:14',0,NULL,3,1,3,1,'RA117730616CN ','les4991\rHSMO011+CCMO001\r'),(3359,784687111012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','terrance1307','terrancelawson@bellsouth.net','terrance lawson','2218 orleans ave.','new orleans','LA','UNITED STATES','70119','(504) 309-6236','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 12:38:00',0,NULL,3,1,1,1,'、 ','terrance1307'),(3360,784712490012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','softballmom321','lrogalsky@aol.com','Lauren Rogalsky','96 Carlton Dr','Del Rey Oaks','CA','UNITED STATES','93940-5527','(831) 394-7081','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 13:05:41',0,NULL,3,1,1,1,'、 ','softballmom321'),(3361,706515152011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',16.98,'eastar4','tiosymys2011','tiosymys@hotmail.com','JOZELIA ALBERTINA DE SOUSA NOBREGA','RUA CÔNEGO VICENTE MIGUEL MARINO, 275 APTº 101 D<br>BARRA FUNDA','SÃO PAULO','SÃO PAULO','BRAZIL','01135020','11 - 3392.1413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:12:26',0,NULL,3,1,2,1,'、 ','tiosymys2011'),(3362,784739579012,220445373662,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',2,'TRTT002*10',166,'eastar4','tnetusa','ebay@tnetus.com','T-NET TECHNOLOGY INC.','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(718) 369-3828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 14:24:53',0,NULL,3,1,4,1,'YW865907502CN ','tnetusa'),(3363,706548297011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','eric42360','eric.tissier42@orange.fr','TISSIER ERIC','42, RUE DE LA REPUBLIQUE','PANISSIERES','LOIRE','FRANCE','42360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:52:52',0,NULL,3,1,3,1,'RA117730735CN ','eric42360\r欧标\rHSPL009'),(3364,784755062012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.98,'eastar4','rfrederick71','rf33@austin.rr.com','Ronald Frederick','3604 Silver Hill Cir','Austin','TX','UNITED STATES','78746-6683','(512) 496-8153','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 15:06:46',0,NULL,3,1,1,1,'、 ','rfrederick71'),(3365,706565894011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','braatenj1','jeff.braaten@hirshindustries.com','Jeff Braaten','12308 Valdez Dr','Urbandale','IA','UNITED STATES','50323-2374','(515) 334-9388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 15:41:52',0,NULL,3,1,1,1,'、 ','braatenj1'),(3366,528173875003,130466041506,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',63,'cnfaner','lucato2010','lscrlstld@gmail.com','Luis Carlos Toledo','Rua Elvira Bertelli Polessi, 10 - Res Flamboyant','Itatiba','SP','BRAZIL','13253-671','55 11 4487-2333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:10:12',0,NULL,8,1,17,1,NULL,'lucato2010\rWWSI006+ANCN001\r与eastar4店合并了'),(3367,784782418012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',2,'GLSG002',317.98,'eastar4','alegre01','alegre01@gmail.com','Aymart Alegre','3301 SW 88th Ct','miami','FL','UNITED STATES','33165-4223','(786) 357-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 16:11:13',0,NULL,3,1,6,1,'EE520583318CN ','alegre01'),(3368,706577473011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',63,'eastar4','lucato2010','lscrlstld@gmail.com','Luis Carlos Toledo','Rua Elvira Bertelli Polessi, 10 - Res Flamboyant','Itatiba','SP','BRAZIL','13253-671','55 11 4487-2333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:11:58',0,NULL,3,1,3,1,'RA117730704CN ','lucato2010\rWWSI006+ANCN001'),(3369,784786509012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','bigdavedeals','dgm0225@yahoo.com','Dave Mpojeannis','15 Wigmore Drive, Suite B','Toronto','ON','CANADA','M4A 2E4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 16:20:25',0,NULL,3,1,3,1,'RA117730576CN\r ','bigdavedeals\rHSPL014'),(3370,784786603012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',9.2,'eastar4uk','mikelwork','info@lawsltd.co.uk','mike law','30 moorland trading estate<br>metheringham','lincoln','Lincolnshire','UNITED KINGDOM','ln43hx','01526323900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 16:20:38',0,NULL,3,1,3,1,'RA117730752CN ','mikelwork\rHSPL001'),(3371,784792064012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',27.99,'eastar4uk','58415','kolbasa76@yandex.ru','Vetchinkin Evgeniy','ul. 22 April, dom 8-v, kv.4','Omsk','','RUSSIAN FEDERATION','644088','0079131410180','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 16:34:06',0,NULL,3,1,3,1,'RA117730721CN ','58415\rCMLO001'),(3372,784809071012,220713846526,'New in box GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO024',12.9,'eastar4uk','kapa2ou3','rmarmelo@gmail.com','Rafael Marmelo','Instituto Pedro Nunes - FeedZai<br>Rua Pedro Nunes','Coimbra','Coimbra','PORTUGAL','3030-199','+351964158903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 17:09:25',0,NULL,3,1,3,1,'RA117730655CN ','kapa2ou3\rHSNO024\r欧标'),(3373,784810851012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','markf9283','mark@septemberhouse.plus.com','Mark Feeney','September House, Potters Croft, Stone Rd,<br>Tittensor','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST12 9HB','01728373666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:13:43',0,NULL,3,1,3,1,'RA117730562CN ','markf9283\rOTGR001'),(3374,784811015012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','diegopascon23','diegopascon@terra.com.br','Diego T Pascon','Rua Gastão do Rego Monterio,666<br>Ap. 51','São Paulo','SP','BRAZIL','05594030','551194703368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:15:33',0,NULL,3,1,2,1,'、 ','diegopascon23'),(3375,784815468012,220713846504,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET',1,'HSNO025',35.9,'eastar4uk','angiekoku','angelabilauri@hotmail.co.uk','Angela Bilauri','66 Yarmouth Crescent','Tottenham','London','UNITED KINGDOM','N17 9PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:21:51',0,NULL,3,1,3,1,'RA117730678CN ','angiekoku\rHSNO025\r英标'),(3376,580440648013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',5,'WLAT001',159.2,'eastar4','athenafreya','klnguyen_1998@yahoo.com','Kim Nguyen','25050 Riding Plz<br>Ste 130-250','South Riding','VA','UNITED STATES','20152-5925','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 17:29:51',0,NULL,3,1,1,1,'\\ ','athenafreya\r再发5 个NEW Atheros AR5B93 Half Height Wireless WiFi card 300M\r新地址\rKIM NGUYEN\r14280 SULLYFIELD CIR # DS04952\rCHANTILLY VA\rUNITED STATES 20151-1699'),(3377,706619360011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','rjpower76','rjpower76@yahoo.com','Rafael Joa','19937 Harrison Ave','Walnut','CA','UNITED STATES','91789-2848','(626) 536-4631','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 17:48:00',0,NULL,3,1,1,1,'、 ','rjpower76\r新地址\rRafael Joa\r22937 Rio Lobos Rd.\rDiamond Bar, CA 91765\rUSA\r'),(3378,784832130012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','leonveliki','leon.stare@gmail.com','Leon Stare','Dragocajna 9a','Smlednik','','SLOVENIA','1216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:54:25',0,NULL,3,1,2,1,'、 ','leonveliki'),(3379,580460645013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',61.99,'eastar4','invernesse','cbosnyak@hotmail.com','Csaba Bosnyák','Borsó u. 44.','Budapest','Budapest','HUNGARY','1173','+36204500650','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-09 18:12:01',0,NULL,3,1,3,1,'RA117730681CN ','invernesse\rHSNO019\r欧标'),(3380,580480156013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',7,'WWSI005',216.3,'eastar4','magalies2001','marius@magalies.net','Marius Bijker','1274 Walter avenue<br>Waverley','Pretoria','Gauteng','SOUTH AFRICA','0186','(083) 627-4872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:01:05',0,NULL,3,1,3,1,'RA117731418CN\r ','magalies2001\rWWSI005\r'),(3381,528247441003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','buythewayside','kievers@comcast.net','Robert S Kiever','17660 Wayside Ln','Lake Oswego','OR','UNITED STATES','97034-6450','(503) 353-1560','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 19:45:21',0,NULL,3,1,1,1,'、 ','buythewayside'),(3382,784903195012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','jarolumon','javito@jrlm.jazztel.es','Javier Rodríguez Lucas-Montoya','Ronda de Segovia Nº79 2ºB','Madrid','Madrid','SPAIN','28005','636425374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:48:24',0,NULL,3,1,2,1,'、 ','jarolumon'),(3383,580496674013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.99,'eastar4','1193dave','davegagnon007@hotmail.com','Dave Gagnon','414 Diane #1','longueuil','QC','CANADA','j4j2c3','(450) 646-1156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:52:04',0,NULL,3,1,2,1,'、 ','1193dave'),(3384,706183925011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',45.98,'eastar4','lionheadbaby','simon_kwok@msn.com','Simon Kwok','3043 Charles St.','Vancouver','BC','CANADA','V5K 3B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 19:52:34',0,NULL,3,1,3,1,'RA117730633CN ','lionheadbaby\rHSMO019'),(3385,706693746011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','piedra_79','jfernandezv@att.net','Jaime Fernandez','2250 Eldridge Pkwy<br>Apt 711','Houston','TX','UNITED STATES','77077-1862','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 20:06:05',0,NULL,3,1,1,1,'、 ','piedra_79'),(3386,580517243013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',61.8,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 20:35:58',0,NULL,3,1,3,1,'RA117730664CN ','update_marcelo\rWWSI005'),(3387,706715751011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.98,'eastar4','jasemanus','jhintz@comcast.net','Jason Hintz','1327 Yorkshire Rd','Grosse Pointe Park','MI','UNITED STATES','48230-1107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 20:45:39',0,NULL,3,1,1,1,'、 ','jasemanus'),(3388,784943300012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','tonymiddo2011','tonymiddo@yahoo.co.uk','tony middleton','54 rensherds place','high legh','Merseyside','UNITED KINGDOM','wa16 6ng','01925354301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 21:00:08',0,NULL,3,1,3,1,'RA117730718CN ','tonymiddo2011\r英标\rHSSE006\r'),(3389,580532444013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','devcar_sys','devin@devcar.com','Devin Gregoire','31262 Old Baton Rouge Hwy','Hammond','LA','UNITED STATES','70403-8352','(225) 202-3894','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 21:23:08',0,NULL,3,1,1,1,'、 ','devcar_sys'),(3390,580538665013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','smal7005','kumarm2010@hotmail.com','Shreejana Malla','20 Lindenwoods Rd.','Norwalk','CT','UNITED STATES','06851','(203) 286-8757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 21:46:53',0,NULL,3,1,1,1,'、 ','smal7005'),(3391,706764253011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','cybercenter816','cyber.center@live.com','Alexander Kornus','11518 N Walnut St','Kansas City','MO','UNITED STATES','64155-1120','(816) 508-9961','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 23:04:52',0,NULL,3,1,1,1,'、 ','cybercenter816'),(3392,784992059012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','vcollection777','vlad13@gmail.com','Vlad Zhitnitzky','11/9-13 Coorigil Rd.','Carnegie','Victoria','AUSTRALIA','3163','01395687167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 23:14:21',0,NULL,3,1,2,1,'、 ','vcollection777'),(3393,580556148013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','joehsker','jrhusker@gmail.com','joseph holt','1627 woodlawn ave','terre haute','IN','UNITED STATES','47804-4052','(812) 236-0745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-09 23:24:40',0,NULL,3,1,1,1,'、 ','joehsker'),(3394,784282396012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','alma_hernandez','ivanhoe.escobar@hotmail.com','Alma Hernandez','511 E San Ysidro Blvd<br># 2253','San Ysidro','CA','UNITED STATES','92173','(619) 567-6292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:14:28',0,NULL,3,1,1,1,'、 ','alma_hernandez'),(3395,577536202013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','denice202001','denice202001@yahoo.com','TASHONDRA D ROPER','8100 Winterwood Dr','Little Rock','AR','UNITED STATES','72209-7319','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:34:32',0,NULL,3,1,1,1,'、 ','denice202001'),(3396,580554099013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','green.318','l44948@bellsouth.net','gregory cooper','4029 Union Ave','shreveport','LA','UNITED STATES','71108-2231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 00:53:24',0,NULL,3,1,1,1,'、 ','green.318'),(3397,706799373011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','hcl0','tugkans@gmail.com','Tugkan Sahinler','302 Sokak No:18 Daire:7<br>Şirinyer','İzmir','','TURKEY','35140','+905326404544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 01:33:02',0,NULL,3,1,2,1,'、 ','hcl0'),(3398,785033711012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','anthonyl5253','mindofhisown@gmail.com','Anthony L Pietrangelo III','1528 Forest Hill Rd','Staten Island','NY','UNITED STATES','10314-6336','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 01:42:58',0,NULL,3,1,1,1,'、 ','anthonyl5253\r红边优联'),(3399,701885205011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','victorasieduyoung','victor.asieduyoung51@gmail.com','Victor Asiedu-Young','71 Nightstar Drive','Richmond Hill','ON','CANADA','L4C 8H5','(647) 701-5952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 02:40:02',0,NULL,3,1,2,1,'、 ','victorasieduyoung'),(3400,706820884011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','blaze-won','blaze_won@yahoo.com','James A. Guerrero Jr.','5062 N Maywood Ave','Los Angeles','CA','UNITED STATES','90041','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 02:54:01',0,NULL,3,1,1,1,'、 ','blaze-won'),(3401,580618362013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','tomek2961817','orion_101@hotmail.com','Tomek','12 Karlson Way','Cranbourne North','Victoria','AUSTRALIA','3977','0410021806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 05:04:10',0,NULL,3,1,2,1,'、 ','tomek2961817\rCAB-6060'),(3402,785067830012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.8,'eastar4','inkyrat01','inkyrat@yahoo.com','Alice Garratt','60 Edward Street','carlton','New South Wales','AUSTRALIA','2218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 05:19:20',0,NULL,3,1,2,1,'、 ','inkyrat01\rHP 6pin 1.0 12cm '),(3403,706847506011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','joserodriguezcuevas','jarcvs88@gmail.com','JOSE RODRIGUEZ','1131 Leahy RD','MONTEREY','CA','UNITED STATES','93940-7451','(831) 831-5572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 05:19:56',0,NULL,3,1,1,1,'、 ','joserodriguezcuevas'),(3404,785097567012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','georger0906','yellow_54@hotmail.com','George Romanacce','109 Meadowfield Ln','Longwood','FL','UNITED STATES','32779-4412','(407) 415-7905','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 06:35:26',0,NULL,3,1,1,1,'、 ','georger0906'),(3405,580637558013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','bronyaurstomp0123','the335@gmail.com','Yuki Tokuhiro','YAMASA Institute<br>1-2-1 Hanehigashimachi','Okazaki','Aichi','JAPAN','444-8691','(080) 421-0179 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:34:01',0,NULL,3,1,2,1,'\\ ','bronyaurstomp0123'),(3406,785111506012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','peckchoonheng','chpeck@pacific.net.sg','Peck Choon Heng','No.2 Lebuh Sungai Nyior','Butterworth','Penang','MALAYSIA','12100','043311717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:40:42',0,NULL,3,1,2,1,'\\ ','peckchoonheng'),(3407,706875125011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','aaleez','aaleezee@hotmail.com','Aaron Lee','15 Sandrigo Way','Stirling','Western Australia','AUSTRALIA','6021','0892072879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 07:44:49',0,NULL,3,1,2,1,'\\ ','aaleez'),(3408,785118751012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','3560michelle','hipwell.m@euro.apple.com','Michelle Hipwell','Apple Operations Europe<br>Hollyhill Industrial Estate','Cork','Cork','IRELAND','default','0872791980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 08:13:14',0,NULL,3,1,3,1,'RA117730973CN ','3560michelle\rCMLO001\r'),(3409,785130656012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','emanuel333','efogl@yahoo.com','Emanuel Fogl','Lanište 17b','Zagreb','Zagreb','CROATIA','10000','0998460071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 09:02:57',0,NULL,3,1,2,1,'\\ ','emanuel333\r红边优联'),(3410,534126918004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','4werter','bbccdd@bk.ru','Oleg Mashtakov','Krasnodarskaya street<br>house 51, building 4, office 98','Moskva','','RUSSIAN FEDERATION','109559','+7 9198275574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 09:34:39',0,NULL,3,1,3,1,'RA117733161CN\r ','4werter\rWWSI005'),(3411,670953943001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','zlc2002','zlc20022@yahoo.com','AZ','11831 Sir Winston Way','Orlando','FL','UNITED STATES','32824-6035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 10:44:16',0,NULL,3,1,1,1,'\\ ','zlc2002\rLK048091408CN'),(3412,785158544012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','zander.83','zander83@gmail.com','Alex Ulanovski','Bialik 94<br>Entrance B','Ramat Gan','','ISRAEL','52536','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:50:35',0,NULL,3,1,2,1,'、 ','zander.83'),(3413,580672259013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 11:05:35',0,NULL,3,1,3,1,'RA117732798CN\r ','flashy69\rMOSA002'),(3414,785175632012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','alindsay','alex@lindsay.cc','Alex Lindsay','179 George St','Redfern','New South Wales','AUSTRALIA','2016','0419490735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 11:50:33',0,NULL,3,1,2,1,'\\ ','alindsay'),(3415,706935739011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','hhjeb','blaue69@verizon.net','Harold Blaue','69 Lincoln Rd','Sutton','MA','UNITED STATES','01590','(508) 865-5374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 11:58:12',0,NULL,3,1,1,1,'\\ ','hhjeb'),(3416,785181536012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dracul6ijb','rudy_boc@yahoo.com.sg','Rudy Harjanto','30 Ah Hood Road<br>#08-01','Singapore','','SINGAPORE','329976','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:08:36',0,NULL,3,1,11,1,'\\ ','dracul6ijb\rHSPL010'),(3417,785187626012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','jasambond','vedran_radonic@yahoo.com','Vedran Radonić','Milana Rešetara 12','Zagreb','','CROATIA','10090','0922055172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:31:01',0,NULL,3,1,11,1,'\\ ','jasambond\rANYA002'),(3418,580690703013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','elm1232011','eliavmoryoussef@gmail.com','Eliav Moryoussef','Ha\'meginim 1','Nesher','','ISRAEL','36620','972 0502298900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:38:57',0,NULL,3,1,2,1,'\\ ','elm1232011'),(3419,706955942011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','uglyfish73','quincy00@hotmail.co.uk','Jody McKenzie','SOCO, Slough Police Station<br>Windsor Road','Slough','Berkshire','UNITED KINGDOM','SL1 2HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 13:02:58',0,NULL,3,1,3,1,'RA117732775CN\r ','uglyfish73\rMOAP001'),(3420,785206735012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','d.kim.15','dkim.15@gmail.com','Tae Kim','1477 N. Pembroke Dr.','South Elgin','IL','UNITED STATES','60177','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 13:25:47',0,NULL,3,1,1,1,NULL,'d.kim.15\r红边优联\\'),(3421,785212172012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','globaltres','globaltreasure1@gmail.com','Global Treasures LLC','38 Glenaire Dr','Greer','SC','UNITED STATES','29650-2573','(484) 336-7324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 13:42:53',0,NULL,3,1,1,1,'\\ ','globaltres'),(3422,579155490013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','havix_end','h_a_v_i_x@yahoo.com','Philip Johnson','182 Mount Marie Ave NW','Canton','OH','UNITED STATES','44708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 14:09:06',0,NULL,3,1,1,1,'\\ ','havix_end'),(3423,706982664011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','nadia_rick','nadia_alcindor@yahoo.com','Nadia Alcindor','10 Starbird Ave','Roslindale','MA','UNITED STATES','02131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 14:33:57',0,NULL,3,1,1,1,'\\ ','nadia_rick'),(3424,785232176012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',23.98,'eastar4uk','pinkhairdreser','s.b.murray@btinternet.com','shauna murray','26 shantallow avenue<br>belmont','derry','Londonderry','UNITED KINGDOM','b48 7ub','02871352174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 14:41:53',0,NULL,3,1,3,1,'RA117732784CN\r ','pinkhairdreser\rHSMO018\r英标\r'),(3425,706987395011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','anthonyyeung1106','anthony1106@gmail.com','Anthony Yeung','9/20 Gochean Ave, Bentley','Perth','Western Australia','AUSTRALIA','6102',' 0432748941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 14:45:27',0,NULL,3,1,2,1,'\\ ','anthonyyeung1106'),(3426,706992436011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',2,'WWSI006+ANCN001',126,'eastar4','pljubas1806','pljubas@vip.hr','Petar Ljubas','Dankovecka 3','Zagreb','Zagreb','CROATIA','10040','+385 91 2293388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:00:41',0,NULL,3,1,3,1,'RA117733303CN\r ','pljubas1806\rWWSI006+ANCN001'),(3427,706993484011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',2,'WWSI006+ANCN001',126,'eastar4','pljubas1806','pljubas@vip.hr','Dalibor Ljubic','I Trnava 39','Zagreb','Zagreb','CROATIA','10040','+385 91 2293388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:07:11',0,NULL,3,1,3,1,'RA117733294CN\r ','pljubas1806\rWWSI006+ANCN001'),(3428,707014576011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','massoodi','m_massood@hotmail.com','Mohamed Massoud','Airport Road<br>P.O.BOX: 43853','Abu Dhabi','UT','UNITED ARAB EMIRATES','02','00971504190911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:02:26',0,NULL,3,1,2,1,'\\ ','massoodi'),(3429,785275422012,220627153736,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',26.59,'eastar4','titichou64','jendav64@hotmail.fr','david cirillo','7 impasse d\'ossau<br>résidence la florentine app. B-06','lons','Aquitaine','FRANCE','64140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:32:26',0,NULL,3,1,2,1,'\\ ','titichou64\r欧标'),(3430,580752542013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','joaaann','ametllamotard@gmail.com','Joan Antoni González Crego','Amistat<br>38','L\'Ametlla del Vallès','Cataluña','SPAIN','08480','666971370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:50:45',0,NULL,3,1,2,1,'\\ ','joaaann'),(3431,580752480013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','rickoh1970','rickoh88@gmail.com','Rick Oh','13118 Sunstone pt','San Diego','CA','UNITED STATES','92130-5775','(858) 229-5923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 16:53:17',0,NULL,3,1,1,1,'\\ ','rickoh1970'),(3432,785305692012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','nj_kung','reginaqn@hotmail.com','Tossaporn Jiamsrisukhon','835/3   Sathupradit.RD trok watjannai<br>Bangprongprang   Yannawa　Poka House   room 2404','Bangkok','Center','THAILAND','10120','0891807100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 17:40:43',0,NULL,3,1,2,1,'\\ ','nj_kung'),(3433,707064144011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','sega_vs','sega1984@gmail.com','Sergey Vasiliev','Engelsa 74-89','Verkhnaya Salda','Sverdlovskaya oblast','RUSSIAN FEDERATION','624766','+7 909 0171040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 18:00:33',0,NULL,3,1,2,1,'\\ ','sega_vs\r欧标'),(3434,785344165012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','dsully20202','dsully2020@yahoo.com','Daniel Sullivan','330 Cabot St','Beverly','MA','UNITED STATES','01915-3340','(978) 998-2481','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 18:49:40',0,NULL,3,1,1,1,'\\ ','dsully20202'),(3435,784889120012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','pauleo1214','pauleliasson@gmail.com','Paul Eliasson','3925 Beech Ave<br>APT 213','Baltimore','MD','UNITED STATES','21211-2254','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 18:56:43',0,NULL,3,1,1,1,'\\ ','pauleo1214'),(3436,785352749012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','cdaisjr','cdaisjr@yahoo.com','Charles F. Dais II','3866 Tamarack Dr','Green Bay','WI','UNITED STATES','54313-4815','(920) 865-3866','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 19:04:02',0,NULL,3,1,1,1,'\\ ','cdaisjr'),(3437,580807799013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','remybobo06','remy_nos@hotmail.com','remy BORGHESE','87 avenue des combattants d\'afn','st laurent du var','Provence-Alpes-Côte d\'Azur','FRANCE','06700','0493143662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:28:38',0,NULL,3,1,2,1,'\\ ','remybobo06'),(3438,785358320012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','909everardo','evercarmin@hotmail.com','Everardo Carrillo Mijares','15047 seville ave','fontana','CA','UNITED STATES','92335-7009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 19:30:35',0,NULL,3,1,1,1,'\\ ','909everardo'),(3439,707108454011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.99,'eastar4','sircarodoc','barrier@rogers.com','B.M. WASSMANSDORF','120 - 1915 Broad Hollow Gate','Mississauga','ON','CANADA','L5L 6A3','(905) 820-5225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:56:48',0,NULL,3,1,2,1,'\\ ','sircarodoc\r\r'),(3440,707128003011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','curtis3332','nicholascurtis@f2s.com','Nicholas Curtis','2 St Barnabas Villas<br>Stockwell','London','London','UNITED KINGDOM','SW8 2EH','02076223471','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 20:02:06',0,NULL,3,1,3,1,'RA117733229CN\r ','curtis3332\rMOAP001'),(3441,707128943011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',11.95,'eastar4','altimadude22','diegoalfredo@me.com','Diego A Lopez','1009 Lamar St','Marion','NC','UNITED STATES','28752-5835','(828) 460-8112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 20:04:56',0,NULL,3,1,1,1,'\\ ','altimadude22'),(3442,707136973011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',134.99,'eastar4','tempo817','eblacourt@hotmail.com','Edwin Burgos','Urb. Colinas de San Martin calle 4 D3','Juana Diaz','PR','UNITED STATES','00795','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 20:19:12',0,NULL,3,1,1,1,'\\ ','tempo817'),(3443,707139324011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','wf-m','wf-m@freenet.de','Waldemar Felk','Josefa-Berens-Str. 23','Finnentrop','','GERMANY','57413','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:24:42',0,NULL,3,1,2,1,'\\ ','wf-m'),(3444,785400208012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',22.93,'eastar4','kovois','sykora@shaw.ca','Bohumil Sykora','3920 Westridge Ave<br>SYSCA INTERNATIONAL corp.','West Vancouver','BC','CANADA','V7V3H7','(604) 925-5749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:26:13',0,NULL,3,1,2,1,'\\ ','kovois\r再发一个New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card\r'),(3445,785414885012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','remcoz','remcoz@hotmail.com','Remco van der Zon','1e Kruisstraat 15','Deventer','','NETHERLANDS','7413 VE','0624696071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:55:55',0,NULL,3,1,2,1,'\\ ','remcoz\r红边优联'),(3446,707155538011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','robertosoltz','roberto@robertosoltz.com','Roberto Soltz','Av. Afonso Pena Street # 732, 9 andar<br>Centro, CEP: 30.130-003','Belo Horizonte, MG','Belo Horizonte, MG, Brazil','BRAZIL','30.130-003','31 3274-2900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:11:07',0,NULL,3,1,3,1,'RA117733189CN\r ','robertosoltz\rUDAP001'),(3447,785421729012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',10.95,'eastar4','14111981ihsan','ihsan_akar@hotmail.com','ihsan akar','hürriyet mah.başaran caddesi no:45/3<br>küçükköy','gaziosmanpaşa','istanbul','TURKEY','34250','00902126169039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:13:00',0,NULL,3,1,2,1,'\\ ','14111981ihsan\r欧标'),(3448,534307319004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',44.98,'cnfaner','retorosiba','holger.noack@web.de','Sven-Holger Noack','Gartenstr.4','Sarstedt','','GERMANY','31157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:27:36',0,NULL,3,1,3,1,'RA117733246CN\r ','retorosiba\rWWOT001'),(3449,580859820013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',2,'HSJA002',43,'eastar4','7043yeshua','jkhouchens@q.com','Kimberly Houchens','7737 Columbine Ct','Rapid City','SD','UNITED STATES','57702-9078','(605) 343-1849','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 22:12:55',0,NULL,3,1,1,1,'\\ ','7043yeshua'),(3450,580825636013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','alhasas96','mohd8609@hotmail.com','mohammed ali Al-Hasaei','ALBA P.O.Box 570<br>Inst. Red. Maint. CC 26','Bahrain','Middle East','BAHRAIN','No','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:27:30',0,NULL,3,1,2,1,'\\ ','alhasas96'),(3451,707188490011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.99,'eastar4','pgprazak','prazak@westnet.com.au','Peter Prazak','37 Pine Avenue','Wentworth Falls','New South Wales','AUSTRALIA','2782','0247571458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:31:04',0,NULL,3,1,2,1,'\\ ','pgprazak'),(3452,707187503011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','lour_madrid','lourdes190684@gmail.com','Lourdes Villa Fernandez','C/ Luxemburgo Nº13, 3º2','Fuenlabrada','Madrid','SPAIN','28943','676162768','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 22:33:00',0,NULL,3,1,3,1,'RA117731421CN\r ','lour_madrid\rGLSG001'),(3453,785458672012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','gimpybonez','gimpybonez@yahoo.com','Chris Swartz','22260 Riverwalk','Rocky River','OH','UNITED STATES','44116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 22:51:05',0,NULL,3,1,1,1,'\\ ','gimpybonez'),(3454,785463266012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','trxtoby','toby@littleport46.freeserve.co.uk','TOBY PRICE','21 ELY ROAD','ELY','Cambridgeshire','UNITED KINGDOM','CB61HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 23:05:35',0,NULL,3,1,3,1,'RA117733175CN\r ','trxtoby\rANCN001'),(3455,534332583004,140481827793,'New Plantronics Voyager 851/855 Bluetooth Headse track#',1,'HSPL009',49.9,'cnfaner','154neuville','yvesstamant@msn.com','Yves St-Amant','154 rue Côté','Neuville','QC','CANADA','G0A2R0','(418) 876-3465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 23:32:22',0,NULL,3,1,3,1,'RA117731435CN\r ','154neuville\rHSPL009\r'),(3456,785478426012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','mrdjol','mrdjol@yahoo.fr','Olivier GOYFFON','4 Rue du Dr Horand','Lyon','Rhône-Alpes','FRANCE','69009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 00:05:30',0,NULL,3,1,2,1,'\\ ','mrdjol\r4pin 1.25'),(3457,785487573012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',2,'WLAP001+WLAP004',37.98,'eastar4','ciclirossetto','ciclirossetto@excite.com','Cicli Rossetto','4401 San Leandro St<br>Apt 51','Oakland','CA','UNITED STATES','94601-4461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 00:56:02',0,NULL,3,1,1,1,'\\ ','ciclirossetto'),(3458,580890330013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','wendo1jose','jwendo1@yahoo.com','jose fernandez','1473 lydia ave','elmont','NY','UNITED STATES','11003-4529','(347) 476-0852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 00:58:01',0,NULL,3,1,1,1,'\\ ','wendo1jose'),(3459,580263159013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','jaboo76','jaboo76@yahoo.com','Jason Boo','Blk 238 Compassvale Walk<br>#10-552','default','','SINGAPORE','540238','96854522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:05:38',0,NULL,3,1,11,1,'\\ ','jaboo76\rWLIN010'),(3460,580892072013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA002',48.95,'eastar4','salemalharthy','rasta915@hotmail.com','Salem Said Al Harthy','P O  Box 1572','Musact','Al Khwair','OMAN','133','+96899333480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:09:19',0,NULL,3,1,3,1,'RA117733250CN ','salemalharthy\rOTRA002'),(3461,785502298012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','motorcyclearcher1960','peter@repairman.com','peter needham','59 Oakland St','medford','MA','UNITED STATES','02155','(781) 396-4800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 01:33:47',0,NULL,3,1,1,1,'\\ ','motorcyclearcher1960'),(3462,707236444011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.98,'eastar4','alanyhsiao','alan_y_hsiao@yahoo.com','Alan Hsiao','5/2 Bechert Rd','Chiswick','New South Wales','AUSTRALIA','2046','0297155472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 01:47:58',0,NULL,3,1,2,1,'\\ ','alanyhsiao'),(3463,707245426011,320661552604,'Genuine LOGITECH Battery for G7 Cordles Mouse+ charger',1,'BALO005+BALO006',19.99,'eastar4','g_odagi','odagi@internode.on.net','George Odagi','3 Dale Court','Bundall','Queensland','AUSTRALIA','4217','0755735949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 02:28:43',0,NULL,5,1,18,1,' ','g_odagi\r因缺货  已退款'),(3464,785518462012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','yonseikim02','yonseikim@hotmail.com','Hyunjin Kim','310 Chestnut hill st','Gaithersburg','MD','UNITED STATES','20878-2178','(301) 358-5082','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 02:34:04',0,NULL,3,1,1,1,'\\ ','yonseikim02\r红边优联'),(3465,785526192012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','manoj27814','manoj27814@gmail.com','Manoj Menon','1131 Pinnacle Fls','San Antonio','TX','UNITED STATES','78260-2481','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 03:07:14',0,NULL,3,1,1,1,NULL,'manoj27814\r红边优联'),(3466,580917560013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',23.98,'eastar4','xes7488','slbuddy@att.net','Steven Romund','55417 Macintosh Ct','Shelby Township','MI','UNITED STATES','48316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 03:26:48',0,NULL,3,1,1,1,'\\ ','xes7488'),(3467,707271997011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',135.98,'eastar4','mamallama53','mamallama51@mac.com','Margaret Boersma','1017 Bandera Ave','Douglas','WY','UNITED STATES','82633-3040','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 04:42:15',0,NULL,3,1,1,1,'\\ ','mamallama53'),(3468,707274682011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','uptown_anthem','uzzy_man_01@hotmail.com','Usman Majid','72 ROCKWELL ROAD','LIVERPOOL','MERSEYSIDE','UNITED KINGDOM','L12 4XZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 04:55:14',0,NULL,3,1,3,1,'RA117733215CN\r ','uptown_anthem\rMOAP001\r'),(3469,707275977011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','rdvolkman','renovatio_2006@comcast.net','Robert Volkman','15032 Mission Ave','Oak Forest','IL','UNITED STATES','60452-1311','(708) 401-3194','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 05:05:10',0,NULL,3,1,1,1,'\\ ','rdvolkman'),(3470,580934645013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','flam4086','franki@techo-bloc.com','Franki Lam','7162 Cartier Street','Montreal','QC','CANADA','H2E 2J2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 05:37:26',0,NULL,3,1,2,1,'\\ ','flam4086'),(3471,580939840013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','worawisut','worawisut@gmail.com','Worawisut Pinyoyang','518/480 The Room Ratchada Ladprao<br>Chankasem Chatuchak','Bangkok','','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:21:48',0,NULL,3,1,3,1,'RA117731449CN\r ','worawisut\rBAZA001'),(3472,785569844012,220778495356,'New Replaceable Shell 4 logitech anywhere MX Mouse M905',3,'SHLO005',50.97,'eastar4','eilu120','einar.lund@broadpark.no','Einar Lund','Ringvolveien 120','Trondheim','','NORWAY','7089','+047 41568957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:47:44',0,NULL,3,1,3,1,'RA117727784CN ','eilu120\rSHLO005\r\r发两个鼠标壳\r退了一个的钱'),(3473,707297183011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','athena3967','alex3967@gmail.com','Alexandre DUFER','Villa 18 Street 89<br>Jumeirah 1 PO 214929','DUBAI','UNITED ARAB EMIRATES','UNITED ARAB EMIRATES','214929','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 07:00:33',0,NULL,3,1,3,1,'RA117731585CN\r ','athena3967\rEXLO001\r'),(3474,580969410013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','motael123','tarekrules@hotmail.com','Tarek El-hamawi','284 Waterloo Road<br>Greenacre','Sydney','New South Wales','AUSTRALIA','2190','0297426405','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'motael123'),(3475,580971336013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'eastar4','balage001','speed.limit@freemail.hu','Tözser Balazs','Etele ter 3. fszt. 2.','Budapest','','HUNGARY','1115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:51:52',0,NULL,3,1,3,1,'RA117731727CN ','balage001\rCACN004\r\r'),(3476,707334113011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',3,'OTCN002',11.97,'eastar4','kirillt1979','89184488446@mail.ru','Kirill Tachanov','2-ya liniya 48','Krasnodar','Krasnodar','RUSSIAN FEDERATION','350004','+79184488446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:53:50',0,NULL,3,1,2,1,'、 ','kirillt1979'),(3477,785616766012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','mmapasflg','mmapas@gmail.com','Marek Pinc','Bukova 94','p.Jince','','CZECH REPUBLIC','26223','+420603182733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:01:18',0,NULL,3,1,2,1,'\\ ','mmapasflg\r红边优联'),(3478,707346323011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'eastar4','liron_levi','lironxxx@gmail.com','liron levi','meshek 78','shetulim','israel','ISRAEL','79280','97288552336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:43:18',0,NULL,3,1,2,1,'、 ','liron_levi'),(3479,785629744012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','makdel11','makdel@mycosmos.gr','AVRAAM DELIGIANNIS','ANTHEON & ELLIS','THESSALONIKI','','GREECE','57019','+302392075376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:48:00',0,NULL,3,1,2,1,'、 ','makdel11\r红边优联'),(3480,580286952013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','krjrs','scissol@hotmail.com','Laura Scissons','RR#2 2203 Ashton Station Road','Ashton','ON','CANADA','K0A 1B0','(613) 257-4366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:56:14',0,NULL,3,1,2,1,'、 ','krjrs'),(3481,785651930012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',61.68,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:01:13',0,NULL,3,1,3,1,'RA117732705CN ','i.gabunia\rANCN002+WWOT001\r再发一个NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530'),(3482,784886792012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','compraszeballos','mozovidal.dyo@gmail.com','Oscar Justiniano / Zeballos','2931 NW 26th St','Miami','FL','UNITED STATES','33142-6415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 12:06:09',0,NULL,3,1,1,1,'、 ','compraszeballos'),(3483,534447061004,140523331018,'New Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65,'cnfaner','raziel7002','markus.benkert@gmx.net','Markus Benkert','Max-Reger-Straße 1','Ostheim','','GERMANY','97645','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:07:12',0,NULL,3,1,3,1,'RA117733277CN ','raziel7002\rMOLO001'),(3484,707379668011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',15,'eastar4','vickygill18','vicky_gill18@yahoo.com.au','Davinder Singh','2/377 Regency Road','Prospect','South Australia','AUSTRALIA','5082','0430230035','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'vickygill18\rECHECK'),(3485,707401624011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','wayne1967','wgalutz@gmail.com','Wayne Galutz','5533 Bingley Ln','Clay','NY','UNITED STATES','13041-9714','(315) 420-0910','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 13:53:36',0,NULL,3,1,1,1,'、 ','wayne1967'),(3486,707414225011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','hgirllittleb','mattothomas@hotmail.com','Matt Thomas','14023 Halprin Creek','Cypress','TX','UNITED STATES','77429','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 14:33:21',0,NULL,3,1,1,1,'、 ','hgirllittleb'),(3487,577087904013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','christopher_ms77','christopher_ms@yahoo.com','Christopher Smith','14750 Ries Rd','Venedocia','OH','UNITED STATES','45894-9628','(419) 303-4824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 14:49:57',0,NULL,3,1,1,1,'、 ','christopher_ms77'),(3488,580956754013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','goopgive','goopgive.ebay@gmail.com','Chalika Jai-Ai','813/29 Kheha Chumchon Nawa Min Moo10 Nawamin Street<br>Khlong Kum Bueng Kum','Bangkok','Thailand','THAILAND','10230','066-834347898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:33:18',0,NULL,3,1,3,1,'RA117732740CN ','goopgive\rBAZA001\r新地址\rMr.Khankorn Punyamanob 263/25 saengthong condo ruamjit rd. Cha-am Phetchaburi 76120 \rThailand\r 0818577047'),(3489,581043974013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'eastar4','bubu742011','resp.esv@gmail.com','bruno piotin','55 ROUTE DE BOSSEY<br>BP 25','COLLONGES-SOUS-SALEVE','Rhône-Alpes','FRANCE','74165','0450436023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:40:52',0,NULL,3,1,3,1,'RA117731713CN ','bubu742011\rTRTT002*10'),(3490,581047400013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','rxgn','ongwaileong@hotmail.com','waileong ong','Blk 946 Jurong West St 91<br>#07-669','default','','SINGAPORE','640946','+6594766562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:49:59',0,NULL,3,1,11,1,'、 ','rxgn\rCACN004'),(3491,707441716011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','finecard','michael@intelore.com','Mikhail Bolshakov','P.O. BOX 139','Vologda','','RUSSIAN FEDERATION','160000','79115109314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:53:41',0,NULL,8,1,17,0,NULL,'finecard'),(3492,707451265011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','flying_monkey80','victorsoe@hotmail.com','Victor Soe','5 Covepark Bay NE','Calgary','AB','CANADA','T3K6K8','(403) 606-8315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:18:19',0,NULL,3,1,3,1,'RA117732753CN ','flying_monkey80\rRCLO006'),(3493,707455257011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','move_along_now','patbright07@googlemail.com','Pat Bright','101 London Road<br>Marks Tey','Colchester','Essex','UNITED KINGDOM','CO6 1EB','01206212878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:29:09',0,NULL,3,1,2,1,'、 ','move_along_now'),(3494,785752879012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','finecard','michael@intelore.com','Mikhail Bolshakov','P.O. BOX 139','Vologda','','RUSSIAN FEDERATION','160000','79115109314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:38:26',0,NULL,3,1,2,1,'、 ','finecard\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e'),(3495,707461040011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',8.55,'eastar4','notadmin','jen140@gmail.com','Yevgen Goncharuk','Rua Nuno Netto De Almeida Nº3 1ºDir.','Santarém','Jardim De Baixo','PORTUGAL','2005-280','967106719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 16:45:39',0,NULL,3,0,2,1,'、 ','notadmin'),(3496,528779689003,130490590870,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',83,'cnfaner','rakanbi1jel','rakanbi@yahoo.com','robert babs cole','16225 Greenfield apt # 309','detroit','MI','UNITED STATES','48235','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 16:50:31',0,NULL,3,1,1,1,'、 ','rakanbi1jel'),(3497,581069295013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',2,'MOSA002',143.94,'eastar4','robertobaggiocalcio','robybrescia_baggio@yahoo.de','Gaetano Cambria Zurro','Marienbaderstr. 2','Hünfelden / Nauheim','','GERMANY','65597','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:02:14',0,NULL,3,1,4,1,'YW865907631CN ','robertobaggiocalcio'),(3498,534516385004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','l-1-vaivis','a.vaivods@e-no.lv','Aivars Vaivods','Rigas iela 41-56','Livani','Preilu raj','LATVIA','LV-5316','22370725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:08:43',0,NULL,3,1,3,1,'RA117732682CN\r ','l-1-vaivis\rHSNO005\r欧标'),(3499,785791524012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','mariamercedessalcedo','edwardjm50@hotmail.com','maria salcedo','1808 Amethyst St<br>Fl 1','bronx','NY','UNITED STATES','10462-3516','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 18:03:25',0,NULL,3,1,1,1,'、 ','mariamercedessalcedo'),(3500,707508457011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','panocha48','tramoyeres48@hotmail.com','jose tramoyeres sanchez','abenida de las ferias <br>patio 12 puerta 16','valencia','Comunidad Valenciana','SPAIN','46035','96 3641085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:31:37',0,NULL,3,1,3,1,'RA117732665CN ','panocha48\rGLSG001*2'),(3501,581099773013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','macman5000','macman1000@web.de','M-Design Berlin Michael Wodtke','Feldtmannstr. 143a','Berlin','','GERMANY','13088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:34:29',0,NULL,3,1,2,1,'、 ','macman5000'),(3502,581100386013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'eastar4','musicconsummer','mybuffalo@yandex.ru','Vladimir Sadkovskiy','122 Mira Str.','Krasnodar,village Maryanskaya','','RUSSIAN FEDERATION','353823','7861659651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:47:40',0,NULL,3,1,3,1,'RA117731758CN ','musicconsummer\rOTES001'),(3503,581107294013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','superiousblueangel','ebay@bummens.de','Thomas Stein','Beukenweg 21','Vlotho','','GERMANY','32602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:51:21',0,NULL,3,1,2,1,'\\ ','superiousblueangel'),(3504,785816712012,220770080684,'Logitech Harmony RF extender 890 pro 1000 1100 90% new',1,'RCLO007',29.99,'eastar4','franka1380','gsbol@upcmail.nl','frank asmus','adriaen van der doeslaan 47','rotterdam','zh','NETHERLANDS','3054 eb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 18:52:18',0,NULL,3,1,2,1,'、 ','franka1380'),(3505,785827898012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','cj13bny','rben84@yahoo.com','Mircea Talos','Str. Trotusului Nr. 5<br>BL. Y5 Ap. 31','Cluj-Napoca','Cluj','ROMANIA','400621','40742120190','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 19:02:57',0,NULL,3,1,2,1,'\\','cj13bny\r欧标\r\r\r'),(3506,707528360011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','segreto7','kristinsegreto@gmail.com','kristin segreto','3416 silver meadow way','plant city','FL','UNITED STATES','33566-0724','(813) 458-5776','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 19:07:21',0,NULL,3,1,1,1,'、 ','segreto7'),(3507,581116962013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','pengguj','pengguj2000@yahoo.com','pengguang jiang','2860 Geer Rd','turlock','CA','UNITED STATES','95382-1141','(209) 668-9988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 19:15:17',0,NULL,3,1,1,1,'、 ','pengguj'),(3508,581126193013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','rx8-323','gioiuliano@yahoo.com','John Iuliano','1 Hanover rd Cameron Park','Newcastle','New South Wales','AUSTRALIA','2285','0249530664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 19:40:15',0,NULL,3,1,2,1,'、 ','rx8-323'),(3509,707546504011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',2,'HSNO006',29.9,'eastar4','okker3578123','okkerdeklerk@vodamail.co.za','Okker de Klerk','PO Box 1437','KURUMAN','Northern Cape','SOUTH AFRICA','8460','0828290292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 19:43:27',0,NULL,3,1,2,1,'、 ','okker3578123'),(3510,707576466011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',2,'WLAT001+ANTY002',33.98,'eastar4','deaduska','rip1985@mail.ru','Evgenij Shajgam','ul. Sovnarkomovskaja, d.34, kv.157','Nizhnij Novgorod','','RUSSIAN FEDERATION','603086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 20:50:08',0,NULL,3,1,3,1,'RA117732807CN\r ','deaduska\rWLAT001+ANTY002'),(3511,707577514011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','eeldivad','david@eeldivad.com','David Lee','326 Golden Rod Ln','Auburn','GA','UNITED STATES','30011-3309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 21:03:57',0,NULL,3,1,1,1,'、 ','eeldivad'),(3512,707610419011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',19.99,'eastar4','alexdems','alex.desmonts@noos.fr','alexandre DESMONTS','3 SQUARE DES ALLOBROGES','VILLIERS SUR MARNE','Île-de-France','FRANCE','94350','0676739815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 22:13:53',0,NULL,3,1,2,1,'、 ','alexdems'),(3513,785929994012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','xyzdave','martindavidson@live.ca','martin davidson','1335 andy','st-hubert','QC','CANADA','J4T1H1','(450) 926-8626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 22:31:31',0,NULL,3,1,2,1,'、 ','xyzdave'),(3514,785936169012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','scarri20','scarri2016@yahoo.com','Sarah Carrington','300 N 725 W','Orem','UT','UNITED STATES','84057-4511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 22:53:11',0,NULL,3,1,1,1,'、 ','scarri20'),(3515,785936056012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','jahfam2010','jahfam@clearwire.net','jason hietala','1221 E 9th st','duluth','MN','UNITED STATES','55805-1608','(218) 786-0859','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 22:54:39',0,NULL,3,1,1,1,'、 ','jahfam2010'),(3516,707624243011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','maxibons','dannydgolding@gmail.com','Danny Golding','163 Albemarle Road','York','North Yorkshire','UNITED KINGDOM','YO231HD','01904611940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 23:06:33',0,NULL,3,1,3,1,'RA117732696CN ','maxibons\rMOAP001'),(3517,785957196012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','sylvalab','sgalipeau@videotron.ca','sylvain labrie','261 desbouleaux','charlemagne','QC','CANADA','j5z3z1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 00:16:44',0,NULL,8,1,17,0,' ','sylvalab\rBAZA001'),(3518,581194959013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','sylvalab','sgalipeau@videotron.ca','sylvain labrie','261 desbouleaux','charlemagne','QC','CANADA','j5z3z1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:18:15',0,NULL,3,1,3,1,'RA117732736CN\r ','sylvalab\rBAZA001\r一共买了两个\r与EASTAR4UK 合并'),(3519,707643614011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',10,'CASS003',87,'eastar4','andre.iacono','lorenalive@hotmail.co.uk','Lorena Oliveira','SRTVS, Qd 701 - Bloco K - Sala 725<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:32:57',0,NULL,3,1,3,1,'RA117731611CN ','andre.iacono\rCASS003'),(3520,785972804012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','rcwindy','rcwindy@gmail.com','Richard Williams','8709 Orchard Grove Ln','Camby','IN','UNITED STATES','46113-8218','(317) 821-2218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 01:12:33',0,NULL,3,1,1,1,'、 ','rcwindy'),(3521,707658507011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','thanz','jmthanz@yahoo.com','jonathan mariano','DepEd, Pagadian City Division<br>San Jose Heights','pagadian city','zamboanga del sur','PHILIPPINES','7016','9298438569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:35:14',0,NULL,3,1,2,1,'、 ','thanz\r银色的'),(3522,785990757012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','caldie226','crcaldie@gmail.com','Christian Caldie','1166 Carmel Cir<br>Apt 420','Casselberry','FL','UNITED STATES','32707-6455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 02:18:46',0,NULL,3,1,1,1,'、 ','caldie226'),(3523,581223530013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','outbidem_all','harlan@pbdesigns.biz','Harlan Bachmayer','12101 FM 619','Coupland','TX','UNITED STATES','78615-4973','(512) 352-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 02:58:08',0,NULL,3,1,1,1,'、 ','outbidem_all'),(3524,580881482013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','dennisfl3','dstav@bellsouth.net','Dennis Tavares','1810 NW 86th Ave','Pembroke Pines','FL','UNITED STATES','33024-3354','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:02:56',0,NULL,3,1,1,1,'、 ','dennisfl3'),(3525,786003720012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',12.5,'eastar4','miriambaby1983','miriam_curtidor@yahoo.com','MIRIAM ESPARZA','17701 avalon blvd<br>spc 203','carson','CA','UNITED STATES','90746','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:11:03',0,NULL,3,1,1,1,'\\ ','miriambaby1983\racer 6pin1.25 23cm'),(3526,786012077012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','bfg542','bfg221@yahoo.co.uk','Stephen Coppins','124 Ringway','Waverton','Cheshire','UNITED KINGDOM','CH3 7NR','01244332182','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 03:50:06',0,NULL,3,1,3,1,'RA117731744CN ','bfg542\rHSPL010\r英标\r'),(3527,707687740011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','moviefreak88','barboza@entouch.net','Leslee Barboza','26702 Blanchard Grove Dr','Katy','TX','UNITED STATES','77494-0377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:51:46',0,NULL,3,1,1,1,'、 ','moviefreak88'),(3528,707687978011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','venturarick','venturarick@sbcglobal.net','Rick K Watanabe','2083 Foster Ave','Ventura','CA','UNITED STATES','93001-2419','(805) 653-1378','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 03:54:35',0,NULL,3,1,1,1,'、 ','venturarick'),(3529,707687560011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',71.98,'eastar4','tavisakp','tavisak@email.com','Tavisak Poontanes','302 / 64 Lardprao 1 Road,<br>Jormpol, Jatujak,','Bangkok','','THAILAND','10900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:00:53',0,NULL,3,1,3,1,'RA117731687CN ','tavisakp\rHSNO015\r一共买了两个'),(3530,786014289012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','reyerwalk','mwalker@alum.mit.edu','Martin Walker','378 Cambridge Ave<br>Suite N','Palo Alto','CA','UNITED STATES','94306-1544','(650) 331-0200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 04:01:27',0,NULL,3,1,1,1,'、 ','reyerwalk'),(3531,707693590011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',2,'HSNO008',30,'eastar4','fabiorbarbosa','fabiobarbosaa@gmail.com','FÁBIO BARBOSA','RUA CARDOSO DE ALMEIDA<br>668 APTO 166','SÃO PAULO','SÃO PAULO','BRAZIL','05013000','551198140834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:25:02',0,NULL,3,1,3,1,'RA117731700CN ','fabiorbarbosa\rHSNO008'),(3532,785560312012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','kings_park','ckwkwong@shaw.ca','Chris Kwong','UBC Okanagan, IT Services<br>3333 Unversity Way','Kelowna','BC','CANADA','V1V 1V7','(250) 807-9149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 04:39:37',0,NULL,3,1,2,1,'、 ','kings_park\r红边优联'),(3533,786033559012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',51.98,'eastar4','sirlonramos','sirlonbaixo@hotmail.com','Amando Ramos','Rua Fortaleza qd 29 lt 03<br>Jd das Esmeraldas','Aparecida de Goiânia','Goias','BRAZIL','74905060','6281275304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 05:47:39',0,NULL,3,1,3,1,'RA117731660CN ','sirlonramos\rHSSH002'),(3534,786043376012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','jacobpank','jacob.pank@gmail.com','Jacob Pankovski','7 Ha-Gai St.','Jerusalem','Israel','ISRAEL','96262','02-6521153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 06:36:08',0,NULL,3,1,2,1,'、 ','jacobpank'),(3535,534688966004,140482241366,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',12.99,'cnfaner','muratd77murat','donmez-murat@hotmail.com','murat dönmez','124 sok. no:2 sevenyuva apt. K.1 D.1<br>evka-3 Mahalle Bornova','izmir','izmir','TURKEY','35050','+905335069291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 07:13:27',0,NULL,3,1,3,1,'RA117731673CN ','muratd77murat\rHSMO007\r欧标\r'),(3536,581258359013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','gerasinalexander','gerasinao@mail.ru','Gerasin Alexander','District 3, house 1, flat 117','Moscow Area, Leninskiy District, Moskovskiy City','+79262625080','RUSSIAN FEDERATION','142784','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 07:20:16',0,NULL,3,1,3,1,'RA117731695CN ','gerasinalexander\rOTRA001'),(3537,707685755011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',101,'eastar4','bahaa_123','ccbc_canada@hotmail.com','BAHAA AL-SILWDI','P.O.BOX 7534 ; THE CANADIAN COMMERCIAL BROKER COMPANY,AIRPORT RD<br>OWEIDAH BUIDING, OFFICE FLOOR # 3','ABU DHABI','','UNITED ARAB EMIRATES','P.O.BOX 7534','(971) 506-4230 ext.: 39','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 08:27:55',0,NULL,3,1,3,1,'RA117731965CN','bahaa_123\rKBVI001\r'),(3538,707737938011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',2,'BALO007',23.4,'eastar4','jeroenjohnny','jeroenbaas@gmail.com','Jeroen Baas','Willem Hedastraat 3','UTRECHT','','NETHERLANDS','3552AN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 08:30:28',0,NULL,3,1,2,1,NULL,'jeroenjohnny\\'),(3539,581273592013,230546985871,'New Motorola H700 Bluetooth Wireless Headset+carcharger',1,'HSMO011+CCMO001',14.99,'eastar4','kimi2005','rklaw@bigpond.com','Kirstie Law','685 Burke Road','Camberwell','Victoria','AUSTRALIA','3113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:04:27',0,NULL,3,1,2,1,NULL,'kimi2005\\'),(3540,532427257004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','bjarnei','bjaisak@gmail.com','Bjarne Isaksen','Øvre Brennelv','9700 LAKSELV','Finnmark','NORWAY','9700','(047)91574179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:23:15',0,NULL,3,1,3,1,'RA117733365CN ','bjarnei\rHSNO003\r欧标'),(3541,786091954012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','zermattjohn','jmsanderson@gmail.com','John Sanderson','30 Pytha Fold Road','Manchester','Lancashire','UNITED KINGDOM','M20 4UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 10:00:29',0,NULL,3,1,3,1,'RA117733325CN ','zermattjohn\rRELO002'),(3542,786093714012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','charitysunshine','newyorkhardbody@gmail.com','Charity Edwards','455 EOSS/IN','APO','AE','AA','09352','(716) 200-6107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 10:08:41',0,NULL,3,1,1,1,'、 ','charitysunshine'),(3543,581283747013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',42.65,'eastar4','lexj2010','222468@mail.ru','Alex Solodyankin','Tipanova 34 korp 3 kv.32','Sankt-Peterburg','','RUSSIAN FEDERATION','196233','79119704264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:09:17',0,NULL,3,1,3,1,'RA117727055CN ','lexj2010\rWLIN014\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e\r'),(3544,528985234003,130493270294,'New Sony Ericsson HBH-608 BLUETOOTH HEADSET track#',1,'HSSE007',19.9,'cnfaner','ebuddhika','asankabuddhika@gmail.com','Asanka Alwis','No 190/1<br>Madelgamuwa','Gampaha','Other','SRI LANKA','11000','0094773333117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:13:34',0,NULL,3,1,3,1,'RA117733396CN ','ebuddhika\rHSSE007\r'),(3545,786107947012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',8,'HSPL010',191.2,'eastar4','andi728i','andi.fottner@freenet.de','Firma FBH GmbH A. Fottner','Hirschenhausener Str. 11','Hilgertshausen','','GERMANY','86567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:03:22',0,NULL,3,1,3,1,'RA117733436CN ','andi728i\r欧标\rHSPL010'),(3546,581294103013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','horsechristy_lynn','christydunkle@zoominternet.net','christy dunkle','203 McFate Rd','pleasantville','PA','UNITED STATES','16341-5203','(814) 589-5334','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-12 11:05:50',0,NULL,3,1,1,1,'、 ','horsechristy_lynn'),(3547,581295304013,230620420999,'NIB GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO029',38.9,'eastar4','tpaje','tristan_paje@hotmail.com','Tristan Paje','Colonial First State<br>Level 23, 52 Martin Place','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:13:15',0,NULL,3,1,3,1,'RA117733263CN ','tpaje\rHSNO029\r澳标\r盒装'),(3548,786114476012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','sjor_bepo','dario.kranjcec@yahoo.com','Dario Kranjčec','Oktavijana Valića 53','Rijeka','primorsko-goranska','CROATIA','51000','+385917623972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:24:41',0,NULL,3,1,2,1,'、 ','sjor_bepo\r欧标'),(3549,707788228011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.7,'eastar4','szhu0618','sam.junzhu@gmail.com','Jun Zhu','123 George Street','Scoresby','Victoria','AUSTRALIA','3179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:58:10',0,NULL,3,1,2,1,'、 ','szhu0618'),(3550,707805986011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',15.9,'eastar4','igm1','igor@mmmm.sk','Igor Maly','Palkovicova 16','Bratislava','','SLOVAK REPUBLIC','82108','903404453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 12:58:49',0,NULL,3,1,2,1,'、 ','igm1'),(3551,786152431012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA001',25.59,'eastar4uk','raum2010','raum2000@yandex.ru','Valeriy Smirnov','Kosmonavtov 8-33','Noyabrsk','Russian Federation','RUSSIAN FEDERATION','629802','+7 922 464 8888','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 13:36:34',0,NULL,3,1,3,1,'RA117733379CN ','raum2010\rOTRA001'),(3552,707827905011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',12.5,'eastar4','123-kirkp','ianwkirkpatrick@tiscali.co.uk','Ian Kirkpatrick','11 Oaklands Terrace, London Road<br>Kessingland','Lowestoft','Suffolk','UNITED KINGDOM','NR33 7PH','01502740157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 14:10:09',0,NULL,3,1,2,1,'、 ','123-kirkp\r华硕 10 pin 1.0 5cm'),(3553,786181284012,220759518691,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',35.49,'eastar4uk','hmcc7560','peter.mcculloch@homecall.co.uk','Heather Mcculloch','22 Clarence court<br>Weavering','Maidstone','Kent','UNITED KINGDOM','Me14 5up','01622734279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 14:41:46',0,NULL,3,1,3,1,'RA117727033CN ','hmcc7560\rMOLO001\r'),(3554,786161778012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','pintuzeza','pintu_zeza@yahoo.com','DHARMANTO RAHARDJO','JL FLAMBOYAN NO. 118<br>KOMPLEK KODAM - KEBON JERUK','JAKARTA BARAT','DKI JAKARTA','INDONESIA','11530','08812001568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:02:43',0,NULL,3,1,2,1,'、 ','pintuzeza'),(3555,707848429011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.99,'eastar4','lubiha','lutz.liepelt@arcor.de','Lutz Liepelt','Zum Steinpleiser Bahnhof 2','Werdau','','GERMANY','08412','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:13:58',0,NULL,3,1,2,1,'、 ','lubiha'),(3556,707852478011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','dictatorhales','jhales.perth@gmail.com','James Hales','24 Dollis Way Kingsley','Perth','Western Australia','AUSTRALIA','6026','0411664073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:25:38',0,NULL,3,0,2,1,'、 ','dictatorhales'),(3557,786199722012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',2,'ANYA001',28.9,'eastar4','silver_1976','concordia@ole.com','Francisco Vela Ledesma','c/ Veremundo perera nº 20  1ºdcha','Santa Cruz de Tenerife','Canarias','SPAIN','38006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:31:53',0,NULL,3,1,3,1,'RA117731982CN ','silver_1976\rANYA001'),(3558,786230856012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','zversabvbg','zefir@bginfo.net','Zefir Psaryanov','Konstantin Velichkov 34','Burgas','Burgas','BULGARIA','8001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 16:44:57',0,NULL,3,1,2,1,'、 ','zversabvbg'),(3559,784700231012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','neiloppiton','ebay@neilwoolford.co.uk','Neil Woolford','27 York Place','Worcester','Worcestershire','UNITED KINGDOM','WR13DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 16:53:12',0,NULL,3,1,3,1,'RA117733422CN\r ','neiloppiton\rOTCN003\r'),(3560,786234124012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',34.8,'eastar4','rootphreak','nawcom@nawcom.com','Ben Nawrocki','31600 W 9 Mile Rd<br>Apt 307','Farmington Hills','MI','UNITED STATES','48336-4136','(810) 623-8947','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 16:54:12',0,NULL,3,0,1,1,'、 ','rootphreak'),(3561,581378643013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','enok','ojaiburke@gmail.com','ADRIAN BURKE','2575 Vista Del Mar Dr','Ventura','CA','UNITED STATES','93001-3920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:06:16',0,NULL,3,1,1,1,'、 ','enok'),(3562,534807721004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','sasthaonlinestore','rsganesh@gmail.com','Neela Ganesh','20 South Beach Avenue<br>M.R.C.Nagar, R.A.Puram','Chennai','TN','INDIA','600028','9840385675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:28:31',0,NULL,3,1,3,1,'RA117733348CN ','sasthaonlinestore\rHSPL001'),(3563,581385836013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','henry2870','henryfujita@yahoo.com','Henry Fujita','2870 Booth Rd<br># B','Honolulu','HI','UNITED STATES','96813-1140','(808) 533-6658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:31:58',0,NULL,3,1,1,1,'、 ','henry2870'),(3564,707904861011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','hitman593','hitman593@hotmail.com','LUTICK Gregory','62 RUE FOCH<br>appartement 1','IWUY','Nord-Pas-de-Calais','FRANCE','59141','0624633978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:39:19',0,NULL,3,1,2,1,'、 ','hitman593'),(3565,786260011012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','revvon','revkrisvon@aol.com','Kris von Maluski','100 Ochre Point Ave','Newport','RI','UNITED STATES','02840-4149','(401) 481-8887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 17:46:17',0,NULL,3,1,1,1,'、 ','revvon'),(3566,786159815012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','sun-light108','lequanghai@gmx.de','Giamy Le (Tou Chia Mei)','167 / F7 Dayou Rd','Taoyuan','','TAIWAN','330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 17:55:56',0,NULL,3,1,2,1,'、 ','sun-light108'),(3567,786275166012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',59,'eastar4','sharif_matadar','matadar@bell.blackberry.net','Sharif Matadar','1070 Kos Blvd','Mississauga','ON','CANADA','L5J4L6','(905) 609-6969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:18:42',0,NULL,3,1,3,1,'RA117731761CN ','sharif_matadar\rKBFF001'),(3568,707934877011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','tsavdhm_123','tsavdhm@yahoo.gr','DIMITRIOS TSAVTARIDIS','111 PTERYGA MAXHS','NEA AGHIALOS','MAGNISIAS','GREECE','37400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:40:33',0,NULL,3,1,2,1,'、 ','tsavdhm_123\r欧标'),(3569,707942347011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','martinh85','3dcoder@gmail.com','Martin Hoffesommer','3246 Deluna Dr','Rancho Palos Verdes','CA','UNITED STATES','90275-6264','(310) 377-1348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 18:55:49',0,NULL,3,1,1,1,'、 ','martinh85'),(3570,786298013012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',44.23,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:00:46',0,NULL,3,1,3,1,'RA117727047CN ','i.gabunia\r\r一共买了\r\r（1）一个New genuine Intel WiMAX 6250 622AGXHRU wifi\r（2）一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r（3）一个 NEW Sierra WWAN MC8781  +3G antenna\r（4）一个IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781\r（5）两个Bracket of half intel 5300 6250 wireless card to pci-e\r\r\r'),(3571,786314110012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',60.98,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:24:45',0,NULL,8,0,17,0,NULL,'i.gabunia'),(3572,786330302012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','sekkebek100','sekkebek@hotmail.com','Jens Kristian Wikstøl','Sentrum','Hægeland','Vest-Agder','NORWAY','4720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:56:32',0,NULL,3,1,3,1,'RA117733317CN ','sekkebek100\rHSSH001'),(3573,786335521012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','eastale818','dpmeng@hotmail.com','da meng','8508 Frandsen St','San Gabriel','CA','UNITED STATES','91776-2020','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 20:03:43',0,NULL,3,1,1,1,'、 ','eastale818\r红边优联'),(3574,786341721012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','sirlonramos','sirlonbaixo@hotmail.com','Amando Ramos','Rua Fortaleza qd 29 lt 03<br>Jd das Esmeraldas','Aparecida de Goiânia','Goias','BRAZIL','74905060','6281275304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:24:23',0,NULL,3,1,3,1,'RA117733382CN ','sirlonramos\rHSSH001'),(3575,786362400012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','jc.berna525','joao.carlos@giacomini.net.br','Joao Carlos Giacomini','R. Antonia Bizarro, 70<br>apto 112','Osasco','São Paulo','BRAZIL','06083-160','55 11 99530714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:59:17',0,NULL,3,1,3,1,'RA117733453CN ','jc.berna525\rHSPL010'),(3576,786365527012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','dwagner222','dave.wagner.art@gmail.com','David Wagner','275 Sprowl Creek Rd','Garberville','CA','UNITED STATES','95542-3305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 21:03:57',0,NULL,3,1,1,1,'、 ','dwagner222'),(3577,786324592012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','gushart','ghartmann2@gmail.com','Cory Hartmann','904 Harrison Ave','South Bend','IN','UNITED STATES','46616-1217','(512) 826-1765','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 21:18:43',0,NULL,3,1,1,1,'、 ','gushart\r红边优联'),(3578,534889623004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','hofharili','harald.hofstadler@liwest.at','Harald Hofstadler','Peuerbachstr. 23','Linz','','AUSTRIA','4040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:46:18',0,NULL,3,1,3,1,'RA117733405CN ','hofharili\rHSNO022\r欧标\r'),(3579,708022898011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','januzi.2009','gani.januzi@hotmail.co.uk','gani januzi','129 blenheim court<br>navestock crescent','woodford green','Essex','UNITED KINGDOM','ig8 7bb','07930416324','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:53:55',0,NULL,3,1,3,1,'RA117733351CN ','januzi.2009\rUDAP001\r'),(3580,671986508001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',78.95,'buysia','pele10eng','pele10eng@hotmail.com','Vladislav Petkovic','3214 Hornbeam Crescent','Mississauga','ON','CANADA','L5L 1B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:55:01',0,NULL,3,1,3,1,'RA117733334CN ','pele10eng\rOTSO001'),(3581,708024044011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:57:03',0,NULL,8,0,17,0,NULL,'i.gabunia'),(3582,708024759011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','buildandtest','kkyip1@gmail.com','Kenneth Yip','45 E 89th St<br>Apt 32B','New York','NY','UNITED STATES','10128-1231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 22:01:50',0,NULL,3,1,1,1,'、 ','buildandtest'),(3583,786417303012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',158.99,'eastar4','tex_rasco','mtr_rasco@yahoo.com','Mike Rasco','476 NW County Road 3140','Purdon','TX','UNITED STATES','76679-3049','(254) 578-3878','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 23:43:40',0,NULL,3,1,1,1,'、 ','tex_rasco'),(3584,581503173013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','amanda112699','almad_2003@yahoo.com','almadelia escobar','5328 monterey rd suite c','san jose','CA','UNITED STATES','95111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 00:19:27',0,NULL,3,1,1,1,'\\ ','amanda112699'),(3585,708060766011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','pete7476','ben1297@cox.net','Ben Owen','452 Fort Worth ST','Hampton','Va','UNITED STATES','23669','(757) 851-3702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 00:22:36',0,NULL,3,1,1,1,'、 ','pete7476'),(3586,581505834013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','cheeho04','cheeho04@yahoo.com','Chee Ho Wong','A17<br>212 State Highway 17','Albany','Auckland','NEW ZEALAND','0632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:34:19',0,NULL,3,1,3,1,'RA117733440CN ','cheeho04\rBAZA001\r'),(3587,786480133012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','ahmedk3333','koitas2000@yahoo.com','AHMED KOITA','2100 Tiebout Ave<br>Apt 403','bronx','NY','UNITED STATES','10457-3162','(718) 295-6867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 03:57:08',0,NULL,3,1,1,1,'、 ','ahmedk3333\r单机 发之前好好测试'),(3588,708127911011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','caxe13','caxe13@yahoo.com','Tommy Honton','1411 W Kenneth Rd #A','Glendale','CA','UNITED STATES','91201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 05:58:01',0,NULL,3,1,1,1,'\\ ','caxe13'),(3589,708138326011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','arveni85','arven_c@hotmail.com','arven cuko','Rr.\"Kongresi Manastirit\" Internet Cajupi perball shkolles Cajupi','tirane','tirane','ALBANIA','00000','00355672159964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 06:51:35',0,NULL,3,1,2,1,'、 ','arveni85'),(3590,708140067011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',2,'ANTY001*3',7.16,'eastar4','max12365','malhashem111@gmail.com','Mahmoud A Alhashem','3375 SE Shoreline Dr','Corvallis','OR','UNITED STATES','97333-3197','(541) 602-7780','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 07:00:26',0,NULL,3,0,1,1,'、 ','max12365'),(3591,708141645011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',267.98,'eastar4','055saxon','macandjo4@bigpond.com','Ross Mckinnon','22 Brotherglen drive','Kew','New South Wales','AUSTRALIA','2439','0265590296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:07:46',0,NULL,3,1,6,1,'EE520583321CN ','055saxon\r'),(3592,708146270011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ldk-xz','hw@hw-computer.de','Harry Weber','Solmserstr. 6','Waldsolms','','GERMANY','35647','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:30:39',0,NULL,3,1,2,1,'\\ ','ldk-xz'),(3593,784737853012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',26,'eastar4uk','kicsishaman','vidaj@tvnetwork.hu','Vida János','Kecskeméti utca 1','default','','HUNGARY','6723','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 08:06:25',0,NULL,3,1,3,1,'RA117727775CN ','kicsishaman\rWWSI002+ANCN001\r'),(3594,581574313013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','jrudnickis','j.rudnickis@clear.net.nz','FOR JURIJS RUDNICKIS (TO COLLECT)','C/O NZ POST SHOP MIRAMAR<br>67 MIRAMAR AVENUE, MIRAMAR','WELLINGTON 6022 (027) 2976341','NORTH ISLAND, NEW ZEALAND','NEW ZEALAND','6022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:11:02',0,NULL,3,1,2,1,'\\ ','jrudnickis'),(3595,526699965003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','2682ensor','j.gettmann@web.de','johannes Gettmann','Benzweg 5','Darmstadt','','GERMANY','64293','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:11:23',0,NULL,3,1,3,1,'RA117727095CN ','2682ensor\rMOSA002\r'),(3596,786537793012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','mpr312kadir','bympr312@hotmail.com','kadir dinçer','Yenibağlar mah<br>Ömür Sok No: 17','BURSA','osmangazi / BURSA','TURKEY','16160','5345991392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:34:54',0,NULL,3,1,2,1,'\\ ','mpr312kadir'),(3597,581579085013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','connectic','connectic7@gmail.com','Andrei Janajev','Katleri 17- 73','Tallinn','Haarjumaa','ESTONIA','13915','+37255545416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:42:00',0,NULL,3,1,2,1,'\\ ','connectic\r黑色的'),(3598,708166426011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','stevestr1ke','stevestr1ke@yahoo.com','Steve Strykowski','69 Merrimac St','Laconia','NH','UNITED STATES','03246-3864','(603) 738-0544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 09:03:21',0,NULL,3,0,1,1,'、 ','stevestr1ke'),(3599,786545306012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','s.kamenskih','skamenskih@gmail.com','Sergey Kamenskikh','Leninskij pr., d. 79, k.2, kv. 318','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','(921) 9464710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 09:06:39',0,NULL,3,1,2,1,NULL,'s.kamenskih\\'),(3600,708185180011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','jamusjae','jamusjae@talk21.com','jamus wood','240 mina road<br>st werburghs','Bristol','Bristol','UNITED KINGDOM','BS29YP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:28:13',0,NULL,3,1,3,1,'RA117727268CN ','jamusjae\rMOAP001'),(3601,786578729012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','tommi123_37','tommi123_37@hotmail.com','Tommy Nichols','31 Bourne drive<br>Langley Mill','Nottingham','Nottinghamshire','UNITED KINGDOM','NG164BJ','07511156471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:11:54',0,NULL,3,1,2,1,'\\ ','tommi123_37'),(3602,784946594012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','leventsd11','levent.dikmen@deu.edu.tr','levent Dikmen','Dokuz Eylul Univercity IIBF Bilgi Islem<br>Dokuzcesmeler - Buca','IZMIR','','TURKEY','35124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:12:40',0,NULL,3,1,2,1,'\\ ','leventsd11'),(3603,708221743011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','sell_stuff_today','plewis00_uk@yahoo.co.uk','Peter Lewis','BPD, 1 The Belfry<br>4400 Parkway','Whiteley','Hampshire','UNITED KINGDOM','PO15 7FJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:41:23',0,NULL,3,1,2,1,'\\ ','sell_stuff_today'),(3604,581628685013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','secodu','g.raichev@gmail.com','George Raichev','3 Kraishte str.<br>Rozeli cofee shop','Sofia','Bulgaria','BULGARIA','1504','359 895 655 555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 13:12:54',0,NULL,3,1,2,1,' \\','secodu'),(3605,581638163013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',27,'eastar4','sergifcsergio','sergifc@gmail.com','sergio cavaco','rua aquiles monteverde n28 6dto','Lisboa','Lisboa','PORTUGAL','1000-018','961128652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 13:53:47',0,NULL,3,1,2,1,'\\ ','sergifcsergio\r一共买了两个\r欧标'),(3606,581639286013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','andru*2011','andru6a@bk.ru','Andrey Nikishin','Sheremetievskaya 19-2-149','Moscow','Moscow','RUSSIAN FEDERATION','127521','+79031059699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 14:05:26',0,NULL,3,1,2,1,'\\ ','andru*2011'),(3607,581649904013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','servingthecreator08','rdrye78@yahoo.com','Dottie Rye','676 Durham Rd','Adams','TN','UNITED STATES','37010-9007','(931) 933-5600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 14:43:15',0,NULL,3,1,1,1,'\\ ','servingthecreator08'),(3608,786647204012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','joejoe803','oliver.joe64@yahoo.com','joe oliver','3665 heritage ct','oxford','NC','UNITED STATES','27565-6512','(803) 460-0313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 14:50:43',0,NULL,3,1,1,1,'\\ ','joejoe803'),(3609,786663701012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','perchiehouse','islander@ntlworld.com','nicholas friendlay','51, Sidney Rd','Walton-On-Thames','Surrey','UNITED KINGDOM','KT12 2LZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 15:27:23',0,NULL,3,1,3,1,'RA117727271CN\r ','perchiehouse\rHSPL010\r英标'),(3610,786667575012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','nhritz','nhritz@hotmail.com','Nick Hritz','606 Rittenhouse St NW','Washington','DC','UNITED STATES','20011-1239','(571) 232-9152','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:38:45',0,NULL,3,1,1,1,'\\ ','nhritz'),(3611,708279508011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.95,'eastar4','risingsn','tony@risingsuntechnologies.com','Tony Davis','7524 Baird Way','Citrus Heights','CA','UNITED STATES','95610','(916) 485-2998','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:39:50',0,NULL,3,1,1,1,'\\ ','risingsn'),(3612,786673015012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',47.8,'eastar4','wozniakr','robert11415@gmail.com','Robert Wozniak','8110 135th St<br>Apt 519','Briarwood','NY','UNITED STATES','11435-1048','(718) 825-4796','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 15:52:34',0,NULL,3,1,1,1,'\\ ','wozniakr\r一共买了两个'),(3613,708305228011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',25.96,'eastar4','enescobedo','enrique_escobedo@transalta.com','Enrique Escobedo','4501B Golf Course Road Apt 309','Stony Plain','AB','CANADA','T7Z2N4','(780) 499-8951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 16:52:13',0,NULL,3,1,2,1,'\\ ','enescobedo\r一共买了两个'),(3614,705413516011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','sdodang15','sdodang@online.fr','DO Dang Son','25 rue Pasteur','BRUNOY','Essonne','FRANCE','91800','0688071814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 17:02:17',0,NULL,3,1,3,1,'RA117727413CN\r ','sdodang15\rRCLO007+POLO001+RCLO008*4'),(3615,786711192012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','foxhound27','ivt@georgetown.edu','Ivo Tchernev','8727 Harding','Skokie','IL','UNITED STATES','60076','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 17:28:29',0,NULL,3,1,1,1,'\\ ','foxhound27'),(3616,786721271012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','hoveringmallard','gaviens@gmail.com','Gerard Viens','645 Flagstaff Drive','Wyoming','OH','UNITED STATES','45215','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 17:46:51',0,NULL,3,1,1,1,'\\ ','hoveringmallard'),(3617,581711668013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','napple252','ncapple24@yahoo.com','DEBBIE BAGGETT','148 Godwin Town Rd','AHOSKIE','NC','UNITED STATES','27910-9455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 18:27:55',0,NULL,3,1,1,1,'\\ ','napple252'),(3618,786745065012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','boubeth','litteautr@gmail.com','Robin LITTEAUT','12 Avenue Auguste Renoir','Marly le roi','Ile-de-France','FRANCE','78160','+33670894638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 18:37:47',0,NULL,3,1,2,1,'\\ ','boubeth'),(3619,581716163013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',12.43,'eastar4','molacacho','valverman@hotmail.com','Jesus Valverde Romero','C/ Pensamiento, 27, esc. dcha. 7º 1','Madrid','Madrid','SPAIN','28020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 18:42:48',0,NULL,3,1,2,1,'\\ ','molacacho\racer 8pin1.0 3cm'),(3620,708356237011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',28.49,'eastar4','glen5958','steyn01@hughes.net','Glen Steyn','15844 Lambert Rd','Saint Marys','OH','UNITED STATES','45885-9202','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 18:58:15',0,NULL,3,1,1,1,'\\ ','glen5958'),(3621,581726279013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',1,'RELE001',9.45,'eastar4','matfaub','matfaubert@hotmail.com','Mathieu  Faubert','16585 ave Lajoie','Saint-Hyacinthe','QC','CANADA','J2T3J7','(450) 768-4747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:11:47',0,NULL,3,1,2,1,'\\ ','matfaub'),(3622,708366741011,320552968178,'New Motorola HS810 Bluetooth Wireless Headset HS-810',1,'HSMO017',20.99,'eastar4','agekai','hermann.foester@versanet.de','Föster Hermann','Rebell 12','Meschede','','GERMANY','59872','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:22:19',0,NULL,3,1,2,1,'\\ ','agekai\r欧标'),(3623,581732736013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','csrcarlson','tom@nmpcmd.com','tom carlson','344 aliso dr ne','albuquerque','NM','UNITED STATES','87108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 19:34:46',0,NULL,3,1,1,1,'\\ ','csrcarlson'),(3624,708379279011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',1,'GLSG003',89,'eastar4','lombricultura0','jmmatiu@hotmail.com','Juan Monserrat','Dean Funes 226<br>Castelar','Buenos Aires','Buenos Aires','ARGENTINA','1712','1561477848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 19:52:50',0,NULL,3,1,3,1,' RA117727360CN\r','lombricultura0\rGLSG003'),(3625,581741731013,230545855021,'2.1 Acer TM 3000 3020 /AS5760 Bluetooth Module+cable',1,'BTAC2126',12.43,'eastar4','raponchito','jc.naranjo@terra.es','Jair Naranjo','C/ Leon y Castillo, 128 - Local Comercial','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 20:00:41',0,NULL,3,1,2,1,'\\ ','raponchito\racer 8pin1.25 10cm '),(3626,786807849012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',129.69,'eastar4','draken177','lukasmbm@hotmail.com','Lucas Bezerra','Avenida Ailton Gomes, 3204','Juazeiro do Norte','Ceará','BRAZIL','63020-000','88-35713708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 20:49:16',0,NULL,3,1,3,1,'RA117727444CN\r ','draken177\r再发一个New in box genuine SONY 3D Active Glasses TDG-BR100'),(3627,786817200012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','grayle70','pilgrim7000@gmail.com','Jerry  San Jose','2126 Glenbrook Ave','Camarillo','CA','UNITED STATES','93010-1926','(805) 987-1179','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:10:04',0,NULL,3,1,1,1,'\\ ','grayle70\r红边优联'),(3628,786824704012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','organphil','philipbrk584@gmail.com','Philip Burke','202 Misty Point Ln','Newport News','VA','UNITED STATES','23603-1441','(757) 369-0693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:28:41',0,NULL,3,1,1,1,'\\ ','organphil\r红边优联'),(3629,708432044011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','tigersbd','masudy2k@hotmail.com','Masud Rahman','909 Laurel Meadow Dr','FORT MILL','SC','UNITED STATES','29708-7891','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 21:59:36',0,NULL,5,0,18,0,NULL,'tigersbd\r已经退款'),(3630,581780419013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','d12aurorarichard','d12aurora@hotmail.com','Richard Desruisseaux','PO Box 292<br>9 Birch st','Greenwood','NS','CANADA','B0P1N0','(902) 840-0814','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'d12aurorarichard'),(3631,581781638013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','hrissan','hrissan@mail.ru','Grigory Buteyko','Sadovaya 90 kv 10','Sankt-Peterburg','','RUSSIAN FEDERATION','190121','+7(921)986-93-21','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 22:30:04',0,NULL,3,1,2,1,'\\ ','hrissan'),(3632,786871697012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','yvette-b','yvettebonnet@hotmail.com','Yvette Bonnet','16301 Englewood Ave','Los Gatos','CA','UNITED STATES','95032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:08:11',0,NULL,3,1,1,1,'\\ ','yvette-b'),(3633,535188690004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','viensm','marcviens@videotron.ca','Marc Viens','1477 Louis-Francoeur','Québec','QC','CANADA','g1y 1n7','(418) 653-7012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 00:14:43',0,NULL,3,1,3,1,'RA117727285CN ','viensm\rOTGR002'),(3634,708466208011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','austink','laustinthought@gmail.com','Austin Karpola','1438 N Greenview Ave<br>Frnt 3F','Chicago','IL','UNITED STATES','60642-6784','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:19:26',0,NULL,3,1,1,1,'\\ ','austink'),(3635,786879987012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','ericf9385','efx88@sbcglobal.net','Mary Eilzabeth Pettinelli','7123 N Paulina St<br>Apt 3N','Chicago','IL','UNITED STATES','60626-2550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:48:17',0,NULL,3,1,1,1,'\\ ','ericf9385'),(3636,786881635012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','arpi','rpvarga@msn.com','Arpad Varga','139 S 100 E','American Fork','UT','UNITED STATES','84003','(801) 756-5099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 00:51:00',0,NULL,3,1,1,1,'\\ ','arpi'),(3637,708483414011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','pig_meat','nickpotter@netspace.net.au','Nicholas Potter','PO Box 2064','Fitzroy M.D.C.','Victoria','AUSTRALIA','3065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:42:14',0,NULL,3,1,2,1,'\\ ','pig_meat'),(3638,786894036012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','m0rd0','nat@manic-cabbage.com','Nathanael Dyke','Hewlett Packard, Bld 1<br>Longdown Avenue, Stoke Gifford','Bristol','Avon','UNITED KINGDOM','BS34 8QZ','07747467457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:45:38',0,NULL,3,1,2,1,'\\ ','m0rd0\racer 8pin1.00 8cm'),(3639,786895460012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','walleyenutts','timkluss007@yahoo.com','Tim Kluss','405 Markham Rd','Eagle','WI','UNITED STATES','53119-2207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 01:57:40',0,NULL,3,1,1,1,'\\ ','walleyenutts'),(3640,535203624004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.79,'cnfaner','auctionmaster111','auctionmaster111@gmail.com','Wing Lau','68 Warraroong Street','Beverly Hills,  Sydney','New South Wales','AUSTRALIA','2209','0411253710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 02:00:23',0,NULL,3,1,3,1,'RA117727299CN\r ','auctionmaster111\rBALO007'),(3641,581686472013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',2,'BTHP2107',24.86,'eastar4','rccomputer33','rcraney@live.com','Richard Raney','PO Box 1881<br>112 Ohio','Bloomfield','NM','UNITED STATES','87413-1881','(505) 860-5225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 04:29:01',0,NULL,3,1,1,1,'\\ ','rccomputer33\rHP 8pin 1.0 23cm '),(3642,535226855004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','geduc2010','gatucristian@yahoo.com','Gatu Cristian','Stefan cel mare, 199, E, 13','Vaslui','Vaslui','ROMANIA','730006','+40335401562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 05:03:38',0,NULL,3,1,3,1,'RA117727325CN\r ','geduc2010\rHSPL001'),(3643,786936298012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','caitudo74','molotov1976@yahoo.com','Cesar Lopez','952 east 112th st','Los Angeles','CA','UNITED STATES','90059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:27:50',0,NULL,3,1,1,1,'\\ ','caitudo74'),(3644,786936769012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','ramiro123','ramirofuentes@msn.com','Ramiro Fuentes','14787 Valley View Dr','Mount Vernon','WA','UNITED STATES','98273-3279','(360) 848-1625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:28:54',0,NULL,3,1,1,1,'\\ ','ramiro123'),(3645,581845412013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',11.9,'eastar4','amy*eden','amyeden30@yahoo.com','Amy Eden','12200 Newgard ave','Sylmar','CA','UNITED STATES','91342-5059','(818) 675-6648','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 05:45:04',0,NULL,3,1,1,1,'\\ ','amy*eden'),(3646,786949244012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','tiasaff','tiasaff@ntlworld.com','debbie marchant','130 coventry road','ilford','Essex','UNITED KINGDOM','ig1 4rg','02082205626','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 06:35:00',0,NULL,3,1,3,1,'RA117727166CN ','tiasaff'),(3647,581852957013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',14.99,'eastar4','rafalow','rafalow@zonnet.nl','R Kuipers','dassenbos 116','Hoofddorp','Nh','NETHERLANDS','2134RH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 06:40:48',0,NULL,3,1,2,1,'\\ ','rafalow\r黑色的\r欧标'),(3648,708536144011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','francis9118','michellefrancis@wanadoo.fr','francis lempereur','50 rue Hallé','HAMEL','Nord-Pas-de-Calais','FRANCE','59151','0327922916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 06:54:23',0,NULL,3,1,2,1,'\\ ','francis9118'),(3659,581977065013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.97,'eastar4','firefighterjan','jan.rittierodt@gmx.de','Jan Christopher Rittierodt','Pillauer Straße 1','Kiel','','GERMANY','24149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 16:12:44',0,NULL,3,1,3,1,'RA117727149CN ','firefighterjan\rMOSA002'),(3649,581894673013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18.99,'eastar4','krimson_dk','jesper@krimson.dk','Jesper Kleis Jensen','Havdrupvej 26','Brønshøj','','DENMARK','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 10:51:40',0,NULL,3,1,2,1,'\\ ','krimson_dk'),(3650,708602408011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','dolphin270479','jazzy001@hotmail.co.uk','Christine Beman','34 Hillborough Road','Westcliff on Sea','Essex','UNITED KINGDOM','SS0 0SA','07970015387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 11:06:57',0,NULL,3,1,3,1,'RA117727254CN ','dolphin270479\rMOAP001'),(3651,581899232013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',107.97,'eastar4','huszar.adam','oregonlogos@gmail.com','Ádám Huszár','István 41','Gyöngyöstarján','Heves','HUNGARY','3036','+36204474046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:08:41',0,NULL,3,1,3,1,'RA117727183CN ','huszar.adam\rWWSI005'),(3652,581908345013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','danielelel27','bassindaniel@gmail.com','Daniel Bassin','Kibutz Kfar-aza 85142','Kfar-aza','ID','ISRAEL','85142','972506344103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:52:57',0,NULL,3,1,2,1,'\\ ','danielelel27'),(3653,708625595011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','amanolar','aristos@manolarakis.gr','Aristos Manolarakis','Odos Blyxadas<br>Pano apo tavern Haris','Kato Gouves','Heraklion Crete','GREECE','70014','00306944456620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 12:27:09',0,NULL,3,1,2,1,'\\ ','amanolar'),(3654,787061821012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jurica1976','jurica.stojkovic1@zg.t-com.hr','Jurica Stojkovic','Skolska 6','Novoselec','','CROATIA','10315','0912385194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 13:03:05',0,NULL,3,1,2,1,'\\ ','jurica1976\r欧标'),(3655,535270466004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','del1riouz','lipteh@usa.com','Lip Gen Teh','8 Nardina Crescent','Dalkeith','Western Australia','AUSTRALIA','6009','0893865263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 14:14:05',0,NULL,3,1,3,1,'RA117727245CN ','del1riouz\rOTGR001+OTGR002'),(3656,581945004013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','rajiv61','rajivpooja@yahoo.com','Rajiv Ramrakhiani','3611 Chimney Rock Dr','Carrollton','TX','UNITED STATES','75007-2785','(504) 355-9999','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 14:25:44',0,NULL,3,1,1,1,'\\ ','rajiv61'),(3657,708669236011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','hmadah','hmadah1384@hotmail.com','Hala Maddah','Flat 6, Watervale<br>Vale Farm Road','Woking','Surrey','UNITED KINGDOM','GU21 6AB','07882697666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 14:31:07',0,NULL,3,1,3,1,'RA117727395CN ','hmadah\rMOAP001'),(3658,708697363011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','isadore529','johneforges@hotmail.com','Johne Forges','12241 Fairfield House Dr<br>Apt 311','Fairfax','VA','UNITED STATES','22033-3954','(202) 746-6348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 15:38:07',0,NULL,3,1,1,1,'\\ ','isadore529'),(3660,529634440003,130490223099,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',22,'cnfaner','pugtastic','carterfickling@hotmail.com','Christopher Fickling','38 Clifford Ave','Welland','ON','CANADA','L3C2G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 16:18:59',0,NULL,3,1,3,1,'RA117727197CN ','pugtastic\rSCLO001'),(3661,787146598012,220502333735,'2.1 HP DV8000 DV8100 DV8200  Bluetooth Module+ cable',1,'BTHP2103',12.43,'eastar4','scerenity1','ruonline.now@frontier.com','David Brummond','Brummond Systems LLC<br>207 Thomson Ln','Oregon','WI','UNITED STATES','53575-3257','(608) 334-8150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 16:22:36',0,NULL,3,1,1,1,'\\ ','scerenity1\rHP 8pin 1.0 12cm '),(3662,582006699013,230543428190,'NEW Logitech lenovo dual-band Mini USB receiver MX3200',2,'RELE001',18.9,'eastar4','johe123','johe12@t-online.de','Hans-Joachim Hentschel','Fuldastr. 1-5<br>Fa.Cosy-Wasch am Ratiomarkt','BAUNATAL','','GERMANY','34225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 17:43:33',0,NULL,3,1,2,1,'\\ ','johe123'),(3663,708574561011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','duongnguyen1974','duongnguyen1974@yahoo.com','DYLAN  NGUYEN','5581 W 72nd Dr','WESTMINSTER','CO','UNITED STATES','80003-3300','(720) 536-8613','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 17:51:35',0,NULL,3,1,1,1,'\\ ','duongnguyen1974'),(3664,582013116013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','lowrange200004','lowrange200004@yahoo.com','jeffrey','220 oak st','knoxville','AR','UNITED STATES','72845-8906','(479) 747-8896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 18:04:21',0,NULL,3,1,1,1,'\\ ','lowrange200004'),(3665,708764989011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',12.5,'eastar4','r.dominick','ronnyhoth@web.de','Ronny Dominick','Am Scheunenviertel 27','Zossen','','GERMANY','15806','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 18:05:26',0,NULL,3,1,2,1,'\\ ','r.dominick\racer 4pin1.25 15cm '),(3666,708804297011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','iuzer46','iuzer@mail.ru','Антон Новиков','Пионеров 17, кв 144','Курск','','RUSSIAN FEDERATION','305001','(4712)310347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 19:34:11',0,NULL,3,1,2,1,'\\ ','iuzer46'),(3667,708816288011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','krem_de','krem@gmx.net','Martin Kreschel','Rastatter Straße 10a','Mannheim','','GERMANY','68239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 19:47:24',0,NULL,3,1,2,1,'\\ ','krem_de'),(3668,708816531011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','matanui09','karlo_hi@sbcglobal.net','Krystalene Manalo','161 W Victoria St<br>Ste 220','Long Beach','CA','UNITED STATES','90805-2169','(323) 440-6813','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 19:52:27',0,NULL,3,1,1,1,'\\ ','matanui09'),(3669,787256895012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','shopgodness','robinalexandra@hotmail.com','Heleen van Dam','Boeroestraat 13','Wormerveer','','NETHERLANDS','1521SJ','0651466804','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','shopgodness'),(3670,708821998011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','astajurg','alius.jurgelis@gmail.com','Asta Jurgeliene','Latviu 1-6','Joniskis','','LITHUANIA','84147','+370 685 58888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 19:57:07',0,NULL,3,1,2,1,'\\ ','astajurg'),(3671,787095543012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','pahardie','patrickahardie@gmail.com','Patrick Hardie','12 4940 39th Avenue SW','Calgary','AB','CANADA','T3E 6M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 19:59:10',0,NULL,3,1,2,1,'\\ ','pahardie'),(3672,787264463012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','yn.n','yosanan_n@yahoo.com','Yosanan Nanthiwatthanawong','132/12 M.15 Petchkasem 48 Rd., Bang Duan,<br>Phasichalaun','Bangkok','Bangkok','THAILAND','10160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 20:09:31',0,NULL,3,1,3,1,'RA117727135CN ','yn.n\rOTSO002'),(3673,708826625011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','bad-boy2k','bad-boy2k@web.de','Lars Brodersen','Pilgermannsweg 5','Dortmund','','GERMANY','44379','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 20:10:38',0,NULL,3,1,2,1,'\\ ','bad-boy2k'),(3674,787267739012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dickriegle','driegle@itwbcg.com','Richard Riegle','1713 Del Rancho Dr','Irving','TX','UNITED STATES','75061-2408','(817) 313-5298','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 20:16:22',0,NULL,3,1,1,1,'\\ ','dickriegle\r红边优联'),(3675,708855951011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','jf555555','jfdrmtl@hotmail.com','Jean-François Dumont-Roussin','16 Woodhaven','Dollard-Des-Ormeaux','QC','CANADA','H9B 1W4','(151) 468-3295 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 21:23:13',0,NULL,3,1,2,1,'\\ ','jf555555'),(3676,708765657011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','steven5223063','steven52230@hotmail.com','steven bedard','694 rue hoggar<br>quebec','quebec','QC','CANADA','g1b3e4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 21:43:57',0,NULL,3,1,2,1,'\\ ','steven5223063'),(3677,708882358011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','41shoreline','texas608@aol.com','Lana Craig','38 Shoreline Dr','Malakoff','TX','UNITED STATES','75148','(903) 489-2157','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 22:41:27',0,NULL,3,1,1,1,'\\ ','41shoreline'),(3678,582100095013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.5,'eastar4','yossi.2011','yossi.shargal@gmail.com','Yossi Shargal','4c Bosmat St. Apt. #6','Shoham','Israel','ISRAEL','60850','0546650698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 22:55:20',0,NULL,3,1,2,1,'\\ ','yossi.2011'),(3679,787342259012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','bassist-half','che_blaise@hotmail.com','Blaise Che','5936 E Constantine Rd','Anaheim','CA','UNITED STATES','92807-3912','(310) 710-4253','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 23:32:17',0,NULL,3,1,1,1,'\\ ','bassist-half'),(3680,582075818013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','rydep12','depewryan@yahoo.com','Ryan Depew','1900 22nd Ave SW','Willmar','MN','UNITED STATES','56201-4985','(320) 444-3262','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 23:34:23',0,NULL,3,1,1,1,'\\ ','rydep12'),(3681,582096383013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','wagner2af','afwagner@cummingutilities.com','Franklin Wagner','302 Jones St<br>Ste 403','Sioux City','IA','UNITED STATES','51101-1341','(712) 574-9161','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-14 23:41:34',0,NULL,3,1,1,1,'\\ ','wagner2af'),(3682,787346586012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','cyn19652','cyn19652003@yahoo.com','CYNTHIA SMITH','630 US HWY 21 SOUTH , P.O. BOX 686','RIDGEWAY','SC','UNITED STATES','29130','(803) 337-8979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 00:48:33',0,NULL,3,1,1,1,'\\ ','cyn19652'),(3683,535498205004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','jacky9142','jack.swank@aircanopy.net','Jacky Swank','3640 Willow Bend Ln','Midlothian','TX','UNITED STATES','76065-6341','(903) 880-5518','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 01:37:45',0,NULL,3,1,1,1,'\\ ','jacky9142'),(3684,708925314011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','trv_brin59','trv_brin@yahoo.com','travis brinson','1534 Antietam Dr<br>Unit 931','columbus','GA','UNITED STATES','31907-4723','(706) 536-5206','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 01:39:00',0,NULL,3,1,1,1,'\\ ','trv_brin59'),(3685,708929396011,320687842759,'New 2.8\" 4G LCD Touch Screen MP4+MP3+FM MEDIA PLAYER',1,'OTMP001',35.99,'eastar4','yamonserat','yaneto220@hotmail.com','yanett monserrat','61 Calle Ulises Ortiz<br>Jose Severo Quinones','carolina','PR','PUERTO RICO','00985-5654','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 01:55:10',0,NULL,3,1,1,1,'\\ ','yamonserat'),(3686,708938871011,320693988601,'New Replaceable Shell for logitech Mouse G500 G 500',1,'SHLO006',15.99,'eastar4','tgeh7369','lge49195@bigpond.net.au','Tim Gehrke','36 Huntingwood Drive','Huntingwood','New South Wales','AUSTRALIA','2148','0298880836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 02:37:42',0,NULL,3,1,2,1,'\\ ','tgeh7369'),(3687,787393203012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',4,'HSPL010',95.6,'eastar4','jimwatson42','jwatson42@email.com','jim watson','320 N Columbus #17','goldendale','WA','UNITED STATES','98620','(360) 521-2735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 02:47:07',0,NULL,3,1,1,1,'\\ ','jimwatson42'),(3688,787398579012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.43,'eastar4','hobbyloeter','do4hmj@online.de','Helfried Marter','August-Bebel-Platz 9','Ostseebad Kühlungsborn','','GERMANY','18225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 03:10:16',0,NULL,3,1,2,1,'\\ ','hobbyloeter\racer 8pin1.00 18cm '),(3689,708949417011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','eliypi','eliy.pi@gmail.com','eliypi','1/336 Weidner Crescent','East Albury','New South Wales','AUSTRALIA','2640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 03:34:10',0,NULL,3,1,2,1,'\\ ','eliypi'),(3690,535516555004,140482241514,'New Genuine Motorola H670 Bluetooth Headset track#',1,'HSMO010',14.99,'cnfaner','stephens1105','stephen1105@yahoo.com','Stephen Steeneck','2676 Old Yorktown Rd','Yorktown Heights','NY','UNITED STATES','10598-3139','(914) 302-6965','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 03:41:04',0,NULL,3,1,1,1,'\\ ','stephens1105'),(3691,708952582011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','nuangquang','cli107@uottawa.ca','Chen Li','2211-180 LEES AVE.','Ottawa','ON','CANADA','K1S5J6','(613) 513-8250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 03:51:04',0,NULL,3,1,2,1,'\\ ','nuangquang'),(3692,787425795012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','www-jfin-biz','jeff@finlay.info','Jeff Finlay','1218 Salazar Trl','San Antonio','TX','UNITED STATES','78216','(210) 764-1575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 05:33:45',0,NULL,3,1,1,1,'\\ ','www-jfin-biz'),(3693,582055976013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','basti9877','basti.s77@gmx.de','SEBASTIAN SOWKA','Am Dahlhof 80','hamm','','GERMANY','59075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 06:04:20',0,NULL,3,1,2,1,'\\ ','basti9877'),(3694,787434106012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',11.9,'eastar4','clm0873','christark71@yahoo.com','Christina McLain','3026 Hickory Bluff Rd','Sapulpa','OK','UNITED STATES','74066-8596','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 06:19:23',0,NULL,3,1,1,1,'\\ ','clm0873'),(3695,787435376012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','zuwinnie','zuwinni@gmail.com','Nicky Bok','534 Altino Blvd','San Jose','CA','UNITED STATES','95136-4833','(408) 264-6183','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 06:23:46',0,NULL,3,1,1,1,'、 ','zuwinnie'),(3696,709017926011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','ashwin3011','ash.pro2011@gmail.com','ashwin shewnarain','vaudagne road','Bambous','Black River','MAURITIUS','+230','7088147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 08:52:32',0,NULL,3,1,2,1,'\\ ','ashwin3011'),(3697,708878753011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','vjpca1','vjpca@bellsouth.net','Vince  J Portera','1390 Crevalle Ave','Merritt Island','FL','UNITED STATES','32952-5785','(321) 452-2520','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 10:10:11',0,NULL,3,1,1,1,'\\ ','vjpca1'),(3698,709077701011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','bungl','blitekjc@free.fr','blitek jean christophe','12 rue de la bequette','masny','Nord-Pas-de-Calais','FRANCE','59176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 11:25:39',0,NULL,3,1,3,1,'RA117727206CN ','bungl\rHSPL009\r欧标'),(3699,787567147012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','luxuly','jontue@empas.com','Young Lee','108-404. Shinil Utovile APT. 55-4.<br>Howon-Dong','Uijeongbu','Kyunggi-Do','KOREA,REPUBLIC OF','480-917','+82-2-943-6541','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 12:15:10',0,NULL,3,1,2,1,'\\ ','luxuly'),(3700,709098888011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','table1974','strimbeanum@yahoo.com','MARIUS STRIMBEANU','STR. GEORGE ENESCU, BL.200 J1, SC.1, AP.3','CRAIOVA','DOLJ','ROMANIA','200710','0040761126366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 12:17:20',0,NULL,3,1,3,1,'RA117727387CN\r ','table1974\rGLSG001*2'),(3701,787569980012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','davtjon03','davjon@gmail.com','David Jones','5 Twineham Green<br>Woodside Park','London','London','UNITED KINGDOM','N12 7ER','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 12:20:37',0,NULL,3,1,2,1,'\\ ','davtjon03'),(3702,787576194012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','maverickmatt','mattimatico@hotmail.com','Matthew Richardson','3 Thornhill Road','London','London','UNITED KINGDOM','N1 1HX','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'maverickmatt'),(3703,582267177013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',21.99,'eastar4','reality-maker','victorovcharenko@gmail.com','Viktor Ovcharenko','342 Riding Rd','Balmoral','Queensland','AUSTRALIA','4171','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 12:52:41',0,NULL,3,1,2,1,'\\ ','reality-maker'),(3704,787585127012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',5,'HSSE005',69.5,'eastar4uk','bogunovic46','zulee46@yahoo.com','Milos Djuric','Balkanska 12','Belgrade','Serbia','SERBIA','11000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 12:56:45',0,NULL,3,1,3,1,'RA117727400CN ','bogunovic46\rHSSE005\r欧标'),(3705,529911915003,130490602150,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',31.98,'cnfaner','r_mihail','raznitsin@yandex.ru','Mihail Raznitsin','str. Krasnij Majak, bld. 13A-1, flat 125.','Moscow','','RUSSIAN FEDERATION','117570','387-72-46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 13:16:51',0,NULL,3,1,3,1,'RA117727311CN\r ','r_mihail\rWLIN004'),(3706,709126487011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','ultimatekenz','kenny.huynh@live.com.au','Kenny Huynh','9 Whitewood Place','Molendinar','Queensland','AUSTRALIA','4214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 13:19:34',0,NULL,3,1,3,1,'RA117727373CN ','ultimatekenz\rGLSG001'),(3707,582301376013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.43,'eastar4','bbh3838','delhorme.claude@free.fr','Delhorme Claude','3, les Petites Chaumes','Ruy','Rhône-Alpes','FRANCE','38300','04.74.21.23.12.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 14:32:44',0,NULL,3,1,2,1,'\\ ','bbh3838\rHP 8pin 1.0 23cm '),(3708,787639136012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','shaikandleker','shaikn@gmail.com','pini zkhariya','tzahal 4/10 b','ramle','','ISRAEL','72326','972546671269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 14:38:36',0,NULL,3,1,2,1,'\\ ','shaikandleker'),(3709,787657539012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','musicdes','musicdes@coqui.net','EDGARD NEVAREZ','URB CAPARRA HTS<br>609 CALLE ESTONIA','San Juan','PR','UNITED STATES','00920-4713','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 15:07:59',0,NULL,3,1,1,1,'\\ ','musicdes\r '),(3710,582327346013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','matangeva','elementewfw@gmail.com','Matan Geva','Kaplan 8<br>8','azor, israel','','ISRAEL','58015','0523136655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 15:35:47',0,NULL,3,1,2,1,'\\ ','matangeva'),(3711,709222566011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','b12doxi','kucher04@yahoo.com','Michael A Kucher','4 Christopher St','Port Jervis','NY','UNITED STATES','12771-3705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 16:08:43',0,NULL,3,1,1,1,'\\ ','b12doxi'),(3712,787699680012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4uk','bodek-1','bodo@onet.pl','Bogdan Lipski','68 Belleville<br>Blackhorse Avenue','Dublin','Dublin','IRELAND','D7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 16:09:14',0,NULL,3,1,3,1,'RA117727308CN\r ','bodek-1\rOTCN001'),(3713,535712084004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','kirill.k2','k2@id.ru','Kirill Kozlovskiy','Lobachevskogo, 74, kv.17','Moscow','','RUSSIAN FEDERATION','119454','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 16:46:58',0,NULL,3,1,3,1,'RA117727210CN\r ','kirill.k2\rWLAT001+ANTY002'),(3714,709272296011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','ruk110','ruk1987@gmail.com','Rukmin Gohel','9 Kilmelford Close','LEICESTER','Leicestershire','UNITED KINGDOM','LE4 7YF','01162612406','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 17:14:18',0,NULL,3,1,3,1,'RA117727237CN ','ruk110\rMOAP001'),(3715,708977460011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',133.99,'eastar4','time*inc','johnny_time_@hotmail.com','john morana','1 Shaneen Blvd','Scarborough','ON','CANADA','M1R1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 17:18:51',0,NULL,3,1,3,1,'RA117727458CN\r ','time*inc\rGLSG001*2'),(3716,787891916012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','neilhar68','neil.harris@itcareuk.com','Neil Harris','6 Kestrel Crescent','Droitwich','Worcestershire','UNITED KINGDOM','WR9 7HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 19:26:50',0,NULL,3,1,3,1,'RA117727223CN\r ','neilhar68\rHSMO017\r英标'),(3717,787919977012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','j_bistretti','bistretti@gmail.com','Julia Bystrova','Oranienbaumskij pr. 43/1-28<br>Lomonosov','Saint Petersburg','Saint Petersburg','RUSSIAN FEDERATION','198412','79062255132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 19:57:58',0,NULL,3,1,2,1,'\\ ','j_bistretti\r红边优联'),(3718,787943621012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','matty1864','matthewhollas@yahoo.co.uk','matthew hollas','13 seaton terrace','irvine','North Ayrshire','UNITED KINGDOM','KA120ST','01294274670','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 20:26:45',0,NULL,3,1,3,1,'RA117727118CN ','matty1864\r英标\rHSMO014'),(3719,530134520003,130489927197,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',21.9,'cnfaner','pumiki','lamihai@gmail.com','lior amihai','aharon katzenelson 21/3','petach-tikva','','ISRAEL','49721','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 20:36:01',0,NULL,3,1,3,1,'RA117727121CN ','pumiki\rOTHP003\r'),(3720,787955923012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','forma81','tourism@mac.com','aj cookson','74 high street<br>ponders end','enfield','england','UNITED KINGDOM','en3 4er','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 20:42:42',0,NULL,3,1,2,1,'\\ ','forma81'),(3721,709471745011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','amarcol08-2009','amarcol08@gmail.com','Angel L. Martinez- Colon','Bo Islote II Calle 16 casa #438','Arecibo','PR','UNITED STATES','00612-5448','(787) 420-9733','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 21:03:01',0,NULL,3,1,1,1,'\\ ','amarcol08-2009\r无线蓝牙二合一'),(3722,787972679012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','keith405','ksenti@gmail.com','Keith Senti','11705 Ridge Pointe','Guthrie','OK','UNITED STATES','73044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 21:10:12',0,NULL,3,1,1,1,'\\ ','keith405\r红边优联'),(3723,787991088012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',258,'eastar4','iconic7677','danny@iconinteriors.net.au','gavin morley','12 bodkin st','kyneton','Victoria','AUSTRALIA','3444','0354211300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 21:44:37',0,NULL,3,1,4,1,'YW865907760CN ','iconic7677\r澳标'),(3724,787999092012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','toaohws','deputydroopy@gmail.com','H.W. Scholten','Nijlansdijk 85-d','Leeuwarden','','NETHERLANDS','8931ES','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 22:02:44',0,NULL,3,1,3,1,'RA117727152CN ','toaohws\rHSSE006\r'),(3725,582543990013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','guilhermeschaffer','guigo@gmx.de','Guilherme Carlos Schäffer','Rua Dr. Fritz Muller 1253, fundos da 1255','Blumenau','SC','BRAZIL','89031-620','047 8856-6269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 22:05:11',0,NULL,3,1,2,1,'\\ ','guilhermeschaffer'),(3726,788002361012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','killshere','kills-here@hotmail.com','KIllian Comerford','18 Mount eagle Lawn<br>Leopardstown Heights','Dublin','Dublin','IRELAND','18','0877246758','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 22:10:31',0,NULL,3,1,2,1,'\\ ','killshere'),(3727,788008543012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',2,'HSSH001',51.98,'eastar4','agad7033','isaac.gade@hotmail.com','Alexander Gade','301 Park 26th Street NW','Waverly','IA','UNITED STATES','50677','(319) 240-5511','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 22:25:13',0,NULL,3,1,1,1,'\\ ','agad7033'),(3728,709512600011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',2,'GLSG003',178,'eastar4','nboucher23','nclark@prtm.com','Nancy   Boucher-Clark','8 Candlewood Rd','Windham','NH','UNITED STATES','03087','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 22:33:29',0,NULL,3,1,1,1,'\\ ','nboucher23'),(3729,788012246012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','denniskeepitreal','dennismoore5826@yahoo.com','dennis moore','5826 longforest dr','houston','TX','UNITED STATES','77088','(281) 591-0819','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 22:37:29',0,NULL,3,1,1,1,'\\ ','denniskeepitreal'),(3730,788012995012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','eduardo_alvm','eduardo.alvm@gmail.com','Eduardo Alvarenga de Melo','Rua Jasmim 28 Ap1003 A<br>Ch. Primavera','Campinas','São Paulo','BRAZIL','13087460','1932966143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 22:39:52',0,NULL,3,1,2,1,'\\ ','eduardo_alvm'),(3731,709516406011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','mrwkim0','mrwkim@gmail.com','Wonkyu Kim','650 Wynn Dr NW APT 287','Huntsville','AL','UNITED STATES','35816','(256) 690-1014','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 22:45:05',0,NULL,3,0,1,1,'\\ ','mrwkim0'),(3732,582555099013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','krsjuan','krsjuan@gmail.com','fernando frausto','1201 russell st','la habra','ca','UNITED STATES','90631','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 22:45:52',0,NULL,3,1,1,1,'\\ ','krsjuan'),(3733,788023102012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','lowlar2011','lowlar2010@gmail.com','Lola Odufuye','19610 Mackinaw Isle Ct','Cypress','TX','UNITED STATES','77429-4347','(832) 752-4218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 23:07:04',0,NULL,3,1,1,1,'\\ ','lowlar2011'),(3734,788023940012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','lowlar2011','lowlar2010@gmail.com','Tracy Popoola','8313 Brentwood St','Rowlett','TX','UNITED STATES','75088-4772','(972) 412-9960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 23:10:08',0,NULL,3,1,1,1,'\\ ','lowlar2011'),(3735,582566338013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','moesob987','ebayking93@gmail.com','Mohamed  Sobhy','9120 Kedvale Ave','Oak Lawn','IL','UNITED STATES','60453-1917','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-15 23:31:24',0,NULL,3,1,1,1,'\\ ','moesob987'),(3736,788041990012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jrok83','larry925@gmail.com','larry richardson','9777 Good Luck Rd<br>Apt 9','lanham','MD','UNITED STATES','20706-3337','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 00:04:33',0,NULL,3,1,1,1,'\\ ','jrok83'),(3737,582582650013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','drvolcheck','drvolcheck@cox.net','tim volcheck','17908 Grenelefe Ave','Omaha','NE','UNITED STATES','68136-2139','(402) 212-7673','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 00:41:15',0,NULL,3,1,1,1,'\\ ','drvolcheck'),(3738,535926082004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','weekendgfr','kolivas@sbcglobal.net','Kevin Olivas','731 W Ashcroft Ave<br>(559) 347-0151','Clovis','CA','UNITED STATES','93612','(559) 940-2152','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 01:12:37',0,NULL,3,1,1,1,'\\ ','weekendgfr'),(3739,788072578012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','foobeca','lavin@byu.net','Jeff Lavin','PO Box 243583','Anchorage','AK','UNITED STATES','99524-3583','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 01:27:57',0,NULL,3,1,1,1,'\\ ','foobeca\r红边优联'),(3740,582598670013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','internews','edukinishi@gmail.com','Eduardo Inoue','Rua Nossa Senhora Aparecida, 588 - Vila Costa - Suzano-SP','Suzano','São Paulo','BRAZIL','08675-025','551192278689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 01:43:52',0,NULL,3,1,2,1,'\\ ','internews'),(3748,788140729012,220741062544,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'eastar4','heenavadgama','heena.vadgama@gmail.com','Heena Vadgama','336 GLASTONE AVENUE SOUTH<br>APT # 16','Yorkton','SK','CANADA','S3N3W3','(306) 818-0025','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 06:13:09',0,NULL,3,1,2,1,'\\ ','heenavadgama'),(3741,582617149013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','believenu77','empress2fine@cs.com','Samantha Moorer','251 Wisteria Dr','East Palo Alto','CA','UNITED STATES','94303-2615','(650) 269-1161','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 03:00:50',0,NULL,3,1,1,1,'\\ ','believenu77'),(3742,788115539012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','bronzelvr','sheridishman@yahoo.com','Sheri Dishman','5424 Silver Maple Ln','Fredericksburg','VA','UNITED STATES','22407','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 03:42:37',0,NULL,3,1,1,1,'\\ ','bronzelvr'),(3743,788116495012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','claudiupt','claudiupt@gmail.com','Petrisor Claudiu','str.Rapsodiei<br>no.15, ap.38','Cluj-Napoca','Cluj','ROMANIA','400359','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 03:46:34',0,NULL,3,1,2,1,'\\ ','claudiupt'),(3744,709608794011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','sivarudrappa','sivarudrappa_mahesh@hotmail.com','Sivarudrappa Mahesh','9952 228th Ter NE','Redmond','WA','UNITED STATES','98053-5852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 04:01:42',0,NULL,3,1,1,1,'\\ ','sivarudrappa'),(3745,709619438011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','mrh61','haskard@email.com','Mark Haskard','level 2 Tower A,  26 Talavera Rd','MACQURIE PARK','New South Wales','AUSTRALIA','2113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 05:02:42',0,NULL,3,1,4,1,'YW865907771CN ','mrh61\rEXLO001'),(3746,788133584012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','ericjosefsson','eric.josefsson@gmail.com','Eric Josefsson','Ringgatan 5','Skänninge','','SWEDEN','59632','+46702705174','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 05:11:06',0,NULL,3,1,2,1,'\\ ','ericjosefsson\r欧标'),(3747,582637604013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',60,'eastar4','andlcp','k.and3rson@gmail.com','Anderson L C Pereira','Rua Capim Branco, 32 Vila Valqueire','Rio de Janeiro','RJ','BRAZIL','21330050','78379578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 05:16:17',0,NULL,3,1,3,1,'RA117727705CN\r ','andlcp\rRCLO004'),(3749,788151263012,220759427760,'New Ralink RT2870F USB Adapter 300M replace WIS09ABGN',1,'OTRA001',25.59,'eastar4uk','philippec1615','philippe.charrier.2@cegetel.net','philippe charrier','le garafrent','lancon','Provence-Alpes-Côte d\'Azur','FRANCE','13680','0490428611','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 06:45:36',0,NULL,3,1,3,1,'RA117727501CN\r ','philippec1615\rOTRA001\r'),(3750,709642525011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','janh7973','j.andrea@hotmail.de','Jan Haug','Ufhoferstr. 33','Balingen-Zillhausen','','GERMANY','72336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 07:09:34',0,NULL,3,1,2,1,'\\ ','janh7973\racer 5pin1.25 4cm'),(3751,709646666011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','girishmadan','girishmadan1@yahoo.com','girish madan','1/63 Bevan Avenue','Clayton South','Victoria','AUSTRALIA','3169','61402708784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 07:34:15',0,NULL,3,1,2,1,'\\ ','girishmadan\r澳标'),(3752,582661457013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','fyodorstanislavovich2011','fred1984@yandex.ru','Fyodor Stanislavovich Zaikin','Yarega, Neftyanikov 6-4','Ukhta','KOMI','RUSSIAN FEDERATION','169347','+79505694181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 08:13:19',0,NULL,3,1,3,1,'RA117727617CN\r ','fyodorstanislavovich2011\rOTRA001\r'),(3753,708712207011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.96,'eastar4','a2zbeesness247','biothebest@me.com','benadim abdelaziz','17 Oberferst St','liberty','NY','UNITED STATES','12754-1809','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 08:44:53',0,NULL,3,1,1,1,'\\ ','a2zbeesness247'),(3754,788189310012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','swad9389','sahil_wadhwa90@yahoo.com','Sahil Wadhwa','363 Ryrie Street','Geelong','Victoria','AUSTRALIA','3220','0061430079252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 09:33:18',0,NULL,3,1,2,1,'\\ ','swad9389\r红边优联'),(3755,786923797012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','kecakk','ruzaini@operamail.com','Sadiah Shamsuddin','Level 4, Block E 4/5, Government Complex Parcel E,<br>Federal Government Administrative Centre,','Putrajaya','Putrajaya','MALAYSIA','62668','0126151280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 09:36:46',0,NULL,3,1,3,1,'RA117733569CN\r ','kecakk\rHSSE006'),(3756,709133490011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',6.6,'eastar4uk','mightythorpe','david@cyberium.co.uk','Beatrice Adam','3 Penpound Lane<br>Llandybie','Ammanford','Carmarthenshire','UNITED KINGDOM','SA18 3JF','07901925671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 09:50:31',0,NULL,3,1,3,1,'RA117733590CN\r ','mightythorpe\rWLAP004'),(3757,530292362003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',27.16,'cnfaner','verito18','maquino2391@hotmail.com','Manuel Aquino Oliva','116 Seneca Chase Ct','Sterling','VA','UNITED STATES','20164-5519','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 10:05:41',0,NULL,3,1,1,1,'\\ ','verito18'),(3816,786478441012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',52.2,'eastar4','nomel28','gangamartial@aol.com','Martial GANGA','210 ufton court<br>Canberra Drive','Northolt Middesex','Middlesex','UNITED KINGDOM','UB5 6JQ','07933934488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 09:44:43',0,NULL,3,1,3,1,'RA117726951CN ','nomel28\rCAB-6060\rCASS003'),(3758,709718411011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',15.9,'eastar4','mbmilescu','mb.milescu@gmail.com','Milescu Marius-Bogdan','Bdul. Garii 21<br>Ap. 17','Brasov','','ROMANIA','500227','+40766441667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 12:09:45',0,NULL,3,1,2,1,'\\ ','mbmilescu'),(3759,788262772012,220705197816,'New in box  Motorola H700 Bluetooth Wireless Headset',1,'HSMO013',16.9,'eastar4uk','nads8496','n.huq@sky.com','nadim huq','28 east acton court<br>east acton lane','acton,london','London','UNITED KINGDOM','w3 7es','02087352813','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 13:26:31',0,NULL,3,1,3,1,'RA117733657CN\r ','nads8496\rHSMO013\r盒装 英标'),(3760,709747767011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',14,'eastar4uk','roseannrosebud','roseann_burns99@msn.com','Roseann Burns','160 Grampian way<br>Thorne','Doncaster','South Yorkshire','UNITED KINGDOM','DN85YW','01045817605','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 13:42:34',0,NULL,3,1,3,1,'RA117733609CN\r ','roseannrosebud\rMOAP001'),(3761,788265482012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','bkkelly101','courtpaige@kc.rr.com','Courtney Cooley','16008 E 78th St','Kansas City','MO','UNITED STATES','64139-1288','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 13:42:59',0,NULL,3,1,1,1,'、 ','bkkelly101'),(3762,788273918012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','makaay3413','makaay1@o2.pl','Krzysztof Grzelak','Dzielna<br>25/5','Wrocław','dolnośląskie','POLAND','54152','517 464168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 13:49:22',0,NULL,3,1,2,1,'\\ ','makaay3413\r红边优联'),(3763,582737502013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',101.99,'eastar4','pumpkin_pam','mrspameladickie@hotmail.co.uk','Pamela Dickie','151a Peninsula Road<br>Maylands','Perth','Western Australia','AUSTRALIA','6051','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117733515CN\r ','pumpkin_pam\rMOSA005'),(3764,582738156013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','vivalld','virgot_loik@hotmail.com','Vivier Allard Daudelin','7179 Rue Boyer','Montréal','QC','CANADA','H2R 2R6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 14:31:20',0,NULL,3,1,2,1,NULL,'vivalld'),(3765,582741596013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','foschia12345','flafosc@yahoo.com.br','FLAVIO FOSCHIA','RUA CORONEL ROCHA SANTOS 447 AP 201<br>JARDIM BRASILIA','RESENDE','RJ','BRAZIL','27515000','55 24 33554914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 14:45:25',0,NULL,3,1,3,1,'RA117733538CN\r ','foschia12345\rOTRA001'),(3766,709780768011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',15.9,'eastar4','call2die4','s-pedigo@sbcglobal.net','stacee pedigo','3340 Spring Valley Dr','Columbus','IN','UNITED STATES','47203-4739','(812) 373-0237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 15:15:35',0,NULL,3,1,1,1,'\\ ','call2die4'),(3767,709791465011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',2,'HSMO019',45.98,'eastar4','jfdl000','jackiedonley@netscape.net','Jackie Lude','71649 Sharon Rd','Bridgeport','OH','UNITED STATES','43912','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 15:41:20',0,NULL,3,1,1,1,'\\ ','jfdl000'),(3768,582767358013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',7,'CACN004',91,'eastar4','farcaller','farcaller@gmail.com','Vladimir Pouzanov','2972 Columbia St<br>Ste 15806','Torrance','CA','UNITED STATES','90503-3806','909 248 3463','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 16:15:31',0,NULL,3,1,1,1,'\\ ','farcaller'),(3769,788336541012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','jrsahlberg','jrsahlberg@gmail.com','Jean Rafael Sahlberg','Rua São Mateus, 27','Porto Alegre','RS','BRAZIL','91410-030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:22:19',0,NULL,3,1,2,1,'\\ ','jrsahlberg'),(3770,788339961012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','lebarbu56','denis.bregent@wanadoo.fr','Denis Bregent','1 impasse boris vian','Hennebont','Bretagne','FRANCE','56700','02 09 36 25 85','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:29:15',0,NULL,3,1,3,1,'RA117733524CN\r ','lebarbu56\rOTSO002'),(3771,788339277012,220726304143,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',63.5,'eastar4','myndbandavinnslan','koa@fonix.is','Kristjan Andresson','C/o Fonix ehf - Myndbandavinnslan<br>Hatun 6a-b','Reykjavik','IS','ICELAND','105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:32:31',0,NULL,3,1,3,1,'RA117733691CN\r ','myndbandavinnslan\rMOLO001'),(3772,788358114012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','juliana668','juliana_668@yahoo.com','Tammy Cavana','668 Desert Canyon Rd','Brea','CA','UNITED STATES','92821-7300','(714) 869-6166','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 17:07:00',0,NULL,3,1,1,1,'\\ ','juliana668'),(3773,582789911013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','travolta1978','h19011987@singnet.com.sg','Daniel Frank','BLK 916 TAMPINES ST 91<br>#16-61','default','','SINGAPORE','520916','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 17:36:43',0,NULL,3,1,11,1,NULL,'travolta1978\rWLDL001'),(3774,788348745012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','pjaria','pajaria@yahoo.com','pyarali jaria','1723 Coleville Cir','norcross','GA','UNITED STATES','30093-4959','(770) 837-1126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 17:37:57',0,NULL,3,1,1,1,'\\ ','pjaria'),(3775,788375818012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','kevinhill3000','kevinhill3000@hotmail.com','kevin  hill','2950 Mount Wilkinson Pkwy SE<br>Unit 319','Atlanta','GA','UNITED STATES','30339-3648','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 17:38:06',0,NULL,3,1,1,1,'、 ','kevinhill3000'),(3776,788385953012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','odklein121','klein121@walla.co.il','klein eliezer','P.O.B 1032<br>Tel. 972-4-8758705','Kiryat Bialik','Israel','ISRAEL','27110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 17:56:24',0,NULL,3,1,2,1,'\\ ','odklein121'),(3777,709857700011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','ronaldegrant500','ronaldegrant@hotmail.com','Ronald Grant','641 East F.M. 1118','Kingsville','TX','UNITED STATES','78363','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 18:10:48',0,NULL,3,1,1,1,'\\ ','ronaldegrant500\r一共买了两个'),(3778,788405575012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','julmaff','freak.smart@hotmail.com','Dmitri Jermohhin','Maepealse 14-21','Tallinn','Harjumaa','ESTONIA','12619','+3725275423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 18:26:48',0,NULL,3,1,2,1,'\\ ','julmaff'),(3779,582803667013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',17.4,'eastar4','solid_company','powerhorse@wp.pl','Roger Łyszkiewicz','Baśniowa 3/12','Pruszków','mazowieckie','POLAND','05800','506 106282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 18:27:47',0,NULL,3,1,2,1,'\r\\ ','solid_company\r一共买了两条CAB-SS-2626'),(3780,788408662012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dave_mnak','davemartinak@yahoo.com','David Martinak','128 Brookmead Ct','Advance','NC','UNITED STATES','27006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 18:31:52',0,NULL,3,1,1,1,'\\ ','dave_mnak\r红边优联'),(3781,709881915011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','ronaldegrant500','ronaldegrant@hotmail.com','Ronald Grant','641 East F.M. 1118','Kingsville','TX','UNITED STATES','78363','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 18:46:17',0,NULL,8,1,17,0,NULL,'ronaldegrant500'),(3782,709896224011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','lolopollo','frajorga@gmail.com','Francisco Jorques Garrido','Csantiago de les patio 7 puerta 2','Valencia','Comunidad Valenciana','SPAIN','46014','649564100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:10:41',0,NULL,3,1,2,1,'\\ ','lolopollo'),(3783,788437869012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','jazzboy1010','rol344@hotmail.com','Roland Pieters','11642<br>80A Avenue','Delta','BC','CANADA','V4C 1Y9','(778) 593-0163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:17:36',0,NULL,3,1,2,1,'\\ ','jazzboy1010'),(3784,709912229011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','mashka1972','komomo5@gmail.com','Marianna Golub','zevoni str3/1','Nesher','','ISRAEL','36831','97252351930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:36:55',0,NULL,3,1,3,1,'RA117733612CN\r ','mashka1972\rHSPL015'),(3785,708790385011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',39.99,'eastar4','bjosolu','bjosolu@online.no','Bjørn Solum','Ringshaugtunet 7D','Tolvsrød','','NORWAY','3150','+4795205574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:36:56',0,NULL,3,1,3,1,'RA117733626CN\r ','bjosolu\rBR3D001'),(3786,788464465012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ajb043','andrew.j.bade@gmail.com','Andrew Bade','2325 Traceway Dr<br>Apt 108','Fitchburg','WI','UNITED STATES','53713-3514','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 20:01:54',0,NULL,3,1,1,1,'\\ ','ajb043\r红边优联'),(3787,788475216012,220713846354,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET+carcharger',1,'HSNO006+CCNO001',11.49,'eastar4uk','autopi66','aautopi@gmail.com','Todor Piperov','Stefan Popstoyanov 142','Zlataritsa','Veliko Tarnovo','BULGARIA','5090','+359889975577','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 20:19:17',0,NULL,3,1,2,1,'\\ ','autopi66'),(3788,788486177012,220759964705,'Logitech MX1000 Mouse special bluetooth  version',2,'MOLO005',119.8,'eastar4','tatpole99','andrew.tatarek@c2mdesign.co.uk','Andrew Tatarek','Gower House<br>Croft Road','Aldershot','Hampshire','UNITED KINGDOM','GU11 3HR','01252332007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 20:40:54',0,NULL,3,1,3,1,'RA117733705CN\r ','tatpole99\rMOLO005\r蓝牙版\r英标'),(3789,536193076004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','trangha16','trangha16@optusnet.com.au','Trac Ha','267 The Boulevarde','Fairfield Heights','New South Wales','AUSTRALIA','2165','0403202678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 21:10:41',0,NULL,3,1,3,1,'RA117733643CN\r ','trangha16\rOTGR001+OTGR002'),(3790,530479309003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'cnfaner','adm_trion','adm@post.skynet.lt','Arūnas Michejus','Ukmerges g.<br>196-64','Vilnius','Vilnius','LITHUANIA','07169','864686566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 21:12:45',0,NULL,3,1,3,1,'RA117733586CN\r ','adm_trion\rWLIN013'),(3791,788530151012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','vinga2004','ndushney@gmail.com','Natalie Dushney','129 Septonne Avenue','Newmarket','ON','CANADA','L3Y 2W4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 22:21:34',0,NULL,3,1,2,1,'\\ ','vinga2004\r红边优联'),(3792,709988548011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','xal3x','alexsilvasp@yahoo.com.br','Alexsandre Silva','Rua tuiuti, 1038 casa 08','São Paulo','Sp','BRAZIL','03081-015','11 71172511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 22:37:50',0,NULL,3,1,3,1,'RA117733630CN\r ','xal3x\rGLSG001\r申报23美金'),(3793,582908515013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','orvholt','hjelteig@hotmail.com','Kristine Orvholt Hjelteig','Hasliveien 23','Skjeberg','Østfold','NORWAY','1746','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 23:15:00',0,NULL,3,1,2,1,'\\ ','orvholt\r欧标'),(3794,710003059011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',12.5,'eastar4','bigkarkus','nleach@picknowl.com.au','Nick Leach','115 Morphett Road','Morphettville','South Australia','AUSTRALIA','5043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 23:27:26',0,NULL,3,1,2,1,'\\ ','bigkarkus\rHP 8pin 1.0 3cm'),(3795,788556354012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','greenbeans14','kevie_smithy@yahoo.com','Kevin Smith','815 Smith Hudson Rd','Siler City','NC','UNITED STATES','27344-6988','(919) 663-2271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 23:50:10',0,NULL,3,1,1,1,'、 ','greenbeans14'),(3796,710009326011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','chuckhoag','choag@sprintmail.com','Charles Hoag','521 Claire Ct','Aledo','TX','UNITED STATES','76008-6448','(520) 407-6160','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 23:51:30',0,NULL,3,1,1,1,'\\ ','chuckhoag'),(3797,788558860012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',29,'eastar4uk','swan_1982','friday1958@sbcglobal.net','Pamela K. Schwaner','1 Bromley Cir','Madison','WI','UNITED STATES','53714-3307','(608) 235-4766','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 00:01:40',0,NULL,3,1,1,1,'\\ ','swan_1982'),(3798,788568427012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','firefettish','fantabulum@gmail.com','Gary Rayman','805 PATRIOT PKWY APT 105','Rock Hill','SC','UNITED STATES','29730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 00:34:18',0,NULL,3,1,1,1,'\\ ','firefettish\r红边优联'),(3799,788582190012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','maoobilly','maoobilly@yahoo.com','FAISAL ABDUL WAHID','816 NORWICK RD','NEWMARKET','ON','CANADA','L3X 1K8','(905) 392-0765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 01:29:35',0,NULL,3,1,2,1,'\\ ','maoobilly'),(3800,710032204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',75.98,'eastar4','bpw1595','bwaterson@mac.com','Bernard Waterson','26a Edwards Rd','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 01:33:33',0,NULL,3,1,3,1,'RA117733572CN\r ','bpw1595\rUDAP001'),(3801,710045920011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.43,'eastar4','wschuyler','wschuyler@cablespeed.com','Wayne Schuyler','40 Stone Dr','Pasadena','MD','UNITED STATES','21122-4226','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 02:17:45',0,NULL,3,1,1,1,'\\ ','wschuyler\racer 6pin1.25 23cm'),(3802,579793426013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',5,'HSPL005',67.5,'eastar4','calitoguazha','drcarlosguazha2008@hotmail.com','carlos guazha','7 vitti st','new canaan','CT','UNITED STATES','06840-4824','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 03:18:21',0,NULL,3,1,1,1,'\r\\ ','calitoguazha'),(3803,536266273004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','mkmercier78','perdu_78@hotmail.com','Martin-Karl Mercier','2175 rue Louise','Sherbrooke','QC','CANADA','J1E 4B8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 03:26:53',0,NULL,3,1,3,1,'RA117733555CN\r ','mkmercier78\rHSPL011\r'),(3804,710068914011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',49.9,'eastar4','orchteacher','kellydaza@gmail.com','Kelly Daza','2603 51st St','Des Moines','IA','UNITED STATES','50310-1612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 04:03:24',0,NULL,3,1,1,1,'、 ','orchteacher'),(3805,788628037012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',2,'HSSH002',51.98,'eastar4','ashakydd','ashakydd@hotmail.com','Asha Kydd','c/o A.T.S<br>18331 Blundell Road','Richmond','BC','CANADA','V6W 1L8','(604) 231-6300 ext.: 6237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 04:24:27',0,NULL,3,1,3,1,'RA117733688CN ','ashakydd\rHSSH002'),(3806,710073400011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',16.75,'eastar4','scapegoat18usc3059','scapegoat18usc3059@yahoo.com','Kevin Wiederhold','1416 Coleman Ave','Corpus Christi','TX','UNITED STATES','78401-3245','(361) 737-4833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 04:31:25',0,NULL,3,1,1,1,'、 ','scapegoat18usc3059'),(3807,788649101012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','tau696969','taumaso@gmail.com','takahiro kurosawa','5-1-25-102 asaoku ozenjinisi','kawasakisi','Kanagawa','JAPAN','215-0017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 06:19:11',0,NULL,3,1,2,1,NULL,'tau696969'),(3808,788659497012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','dtp_and_photo','ronypsk@hotmail.com','Ronald Pari','107-145 West 5th St.','North Vancouver','BC','CANADA','V7M 1J7','(604) 980-0054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 07:14:15',0,NULL,3,1,2,1,NULL,'dtp_and_photo\rmouse 简装 used'),(3809,710110851011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','ran_carney','carneyran@gmail.com','ran carney','moshav beit ezra 22','moshav beit ezra 22','','ISRAEL','79285','054-6680609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 07:58:01',0,NULL,3,1,3,1,'RA117726015CN ','ran_carney\rRCLO007+POLO001+RCLO008*4\r'),(3810,788679285012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mralexman1970','jobfinder_70@hotmail.com','Jonas Soderlund','Mjolnare Grips Vag 27','Stockholm','Haninge','SWEDEN','13647','+46 70 375 10 83','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 08:38:22',0,NULL,3,1,2,1,'\\ ','mralexman1970\r红边优联'),(3811,788679560012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',10.5,'eastar4uk','mag328','mag328@aol.com','William Murrain','Blackacre Bungalow, St. Columb','St Columb Major','Cornwall','UNITED KINGDOM','TR96JA','01637881489','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 08:39:06',0,NULL,3,1,3,1,'RA117726024CN ','mag328\rHSPL002\r'),(3812,582998871013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',459.8,'eastar4','isaurom','jimedina@mail.multiw.com','Javier Medina','5580 Paredes Line Rd','Brownsville','TX','UNITED STATES','78526','(956) 548-2063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 08:43:45',0,NULL,3,1,4,1,'YW865907885CN ','isaurom\r好好测试\r一共买了20个'),(3813,788687935012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dmitry_schulz','diamond75@list.ru','Dmitry Schulz','5 Aktaiou Cydonia Gardens block 6 flat 3','Limassol','Germasogeia','CYPRUS','4046','357 978-43270','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 09:13:15',0,NULL,3,1,2,1,NULL,'dmitry_schulz\r红边优联'),(3814,710129959011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 09:22:32',0,NULL,3,1,3,1,'RA117727002CN ','tudijaidem\rANYA001'),(3815,788691778012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mvachuda','michal@klestil.cz','Michal Vachuda','nam. M. Horakove 2','Plzen','','CZECH REPUBLIC','32600','+420777883224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 09:29:26',0,NULL,3,1,2,1,'\\ ','mvachuda\r红边优联'),(3873,536622755004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','martin.f.krafft','ebay.com@pobox.madduck.net','Martin Krafft','Hanfstaenglstraße 15','München','','GERMANY','80638','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 10:29:46',0,NULL,3,1,3,1,'RA117733935CN\r ','martin.f.krafft\r欧标\rHSJA002'),(3817,788707885012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',12.99,'eastar4','orlando4201','taicoma@hotmail.com','orlando mendez','15720 SW 102nd Ct','miami','FL','UNITED STATES','33157-1522','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 10:30:02',0,NULL,3,1,1,1,'\\ ','orlando4201'),(3818,788712457012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','rahimmunna','munnaboss@hotmail.com','Rahim munna','Doctor Hermansweg 106','Eindhoven','','NETHERLANDS','5624HT','0630244220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 10:46:11',0,NULL,3,1,2,1,'\\ ','rahimmunna\r红边优联'),(3819,583022258013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','alex.gabriel.onciu','alex.onciu@gmail.com','Alex Gabriel Onciu','Intrarea Vaslei nr. 1<br>bl. PM63, sc. A, ap. 47','Bucharest','Sector 3','ROMANIA','030384','+40726633999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 11:02:40',0,NULL,3,1,3,1,'RA117726894CN ','alex.gabriel.onciu\rWLIN014'),(3820,788722549012,220620860324,'NEW GENUINE NOKIA BH-207 BLUETOOTH HEADSET BH 207',1,'HSNO010',22.99,'eastar4','bagrow','trunov@web.de','Trunov Eugen','Kirchstr.9','Bad Krozingen','','GERMANY','79189','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 11:17:38',0,NULL,3,1,2,1,'\\ ','bagrow\r欧标\r盒装'),(3821,710168933011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','pjmyoung','w9wy@hotmail.com','William Young','1/72 Maud St<br>North Balwyn','Melbourne','Victoria','AUSTRALIA','3104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 11:54:25',0,NULL,3,1,3,1,'RA117726965CN ','pjmyoung\rGLSG001  运单号有问题'),(3822,583038367013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','gsti3702','aatv@suddenlink.net','Glenn Stinson','2435 College Hills','San Angelo','TX','UNITED STATES','76904','(325) 277-9248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 12:18:48',0,NULL,3,1,1,1,'\\ ','gsti3702'),(3823,710193139011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','purple_tomato_designs','cmoliver@gmail.com','Charlotte Oliver','27 Kenneth Pl','Oceanside','NY','UNITED STATES','11572-3009','(917) 435-2075','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'purple_tomato_designs'),(3824,710199843011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','2010hpservice','hpservice1@gmail.com','Hamlet Altunyan','Atoyan 166','Yerevan','','ARMENIA','0041','37477203208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 13:39:02',0,NULL,3,1,2,1,'、 ','2010hpservice'),(3825,583058196013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','lekchai','jchan2@chicagobooth.edu','Kong, Weiling','314, CHI Residences Apt 8E, Nathan Road<br>Jordan, Kowloon','default','','HONG KONG','default','(852)90226356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 13:48:33',0,NULL,3,1,2,1,'\\ ','lekchai'),(3826,788771746012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',24.59,'eastar4uk','pedrofsc','pedrofsc@gmail.com','Pedro Cardoso','Rua Juruviara, 32 - Todos os Santos','Rio de Janeiro','RJ','BRAZIL','20735150','552176291866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 13:50:19',0,NULL,3,1,3,1,'RA117726885CN ','pedrofsc\rUDAP002'),(3827,788772861012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',25.98,'eastar4','0313george','george2js@sbcglobal.net','george saridis','950 E Chicago St','elgin','IL','UNITED STATES','60120-6821','(847) 888-1048','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 13:50:58',0,NULL,3,1,1,1,'\\ ','0313george'),(3828,788778235012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',5,'HSPL011',115,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:07:43',0,NULL,3,1,3,1,'RA117726917CN ','solopo2009\rHSPL011+HSPL010\r再发5个New Plantronics Voyager 510 Multi-Point Bluetooth Heads\r都是只发耳机和USB CABLE 不给电源'),(3829,788780461012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',5,'HSPL010',119.5,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:12:45',0,NULL,8,1,17,0,NULL,'solopo2009'),(3830,583067763013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','daemon64','wpacheco@ymail.com','William Pacheco','JEONGPYUNG-DONG 221','GYEONGSAN-SI','GYEONG-BUK','KOREA,REPUBLIC OF','712-110','010-7136-9159','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:29:03',0,NULL,3,1,2,1,'\\ ','daemon64'),(3831,710226323011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',24.59,'eastar4uk','goldnetuk','foneuk@fsmail.net','ANDY McCAFFERTY','134 CRESSINGHAM ROAD','READING','Berkshire','UNITED KINGDOM','RG2 7LN','07971775481','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 14:53:16',0,NULL,3,1,3,1,'RA117726863CN ','goldnetuk\rUDAP001'),(3832,583076512013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','spruebucket','molder1d@comcast.net','WILLIAM BROWNING','2128 DURKIN AVE','SCRANTON','PA','UNITED STATES','18508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 15:03:49',0,NULL,3,1,1,1,'\\ ','spruebucket'),(3833,536381723004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','diamonddd_d','diamonddd_d@hotmail.com','Dale Fevens','83 Tanner Road','Blockhouse','NS','CANADA','B0J1E0','(902) 624-0077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 15:17:32',0,NULL,3,1,3,1,'RA117726934CN ','diamonddd_d\rRCLO006\r'),(3834,710250465011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','charalambos6845','clouca1@yahoo.com','CHARALAMBOS LOUCAIDES','AVLIXOU 12','LIMASSOL','','CYPRUS','TT3112','0035799535205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 15:58:39',0,NULL,3,1,2,1,'\\ ','charalambos6845'),(3835,710253151011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','gzhubrak','garry.zhubrak@gmail.com','Igor Zhubrak','755 sinclair Ave','Staten island','NY','UNITED STATES','10312-2523','(917) 763-9645','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 16:11:48',0,NULL,3,1,4,1,'YW865907874CN ','gzhubrak'),(3836,788848879012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','uncordless.9294','uncordless@vodamail.co.za','Shaun Dirks','4 Kornet Lane<br>Steenberg','Cape Town','Western Cape','SOUTH AFRICA','7945','+27824079294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 17:04:22',0,NULL,3,1,2,1,'\\ ','uncordless.9294'),(3837,788873931012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','belbereth83','belbereth@hotmail.com','Arantxa Ballesteros Salvador','C/ Campos Crespo 6-34','Valencia','Valencia','SPAIN','46017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 17:48:59',0,NULL,3,1,2,1,'\\ ','belbereth83\r红边优联'),(3838,710298344011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',2,'OTSO001',147.9,'eastar4','imagemshop145','imagemshop1@imagemreal.com.br','ROBERTO CAMPOS','TRAV. RAFAEL FRANCISCO GRECA, 34 - APTO 1201<br>AGUA VERDE','CURITIBA','PARANA STATE','BRAZIL','80620-150','41-3244-2777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 17:51:05',0,NULL,3,1,3,1,'RA117726126CN ','imagemshop145\rOTSO001'),(3839,710337618011,320688324995,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.95,'eastar4','sicfifty','rick_warren@emcorgroup.com','Rick Warren','32401 Sheffield Ln','Union City','CA','UNITED STATES','94587-1923','(510) 489-9392','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 19:05:29',0,NULL,3,1,1,1,'\\ ','sicfifty'),(3840,788927018012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',46,'eastar4','winner_hun','fizetosmailcimem@gmail.com','Pintér László','Budapesti krt. 24/A 1/3','Szeged','','HUNGARY','6723','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 19:22:18',0,NULL,3,1,3,1,'RA117726903CN ','winner_hun\rHSPL011\r欧标\r'),(3841,710370878011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','memyselfnmygirlz','antzwife014@yahoo.com','Jennifer Charles','812 Jordan Pl','Rockford','IL','UNITED STATES','61108-3704','(815) 398-8365','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 20:08:02',0,NULL,3,1,1,1,'、 ','memyselfnmygirlz'),(3842,710389374011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',10,'HSJA006',135.5,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 20:48:13',0,NULL,3,1,1,1,'\\ ','gogo-buyers'),(3843,583199050013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',5,'HSPL001',59,'eastar4','patdaly','patdaly1@yahoo.com','Pat\'s Computers','20 Lorimer St.','Indian Orchard','MA','UNITED STATES','01151-1817','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 21:04:30',0,NULL,3,1,1,1,'\\ ','patdaly'),(3844,788993045012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','rahmanfazal','rahfazal@gmail.com','Fazlur Rahman','604 Laredo Dr','Murphy','TX','UNITED STATES','75094-3669','(443) 345-4674','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 21:41:50',0,NULL,3,1,1,1,'\\ ','rahmanfazal\r红边优联'),(3845,789006818012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',2,'HSMO007',23.8,'eastar4','joseaagomes','colocagomes@sapo.pt','José Gomes','Rua Cimo da Serra, 324<br>S. Cosme','Gondomar Porto','S Cosme Gondomar Porto','PORTUGAL','4420-084','00351 224643926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 21:56:46',0,NULL,3,1,2,1,'\\ ','joseaagomes\r欧标'),(3846,789011649012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.99,'eastar4','rlatino2003','rogerfreire2000@gmail.com','Rogerio Silva','rua ana aslan 02 bl 06 ap 33','são paulo','São Paulo','BRAZIL','05892385','055 11 58241100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 22:14:00',0,NULL,3,1,2,1,'\\ ','rlatino2003'),(3847,710431126011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','bluecrazy8deals','christopher.mathews@comcast.net','Christopher Mathews','1201 The Grove Road','Orange Park','FL','UNITED STATES','32073','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 22:35:40',0,NULL,3,1,1,1,'\\ ','bluecrazy8deals'),(3848,789020803012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.9,'eastar4','timporium','ttalimon@mail.win.org','Tim Talimonchuk','1879 S Old Highway 94','Saint Charles','MO','UNITED STATES','63303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-17 22:36:06',0,NULL,3,1,1,1,'\\ ','timporium'),(3849,789050649012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','richy8848','vtran@transitchicago.com','vu tran','1920 W Hood ave<br>Apt. 2A','Chicago','IL','UNITED STATES','60660','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 00:17:38',0,NULL,3,1,1,1,'\\ ','richy8848'),(3850,583248158013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','alan_carajo','cashprueba@hotmail.com','Alan Noguera','13430 S.w. 131 St.<br>NB#123620','MIAMI','FL','UNITED STATES','33186','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 00:47:54',0,NULL,3,1,1,1,'\\ ','alan_carajo'),(3851,583250954013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',3,'MOLO004',113.7,'eastar4','diegosanabrazil','diego.flogao@uol.com.br','Diego de Morais Sana','Rua Diogenes Nascimento das Neves<br>165/102B','Vitoria','Espirito Santo-ES','BRAZIL','29055915','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 00:58:18',0,NULL,3,1,3,1,'RA117726815CN ','diegosanabrazil\rMOLO004\r华硕限量版'),(3852,789064662012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mjmlooper','mjmlooper@gmail.com','Michael Looper','2063 Sunset Ave','Morro Bay','CA','UNITED STATES','93442-1651','(530) 392-0348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 01:08:47',0,NULL,3,1,1,1,'\\ ','mjmlooper\r红边优联'),(3854,789077433012,220761218614,'Brand Shure E2c Sound Isolating Earphone headset Black',1,'HSSH001',25.99,'eastar4','laraza2011','dmferrey@hotmail.com','Diego Ferreyra','1238 Oxalis Ave','Orlando','FL','UNITED STATES','32807','(407) 535-1912','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 01:53:23',0,NULL,3,1,1,1,'\\ ','laraza2011'),(3853,583262877013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','keith_sparrow','keith@sparrownest.com','Keith Sparrow','237 Willis Drive','Aurora','ON','CANADA','L4G 7M2','(416) 907-4276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 01:52:49',0,NULL,3,1,3,1,'RA117726925CN ','keith_sparrow\rBAZA001'),(3855,710486777011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','gerizaldo.maia','gerizaldo@gmail.com','Gerizaldo Maia','Rua Silvino Lopes 480, Apto. 804<br>Tambaú','João Pessoa','PB','BRAZIL','58039-190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 02:17:43',0,NULL,3,1,2,1,'\\ ','gerizaldo.maia\r无线蓝牙二合一'),(3856,710488592011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','jinyshop','yunseonkang@gmail.com','yunseon kang','bundang dong 183-12 3F 301<br>bundang gu','Seongnam-si,','Gyeonggi-do','KOREA,REPUBLIC OF','463-876','010 9961 4123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 02:22:32',0,NULL,3,1,3,1,'RA117726979CN ','jinyshop\rGLSG001'),(3857,789085976012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',35.99,'eastar4','makin.ditch','rob_mundy@msn.com','Rob Mundy','Box 3254 Stn Main','Morinville','AB','CANADA','T8R1S2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 02:25:54',0,NULL,3,1,3,1,'RA117726877CN ','makin.ditch\rWLIN001'),(3858,789087597012,220770080684,'Logitech Harmony RF extender 890 pro 1000 1100 90% new',1,'RCLO007',29.99,'eastar4','thitsybitsyspidr','jvtcamp@aol.com','Jason Campbell','13012 Willowcrest Ln','Oklahoma City','OK','UNITED STATES','73170','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 02:27:57',0,NULL,3,1,1,1,'、 ','thitsybitsyspidr'),(3859,710486435011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',39.99,'eastar4','gerka15','gera@graffin.ru','Георгий Уморин','ул. Белореченская 9/3, 61','Екатеринбург','Свердловская область','RUSSIAN FEDERATION','620103','+7 (343) 2902152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 03:44:50',0,NULL,3,1,3,1,' RA117726112CN','gerka15\rWWSI005+ANCN001\r'),(3860,789107397012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','kingatpwning','davidkang006@yahoo.com','david kang','5584 Orange Ave','Cypress','CA','UNITED STATES','90630-3829','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 03:54:25',0,NULL,3,1,1,1,'\\ ','kingatpwning\r红边优联'),(3861,710519977011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','gimondi68','ridecampy@cox.net','Walter F Ellsworth','16849 S 30th Ave','Phoenix','AZ','UNITED STATES','85045-2217','(480) 254-8288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 05:04:55',0,NULL,3,1,1,1,'\\ ','gimondi68'),(3862,583295929013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','rgmiller01','thesupergeekryan@yahoo.com','Ryan Miller','680 Bryn Mawr Ave','Bartlett','IL','UNITED STATES','60103-5835','(630) 696-2302','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 05:19:00',0,NULL,3,1,1,1,'\\ ','rgmiller01'),(3863,789124420012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','stevethong','stevethong@gmail.com','Steve Thong','Blk 228 Choa Chu Kang Central<br>#07-113 Singapore 680228','default','','SINGAPORE','680228','+65-8383-9423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 05:35:20',0,NULL,3,1,11,1,NULL,'stevethong\rOTCR001'),(3864,583298406013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.95,'eastar4','inuyaga','mikecmcminn@hotmail.com','Michael C. McMinn','5360 Repecho Dr<br>APT 211','San Diego','CA','UNITED STATES','92124-1732','(760) 613-0015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 05:40:25',0,NULL,3,1,1,1,'\\ ','inuyaga'),(3865,583309601013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','areacode403','andy.tse@shaw.ca','Andy Tse','60 Arbour Crest Rd NW','Calgary','AB','CANADA','T3G 4J9','(403) 560-6558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 06:58:13',0,NULL,3,1,2,1,NULL,'areacode403\rCAB-SS-2626'),(3866,789144886012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','led_ozzy','hell_ozzy@yahoo.com.br','Marcos Lopes da Silva','Rua Comendador Rheingantz 431 Apt 301','Porto Alegre','RS','BRAZIL','90450-020','55 5181075114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 07:06:27',0,NULL,3,1,2,1,NULL,'led_ozzy'),(3867,789148920012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',2,'WLDL001',11.5,'eastar4uk','friend_gary','garmar@ntlworld.com','margaret mcarthur','19 Graymount Parade','belfast','Antrim','UNITED KINGDOM','BT367DP','02890778918','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 07:22:13',0,NULL,3,1,3,1,'RA117733714CN ','friend_gary\rWLDL001\r'),(3868,583316257013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','marcinreklin','bimmr@wp.pl','MARCIN REKLIN','KAKOLOWA 3/4','BYDGOSZCZ','kujawsko-pomorskie','POLAND','85-811',' 668180215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 07:47:44',0,NULL,3,1,2,1,NULL,'marcinreklin'),(3869,583319488013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','zktk2510','zktk35@hanmail.net','Yongun Baek','244-6 Po-il dong','Uiwang','Kyunggi','KOREA,REPUBLIC OF','437120','010-2422-1712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 08:06:17',0,NULL,3,1,3,1,'RA117733731CN ','zktk2510\rWLIN014\r'),(3870,583319605013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',8.49,'eastar4','albertiniguez','albertiniguez@hotmail.com','jose iniguez','720 N Idaho St','san mateo','CA','UNITED STATES','94401-1121','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 08:07:05',0,NULL,3,1,1,1,NULL,'albertiniguez'),(3871,789185363012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','oguerriat','olivier+ebay@guerriat.be','Olivier Guerriat','Rue du tilleul 19','Daussois','','BELGIUM','5630','071613096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 09:54:15',0,NULL,3,1,2,1,'\\ ','oguerriat'),(3872,583339915013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','underhenna','xlns@mail.ru','Igor Novikov','Shipilovskaya street 54-2-392','Moscow','','RUSSIAN FEDERATION','115573','8(910)4073773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 10:14:46',0,NULL,3,1,3,1,'RA117733952CN\r ','underhenna\rOTRA001'),(3953,789651370012,220763412711,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',9.9,'eastar4uk','anton.gretskosi','vista888@yandex.ru','Anton Gretskosi','Muhu 2-31','Tallinn','','ESTONIA','13912','003725091120','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 09:08:26',0,NULL,3,1,2,1,'\\ ','anton.gretskosi\r欧标'),(3874,530915836003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','sivananat','sgr4679@gmail.com','Sivan Grinberg','Aba Hillel Silver 111/45','Haifa','Israel','ISRAEL','32697','+972 0508569897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 10:51:19',0,NULL,3,1,3,1,'RA117733921CN\r ','sivananat\rHSMO018'),(3875,789002815012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',11.9,'eastar4uk','pureharmony1','pureharmony0@gmail.com','Dr Fahmy','Netlogic Consulting<br>84 Park Avenue North','London','London','UNITED KINGDOM','NW10 1JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 11:41:28',0,NULL,3,1,3,1,'RA117733802CN\r ','pureharmony1\rOTCN004*10'),(3876,789217053012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','wiseguyhuh','wisekracker84@hotmail.com','TJ Toohey','10900 Pump House Rd<br>Millennium Marketing Solutions','Annapolis Junction','MD','UNITED STATES','20701-1207','(301) 395-1162','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 11:43:08',0,NULL,3,1,1,1,'\\ ','wiseguyhuh'),(3877,530925631003,130458358283,'New  NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'HSNO006+CCNO001',33.9,'cnfaner','sbirulina3','piccolapulce3@libero.it','Gianna De Vellis','strada San Pietro 5','Feletto C.se','TO','ITALY','10080','346/1205846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 11:45:38',0,NULL,3,1,3,1,'RA117733997CN\r ','sbirulina3\rHSNO006+CCNO001\r一共买了两个'),(3878,710611432011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','yeala','hans.beckers@ewetel.net','Hans Beckers','Im Westerende 1','Ihlow-Simonswolde','','GERMANY','26632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 11:47:30',0,NULL,3,1,2,1,'\\ ','yeala'),(3879,710619455011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',12.5,'eastar4','itsmesikander','alonethesedays@hotmail.com','sikander qureshi','Hampton Tyres<br>5-9 Thames Street','Hampton','Middlesex','UNITED KINGDOM','tw122ew','02089411027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 12:14:58',0,NULL,3,1,2,1,'\\ ','itsmesikander\racer 5pin1.25 4cm'),(3880,710619687011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',2,'GLSG003',178,'eastar4','wphonewatch','xuwenhao1983@gmail.com','Barbara Blount','1145 Sherry Avenue Virginia Beach, Virginia 23464,United States','Virginia','VA','UNITED STATES','23464','757 420 6472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 12:36:33',0,NULL,3,1,1,1,'\\ ','wphonewatch'),(3881,789244267012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','danielbluephoenix','patrik_roka@centrum.sk','Patrik Róka','Frana Krala 2','Sala / Veca','Sala','SLOVAK REPUBLIC','92705','00421 903 806 455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 13:04:29',0,NULL,3,1,2,1,'\\ ','danielbluephoenix'),(3882,674410634001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','alpa0171','alpa54@teletu.it','Aldo Parodi','Via S. Martino 1/b<br>Fraz. Santa Croce','Cervasca','CN','ITALY','12010','0171 46306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 13:05:03',0,NULL,3,1,3,1,'RA117734003CN\r ','alpa0171\rOTSO001'),(3883,789245111012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','n10aguy','n10aguy@cfl.rr.com','Brian Anderson','720 Armitage Ave','Apopka','FL','UNITED STATES','32703-5434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 13:08:37',0,NULL,3,1,1,1,'\\ ','n10aguy'),(3884,789249416012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','ericandrew231','eric.bartos@gmail.com','Eric Bartos','3043 140th ave','Dorr','MI','UNITED STATES','49323-9531','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 13:20:38',0,NULL,3,1,1,1,'\\ ','ericandrew231'),(3885,583288428013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.95,'eastar4','cheungvinws','cheungvinws-shopping@yahoo.com.hk','Vincent Cheung','Flat B 3/F Blk 22 Mei Wah Court<br>South Horizons, Ap Lei Chau, HK','default','','HONG KONG','default','(852) 94826038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 14:11:20',0,NULL,3,1,14,1,'010911045424 ','cheungvinws\r'),(3886,582729978013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'eastar4','dmitrijs777','kristjucha@mail.ru','Dmitrijs Shavshajevs','Inzenieru iela 77-92','Ventspils','Latvia','LATVIA','LV-3605','(371)22309209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 14:29:19',0,NULL,3,1,3,1,'RA117726452CN\r ','dmitrijs777\rOTES001'),(3887,789284806012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','sgm54','sg-monger@wiu.edu','Steve Monger','227 W Piper St','Macomb','IL','UNITED STATES','61455-2850','(309) 833-2340','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 14:59:05',0,NULL,3,1,1,1,'\\ ','sgm54'),(3888,710112946011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','anj.wallace','wallace-anj@yandex.ua','Andrey Kirienko','Kurchatova 38/24','Severodonetsk','Luhanskaya obl','UKRAINE','93400','+380505725063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 15:26:53',0,NULL,3,1,2,1,'\\ ','anj.wallace\r 无线蓝牙二合一'),(3889,710683028011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','polifessor','eksbyun@gmail.com','KUNSEOP BYUN','U 1718 /  30 GLEN ST','MILSONS POINT','New South Wales','AUSTRALIA','2061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 15:28:05',0,NULL,3,1,2,1,'\\ ','polifessor'),(3890,710686988011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','desperadodema','jimdema@newwavecomm.net','James Dema','203 E. 18th St.','Benton','KY','UNITED STATES','42025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 15:41:49',0,NULL,3,1,1,1,'\\ ','desperadodema'),(3891,789301582012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','waackoo','dwburlington@rogers.com','David Burlington','14 Connie Cres, Unit #1','Concord,','ON','CANADA','L4K 2W8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 15:42:53',0,NULL,3,0,2,1,'\\ ','waackoo'),(3892,789307496012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','chris1991dog','jaynekhill@hotmail.com','jayne hill','15 oriel road','ashton-in-makerfield','nr wigan','UNITED KINGDOM','wn4 9rq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 15:56:49',0,NULL,3,1,3,1,'RA117733780CN\r ','chris1991dog\rHSPL010\r英标'),(3893,789323986012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',3,'HSNO006',44.85,'eastar4','stevesmoof','stevesmoof@aol.com','Stefan Schauwecker','Friedrichstrasse 26','Herbolzheim','','GERMANY','79336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 16:36:16',0,NULL,3,1,3,1,'RA117733864CN\r ','stevesmoof\rHSNO006\r欧标'),(3894,789326574012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','rodasturbo','joelrodasturbo@hotmail.com','Joel Ramos','Rua Ferreira de Castro nº 69','Valbom','Gondomar','PORTUGAL','4420-451','+351918435152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 16:42:30',0,NULL,3,1,2,1,'\\ ','rodasturbo\r欧标'),(3895,710710442011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',12.5,'eastar4','dochartt','mdhartt@mdhartt.com','Morgan D Hartt','1439 W Chapman Ave.,<br>Unit 37,','Orange','CA','UNITED STATES','92868','(310) 598-8424','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 16:51:50',0,NULL,3,1,1,1,'\\ ','dochartt\racer 4pin1.25 6cm'),(3896,787576194012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',13.49,'eastar4uk','maverickmatt','mattimatico@hotmail.com','Matthew Richardson','3 Thornhill Road','London','London','UNITED KINGDOM','N1 1HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 16:54:36',0,NULL,3,1,3,1,'RA117733793CN\r ','maverickmatt\rRELO002'),(3897,789332847012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','imbender88','imbenderama@gmail.com','Ted stevenson','112 S Oak St','Traverse City','MI','UNITED STATES','49684-2450','(231) 935-4052','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 16:56:39',0,NULL,3,1,1,1,'\\ ','imbender88'),(3898,789337374012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','bvumer','bertrand.bloch@yahoo.fr','Bertrand Bloch','13 Square Lamartine','Evry','Île-de-France','FRANCE','91000','0160779004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 17:05:46',0,NULL,3,1,2,1,'\\ ','bvumer\r红边优联'),(3899,789338670012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','jc244','joel@evanstech.ca','Joel Evans','3737 Bartlett CRT APT 303','Burnaby','BC','CANADA','V3J 7E3','(604) 444-5452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 17:08:53',0,NULL,3,1,2,1,'\\ ','jc244'),(3900,710723818011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','czelaya33','christian_zel40@hotmail.com','Christian Zelaya','Cirujano Guzman<br>245','Punta Arenas','Magallanes','CHILE','6200000','+56997893740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 17:11:24',0,NULL,3,1,3,1,'RA117726364CN\r ','czelaya33\rGLSG001'),(3901,529531879003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',22.49,'cnfaner','nakdemir','postmail.ebay@gmail.com','Nejdet Akdemir','Kirkkonaklar mh. Semsettin Gunaltay cd<br>363 sok. 3/4','ANKARA','cankaya','TURKEY','06610','903124963904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 18:00:31',0,NULL,3,1,3,1,'RA117738107CN\r ','nakdemir\rMOAP001\r'),(3902,582632915013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'eastar4','spartynumberone','marvinf_1@yahoo.com','Marvin Fajardo','713 Windsong Dr','Rochester Hills','MI','UNITED STATES','48307','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 18:11:30',0,NULL,3,1,1,1,'\\ ','spartynumberone'),(3903,531029881003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',21.99,'cnfaner','lance8022','bgbfbg@comcast.net','Lance Lewis','2588 Hawthorne Rd','Ann Arbor','MI','UNITED STATES','48104-4032','(734) 995-1726','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 18:38:18',0,NULL,3,1,1,1,'\\ ','lance8022'),(3904,583472742013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','p_drumeva','paula_drumeva@abv.bg','Paula Drumeva','5, Angel Kanchev','Osenec','Razgrad','BULGARIA','7200','0883483192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 18:53:40',0,NULL,3,1,2,1,NULL,'p_drumeva\r黄色的\r欧标'),(3905,789398832012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','55956430','lovexx@mail.ru','Sergei Ivannikov','Harma 5-13','Tallinn','Harjuma','ESTONIA','13615','0037255956430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 19:22:39',0,NULL,3,1,11,1,NULL,'55956430\rANYA002'),(3906,583487206013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','maxik25','nevajno_@hotmail.com','Maxim Antsyferov','712-326 major mackenzie','richmond hill','ON','CANADA','l4c8t4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 19:26:35',0,NULL,3,1,3,1,'RA117733776CN\r ','maxik25\rHSNO019'),(3907,710800729011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.43,'eastar4','dejan.horgas','dejan.horgas@gmail.com','Dejan Horgas','413, 5889 Irmin Street<br>Buzzer Code #1084','Burnaby','BC','CANADA','V5J 0C1','(604) 431-5901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 19:40:54',0,NULL,3,1,2,1,'\\ ','dejan.horgas\rHP 8pin 1.25 18cm '),(3908,710803096011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','zuvaks','v.gurkovskis@inbox.lv','vitalijs gurkovskis','gimnazijas 7/9 -34','Daugavpils','','LATVIA','LV-5400','+37129734622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 19:53:38',0,NULL,3,1,11,1,NULL,'zuvaks\rANYA001'),(3909,583499944013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','jimz5629','jzenda@wi.rr.com','Jim Zenda','N39W27437 Hillside Grv','Pewaukee','WI','UNITED STATES','53072-2246','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 19:58:57',0,NULL,3,1,1,1,'\\ ','jimz5629\r罗技 USB receiver no shell'),(3910,710813288011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.99,'eastar4','zanej007','admin@zane.co.za','Zane Jacobs','12 Montrose Creek<br>Montrose Road, Brentwood Park','Port Elizabeth','Eastern Cape','SOUTH AFRICA','6025','+27 836306999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 20:03:54',0,NULL,3,1,3,1,'RA117726378CN\r ','zanej007\rGLSG001*2'),(3911,789444415012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','relypsa','vciaravino@comcast.net','Vic Ciaravino','Anacor, Inc.<br>1020 East Meadow Circle','Palo Alto','CA','UNITED STATES','94303-4230','(650) 543-7646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 20:27:09',0,NULL,3,1,1,1,'\\ ','relypsa\r红边优联'),(3912,788954808012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.95,'eastar4','alo_alex','alejandrorudon@hotmail.com','Alex Rudon- Mendoza','15701 SW 44th Ter','Miami','FL','UNITED STATES','33185-3841','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 20:35:03',0,NULL,3,1,1,1,'\\ ','alo_alex'),(3913,789454809012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','redmoon.0208','davmrr356@aol.com','david norris','19 longstaff road','wandsworth','London','UNITED KINGDOM','SW18 4AZ','02088713236','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 20:39:32',0,NULL,3,1,3,1,'RA117733762CN\r ','redmoon.0208\rHSPL010\r英标'),(3914,710831276011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','icemaddy','terrigcrowley@yahoo.com','Terri Crowley','1205 Lakeview Ct','Versailles','KY','UNITED STATES','40383','(859) 873-1045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 20:39:36',0,NULL,3,1,1,1,'\\ ','icemaddy'),(3915,789458659012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.98,'eastar4','ovpos2011','ovpos@upcmail.nl','Orlando Samseer','Botterweg 19','Diemen','','NETHERLANDS','1113HP','0031641487885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 20:47:17',0,NULL,3,1,2,1,'\\ ','ovpos2011\r红边优联'),(3916,710837275011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','gedevitt','gedevitt@aol.com','Mr. Craig Apatov','Ascension<br>2000 River Edge Parkway, Suite 660','Atlanta','GA','UNITED STATES','30328','(404) 432-5269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 20:52:30',0,NULL,3,1,4,1,'YW865907966CN ','gedevitt'),(3917,785515924012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',3,'HSMO008',32.85,'eastar4','theboss749','uizwackz@aol.com','NATIVIDAD GUEVARA','1665 Vyse Ave # 5b<br>Apt # 5B Apt 5B','bronx','NY','UNITED STATES','10460-5392','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 20:59:26',0,NULL,3,1,1,1,'\\ ','theboss749'),(3918,710843901011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',18.85,'eastar4','jwil10007','jlwilleford@msn.com','JOHN WILLEFORD','4255 E. STETSON LANE','COTTONWOOD','AZ','UNITED STATES','86326','(928) 649-8965','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 21:06:11',0,NULL,3,1,1,1,'\\ ','jwil10007'),(3919,583530130013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','enrybnala','james.alan.byrne@gmail.com','Alan Byrne','IT Department<br>Valeo Vision Systems','Tuam','Galway','IRELAND','default','0860733525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 21:27:04',0,NULL,3,1,2,1,'\\ ','enrybnala\rCAB-6060'),(3920,583536308013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','xainkodi','mlescoul@optusnet.com.au','Maureen Le Scoul','16/90 Collins Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 21:50:10',0,NULL,3,1,2,1,'\\ ','xainkodi'),(3921,583537957013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.76,'eastar4','2faste2furious','rafael-lozano@hotmail.com','Rafael Lozano Espasandin','Av. Monsenhor Ascâneo 592 apt 202<br>Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22621060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 21:56:46',0,NULL,3,1,3,1,'RA117733904CN\r ','2faste2furious\rMOSA001'),(3922,583544322013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','djpsycho7','djpsycho.osx@gmail.com','Petros Nenos','Kolokotroni 1','Orestiada','Evros','GREECE','68200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 22:22:44',0,NULL,3,1,2,1,'\\ ','djpsycho7'),(3923,789500322012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','sture.vandemoortel','sture.vandemoortel@gmail.com','Matthias Michel','Chäferweg 6','Sursee','','SWITZERLAND','6210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 22:26:26',0,NULL,3,1,2,1,'\\ ','sture.vandemoortel'),(3924,710886596011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',21.9,'eastar4','lprendiz','lprendiz@juno.com','Louis Albert Prendiz','807 Kilpatrick Street','Channelview','TX','UNITED STATES','77530-3463','(281) 452-3427','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 23:18:53',0,NULL,3,1,1,1,'\\ ','lprendiz'),(3925,583565283013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',83.85,'eastar4','casey*adg','cgaik@bell.net','Casey  Gaik','1035 Meadowridge Cres','Pickering','ON','CANADA','L1V 4Z5','(905) 420-7566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 00:08:16',0,NULL,3,1,3,1,'RA117733878CN\r ','casey*adg\rMOSA003'),(3926,583566443013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',2,'RELO002',25.96,'eastar4','asg_computers_shanib','shanibatebay@gmail.com','Shanib Rahman (Communities @ Work)','245 Cowlishaw St','Greenway','Australian Capital Territory','AUSTRALIA','2900','0402839621','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 00:18:10',0,NULL,3,1,2,1,'\\ ','asg_computers_shanib'),(3927,789532577012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','glenndalton','glenndalton@cox.net','Glenn Dalton','50 Weaver St','Cranston','RI','UNITED STATES','02920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 00:18:21',0,NULL,3,1,1,1,'\\ ','glenndalton'),(3928,789536236012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','onepartlove','liveaidrules@hotmail.com','Stephen  Bean','256 Old Salem Rd','Bozrah','CT','UNITED STATES','06334-1514','(860) 334-8164','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 00:33:06',0,NULL,3,1,1,1,'\\ ','onepartlove'),(3929,536827917004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.88,'cnfaner','mrzsward','mrzs.ward@gmail.com','Tanisha Hannah','12470 Browning Road 520','Greenwood','MS','UNITED STATES','38930-9528','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 00:40:24',0,NULL,3,1,1,1,'\\ ','mrzsward'),(3930,789556884012,220761218621,'Brand Shure E2c Sound Isolating headset transparent ver',1,'HSSH002',25.99,'eastar4','cope0409','ccope49@yahoo.com','CAROLYN COPELAND','1711 NE 132ND LN','TRENTON','FL','UNITED STATES','32693-8836','(330) 309-3406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 01:51:29',0,NULL,3,1,1,1,'\\ ','cope0409'),(3931,789556220012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','gredpv','v.dapontis@yahoo.gr','Vasilios Dapontis','ETH. ANTISTASEOS 51','HERAKLION CRETE','GREECE','GREECE','71306','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 01:54:14',0,NULL,3,1,2,1,'\\ ','gredpv'),(3932,789558666012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','mboi5622','boivin_martin@videotron.ca','Martin Boivin','192 rue Guillemette','Québec','QC','CANADA','G1B3M1','(418) 661-6702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 01:55:27',0,NULL,3,1,2,1,'\\ ','mboi5622'),(3933,710926277011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','bluefin97','burditt1@netzero.net','STEVE BURDITT','1400 Graham Dr<br>Ste B-268','Tomball','TX','UNITED STATES','77375-4603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 02:01:18',0,NULL,3,1,4,1,'YW865907970CN ','bluefin97'),(3934,710930158011,320700561477,'New genuine Samsung 3D Active Glasses SSG-2100AB ',1,'',71.99,'eastar4','vagnerar','vagnerpoa@terra.com.br','Vagner Rosa','Rua Cássio de Medeiros,760/109<br>Bairro: Tristeza','Porto Alegre','Rio Grande do Sul','BRAZIL','91900020','555193065722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-19 02:14:51',0,NULL,3,1,3,1,'RA117726381CN\r ','vagnerar\rGLSG001'),(3935,710934206011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',3,'WLAT003',95.7,'eastar4','afschulte','aschulte@cfl.rr.com','alfons schulte','3331 Hadleigh Crest','orlando','FL','UNITED STATES','32817','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 02:33:24',0,NULL,3,1,1,1,'\\ ','afschulte'),(3936,583595890013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','smbdyelse','whahappan@gmail.com','Vladimir Tolochko','Krivorojskaya St., 7/32','Moscow','RU','RUSSIAN FEDERATION','117638','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 02:48:36',0,NULL,3,1,3,1,'RA117733816CN\r ','smbdyelse\rWLIN002'),(3937,789577301012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','jrwarwick','joe@icon101.com.au','Joseph Warwick','Level 7, Tower Building Australia Square<br>264 George St','Sydney','New South Wales','AUSTRALIA','2000','0293836143','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 03:03:14',0,NULL,3,1,3,1,'RA117733820CN\r ','jrwarwick\rBAZA001'),(3938,583600485013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','reddy351','reddy351@wowway.com','Robert C. Eddy Jr','2766 Pontiac St','Columbus','OH','UNITED STATES','43211-1146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 03:13:50',0,NULL,3,1,1,1,NULL,'reddy351'),(3939,789583247012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','bodemkerendem','i_djohari@yahoo.com','Isa Djohari','Jl. Budi Raya No. 31<br>Komp. Pajak Kemanggisan','Jakarta Barat','DKI Jakarta','INDONESIA','11480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 03:33:03',0,NULL,3,1,2,1,NULL,'bodemkerendem\r红边优联'),(3940,710953341011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',29.99,'eastar4','howiejr7','langjr0@live.com','HOWARD LANG','1036 Marcus St','INDIAN LAND','SC','UNITED STATES','29707-1509','(803) 554-4871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 04:03:57',0,NULL,3,1,1,1,NULL,'howiejr7'),(3941,583613859013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',71.97,'eastar4','cc6848','carlos.coelho@iag.com.au','Carlos Coelho','Unit 1 / 2 Holker St<br>IAG Research Centre','Newington','New South Wales','AUSTRALIA','2127','0411011203','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 04:55:34',0,NULL,3,1,3,1,'RA117726829CN ','cc6848\rMOSA002'),(3942,710973919011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','hando_13','ebay@hanwright.com.au','Dyno Nobel c/o Steve Hanwright PH: 0419 723 513 or ext 3811','282 Paringa Rd<br>Murarrie','Brisbane','Queensland','AUSTRALIA','4172','0419723513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 06:05:44',0,NULL,3,1,2,1,NULL,'hando_13'),(3943,583623544013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','magulkn','marian.g@hotmail.com','Marian Gulis','Dataserv Ltd.<br>Hawthorne Road','Staines','Middlesex','UNITED KINGDOM','TW18 3AY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 06:09:09',0,NULL,3,0,2,1,' ','magulkn\rCAB-6060'),(3944,789331782012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',43.8,'eastar4','khald1981','waheeb1981@gmail.com','khald kaabau','kaabau כעביה','default','kaabau  כעביה','ISRAEL','30925','0544512150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 06:56:07',0,NULL,3,1,3,1,'RA117726537CN ','khald1981\rOTGR002'),(3945,710984776011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','idanatal2011','idanatal2010@walla.com','idan atal','ameyasdim 31 apt 3','kiryat atta','','ISRAEL','28000','972-52-5381318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 07:01:36',0,NULL,3,1,2,1,NULL,'idanatal2011'),(3946,789627994012,220695779881,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg',1,'HSPL001+CCPL001',15.8,'eastar4','sevicon','ebay@sevicon.com','Luis','C/ Forjadores nº 2 Bajo A','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','954942695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 07:17:56',0,NULL,8,1,17,0,NULL,'sevicon'),(3947,583633004013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',3,'HSPL001',35.4,'eastar4','sevicon','ebay@sevicon.com','Luis','C/ Forjadores nº 2 Bajo A','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','954942695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 07:20:03',0,NULL,3,1,3,1,'RA117733983CN ','sevicon\rHSPL001\r再发一个NEW PLANTRONICS EXPLORER 220 Bluetooth headset+carcharg'),(3948,789630429012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',24.59,'eastar4uk','nauxcuhp','ryanh_98144@yahoo.com','Phuc Huynh','13308 24th ave w','lynnwood','WA','UNITED STATES','98087-6076','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 07:29:24',0,NULL,3,1,1,1,'、 ','nauxcuhp'),(3949,583634258013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'eastar4','musicphoto','loongar@mail.ru','Ruslan Ropat','Internacionalnaya<br>39/59','Mozyr','Gomelskaya oblast','BELARUS','247760','+3750236342344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 07:33:22',0,NULL,3,1,3,1,'RA117733970CN ','musicphoto\rESI maya44 声卡\rOTES001\r'),(3950,583636064013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',75.99,'eastar4','wcor4615','coppertone2010@yahoo.com','william cording','11914 Briarleaf Way','san diego','CA','UNITED STATES','92128','(619) 532-1725','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 07:41:46',0,NULL,3,1,1,1,'\\ ','wcor4615'),(3951,789638137012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','tlarajhe','heikki.rajamaki1@saunalahti.fi','Heikki Rajamäki','Vaapukkapolku 7','Vantaa','','FINLAND','01690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 08:08:18',0,NULL,3,1,2,1,NULL,'tlarajhe\\\r'),(3952,710999290011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',11.99,'eastar4uk','srob2105','sallyrobinson1973@hotmail.co.uk','sally robinson','48 widley road<br>cosham','portsmouth','Hampshire','UNITED KINGDOM','PO6 2du','02392667009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 08:15:59',0,NULL,3,1,3,1,'RA117726832CN ','srob2105\rOMHJ001\r'),(3960,789667683012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','jmcesareo','janine_cesareo@hotmail.com','Janine Micallef Cesareo','60, Rhinestar<br>Triq il-Musbieh','Naxxar','','MALTA','Nxr 3644','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 10:08:15',0,NULL,3,1,2,1,'\\ ','jmcesareo\r欧标'),(3954,789655723012,220705652000,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET',1,'HSNO003',21.57,'eastar4uk','saybamu','say_bamu@rediffmail.com','Balamurugan','C/O Mr. Aravindan, #19, Anu Graha, Vivekanandha Street, Chelliamman Nagar, Otteri Extension<br>Vandalur,','Chennai','TN','INDIA','600048','9894349712','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 09:29:20',0,NULL,3,1,3,1,'RA117724037CN ','saybamu\rHSNO003'),(3955,711015601011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','123-roudoudou','eric.plazen@laposte.net','PLAZEN eric','lieu-dit BERGERAT','MONTJOIE en Couserans','Midi-Pyrénées','FRANCE','09200','0561048793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:32:43',0,NULL,3,1,2,1,'\\ ','123-roudoudou'),(3956,789615944012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','unolan','luan__on@hotmail.com','Luan On','152 Roberts St','Yarraville','Victoria','AUSTRALIA','3013','0451460755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:41:49',0,NULL,3,1,2,1,'\\ ','unolan\r红边优联'),(3957,580969410013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','motael123','tarekrules@hotmail.com','Tarek El-hamawi','284 Waterloo Road<br>Greenacre','Sydney','New South Wales','AUSTRALIA','2190','0297426405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:42:40',0,NULL,3,1,3,1,'RA117724045CN ','motael123'),(3958,707379668011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',15,'eastar4','vickygill18','vicky_gill18@yahoo.com.au','Davinder Singh','2/377 Regency Road','Prospect','South Australia','AUSTRALIA','5082','0430230035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:45:33',0,NULL,3,1,2,1,'\\ ','vickygill18\r澳标'),(3959,583656572013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.43,'eastar4','valerimsk','vkrav@hotmail.com','Valeri Kravtchenko','5/57 Hythe Street','Mount Druitt','New South Wales','AUSTRALIA','2770','0415887551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:58:32',0,NULL,3,1,2,1,'\\ ','valerimsk\racer 4pin1.25 15cm '),(3961,536913593004,140481828640,'GENUINE Plantronics Voyager 520 Bluetooth Headset trac#',1,'HSPL011',23,'cnfaner','stalker414','agentecstasy@gmail.com','Alexandr Nastaev','22 Flotskaya Str. App.138','Moscow','','RUSSIAN FEDERATION','125493','+79636699366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 10:11:34',0,NULL,3,1,3,1,'RA117726568CN ','stalker414\rHSPL011\r欧标'),(3962,789668305012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',12.95,'eastar4','kanatish','kanatish@hotmail.com','Ángel Roldán Córdoba','C/ Camino del caserio Nº8 Bajo C','Torrecaballeros','Castilla y León','SPAIN','40160','670697254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 10:11:40',0,NULL,3,1,2,1,'\\ ','kanatish'),(4008,790091987012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','bragmayer','bragmayer@orange.fr','bragmayer mike','21, avenue claude vellefaux','paris','Île-de-France','FRANCE','75010','+33672365895','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 07:33:27',0,NULL,3,1,3,1,'RA117723155CN ','bragmayer\r欧标\rHSPL014'),(3963,711028238011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',59.9,'eastar4','pb8472','pard@io.com','Richard Siggs c/o Groundhog Software','Level 4, 139 Frome Road','ADELAIDE','South Australia','AUSTRALIA','5000','61414882225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 10:26:11',0,NULL,3,1,3,1,'RA117726656CN ','pb8472\rHSPL009'),(3964,789677965012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.69,'eastar4','rrclerk','rrclerk68@gmail.com','Michael Eggleston','21 Langdon Park Dr','Kirkwood','NY','UNITED STATES','13795','(607) 775-1871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 10:46:54',0,NULL,3,1,1,1,'\\ ','rrclerk'),(3965,789682133012,220763368578,'D-Link DWL-G122 Wireless USB Adapter 802.11g 54M Ver.C1',1,'WLDL001',5.75,'eastar4uk','2212sue09','suesmith10@blueyonder.co.uk','suzanne smith','68 springfield','rainford','Merseyside','UNITED KINGDOM','wa11 7lp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 11:01:36',0,NULL,3,1,3,1,'RA117726642CN ','2212sue09\rWLDL001'),(3966,711042063011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.49,'eastar4','rads71','kha1971@gmail.com','Kha Nguyen','2630 N Albany Ave','Chicago','IL','UNITED STATES','60647','(773) 384-6689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 11:19:21',0,NULL,3,1,1,1,'\\ ','rads71'),(3967,711046952011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',22.99,'eastar4','svprpastry','george53@go.net.mt','George Mifsud','\'Stefania\' 225 Bastion Street','Fgura','','MALTA','FGR 1240','21691220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 11:38:52',0,NULL,3,1,2,1,'\\ ','svprpastry\r欧标'),(3968,531123704003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','bieloselhi','bobsuarez@mac.com','Bob Suarez','18 Turnberry Rd','Bourne','MA','UNITED STATES','02532-8318','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 12:19:05',0,NULL,3,1,1,1,'\\ ','bieloselhi'),(3969,583685629013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','thet.hein','thethein@yahoo.co.uk','Thet Hein','Flat - 2<br>70 Reads Avenue','Blackpool','Lancashire','UNITED KINGDOM','FY1 4DE','07946790576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 12:33:44',0,NULL,3,1,2,1,'\\ ','thet.hein\rCAB-6060'),(3970,789714844012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',159.96,'eastar4','james4f','james.yip.2010@gmail.com','James','13 Cameron Rd<br>Box Hill North','Melbourne','Victoria','AUSTRALIA','3129','0392214173','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-19 12:50:08',0,NULL,3,1,3,1,'RA117726687CN ','james4f\rOTSO004'),(3971,789726922012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',85.9,'eastar4','psychomush','ung.michael@gmail.com','Michael Ung','36 Northcote St','Naremburn','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 13:30:18',0,NULL,3,1,3,1,'RA117726639CN ','psychomush\rOTSO002'),(3972,531250780003,130458644453,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET track#',1,'HSNO015',35.99,'cnfaner','autobangarage0401','autobangarage@gmail.com','Aleksandr Luskarev','Zevulun 70/5','Kiryat-ata','','ISRAEL','28061','972-54-5282054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 14:21:21',0,NULL,3,1,3,1,'RA117726571CN ','autobangarage0401\rHSNO015'),(3973,788779782012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',5,'HSPL010',119.5,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 14:28:06',0,NULL,3,1,3,1,'RA117726599CN ','solopo2009\rHSPL010\r只发耳机'),(3974,711095236011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','clatza71','clatza@gmail.com','Luis Perez / Staybridge Suites Room 252','6103 LANDERHAVEN DR','Cleveland','OH','UNITED STATES','44124-4189','440 646 5000 252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 14:29:21',0,NULL,3,1,1,1,'\\ ','clatza71'),(3975,789760227012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','je$u$ete','mi-cuentica@hotmail.com','Jesus Andres Ezquerra Artigas','C/ El Globo 28, Esc. 4, 3º B','Zaragoza','Aragón','SPAIN','50015','976066373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:08:32',0,NULL,3,1,2,1,'\\ ','je$u$ete'),(3976,583716873013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',74.36,'eastar4','goopgive','goopgive.ebay@gmail.com','Chalika Jai-Ai','813/29 Kheha Chumchon Nawa Min Moo10 Nawamin Street<br>Khlong Kum Bueng Kum','Bangkok','Thailand','THAILAND','10230','066-834347898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:12:23',0,NULL,3,1,3,1,'RA117726801CN ','goopgive\rBAZA001\r新地址\rPeerapong Enguthaiwat\rAddress : 153-154 Posri Road \rMuang District \rUdornthani 41000\rTHAILAND\rTel : 081-6621313\r\r'),(3977,583727217013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','rexmantre','paul.seppala@pp.inet.fi','Paul Seppala','Vainamoisenkatu 7 E 81<br>33540','Tampere','','FINLAND','33540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:40:27',0,NULL,3,1,2,1,'\\ ','rexmantre\r欧标'),(3978,531268143003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',74.9,'cnfaner','arthurreis','arthurrs@ig.com.br','Arthur Reis Santos','Rua Otto Bender, 137<br>Mandaqui','São Paulo','SP','BRAZIL','02418-030','(5511) 8119-6120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:43:56',0,NULL,3,1,3,1,'RA117726585CN ','arthurreis\rMOSA002'),(3979,711124151011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','arthurreis','arthurrs@ig.com.br','Arthur Reis Santos','Rua Otto Bender, 137<br>Mandaqui','São Paulo','SP','BRAZIL','02418-030','(5511) 8119-6120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:52:18',0,NULL,3,1,3,1,'RA117726744CN ','arthurreis\rGLSG001'),(3980,536981986004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'cnfaner','diode78','diodeland@free.fr','Olivier Coulet','1, rue Mozart','Fontenay le Fleury','Île-de-France','FRANCE','78330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 16:02:16',0,NULL,3,1,3,1,'RA117726700CN ','diode78\rOTSO002'),(3981,583732225013,230622403729,'New Philips SHB6102 Bluetooth Stereo Headset  ',1,'HSJA007',74.9,'eastar4','falcon-kbng','keckboon@hotmail.com','keckboon ng','b49 #13-77 T.P Lor 5','default','','SINGAPORE','310049','06596266856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 16:30:58',0,NULL,3,1,3,1,'RA117723031CN ','falcon-kbng\rHSJA007'),(3982,789795695012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.4,'eastar4','pawel-lizak','pawel.lizak@wp.pl','Pawel Lizak','Podzwierzyniec 1F','Lezajsk','podkarpackie','POLAND','37300','600 599959','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 16:38:36',0,NULL,3,1,2,1,'\\ ','pawel-lizak\r欧标'),(3983,711150497011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','kingwonders','kingmiracles@me.com','Alexey Borisov','Bestugevich 21-163','Moskow','','RUSSIAN FEDERATION','127566','9166359342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:00:02',0,NULL,3,1,3,1,'RA117726758CN ','kingwonders\rUDAP001'),(3984,711154595011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','rafikichi','cory@coryb.net','Sutinen Consulting, Inc.','2111 30th Ave','Longview','WA','UNITED STATES','98632-3429','(360) 578-9144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 17:13:33',0,NULL,3,1,1,1,'\\ ','rafikichi\r新的'),(3985,711158694011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',44.79,'eastar4uk','kekomuirhead','keko@supanet.com','Kenny Muirhead','25 Big Brigs Way','Newtongrange','Midlothian','UNITED KINGDOM','eh22 4dg','01315619667','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 17:21:52',0,NULL,3,1,3,1,'RA117726695CN ','kekomuirhead\rGLSG001\r加到这行了'),(3986,711157294011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','tonydn','nhdang92@yahoo.com','Dang Nguyen','758 Heatherton Road','Springvale South','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:25:28',0,NULL,3,1,2,1,'\\ ','tonydn'),(3987,583757981013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',23.98,'eastar4','first_life','turkerakaras@hotmail.com','TÜRKER AKARAS','T.C. BASBAKANLIK DIS TICARET MUSTESARLIGI<br>BILGI ISLEM MERKEZI KAT 2 INONU BULVARI EMEK','ANKARA','','TURKEY','06510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:29:29',0,NULL,3,1,2,1,'\\ ','first_life\rHSMO018\r欧标'),(3988,583759521013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','darksidem2k','morin07@yahoo.com','Antonio Miguel Morin Rodriguez','Dacil 6','Puerto de la Cruz','Canarias','SPAIN','38400','922 38 01 39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:33:43',0,NULL,3,1,2,1,'\\ ','darksidem2k'),(3989,531322639003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',2,'OTGR001',39.8,'cnfaner','khald1981','waheeb1981@gmail.com','khald kaabau','kaabau כעביה','default','kaabau  כעביה','ISRAEL','30925','0544512150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 18:52:53',0,NULL,3,1,3,1,'RA117726608CN ','khald1981\rOTGR001'),(3990,711206262011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.96,'eastar4','bargain-village1','ebay3@knightxchange.co.uk','knight Xchange','88 Green Lane','Addlestone','Surrey','UNITED KINGDOM','KT15 2TH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:03:47',0,NULL,3,1,2,1,'\\ ','bargain-village1'),(3991,583796940013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','grigorij4483','sheleziaka1@mail.ru','Grigorij Semenihin','Internacional\'naja st, 51  111','Kursk','','RUSSIAN FEDERATION','305009','79102142451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:23:55',0,NULL,3,1,3,1,'RA117726673CN ','grigorij4483\rWLIN014'),(3992,711219211011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','gibarian1247','tomsgate@yahoo.fr','Thomas Hoffmann','82, rue d\'Abweiler','Bettembourg','','LUXEMBOURG','L-3211','516119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:30:24',0,NULL,3,0,2,1,'\\ ','gibarian1247'),(3993,583810037013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','taylordunn233','taylordunn233@hotmail.com','Nicolas Bergeron','3634 St-Léandre','Jonquière','QC','CANADA','G7X2B2','(418) 542-7962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:59:01',0,NULL,3,1,3,1,'RA117726611CN ','taylordunn233\rOTRA001'),(3994,789922311012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mel_217','m.panayiotou@ugrad.unimelb.edu.au','Melanie Panayiotou','3/129 Glen Huntly Rd','Elwood','Victoria','AUSTRALIA','3184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 21:03:21',0,NULL,3,1,2,1,'\\ ','mel_217\r红边优联'),(3995,711279286011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',115,'eastar4','turbosverre','jsverre@gmail.com','Jon Sverre Skaanes','Springvannsheia 2','Lillesand','Lillesand','NORWAY','4790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 21:52:19',0,NULL,3,0,3,1,'RA117726625CN ','turbosverre\rGLOT001*2\r申报30美金'),(3996,711282701011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','mentallo306','jk1@htp-tel.de','Jens Kretschmer','An der Landwehr 4 B','Hemmingen','','GERMANY','30966','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 22:03:18',0,NULL,3,1,3,1,'RA117726713CN ','mentallo306\rBR3D001'),(3997,789962878012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.99,'eastar4','simlego','tore.eriksson@mbox325.swipnet.se','Ingemar Eriksson','Gyllenstjärnas Väg 12 B','Karlskrona','','SWEDEN','S-37140','+46 455-690622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 22:37:05',0,NULL,3,1,2,1,'\\ ','simlego\r欧标'),(3998,583856143013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bertram1233','aznwond3r5@hotmail.com','Bertram Truong','1/142 Terrara Road','Melbourne','Victoria','AUSTRALIA','3133','0390056666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 22:46:31',0,NULL,3,1,2,1,NULL,'bertram1233'),(3999,711300031011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','russelr13','russler13@aol.com','Rich Russell','23006 Port St','Saint Clair Shores','MI','UNITED STATES','48082-1331','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 23:04:36',0,NULL,3,1,4,1,'YW866010995CN ','russelr13'),(4000,789997688012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','jorgehirata','hirata@jorgehirata.com','jorge hirata','rua tabapua 1590 ap61','sao paulo','sao paulo','BRAZIL','04533005','551130785182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 00:42:32',0,NULL,3,1,2,1,'\\ ','jorgehirata'),(4001,583883724013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',23.6,'eastar4','odessa702','jsmcmcw@yahoo.com','James McWilliams','1602 E 53rd St','Odessa','TX','UNITED STATES','79762-4382','(432) 550-0842','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 01:11:08',0,NULL,3,1,1,1,NULL,'odessa702'),(4002,537117275004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','padraiggux','padraigg@nortel.com','Padraig Guckian','28 Cook Street<br>Baulkham Hills','Sydney','New South Wales','AUSTRALIA','2153','0423603340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 01:14:26',0,NULL,3,1,3,1,'RA117724054CN ','padraiggux\rHSJA002\r澳标\r加到这行了'),(4003,583897717013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.9,'eastar4','bsj971','brett@josren.com.au','Brett Johnston','24-26 Doyle Ave','Unanderra','New South Wales','AUSTRALIA','2526','0402932005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 02:20:11',0,NULL,3,1,2,1,'\\ ','bsj971\r澳标\r银色的'),(4004,583904107013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','pengguj','pengguj2000@yahoo.com','pengguang jiang','2860 Geer Rd','turlock','CA','UNITED STATES','95382-1141','(209) 668-9988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 02:53:02',0,NULL,3,1,1,1,'\\ ','pengguj'),(4005,790045499012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','tullyking','tullyking@yahoo.com','Tony Sam','3324 vernice ave','san jose','CA','UNITED STATES','95127','(510) 304-0255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 03:50:41',0,NULL,3,1,1,1,'\\ ','tullyking'),(4006,790052919012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','zeone31','dewanashish@gmail.com','Ashish Dewan','124 Broadway Ave., Apt. #107','Toronto','ON','CANADA','M4P 1V8','(416) 786-0055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 04:26:49',0,NULL,3,1,3,1,'RA117723059CN ','zeone31\rHSPL014\r加到这行了'),(4007,790064882012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','more.tech.4.me','more.tech.for.u@gmail.com','ZHAO XIN HERBERT ANG','Blk 106 Jurong East St 13<br>#22-218','default','','SINGAPORE','600106','97868336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 05:28:51',0,NULL,3,1,11,1,NULL,'more.tech.4.me\r红边优联\rRELO003'),(4009,790093664012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',27.99,'eastar4uk','dddt_umpire','donald.hutchins@bigpond.com','Don Hutchins','76 Campbell','Ararat','Victoria','AUSTRALIA','3377','0353523232','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 07:42:31',0,NULL,3,1,3,1,'RA117723133CN ','dddt_umpire\rCMLO001'),(4010,790096989012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','dandan0000','d.jessup@talktalk.net','Dan Jessup','79 Woodhall Rise','Peterborough','Cambridgeshire','UNITED KINGDOM','PE45BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 07:55:56',0,NULL,3,1,3,1,'RA117723147CN ','dandan0000\rHSPL010\r英标'),(4011,711413160011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.43,'eastar4','a-r-g-i-n-y','arginy@tlen.pl','Andrzej Ujejski','4go-marca 8a4','Koszalin','zachodniopomorskie','POLAND','75708','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 08:16:07',0,NULL,3,1,2,1,'\\ ','a-r-g-i-n-y\racer 5pin1.25 4cm '),(4012,711424699011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','pazdurovci','annapazdur@gmail.com','Anna Pazdurova','Podbiel 32<br>Podbiel','Podbiel','Tvrdosin','SLOVAK REPUBLIC','027 42','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 09:07:57',0,NULL,3,1,2,1,'\\ ','pazdurovci\\'),(4013,790127301012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.99,'eastar4uk','countybroadband','ebay@countybroadband.net','County Broadband Ltd','The Old Chapel<br>33 Church Street','Coggeshall','Essex','UNITED KINGDOM','CO61TX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 10:01:36',0,NULL,3,1,3,1,'RA117723646CN\r ','countybroadband\rBALO007'),(4014,711438417011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','deathr0ll','massivekillingcapacity@gmail.com','David Gago Ferreira','C/ Miguel Bravo nº4 1ºD','Santander','Cantabria','SPAIN','39009','652378401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 10:08:28',0,NULL,3,1,2,1,NULL,'deathr0ll\\\r已发货'),(4015,790132710012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','thierry170764','tcostes@wanadoo.fr','Thierry COSTES','22, rue de Perpeigneux, SAULCHERY','CHARLY','Picardie','FRANCE','02310','0323700341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 10:25:16',0,NULL,3,1,2,1,'\\ ','thierry170764\r'),(4016,537196627004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'',17.4,'cnfaner','warren092003','mr_wrivera76@yahoo.com','Warren Rivera','118 ringwood crescent<br>southmead','bristol','Bristol','UNITED KINGDOM','bs10 5qy','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 10:25:35',0,NULL,3,0,3,1,'RA117723632CN\r ','warren092003\r'),(4017,790145812012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','azzouzi1969','azzouzimomo@yahoo.fr','Mohamed el Azzouzi','11 bd salvador allende barriol','arles','Provence-Alpes-Côte d\'Azur','FRANCE','13200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 11:10:41',0,NULL,3,1,2,1,'\\ ','azzouzi1969'),(4018,711458889011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','atari_2600','atari@twcny.rr.com','Joshua DeLorenzo','56 Jackim Rd','Oswego','NY','UNITED STATES','13126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 11:30:39',0,NULL,3,1,1,1,'\\ ','atari_2600'),(4019,790149532012,220741062544,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'eastar4','karen400109','xachkar@mail.ru','Karen Khachatryan','10 Verin Shengavith<br>2, #31','Yerevan','ARM','ARMENIA','0006','+37491400109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 11:31:20',0,NULL,3,1,2,1,'\\ ','karen400109'),(4020,711460586011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',5,'CASS002',43.5,'eastar4','has.2009','mete@eosbil.com.tr ','Mete Can GURCAN','Perpa B Blok Kat 6 No 653<br>Sisli','Istanbul','','TURKEY','34384','+90-532-668-1191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 11:37:18',0,NULL,3,1,3,1,'RA117723694CN\r ','has.2009\rCASS002'),(4021,711467089011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',115,'eastar4','musew','frankmarsh@iinet.net.au','Frank Marsh','PO Box 389','Hervey Bay','Queensland','AUSTRALIA','4655','0741248492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:03:40',0,NULL,3,1,3,1,'RA117738265CN\r ','musew\rGLOT001*2\r需问客户电视的型号  Panasonic Viera 3D TV is model TH-P50VT20A\r'),(4022,711475708011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',2,'HSJA005',35.98,'eastar4','theamitma','the.amitma@gmail.com','shlomo menachem','gafnovich 5','Hadera','Haifa','ISRAEL','38491','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:35:15',0,NULL,3,1,3,1,' RA117734017CN','theamitma\rHSJA005\r盒装的'),(4023,790194377012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','birdbrain2all','sbassettco@aol.com','Sharon Bassett','1038 W US Highway 24','Woodland Park','CO','UNITED STATES','80863-9201','(719) 687-7552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 13:47:55',0,NULL,3,1,1,1,'\\ ','birdbrain2all'),(4024,790208039012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','serokez67','serokez@yandex.ru','163015Sergey Posedelov','Leningradskiy 167/1 k.121','Arkhanelsk','','RUSSIAN FEDERATION','163015','911 557 6332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 14:26:38',0,NULL,3,1,2,1,'\\ ','serokez67\r欧标'),(4025,790055143012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','catherinexx','catherine@mattvowles.com','MATT VOWLES','4718 HALBRENT AVE','SHERMAN OAKS','CA','UNITED STATES','91403-2420','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 15:22:11',0,NULL,3,1,1,1,'\\ ','catherinexx'),(4026,537256048004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','irimia_mishpaha','yelenali@smile.net.il','ion irimia','shprintzak \"7a\" apartment \"14\"','petah tikva','','ISRAEL','49532','0508844683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:25:08',0,NULL,3,1,3,1,'RA117723805CN\r ','irimia_mishpaha\rOTGR001+OTGR002'),(4027,790228517012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','donkeyburger2001','crozzie@btopenworld.com','paul crosby','17 Braemar Road<br>Norton Canes','Cannock','Staffordshire','UNITED KINGDOM','WS119QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 15:26:15',0,NULL,3,1,3,1,'RA117723629CN\r ','donkeyburger2001\rOTCN003'),(4028,711529194011,320585224260,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',1,'WLIN009+ANTY002',22.95,'eastar4','olegich198529','eo85@yandex.ru','OLEG EPISHIN','Malkova st. 6 - 102','Perm','Permskiy kray','RUSSIAN FEDERATION','614087','(790) 972-9007 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:29:51',0,NULL,3,1,2,1,'\\','olegich198529'),(4029,711540076011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','tommytom2002','tommytom2002@web.de','Thomas Wagner','Schillerstrasse 25','Dachau','','GERMANY','85221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:55:34',0,NULL,3,1,2,1,'\\ ','tommytom2002'),(4030,790241814012,220741050719,'NEW GENUINE NOKIA BH-205 BLUETOOTH HEADSET BH 205',1,'HSNO009',15.5,'eastar4','6525moon6525','joaojmoura@gmail.com','João Moura (Ext.3311)','Rua Xavier Araujo,<br>Edificio Estação Laranjeiras','Lisboa','','PORTUGAL','1600-226','00351968355630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:58:08',0,NULL,3,1,2,1,'\\ ','6525moon6525\r欧标'),(4031,710193139011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','purple_tomato_designs','cmoliver@gmail.com','Charlotte Oliver','27 Kenneth Pl','Oceanside','NY','UNITED STATES','11572-3009','(917) 435-2075','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 16:02:25',0,NULL,3,1,1,1,'\\ ','purple_tomato_designs'),(4032,790244444012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','amanjiii','amanjii@web.de','aman nasir','langer steinweg 42','blomberg','','GERMANY','32825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 16:04:06',0,NULL,3,1,2,1,'\\ ','amanjiii\r红边优联'),(4033,537272755004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'cnfaner','sccs2','jimbr@sccsonline.com','Jim Bowsher','157 Adams St','Monte Vista','CO','UNITED STATES','81144-1421','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 16:33:25',0,NULL,3,1,4,1,'YW866011113CN ','sccs2'),(4034,584052368013,230393505746,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2101',12.43,'eastar4','xelose','xelose@gmail.com','Noah Young','621 29th st w','dickinson','nd','UNITED STATES','58601-2536','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 16:37:13',0,NULL,3,1,1,1,'\\ ','xelose'),(4035,790264778012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',39.99,'eastar4','mhillaby','mhillaby@gmail.com','Michael Hillaby','500-5 Alfred St','Pembroke','ON','CANADA','K8A 3B5','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mhillaby'),(4036,584037579013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'eastar4','balage001','speed.limit@freemail.hu','Tözser Balazs','Etele ter 3. fszt. 2.','Budapest','','HUNGARY','1115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 17:36:44',0,NULL,3,1,3,1,'RA117723703CN\r ','balage001\rCACN004'),(4037,790287630012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','dozdik22','sergei1970@yahoo.com','serggei sherman','barzelai<br>box-978','kiriyat shemona','','ISRAEL','10200','0507633740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 17:49:03',0,NULL,3,1,2,1,'\\ ','dozdik22\rASUS N554 蓝牙鼠标无接收器\r+manual'),(4038,584081059013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','djc13090','chaimo123@aol.com','Danny Chaimovitz','2893 Springdale ln','Boulder','CO','UNITED STATES','80303-7503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 18:14:05',0,NULL,3,1,1,1,'\\ ','djc13090'),(4039,790281398012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','6eric9','eric_barr@hotmail.com','Eric Barr c/o Sahuarita Auto','16301 S Santa Rita Rd','Sahuarita','AZ','UNITED STATES','85629','(520) 954-7776','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 18:36:17',0,NULL,3,1,1,1,'\\ ','6eric9'),(4040,584090333013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','companies_incorporated','kevinw@companiesinc.com','Kevin Wessell','28015 Smyth Dr','Santa Clarita','CA','UNITED STATES','91355','(661) 253-3303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 18:42:39',0,NULL,3,1,1,1,NULL,'companies_incorporated'),(4041,790330759012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','stewart5inpgh','stewart5inpgh@comcast.net','Robert Stewart','880 Old Mill Road','Pittsburgh','PA','UNITED STATES','15238','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 19:17:57',0,NULL,3,1,1,1,'\\ ','stewart5inpgh\r红边优联'),(4042,531618409003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','alzait','abualzait@gmail.com','Bilal Abualzait','Jubiha, Al malahi city street<br>mini market abu alzait 962-777766615','Amman PO Box 540102','','JORDAN','11937','(962) 777-7666 ext.: 15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 19:25:22',0,NULL,3,1,3,1,'RA117723685CN\r ','alzait\rHSPL005'),(4043,583508756013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','ecla4576','sporadicmotion@gmail.com','Edward Clark','1652 E 3rd Ave<br>Apt 203','Vancouver','BC','CANADA','V5R1G9','(778) 828-2947','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ecla4576'),(4044,790353892012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','markf9283','mark@septemberhouse.plus.com','Mark Feeney','September House, Potters Croft, Stone Rd,<br>Tittensor','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST12 9HB','01728373666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 20:07:16',0,NULL,3,1,3,1,'RA117724142CN\r ','markf9283\rOTGR001'),(4045,711646023011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',44.79,'eastar4uk','branko2222','milos.andoljsek@telemach.net','Anže Andoljšek','Preglov Trg 2','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 20:11:39',0,NULL,3,1,3,1,'RA117733966CN\r ','branko2222\rGLSG001'),(4046,790356737012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.99,'eastar4','ghil3950','preciousocs@msn.com','Gary Hill','PO BOX 6361','Cleveland','OH','UNITED STATES','44101','(216) 324-1374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 20:12:08',0,NULL,3,1,1,1,'\\ ','ghil3950'),(4047,790357913012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',80.98,'eastar4','raphael-2234','kidtaveira@globo.com','luiz jose taveira neto','avenida independencia quadra 121,lote 4<br>distrito federal','planaltina','distrito federal','BRAZIL','73330005','(55)6133887132','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-20 20:14:46',0,NULL,3,1,3,1,'RA117724010CN\r ','raphael-2234\rOTSO004\r申报50美金'),(4048,711644671011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','joea40179','joea40179@aol.com','Joe W. Amador','1589 Ward Ct','The Villages','FL','UNITED STATES','32162-6142','(352) 350-6220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 20:19:43',0,NULL,3,1,1,1,'\\ ','joea40179'),(4049,537335511004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',3,'HSJA002',64.5,'cnfaner','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 20:20:44',0,NULL,5,1,18,1,' ','vjendrisvelimir  \r欧标'),(4050,790364984012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',24.97,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 20:32:58',0,NULL,3,1,2,1,'\\ ','masteroll2010\r一共买了\r一个红边优联\r一个NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse \r'),(4051,790365903012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','florilor','sbyzgu@sbcglobal.net','Sergey Biletsky','800 Elgin Rd<br>Apt 1413','EVANSTON','IL','UNITED STATES','60201-5629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 20:33:34',0,NULL,3,1,1,1,'\\ ','florilor'),(4052,711669585011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',19,'eastar4uk','bckloon','kgfraser@mac.com','Keith Fraser','77, BUCKIE ROAD','ABERDEEN','Aberdeen City','UNITED KINGDOM','AB228DN','07776194596','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 21:09:54',0,NULL,3,1,3,1,'RA117738067CN\r ','bckloon\rMOAP001'),(4053,787256895012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','shopgodness','robinalexandra@hotmail.com','Heleen van Dam','Boeroestraat 13','Wormerveer','','NETHERLANDS','1521SJ','0651466804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 22:16:44',0,NULL,3,1,2,1,'\\ ','shopgodness\r红边优联'),(4054,711695928011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','zdomex','zdomex@aol.com','zbigniew domek','22364 Dupree Dr','Land O Lakes','FL','UNITED STATES','34639-3466','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 22:34:58',0,NULL,3,1,1,1,'\\ ','zdomex'),(4055,790418834012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','s_skifin','skifin@gmail.com','Valery Karavalis','Struma 6h/5','Haifa','','ISRAEL','35708','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 23:04:48',0,NULL,3,1,2,1,'\\','s_skifin'),(4056,711715050011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','marcelobyms','byms@hotmail.com','Marcelo Siqueira','Rua Aiuba, 89<br>Anchieta','Rio de Janeiro','RJ','BRAZIL','21630-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 23:59:48',0,NULL,3,1,2,1,'\\ ','marcelobyms'),(4057,584175686013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',11.8,'eastar4','kclo4563','kclod70@live.com','Kirby Clodfelter','2828 S. H. 21 W. #96','Bryan','TX','UNITED STATES','77803','(979) 775-4026','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 00:38:35',0,NULL,3,1,1,1,'\\ ','kclo4563'),(4058,790441512012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',2,'MOLO006',53.98,'eastar4','triad727','tate.handy@gmail.com','Tate Handy','312 Candlewyck Dr<br>apt 1824','Kalamazoo','MI','UNITED STATES','49001','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 00:39:35',0,NULL,3,1,1,1,'\\ ','triad727'),(4059,711727723011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','meganuke76','meganuke76ebay@yahoo.com','Oscar Moreno','11930 Steppingstone Blvd','Tampa','FL','UNITED STATES','33635-6260','(831) 915-0346','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 01:01:14',0,NULL,3,1,1,1,'\\ ','meganuke76'),(4060,711730823011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','larryw4395','lbw1@pge.com','Larry  Wise','1683 Bella Vista Ct','Paso Robles','CA','UNITED STATES','93446-6372','(805) 226-0393','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 01:20:12',0,NULL,3,1,1,1,'\\ ','larryw4395'),(4061,711735326011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','adriana3052','adi_670@hotmail.com','adriana vieyra','1628 summertime dr','el cajon','CA','UNITED STATES','92021','(619) 938-4344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 01:39:57',0,NULL,3,1,1,1,'\\ ','adriana3052'),(4062,711735494011,320678793994,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',9.26,'eastar4uk','the-last-vampire','paranormalcy@live.com.au','Chrie lynn Puime','15 wrybourne street','deception bay','Queensland','AUSTRALIA','4508','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'the-last-vampire'),(4063,790459854012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','peoplesoftie','donigan_md@comcast.net','Michael D Donigan','240 NATOMA STATION DR<br>APT 256','FOLSOM','CA','UNITED STATES','95630-7991','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 02:01:25',0,NULL,3,1,1,1,'\\ ','peoplesoftie\r红边优联'),(4064,711739987011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','17ogglethorpe','rooney523@rogers.com','Jamie Rooney','1075 Nellie Little Cres','Newmarket','ON','CANADA','L3X 3E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 02:06:13',0,NULL,3,1,2,1,'\\ ','17ogglethorpe'),(4065,531695177003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',2,'OTGR001',39.8,'cnfaner','antisynclastic','greg@gregkillen.com','Greg Killen','18 Wool Street<br>Toowong','Brisbane','Queensland','AUSTRALIA','4066','0733715599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 02:21:43',0,NULL,3,1,3,1,'RA117723779CN\r ','antisynclastic\rOTGR001'),(4066,584197660013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.5,'eastar4','manglu_ooo','hotsam_ken@msn.com','Jingfeng Sang','618 Jersey St<br>FL 2','Harrison','NJ','UNITED STATES','07029-1814','(973) 204-4787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 02:59:43',0,NULL,3,1,1,1,'\\','manglu_ooo'),(4067,711757054011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',14.99,'eastar4','kruga1955','kruga@tpg.com.au','Brian Schnabel','c/- Kempe Supply Group<br>unit 2,  100 pipe Rd','Laverton North','Victoria','AUSTRALIA','3026','0407822216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 03:38:13',0,NULL,3,1,2,1,'\\ ','kruga1955\r澳标'),(4068,790481269012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.95,'eastar4','fernyusa13','fernyusa@hotmail.com','Fernando Rofrano','Varela 818','Buenos aires','Capital Federal','ARGENTINA','1406','00549111561720976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 03:43:09',0,NULL,3,1,3,1,'RA117724108CN\r ','fernyusa13\rHSMO020'),(4069,711759531011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',27.98,'eastar4','rbta007','robarr007@gmail.com','Roberto Arrastia','6 Prospect Hill Crescent','Dandenong North','Victoria','AUSTRALIA','3175','0397958473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 03:51:42',0,NULL,3,1,2,1,'\\ ','rbta007\rHP 5pin1.0 20cm '),(4070,790484116012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','tompkins4zwp','info@tfgglobal.com','TFG Global Insurance Solutions Ltd.','#216 - 2438 Marine Drive','West Vancouver','BC','CANADA','V7V 1L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 04:00:36',0,NULL,3,1,2,1,'\\ ','tompkins4zwp'),(4071,711761771011,320618274704,'New 3.0 Bluetooth BCM2070 Module+cable HP mini5101 5102',1,'BTHP3003',27.98,'eastar4','chris_kts','callchrischan@gmail.com','Chris Chan','7 Empire Ave.<br>Blakehurst','Sydney','New South Wales','AUSTRALIA','2221','610405386078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 04:04:58',0,NULL,3,1,2,1,'\\ ','chris_kts\rHp 8pin1.0 3cm '),(4072,584214744013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'eastar4','amaperson','jebusbando@gmail.com','Steven Drenning Jr','16415 Woodson Crest Rd','Ramona','CA','UNITED STATES','92065','(760) 239-1106','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 05:17:29',0,NULL,3,1,1,1,'\\ ','amaperson'),(4073,711783086011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',14.9,'eastar4uk','dazzzydarren','darrenphillips68@googlemail.com','DARREN PHILLIPS','1 LLEWELLYN STREET','MERTHYR TYDFIL','Merthyr Tydfil','UNITED KINGDOM','CF47 8SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 06:17:53',0,NULL,3,1,3,1,'RA117723748CN\r ','dazzzydarren\rHSJA002\r英标'),(4074,790543717012,220502334354,'2.1 HP V2000 V2100 V2200 Bluetooth Module EDR +cable',2,'BTHP2109',24.86,'eastar4','danilorcesar','danilorcesar@ig.com.br','Danilo55 César','Rua Sergio Carvalho 100<br>Bairro: Federação','Salvador','Bahia','BRAZIL','40230-680','71 92086985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 08:56:25',0,NULL,3,1,2,1,'\\ ','danilorcesar\rHP 8pin 1.25 3cm'),(4075,711818126011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','agjell','andreas@gjellesvik.no','Andreas Jensen Gjellesvik','Biskop Jens Nilssons gt 28','Oslo','','NORWAY','N-0659','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 09:03:20',0,NULL,3,1,2,1,'\\ ','agjell'),(4076,711833672011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',65,'eastar4','sergey430','sergey430@msn.com','sergey visotskiy','9730 27th ave se','Everett','WA','UNITED STATES','98208-4325','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 10:07:32',0,NULL,3,1,1,1,'\\ ','sergey430\r需问客户电视的型号'),(4077,584259715013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.95,'eastar4','eabreu73','estabreu@gmail.com','Estevão Abreu','RUA DO RIBEIRINHO Nº 33 C','Funchal','','PORTUGAL','9050-447','+351962919896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 10:14:31',0,NULL,3,1,3,1,'RA117723734CN\r ','eabreu73\rMOSA002'),(4078,711850217011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','clai7','clai7@hotmail.com','CHIN LAI','13077 BLUFF CREEK DRIVE','PLAYA VISTA','CA','UNITED STATES','90094','(310) 439-2448','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 11:10:42',0,NULL,5,0,18,0,NULL,'clai7\r客户要撤单已退款'),(4079,790589714012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',33.99,'eastar4','ohioboyo','ohioboyo@yahoo.com','Raymond Eldreth','1447 Lupe Ave NW','North Canton','OH','UNITED STATES','44720-1631','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 11:41:09',0,NULL,3,1,1,1,'\\ ','ohioboyo'),(4080,790599022012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',10.99,'eastar4uk','les4991','lescox1@btinternet.com','LES COX','6 HILLVIEW LANE, GREAT BILLINGTON','LEIGHTON BUZZARD','Bedfordshire','UNITED KINGDOM','LU79BH','01525852229','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 12:08:12',0,NULL,3,1,3,1,'RA117723677CN\r ','les4991\rHSMO011+CCMO001'),(4081,790598971012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','gmacnaught','boondocks@centurylink.net','Gary MacNaught','HC 67 Box 69X','Mountain View','MO','UNITED STATES','65548-9005','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 12:09:59',0,NULL,3,1,1,1,'\\ ','gmacnaught'),(4082,531785653003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',19.9,'cnfaner','marting811','martingruen@aon.at','Martin Grün','Platti 317','Kappl','','AUSTRIA','6555','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 12:24:10',0,NULL,3,1,3,1,'RA117723535CN\r ','marting811\r澳标\rHSNO016'),(4083,711896581011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','lico666','pecherkin@ou4.ru','Shubin Igor','Novosibirskaja, 24-45','Perm','Permskij','RUSSIAN FEDERATION','614033','79091080131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 13:47:35',0,NULL,3,1,2,1,'\\ ','lico666'),(4084,790644605012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','krzysiek26','reksiu1@vp.pl','KRZYSZTOF MAJEWSKI','6 STOCKWOOD MEWS<br>ROCKINGHAM ROAD','CORBY','Northamptonshire','UNITED KINGDOM','NN171 AH','05602308666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 14:21:16',0,NULL,3,1,3,1,'RA117723663CN\r ','krzysiek26\rHSPL010\r英标'),(4085,790643671012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','dang.sweden','sud_dang@yahoo.com','Sudhanshu Dang','Utövagen 26<br>Saltsjö-Boo, Nacka','Stockholm','','SWEDEN','13230','+46737075876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 14:23:02',0,NULL,3,1,2,1,'\\ ','dang.sweden'),(4086,584316568013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','unaimg91','unimg@hotmail.com','Unai Márquez','CTamarit 147 2º2ª','Barcelona','BARCELONA','SPAIN','08015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 14:43:08',0,NULL,3,1,2,1,NULL,'unaimg91'),(4087,584327983013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.95,'eastar4','chikdani','dvalding@yahoo.com','Daniela Val','91 Westland Ave<br>Apt 118','Boston','MA','UNITED STATES','02115-3825','(774) 444-5455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 15:27:30',0,NULL,3,1,1,1,'\\ ','chikdani'),(4088,790690175012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','wireless0404','wireless0303@aol.com','Pat LAgana','240 Halstead Ave','Harrison','NY','UNITED STATES','10528-3639','(914) 447-0303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 16:14:55',0,NULL,3,1,1,1,'\\ ','wireless0404'),(4089,584344025013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','shu270324','sssh54@yandex.ru','Sergey Shust','ul. Krasnie zori, dom 15,kv 8','Obninsk','Kaluga','RUSSIAN FEDERATION','249037','7-9105192190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 16:25:43',0,NULL,3,1,3,1,'RA117723751CN\r ','shu270324\rOTRA001'),(4090,711954110011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','dagkajander','dkajand@online.no','Dag Kajander','Bjørnhaugveien 9','Kabelvåg','','NORWAY','8310','+4791594546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 16:30:29',0,NULL,3,1,3,1,'RA117723725CN\r ','dagkajander\rWLAP003\r新的'),(4091,531847462003,130490221415,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'cnfaner','mik-pompey','mikul_patel@hotmail.com','Mikul Patel','32 Nonsuch Walk','Cheam','Surrey','UNITED KINGDOM','SM2 7NG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 16:52:03',0,NULL,3,1,3,1,'RA117723796CN\r ','mik-pompey\rRELO002'),(4092,711981057011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','paulofusapaul','paulofusa@yahoo.com','Paul Feinberg','2007 Via Aguila','San Clemente','CA','UNITED STATES','92673-5671','(949) 492-5011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 17:34:37',0,NULL,3,1,1,1,'\\ ','paulofusapaul'),(4093,711979944011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','back2collection','inmysmallroom@hotmail.com','Linda Kraivanich','25/601-602<br>Moo 3, Bangyaprak','Muang','Samutsakorn','THAILAND','74000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 17:40:21',0,NULL,3,1,2,1,'\\ ','back2collection'),(4094,785429246012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','kaczor0514','piotrkaczmarek74@yahoo.com','Piotr Kaczmarek','4a Russell Parade<br>Golders Green','London','London','UNITED KINGDOM','Nw11 9Nn','4407564688','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-21 17:41:01',0,NULL,3,1,3,1,'RA117723717CN\r ','kaczor0514\rOTCR001'),(4095,584380275013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',21.9,'eastar4','203samiriss23','samiriss29@hotmail.com','samira bouderka','17 Fairfield Ave<br>Apt 31','norwalk','CT','UNITED STATES','06854-2156','(203) 551-0003','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-21 18:29:10',0,NULL,3,1,1,1,'\\ ','203samiriss23'),(4096,790753319012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','w3bmw','etkenterprises@yahoo.com','Edward T Karsin','108 August Dr','Coraopolis','PA','UNITED STATES','15108-3402','(412) 859-3563','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 18:32:10',0,NULL,3,1,1,1,'\\ ','w3bmw'),(4097,790758242012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jon9538','jonbuxer@hotmail.com','jon buxer','3720 Stone Canyon Ave','Sherman Oaks','CA','UNITED STATES','91403','(818) 990-2921','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 18:44:04',0,NULL,3,1,1,1,'\\ ','jon9538'),(4098,790766838012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','007numbnuts','thegrovesnw@yahoo.co.uk','Sean Tierney','62, Egton Street,New Cleveland Street','Hull','Humberside','UNITED KINGDOM','HU87HU','01482219887','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 19:00:33',0,NULL,3,1,3,1,'RA117723460CN\r ','007numbnuts\rOTCN003'),(4099,584401885013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','bvika','bernt.vika@moelven.no','Bernt Vika','Tyttebærhausen','Sundebru','','NORWAY','4993','90059015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 19:34:21',0,NULL,3,1,17,0,NULL,'bvika'),(4100,712033100011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',3,'HSNO019+CCNO001',136.5,'eastar4','bvika','bernt.vika@moelven.no','Bernt Vika','Tyttebærhausen','Sundebru','','NORWAY','4993','90059015','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-21 19:34:22',0,NULL,3,1,3,1,'RA117738141CN\r ','bvika\rHSNO019+CCNO001+WLDL001\r再发一个D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter\r申报gift  20美金\r'),(4101,790797601012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','mnsherry','sherrycarmichael@yahoo.com','Sherry  Carmichael','604 S Wall ST','Montfort','WI','UNITED STATES','53569-9795','(608) 354-7450','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 20:14:31',0,NULL,3,1,1,1,'\\ ','mnsherry'),(4102,711824400011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','sergey199rus','mrsuperprofessor@gmail.com','Sergey Ermishin','Proletarskij prospekt dom 1 kv. 426','Moscow','','RUSSIAN FEDERATION','115522','74953209684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 20:20:47',0,NULL,3,1,2,1,'\\ ','sergey199rus\r欧标'),(4103,790781324012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.43,'eastar4','jeck60','berlogin@mail.ru','Евгений Берлогин','пр.Ленина, д.53, кв.50','Ухта','Республика Коми','RUSSIAN FEDERATION','169312','9129476474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 20:26:27',0,NULL,3,1,2,1,'\\ ','jeck60\rAcer 5pin1.25 3cm\r新地址\rEvgeni Berlogin\rProspekt Lenina, dom 53, kv50\rUkhta, Respublika Komi, 169312\rRussian Federation\rphone: +79129476474\r\r'),(4104,712077522011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','chrisdandy','cbutryn@gmail.com','Chris Butryn','1153 Glen Valley Rd','Oakville','ON','CANADA','L6M 3K2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 21:23:38',0,NULL,3,0,2,1,'\\ ','chrisdandy'),(4105,584434699013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','eymiha','eymiha@gmail.com','David Anderson','1145 Olivia Ln','Cincinnati','OH','UNITED STATES','45238-4517','(513) 921-3361','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-21 21:25:38',0,NULL,3,1,1,1,NULL,'eymiha'),(4106,712084874011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',157,'eastar4','xlinkersx','xlinkersx@gmail.com','Pierre-Olivier Fillion','5-373 Mohammed-El-Sabh','RIMOUSKI','QC','CANADA','G5M 0E1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-21 21:43:54',0,NULL,3,0,3,1,'RA117724071CN\r ','xlinkersx\rOTSO004*2'),(4107,584445862013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.2,'eastar4','drkifailclown','bax.michel@gmail.com','michel Bax','52 bis rue Etienne Dolet','Alfortville','Ile-de-France','FRANCE','94140','06 62 82 46 59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 22:12:01',0,NULL,3,1,3,1,'RA117723544CN\r ','drkifailclown\rWWSI004+ANCN001'),(4108,712106031011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','flak!','home@jm-sangermann.de','John Marc Sangermann','An den Hässeln 18-20','Olpe','','GERMANY','57462','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 22:59:43',0,NULL,3,1,2,1,'\\ ','flak!'),(4109,537126854004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',81.98,'cnfaner','ifcc','ivanfleury@gmail.com','Ivan Curado','SQS 310 Bloco G Apt 606<br>Asa Sul','Brasilia','DF','BRAZIL','70363-070','+556181709300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 00:34:22',0,NULL,3,1,3,1,'RA117724099CN\r ','ifcc\rOTRA001\r带CD\r一共买了两个\r'),(4110,712130809011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','mcas5060','williebones@aol.com','madeline castro','957 east 105th st','new york','NY','UNITED STATES','11236','(718) 257-1420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 00:47:07',0,NULL,3,1,1,1,'\\ ','mcas5060'),(4111,790893395012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',10.69,'eastar4','franchuspc','franhorv@gmail.com','Laszlo Francisco Horvath','la pampa 2802<br> 1ro \"F\"','Capital Federal','Buenos Aires','ARGENTINA','1428','114-785-2330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 00:53:36',0,NULL,3,1,2,1,'\\ ','franchuspc'),(4112,790894385012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',14.99,'eastar4uk','jmkoz','kenny.johnm@gmail.com','John Kenny','11 Lucerne Street','Ashburton','Victoria','AUSTRALIA','3147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 00:57:52',0,NULL,3,1,2,1,'\\ ','jmkoz'),(4113,712138077011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','wildman4u','thelaw1@sbcglobal.net','jerry law','434 N. 5th St','Wood River','IL','UNITED STATES','62095-1706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 01:22:12',0,NULL,3,1,1,1,'\\ ','wildman4u'),(4114,712139924011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',2,'BTHP2107',24.86,'eastar4','rraha1','rahara@cox.net','Randall Raha','725 Gullwing Ln','North Las Vegas','NV','UNITED STATES','89081-3103','(702) 399-0906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 01:31:11',0,NULL,3,1,1,1,NULL,'rraha1\rHP 8pin 1.0 23cm '),(4115,790910111012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','cockyboy69','zebenir@hotmail.com','David Robinson','1222 W Baseline #161','Tempe','AZ','UNITED STATES','85283','(480) 221-4565','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 02:04:23',0,NULL,3,1,1,1,'\\ ','cockyboy69\r红边优联'),(4116,712150607011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','loupenz','petersquires@squiresmarine.com','Peter Squires','1259 Kaipara Coast Highway<br>RD4 Warkworth','Auckland','Auckland','NEW ZEALAND','0984','021 2518707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 02:18:25',0,NULL,3,1,3,1,'RA117724085CN\r ','loupenz\rGLSG001*2'),(4117,712152447011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','matthewb561','paradigmplumbing@aol.com','Paradigm Plumbing','878 Taft Ct','Palm Beach Gardens','FL','UNITED STATES','33410-1567','(561) 776-5604','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 02:26:06',0,NULL,3,1,1,1,'\\ ','matthewb561\rINOVA(爱诺华) T4 手电 光杯版电池'),(4118,712159961011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','bredbu','davebredbury@gmail.com','David Bredbury','535 n oneil st','clayton','NC','UNITED STATES','27520-1806','(727) 271-6509','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 03:01:57',0,NULL,3,1,1,1,'\\ ','bredbu'),(4119,790930087012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','hayslett','thayslett@bak.rr.com','Thomas Hayslett','9213 Eastwind Cir','Bakersfield','CA','UNITED STATES','93306','(661) 363-5297','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 03:32:29',0,NULL,3,1,1,1,'\\ ','hayslett\r新的'),(4120,790930099012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','dtieva','dannytieva@hotmail.com','Daniel Tieva','co Cathy Fiore sw 229<br>MMC 300 2nd Ave','Long Branch','NJ','UNITED STATES','07740','(317) 224-4906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 03:34:34',0,NULL,3,1,1,1,'\\ ','dtieva'),(4121,790932166012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',2,'OTPL001',94,'eastar4','janineandglen','janine.johnson5764@yahoo.ca','Janine Johnson','10119 Robison Avenue','Hudson Hope','BC','CANADA','V0C 1V0','(250) 783-0585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 03:42:02',0,NULL,3,1,3,1,'RA117738787CN ','janineandglen\rOTPL001\rplantronics 音频发射器'),(4122,790940659012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',2,'HSPL014',67.98,'eastar4','jaymew1','ebay@numail.org','Jayme Williams','45 Barclay Court','Newnan','GA','UNITED STATES','30263','(770) 254-9444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 04:24:45',0,NULL,3,1,1,1,'\\ ','jaymew1'),(4123,790939877012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',2,'HSPL011',46,'eastar4','dimiller743','dimiller74@yahoo.com','Dolly  Miller','PO BOX 5787','Pagosa SPrings','CO','UNITED STATES','81147-5787','(970) 422-4266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 04:24:58',0,NULL,3,1,1,1,'\\ ','dimiller743'),(4124,712176504011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.95,'eastar4','sharifzada','yassam88@bigpond.com.au','Amin Mahmood','45 Fleet St','Narre Warren South','Victoria','AUSTRALIA','3805','0420977876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 04:31:49',0,NULL,3,1,2,1,'\\ ','sharifzada\r澳标'),(4125,712177610011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','bkbharkhada','bkbharkhada@yahoo.com','Bharat Bharkhada','451 TOWN PLACE CIR<br>Apt 506','Buffalo Grove','IL','UNITED STATES','60089-6734','(215) 586-1090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 04:48:56',0,NULL,3,1,1,1,'\\ ','bkbharkhada'),(4126,790948906012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','donellis88','don@donellis.com','Don Ellis','c/o McCann Erickson (CXCT)<br>22/F, Sunning Plaza; 10 Hysan Avenue; Causeway Bay','default','','HONG KONG','default','(852) 9377 7105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 05:09:33',0,NULL,3,1,2,1,'\\ ','donellis88'),(4127,584497320013,230622403729,'New Philips SHB6102 Bluetooth Stereo Headset  ',1,'HSJA007',74.9,'eastar4','i7andiass','anderson.dias@vezell.com','Anderson Silva','Rua Almirante Calheiros, 201 - Apto 164','Sao Paulo','SP','BRAZIL','03066070','(551) 180-8393 ext.: 55','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 05:32:40',0,NULL,3,1,3,1,'RA117738800CN ','i7andiass\rHSPH001\r美标'),(4128,712187115011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','wernerschulz1','david-julian@gmx.de','David Krips','Dachauer Str. 27','München','','GERMANY','80335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 05:38:39',0,NULL,3,1,2,1,'\\ ','wernerschulz1'),(4129,790980509012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','gobion','iain_andrew@bigfoot.com','Mr Iain Andrew','SVP, 1st Floor, Dnata Travel Centre<br>Sheikh Zayed Road','Dubai','','UNITED ARAB EMIRATES','po box 1515','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 07:37:22',0,NULL,3,1,3,1,'RA117723495CN\r ','gobion\rBAZA001'),(4130,790983140012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','kmelich.1108','kmelich@gmail.com','Kenneth Melich','28900 SW Villebois Dr N Apt 402','Wilsonville','OR','UNITED STATES','97070','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 07:43:27',0,NULL,3,1,1,1,'\\ ','kmelich.1108'),(4131,712236463011,320701428027,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',74.99,'eastar4','yogie_golf','snvhunt@gmail.com','Scott Hunt','46 Bradley\'s Road','North Avoca','New South Wales','AUSTRALIA','2260','0418476599','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 08:55:59',0,NULL,3,1,3,1,'RA117723487CN\r ','yogie_golf\rOTSO001'),(4132,791007045012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','arsanbe','artin_15645@yahoo.com','Artin BarzegarEskandari','457 W Lexington Dr<br>Apt 211','Glendale','CA','UNITED STATES','91203','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 08:56:34',0,NULL,3,0,1,1,'\\ ','arsanbe\r白色的'),(4133,584561191013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','kupokomapa','kupokomapa@gmail.com','Kiril Angov','21 Nikolay Gogol St<br>apt 12, floor 4','Yavorov','Sofia','BULGARIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 09:25:43',0,NULL,3,1,2,1,'\\ ','kupokomapa'),(4134,712255539011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.76,'eastar4','juniorin','danyelsil@terra.es','Daniel Silván Redondo','C/Mayor, 3','Albares de la Ribera (Leon)','Castilla y León','SPAIN','24310','625345814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 09:48:21',0,NULL,3,1,3,1,'RA117723527CN\r ','juniorin\rMOSA001'),(4135,791061273012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','07oscar07','jpoppy@tpg.com.au','Joseph Poppelock','30 BISDEE STREET','CORAL COVE','Queensland','AUSTRALIA','4670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 11:09:28',0,NULL,3,1,2,1,'\\ ','07oscar07'),(4136,791072257012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',38.5,'eastar4uk','emilpanum','emil88dk@gmail.com','Emil Kold Panum','Vilhelminevej 18 1.','Odense','Fyn','DENMARK','5000','+4528999531','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 11:33:45',0,NULL,3,1,3,1,'RA117723558CN\r ','emilpanum\rWWSI006+ANCN001'),(4137,791077969012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',24.5,'eastar4uk','konnijo','sir.konner@yahoo.de','Konrad Junghanß','Hechtstrasse 37<br>(2. OG Mitte)','DRESDEN','','GERMANY','01097','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 11:47:12',0,NULL,3,1,3,1,'RA117723513CN\r ','konnijo\rWWSI002'),(4138,584603499013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','jul4ik1003','julia-10031989@yandex.ru','Julia Massold','Poststrasse 15','Wächtersbach','','GERMANY','63607','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 11:56:36',0,NULL,3,1,2,1,'\\ ','jul4ik1003 '),(4139,537785788004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',21.9,'cnfaner','sky1sky2','sky1sky10@gmail.com','loui kheir','P.O.BOX 8656','TEL-AVIV-YAFO','','ISRAEL','61086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 12:07:09',0,NULL,3,1,3,1,'RA117723822CN\r ','sky1sky2\rOTHP004'),(4140,712324212011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','cp97','carlp@carlphillips.com','Carl Phillips','37 Malthouse Road','Manningtree','Essex','UNITED KINGDOM','CO11 1BY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 12:37:25',0,NULL,3,1,2,1,'\\ ','cp97'),(4141,584615763013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',19.9,'eastar4','mein-fusion','meinfusion@aol.com','Stefan Korte','c/o H. Hermann Ehlers GmbH<br>An der Autobahn 45','Oyten','','GERMANY','28876','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 12:37:50',0,NULL,3,1,2,1,'\\ ','mein-fusion\r欧标'),(4142,791106140012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','mikeysantella','mikeysantella@hotmail.com','Michael Santella','9301 Glenville Rd','Silver Spring','MD','UNITED STATES','20901-3638','(202) 413-4710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 12:48:03',0,NULL,3,0,1,1,'\\ ','mikeysantella'),(4143,712355201011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','gilligan110','jkgillund@q.com','Jay M. Gillund','3475 24th Ave','Marion','IA','UNITED STATES','52302-1478','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 13:49:35',0,NULL,3,1,1,1,'\\ ','gilligan110'),(4144,791139238012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.99,'eastar4','danimarie37','danielle.argenti@gmail.com','Danielle Argenti','10711 Rockledge View Dr','Riverview','FL','UNITED STATES','33579-2365','(813) 516-2195','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 14:01:00',0,NULL,3,1,1,1,'\\ ','danimarie37'),(4145,712363739011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','bengalsfaninjax','tmh1980@aol.com','Tim Harvey','886 11th Ave S','Jacksonville Beach','FL','UNITED STATES','32250-4248','(937) 232-9180','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 14:04:45',0,NULL,3,1,1,1,'\\ ','bengalsfaninjax'),(4146,712366955011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',37.99,'eastar4','borja_santander','rizo_borja@hotmail.com','Alicia gutierrez anton','c/nicolas salmeron<br>nº 6 6º G','santander','Cantabria','SPAIN','39009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:15:46',0,NULL,3,1,3,1,'RA117723601CN\r ','borja_santander\rUDAP001'),(4147,712377916011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','kuchmiy.alex','kuchmiy.a@gmail.com','Alexey Kuchmiy','ul. Ganni 17 kv 4','Kharkov','','UKRAINE','61001','+380633139055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:32:47',0,NULL,3,1,2,1,'\\ ','kuchmiy.alex'),(4148,537833291004,140519339815,'New Jabra BT250 FreeSpeak Bluetooth Headset track#',1,'HSJA002',21.5,'cnfaner','dakotalaceycody','ptremblett123@hotmail.com','Paula Tremblett','p o box 692<br>bonavista','newfoundland','NL','CANADA','a0c 1b0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:42:08',0,NULL,3,1,3,1,'RA117723589CN\r ','dakotalaceycody\rHSJA002'),(4149,712380986011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','rag1486','cuddlykittens1486@hotmail.com','Rachael Gutierrez','5950 Nora Pt<br>Apt 1','Colorado Springs','CO','UNITED STATES','80919-3767','(719) 208-2770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 14:50:49',0,NULL,3,1,1,1,'\\ ','rag1486'),(4150,712418743011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',28.47,'eastar4','phammari','ebay@hammarin.com','Per Hammarin','21300 Ridgetop Cir<br>Saab Support and Services LLC','Sterling','VA','UNITED STATES','20166-6520','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 15:45:39',0,NULL,3,1,1,1,'\\ ','phammari'),(4151,712389863011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','klubmobil','jj@klubmobil.com','James Jansen','Pademangan II Gang 17 No.10 Rt.003 Rw.03','Jakarta Utara','DKI Jakarta','INDONESIA','14410','62817153153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 15:51:06',0,NULL,3,1,2,1,'\\ ','klubmobil'),(4152,584704629013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','barakarichatamir','aricha@bgu.ac.il','Barak Aricha-Tamir','Avraham amir 8/9','Beer-sheva','','ISRAEL','84685','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 16:27:28',0,NULL,3,1,3,1,'RA117723575CN\r ','barakarichatamir\rWWOT001+ANCN001'),(4153,791255475012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','evrythng_mst_sell','jninwii@yahoo.com','Joni Thorpe','1405 1/2 N Allen Ave','Pasadena','CA','UNITED STATES','91104-1656','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 16:57:35',0,NULL,3,0,1,1,'\\ ','evrythng_mst_sell'),(4154,791277529012,220723618818,'Nokia HF-31W Bluetooth Plug-in Car Kit Speakphone',1,'HSNO027',15.5,'eastar4','chen5058','chenziv1@gmail.com','liron ziv','Bait Vagan<br>Harav Uziel 93','Jerusalem','','ISRAEL','96431','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 17:18:54',0,NULL,3,1,2,1,'\\ ','chen5058'),(4155,791305899012,220759518665,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',6.59,'eastar4uk','3447bobbyo','lexdimp@yahoo.co.uk','Mr bobby oneill','52 glenmore','drogheda','Louth','IRELAND','default','0419830207','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 17:47:35',0,NULL,3,1,3,1,'RA117723561CN\r ','3447bobbyo\rBALO001'),(4156,712521793011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','apipon','apipon@gmail.com','Apipon Wassanasuriyapong','399/16 rama6 rd. petchaburi, rajchatewee','-','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:08:12',0,NULL,3,1,2,1,'\\ ','apipon'),(4157,712528686011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','1933johnb','jbyers@canby.com','john byers','654 nw 3rd ave','canby','OR','UNITED STATES','97013-3402','(503) 680-1189','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 18:10:11',0,NULL,3,1,1,1,'\\ ','1933johnb'),(4158,712547821011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','duch31170','duchledieu@hotmail.com','Nicolas Duchez','55 Rue gaston Doumergue','Tournefeuille','Midi-Pyrénées','FRANCE','31170','0687467577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:40:51',0,NULL,3,1,2,1,'\\ ','duch31170'),(4159,584790160013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','6topal','shestopal@gmail.com','Konstantin Shestopal','Gorodnya str., 13, app. 42','Kiev','','UKRAINE','03141','+38 068 9054985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:42:31',0,NULL,3,1,2,1,NULL,'6topal'),(4160,712564731011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',265.9,'eastar4','mdhayes0','johngerard@comcast.net','John Hayes','2800 NE 46TH ST','Lighthouse Point','FL','UNITED STATES','33064-7265','(954) 415-5289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 18:42:39',0,NULL,3,1,6,1,'EE520583397CN ','mdhayes0'),(4161,791381103012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','spmichi','michael.pufke@web.de','Michael Pufke','Kleiner Eichfelder Weg 10','Arnstadt','','GERMANY','99310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 19:00:25',0,NULL,3,1,2,1,'\\ ','spmichi\r红边优联'),(4162,712591345011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','al_now','now@list.ru','ALEKSEI NOVIKOV','UL. ZOI KOSMODEMYANSKOY, 7-63','VORONEZH','VORONEZHSKAYA OBLAST','RUSSIAN FEDERATION','394063','(952)9516074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 19:13:59',0,NULL,3,1,3,1,'RA117724068CN\r ','al_now\rHSPL015\r欧标'),(4163,712608122011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','businessg36','rahamouz_marketing@yahoo.de','Amir Rahamouz','Dr.Gessler Str.3<br>Zimmer 3501','Regensburg','','GERMANY','93051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 19:31:35',0,NULL,3,1,2,1,'\\ ','businessg36'),(4164,584846806013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','esmrlzelimhan','esmrl@yahoo.com','Zelimhan Ismailov','Haoren 38 / 21','akko','israel','ISRAEL','24407','0523281501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 20:18:59',0,NULL,3,1,2,1,NULL,'esmrlzelimhan'),(4165,584857650013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','xscat1231','mmkopp@one.net','M. Moore','2778 Werkridge Dr','Cincinnati','OH','UNITED STATES','45248','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 20:42:18',0,NULL,3,1,1,1,'\\ ','xscat1231'),(4166,712658313011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',5,'HSUE004',67.45,'eastar4','tigeriron','tansunk@gmail.com','Amornrat Weerapaiboon','189/14 Budhamonthonsai2 Road, Soi. 7<br>Bangkaenuea','Bangkae','Bangkok','THAILAND','10160','0878227200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 20:43:23',0,NULL,3,1,3,1,'RA117723650CN\r ','tigeriron\rHSUE004'),(4167,584859494013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','prizefightercoca','laurennreed@hotmail.com','Lauren Reed','4118 Michael Drive','Henderson','KY','UNITED STATES','42420','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 20:46:33',0,NULL,3,1,1,1,'\\ ','prizefightercoca'),(4168,791469917012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',159.96,'eastar4','ntre2282','treffandiernicolas@neuf.fr','NICOLAS TREFFANDIER','4 PLACE DE L EGLISE','MONTESSON','Ile-de-France','FRANCE','78360','0633305175','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-22 20:49:37',0,NULL,3,1,3,1,'RA117724023CN\r ','ntre2282\rOTSO004'),(4169,791474245012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',11.99,'eastar4','jlan5547','joshlang1088@yahoo.com','josh langer','1132 Willowbrook Rd','staten island','NY','UNITED STATES','10314-6511','(718) 761-4253','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 21:10:31',0,NULL,3,1,1,1,'\\ ','jlan5547'),(4170,791481789012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','lorryman1844','andycurtis01@btinternet.com','Mr Andy Curtis','Bott Ltd<br>Bude Stratton Business Park','Bude','Cornwall','UNITED KINGDOM','EX23 8LY','07774003704','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 21:14:54',0,NULL,3,1,3,1,'RA117723615CN\r ','lorryman1844\rHSPL010\r英标'),(4171,712678698011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',4,'CCGR001',37.96,'eastar4','mcelhenny303','smcelhenny@gmail.com','Steve McElhenny','33400 Retrievers Trail','Golden','CO','UNITED STATES','80403','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 21:22:21',0,NULL,3,1,1,1,'\\ ','mcelhenny303'),(4172,712696775011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','ayhan2156','humici@gmail.com','Ayhan Teker','karlitepe mahallesi karliktepe sokak no:10 d:4<br>gaziosmanpasa/istanbul','istanbul','','TURKEY','34246','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 22:07:21',0,NULL,3,1,3,1,'RA117723840CN\r ','ayhan2156\rGLSG001'),(4173,712699560011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','themime','themime@gmail.com','Michael Whitten','131 Fairfax Ave<br>Apt A','Murfreesboro','TN','UNITED STATES','37130-0321','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 22:14:47',0,NULL,3,1,1,1,'\\ ','themime'),(4174,584238596013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',63.64,'eastar4','xdandy2004','cliftond@senet.com.au','David Clifton','14 Blinkbrae Ave','Happy Valley','South Australia','AUSTRALIA','5159','0883816697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 22:20:27',0,NULL,3,1,3,1,'RA117723853CN\r ','xdandy2004\rWWSI005+MOCN001+WLIN013\r一共买了\r一个Bracket of half intel 5300 半高卡架子\r一个Marvell 88W8363 \r一个 NEW Sierra MC8781 '),(4175,712719065011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','vulcan_46','vpatoglu@umich.edu','Volkan Patoglu','3813 10TH ST<br>Ste CRX-E1028','LONG ISLAND CITY','NY','UNITED STATES','11101-6111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 23:15:52',0,NULL,3,1,1,1,'\\ ','vulcan_46'),(4176,791044113012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','perthvet96','lcyvet@iinet.net.au','Lian Yeap','46B Sorrento ST<br>North Beach','Perth','Western Australia','AUSTRALIA','6020','61419905008','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 23:27:37',0,NULL,3,1,3,1,'RA117723473CN\r ','perthvet96\rBAZA001'),(4177,712728278011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',1,'GLSG003',89,'eastar4','lombricultura0','jmmatiu@hotmail.com','mabel ruiz','dean funes 226','castelar','buenos aires','ARGENTINA','1712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 23:48:15',0,NULL,3,1,3,1,'RA117738566CN\r ','lombricultura0\rGLSG003'),(4178,791561149012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','1986elena1228','v92@netzero.com','VLADIMIR IVANOV','2200 Ocean Ave<br>Apt 1B','Brooklyn','NY','UNITED STATES','11229-2248','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 00:38:24',0,NULL,3,1,1,1,'\\ ','1986elena1228'),(4179,712748059011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','jrob5808','jon.roberts58@gmail.com','Jonathan Roberts','2792 Jasmine Ct NE','Atlanta','GA','UNITED STATES','30345-1430','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 00:50:25',0,NULL,3,1,1,1,'\\ ','jrob5808'),(4180,532385463003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','daray1946','darjkaz@verizon.net','darryl kazmierczak','608 richmond ave','buffalo','NY','UNITED STATES','14222','(716) 881-3759','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 01:18:04',0,NULL,3,1,1,1,'\\ ','daray1946'),(4181,584936704013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','kivasdad','pimiller@hotmail.com','paul Miller','1303 sunset cliffs blvd','san diego','CA','UNITED STATES','92107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 01:22:52',0,NULL,3,1,1,1,'\\ ','kivasdad'),(4182,791582496012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','csb_32','csb_32@yahoo.com','christopher bryant','6325 Alta Ave<br>Apt 1','Whittier','CA','UNITED STATES','90601-4603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 01:34:55',0,NULL,3,1,1,1,'\\ ','csb_32'),(4183,712770174011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',2,'RCLO003',297.98,'eastar4','jeankido','jeankido@yahoo.com','Jean Pelegrin','6869 Tumbleweed Ln','Canal Winchester','OH','UNITED STATES','43110-7807','(614) 402-6141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 02:06:35',0,NULL,3,1,12,1,' BJ8822501','jeankido\r好好测试'),(4184,584953408013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','yosoymadman','ingjrz@gmail.com','Javier Rivera','Goya #79<br>Colonia Real Vallarta','Zapopan','Jalisco','MEXICO','45020','+52(33)3-629-6372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 02:24:47',0,NULL,3,1,2,1,'\\ ','yosoymadman'),(4185,712783045011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',2,'ADAK002',25.4,'eastar4','originalshop2010','theoriginalshop@hotmail.com','Wichit Poonyoo','139 M.8  Nannapat Apt.#4 Rm.210<br>T.Banklang','Muang','Lamphun','THAILAND','51000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 02:47:26',0,NULL,3,1,2,1,'\\ ','originalshop2010'),(4186,712787187011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',21.9,'eastar4','diljunioradilson','dil.junior@yahoo.com.br','adilson  junior','rua jacareí 214 c 13101<br>pilares','rio de janeiro','rio de janeiro','BRAZIL','20750250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 03:02:50',0,NULL,3,1,17,0,NULL,'diljunioradilson'),(4187,791611469012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','rcharkowski','ebay@charkowski.com','Ronald Charkowski','6345 Landfall Dr','Madison','WI','UNITED STATES','53705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 03:04:04',0,NULL,3,1,1,1,'\\ ','rcharkowski\r红边优联'),(4188,712787900011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',3,'HSSE004',65.7,'eastar4','diljunioradilson','dil.junior@yahoo.com.br','adilson  junior','rua jacareí 214 c 13101<br>pilares','rio de janeiro','rio de janeiro','BRAZIL','20750250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 03:06:10',0,NULL,3,1,3,1,'RA117723592CN ','diljunioradilson 申报8美金\r一共买了四个\rHSSE004'),(4189,538118205004,140516062706,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',40.99,'cnfaner','npinat','noelpinat@hotmail.com','Noel Edgardo Pinat','Moldes 2115 2°C','Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 03:56:22',0,NULL,3,1,3,1,'RA117723765CN\r ','npinat\r带CD\rOTRA001'),(4190,584971726013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',14.99,'eastar4','helitim6200','year2later@yahoo.com','Timothy Jeffery','718 Camarague Pl<br>Apt 200','Lake Mary','FL','UNITED STATES','32746-5169','(407) 878-3687','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 04:00:44',0,NULL,3,1,1,1,'\\ ','helitim6200'),(4191,791642289012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','dregamateur','gerdga@iinet.net.au','Gerd H Gaspars','11 Yarra Road','Croydon','Victoria','AUSTRALIA','3136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 05:29:53',0,NULL,3,1,3,1,'RA117724156CN\r ','dregamateur\rCMLO001'),(4192,584992780013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.2,'eastar4','oldenp','olden.pieterse@gmail.com','Olden Pieterse','PO Box 71655<br>Centrahill','Port Elizabeth','Eastern Cape','SOUTH AFRICA','6006','+27836115842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 06:40:15',0,NULL,3,1,3,1,'RA117724160CN\r ','oldenp\rCASS001'),(4193,791463718012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',12.98,'eastar4uk','completo21','completo.srl@gmail.com','popa nicolae','2 farndon close','northampton','Northamptonshire','UNITED KINGDOM','nn3 8tj','01604407256','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 06:47:05',0,NULL,3,1,3,1,'RA117724187CN\r ','completo21\rHSPL011\r英标'),(4194,788794381012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.9,'eastar4','martins_kalnin','vilkatis13@gmail.com','Martins Kalnins','Unijas 37-79','Riga','','LATVIA','LV-1039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 07:11:59',0,NULL,3,1,3,1,'RA117738075CN\r ','martins_kalnin\rOTSO002'),(4195,585003851013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','vicamelamed','vic.melamed@yahoo.com','Vica Melamed','La gvardia 50/2 Entrance: 3','Tel Aviv','','ISRAEL','67312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 08:01:43',0,NULL,3,1,2,1,NULL,'vicamelamed'),(4196,712846523011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','baymler','bhougaard@gmail.com','brian hovgaard','svalevej 2','ishøj','ishøj','DENMARK','2635','(0045)28105505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 08:14:33',0,NULL,3,1,3,1,'RA117724173CN\r ','baymler\rBR3D001'),(4197,712846880011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',16.99,'eastar4','kazenoou','holy_devil_89@hotmail.com','kh tan','Blk 643 Woodlands Ring Rd #08-36','default','','SINGAPORE','730643','96990664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 08:17:02',0,NULL,3,1,11,1,NULL,'kazenoou\rWLAT001+ANTY002'),(4198,585009649013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','jrudnickis','j.rudnickis@clear.net.nz','Carl Gill','232 Coutts Street<br>Rongotai','Wellington','North Island','NEW ZEALAND','6022','(04) 387 93 63','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 08:38:42',0,NULL,3,1,2,1,'\\ ','jrudnickis'),(4199,585015572013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','andriux_lt','nightbock@yahoo.com','Andrius Rupslaukis','Respublikos g. 34-38','Kedainiai','Kedainiai','LITHUANIA','57405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 09:07:40',0,NULL,3,1,2,1,'\\ ','andriux_lt\r欧标  银色的'),(4200,791699715012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',39,'eastar4','assafr','assaf-ebay@razon-family.com','Assaf Razon','23 Hageffen St.','Ramat-Gan','','ISRAEL','52546','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 09:41:52',0,NULL,3,1,3,1,'RA117738022CN\r ','assafr\r\r'),(4201,712868026011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','b_osbo','bardosterbo@yahoo.no','Bård Østerbø','Nordre Vardhaugen 65','Bergen','Sandsli','NORWAY','5253','004748161702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 09:42:23',0,NULL,3,1,2,1,'\\ ','b_osbo'),(4202,791713244012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','karen-grigoryan','grigoryan_75k@yahoo.com','Arman Vardanyan','Mantashyan 4/6, apt. 10','Yerevan','Yerevan','ARMENIA','0006','(37410) - 481761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 10:28:58',0,NULL,3,0,2,1,NULL,'karen-grigoryan\rOTCN005*10\r白色的'),(4203,712884590011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','hvmodi','modih@umich.edu','Harshvardhan Modi','6C Elgin Road<br>4th Floor, Oriental House','Kolkata','West Bengal','INDIA','700020','919830486149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 10:47:32',0,NULL,3,1,2,1,NULL,'hvmodi'),(4204,791733547012,220627153736,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',27.59,'eastar4','yoel_hamani','yoel.hamani@gmail.com','Yoel Hamani','12 Jerusalem st.','qiryat atta','','ISRAEL','28077','054-7699500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 11:35:08',0,NULL,3,1,2,1,NULL,'yoel_hamani\r旧的'),(4205,712915868011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','hhchua','lawrence.infinity@gmail.com','Chua Lawrence','68 Toh Tuck Road, Highgate Condo, #03-09','Singapore','','SINGAPORE','596733','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 12:32:52',0,NULL,3,1,11,1,'RA117724465CN\r ','hhchua\rCCGR001'),(4206,712921103011,320441567733,'2.1 Acer Aspire 5680 5630 3690  Bluetooth Module+cable',1,'BTAC2122',12.43,'eastar4','stzahi1','stzahi@gmail.com','Tzahi Serruya','D.N Emek Soreq. 76810','Moshav Yesodot','Israel','ISRAEL','76810','0547520100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 12:49:38',0,NULL,3,1,2,1,NULL,'stzahi1\racer 8pin1.00 8cm \r'),(4207,791759125012,220747230995,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',18.69,'eastar4uk','mmprasadh','mmprasadh@gmail.com','Prasadh Mankali Muralidharan','Apartment 50, CityGate<br>2, Sussex Place','Belfast','Antrim','UNITED KINGDOM','BT28LN','07738106423','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 12:51:15',0,NULL,3,1,3,1,'RA117738019CN\r ','mmprasadh\rHSUE003\r'),(4208,532504936003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',14.99,'cnfaner','antiquesalon611','antiquesalon61@gmail.com','Kaletinskay Rita','Dimitrova 78b-106','Mogilev','','BELARUS','212030','(460) 492-','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 13:04:34',0,NULL,3,1,3,1,'RA117738098CN\r ','antiquesalon611\rHSNO007\r欧标\r'),(4209,712928785011,320667818608,'New Logitech battery 4  DJ remote diNovo keyboard 930mA',1,'BALO004',10.99,'eastar4','fhandl1','matt_bywaters@yahoo.co.uk','Fiona Bywaters','23 Windsor Place','St Ives','New South Wales','AUSTRALIA','2075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 13:16:18',0,NULL,3,1,2,1,NULL,'fhandl1'),(4210,712931209011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','thomas.joyce16-2009','thomas.joyce16@yahoo.com','Thomas Joyce','6 Brigadier drive<br>Westderby','liverpool','Merseyside','UNITED KINGDOM','L12 4WU','01512300130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 13:28:33',0,NULL,3,1,3,1,'RA117738138CN\r ','thomas.joyce16-2009\rGLSG001*2'),(4211,712936074011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','alissontol86','alissontol@oi.com.br','Alisson Tolentino','R. Altamiro Nunes Leite, 330 AP 02<br>Barreiros','Teófilo Otoni','Minas Gerais','BRAZIL','39803-320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 13:37:05',0,NULL,3,1,2,1,NULL,'alissontol86'),(4212,712943542011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','noiseless*','chend_99@hotmail.com','Dong Chen','BLK 667C #16-151 Jurong West ST65','default','','SINGAPORE','643667','96547167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 14:06:11',0,NULL,3,1,3,1,'RA117738084CN\r ','noiseless*\rBR3D001'),(4213,712948835011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','jettahunter','ruger1v@aol.com','Nicholas','1733 Robin Dr','Bensalem','PA','UNITED STATES','19020-4415','(267) 226-0881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 14:17:21',0,NULL,3,1,1,1,'\\ ','jettahunter'),(4214,710551832011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',3,'HSUE004',40.47,'eastar4','modelbuilder1','kgb_corvette@hotmail.com','Karl Bengtsson','Börringegatan 1 B','Malmö','Sweden','SWEDEN','21772','+46-40-120827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 14:28:19',0,NULL,3,1,3,1,'RA117724227CN ','modelbuilder1\rHSUE004+HSUE002\r再发一个New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE\r\r\r'),(4215,789154808012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',18.69,'eastar4uk','modelbuilder1','kgb_corvette@hotmail.com','Karl Bengtsson','Börringegatan 1 B','Malmö','Sweden','SWEDEN','21772','+46-40-120827','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 14:29:34',0,NULL,3,1,17,1,NULL,'modelbuilder1'),(4216,585088756013,230592872476,'New Jabra BT250 BT 250 FreeSpeak Bluetooth Headset',1,'HSJA002',21.58,'eastar4','robito2010','romasipe@hotmail.com','Robinson Silva','Alberto Figueroa 440 Depto 903','Santiago','Metropolitana','CHILE','8420000','02 7891448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 14:50:58',0,NULL,3,1,2,1,NULL,'robito2010'),(4217,712811763011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','rj.hythloday','rj_loy@yahoo.com','robert loy','358 N Gateway Dr<br>Unit 425','providence','UT','UNITED STATES','84332-9852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 15:33:45',0,NULL,3,1,1,1,NULL,'rj.hythloday'),(4218,712983044011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','healthycrickets','andrew.jobs@gmail.com','Healthy Crickets','528 Amhurst Square','Bensalem','PA','UNITED STATES','19020','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 15:48:30',0,NULL,3,1,1,1,'\\ ','healthycrickets'),(4219,712987545011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','tennishelloworld','perryliu@sbcglobal.net','Perry Liu','9601 Camelot St','Pickerington','OH','UNITED STATES','43147-9265','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 16:00:07',0,NULL,3,1,1,1,NULL,'tennishelloworld'),(4220,791836274012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','eugeny_s','e.shastin@gmail.com','Eugeny Shastin','43-22, Metallistov st.','Izhevsk','','RUSSIAN FEDERATION','426054','+7-904-312-37-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 16:13:13',0,NULL,3,1,2,1,NULL,'eugeny_s'),(4221,791851210012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','zuaguns','mcb2300@yahoo.com','Michael Cain','4149 Long Drive','Braselton','GA','UNITED STATES','30517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 16:45:34',0,NULL,3,1,1,1,NULL,'zuaguns'),(4222,713010507011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',157,'eastar4','orchie88','scorchard@gmail.com','Michael Orchard','8 Linwood Tce','Brighton','South Australia','AUSTRALIA','5048','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-23 16:53:27',0,NULL,3,0,3,1,'RA117738124CN\r ','orchie88\rOTSO004*2'),(4223,713011714011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',148.99,'eastar4','mike_maureen','mike_maureen2010@yahoo.ca','Mike Murphy','49 Andrea Cr.','Orillia','ON','CANADA','L3V 6Y1','(705) 325-5096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 17:09:36',0,NULL,3,1,3,1,'RA117738345CN\r ','mike_maureen\rRCLO003'),(4224,713022762011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','kaldrak09','justindrouin@hotmail.com','Justin Drouin','600, rue Sicard','Mascouche','QC','CANADA','J7K 3G5','(514) 250-0338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 17:21:26',0,NULL,3,1,2,1,NULL,'kaldrak09'),(4225,791873682012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jstanek0518skq','jstanek051@aol.com','James Stanek','8 Nogales Ct','Novato','CA','UNITED STATES','94947-2903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 17:29:30',0,NULL,3,1,1,1,NULL,'jstanek0518skq'),(4226,713036482011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','dogface2424','bryanjmeyer4@yahoo.com','Bryan Meyer','124 Hatchet Creek Ct','Morrisville','NC','UNITED STATES','27560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 17:48:55',0,NULL,3,1,1,1,NULL,'dogface2424'),(4227,791894572012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','lilianitsa','lillypopescu@yahoo.com','liliana siakalli','pompiias 2A<br>pompiias 2A','aradippou','larnaka','CYPRUS','7103','0035799968179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 18:06:43',0,NULL,3,1,2,1,NULL,'lilianitsa'),(4228,713066002011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','cryofrontru','a.erivanskiy@ceg.gazprom.ru','Andrey Erivanskiy','Marshala Zakharova, d7, kv188','Moscow','','RUSSIAN FEDERATION','115569','+7(906)715-9842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 18:42:44',0,NULL,3,1,2,1,'\\ ','cryofrontru'),(4229,713067215011,320585224260,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',1,'WLIN009+ANTY002',22.95,'eastar4','thomasraden','thomas_raden@hotmail.com','Thomas Rådén','Vesterøyveien 28, apt 111','Sandefjord','','NORWAY','3235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 18:44:39',0,NULL,3,1,2,1,NULL,'thomasraden'),(4230,713077921011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','coalbeltrr','coalbeltrailroad@bellsouth.net','Jay Ramsey','191 Kennedy Ln','Richmond','KY','UNITED STATES','40475','(859) 625-2092','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 19:03:01',0,NULL,3,1,1,1,NULL,'coalbeltrr'),(4231,713088920011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','jimi403','jmartens70@shaw.ca','Jim Martens','331 Falshire Drive N.E.','Calgary','AB','CANADA','T3J 1T8','(403) 827-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:21:38',0,NULL,3,1,2,1,NULL,'jimi403'),(4232,791941734012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','sam_mosbacher','shmuel_mr@hotmail.com','Sam Mosbacher','Avne Eitan 54','Avne Eitan','Golan Hieghts','ISRAEL','12925','+972-(0)54-2053415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:27:06',0,NULL,3,0,2,1,NULL,'sam_mosbacher'),(4233,713094534011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',19.95,'eastar4','raku33','ralf.kuehnel@htp-tel.de','Ralf Kühnel','Lönsstr. 33','Seelze','','GERMANY','30926','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:31:34',0,NULL,3,1,2,1,NULL,'raku33\r无线蓝牙二合一'),(4234,713102138011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',148.99,'eastar4','williamcdotson','bdotson@gmail.com','Bill Dotson','1795 Alysheba Way<br>Suite 6201','Lexington','KY','UNITED STATES','40509-2435','(859) 361-4464','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 19:45:46',0,NULL,3,1,1,1,NULL,'williamcdotson'),(4235,791972716012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.43,'eastar4','hat2477','usmah15@tiscali.co.uk','Muhammad waheed','1/2  15 Ruel street cathcart','Glasgow','South Lanarkshire','UNITED KINGDOM','G44 4AR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 20:16:10',0,NULL,3,1,2,1,NULL,'hat2477\racer 5pin1.25 6cm'),(4236,585212452013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','freedored','freedo@netfam.org','Fred Van Camp V','8208 S G St','Tacoma','WA','UNITED STATES','98408-5220','(253) 471-4293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 20:33:06',0,NULL,3,1,1,1,NULL,'freedored'),(4237,792013123012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','burnie351','bwilliams2@bcps.k12.md.us','burnelle williams','2701 Baker St','baltimore','MD','UNITED STATES','21216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 21:37:41',0,NULL,3,1,1,1,NULL,'burnie351'),(4238,713160040011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','aleksey_b_rozhkov','rozhkoff.aleksey@mail.ru','Rozhkov Aleksey B.','Govorova 15-224','Moscow','Moscow','RUSSIAN FEDERATION','121596','+79262646300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:47:07',0,NULL,3,1,2,1,'\\ ','aleksey_b_rozhkov'),(4239,713168806011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','doverite','mywebmailaccountonly@hotmail.com','Stephen Price','346 Whistler\'s Cove Rd.','East Dover','NS','CANADA','B3Z3W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 22:16:45',0,NULL,3,1,2,1,NULL,'doverite'),(4240,792036059012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jbuckel','j.buckel@sbcglobal.net','John A Buckel','3120 Evening Bay Pl','Davis','CA','UNITED STATES','95616','(530) 758-2542','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-23 22:43:13',0,NULL,3,1,1,1,NULL,'jbuckel'),(4241,792043229012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','lmattiucci99','lmattiucci@reitmans.com','Lucy Mattiucci','8 Maison Parc Court<br>Suite 412','Thornhill','ON','CANADA','L4J 9K5','(416) 670-7935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 23:06:28',0,NULL,3,1,2,1,NULL,'lmattiucci99'),(4242,792050778012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.4,'eastar4','matty11dc','sanders11dc2@hotmail.com','Matthew Sanders','3 Aldinga Drive','Bunbartha','Victoria','AUSTRALIA','3634','0438672657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 23:37:13',0,NULL,3,0,2,1,NULL,'matty11dc'),(4243,585265980013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',69.98,'eastar4','doughboy1818','jeff.zimmer@shaw.ca','Jeff Zimmer','21 Donnely Terrace','Sherwood Park','AB','CANADA','T8H 2B3','(780) 640-8129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 00:13:31',0,NULL,3,1,3,1,'RA117738036CN\r ','doughboy1818\rBAZA001'),(4244,713200845011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','sierrastrom','elliahblue@wi.rr.com','colleen guzman','8526 S 116th St','franklin','WI','UNITED STATES','53132-8803','(414) 529-4047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 00:17:23',0,NULL,3,1,1,1,NULL,'sierrastrom'),(4245,792071775012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','tikiking1','tikiking1@aol.com','chad gibbs','420 Oak St','Laguna Beach','CA','UNITED STATES','92651-2917','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 00:50:43',0,NULL,3,1,1,1,NULL,'tikiking1'),(4246,792077169012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','jmiz9999','jmiz9000@yahoo.com','Joseph Mizrahi','1860 E 13th St','Brooklyn','NY','UNITED STATES','11229-2808','(718) 787-1810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 01:12:30',0,NULL,3,1,1,1,NULL,'jmiz9999\r新的'),(4247,713224556011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','pinkfloyd01','ebayfloyd@gmail.com','Mike Ellsworth','2639 Birchwood Dr NE','Atlanta','GA','UNITED STATES','30305-3821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 01:53:01',0,NULL,3,1,1,1,NULL,'pinkfloyd01'),(4248,532709861003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',71.9,'cnfaner','curt_truc','curt_truc@hotmail.com','Curtis Schleibaum','1628 Bell Ford Dr','Seymour','IN','UNITED STATES','47274-7422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 02:04:33',0,NULL,3,1,1,1,NULL,'curt_truc'),(4249,713227931011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','electnixon','mcarpenter@burnsmcd.com','Matt Carpenter','9400 Ward Pkwy<br>Burns','Kansas City','MO','UNITED STATES','64114','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 02:04:52',0,NULL,3,1,1,1,NULL,'electnixon'),(4250,585288516013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',22,'eastar4','ceandel','cadp_tata@msn.com','cesar delgado','av. estacion 01200','rancagua','cachapoal','CHILE','2841040','072-587612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 02:06:47',0,NULL,3,1,2,1,NULL,'ceandel'),(4251,792105879012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','degucci-san','dachristian@att.net','David  Christian','9570 Snake Rd','Dayton','OH','UNITED STATES','45426','(937) 405-7940','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 02:52:36',0,NULL,3,1,1,1,NULL,'degucci-san\r红边优联'),(4252,713239845011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','organphil','philipbrk584@gmail.com','Philip Burke','202 Misty Point Ln','Newport News','VA','UNITED STATES','23603-1441','(757) 369-0693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 02:56:26',0,NULL,3,1,1,1,'\\ ','organphil '),(4253,791468017012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','chamellpp2011','chamellpp@gmail.com','renata martins','rua comendador antonio alves n701','pedro leopoldo','minas gerais','BRAZIL','33600000','3136611569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 03:02:55',0,NULL,3,1,2,1,NULL,'chamellpp2011'),(4254,585300005013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',69.98,'eastar4','hrkjp','hrk526@gmail.com','Hiroki Mori','1-24-3-806<br>Honcho','Nakano-ku','Tokyo','JAPAN','164-0012','+81-90-8890-1772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 03:06:17',0,NULL,3,1,3,1,'RA117738040CN\r ','hrkjp\rBAZA001'),(4255,792111411012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',79.98,'eastar4','layanys1','layanys@yahoo.com','Layan Thilanka Silva','1/85<br>High Street Road','Ashwood','Victoria','AUSTRALIA','3147','0398138657','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 03:13:55',0,NULL,3,1,3,1,'RA117738115CN\r ','layanys1\rOTSO004'),(4256,713245202011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','ga-leff','gl.7248@gmail.com','Gary  Leff','2616 S Cottonwood Dr','Tempe','AZ','UNITED STATES','85282-3016','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 03:23:01',0,NULL,3,1,4,1,'YW866011231CN ','ga-leff'),(4257,585303729013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','finger-dance','sales@finger-dance.com','Huy Nguyen','20817 35th DR SE','Bothell','WA','UNITED STATES','98021-7025','(206) 334-6506','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-24 03:24:42',0,NULL,3,1,1,1,NULL,'finger-dance'),(4258,792117718012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','foxbound','walk2u@comcast.net','robert paz','444 Whispering Pines Dr<br>Spc 139','scotts valley','CA','UNITED STATES','95066-4759','(831) 438-0222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 03:43:18',0,NULL,3,1,1,1,NULL,'foxbound'),(4259,792121749012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','kh3864','kht10@singnet.com.sg','Tan Kang Ho','10 Moonbeam Drive','Singapore','Singapore','SINGAPORE','277350','96310787','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 04:01:38',0,NULL,3,1,3,1,'RA117738209CN\r ','kh3864\rBAZA001'),(4260,713255150011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',59.9,'eastar4','japanesevx','serge-the@priest.com','tomoko hirano','Iwasaki-cho, takenoyama 37-82','nissin','Aichi','JAPAN','470-0131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 04:17:13',0,NULL,3,1,3,1,'RA117738190CN\r ','japanesevx\rHSPL009'),(4261,532729287003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','romlor','refriro@sol.racsa.co.cr','Adolfo Romero','Calle 12 y 16  Avenida 14<br>Apartado 97-1009','San Jose','San Jose','COSTA RICA','Apto 97-1009','(506) 22220949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 04:19:10',0,NULL,3,1,3,1,'RA117738169CN\r ','romlor\rCRLO001+POLO001'),(4262,792124941012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','sc40094','sc40094@yahoo.com','Buu Q. Ta','22435 Malden St','West Hills','CA','UNITED STATES','91304','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 04:19:13',0,NULL,3,1,1,1,NULL,'sc40094'),(4263,792130943012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','ykrainskiy_boy','chubay_pavlo@hotmail.com','Pavlo Chubay','13222 SE Harold St','Portland','OR','UNITED STATES','97236-4143','(971) 340-6438','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 04:50:36',0,NULL,3,1,1,1,NULL,'ykrainskiy_boy'),(4264,713264428011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',2,'WLIN015',49.9,'eastar4','503samonoki','ajl.asia@gmail.com','Andrew Leist','PSC 557 Box 411','FPO','AP','AA','96379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 05:15:10',0,NULL,3,1,1,1,NULL,'503samonoki\r无线蓝牙二合一'),(4265,792149524012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','kitkit201','kitster510@sbcglobal.net','Wilson Lam','175 W Saint James St<br>Unit 110','San Jose','CA','UNITED STATES','95110-2407','(415) 823-4864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 06:32:02',0,NULL,3,0,1,1,NULL,'kitkit201'),(4266,792155322012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','carlosmoranoherrero','moranocarlos@gmail.com','Carlos Morano Herrero','Punta Umbria, 29','Arroyomolinos','Madrid','SPAIN','28939','667605649','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 06:56:26',0,NULL,3,1,2,1,'\\ ','carlosmoranoherrero'),(4267,585331969013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','dhym-na','dhym-na197@hotmail.com','AHMED NADHEEM','M.A.BLACK POOL<br>badifasgadhumagu','male\'','','MALDIVES','0091','7660000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 06:57:16',0,NULL,3,1,2,1,'\\ ','dhym-na'),(4268,713282696011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','cagri7972','cagri79@gmail.com','Cagri Cepni','Ahi Evran cad. Polaris İş Merkezi no:1 k:3<br>Maslak','Istanbul','','TURKEY','34398','5324475767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 07:02:06',0,NULL,3,1,3,1,'RA117724258CN ','cagri7972\rBR3D001'),(4269,585335213013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',43.5,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 07:35:25',0,NULL,3,1,3,1,'RA117724235CN ','dcwholesale\rCASS003'),(4270,585340537013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.58,'eastar4','negrila','florine82@yahoo.com','Florin Eremia','13 Palmer Court, Hoppers Crossing','Melbourne','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 07:57:02',0,NULL,3,1,2,1,NULL,'negrila\r澳标'),(4271,585339540013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',39.95,'eastar4','omymma2011','omymma@hotmail.com','Khaled Almuraifea','Mezzanine Floor,Mall View,Baitak Tower,LifeLong  Company.<br>Ahmed al jaber Street','Kuwait City','Kuwait','KUWAIT','Safat 13018','+96566748003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 07:58:14',0,NULL,3,1,3,1,'RA117724244CN ','omymma2011\rMOLO008'),(4272,713296967011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','dim1x','dimix7@gmail.com','Dmitry Becher','Haamoraim<br>9','Holon','Holon','ISRAEL','58581','972545903809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 08:09:54',0,NULL,3,1,2,1,NULL,'dim1x'),(4273,792172212012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','bajaking!','rogiervdwoning@hotmail.com','Rogier van der Woning','Vogelwikke 18','LOCHEM','','NETHERLANDS','7242MB','0573-256276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 08:15:03',0,NULL,3,1,2,1,NULL,'bajaking!\rAcer 5pin1.25 3cm'),(4274,713315185011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',12.5,'eastar4uk','ambrose1954','john_hann@tiscali.co.uk','John Hann','28, Emson\'s Close','Linton','Cambridgeshire','UNITED KINGDOM','CB214NB','01223892458','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 09:33:01',0,NULL,3,1,3,1,'RA117738504CN\r ','ambrose1954\rRELO003\r红边优联'),(4275,792194573012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','b1k3r','enekopi@gmail.com','Eneko Pinar','Amasa 29 Goikoetxe Goikoa 2','Villabona','País Vasco','SPAIN','20150','646391463','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 09:49:45',0,NULL,3,1,3,1,'RA117738495CN\r ','b1k3r\rBAZA001'),(4276,713325256011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','gestev','gestev.net@gmail.com','GEOFFREY STEVENS','24 Hambleton Road','Bishop Auckland, Co Durham','Durham','UNITED KINGDOM','DL148JS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 10:16:18',0,NULL,3,1,2,1,'\\ ','gestev'),(4277,792213972012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','shaysmaga','bar55555@walla.com','shay smaga','shaldag 38','pardes hana','','ISRAEL','37048','972-544555968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 11:00:58',0,NULL,3,1,2,1,'\\ ','shaysmaga'),(4278,585373659013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','facingworld07','riskpremium@gmail.com','Kevin Lo','8 Torwood St','Sans Souci','New South Wales','AUSTRALIA','2219','61404091689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 11:20:38',0,NULL,3,1,2,1,'\\ ','facingworld07'),(4279,713349130011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','nizned1','diskuszucht@onlinehome.de','Rudi Denzin','Erlenfeldweg 55','Kassel','','GERMANY','34123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 11:47:42',0,NULL,3,1,2,1,'\\ ','nizned1\r欧标'),(4280,710949898011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',158.99,'eastar4','josh4652','brown4652@yahoo.com','Joshua Brown','3385 Scott Smith Rd','Alexander','AR','UNITED STATES','72002-9031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 11:50:34',0,NULL,3,1,1,1,' ','josh4652\\'),(4281,713349991011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',27.99,'eastar4','renato_tozo','mr.tozo@live.com','renato tozo','1860 wayside dr','orlando','FL','UNITED STATES','32818-5845','(407) 879-5320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 11:56:08',0,NULL,3,1,1,1,'\\ ','renato_tozo'),(4282,792236893012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','urbanriding','sddacko@ameritech.net','Dan Dacko','5105 Retana Dr','Madison','WI','UNITED STATES','53714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 12:18:09',0,NULL,3,1,1,1,'\\ ','urbanriding\r红边优联'),(4283,792238267012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',88.99,'eastar4uk','edzonijs','edgarsdr@inbox.lv','Laura Drusta','Meiju Ceļš<br>46-61','Jelgava','','LATVIA','LV-3007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 12:23:41',0,NULL,3,0,3,1,'RA117738645CN\r ','edzonijs\rGLSG001*2'),(4284,713372113011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','alanteles1','alanteles@gmail.com','Osana Santos da Silva','Rua Ourem N: 61 Edf. Ubaias<br>Apto. 303','Recife','Pernambuco','BRAZIL','50761340','55 81 88643255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:05:45',0,NULL,3,1,2,1,'\\ ','alanteles1\r盒装的'),(4285,581780419013,230498594539,'D-Link DWL-G122 Wireless G USB Notebook Desktop Adapter',1,'WLDL001',8.35,'eastar4','d12aurorarichard','d12aurora@hotmail.com','Richard Desruisseaux','PO Box 292<br>9 Birch st','Greenwood','NS','CANADA','B0P1N0','(902) 840-0814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:17:42',0,NULL,3,1,2,1,'\\ ','d12aurorarichard'),(4286,585398723013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27.16,'eastar4','vintner146','brucelehto@yahoo.com','Bruce M Lehto','146 I E Stracener Rd','DeRidder','LA','UNITED STATES','70634-8311','(337) 462-2292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 13:24:19',0,NULL,3,1,1,1,'\\ ','vintner146'),(4287,713378459011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','haddad504','p.hewitt60@ntlworld.com','elizabeth hewitt','103 Wroxham Rd<br>Sprowston','Norwich','Norfolk','UNITED KINGDOM','NR7 8TU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 13:26:21',0,NULL,3,1,3,1,'RA117738597CN\r ','haddad504\rOMHJ001'),(4288,713379820011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','flintstonedk','sos@pc.dk','Henrik Steffensen','Birkehaven 61','Lystrup','Aarhus','DENMARK','8520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:32:42',0,NULL,3,1,2,1,'\\ ','flintstonedk'),(4289,713383020011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:42:12',0,NULL,3,1,3,1,'RA117724213CN\r ','tudijaidem\rANYA001'),(4290,585406331013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','douweh','douwehoekstra@hotmail.com','Douwe Hoekstra','Moerdijkstraat 25','Eindhoven','','NETHERLANDS','5652 JM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:55:42',0,NULL,3,1,2,1,'\\ ','douweh'),(4291,585406881013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',12.59,'eastar4','kirov1045','kirov1045@hotmail.com','Omri Lepek','Kashani 3','Tel Aviv','','ISRAEL','69499','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 13:59:20',0,NULL,3,1,2,1,'\\ ','kirov1045'),(4292,538520625004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','sozethekeyser','m.risom@gmail.com','Mathias R Kristensen','Nordborggade 38 st-th','Aarhus C','','DENMARK','DK8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 14:02:59',0,NULL,3,1,3,1,'RA117738481CN\r ','sozethekeyser\rOTCR001'),(4293,713389577011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','joham86','joost_hammink@hotmail.com','Joost Hammink','Moesstraat 129','Groningen','','NETHERLANDS','9741AS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 14:03:26',0,NULL,3,1,2,1,'\\ ','joham86'),(4294,713400028011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','wolaipea','shulingsung@hotmail.com','Shuling Sung','13903 Blue Vista Dr','Sugar Land','TX','UNITED STATES','77498','(281) 491-6807','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 14:37:09',0,NULL,3,1,1,1,'\\ ','wolaipea'),(4295,792286146012,220778513744,'NIB AUI Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRMX004',16.99,'eastar4','bilgehan1976','bilgehanumay@gmail.com','Bilgehan Umay','Beşevler Mah. Selvi Sok. Gaye Sitesi N0:9/2<br>Nilüfer','Bursa','','TURKEY','16110','(224)451-0207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 15:00:56',0,NULL,3,1,2,1,'\\ ','bilgehan1976\r盒装'),(4296,713409675011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','singreale','wood.programming@gmail.com','Caleb Wood','45 Virginia Rail Dr','Marlborough','CT','UNITED STATES','06447','(860) 295-9171','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 15:05:41',0,NULL,3,1,1,1,'\\ ','singreale'),(4297,792294488012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','swamp2781','graham@gpmills.com','Graham Mills','163 Trysull Road<br>Merry Hill','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 7JP','01902336074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 15:09:41',0,NULL,3,1,3,1,'RA117738478CN\r ','swamp2781\rOTCN004*10'),(4298,790942440012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ernestine_2004','ebgayban@hotmail.com','Ernestine Gayban','7720 Wolf Creek Rd','Las Vegas','NV','UNITED STATES','89128-6844','(702) 480-9816','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ernestine_2004'),(4299,585437616013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','kobi_g','kobi_g1@yahoo.com','Kobi Gabai','14 klii street','Tel Aviv','ISRAEL','ISRAEL','62336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 16:04:24',0,NULL,3,1,2,1,'\\ ','kobi_g'),(4300,713430551011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','1911caspian','fabien@corsini.ca','FABIEN CORSINI','1724 RUE DU RENNE','LONGUEUIL','QC','CANADA','J4N 1M8','(514) 594-8314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 16:05:35',0,NULL,3,1,2,1,'\\ ','1911caspian'),(4301,792323182012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','t.a786','t.ahmed@virgin.net','TAHIR AHMED','44 HEIGHAM ROAD','EAST HAM','London','UNITED KINGDOM','E6 2JG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 16:22:55',0,NULL,3,1,2,1,'\\ ','t.a786\r红边优联'),(4302,792332326012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','ktkachenko','iktkachenko@gmail.com','Konstantyn Tkachenko','Promyshlennaya<br>d.33 kv.133','Krasnodar','Krasnodarsky kray','RUSSIAN FEDERATION','350002','+79183753923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 16:46:07',0,NULL,3,1,2,1,'\\ ','ktkachenko'),(4303,585453556013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','inud','inud@hotmail.com','Robert Duni','2569 Goshawk Ln','Lincoln','CA','UNITED STATES','95648-7711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 16:58:11',0,NULL,3,1,1,1,'\\ ','inud'),(4304,713482359011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT003',30.8,'eastar4','multwave','multwave@hotmail.com','Kyeong-Jin Ban','DaeJuFiore APT 105/2102, YoungDang-Dong','Sunchun-Si','Jeollanam-do','KOREA,REPUBLIC OF','540-707','010-8619-8426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 18:07:55',0,NULL,3,1,3,1,'RA117724598CN ','multwave\rWLAT003'),(4305,792382464012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','dgos2993','dkgosch@msn.com','Dennis Gosch','201 S 8th Street Circle','Springfield','NE','UNITED STATES','68059','(402) 253-2979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 18:22:52',0,NULL,3,1,1,1,'\\ ','dgos2993'),(4306,713500266011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','pillot-fly','edecio@uol.com.br','Edecio Cassio Martins Sibalde','Rua claudino Barbosa, 628 apto 102<br>Macedo','Guarulhos - SP','26','BRAZIL','07113040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 18:43:23',0,NULL,3,1,3,1,'RA117738518CN\r ','pillot-fly\rBR3D001'),(4307,713500425011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','steelct','janpolad@gmail.com','Levon Janpoladyan','K.Ulnetsi str. 66, apt. 52','Yerevan','','ARMENIA','0069','(374) 992-4816 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 18:43:54',0,NULL,3,1,2,1,'\\ ','steelct\r盒装'),(4308,585499009013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','neo-123','schmudee@hotmail.de','Servion Service & Support GmbH','Schelmenwasenstr. 32<br>z. Hd. Marcus Schmidt','Stuttgart','','GERMANY','70567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 19:12:02',0,NULL,3,1,3,1,'RA117738416CN\r ','neo-123\rMOSA002'),(4309,792225278012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','franchuspc','franhorv@gmail.com','Laszlo Francisco Horvath','la pampa 2802<br> 1ro \"F\"','Capital Federal','Buenos Aires','ARGENTINA','1428','114-785-2330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:00:43',0,NULL,3,1,2,1,'\\ ','franchuspc'),(4310,791238588012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',2,'HSPL014',67.98,'eastar4','josephp8nud','josephp@surfbest.net','Joseph Passero','PO Box 400<br>115 - 14th Street','Verplanck','NY','UNITED STATES','10596-0400','(201) 681-6283','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 20:01:44',0,NULL,3,1,1,1,'\\ ','josephp8nud'),(4311,792438667012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','albertarkright','adamsh79@talktalk.net','Adam Shah','9 Rosebery Road, Langley Vale','epsom','Surrey','UNITED KINGDOM','KT186AF','01372272664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:03:10',0,NULL,3,1,2,1,'\\ ','albertarkright\r红边优联'),(4312,792443006012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',7,'HSPL010',167.3,'eastar4','dynamicautosound','dynamicautosound@hotmail.com','DYNAMICAUTOSOUND','3053 S Harbor Blvd','SANTA ANA','CA','UNITED STATES','92704-6448','(714) 754-7700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 20:12:19',0,NULL,3,1,1,1,'\\ ','dynamicautosound'),(4313,792443838012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',5,'OTAP001',47.45,'eastar4','agfa128','agfa123@hotmail.com','Agustin Aguilar','Lázaro Cárdenas 225<br>Col. Benito Juárez','Xalapa','Veracruz','MEXICO','91070','+52 (228) 8177146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:15:23',0,NULL,3,1,3,1,'RA117737968CN\r ','agfa128\rOTAP001'),(4314,585521688013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','jan.rorys.mach','jan.mach71@gmail.com','Jan Mach','AOL Global Operations<br>The Brunnel Building, Block 7A','Heuston South Quarter, Dublin 8','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:18:30',0,NULL,3,1,2,1,'\\ ','jan.rorys.mach'),(4315,792463413012,220788697050,'New genuine Plantronics Voyager pro Bluetooth Headset',1,'HSPL013',51.9,'eastar4','mohoeys','mohoeys@online.no','Morten Høyset','Lisleheradveien 19','Notodden','','NORWAY','3678','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:53:43',0,NULL,3,1,3,1,'RA117738606CN\r ','mohoeys\rHSPL013\r欧标\r申报30美金'),(4316,792473174012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN001+BAIN002+TOIN002',49.9,'eastar4','tonytruong2011','tony_truong8464@yahoo.com','Tony Truong','7019 Corbin Ave','Winnetka','CA','UNITED STATES','91306-3608','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 21:14:18',0,NULL,3,1,1,1,'\\ ','tonytruong2011'),(4317,713577120011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','chhincapie','chhincapie@hotmail.com','Carlos Hincapie','Cra 46A # 29 Sur 20<br>Ap 825','Envigado','Antioquia','COLOMBIA','055422','(573) 002-0124 ext.: 88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:19:59',0,NULL,3,1,2,1,'\\ ','chhincapie'),(4318,585543554013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','torstid','tddraeger@aol.com','Torsten Draeger','Becklingen 139','Bergen','','GERMANY','29303','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:22:07',0,NULL,3,1,2,1,'\\ ','torstid\r欧标'),(4319,713578506011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jamissah','jamissah3@hotmail.com','John Amissah','12301 Quiet Owl Ln','Bowie','MD','UNITED STATES','20720-4307','(240) 281-3833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 21:24:40',0,NULL,3,1,1,1,'\\ ','jamissah'),(4320,585547019013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','lionel3583','lionel.lebas@laposte.net','Lionel Lebas','25, rue Jean Moulin','Vincennes','Île-de-France','FRANCE','94300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:31:53',0,NULL,3,1,2,1,'\\ ','lionel3583'),(4321,713581654011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','mhaa6000','mhaa5000@yahoo.com','Motaz Amashah','p.o.box 53022<br>jeddah 21583','jeddah','','SAUDI ARABIA','21583','00966504631218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:32:10',0,NULL,3,1,2,1,'\\ ','mhaa6000'),(4322,792494312012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',80.98,'eastar4','raphael-2234','kidtaveira@globo.com','luiz jose taveira neto','avenida independencia quadra 121,lote 4<br>distrito federal','planaltina','distrito federal','BRAZIL','73330005','(55)6133887132','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 22:02:49',0,NULL,3,1,3,1,'RA117738570CN\r ','raphael-2234\rOTSO004\r申报50美金'),(4323,792495211012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','jasonhandsley','handsleyj@aol.co.uk','Jason Handsley','25 Cardigan Road','Bridlington','East Riding of Yorkshire','UNITED KINGDOM','YO15 3HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 22:07:05',0,NULL,3,1,3,1,'RA117738464CN\r ','jasonhandsley\rHSPL010\r英标'),(4324,713599091011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','benoitwoo','benoit@intnet.mu','Benoit Woo Show Wing','Appt. 66, Domaine de L\'Intendance<br>Avenue Pere Laval','Rose Hill','','MAURITIUS','NA','(230)2511660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 22:28:59',0,NULL,3,0,2,1,'\\ ','benoitwoo'),(4325,713600688011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','ccastro54','clebercastro54@gmail.com','CLEBER TELLES CASTRO','NORTH CIRCULAR ROAD, 244','Dublin','Dublin','IRELAND','7','861099718','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 22:33:36',0,NULL,3,1,3,1,'RA117738521CN\r ','ccastro54\rWLAP002'),(4326,532963650003,130466024027,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'cnfaner','sallystutz','sally.bobby@btinternet.com','Sally Stutz','1<br>Arundel Close','Knutsford','Cheshire','UNITED KINGDOM','WA16 9BZ','01565650919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 22:47:32',0,NULL,3,1,3,1,'RA117738583CN\r ','sallystutz\rOTGR001'),(4327,792507634012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','bourbon55','d_duranleau@yahoo.com','david duranleau','1207 River Ave','Point Pleasant Boro','NJ','UNITED STATES','08742-3718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-24 22:48:10',0,NULL,3,1,1,1,'\\ ','bourbon55'),(4328,713603910011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','simmonsc','ccw.simmons@comcast.net','Christopher S. Simmons','3890 Union St SE','Albany','OR','UNITED STATES','97322-7644','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'simmonsc'),(4329,792522538012,220684679345,'New in box Jeep Multi-function Handy Saw Openner Pliers',1,'OTJE001',15.9,'eastar4','anyquilmes10','gerardoluisrivas@hotmail.com','gerardo luis rivas','timoteo gordillo 290','ciudad de buenos aires','buenos aires','ARGENTINA','1408','46413594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 23:42:37',0,NULL,3,1,2,1,'\\ ','anyquilmes10'),(4330,792525506012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.97,'eastar4','edmello10','maury_ep@hotmail.com','Maury E Pena Aristy','ave. palacio de los deportes residencial cohisa IV apto 403<br>las praderas','Santo domingo','Dominican Republic','DOMINICAN REPUBLIC','10135','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 23:54:31',0,NULL,3,1,3,1,'RA117738552CN\r ','edmello10\rOTSO001\r\r'),(4331,713625358011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',24.95,'eastar4','moncayomar1952','moncayomar@yahoo.com','Marcelo Moncayo','Alborada XI manzana 15 villa 24','Guayaquil','Guayas','ECUADOR','0009','2648360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 00:14:24',0,NULL,3,1,2,1,'\\ ','moncayomar1952\r无线蓝牙二合一'),(4332,792531924012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',3,'HSPL011',69,'eastar4','dimiller743','dimiller74@yahoo.com','Dolly  Miller','PO BOX 5787','Pagosa SPrings','CO','UNITED STATES','81147-5787','(970) 422-4266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 00:30:51',0,NULL,3,1,1,1,'\\ ','dimiller743'),(4333,713645025011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','mary9968','solmary_9968@hotmail.com','MARISOL SIERRA','P.O.BOX 2043','Rio Grande','PR','PUERTO RICO','00745','(787)632-3571','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 01:37:05',0,NULL,3,0,1,1,'\\ ','mary9968'),(4334,792553837012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mjramp2084','mjramp@yahoo.com','Mike Rampton','6222 12th St N','Arlington','VA','UNITED STATES','22205-1721','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 01:40:54',0,NULL,3,1,1,1,'\\ ','mjramp2084'),(4335,532992474003,130460438605,'New Plantronics Explorer 340 BLUETOOTH HEADSET track#',1,'HSPL007',19.9,'cnfaner','australiasteve','stevejackson@stevejackson.com.au','Steve Jackson','532 Brighton Road','Brighton','South Australia','AUSTRALIA','5048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 01:47:45',0,NULL,3,1,3,1,'RA117738535CN\r ','australiasteve\rHSPL007\r澳标'),(4336,713648013011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',9.45,'eastar4uk','kuskus2008','markuskus@ig.com.br','Markus Vinicius Gonçalves','128 Norbury Crescent<br>Norbury','London','London','UNITED KINGDOM','SW16 4JZ','07949667670','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 01:49:20',0,NULL,3,1,3,1,'RA117738549CN\r ','kuskus2008\rWLAP001'),(4337,713657715011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','pulsarplus2010','pulsarplus@mail.ru','DMITRIY GLAVITSKIY','NOYABRSKAYA 472, 121','ORENBURG','ORENBURG','RUSSIAN FEDERATION','460000','79033653179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 02:28:21',0,NULL,3,1,3,1,'RA117738637CN\r ','pulsarplus2010\rGLSG001'),(4338,713673391011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','micgamin','gamin@mail.ru','Дмитрий Ступаков','ул.Комсомольская, 23 - 135','Новосибирск','Новосибирская область','RUSSIAN FEDERATION','630066','(913) 8976783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 03:47:16',0,NULL,3,1,2,1,'\\ ','micgamin'),(4339,713677199011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',27.99,'eastar4','cbirman','chris8538424@yahoo.com','Chris Birman','7928 Bluewater Hwy','Saranac','MI','UNITED STATES','48881-9432','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 04:05:54',0,NULL,3,1,1,1,'\\ ','cbirman'),(4340,792594545012,220711648781,'New Powchip POW-N18 MiNI  LAN ADAPTER USB 802.11N 150M',2,'WLPO001',17.98,'eastar4','usbshop','t.tomans@gmail.com','Tarzioriu George Gabriel','Str.sold.Tina Petre,Nr.3,Bl.L34<br>Sc.3, Etj.6,Apt.130, Sect.3','Bucuresti','Romania','ROMANIA','030403','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 04:31:58',0,NULL,3,1,2,1,'\\ ','usbshop'),(4341,538722589004,140481827924,'New Plantronics Explorer 220 BLUETOOTH HEADSE+carcharge',1,'HSPL001+CCPL001',15.8,'cnfaner','yaronwine','yaron.w@gmail.com','yaron winestock','Hamahleva 115','Kfar vitkin','','ISRAEL','40200','050 5907363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 05:06:15',0,NULL,3,1,3,1,'RA117724275CN\r ','yaronwine\rHSPL001+CCPL001'),(4342,538724688004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.95,'cnfaner','ramasatyam','ramasatyam@yahoo.com','Ramasatyam Durvasula','3/105, Pearson street','Brunswick','Victoria','AUSTRALIA','3056','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 05:24:37',0,NULL,3,1,3,1,'RA117724301CN\r ','ramasatyam\rOTSO001'),(4343,713701285011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','syavych','vyacheslav.sobolev@aes.com','Vyacheslav Sobolev','Dostyk 140, 3 floor','Almaty','MT','KAZAKHSTAN','050051','+77017540415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 06:24:56',0,NULL,3,1,2,1,'\\\r ','syavych'),(4344,713706747011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','roman_lipka','roman.lipka@gmail.com','Roman Lipka','Nam. SNP 29, CSOB','Bratislava','Slovakia','SLOVAK REPUBLIC','81563','+421903768747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 06:50:37',0,NULL,3,1,2,1,'\\ ','roman_lipka'),(4345,713708185011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','magriplis2005','r.magriplis@gmail.com','Robert Magriplis','9 Niccoli Park  Way','Mernda','Victoria','AUSTRALIA','3754','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 07:03:03',0,NULL,3,1,2,1,'\\ ','magriplis2005'),(4346,792627129012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','murzi1ko','murzi1ka@ya.ru','Sergey Ostrishko','Rossiskay, 128 k 231','krasnodar','','RUSSIAN FEDERATION','350029','(964) 9011493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 07:20:08',0,NULL,3,1,3,1,'RA117724261CN\r\r ','murzi1ko\rRCLO002'),(4347,713731437011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','willyomg','wtwliew@gmail.com','William Liew','100 Tory Street<br>Te Aro, Level 1 Squiz','Wellington','-Select-','NEW ZEALAND','6011','0211351994','NoPaymentFailure','SellerResponded','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'\\ ','willyomg\r'),(4348,713750305011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','thrapped','d_tidyman@yahoo.com','Daniel Tidyman','7 goldsmith rd, acton','acton','London','UNITED KINGDOM','w36px','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 10:14:18',0,NULL,3,1,3,1,'RA117724425CN\r ','thrapped\rWLAP002'),(4349,792672167012,220786829840,'New SonyEricsson HBH-PV703 Bluetooth Headset flower ver',1,'HSSE004',21.9,'eastar4','scmires','s.c.mires@gmail.com','TECHOLOGY SHOP','25HS MARTIOY 241<br>MIRES','MIRES','MIRES IRAKLIO','GREECE','70400','+302892022372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 10:25:34',0,NULL,3,1,2,1,'\\ ','scmires\r带花的\r欧标'),(4350,713755231011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','thrapped','d_tidyman@yahoo.com','Daniel Tidyman','Gyro London, Third Floor, The Chambers<br>Chelsea Harbour','London','chelsea','UNITED KINGDOM','SW10 0XF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 10:29:18',0,NULL,3,1,3,1,'RA117724451CN\r ','thrapped\rWLAP002'),(4351,792678560012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','adamoaberroinc2011','adamoaberroinc@gmail.com','Damian Rodriguez','480 Farmington Ave','Cranston','RI','UNITED STATES','02920-7708','(401) 270-3903','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 10:48:40',0,NULL,3,1,1,1,'\\ ','adamoaberroinc2011'),(4352,677346371001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','istorm2010','cdisk111@mail.ru','Khan Evgeniy Yakovlevich','Zhambul street, 173/6','Almaty','','KAZAKHSTAN','050008','(727) 3276533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 11:26:44',0,NULL,3,1,3,1,'RA117724403CN\r ','istorm2010\rOTSO001'),(4353,713513174011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',3,'HSNO019',119.97,'eastar4','denis.kuzin','kuzin.d@mail.ru','Denis Kuzin','Alovsat Quliyev 65 app4','Baku','','AZERBAIJAN','1009','99412-596-19-48','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-25 11:30:21',0,NULL,3,1,3,1,' RA117724496CN\r','denis.kuzin\rHSNO019\r'),(4354,792700740012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','la7947','lyeboa@gmail.com','Lakwame Anyane-Yeboa','1 Woodbine Ave','New Rochelle','NY','UNITED STATES','10801-3207','(914) 417-9650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 12:10:13',0,NULL,3,1,1,1,'\\ ','la7947'),(4355,538787157004,140516860307,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',16.55,'cnfaner','butovskyy','butovskyy.ebay@gmail.com','Roman Butovskyy','via Brugali 16','Albino','BG','ITALY','24021','3421782341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 12:13:26',0,NULL,3,1,3,1,'RA117724448CN\r ','butovskyy\rWLAT008+ANTY001'),(4356,713786647011,320679575680,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',19.9,'eastar4uk','oddslee','odds.lee@gmail.com','Odd Magne Raugstad','Leiteveien 54','SANDNES','Rogaland','NORWAY','4312','+4740418374','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-25 12:22:02',0,NULL,3,1,2,1,'\\ ','oddslee'),(4357,792709171012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','perchiehouse','islander@ntlworld.com','nicholas friendlay','51, Sidney Rd','Walton-On-Thames','Surrey','UNITED KINGDOM','KT12 2LZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 12:30:26',0,NULL,3,1,3,1,'RA117724434CN\r ','perchiehouse\rHSPL010\r英标'),(4358,792714743012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mky5439','mky5439@netscape.net','Michael Gattone','515 Bash Ct<br>Apt 9','Champaign','IL','UNITED STATES','61820-5573','(630) 802-3806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 12:51:11',0,NULL,3,1,1,1,'\\ ','mky5439\r红边优联\r'),(4359,585705632013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','tcone_de','f.emden@yahoo.de','Friedrich Emden','Voigtstr. 41','Berlin','','GERMANY','10247','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 13:01:55',0,NULL,3,1,3,1,'RA117724505CN\r ','tcone_de\rWLAP008'),(4360,792239199012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','lost747','mrwendel2003@hotmail.com','Daniel Griffin','PO Box 174','Frenchs Forest','New South Wales','AUSTRALIA','1640','0402663460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 13:01:58',0,NULL,3,1,2,1,'\\ ','lost747\r红边优联'),(4361,713803583011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',5,'CASS002',43.5,'eastar4','has.2009','mete@eosbil.com.tr ','Mete Can GURCAN','Perpa B Blok Kat 6 No 653<br>Sisli','Istanbul','','TURKEY','34384','+90-532-668-1191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 13:19:50',0,NULL,3,1,3,1,'RA117724394CN\r ','has.2009\rCASS002'),(4362,713829329011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',2,'BTHP3000',34.3,'eastar4','nirmor','nir.mor@ncortex.com','Nir Mor','15 Ha Broshim st.<br>P.O.B 3944','Kadima','','ISRAEL','60920','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 14:42:14',0,NULL,3,1,3,1,'RA117724329CN\r ','nirmor\rBTHP3000'),(4363,677401420001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','row1997','rwalker78@att.net','Randall Walker','718 Weeping Oaks Ln','Spring','TX','UNITED STATES','77388-8918','(713) 591-3335','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 14:42:22',0,NULL,3,1,1,1,'\\ ','row1997'),(4364,792751820012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','herman77guerrero','hermanguerrero18@yahoo.com','Herman Arias','1043 Lakeside Pl','baldwin','NY','UNITED STATES','11510-3312','(516) 859-0272','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 14:50:39',0,NULL,3,1,1,1,'\\ ','herman77guerrero'),(4365,713836091011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.49,'eastar4','999lex','lex-off@mail.ru','Aleksey Podshibyakin','140170, Rossiya, Moskovskaya oblast, gorod Bronnitsy, pos. Gorka, d. 7, kv. 36','Bronnitsy','Moskovskaya oblast','RUSSIAN FEDERATION','140170','8(926)3945625','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 15:08:06',0,NULL,3,1,2,1,'\\ ','999lex'),(4366,792764972012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','space48a','rosake@sbcglobal.net','Robert Brown','501 W Woodruff Ave','Arcadia','CA','UNITED STATES','91007-8345','(951) 760-4248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 15:16:12',0,NULL,3,1,1,1,'\\ ','space48a'),(4367,538831036004,140519339941,'New Jabra BT320s StereoBluetooth Clip-On Earbud Headset',1,'HSJA003',23.79,'cnfaner','sampei59','favaro_francesco@libero.it','ANDREA PIERUCCI','CANTON BASSO 36','ADRIA','RO','ITALY','45011','3313647264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 15:43:33',0,NULL,3,1,3,1,'RA117724315CN\r ','sampei59\rHSJA003\r欧标'),(4368,585744463013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','labral99','falso999@aol.com','Luis Labra Villafañez','calle La Mancha 38   4ºdcha','Gijón','Asturias','SPAIN','33210','605584442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 15:47:48',0,NULL,3,1,2,1,'\\ ','labral99'),(4369,792784039012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','netaire-sales','paypal@netaire.com','Jeremy Holdridge','18 Avondale Crescent<br>Shipley','Bradford','West Yorkshire','UNITED KINGDOM','BD18 4QS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 16:04:11',0,NULL,3,1,3,1,'RA117724377CN\r ','netaire-sales\rOTCN002'),(4370,585749246013,230552652688,'New PHILIPS Salon HP8309 ULTRA-SLIM HAIR STRAGHTENER',2,'OTPH002',39.98,'eastar4','mauripardo','mauripardo2003@yahoo.com.ar','Mauricio Pardo','Moreno 2340  10º (i)<br>Moreno 2328 6º (a)','Mar del Plata','Buenos Aires','ARGENTINA','7600','0223-4946393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 16:04:48',0,NULL,3,1,3,1,'RA117738711CN ','mauripardo\rOTPH002'),(4371,792786747012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','gervitaly','germentotipb@yandex.ru','Vitaly Ustyuzhantsev','2 mkr.<br>235-8','Strezevoy','Tomskaya oblast','RUSSIAN FEDERATION','636780','913-101-4253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 16:12:43',0,NULL,3,1,2,1,'\\ ','gervitaly'),(4372,585761898013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','elets2005','89057589931@mail.ru','Sergey  Manyukov','Koroleva, 11-60','Elets','Lipetskaj obl','RUSSIAN FEDERATION','399784','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 16:54:04',0,NULL,3,1,3,1,'RA117724385CN\r ','elets2005\rOTRA001'),(4373,792804937012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',8.49,'eastar4','ole_und_dodo','oliver-ice-becker@gmx.de','Oliver Becker','Paster-Behrens-Straße 21','Berlin','','GERMANY','12359','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 16:54:26',0,NULL,3,1,2,1,'\\ ','ole_und_dodo'),(4374,792810214012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',2,'HSMO011',31.98,'eastar4','leebail','abacabail@sbcglobal.net','Timothy Lee','518 Chester Ave','Bakersfield','CA','UNITED STATES','93301-5418','(661) 201-0523','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 17:07:01',0,NULL,3,1,1,1,'\\ ','leebail'),(4375,792817669012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','rwickramage','ravindra.wickramage@aes.com','ravindra wickramage','No:521,Atigala Road,','Meegoda','Western','SRI LANKA','10504','+94 773060380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 17:24:15',0,NULL,3,1,2,1,'\\ ','rwickramage'),(4376,585775768013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'eastar4','rn2009','amandabelanger@cogeco.ca','Amanda Belanger','11873 Tecumseh Road East<br>Apartment 221','Tecumseh','ON','CANADA','N8N3K1','(519) 980-1317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 17:36:41',0,NULL,3,1,2,1,'\\ ','rn2009'),(4377,533158935003,130458358283,'New  NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'HSNO006+CCNO001',16.95,'cnfaner','janrathouz','j.mcg@seznam.cz','Jan Rathouz','zizkova 17','Zásmuky','','CZECH REPUBLIC','28144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 17:36:47',0,NULL,3,1,3,1,'RA117724417CN\r ','janrathouz\rHSNO006+CCNO001'),(4378,713886625011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','bqbskydive','bbergfield@hotmail.com','Brian  Bergfield','6808 Lochwood Ct','Garland','TX','UNITED STATES','75044-3474','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 17:50:01',0,NULL,3,1,1,1,'\\ ','bqbskydive'),(4379,585782309013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',79.99,'eastar4','aplusco1','adamppham@yahoo.com','Adam Pham','11330 Knott St','Garden Grove','CA','UNITED STATES','92841-1400','(714) 600-6999','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 18:31:37',0,NULL,3,1,1,1,'\\ ','aplusco1'),(4380,533169825003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','sevketserdar','sevketserdar@hotmail.com','Sevket Serdar','örnek mahallesi Ahmet Yesevi Cadde<br>No:136 Atasehir /istanbul','istanbul','Atasehir /istanbul','TURKEY','34704','902164725763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 18:55:22',0,NULL,3,1,3,1,'RA117724363CN\r ','sevketserdar\rWWSI005+ANCN001'),(4381,713969536011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','gilbege','gilbert40@comcast.net','Geoffrey Gilbert','6 Brighton Way<br>Apt 2B','Clayton','MO','UNITED STATES','63105-1612','(314) 727-0617','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 20:04:37',0,NULL,3,1,1,1,'\\ ','gilbege'),(4382,713876595011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',167.98,'eastar4','fredy_isc','fredy_toy@hotmail.com','FREDY YONATAN ZENDEJAS BARRERA','Vicente Suarez # 5<br>Colonia Niños Heroes San Luis Tlaxialtemalco','Xochimilco','Distrito Federal','MEXICO','16610','015558437609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 20:09:46',0,NULL,3,1,3,1,'RA117724479CN\r ','fredy_isc\rOTSO004'),(4383,792911368012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','chaos_r','lorboy15@hotmail.com','Chong Lor','506 Jefferson st','Eau Claire','WI','UNITED STATES','54701','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 20:15:28',0,NULL,3,1,1,1,'\\ ','chaos_r\r红边优联'),(4384,792915544012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',35.99,'eastar4','tanlaas','msouthwell@me.com','Matthew Southwell','1024 Cayer Dr<br>Apt 802','Glen Burnie','MD','UNITED STATES','21061-4161','(443) 253-0003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 20:24:09',0,NULL,3,1,1,1,'\\ ','tanlaas'),(4385,792923491012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',88.99,'eastar4uk','b0skins','justynpeterhoskins@hotmail.com','Justyn Hoskins','Sanderson - RBS, 24 - 26 Vincent Avenue<br>Crownhill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK80AB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 20:45:49',0,NULL,3,0,3,1,'RA117724482CN\r ','b0skins\rGLSG001*2'),(4386,713561048011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',9.45,'eastar4uk','2010maritime','gm.ford@btinternet.com','Jayne Ford','56 , Church Street','Lyme Regis','Dorset','UNITED KINGDOM','DT7 3DA','01297443522','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 20:51:46',0,NULL,3,1,3,1,'RA117724332CN\r ','2010maritime\rWLAP001'),(4387,713997628011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','tonyto210','tonyto@lyse.net','Bjørnar Totland','Terneveien 13','Stavanger','Hafrsfjord','NORWAY','4049','004797088308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 21:06:23',0,NULL,3,1,2,1,'\\ ','tonyto210\r欧标'),(4388,792942310012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','gibay1','gioangn@sbcglobal.net','Gioang Nguyen','2511 Mandy Way','Arlington','TX','UNITED STATES','76017','(817) 419-9601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 21:21:23',0,NULL,3,0,1,1,'\\ ','gibay1'),(4389,714004300011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',6,'MOAP001',101.94,'eastar4uk','maccess_inc','maccessinc@comcast.net','Lew Rossi','1230 Ellis Mill Rd','Mullica Hill','NJ','UNITED STATES','08062-4426','(856) 307-1200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-25 21:22:44',0,NULL,3,1,1,1,'\\ ','maccess_inc'),(4390,792943386012,220594073947,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10 S10e S9',1,'BTLE2101',12.4,'eastar4','gsah9387','guy@baystateflowers.com','Guy Sahatjian','2908 Brownsboro Rd suite 110','Louisville','KY','UNITED STATES','40206','(502) 345-9886','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 21:22:43',0,NULL,3,1,1,1,'\\ ','gsah9387'),(4391,792948100012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',166.99,'eastar4','arizona1949','rdemeyere@aol.com','Russell DeMeyere','1903 Stafford Street','Woodbridge','VA','UNITED STATES','22191','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 21:34:59',0,NULL,3,0,1,1,'\\ ','arizona1949'),(4392,585862896013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','ericcivil','ericcivil@gmail.com','Eric Miller','1587 2nd Ave<br>Apt 1','Walnut Creek','CA','UNITED STATES','94597','(925) 212-8142','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 21:52:54',0,NULL,3,0,1,1,'\\ ','ericcivil\r旧的'),(4393,714018760011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','up92','phung.ws1@gmail.com','Phouric Ung','18 rue de Bitche','Courbevoie','Ile-de-France','FRANCE','92400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 22:03:35',0,NULL,3,1,3,1,'RA117724584CN ','up92\rEXLO001'),(4394,792962253012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','jasongreensides','jason@sugarhouse.com','Jason Greensides','450 E 2200 S','Salt Lake City','UT','UNITED STATES','84115-2874','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 22:13:56',0,NULL,3,1,1,1,'\\ ','jasongreensides'),(4395,792964240012,220684633355,'INOVA T4 LED FLASHLIGHT TORCH + charger',1,'BAIN001+BAIN002+TOIN002',49.9,'eastar4','petebest1471','bestmoule@btinternet.com','Pete Best','2 Broad Road<br>Fleggburgh','Fleggburgh','Norfolk','UNITED KINGDOM','NR29 3DD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 22:21:14',0,NULL,5,1,3,1,NULL,'petebest1471\rBAIN001+BAIN002+TOIN002\r由于无货已退款'),(4396,792973145012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','myashi','mdm6x7@gmail.com','Mark Murabayashi','4855 Colony Church Rd<br>Apt 1','Saint Louis','MO','UNITED STATES','63129-1154','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 22:50:28',0,NULL,3,1,1,1,'\\ ','myashi\r旧的'),(4397,536956279004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',35.99,'cnfaner','mzawamarcelo','mzawa@uol.com.br','Marcelo Zawadzki','Rua H09 B 404 CTA','São José dos Campos','São Paulo','BRAZIL','12228611','551281184934','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 22:54:13',0,NULL,3,1,3,1,'RA117724346CN\r ','mzawamarcelo\rWWSI005'),(4398,585880391013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','jimsaxman','jimsnodgrass@cox.net','James Snodgrass','3232 Feathering Ct','North Las Vegas','NV','UNITED STATES','89084','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-25 23:17:32',0,NULL,3,1,1,1,'\\ ','jimsaxman'),(4399,711735494011,320678793994,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',9.26,'eastar4uk','the-last-vampire','paranormalcy@live.com.au','Chrie lynn Puime','15 wrybourne street','deception bay','Queensland','AUSTRALIA','4508','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-25 23:25:45',0,NULL,3,1,2,1,'\\ ','the-last-vampire\r澳标'),(4400,792996949012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','fefaj1esteban','fefaj1@student.monash.edu.au','Felipe Fajardo','5/16 Clive St','Brighton East','Victoria','AUSTRALIA','3187','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 00:26:29',0,NULL,3,1,2,1,'\\ ','fefaj1esteban\r红边优联'),(4401,714064971011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','sinh-h','sinhhua@gmail.com','Chi Sinh Hua','458 Reeves Way Blvd.','Stouffville','ON','CANADA','L4A0H2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 01:19:46',0,NULL,3,1,2,1,'\\ ','sinh-h'),(4402,714075111011,320667818608,'New Logitech battery 4  DJ remote diNovo keyboard 930mA',1,'BALO004',10.99,'eastar4','mpkhc','lma71530@bigpond.com','Leigh Meager','39 Fleetway Street<br>Morningside','Brisbane','Queensland','AUSTRALIA','4170','0738994456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 02:01:01',0,NULL,3,1,2,1,'\\ ','mpkhc'),(4403,714078809011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','luke_and_lisa','lukeramsey84@bigpond.com','Lisa and Luke Ramsey','80 Rowbotham Street','Rangeville','Queensland','AUSTRALIA','4350','0746135075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 03:00:36',0,NULL,3,1,3,1,'RA117724567CN ','luke_and_lisa\rHSPL015\r澳标'),(4404,538988442004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','roca327','roca_327@yahoo.es','Roberto Santibañez','eleuterio ramirez 327','Lota','Region del BioBio','CHILE','1700000','56990614420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 03:04:39',0,NULL,3,1,3,1,'RA117724350CN\r ','roca327\rHSNO022'),(4405,793038192012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','scharnhorstab','abscharnhorst@butler-bremer.com','Andrew Scharnhorst','1413 dakota ave','plainfield','IA','UNITED STATES','50666','(319) 415-4403','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 03:12:36',0,NULL,3,1,1,1,'\\ ','scharnhorstab'),(4406,585927397013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','kopcev','kopcev-av@yandex.ru','Anton Koptsev','K.Marksa 57/1, 41','Magnitogorsk','Chelyabinskaya oblast\'','RUSSIAN FEDERATION','455023','89030911654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 03:53:59',0,NULL,3,1,3,1,'RA117724553CN ','kopcev\rOTRA001'),(4407,533299237003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','henrykhyap','henrykhyap@yahoo.com.my','Yap Kiam Hiang','C-0-4 Pangsapuri Kesuma ,<br>Jln. BK3/1 Bdr. Kinrara,','Puchong','Selangor','MALAYSIA','47100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 04:02:07',0,NULL,3,1,3,1,'RA117724536CN ','henrykhyap\rHSMO016'),(4408,793054166012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',17.96,'eastar4','j-acord','jacord@live.com','Joel Acord','PO Box 361<br>611 S Pine Street','Troy','ID','UNITED STATES','83871-0361','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 04:29:02',0,NULL,3,1,1,1,'\\ ','j-acord\r一共买了两个\r新地址\rJoel Acord\r400 N Adams St. Apt #5\rMoscow, ID 83843\r'),(4409,793055673012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','misseducated88','ameliaorr@yahoo.com','Amelia Orr','935 Hollytree Dr','Cincinnati','OH','UNITED STATES','45231-4746','(513) 582-8535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 04:37:50',0,NULL,3,1,1,1,'\\ ','misseducated88'),(4410,793065548012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',8.7,'eastar4','corruptor23','nemeth.denes@gmail.com','Denes Nemeth','Frangepan u. 26.','Budapest','','HUNGARY','1139','0036308192782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 05:32:53',0,NULL,3,1,17,0,'\\ ','corruptor23'),(4411,793066067012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','corruptor23','nemeth.denes@gmail.com','Denes Nemeth','Frangepan u. 26.','Budapest','','HUNGARY','1139','0036308192782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 05:34:07',0,NULL,3,1,17,0,'\\ ','corruptor23'),(4412,714114908011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',1,'CASS001',8.7,'eastar4','corruptor23','nemeth.denes@gmail.com','Denes Nemeth','Frangepan u. 26.','Budapest','','HUNGARY','1139','0036308192782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 05:34:59',0,NULL,3,1,2,1,'\\ ','corruptor23\r一共买了\r一个CAB-2626\r一个CAB-2660\r一个CAB-6060\r'),(4413,714115337011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',15.99,'eastar4','mrschiefer','frank.paukstat@online.de','Frank Paukstat','P+S Labormedien GmbH<br>Salvatorweg 3','Hohenwart-Deimhausen','','GERMANY','86558','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 05:40:02',0,NULL,3,1,2,1,'\\ ','mrschiefer\r欧标'),(4414,793071680012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','karynkrafts','karyn.newbill@yahoo.com','Karyn Newbill','3064 Divernon Ave','Simi Valley','CA','UNITED STATES','93063-1609','(805) 583-1385','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 06:04:44',0,NULL,3,1,1,1,'\\ ','karynkrafts\r新的'),(4415,714123100011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',67.99,'eastar4','loulouganda','legaspi2006@yahoo.com.au','marilou legaspi','1380 canterbury rd','Punchbowl','New South Wales','AUSTRALIA','2196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 06:23:23',0,NULL,3,1,3,1,'RA117724519CN ','loulouganda\rGLSG001'),(4416,714115551011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','sishkovrs','nitro@mail.ru','Alexander Sishkov','Eseninia street 1-1-326','St-Petersburg','St-Petersburg','RUSSIAN FEDERATION','194354','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 06:38:41',0,NULL,3,1,3,1,'RA117724607CN ','sishkovrs\rGLSG001*2'),(4418,793088612012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','yvladi83','yvladi83@gmail.com','Vladislav Yusupov','Sthayinberg 31/4','Kiryat Atta','','ISRAEL','28068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 07:30:13',0,NULL,3,1,2,1,'\\ ','yvladi83'),(4417,714131492011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','jefff31400','jf.verdier@free.fr','VERDIER Jean-François','22 rue Eugene MONTEL<br>Apt.02','TOURNEFEUILLE','Midi-Pyrénées','FRANCE','31170','0611085368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 07:07:01',0,NULL,3,1,2,1,'\\\r ','jefff31400\racer 8pin1.00 8cm'),(4419,793090917012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',2,'HSMO019',33.98,'eastar4uk','vespadude67','b.davison@talktalk.net','becky davison','1 beechwood avenue','sittingbourne','Kent','UNITED KINGDOM','me102dy','01795439067','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 07:39:31',0,NULL,3,1,3,1,'RA117724575CN ','vespadude67\rHSMO019\r英标'),(4420,793097264012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',25.98,'eastar4','alebastr_89','alebastr89@gmail.com','Alexey Bavshin','Elizarovyh st. 46, app. 19','Tomsk','Tomskaya obl','RUSSIAN FEDERATION','634012','+79618920818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 08:10:05',0,NULL,3,1,2,1,'\\ ','alebastr_89'),(4421,793101563012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.4,'eastar4','sr20dedweeb','maxchillin@gmail.com','david thong','4580 la madera ave','el monte','CA','UNITED STATES','91732-1658','(626) 213-4482','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 08:26:02',0,NULL,3,1,1,1,'\\ ','sr20dedweeb\rHP 6pin 1.0 12cm '),(4422,792765365012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','kstavr','k_stavr@hotmail.com','Aikaterini Stavraki','Velanidias 14','Athens','Attiki','GREECE','14561','+306938897862','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 08:27:36',0,NULL,3,1,3,1,'RA117738795CN ','kstavr'),(4423,793097355012,220451372871,'Benq R55  Bluetooth Module 2.0 EDR+cable',1,'BTBE2004',12.5,'eastar4','kostya82bk','kostya82@bk.ru','Konstantin Shalagin','Moskovskiy trakt, 167-146','Tyumen','Tyumenskaya oblast','RUSSIAN FEDERATION','625049','+7 9504863825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 08:29:23',0,NULL,3,1,2,1,'\\ ','kostya82bk'),(4424,788245844012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',3,'CMLO001',83.97,'eastar4uk','cjayward','jeanluc.profumo@wanadoo.fr','Jean-Luc PROFUMO','3, Place du 21 août 1944','COMBLANCHIEN','Bourgogne','FRANCE','21700','03 80 62 73 16','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 08:52:52',0,NULL,3,1,3,1,'RA117724686CN\r ','cjayward\rCMLO001'),(4425,793131688012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','13291629','mixalis1964@live.com','michalis damianou','zinonos 5','yeroskipou','','CYPRUS','8200','0035799626697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 10:28:22',0,NULL,3,1,2,1,'\\ ','13291629\r欧标'),(4426,714191131011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','nunoborralho','nunoborralho@mac.com','Nuno Borralho','Edificio Grupo Impala<br>Rua da Impala, 33-A','S. Pedro de Penaferrim','Abrunheira','PORTUGAL','2710-070 Sin','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 11:28:10',0,NULL,3,1,2,1,'\\ ','nunoborralho\r旧的'),(4427,539063732004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','koscica75','nkoscica@tankerska.hr','Nikola Koščica','Stanka Vraza 8A','Zadar','','CROATIA','23000','+385 98418565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 11:32:54',0,NULL,3,1,3,1,'RA117724672CN\r ','koscica75\rOTHP004'),(4428,585997012013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','morganbressler','faststix976@aol.com','Sandra Bressler','2563 valley view rd','morgantown','PA','UNITED STATES','19543-9442','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 11:46:30',0,NULL,3,1,1,1,'\\ ','morganbressler'),(4429,714199236011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','g_ricketts','george@wheresmycows.com','George Ricketts','19 East Street','Palmerston North','','NEW ZEALAND','4410','6421811982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 12:00:36',0,NULL,3,1,3,1,'RA117724743CN\r ','g_ricketts\rBR3D001\r新地址\rGeorge Ricketts\r232 Victoria Ave\rPalmerston North 4410\rNew Zealand\r(64) 21 811 982\r'),(4430,793156519012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','miciux20','miciux@walla.com','Mindaugas Miceika','Kalvestien 14','Vøyenenga','Bærum','NORWAY','1339','(+47) 98825850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 12:13:59',0,NULL,3,1,2,1,'\\ ','miciux20\r欧标'),(4431,793175173012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',19.61,'eastar4','maximsk','mskurakin@gmail.com','Maxim Kurakin','ul. Kasimovskaya, dom 21, kv. 64','Nizhniy Novgorod','','RUSSIAN FEDERATION','603108','910-10-45-785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 12:56:58',0,NULL,3,1,2,1,'\\ ','maximsk\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e'),(4432,586013516013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','keytechky','jireeder@1stcorbin.com','Key Technology-Jim Reeder','2400 S Main St','Corbin','KY','UNITED STATES','40701','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 13:02:09',0,NULL,3,1,1,1,'\\ ','keytechky'),(4433,793214274012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','hirukohector','hector.hfarias@gmail.com','Hector Farias Hettich','Ibsen 568<br>departamento B73','Valparaiso','Valparaiso/ V region','CHILE','2340000','+56971395570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 14:50:23',0,NULL,3,1,2,1,'\\ ','hirukohector'),(4434,714252743011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','nir_o','nirozer@hotmail.com','Andrea Ozer','Austrian Embassy<br>Crystal House, 12 Hachilason St.','Ramat Gan','Ramat Gan','ISRAEL','52522','009729-9555550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 15:03:53',0,NULL,3,1,2,1,'\\ ','nir_o'),(4435,793221307012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','chredit','chris_coles@hotmail.com','Chris Coles','11212 Lake Overlook Pl','Mitchellville','MD','UNITED STATES','20721-2933','(301) 336-0031','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 15:12:56',0,NULL,3,1,1,1,'\\ ','chredit'),(4436,793228631012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','cesarcarrera','info@cesarcarrera.com','cesar carrera','12, Isabel Serrano ST. 2 - B','MADRID','','SPAIN','28029','913141550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 15:28:12',0,NULL,3,1,2,1,'\\ ','cesarcarrera'),(4437,793229950012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','peekay47','kelly_paul@sky.com','Paul Kelly','61 Atherley Grove','Chadderton','Lancashire','UNITED KINGDOM','OL9 8DD','07896490262','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 15:31:17',0,NULL,3,1,3,1,'RA117724615CN\r ','peekay47\r英标\rHSPL010'),(4438,586049002013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','eduforti','edusaita@hotmail.com','Juliana Ernesto Gimenez','Rodovia PR 461 - Km 01','Lobato','Parana','BRAZIL','86790-000','+55 44 33233130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 15:35:30',0,NULL,3,1,3,1,'RA117724624CN\r ','eduforti\rOTRA001'),(4439,533414128003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','chen91079','chrish@salem.cc','Chris Henderson','4880 Santa Rosa Rd','Camarillo','CA','UNITED STATES','93012','(805) 987-0400 ext.: 1010','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 15:40:35',0,NULL,3,1,1,1,'\\ ','chen91079'),(4440,586050269013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','radiokirill','karpovkirill@hotmail.com','Kirill Karpov','537 Rue Des Clematites','Saint-Eustache','QC','CANADA','J7P0B9','(450) 623-7528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 15:46:00',0,NULL,3,1,3,1,'RA117734079CN\r ','radiokirill\rOTES001'),(4441,714275321011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','geovaldivia','geovaldivia@hotmail.com','Denisse Amanqui Reategui','Cl. Monte Caoba Mz. N1 Lt. 32<br>Residencial Monterrico Sur - Surco','Lima','Lima','PERU','Lima33','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 16:08:06',0,NULL,3,1,3,1,'RA117724730CN\r ','geovaldivia\rOTSO004'),(4442,713941423011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','shaki2981','danettelarkins@gmail.com','Ashaki Larkins','229 Smith St','Newark','NJ','UNITED STATES','07106-1709','(862) 579-9223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 16:09:45',0,NULL,3,1,1,1,'\\ ','shaki2981'),(4443,714279215011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','geovaldivia','geovaldivia@hotmail.com','Eduardo Valdivia Espinoza','Cl Monte Caoba Mz N1 Lt 32<br>Urb Residencial Monterrico Sur - Surco','Lima','Lima','PERU','Lima33','5112780733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 16:10:56',0,NULL,3,1,3,1,'RA117724690CN\r ','geovaldivia\rOTSO004'),(4444,793258975012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','saaron11','saaron1022@gmail.com','Steve Aaron','562 Kings Hwy','Mickleton','NJ','UNITED STATES','08056-1405','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'saaron11'),(4445,585465100013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','hulk.maniac','denni_muharam@yahoo.com','Septian Setia Dwi Putra','Jln. Sarangan Atas No.18','Malang','','INDONESIA','65141','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 17:36:36',0,NULL,3,1,3,1,'RA117724638CN\r ','hulk.maniac\rWWOT001+ANCN001\r\r'),(4446,539153462004,140482633304,'New GENUINE NOKIA HS-11W BLUETOOTH HEADSET track#',1,'HSNO023',14.98,'cnfaner','jakamax','jameskang5@gmail.com','James Kang','GangNam-ku, YeokSam-dong, 817-29<br>Joey Bldg. #504','Seoul','Seoul','KOREA,REPUBLIC OF','135-080','(010) 478-6888 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:01:10',0,NULL,3,1,3,1,'RA117724641CN\r ','jakamax\rHSNO023'),(4447,793322234012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','bodor0276','bodor02.76@freemail.hu','Attila Bódor','Fehérvári út 153/b','Gy&#337;r','','HUNGARY','9028','+36205564096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:52:23',0,NULL,3,1,3,1,'RA117724709CN\r ','bodor0276\rHSPL010+HSNO022\r再发一个New GENUINE NOKIA HS-4W BLUETOOTH HEADSET '),(4448,586112258013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','bodor0276','bodor02.76@freemail.hu','Attila Bódor','Fehérvári út 153/b','Gy&#337;r','','HUNGARY','9028','+36205564096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:56:43',0,NULL,3,1,17,0,NULL,'bodor0276'),(4449,714359998011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','orabera','goldmike@gmail.com','G. Michael Goldsberry','735 Struthers Ranch Rd','Colorado Springs','CO','UNITED STATES','80921-4802','(719) 481-1091','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 19:10:11',0,NULL,3,1,4,1,'YW865717942CN ','orabera'),(4450,586118690013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','extremehick18','extremehick@hotmail.com','James Powell','500 New Creation Rd N','Newark','MO','UNITED STATES','63458-9743','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 19:14:01',0,NULL,3,1,1,1,'\\ ','extremehick18'),(4451,793339156012,220448674413,'Acer Travelmate 5110 5610 Bluetooth Module2.0 EDR+cable',1,'BTAC2008',12.5,'eastar4','hugh2611','hughatthepub2610@gmail.com','A-Hugh Edwards','10800 NW 103rd St<br>Ste 5E','Miami','FL','UNITED STATES','33178','(809) 571-3209','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 19:21:49',0,NULL,3,1,1,1,'\\ ','hugh2611\racer 4pin1.25 18cm  '),(4452,714368375011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',59.99,'eastar4','gstrickland','gscoppell@gmail.com','Greg Strickland','609 Waverly Ln','Coppell','TX','UNITED STATES','75019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 19:26:33',0,NULL,3,1,1,1,'\\ ','gstrickland'),(4453,533505463003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','dimannius','dmy.goncharenko@gmail.com','Dmytro Goncharenko','Oldenburger Str. 65, Deutsche WindGuard Consulting GmbH, 2.OG','Varel','','GERMANY','26316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 20:37:04',0,NULL,3,1,3,1,'RA117724805CN\r ','dimannius\rWWSI005+ANCN001'),(4454,714412544011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','trondproductdesign','tsundt@gmail.com','Trond Sundt','Vognstølbakken 2','Bergen','','NORWAY','5096','004792662155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 21:04:22',0,NULL,3,1,2,1,'、 ','trondproductdesign'),(4455,793393401012,220681549405,'New SAMSUNG WMN1000A ULTRA SLIM WALL-MOUNT LED 26\"-37\" ',1,'MOSA001',45.98,'eastar4uk','annanolly1','v100lly@fsmail.net','Tristan Oldnall','40 Upper Landywood Lane<br>Landywood','Walsall','West Midlands','UNITED KINGDOM','WS6 7AU','01922417173','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 21:07:05',0,NULL,3,1,3,1,'RA117724655CN\r ','annanolly1\rMOSA001'),(4456,533516352003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','bagwan69','robert.vandermeer5@gmail.com','Robert VanderMeer','62 Wayne St SE','Grand Rapids','MI','UNITED STATES','49548','(616) 293-0722','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 21:12:24',0,NULL,3,1,1,1,'\\ ','bagwan69'),(4457,793399496012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','jazzinatl','jeffjohnson49@gmail.com','Jeffrey C Johnson','3879 Stratford Park Drive NE','Atlanta','GA','UNITED STATES','30342-4301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 21:20:36',0,NULL,3,1,1,1,'\\ ','jazzinatl'),(4458,793405382012,220743499505,'NEW Genuine Motorola S9 Bluetooth Stereo Headset',1,'HSMO002',31,'eastar4uk','martink4508','mekalaher@blueyonder.co.uk','M Kalaher','151 Nevill Road<br>Stoke Newington','London','London','UNITED KINGDOM','N16 0SU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 21:34:07',0,NULL,3,1,3,1,'RA117724726CN\r ','martink4508\rHSMO002\r英标'),(4459,714443684011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','rischubert','tec_schubert@yahoo.com.br','Richard Schubert da Silva','Rua Orozimbo Rodrigues Paiva, 06 (Estrada do M Boi Mirim, 2617)','São Paulo','São Paulo','BRAZIL','04905-000','+551167555587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 22:29:48',0,NULL,3,1,2,1,'\\ ','rischubert'),(4460,714445550011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','liwan74','lilihanse@yahoo.com','LILIAN WANJALA','12643 ROBISON BLVD<br>Apt 220','POWAY','CA','UNITED STATES','92064-4430','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 22:36:08',0,NULL,3,1,1,1,'\\ ','liwan74'),(4461,714444786011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',167.98,'eastar4','802962774','joved8@hotmail.com','JOVED GONZALEZ-RIVERA','URB COLINAS VERDES<br>CALLE 2 C-5','SAN SEBASTIAN','PR','PUERTO RICO','00685','(787) 896-7034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 22:40:29',0,NULL,3,1,1,1,'\\ ','802962774\r一共买了两个'),(4462,793428199012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','teigen75','thafslun@gmail.com','Terje Hafslund','Trollkleiva 4','Kristiansand','Vest-Agder','NORWAY','4638','+4790753576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 22:46:24',0,NULL,3,1,2,1,'\\ ','teigen75'),(4463,714448934011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',16.6,'eastar4','22c007','calin_vasile@hotmail.com','Calin  Vasile','47 Holland Cr','Guelph','ON','CANADA','N1L 1T4','(519) 836-4764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 22:49:19',0,NULL,3,1,2,1,'\\ ','22c007'),(4464,793433421012,220681620511,'New SAMSUNG WMN1000B ULTRA SLIM WALLMOUNT LED TV 40-50\'',1,'MOSA002',47.89,'eastar4uk','bravo101111','tomtoich@webmail.co.za','Thomas Toich','8 Alice Cove, 61 Princess Alice Drive,<br>Nahoon,','East London,','','SOUTH AFRICA','5241','(027) 82 4139 133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 23:02:49',0,NULL,3,1,3,1,'RA117724712CN ','bravo101111\rMOSA002\r\r货发了，但是点不了已发货。\r\r所以改成了递四方  系统后台有单号了。'),(4465,714453969011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','jeh1950','pc.1950@yahoo.com','John Hamilton','21081 Cocobana Ln','Huntington Beach','CA','UNITED STATES','92646','(714) 964-9895','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 23:11:38',0,NULL,3,1,1,1,'\\ ','jeh1950\rHP 8pin 1.25 18cm '),(4466,714438944011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',132.95,'eastar4','cyberkako','prodrigues.santos@gmail.com','paulo santos','rue wanda santos mullmann 1266 ap41 b06','pinhais','parana','BRAZIL','83323400','55 41 96417420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 23:37:22',0,NULL,3,1,3,1,'RA117724791CN\r ','cyberkako\rGLSG001*2'),(4467,793455230012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','spinaw','aharon.bar@gmail.com','Aharon Bar','Ausishkin 32','Hertzelyia','Israel','ISRAEL','46406','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 00:29:32',0,NULL,3,1,2,1,'\\\r ','spinaw'),(4468,714473857011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','dan1423','sweenick@aol.com','Daniel Fennick','1423 E Market St','York','PA','UNITED STATES','17403-1254','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 00:40:01',0,NULL,3,1,4,1,'YW865717931CN ','dan1423'),(4469,586203062013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','designloveart','chris@mnml.com.au','Chris Seibold','13 Newport St','East Ballina','New South Wales','AUSTRALIA','2478','0266191711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 00:51:26',0,NULL,3,1,3,1,'RA117724669CN\r ','designloveart\rOTES001'),(4470,539258125004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',3,'HSPL014',105,'cnfaner','j_romanr','j_romanr@yahoo.com','ISG','2135 Carr. #2 Suite 15<br>PMB 310','Bayamon','PR','UNITED STATES','00959','(888) 792-2111','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-27 01:14:18',0,NULL,3,1,1,1,'\\ ','j_romanr'),(4471,793483859012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','stephensilva1','stephensilva20@gmail.com','Stephen Silva','36 Madison Ave','Madison','NJ','UNITED STATES','07940-1434','(908) 655-6994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 02:15:56',0,NULL,3,1,1,1,'\\ ','stephensilva1'),(4472,714497943011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','abirm2005','m_ziad77@hotmail.com','ziad malak','46 Sunset boulevard','Mcleod Hill','NB','CANADA','E3G6A2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 02:30:24',0,NULL,3,1,2,1,'\\ ','abirm2005'),(4473,714499999011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jpablos83','jpablosolorzano@hotmail.es','JUAN PABLO','5418 NW 79th Ave<br>WEBBOX 1318','Doral','FL','UNITED STATES','33166-4122','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 02:37:29',0,NULL,3,1,1,1,'\\ ','jpablos83'),(4474,793084179012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','wyeechen','wyeechen@yahoo.com','Wong Yee Chen','3, Jalan Sarjana,<br>Taman Connaught,','Cheras','Kuala Lumpur','MALAYSIA','56000','0123720736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 04:21:17',0,NULL,3,1,2,1,'、 ','wyeechen'),(4475,793512662012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','phoneiexcain','phoneixcain@yahoo.com','Jon Cain','PO Box 419','Mayesville','SC','UNITED STATES','29104-0419','(803) 453-5985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 04:24:38',0,NULL,3,1,1,1,'\\ ','phoneiexcain'),(4476,586247240013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','canningsteve','steve@canning77.com','Stephen Canning','Unit 554 Corinthian Condominium<br>No 5 Jalan Binjai','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 05:31:04',0,NULL,3,1,3,1,'RA117724757CN\r ','canningsteve\rOTRA001'),(4477,586271258013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','smollye','erwin.smolders@gmail.com','Erwin Smolders','A. Sanderslei 71/1','Aartselaar','','BELGIUM','2630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 08:28:07',0,NULL,3,1,2,1,'\\ ','smollye'),(4480,586274732013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','mixu42','mixu42@suomi24.fi','Mikael Lehtinen','Parivaljakontie 6 B 16','Helsinki','','FINLAND','00410','+358407318443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 08:42:09',0,NULL,3,1,3,1,'RA117724774CN\r ','mixu42\rOTRA001'),(4478,714537775011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',59,'eastar4','kangpartners','richard@yoc.com.au','Zhexin  Kang','Unit 803 / 76 Rawson Street','Epping','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 08:36:54',0,NULL,3,1,3,1,'RA117724788CN\r ','kangpartners\rGLOT001'),(4479,714567992011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.96,'eastar4','meyocr','meyocr@gmail.com','MANUEL EYO CASTRO-RIAL','ROSALIA DE CASTRO 30 5ºB','PONTEVEDRA','Galicia','SPAIN','36001','699958729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 08:37:58',0,NULL,3,1,2,1,'\\ ','meyocr'),(4481,586288997013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','valkyrievf4s','valkyrievf4s@gmail.com','Chakrit Kumwong','G.P.O.Box 2779','Bangruk','Bangkok','THAILAND','10500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 10:08:52',0,NULL,3,1,2,1,'\\ ','valkyrievf4s\r银色的'),(4482,793599028012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','mvbsound','mvbsound@optusnet.com.au','Michael Valier-Berther','15 Flinders AV','Molendinar','QUEENSLAND','AUSTRALIA','4214','0411309573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 10:48:15',0,NULL,3,1,2,1,'\\ ','mvbsound'),(4483,714613644011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.99,'eastar4','simcict','tomislav.simcic@ri.t-com.hr','Tomislav Simcic','Radnicka 10','Opatija','','CROATIA','51410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:38:31',0,NULL,3,1,2,1,'\\ ','simcict\rHP 5pin1.0 20cm '),(4484,714624239011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.79,'eastar4','caspon09','caspi_j@hotmail.com','Arie Caspi','zerubavel<br>1','Efrat','','ISRAEL','90435','+972542099122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 12:14:21',0,NULL,3,1,2,1,'\\ ','caspon09'),(4485,714627712011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mblsha','mblsha_mblsha@yahoo.com','Sharfman Michael','Naftaley-Hilel 3/6','Rishon-LeZion','','ISRAEL','75253','+972546241148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 12:25:20',0,NULL,3,1,2,1,'\\ ','mblsha'),(4486,586319054013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','amberboats','ltr34@aol.com','Len Romano','34 Buccaneer Ln','Setauket','NY','UNITED STATES','11733-1967','(631) 433-3196','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 12:39:30',0,NULL,3,1,1,1,'\\ ','amberboats'),(4487,793657401012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','zamjae6129','ybell@wef.org','Yesha Saki Bell','13010 Abner Ave','Woodbridge','VA','UNITED STATES','22192-5602','(703) 786-6051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 13:51:26',0,NULL,3,1,1,1,NULL,'zamjae6129'),(4488,586337194013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',39.95,'eastar4','thyutagon','simon.s.utagon@hotmail.com','simon utagon','1270 N Marine Corps Dr<br>Ste 101 PMB 294','tamuning','GU','UNITED STATES','96913-4331','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 14:00:00',0,NULL,3,1,1,1,'\\ ','thyutagon\r盒装的\r红色的'),(4489,539377462004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','madiazs','mads.mads@gmail.com','MAURICIO ALFONSO DIAZ SUAREZ','AVENIDA CONSISTORIAL 2320-33<br>PEÑALOLÉN','SANTIAGO','METROPOLITANA','CHILE','794-1137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 14:05:30',0,NULL,3,1,3,1,'RA117734051CN\r ','madiazs\rOTCR001'),(4490,539371521004,140516496368,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',82,'cnfaner','globalsolutions_it','carloz@globalsolutions.it','Global Solutions di Zambon Carlo','Via Coppino 135','Torino','TO','ITALY','10147','011-2919047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 14:35:51',0,NULL,3,1,3,1,'RA117737971CN\r ','globalsolutions_it\rTRTS001*10'),(4491,793675428012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','swankyii.330','middleswank@roadrunner.com','Robert Wingerter','2267 Irene Rd','Wadsworth','OH','UNITED STATES','44281-7824','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 14:39:36',0,NULL,3,1,1,1,'\\ ','swankyii.330'),(4492,714678531011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',59,'eastar4','sat112','alpcan66@gmail.com','ALP CAN','Pinar Sut A.S. Kemalpasa Asfalti No:1<br>Pinarbasi','Izmir','','TURKEY','35060','90.232.4361515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 15:02:09',0,NULL,3,1,3,1,'RA117737720CN\r ','sat112\rGLOT001\r'),(4493,714682755011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','cpernot69','cyril.pernot@dbmail.com','Cyril PERNOT','8 rue saint gervais','LYON','Rhône-Alpes','FRANCE','69008','04.78.00.09.34','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 15:14:17',0,NULL,3,1,3,1,'RA117734105CN\r ','cpernot69\rOTSO004'),(4494,793714148012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','agtcitizenx','garcia.joseluis@ymail.com','Jose  Garcia','2101 Lima Loop','Laredo','TX','UNITED STATES','78045','(956) 712-6550','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 16:15:27',0,NULL,3,1,1,1,'\\ ','agtcitizenx'),(4495,714715874011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',45.8,'eastar4','nitromet1','hoakster@live.com','Ron Biekx','Grand Bend Motorplex<br>70292 Grand Bend Line, Highway 81 East, Grand Bend Airport','Grand Bend','ON','CANADA','N0M 1T0','(519) 238-7223 ext.: 26','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 16:41:31',0,NULL,3,1,3,1,'RA117734564CN\r ','nitromet1\rHSSE004'),(4496,586381480013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',9,'HSNO019',359.91,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-27 16:45:28',0,NULL,3,1,3,1,'RA117737985CN\r ','jape324\rHSNO019\r欧标\r\r'),(4497,713603910011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','simmonsc','ccw.simmons@comcast.net','Christopher S. Simmons','3890 Union St SE','Albany','OR','UNITED STATES','97322-7644','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 16:50:29',0,NULL,3,1,1,1,NULL,'simmonsc'),(4498,586387141013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','dex_cz','janweber@volny.cz','Jan Weber','Svážná 32','Brno','výchozí','CZECH REPUBLIC','63400','+420 776113791','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 17:04:11',0,NULL,3,1,2,1,'\\ ','dex_cz'),(4499,539423013004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',5,'WLAP002',127.45,'cnfaner','norunoki','ebay@norunoki.com','Lee Drinnan','4 Tou 505','Higashi-Machi 4-16','Kumamoto','JAPAN','862-0901','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 17:07:20',0,NULL,3,1,3,1,'RA117734034CN\r ','norunoki\rWLAP002'),(4500,714732757011,320700575061,'NIB Samsung SSG-P2100S/W 3D TRIPLE FEATURE blu-ray IMAX',1,'GLSG002',96.99,'eastar4uk','dennisbagge','dk.bagge@hotmail.com','Dennis Bagge','Ejbytoften 3','Glostrup','standard','DENMARK','2600','+4523674770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 17:25:06',0,NULL,3,1,3,1,'RA117737764CN\r ','dennisbagge\rGLSG002'),(4501,586397975013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','dimless','ecograd@list.ru','Dmitry Lessovichenko','Bayganin St. Home 27 ap.3','Almaty','Almaty','KAZAKHSTAN','050008','+7(727)3272711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 17:36:11',0,NULL,3,1,2,1,'\\ ','dimless'),(4502,793207574012,220748684642,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',61.99,'eastar4uk','ultracain3','mcoskun@semahastanesi.com.tr','mehmet coskun','Sema hastanesi sahilyolu dragos maltepe istanbul','default','','TURKEY','34844','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 17:38:05',0,NULL,3,1,3,1,'RA117737945CN\r ','ultracain3\rKBVI001\r白色的'),(4503,790942440012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','ernestine_2004','ebgayban@hotmail.com','Ernestine Gayban','7720 Wolf Creek Rd','Las Vegas','NV','UNITED STATES','89128-6844','(702) 480-9816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 17:41:53',0,NULL,3,1,1,1,NULL,'ernestine_2004\r红边优联'),(4504,586417733013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','rspa7882','ronspacagna@talktalk.net','ron spacagna','2 caversham close<br>sholing','southampton','Hampshire','UNITED KINGDOM','so19 8fg','02380444662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 18:37:42',0,NULL,3,1,3,1,'RA117737821CN\r ','rspa7882\rOTRA001'),(4505,538860250004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',3,'HSPL001',35.4,'cnfaner','thegleasonfamily','clairegleason@hotmail.com','Claire Smith','30 Tolberts Cir','Dover','DE','UNITED STATES','19904-4467','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-27 18:44:45',0,NULL,3,1,1,1,'\\ ','thegleasonfamily'),(4506,533757761003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','twinmarnie','iammac2000@yahoo.com','MARYANNE MACNEIL','#17 1975 Curlew Road','Kamloops','BC','CANADA','V2C 4H9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 18:51:12',0,NULL,3,1,3,1,'RA117737835CN\r ','twinmarnie\rHSMO011+CCMO001'),(4507,793787171012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',166.99,'eastar4','misha_g79','m.gaidamaka@yandex.ru','Misha Gaidamaka','Lenina str. d60 kv.15','Rostov-on-don','','RUSSIAN FEDERATION','344038','+79185208562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 19:29:36',0,NULL,3,0,3,1,'RA117734706CN\r ','misha_g79\rOTSO004*2'),(4508,714800622011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','djamel-93','djamel93@gmail.com','Djamel BENYACOUB','3, rue d\'Arras','Paris','Ile-de-France','FRANCE','75005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 19:53:32',0,NULL,3,1,2,1,'\\ ','djamel-93'),(4509,586444585013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',4,'BALO001',33.96,'eastar4','mav-fan','junk-mail7@cox.net','Chris Cotham','1304 Macarthur Dr','Papillion','NE','UNITED STATES','68046-3822','(402) 293-6055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 20:01:17',0,NULL,3,1,1,1,NULL,'mav-fan'),(4510,714472593011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','coltsray','ray@oehlerking.us','oehlerking','15880 prince frederick rd','hughesville','MD','UNITED STATES','20637-2506','(301) 274-3803','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 20:30:16',0,NULL,3,1,1,1,'\\ ','coltsray'),(4511,537352364004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','roseblue79','c_lyall@hotmail.com','Claire Lyall','5 Akala Place<br>Capalaba','Brisbane','Queensland','AUSTRALIA','4157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 20:47:54',0,NULL,3,1,3,1,'RA117737999CN\r ','roseblue79\rOTGR001+OTGR002'),(4512,714827292011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','crazysmurf73','anna.m.giove@gmail.com','Anna Giove','283-919  Centre St NW','Calgary','AB','CANADA','T2E2P6','(403) 701-9207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 20:56:25',0,NULL,3,1,2,1,'\\ ','crazysmurf73'),(4513,714831907011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','ralpher','ralph.d@devinsys.com','Ralph M Devin','15611 100th Pl NE','Bothell','WA','UNITED STATES','98011','(206) 718-4034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 21:08:20',0,NULL,3,1,1,1,NULL,'ralpher'),(4514,793878554012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','123rmp','rmp@avaya.com','Russell M Pennington','1311 Latham Rd','Greensboro','NC','UNITED STATES','27408-7519','(336) 273-2875','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 22:23:22',0,NULL,3,1,1,1,NULL,'123rmp'),(4515,539522795004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','dementedway','micaelopt@gmail.com','Ricardo Marques','Rua António Sérgio número 740 1º direito Custóias','Matosinhos','Porto','PORTUGAL','4460-679','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 23:30:33',0,NULL,3,1,3,1,'RA117737866CN\r ','dementedway\rOTCR001'),(4516,714873486011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT001',118,'eastar4','50billmurray','wmurrayjr@mac.com','William E Murray Jr','104 Broad St','Mount Holly','NJ','UNITED STATES','08060-1411','(609) 864-4660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 23:30:33',0,NULL,3,1,1,1,'\\ ','50billmurray\r'),(4517,586501602013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','choriz80','cyrille.morisot@orange.fr','Morisot Cyrille','19 rue d\'en haut','Flers sur Noye','Picardie','FRANCE','80160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 00:01:10',0,NULL,3,1,2,1,'\\ ','choriz80'),(4518,539540391004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.95,'cnfaner','qcontinuum99','mqjones@orcon.net.nz','Mark Jones','6 Keepers Drive','Gulf Harbour','Whangaparaoa','NEW ZEALAND','0930','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 01:36:24',0,NULL,3,1,3,1,'RA117737897CN\r ','qcontinuum99\rOTSO001'),(4519,714913749011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','kmoloney','kevin.moloney@jpmorgan.com','Kevin Moloney','115 S Jefferson Rd<br>JP Morgan Chase','Whippany','NJ','UNITED STATES','07981','(973) 793-2173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 03:01:48',0,NULL,3,1,1,1,'\\ ','kmoloney\r这个就是拆了包装发，不发碟'),(4520,793946786012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','revvon','revkrisvon@aol.com','Kris von Maluski','100 Ochre Point Ave','Newport','RI','UNITED STATES','02840-4149','(401) 481-8887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 03:17:59',0,NULL,3,1,1,1,'\\ ','revvon'),(4521,714928100011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','igor_o','igor_o25@mail.ru','Igor Orlov','Prospekt Kalinina 51/6','Kaliningrad','','RUSSIAN FEDERATION','236039','+79527922408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 04:24:59',0,NULL,3,1,2,1,'\\ ','igor_o'),(4522,793970809012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','announsoso','announ.soso@gmail.com','sofiane announ','17 square berthelot','alfortville','Ile-de-France','FRANCE','94140','0635505300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 05:39:56',0,NULL,3,1,2,1,'\\ ','announsoso'),(4523,533893692003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',35.95,'cnfaner','soobin09','soobinc@gmail.com','Soobin Kim','496 S Airport Blvd<br># SEVEN-mutiny09','South San Francisco','CA','UNITED STATES','94080','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-28 08:01:55',0,NULL,3,1,1,1,'\\ ','soobin09'),(4524,794003863012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','drgenius128','readinmachine@yahoo.com','Dominic Rodriguez','703 Navaronne Way','Concord','CA','UNITED STATES','94518-2322','(925) 980-8326','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 08:10:24',0,NULL,3,1,1,1,NULL,'drgenius128\r红边优联'),(4525,714981022011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',157,'eastar4','mrobbo56','mrobbo56@hotmail.com','matthew robinson','5/79 Buderim Avenue','Mooloolaba','Queensland','AUSTRALIA','4557','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-28 08:55:44',0,NULL,3,0,3,1,'RA117734153CN\r ','mrobbo56\rOTSO004*2'),(4526,714985596011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',3,'OTSO004',251.97,'eastar4','arthurdasma','arthur.dasmarinas@yahoo.com','Arthur Dasmarinas','8/13 Chich Place<br>Cannington','Perth','Western Australia','AUSTRALIA','6107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 09:19:02',0,NULL,3,0,3,1,'RA117734082CN\r ','arthurdasma\rOTSO004'),(4527,714985645011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','petr.hubik','hubipe@centrum.cz','Petr Hubik','K Sidlisti 10','Brno','','CZECH REPUBLIC','643 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 09:20:44',0,NULL,3,1,2,1,'\\ ','petr.hubik'),(4528,586594607013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','krakarott','ryan@intermediaweb.lk','Ryan Wijesundera','#52, 4th Floor,<br>Galle Road, Colombo - 03.','Colombo.','Western','SRI LANKA','003300','0094773916916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 10:20:08',0,NULL,3,1,2,1,'\\ ','krakarott'),(4529,794047068012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','0989718861','mmario@live.com','mario muza','staro pracno 53','sisak','croatia','CROATIA','44000','00385989718861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 10:36:40',0,NULL,3,1,2,1,'\\ ','0989718861'),(4530,794060020012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','voidhanger','aselsvold@hotmail.com','Audun Selsvold','Kronstadveien 17','Bergen','','NORWAY','5053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 11:17:59',0,NULL,3,1,2,1,'\\ ','voidhanger'),(4531,715020929011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',2,'CASS001',17.4,'eastar4','solid_company','powerhorse@wp.pl','Roger Łyszkiewicz','Baśniowa 3/12','Pruszków','mazowieckie','POLAND','05800','506 106282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 11:18:34',0,NULL,3,1,3,1,'RA117737883CN\r ','solid_company\rCASS001+CASS002\r\r一共买了两个CAB-SS-2660\r四个CAB-SS-2626'),(4532,586607665013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','solid_company','powerhorse@wp.pl','Roger Łyszkiewicz','Baśniowa 3/12','Pruszków','mazowieckie','POLAND','05800','506 106282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 11:22:59',0,NULL,3,1,17,0,NULL,'solid_company'),(4533,794063888012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',17.4,'eastar4','solid_company','powerhorse@wp.pl','Roger Łyszkiewicz','Baśniowa 3/12','Pruszków','mazowieckie','POLAND','05800','506 106282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 11:28:49',0,NULL,3,1,17,0,' ','solid_company'),(4534,715028635011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','charbel12','sainteana-ebay@yahoo.com','TOUSSAINT MLATAWOU','909 EAGLE CREST DR','Madison','WI','UNITED STATES','53704-8553','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 11:44:51',0,NULL,3,1,1,1,NULL,'charbel12'),(4535,794070882012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','tandrat123','tandrat73@gmail.com','TANDRA THOMPSON','2821 Engleside Dr','JACKSON','MS','UNITED STATES','39212-2815','(601) 201-5014','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 11:50:43',0,NULL,3,1,1,1,NULL,'tandrat123'),(4536,794078854012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','pb3655','paulballard30@yahoo.co.uk','Paul Ballard','1 Winchester Road','Feltham','Middlesex','UNITED KINGDOM','TW13 5JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 12:13:37',0,NULL,3,1,3,1,'RA117737937CN\r ','pb3655\rOTCN004*10'),(4537,794080231012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','evk7evk7','evk7@aol.com','Carl D. Evans','72 Oak Leaf Dr','O Fallon','MO','UNITED STATES','63368-8286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 12:16:57',0,NULL,3,1,1,1,'\\ ','evk7evk7'),(4538,794094026012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','drew6915','rockyb691@yahoo.com','Drew Kelly','349 Bergen Ave','Bellmawr','NJ','UNITED STATES','08031-1635','(609) 230-8466','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 12:55:10',0,NULL,3,1,1,1,NULL,'drew6915'),(4539,715057347011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','basschwarz','s.w.schwarz@gmail.com','Bas Schwarz','Molenstraat-Centrum 345','APELDOORN','','NETHERLANDS','7311XJ','+31555767075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:15:38',0,NULL,3,1,2,1,'\\ ','basschwarz'),(4540,794105609012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','mrscotchkitty','lrobbio@yahoo.com','Lisa Robbio','1142 Amelia Pl','Escondido','CA','UNITED STATES','92026-1500','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 13:28:31',0,NULL,3,1,1,1,NULL,'mrscotchkitty'),(4541,715062004011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','guy.shakh','guy1778@gmail.com','GUY SHKH','BAR YOHAI 42','BEER SHEVA','NEGEV','ISRAEL','84591','(972) 546-3964 ext.: 96','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:35:20',0,NULL,3,1,2,1,'\\ ','guy.shakh'),(4542,715065810011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',18.99,'eastar4','66robert66','gauthier.robert@sbcglobal.net','Robert Gauthier','80 Sheldon Rd<br>C/O Turbocare','Manchester','CT','UNITED STATES','06042','(860) 647-9911 ext.: 316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 13:41:46',0,NULL,3,1,1,1,NULL,'66robert66'),(4543,794114428012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','eu2424','lnh@gmx.de','Hubertus Lengeling','Eupener Straße 24','Köln','','GERMANY','50933','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:51:46',0,NULL,3,1,2,1,'\\ ','eu2424\r欧标'),(4544,794115353012,220747230769,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',11.99,'eastar4uk','jerryjose_90','mangalathjerry@yahoo.com','jerry anto','3<br>Eynsford st','carindale','Queensland','AUSTRALIA','4152','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 13:57:42',0,NULL,3,1,2,1,'\\ ','jerryjose_90\r黑色的\r澳标'),(4545,794124742012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',20,'BALO001+BAIN002',339.8,'eastar4','bellobelli','mttoksoylu@live.com','ERKIN CANOGLU','330 COLLEGE ST','Amherst','MA','UNITED STATES','01002-2331','(401) 688-9025','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 14:18:22',0,NULL,3,1,4,1,'YW865717253CN ','bellobelli'),(4546,794136230012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jamedin2000','jamedin2000@yahoo.com','James Edington','8859 kestrel oak','Converse','TX','UNITED STATES','78109-3522','(210) 274-2391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 14:47:01',0,NULL,3,1,1,1,'\\ ','jamedin2000'),(4547,586614550013,230622403729,'New Philips SHB6102 Bluetooth Stereo Headset  ',1,'HSPH001',74.9,'eastar4','nati_40','nati.00@012.net.il','nati harir','masarik 31/3','Nahariya','','ISRAEL','22301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 14:54:22',0,NULL,3,1,3,1,'RA117737795CN\r ','nati_40\r美标\rHSPH001'),(4548,538367480004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',55.99,'cnfaner','dorabear10','huniebear10@hotmail.com','Dora Aikens','3250 Panorama Rd. #53','Riverside','CA','UNITED STATES','92516-1052','(951) 295-4223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-28 15:18:20',0,NULL,3,1,1,1,NULL,'dorabear10'),(4549,586666798013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','mkaltaf','mkaltaf_cvengr@yahoo.com','mohammed kaleem altaf','saudi archirodon ltd.,sari street, behind jarir bookstore,<br>al rawdah area,p.o.box 2987, jeddah-21461','jeddah','','SAUDI ARABIA','21461','00966548650220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 15:31:50',0,NULL,3,1,3,1,'RA117737662CN\r ','mkaltaf\rHSNO019\r'),(4550,586675164013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','ladymumu89','mu_mu316@hotmail.com','Raylene Lee','57b Slater Court','Kardinya','Western Australia','AUSTRALIA','6163','0430878703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 15:52:38',0,NULL,3,1,2,1,'\\ ','ladymumu89'),(4551,794179826012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','ridgeburyman','stuart@ukhillsweb.com','Stuart Hill','Ridgebury House<br>Curdridge Lane','Southampton','Hampshire','UNITED KINGDOM','SO32 2BJ','01489797302','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 16:29:55',0,NULL,3,1,3,1,'RA117737870CN\r ','ridgeburyman\rBAZA001'),(4552,715134436011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','izassaf','i.assaf@hotmail.com','Izhak Assaf','Dgania<br>4','Ness-Ziona','israel','ISRAEL','74038','972528699809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 16:40:26',0,NULL,3,1,2,1,'\\ ','izassaf'),(4553,715149564011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','ziawhoo','ziawhoo@aol.com','Zia Gheewala','1611 Locksley Ln','Sugar Land','TX','UNITED STATES','77479','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 17:13:31',0,NULL,3,1,1,1,NULL,'ziawhoo'),(4554,712812103011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','mudan','mudanantiques@yahoo.com','Dan Gould','4289 Rocky Glenn','Roswell','GA','UNITED STATES','30075','(770) 993-3023','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 17:16:12',0,NULL,3,1,1,1,'\\ ','mudan'),(4555,586697728013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','dana_18love','daniela.espinosa.m@gmail.com','Daniela Espinosa','General Urrutia 084<br>Angol','Angol','Araucania','CHILE','4650000','56992223218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 17:18:07',0,NULL,3,1,3,1,'RA117737818CN\r ','dana_18love\rOTRA001'),(4556,678640778001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','fbk14','fbk14@earthlink.net','Bruce Korr','4800 Sentinel Dr','Brecksville','OH','UNITED STATES','44141-3149','(216) 387-3887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 17:19:08',0,NULL,3,1,1,1,NULL,'fbk14'),(4557,794217150012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','t.m.a.h','timwilliams02@hotmail.co.uk','TIM WILLIAMS','6 eddystone rd','st austell','Cornwall','UNITED KINGDOM','PL25 4jd','07989530696','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 17:40:25',0,NULL,3,1,3,1,'RA117737954CN\r ','t.m.a.h\rHSPL010'),(4558,586711408013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','teubbi62','teubbi@yahoo.com','Bill Teubel','118 Sheridan Ave','Lisbon','IA','UNITED STATES','52253-9647','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-28 17:48:49',0,NULL,3,1,1,1,NULL,'teubbi62'),(4559,586717402013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','bigos_74','revvao@gmail.com','Oleksandr Revva','3A Smolenskaya st. ap.4','Kiev','UA','UKRAINE','03057','(050) 462-3910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 18:05:08',0,NULL,3,1,2,1,'\\ ','bigos_74'),(4560,794237344012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','rdkurth','rdkurth@directphp.com','Richard Kurth','7504 NE 110th St','Vancouver','WA','UNITED STATES','98662-1370','(360) 600-4918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 18:16:56',0,NULL,3,1,1,1,NULL,'rdkurth'),(4561,715186118011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','kezihallal','ssomer@triad.rr.com','Shubert Somer','CMR 420 Box 971','APO','AE','AA','09063','(336) 784-4416','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'kezihallal'),(4562,714980454011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',167.98,'eastar4','reficul24','kipet.alex@gmail.com','Alexander Kipet','Latyshskih strelkov 11-2-32','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','193231','812-580-33-86','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 18:37:31',0,NULL,3,1,3,1,'RA117734618CN\r ','reficul24\rOTSO004'),(4563,715200695011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','clance911','kalana.wijesekara@gmail.com','Kalana Wijesekara','Eurocenter DDC<br>Level 2, #65, Walukarama Road','Colombo 03','Western Province','SRI LANKA','00300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 19:02:35',0,NULL,3,1,3,1,'RA117737716CN\r ','clance911\rHSLO001'),(4564,715208162011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','m.b.h.','m.b.hanson@sbcglobal.net','Brett Hanson','4463 N Valley Ridge Dr','Belvidere','IL','UNITED STATES','61008','(815) 987-7762','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 19:17:40',0,NULL,3,1,1,1,'\\ ','m.b.h.'),(4565,794334850012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',166.99,'eastar4','josemerc','jam_tyan@yahoo.com.ar','Jose A. Mercado','Irigoyen SUR 317','Tunuyan','Mendoza','ARGENTINA','5560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 21:41:08',0,NULL,3,0,3,1,'RA117737849CN\r ','josemerc\rOTSO004*2'),(4566,715277471011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','kram2724','enwjak@hotmail.com','joel kram','35 W Bujey Dr','Evansville','IN','UNITED STATES','47710-4607','(812) 319-7089','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 22:10:46',0,NULL,3,1,1,1,NULL,'kram2724'),(4567,794349927012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','cohen.naor','naor.ebay.cohen@gmail.com','Naor Cohen','Aharonovich<br>13','Petah Tikva','ISR','ISRAEL','49620','054-7376924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 22:22:49',0,NULL,3,1,2,1,'\\ ','cohen.naor'),(4568,794360246012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','sunshine100876','shiraw8@hotmail.com','Shira Winitzky','6220 Owensmouth Ave<br>Apt 373','WOODLAND HILLS','CA','UNITED STATES','91367-2207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 22:57:01',0,NULL,3,1,1,1,'\\ ','sunshine100876\r新的'),(4569,794363713012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','alajal','espososgonzalez@hotmail.com','Victor Manuel Gonzalez Garcia','Plaza San Francisco de Asis 15 4-C','Alcala de Henares','Madrid','SPAIN','28802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:08:39',0,NULL,3,0,3,1,'RA117737645CN\r ','alajal\r一共买了两个'),(4570,794364018012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','peteswife02','kerrie.lindstrom@comcast.net','Kerrie Lindstrom','2164 Autinori Ct','Livermore','CA','UNITED STATES','94550','(925) 373-0331','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-28 23:10:41',0,NULL,3,1,1,1,NULL,'peteswife02'),(4571,586804114013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','gnomba','sd.filatov@gmail.com','Sergey Filatov','Dobrovolskogo street 42/1, apartment 26','Rostov-on-Don','Rostovskaya Oblast','RUSSIAN FEDERATION','344113','(903)4043699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:11:44',0,NULL,3,1,2,1,'\\ ','gnomba'),(4572,794365528012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','alajal','espososgonzalez@hotmail.com','Victor Manuel Gonzalez Garcia','Plaza San Francisco de Asis 15 4-C','Alcala de Henares','Madrid','SPAIN','28802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:18:43',0,NULL,3,0,17,0,NULL,'alajal'),(4573,794366770012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','rlinqc','rhyce@hotmail.com','Rhyce Langker','11 rue Charlevoix , Apt 209','Montreal','QC','CANADA','H3J2V9','(514) 846-1845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:20:28',0,NULL,3,1,3,1,'RA117737543CN\r ','rlinqc\rOTGR001+OTGR002'),(4574,794369300012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',2,'MOMI001',111.96,'eastar4','bglcom','todd@northrop.biz','Todd Northrop','P.O. Box 302','Martinsville','NJ','UNITED STATES','08836','(908) 722-2721','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 23:29:07',0,NULL,3,1,1,1,'\\ ','bglcom\r美标'),(4575,715299383011,320395390620,'Samsung Q1 Q1U Bluetooth Module 2.0 EDR+cable',1,'BTSA2005',12.5,'eastar4','814jspeeth','jspeeth@gmail.com','Jeff Speeth','118 E Maple St','Port Allegany','PA','UNITED STATES','16743-1349','(814) 642-9124','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 23:32:40',0,NULL,3,1,1,1,NULL,'814jspeeth'),(4576,715299778011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','ramellemar','ramelo1@gmail.com','Ramel Eshed','POB 232','NEHALIM','','ISRAEL','49950','+972544424139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:34:29',0,NULL,3,1,2,1,'\\ ','ramellemar'),(4577,715307221011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','mboatnerjr','morrisboatner@yahoo.com','Morris/Angela Boatner','1710 Camden Landing Trl','fresno','Tx','UNITED STATES','77545-7162','(832) 754-3322','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 00:08:19',0,NULL,3,1,1,1,NULL,'mboatnerjr'),(4578,794381973012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','coolgrm1','coolgrm1@stny.rr.com','Patricia Manns','419 Herrick St','Elmira','NY','UNITED STATES','14904-1614','(607) 733-6413','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 00:21:52',0,NULL,3,1,1,1,NULL,'coolgrm1\r红边优联'),(4579,794388577012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','jouebasnat','jeanlouisjubinville@videotron.ca','Jean-Louis Jubinville','137 Cormier','St-Sulpice','QC','CANADA','J5W 4J9','(450) 589-7927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 00:48:00',0,NULL,3,1,2,1,'\\ ','jouebasnat'),(4580,715329646011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','choco168','chunw@bigpond.net.au','Frank Wong','28 Nickson Street','Bundoora','Victoria','AUSTRALIA','3083','61438266433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 01:55:55',0,NULL,3,1,2,1,'\\ ','choco168'),(4581,715334157011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','thorndan','austin.e.duncan@gmail.com','Austin Duncan','103 Eucalyptus Ln','Costa Mesa','CA','UNITED STATES','92627-5161','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 02:19:53',0,NULL,3,1,1,1,NULL,'thorndan'),(4582,534141684003,130490976205,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',3,'WLAT010',47.97,'cnfaner','owuor','owuor@alum.mit.edu','Victor Owuor','9560 Dogwood Circle','Eden Prairie','MN','UNITED STATES','55347','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 02:34:37',0,NULL,3,1,1,1,NULL,'owuor'),(4583,715337044011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','sonofjesse','douglaskster@gmail.com','Douglas King','170 Teal Cres','Orleans','ON','CANADA','K1E 2C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 02:35:38',0,NULL,3,1,2,1,'\\ ','sonofjesse'),(4584,715338479011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','karentlee702','karentlee@hotmail.com','Karen Cantera','2619 Savannah Springs Ave','Henderson','NV','UNITED STATES','89052-7160','(702) 898-7972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 02:43:54',0,NULL,3,1,1,1,NULL,'karentlee702'),(4585,715339055011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','assafhindi10','assafhindi@walla.co.il','assaf hindi','hofit 3','rosh ha\'ayin','givat haslayim','ISRAEL','48550','972 03 938 09 15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 02:46:08',0,NULL,3,1,2,1,'\\ ','assafhindi10'),(4586,586842869013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','wild_child14','francol@gmail.com','Francis Larkai','350 Rue Prince Arthur - Ouest<br>D428','Montreal','QC','CANADA','H2X3R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 03:09:28',0,NULL,3,1,2,1,'\\ ','wild_child14'),(4587,715373727011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',28.47,'eastar4','robertdeluca','robertdeluca@hotmail.com','Roberto DeLuca','PO Box 778','Redmond','WA','UNITED STATES','98073','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 06:09:47',0,NULL,3,1,1,1,NULL,'robertdeluca'),(4588,715379287011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','wet4018','btillberg@comcast.net','Bill Tillberg','210 Steiger Dr','Westfield','MA','UNITED STATES','01085-4932','(413) 562-5234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 06:38:14',0,NULL,3,1,1,1,NULL,'wet4018'),(4589,794468379012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','alan0184','rduffsilsby@gmail.com','Robert Duff-Silsby','23 Springthorpe Terrace','Clarkson','Western Australia','AUSTRALIA','6030','0405478747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 07:10:49',0,NULL,3,1,2,1,'\\ ','alan0184\r红边优联'),(4590,794490832012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','iue_ishii','shunpei@ishii.name','Shunpei Ishii','2-4-1 Kugenuma-Ishigami','Fujisawa','Kanagawa','JAPAN','251-0025','+81-466-23-2569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 08:26:04',0,NULL,3,1,2,1,'\\ ','iue_ishii'),(4591,534191047003,130504141009,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','nurken2008','nurken@ya.ru','Nurken Kshibayev','Lenina str., 24-5','Karaganda','','KAZAKHSTAN','100000','+7-7212-569180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 08:39:41',0,NULL,5,0,18,1,NULL,'nurken2008\r客户要黑色的\r已退款'),(4592,715428686011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',32.99,'eastar4','nightdesigner1981','nightdesigners@gmail.com','Liubou Kazakova','Денисовская, 41-2-5','Минск','','BELARUS','220006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 10:00:05',0,NULL,3,1,3,1,'RA117737676CN\r ','nightdesigner1981\rWWOP003'),(4593,794551068012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','bigcharlieone10','charlieomalley@hotmail.co.uk','charles o\'malley','118 ashfield drive','donaghadee','Down','UNITED KINGDOM','bt21 0at','07595279154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 10:52:41',0,NULL,3,1,3,1,'RA117737512CN\r ','bigcharlieone10\rHSPL010\r英标'),(4594,794555740012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.9,'eastar4uk','keiththaw61','dcassius@live.co.uk','Keith Thaw','51 Granville Avenue<br>Sneyd Green','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','st1 6bq','07868171196','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 11:04:46',0,NULL,3,1,3,1,'RA117738005CN\r ','keiththaw61\r英标\rHSNO023'),(4595,794566031012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','gemmsc','sukhad_keshkamat@yahoo.com','Sukhad Keshkamat','International Institute for Geo-Information Science and Earth<br>Hengelosestraat 99,','Enschede','','NETHERLANDS','7514 AE','31616761381','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 11:25:27',0,NULL,3,1,3,1,'RA117737910CN\r ','gemmsc\rHSPL014\r欧标'),(4596,794606614012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','dafyddth','thomasda@umich.edu','D. G. Thomas','1150 W Medical Center Dr<br>MSRB2/C570','Ann Arbor','MI','UNITED STATES','48109','(734) 763-2475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 12:52:57',0,NULL,3,1,1,1,NULL,'dafyddth'),(4597,715383953011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','yiw1393','richard@parkwaytaxis.com','Richard Woodward','16 Gables Lea','cullompton','Devon','UNITED KINGDOM','EX152RY','07710620771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 13:19:29',0,NULL,3,1,2,1,'\\ ','yiw1393\r英标'),(4598,715530907011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','broadhaven2010','george.manson1@gmail.com','George Manson','216/1 Craigcrook Road','Edinburgh','Midlothian','UNITED KINGDOM','EH4 7BA','01314678035','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 13:25:44',0,NULL,3,1,3,1,'RA117737852CN\r ','broadhaven2010\rOMHJ001'),(4599,715535308011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','yosis10','dstcomputer@gmail.com','Yosi Shaked','Sara Emeno 90/8','modiin','modiin','ISRAEL','71727','972526027421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 13:36:56',0,NULL,3,1,2,1,'\\ ','yosis10'),(4600,715533119011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','wyt_fox','nittu1874@hotmail.com','mohamed nishan','M. kokaa Handhuvaru / dhakadhaa magu<br>6th Floor','Male','','MALDIVES','20299','9609924565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 13:37:50',0,NULL,3,1,3,1,'RA117737781CN\r ','wyt_fox\rHSPL015'),(4601,794631223012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',43.68,'eastar4','0801chai','chaioj@yahoo.com.sg','Oi Jin Chai','570 Macpherson Rd, #05-01 Macpherson Green','Singapore','Singapore','SINGAPORE','368237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 13:54:29',0,NULL,3,1,3,1,'RA117737680CN\r ','0801chai\rWWOT001'),(4602,794648228012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','dc123617','dcherryc390@rogers.com','darryl cherry','306 oshawa blvd s','oshawa','ON','CANADA','l1h5s2','(905) 259-6982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 14:20:38',0,NULL,3,1,2,1,'\\ ','dc123617'),(4603,586998257013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','tej_bay_uk','tejsandhus@gmail.com','Ranbir Singh Sandhu (Burjanwale)','Vill- Amritsar Kallan<br>PO- Amritsar Khurd','Teh- Ellenabad','HR','INDIA','125102','00911698280272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 14:34:00',0,NULL,3,1,3,1,'RA117737614CN\r ','tej_bay_uk\rOTRA001'),(4604,534301147003,130466041816,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',32.9,'cnfaner','krzy_s','krzyss@gmail.com','Krzysztof Pietrzak','Szeligowskiego 79/6','Szczecin','Zachodniopomorskie','POLAND','71-051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:01:07',0,NULL,3,1,3,1,'RA117737702CN\r ','krzy_s\rWWOP003'),(4605,587010159013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','renebond','renebond0013@yahoo.com','René Verkade','Fenacoliuslaan 118','Maassluis','','NETHERLANDS','3143AE','0653549053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:03:40',0,NULL,3,1,2,1,'\\ ','renebond'),(4606,586994313013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','g0st0rbayter','nnsherstyukov@yandex.ru','Nikolay Sherstyukov','Ubileynaya 24/119','Balashov','Saratovskaya obl','RUSSIAN FEDERATION','412307','917-305-0467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:04:46',0,NULL,3,1,2,1,'\\ ','g0st0rbayter'),(4607,794676229012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',13.99,'eastar4uk','sanj_40','sanjayallagh@hotmail.com','Sanjay Allagh','10 Greengate','Greenford','Middlesex','UNITED KINGDOM','UB6 0QH','07720297888','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 15:06:53',0,NULL,3,1,3,1,'RA117737565CN\r ','sanj_40\rOTGR002'),(4608,587011660013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','michael7034','dwml@comcast.net','Christopher Goree','2226 Riverwood Dr','Auburn','AL','UNITED STATES','36830-6621','(857) 928-4457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 15:11:46',0,NULL,3,1,1,1,NULL,'michael7034'),(4609,587016596013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',69.98,'eastar4','eli_hayut','eli_hayut@hotmail.com','ELI HAYUT - FISHLZON','GIDEON 22','NATANYA','ISRAEL','ISRAEL','42235','0543977818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:19:32',0,NULL,3,1,3,1,'RA117737747CN\r ','eli_hayut\rBAZA001'),(4610,794695251012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','sib1056','blackersanford@yahoo.com','sanford blacker','16 Ferndale Ln','hamburg','NJ','UNITED STATES','07419-9731','(973) 981-1698','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 15:37:26',0,NULL,3,1,1,1,'\\ ','sib1056\r新的'),(4611,715600618011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','tigersbd','masudy2k@hotmail.com','Masud Rahman','909 Laurel Meadow Dr','FORT MILL','SC','UNITED STATES','29708-7891','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 15:39:34',0,NULL,3,1,1,1,'\\ ','tigersbd'),(4612,794724645012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','signal99uk','james.fallon@virgin.net','james fallon','73 offord road','london','London','UNITED KINGDOM','n11ea','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 16:17:37',0,NULL,3,1,3,1,'RA117737631CN\r ','signal99uk\rOTCN003'),(4613,715648128011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','starguy2000','starguy2000@gmail.com','ilya adelman','kalanit<br>building 3B , apartment 36','ashdod','','ISRAEL','77574','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 16:51:16',0,NULL,3,1,2,1,'\\ ','starguy2000'),(4614,715673997011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',110,'eastar4','walkerbecky','beckyb_1961@yahoo.com','Becky Walker','3004 Frontier St','Cheyenne','WY','UNITED STATES','82001-5884','(307) 214-5656','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 17:20:38',0,NULL,3,1,1,1,'\\ ','walkerbecky\r'),(4615,587078286013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','godoi.marcos552','godoi.marcos@gmail.com','MARCOS LIMA GODOI','AV.:ZUZA MOTA N°455 BAIRRO:GUARUS','CAMPOS DOS GOYTACAZES','RIO DE JANEIRO','BRAZIL','28.083-000','+55 22 27387323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 17:24:15',0,NULL,3,1,3,1,'RA117737659CN\r ','godoi.marcos552\rOTRA001'),(4616,794779202012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','silvesterjansen','milan475@gmail.com','Milan Jansen','Verspyckweg 7n','Bergen aan Zee','','NETHERLANDS','1865 BJ','0654358623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 17:24:36',0,NULL,3,0,2,1,'\\ ','silvesterjansen'),(4617,794781375012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','andymic021060','andymic@cytanet.com.cy','Andreas Michael','11 D Kriou Nerou','Ayia Napa','Famagusta','CYPRUS','5330','0035799882168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 17:26:48',0,NULL,3,1,2,1,'\\ ','andymic021060'),(4618,715701718011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','kunjim','jameshighet@bellsouth.net','JAMES HIGHET','3436 Babiche St','JACKSONVILLE','FL','UNITED STATES','32259-2196','(904) 287-9064','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 17:52:23',0,NULL,3,1,1,1,NULL,'kunjim'),(4619,715718226011,320403383811,'Slim DVD/CD to External USB Caddy for IBM T40 T60 SATA2',1,'CACN003',13.5,'eastar4','llin080','lin_li2000@hotmail.com','Li Lin','68 Yoho Drive','Kanata','ON','CANADA','K2M 2R4','(613) 270-8841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 18:11:14',0,NULL,3,1,2,1,'\\ ','llin080'),(4620,794822268012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','jbkbaye','johnbk60@att.net','Sharon Ash','432 Promontory Ter','San Ramon','CA','UNITED STATES','94583-1558','(925) 718-5516','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 18:14:33',0,NULL,3,1,1,1,'\\ ','jbkbaye\r新的'),(4621,587117840013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','devasell','gentleman_heart@hotmail.com','Matias Vieytes','hilarion de la quintana 3088','olivos','Buenos aires','ARGENTINA','1636','4711-1144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 18:20:44',0,NULL,3,1,3,1,'RA117737530CN\r ','devasell\rMOSA005'),(4622,715746990011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','yanshufon','ronen.nachshony@gmail.com','Ronen Nahshony','Nurit 7a','KFAR SABA','','ISRAEL','44413','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 18:37:56',0,NULL,3,1,2,1,'\\ ','yanshufon'),(4623,715756079011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','marks77777','sonnenberg777@msn.com','MARK SONNENBERG','16359 SHADYBEND DR','hacienda heights','CA','UNITED STATES','91745','(626) 336-4385','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 18:49:15',0,NULL,3,1,1,1,NULL,'marks77777'),(4624,585966144013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','manfredima2010','ilunga@mail.ru','Dima Luibimov','Bolshaya Ostroumovskaya, dom 21, kv. 15','Moscow','0','RUSSIAN FEDERATION','107014','+7(916)190-9718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 19:19:32',0,NULL,3,1,3,1,'RA117737605CN\r ','manfredima2010\rOTRA001'),(4625,587162537013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','lena_4e','jelena_cerenkova@mail.ru','Jelena Cerenkova','Nicgales 40-60','Riga','','LATVIA','LV-1035','0037126729372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 19:31:14',0,NULL,3,1,2,1,'\\ ','lena_4e'),(4626,715802774011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','obesitysurgery_phs','dickmanrique@yahoo.com','Dick Manrique Mansilla','Jr. Bernini 352, Oficina 206, San Borja','Lima','','PERU','Lima 41','(511) 998490460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 19:38:45',0,NULL,3,1,3,1,'RA117734025CN\r ','obesitysurgery_phs\rBR3D001'),(4627,715821201011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','jkconners','jconners88@gimail.af.mil','Joseph Conners','PO BOX 29','Ellerslie','MD','UNITED STATES','21529-0029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 20:05:28',0,NULL,3,1,1,1,NULL,'jkconners'),(4628,587187624013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','mesty555','bernard.chizhevsky@gmail.com','Bernard Chizhevsky','Bauskas iela, 17-23','Riga','','LATVIA','Lv-1004','+371 29711866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 20:19:35',0,NULL,3,1,2,1,'\\ ','mesty555'),(4629,715854215011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','evgeniysv','mycontinent@gmail.com','EVGENIY SMIRNOV','22/61, ul. Universitetskaya','Cheboksary','','RUSSIAN FEDERATION','428009','79022883330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 20:58:29',0,NULL,3,1,2,1,'\\ ','evgeniysv'),(4630,587205626013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','nondy2','nondy_2@hotmail.com','jonathan patten','42 greenock drive','kitchener','ON','CANADA','n2e2h2','(519) 500-7273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 21:02:03',0,NULL,3,1,2,1,'\\ ','nondy2'),(4631,715860695011,320557629748,'New Motorola H3 Bluetooth Wireless Headset H 3',1,'HSMO003',14.79,'eastar4','cwo3beckyb','beckyb1952@bellsouth.net','Rebecca Bostick','3607 Westhampton Dr','Martinez','GA','UNITED STATES','30907-3035','(706) 724-9641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 21:10:36',0,NULL,3,1,1,1,'\\ ','cwo3beckyb'),(4632,540188122004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','floodmusic','timheil@yahoo.com','Timothy Heil','61535 S Highway 97<br>Ste 9-208','Bend','OR','UNITED STATES','97702-2154','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 21:12:19',0,NULL,3,1,1,1,NULL,'floodmusic'),(4633,715521565011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','td3454','trdeaton@bellsouth.net','Tom Deaton','5960 River Rush Ct','Sugar Hill','GA','UNITED STATES','30518-7457','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 21:01:19',0,NULL,3,1,1,1,NULL,'td3454'),(4634,715874505011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','youcancallmebatman','alanko+ebay@gmail.com','Alan Ko','8 Wintergreen Cres','Thornhill','ON','CANADA','L4J5M9','(905) 881-1364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 21:39:35',0,NULL,3,1,2,1,'\\ ','youcancallmebatman'),(4635,715872903011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',110,'eastar4','el_celi','el_celi@yahoo.es','Cecilio Torres','c/ hasekura tsunenaga, 25','Coria del rio','Andalucía Ceuta y Melilla','SPAIN','41100','954778274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 21:40:40',0,NULL,3,1,3,1,'RA117734065CN\r ','el_celi\rGLOT001*2'),(4636,586239003013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','nzlaptopsltd','jeff@nzlaptops.co.nz','Greg Young / Gene Palmer','229 Praabaramee Road','patong','Phuket','THAILAND','8315','021486069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 21:52:23',0,NULL,3,1,2,1,'\\ ','nzlaptopsltd'),(4637,540206759004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','susyrick160','a_susy_13@hotmail.com','Susana Aguilar','Senda 2 Poligono 2<br>Jardines de la sabana 2 casa# 2-C','Santa Tecla','La Libertad','EL SALVADOR','503','(762)38036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 22:21:46',0,NULL,3,1,3,1,'RA117737693CN\r ','susyrick160\rHSPL001\r新地址\rMaria Aguilar\rQuintas Recreativas\rLa Hacienda Pol. G Casa# 10-D\rLa Libertad El Salvador 503\rEl Salvador\r\r'),(4638,715899320011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',59,'eastar4','jefferson_judo','jefferson_saul@hotmail.com','Jefferson Guimarães','rua crepusculo dos deuses, 134 - Jardim Guanabara','São Paulo','São Paulo','BRAZIL','04860250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 22:53:00',0,NULL,3,1,3,1,'RA117734048CN\r ','jefferson_judo\rGLOT001'),(4639,587242506013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','claddaghjewl','2claddagh@gmail.com','Catherine De La Torre','11630 Warner Ave<br>Apt 605','Fountain Valley','CA','UNITED STATES','92708-2555','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-29 23:20:58',0,NULL,3,1,1,1,NULL,'claddaghjewl'),(4640,715907292011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','chiquitag','agorzak@sbcglobal.net','Anita R Gorzak','1544 Tulane Dr','Naperville','IL','UNITED STATES','60565-1737','(630) 357-2951','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 23:21:32',0,NULL,3,1,1,1,NULL,'chiquitag'),(4641,795039484012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',166.99,'eastar4','heather3106','yiyi392_volley@yahoo.com','Heather Sepulveda','1897 Francisco Quindos urb. Fairview','San Juan','PR','UNITED STATES','00926','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 00:03:38',0,NULL,3,0,1,1,'\\ ','heather3106'),(4642,587256096013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','patty.oliveira','patty.nicole@hotmail.com','PATTY OLIVEIRA','PAULA MATOS<br>171 APTO 307 - SANTA TERESA','RIO DE JANEIRO','RIO DE JANEIRO','BRAZIL','20251550','2198273138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 00:28:11',0,NULL,3,1,2,1,'\\ ','patty.oliveira'),(4643,795050291012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','karlmdavis','karl@davisonlinehome.name','Karl Davis','5521 E Kelso St','Tucson','AZ','UNITED STATES','85712-2213','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 00:39:49',0,NULL,3,1,1,1,NULL,'karlmdavis\rAcer 5pin1.25 3cm'),(4644,715937615011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',4,'ANYA001',57.8,'eastar4','gadgetguynum1','gadgetguy@horak.us','Harry Horak','PO Box 476<br>Five Star Computer Svcs.','Corpus Christi','TX','UNITED STATES','78403-0476','(361) 888-0666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 01:17:05',0,NULL,3,1,3,1,'RA117737923CN\r ','gadgetguynum1\rANYA001'),(4645,795062353012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','comlore','consulting@comlore.com','Ted Bullock','307-3200 Glenmore Trail SE','Calgary','AB','CANADA','T2C 4B7','(403) 536-8333 ext.: 201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 01:21:34',0,NULL,3,1,2,1,'\\ ','comlore\r新地址\rTed Bullock\r307-3200 Glenmore Trail SE\rCalgary, Alberta, T2C 4V7\rCanada\r\r\r'),(4646,795072935012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','a_castelo','castelo@hughes.net','PILAR SANZ / A CASTELO','C/ Sánchez Barcaiztegui, 40 – 5º A<br>escalera derecha','MADRID','Madrid','SPAIN','28007','697278975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 01:58:26',0,NULL,3,1,3,1,'RA117737588CN\r ','a_castelo\rOTGR001+OTGR002'),(4647,715950806011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','bobfaria','bobfaria@yahoo.com','Robert Faria','40 Brenda Ct','Stockbridge','GA','UNITED STATES','30281-5803','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 02:07:45',0,NULL,3,1,1,1,NULL,'bobfaria'),(4651,714119632011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','bin1279','cholobin@hotmail.com','Benjamin Gomez','5219 s Delaware st<br>Apt I213','Englewood','CO','UNITED STATES','80110-8338','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 04:30:11',0,NULL,3,1,1,1,'\\ ','bin1279'),(4648,795083089012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',25.98,'eastar4','dondell2004','cogshell1001@verizon.net','dondell cogshell','6124 Holy Neck Rd','suffolk','VA','UNITED STATES','23437-9228','(804) 617-1587','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 02:52:03',0,NULL,3,1,1,1,'\\ ','dondell2004'),(4649,587259321013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',2,'BAZA001',139.96,'eastar4','shadow-x9999','jayhoskins2@hotmail.com','Jason Hoskins','189 Simcoe Way','Fort McMurray','AB','CANADA','T9H3B4','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'shadow-x9999'),(4650,715974844011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','2010jbrink','jbfloors@comcast.net','jason brink','5655 Paw Paw Lake Rd<br>Apt C','coloma','MI','UNITED STATES','49038-8509','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 03:53:02',0,NULL,3,1,1,1,'\\ ','2010jbrink'),(4652,715987422011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','ntvandehey','nickvandehey@gmail.com','Nick Vandehey','1257 Hayes St','San Francisco','CA','UNITED STATES','94117-1511','(510) 747-8263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 05:04:54',0,NULL,3,1,1,1,'\\ ','ntvandehey'),(4653,715991224011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',12.5,'eastar4','andi2002','hasanturfeh@hotmail.de','hasan turfeh','transvaalstr 15','berlin','','GERMANY','13351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 05:27:59',0,NULL,3,1,2,1,'\\ ','andi2002\racer 4pin1.25 15cm '),(4654,715991681011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','alexv1265','verdyan@gmail.com','Verdyan Alexander','Usishkin 34/16','Rishon LeZion','','ISRAEL','75286','+972545321213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 05:35:15',0,NULL,3,1,2,1,'\\ ','alexv1265'),(4655,715995984011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','unolan','luan__on@hotmail.com','Luan On','152 Roberts St','Yarraville','Victoria','AUSTRALIA','3013','0451460755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 05:58:05',0,NULL,3,1,2,1,'\\ ','unolan'),(4656,587324792013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 07:21:26',0,NULL,3,1,3,1,'RA117737804CN\r ','small.mac\rWLAP008'),(4657,587329608013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','farasat_88','farasat_cricket@hotmail.com','farasat saboor','1355 Caesar Cir','salt lake city','UT','UNITED STATES','84123-1516','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 07:55:07',0,NULL,3,1,1,1,NULL,'farasat_88'),(4658,716019120011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',129.98,'eastar4','aitorcuenca','aitor@facundocuenca.com','Aitor Cuenca Recio','C/. San Roque, 101.','El Palmar','Murcia','SPAIN','30120','676 40 00 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 08:00:00',0,NULL,3,1,3,1,'RA117737733CN\r ','aitorcuenca\rGLSG001'),(4659,716018721011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','volk0509','volk1984@yahoo.com','Dmitry Volk','Bnei Or 21/4','Beer Sheva','Hadarom','ISRAEL','84454','+972542181401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 08:10:36',0,NULL,3,1,2,1,'\\ ','volk0509'),(4660,715970981011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20,'eastar4','tovanesyan','ovanesyant@aol.com','Тигран Ованесян','Б.Черемушкинская, 12<br>кв. 60','Москва','Россия','RUSSIAN FEDERATION','117447','(903) 1718494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 09:00:54',0,NULL,3,0,2,1,'\\ ','tovanesyan'),(4661,794911660012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','enerrrjy','enerjy@list.ru','Roman Pustovalov','ul. Noviy Arbat 15 - 523','Moscow','','RUSSIAN FEDERATION','119019','8(963)651-5777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 09:37:07',0,NULL,3,1,2,1,'\\ ','enerrrjy'),(4662,587347896013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.95,'eastar4','vitalysennikov','vitaly.sennikov@gmail.com','Vitaly Sennikov','Lopatina, 5-162','Nizhniy Novgorod','Nizhegorodskay oblast','RUSSIAN FEDERATION','603163','+7-915-956-63-19','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 09:46:39',0,NULL,3,1,3,1,'RA117734096CN\r ','vitalysennikov\rOTRA001'),(4663,794979625012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',23.59,'eastar4uk','sager2011','heshengsg2000@yahoo.com.sg','He Sheng Neo','8 Manor Road','Potters Bar','Hertfordshire','UNITED KINGDOM','EN6 1DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 10:05:39',0,NULL,3,1,3,1,'RA117734808CN\r ','sager2011'),(4664,795193443012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',39,'eastar4uk','sanproscho','sandra.schommer@live.de','Sandra Schommer','Rechter Strasse 85<br>Born','Amel','','BELGIUM','4770','0471769354','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-30 10:42:45',0,NULL,3,1,3,1,'RA117734785CN\r ','sanproscho\r欧标\rHSPL009'),(4665,716061488011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',251.98,'eastar4','alternativevideoz','l.strait@gmail.com','Luis Fernandez Lopez','Paseo de la Chopera<br>186, 4ºC','Alcobendas','Madrid','SPAIN','28100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 10:51:23',0,NULL,3,1,6,1,'EE506555497CN','alternativevideoz\r发盒装P2100X 带封口签带碟'),(4666,716076017011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',59,'eastar4','jiraskova','milijerry@yahoo.com','Jaroslav Kohout','1645 Louise Blvd.','London','ON','CANADA','N6G2R2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 11:43:26',0,NULL,3,1,3,1,'RA117734737CN\r ','jiraskova\rGLOT001'),(4667,587377692013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','eelika573','eelika.hammer@mail.ee','Eelika Hammer','Jüri 19a, Polikliinik, 4 korrus, Alignsoft','Võru','Võrumaa','ESTONIA','65608','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:16:11',0,NULL,3,1,2,1,'\\ ','eelika573'),(4668,587384425013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',2,'BTHP2102',24.8,'eastar4','paulopercigo2009','paulopercigo@gmail.com','PAULO PERCIGO','R. Dr Rubens Machado Camara n.26 SB2','CURITIBA','Parana/Curitiba/Brazil','BRAZIL','82520-300','0514196359667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:46:47',0,NULL,3,1,2,1,'\\ ','paulopercigo2009\rBTHP2102\rHP 8pin 1.0 3cm 线序反 '),(4669,716100502011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','jlh035','jhenry02@charter.net','Jeffrey Henry','114 Duke Rd','Maryville','TN','UNITED STATES','37803-3418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 13:07:02',0,NULL,3,1,1,1,'\\ ','jlh035\r新的'),(4670,716102466011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','alyariced','alain.nathalie@videotron.ca','alain jones','2289 rue de Strasbourg','laval','QC','CANADA','H7K 3H4','(450) 663-2332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:12:39',0,NULL,3,1,3,1,'RA117734683CN\r ','alyariced\rGLSG001*2\r发盒装P2100X 带封口签带碟'),(4671,716116081011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','daxter10','daxx@ymail.com','Dax Lee','25 Humbershed Cres.','Bolton','ON','CANADA','L7E 2X3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:54:47',0,NULL,3,1,2,1,'\\ ','daxter10'),(4672,795255822012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','byrondes','byron_v_yu@yahoo.com','Byron Yu','B5 L14 St John Street Marvi Hills Subd','San Mateo','Rizal','PHILIPPINES','1850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:58:52',0,NULL,3,1,2,1,'、 ','byrondes\r新地址\rARVIN YU WS Atkins and Partners Overseas \rAl Rostamani Building Khalid Ibn Al Waleed Road Bur Dubai P.O.Box 5620 Dubai, UAE'),(4673,715676548011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','studboy_5','steve_steichen@yahoo.com','Steve Steichen','2813 Lankford Dr','Lawrence','KS','UNITED STATES','66046','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 14:06:41',0,NULL,3,1,1,1,'\\ ','studboy_5'),(4674,795255711012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','18buzaglo','buzaglo18@gmail.com','Asher Buzaglo','Bait alfa 32','Haifa','','ISRAEL','26221','0574667458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 14:14:26',0,NULL,3,1,2,1,'\\ ','18buzaglo\r新的'),(4675,716126854011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','rriv7080','rafa789456@yahoo.com','Rafael Rivera','1653 Calle Julio C Arteaga','ponce','PR','UNITED STATES','00717-0576','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 14:46:04',0,NULL,3,1,1,1,'\\ ','rriv7080'),(4676,716133469011,320441564467,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',12.4,'eastar4','szzsolti72','szedlak@msn.com','zsolt szedlak','25 Liverpool Road','Cadishead','Lancashire','UNITED KINGDOM','m445bq','07726140315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 14:51:20',0,NULL,3,1,2,1,'\\ ','szzsolti72\racer 4pin1.25 4cm'),(4677,716142047011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',2,'HSJA005',35.98,'eastar4','roadsters_3','robinson.araya.huerta@gmail.com','Robinson  Araya Huerta','Senador Raul Marin Balmaceda #167, Poblacion Cobresal','Ovalle','Ovalle','CHILE','1841733','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 15:14:26',0,NULL,3,1,3,1,'RA117736018CN ','roadsters_3\rHSJA005'),(4678,587422019013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',52.2,'eastar4','oldenp','olden.pieterse@gmail.com','Olden Pieterse','PO Box 71655<br>Centrahill','Port Elizabeth','Eastern Cape','SOUTH AFRICA','6006','+27836115842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 15:18:22',0,NULL,3,1,3,1,'RA117734799CN\r ','oldenp\rCASS003\r再发四个CAB_2660\r'),(4679,716151811011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','tech-home','brian.a.dye@gmail.com','Brian Dye','820 N Brown Ave','Springfield','MO','UNITED STATES','65802-4454','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 15:35:26',0,NULL,3,1,1,1,'\\ ','tech-home'),(4680,716155660011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','dayronrene','dayronrene@yahoo.es','Dayron Trillo','11591 NW 2nd St<br>Apt 208','Miami','FL','UNITED STATES','33172-4952','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 15:54:50',0,NULL,3,1,1,1,'\\ ','dayronrene\r发盒装P2100X 带封口签带碟\r\r新地址\rDayron Trillo\r2751 SW 107 Ave, \rMiami FL 33165\rUNITED STATES\r\r'),(4681,716160566011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','cmyer311','cmyer@shadesofjune.com','Chris Myer','3254 Latonia Ave','Pittsburgh','PA','UNITED STATES','15216-2328','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 15:57:54',0,NULL,3,1,1,1,'\\ ','cmyer311'),(4682,716164112011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','greenraven111','j.w.edwards@sbcglobal.net','Jesse Edwards','17917 Conner Rd','Nelsonville','OH','UNITED STATES','45764-9576','(740) 753-2742','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 16:07:25',0,NULL,3,1,1,1,'\\ ','greenraven111'),(4683,716164066011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','ez075454','dtgee18@yahoo.com','DICKSON GEE','773 Begonia Dr','San Leandro','CA','UNITED STATES','94578-3804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 16:07:45',0,NULL,3,1,1,1,'\\ ','ez075454'),(4684,795312591012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','sign-hang*r','bobbynelsen@yahoo.com','Robert Nelsen','15155 Richmond Ave<br>Apt 1229','Houston','TX','UNITED STATES','77082-1640','(832) 665-9059','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 16:16:21',0,NULL,3,1,1,1,'\\ ','sign-hang*r'),(4685,791481305012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','lorryman1844','andycurtis01@btinternet.com','Mr Andy Curtis','Bott Ltd<br>Bude Stratton Business Park','Bude','Cornwall','UNITED KINGDOM','EX23 8LY','07774003704','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 16:28:04',0,NULL,3,1,3,1,'RA117734811CN\r ','lorryman1844\r英标\rHSPL010'),(4686,540401296004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','junichi.sawada','jsawada11@gmail.com','Junichi Sawada','1-58-10<br>Wakabadai','Inagishi','Tokyo','JAPAN','206-0824','+81-90-6922-5184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 16:41:42',0,NULL,3,1,3,1,'RA117734825CN\r ','junichi.sawada\rHSPL010'),(4687,716179317011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','c0brak1llar','cobra0605@hotmail.com','patrick mckirdy','16 Ewhurst Close<br>Jamaica Street','London','London','UNITED KINGDOM','E1 3JR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 16:44:35',0,NULL,3,1,2,1,'\\ ','c0brak1llar'),(4688,540403037004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','qwerttie','vainio.joonas@gmail.com','Joonas Vainio','Jämeräntaival 5A 193','Espoo','Uusimaa','FINLAND','02150','+358407486008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 16:51:07',0,NULL,3,1,3,1,'RA117734856CN\r ','qwerttie\rBALO007'),(4689,795336873012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',71.7,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 17:11:43',0,NULL,3,1,3,1,'RA117734697CN\r ','solopo2009\rHSPL010\r只发耳机'),(4690,716193050011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',16.98,'eastar4','jbrownbmw','jbrownbmw@comcast.net','JAMES BROWN','15 Wyncliff Ln','NEWARK','DE','UNITED STATES','19711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 17:14:46',0,NULL,3,1,1,1,'\\ ','jbrownbmw'),(4691,795337818012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','robertgb7','robert@ackland.tv','Robert Ackland','Trevaster Farm<br>Porth Kea','Truro','Cornwall','UNITED KINGDOM','TR3 6AL','01872273293','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 17:15:04',0,NULL,3,1,17,0,NULL,'robertgb7'),(4692,795342532012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',5,'HSSE004',69.5,'eastar4uk','robertgb7','robert@ackland.tv','Robert Ackland','Trevaster Farm<br>Porth Kea','Truro','Cornwall','UNITED KINGDOM','TR3 6AL','01872273293','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 17:18:53',0,NULL,3,1,3,1,'RA117734581CN\r ','robertgb7\rHSSE004\r英标\r一共买了六个'),(4693,795345956012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',80.98,'eastar4','mcaroonie','fredolaf@hotmail.com','Fred Olaf Sørensen','Nydalsveien 28','OSLO','','NORWAY','0484','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 17:24:57',0,NULL,3,1,6,1,' EE506555523CN','mcaroonie\rOTSO004\r一共买了四个\r申报35美金'),(4694,716206682011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',167.98,'eastar4','jamanta07','ancn@terra.com.br','Eduardo Niemczewski','Street 15 de Novembro, 817 - APTO 302/A','Pelotas','Rio grande do sul','BRAZIL','96015-000','+55 (53) 3227-6880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 17:48:08',0,NULL,3,1,3,1,'RA117734754CN\r ','jamanta07\rOTSO004'),(4695,795361688012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','sarawut_k','bombbay20@yahoo.com','Mr.Sarawut Kaewkanok','63 M.18 Ubon-Trakarn Rd.<br>T.Rainoi A.Muang','Ubonratchatani','Ubonratchatani','THAILAND','34000','045254563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 17:56:47',0,NULL,3,1,2,1,'\\ ','sarawut_k'),(4696,716209588011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',45.99,'eastar4uk','elfisho','adrianjardine@blueyonder.co.uk','adrian jardine','12 butts close','thornton cleveleys','Lancashire','UNITED KINGDOM','fy5 4ht','01253857110','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 18:34:18',0,NULL,3,1,3,1,'RA117734839CN\r ','elfisho\rOTSO001'),(4697,716233294011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','muthrodrigo','muth_2@hotmail.com','rodrigo narciso','Rua 14 lote 40 quadra 05 loteamento são bento da lagoa Itaipuaçu-maricá rj','maricá','rio de janeiro','BRAZIL','24900000','552178793712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 18:37:06',0,NULL,3,1,3,1,'RA117734723CN\r ','muthrodrigo\rGLSG001\r申报45美金'),(4698,587489312013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','v.keyster','vkeyster@mac.com','Vladimir Keyster','Obuhovskoy oborony 209-5','Saint Petersburg','','RUSSIAN FEDERATION','192174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 18:42:07',0,NULL,3,1,2,1,'\\ ','v.keyster'),(4699,586279882013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pavlovmaksim','pmaks75@gmail.com','maksim pavlov','hanarkis','tiberias','','ISRAEL','14200','972-507701615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 19:03:01',0,NULL,3,1,2,1,'\\ ','pavlovmaksim'),(4700,716271718011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','midnitecop389','vegeta446@comcast.net','Howard Lockwood','67 noel st','springfield','MA','UNITED STATES','01108-1237','(413) 733-7053','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 19:46:31',0,NULL,3,1,1,1,'\\ ','midnitecop389'),(4701,716280432011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.49,'eastar4','dymondznperlz','necia18@hotmail.com','Lynecia Cooper','3218 Wilderness Rd','Durham','NC','UNITED STATES','27712-3006','(919) 382-8415','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 20:04:14',0,NULL,3,1,1,1,'\\ ','dymondznperlz'),(4702,795470783012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','jesusgf13','tiranox@hotmail.com','jesus granada fernandez','c/norte   nº3','las palmas de gran canaria','Las Palmas','SPAIN','35015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 21:12:14',0,NULL,3,1,2,1,'\\ ','jesusgf13\racer 8pin1.00 15cm '),(4703,716321051011,320394892496,'Acer Aspire 5735 5735Z Bluetooth Module 2.0 EDR +cable',1,'BTAC2005',12.5,'eastar4','free2airsat','sharkz@tampabay.rr.com','Joseph Sharkey','1387 Ventnor Ave','Tarpon Springs','FL','UNITED STATES','34689-2730','(727) 466-5066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 21:35:24',0,NULL,3,1,1,1,'\\ ','free2airsat\racer 4pin1.25 8cm \r\r'),(4704,795484891012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','annrageddy','raggedyann65@gmail.com','Lori A Sunkler','649 S 12th St','Cottage Grove','OR','UNITED STATES','97424-2566','(541) 942-5050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 21:46:17',0,NULL,3,1,1,1,'\\ ','annrageddy'),(4705,716331800011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',16.98,'eastar4','cardiacpack1983','alexmitchell@frontier.com','John A. Mitchell','1717 Colvard Farms Rd','Durham','NC','UNITED STATES','27713-7073','(919) 806-1710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 22:03:34',0,NULL,3,1,1,1,'\\ ','cardiacpack1983'),(4706,716340384011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 22:34:13',0,NULL,3,1,3,1,'RA117734666CN\r ','tudijaidem\rANYA001'),(4707,587568076013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','fatboyslim33','keith33@mindspring.com','Keith I Smith','659 Auburn Ave NE<br>Apt 204','Atlanta','GA','UNITED STATES','30312-1975','(803) 474-4116','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 22:46:04',0,NULL,3,1,1,1,'\\ ','fatboyslim33'),(4708,716344107011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','zahtrade','zahtrade@gmail.com','ZAH Trading','4, Sh. Ben Zion','Rishon Lezion','AZ','ISRAEL','75216','972-3-9679677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 22:47:15',0,NULL,3,1,2,1,'、 ','zahtrade'),(4709,716344505011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','godizilla','marcos.morgan@bcb.gov.br','Marcos Morgan Loureiro','Rua Barão do Flamengo 26 apto 1101','Rio de Janerio',' Rio de Janeiro','BRAZIL','22220-080','55-21-96140030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 22:48:52',0,NULL,3,1,3,1,'RA117734710CN\r ','godizilla\rBR3D001'),(4710,716348034011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 23:09:11',0,NULL,3,1,3,1,'RA117734670CN\r ','latiendadelsotano\rGLSG001*2\r发盒装P2100X 带封口签带碟'),(4711,716349652011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',148.99,'eastar4','ericl50','slickrick298@hotmail.com','Eric Leonhardt','749 Mound Rd','Festus','MO','UNITED STATES','63028-3708','(314) 753-3631','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 23:14:02',0,NULL,3,1,1,1,' \\','ericl50'),(4712,716351740011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',59,'eastar4','fort696','farberwayne@aol.com','Wayne Farber','8160 Tollbridge Dr','West Chester','OH','UNITED STATES','45069-1690','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 23:16:28',0,NULL,3,1,1,1,'\\ ','fort696'),(4713,716355528011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','97goldtbird','mar_sergio@hotmail.com','sergio mar','5053 Rowe Dr','fairfield','CA','UNITED STATES','94533-6591','(707) 439-0705','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 23:33:15',0,NULL,3,1,1,1,'\\ ','97goldtbird'),(4714,793422065012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','zooyorkjohn','jbehnke@icmtalent.com','John Behnke','10250 Constellation Blvd<br>ICM 7th Floor','Los Angeles','CA','UNITED STATES','90067-6200','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 23:36:30',0,NULL,3,1,1,1,'\\ ','zooyorkjohn'),(4715,716357859011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','phatxa','brettmartin10@hotmail.com','Brett Martin','17 Hermitage Ave<br>Mount Clear','Ballarat','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 23:46:15',0,NULL,3,1,2,1,'\\ ','phatxa'),(4716,716360694011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',17.4,'eastar4','sdhanwada','dhanwada.s@gmail.com','Sandilya Dhanwada','1640 Worcester Rd Apt 129D','Framingham','MA','UNITED STATES','01702','(213) 304-7010','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'sdhanwada'),(4717,795518115012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','acrv555','l.trutschel@yahoo.ca','Lucinda Trutschel','200 MILL STREET<br>APT. 4','SHELBUNE','ON','CANADA','L0N1S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 00:02:27',0,NULL,3,1,3,1,'RA117734768CN\r ','acrv555\rHSPL014'),(4718,716363047011,320441564486,'2.1 Acer Aspire 5550 5551 5552 Bluetooth Module +cable',1,'BTAC2106',12.4,'eastar4','matoussteve','stevematous@sbcglobal.net','Steve Matous','8447 Winterberry Dr','Elk Grove','CA','UNITED STATES','95624-4202','(916) 588-5113','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 00:07:56',0,NULL,3,1,1,1,'\\ ','matoussteve\racer 4pin1.25 15cm '),(4719,795529936012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','ileanagonzalez','araujo.david@gmail.com','David Araujo','181 Bay Street<br>Suite 400','Toronto','ON','CANADA','M5J 2V8','(416) 520-4051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 00:15:09',0,NULL,3,0,2,1,'\\ ','ileanagonzalez'),(4720,716365545011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','kenjackson9580','kenjack42@sky.com','Ken Jackson','19 Ferrars Ave<br>Eynesbury','St Neots','Cambridgeshire','UNITED KINGDOM','PE19 2TY','01480476752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 00:17:40',0,NULL,3,1,3,1,'RA117734842CN\r ','kenjackson9580\rWLAP002\r旧的'),(4721,716372622011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','fstompkins','fstompkins@yahoo.com','Frank Tompkins','141 Holly Dr','Victoria','TX','UNITED STATES','77905-2541','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 00:50:39',0,NULL,3,1,1,1,'\\ ','fstompkins'),(4722,716374699011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','aday8121','ajdia2246@hotmail.com','amanda day','278 back pond road','stewartstown','NH','UNITED STATES','03576','(603) 246-7051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 00:58:04',0,NULL,3,1,1,1,'\\ ','aday8121'),(4723,716373825011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','radmarkers','tomcash30@yahoo.com','Thomas Jones','310 Patchett Way','Montgomery','NY','UNITED STATES','12549-1208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 01:00:10',0,NULL,3,1,1,1,'\\ ','radmarkers'),(4724,795546553012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','renatopp','renatoppinheiro@gmail.com','Renato Pires Pinheiro','3645 Vergueiro St. ap 506','São Paulo','São Paulo','BRAZIL','04101901','+55 (11) 8267-0470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:20:13',0,NULL,3,1,2,1,'\\ ','renatopp'),(4725,795546227012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.97,'eastar4','anderson_630','anderson_182@ig.com.br','Anderson Menezes','rua 10 casa 03 Conj.31 de Março Japiim I','Manaus','Amazonas','BRAZIL','69077110','(92) 32372982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:22:27',0,NULL,3,1,3,1,'RA117734745CN\r ','anderson_630\rOTSO001+OTSO004\r再发一个NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable'),(4726,795551983012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','rogerpryan','rogerpryan@msn.com','Roger Ryan','16302 59th Avenue Ct E','Puyallup','WA','UNITED STATES','98375-9057','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 01:40:47',0,NULL,3,1,1,1,'\\ ','rogerpryan'),(4727,716385158011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','anderson_630','anderson_182@ig.com.br','Anderson Menezes','rua 10 casa 03 Conj.31 de Março Japiim I','Manaus','Amazonas','BRAZIL','69077110','(92) 32372982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:44:19',0,NULL,3,1,17,0,NULL,'anderson_630'),(4728,716398609011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',18.98,'eastar4','ntai','ntai@smartfruit.com','Naoyuki Tai','37 Wellington St','Arlington','MA','UNITED STATES','02476','(781) 864-8334','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-31 02:40:26',0,NULL,3,1,1,1,'\\ ','ntai'),(4729,716406392011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','twistedhook','hrlyd40@aol.com','Stephen Hill','PO Box 921','Rising Star','TX','UNITED STATES','76471-0921','(254) 643-7617','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 03:20:18',0,NULL,3,1,1,1,'\\ ','twistedhook'),(4730,716408946011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','sgeshikter','slavikge@gmail.com','Viacheslav Geshikter','Ha rav silbert<br>12','Beer-sheva','south','ISRAEL','84625','972 522760738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 03:32:24',0,NULL,3,1,3,1,'RA117734771CN\r ','sgeshikter\rHSNO019'),(4731,716412268011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',45.99,'eastar4uk','pengvin09','joelhardeman@hotmail.com','Joel Hardeman','153 Scarborough Beach Rd, Scarborough','Perth, WA','Western Australia','AUSTRALIA','6019','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 03:50:30',0,NULL,3,1,3,1,'RA117734635CN\r ','pengvin09\rOTSO001'),(4732,793036907012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','mentirita006','roqui_006@hotmail.com','roque dorneles','miller<br>2159','capital federal','capital federal','ARGENTINA','1431','541145445809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 03:50:48',0,NULL,3,1,2,1,'\\ ','mentirita006'),(4733,716423080011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','theadrien','adrien_wolff@yahoo.fr','Wolff Adrien','SOCALMO - B.P. 7290<br>20, rue Forest - Ducos','Nouméa','','NEW CALEDONIA','98800','+687 78 04 44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 04:53:52',0,NULL,3,0,2,1,'\\ ','theadrien'),(4734,795610201012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','j_e_vargas','j_e_vargas@yahoo.com','Jose E. Vargas','7395 Juncus Ct','San Diego','CA','UNITED STATES','92129-4561','(858) 484-2655','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 06:20:01',0,NULL,3,1,1,1,'\\ ','j_e_vargas'),(4735,711871631011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','kruklai','martjuga1@yahoo.com','Anton Martjuga','Akotu14','Riga','latvia','LATVIA','LV1082','+371 26 137 567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 06:53:54',0,NULL,3,1,2,1,'\\ ','kruklai'),(4736,587659120013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',43.5,'eastar4','nurse281','simoncolensonurse@hotmail.com','simon nurse','16 kingdown road<br>Blandford camp','Blandford forum','Dorset','UNITED KINGDOM','dt118bl','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 08:23:13',0,NULL,3,1,3,1,'RA117734122CN ','nurse281\rCASS003\rCAB-6060'),(4737,794413095012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','vicon509','ksabester@gmail.com','Kevin Saber','33955 Jackson II Rd','Carthage','NY','UNITED STATES','13619','(315) 493-9429','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 09:04:43',0,NULL,3,1,1,1,'\\ ','vicon509'),(4738,679867847001,110665428634,'NEW SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER WIFI',1,'OTSO001',73.95,'buysia','agresca7','agresca@terra.es','LORENA ADRADA TOLEDANO','C/ MOLINILLOS, 11','PIEDRALAVES','Castilla y León','SPAIN','05440','605158864','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 09:37:01',0,NULL,3,1,3,1,'RA117724814CN\r ','agresca7\rOTSO001'),(4739,795656335012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.98,'eastar4','demaupassant','jbiggs@userealsugar.com','Josh Biggs','2901 McIntosh Dr','Longmont','CO','UNITED STATES','80503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 09:59:08',0,NULL,3,1,1,1,'\\ ','demaupassant\r美标'),(4740,716498375011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',83.99,'eastar4','alicoksaglam','al.saglam@gmail.com','Ali Saglam','Erdemir Bilgi Islem Binasi Kat:2<br>Yazilim Gelistirme Md.','Zonguldak / Eregli','tr','TURKEY','67300','+905442001155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:00:03',0,NULL,3,1,3,1,'RA117724920CN\r ','alicoksaglam\rOTSO004'),(4741,795676451012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',18.98,'eastar4','eugeny_s','e.shastin@gmail.com','Eugeny Shastin','43-22, Metallistov st.','Izhevsk','','RUSSIAN FEDERATION','426054','+7-904-312-37-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:05:11',0,NULL,3,1,2,1,'\\  ','eugeny_s'),(4742,795678992012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','kastec1','alexander.s.kozlov@gmail.com','Alexander Kozlov','Rusanova pr, 13K1, apt. 20','Moscow','','RUSSIAN FEDERATION','129323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:09:09',0,NULL,3,1,2,1,'\\  ','kastec1'),(4743,587693955013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','kirsam1975','sami.kirves@gmail.com','Sami Kirves','Härkäniityntie 5','Kuusankoski','','FINLAND','45700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:42:28',0,NULL,3,1,2,1,'\\ ','kirsam1975'),(4744,540625196004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.95,'cnfaner','kolmanjeka','kolman@012.net.il','Evgeny Kolman','Hatzionut 44/47','Ashdod','','ISRAEL','77456','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:50:09',0,NULL,3,1,3,1,'RA117724893CN\r ','kolmanjeka\rOTSO001'),(4745,716530112011,320701428027,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',74.99,'eastar4','redbackau','mjlaza@optusnet.com.au','Mario Lazarides','32 Reserve Road Casula','Sydney','New South Wales','AUSTRALIA','2170','0297300012','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-31 12:48:24',0,NULL,3,1,3,1,'RA117724880CN\r ','redbackau\rOTSO001'),(4746,540632582004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','the_wolverine7','haider.srh@hotmail.com','Hayder AlQarawee','12 clifton terrace','whitley bay','Tyne and Wear','UNITED KINGDOM','ne26 2jd','07587194830','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 12:27:55',0,NULL,3,1,3,1,'RA117724902CN\r ','the_wolverine7\rHSNO005\r英标'),(4747,716548700011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','davemarcotte','davemarcotte@hotmail.com','David R Marcotte','PSC 557 Box 1095','FPO','AP','AA','96379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 13:51:00',0,NULL,3,0,1,1,'\\ ','davemarcotte'),(4748,716552030011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',20.98,'eastar4','sgracing10','suegerardo@verizon.net','Susan  Gerardo','30 Templar Way','Parsippany','NJ','UNITED STATES','07054-4063','(973) 879-5299','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 14:01:23',0,NULL,3,1,1,1,'\\ ','sgracing10'),(4749,795735387012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.97,'eastar4','20061961','lambm@aforbes.co.za','Michael Robert Lamb','16 Melt Brink Street<br>Roosevelt Park','Johannesburg','Gauteng','SOUTH AFRICA','2195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 14:08:07',0,NULL,3,1,3,1,'RA117724831CN\r ','20061961\rOTSO001'),(4750,795737858012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.4,'eastar4','stens1983','alinacdoo.com@hotmail.com','Adnan Mulalic','Nurije Pozderca bb','Cazin','USK','BOSNIA AND HERZEGOVINA','77220','00387-61-284-720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 14:14:53',0,NULL,3,1,2,1,'\\  ','stens1983\racer 8pin1.00 18cm '),(4751,716557948011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','lauriew_1959','lauriew_1959@yahoo.com','Laurie Weatherford','750 Glenview Dr<br>Apt 301','San Bruno','CA','UNITED STATES','94066-3703','(650) 515-6863','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 14:19:41',0,NULL,3,1,1,1,'\\ ','lauriew_1959'),(4752,587737496013,230623270363,'NIB 3D Active Shutter TV Glasses with IR emitter',1,'GLOT001+GLOT002',85,'eastar4','electrobay.milenium','ray750430@gmail.com','Raymundo Alfonso Milian Montes','Ave Joven Futura # 29 Escalera 2 piso 1ro A','Murcia  Espinardo','Murcia','SPAIN','30100','626528492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:02:37',0,NULL,3,1,3,1,'RA117736335CN\r ','electrobay.milenium\rGLOT001+GLOT002'),(4753,795758000012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','cliyde2382','oldgaryh@aol.com','Gary Howe','255 Pomona ave','Long Beach','CA','UNITED STATES','90803-3532','(562) 439-7287','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 15:10:40',0,NULL,3,1,1,1,'\\  ','cliyde2382'),(4754,716577616011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','yogevif','i_yogev@walla.co.il','Yogev Ifergan','Mishol Snunit 71','Beer-Sheva','','ISRAEL','84736','0507600505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:18:29',0,NULL,3,1,3,1,'RA117724828CN\r ','yogevif\rUDAP001'),(4755,795256379012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','primaris_2hd','df.fillion@gmail.com','Diane Fillion','1230, 17e rue','Roxton Pond','QC','CANADA','J0E 1Z0','(450) 991-2653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:21:38',0,NULL,3,1,2,1,'\\  ','primaris_2hd'),(4756,795765263012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','jackson_sales','dale2408@yahoo.co.uk','Dale Jackson','Beech House','Ireby','Wigton','UNITED KINGDOM','CA7 1EQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 15:29:33',0,NULL,3,1,3,1,'RA117724765CN\r ','jackson_sales\rHSPL014\r英标'),(4757,716583255011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',2,'HSLO001',71.8,'eastar4','ranker1948','rbmercier@videotron.ca','Raoul Mercier','6201 ave. Chemillé #5','Anjou','QC','CANADA','H1M1T3','(514) 351-5398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:35:13',0,NULL,3,1,3,1,'RA117724876CN\r ','ranker1948\rHSLO001'),(4758,795768009012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','antmotion','antmotion@antmotion.com','Antares Garcia - AntMotion','c/ Dr pi i Molist 64 Tienda Informatica','Barcelona','Cataluña','SPAIN','08016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:36:01',0,NULL,3,1,2,1,'\\  ','antmotion'),(4759,795769794012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:41:29',0,NULL,3,1,2,1,'\\ ','grandizom'),(4760,534984452003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',27.16,'cnfaner','wahs_nevets','stevenshaw@msn.com','Steve Shaw','1045 N 730 E','Pleasant Grove','UT','UNITED STATES','84062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 15:44:39',0,NULL,3,1,1,1,'\\ ','wahs_nevets'),(4761,716588442011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',251.98,'eastar4','germainlariviere','vipsanius@videotron.ca','yanick larivee','481 iberville','st-hilaire','QC','CANADA','j3h2v8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:49:09',0,NULL,3,1,6,1,'EE520583410CN ','germainlariviere\r发盒装P2100X 带封口签带碟'),(4762,795775648012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','hermlee','hermlee64@yahoo.com','Herman L, Barlow','5556 Venus Ln','Fairfield','OH','UNITED STATES','45014-5021','(513) 616-9567','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 15:55:16',0,NULL,3,1,1,1,'\\  ','hermlee'),(4763,716601802011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','wbryanl','wbryanl@hotmail.com','Bryan Lucas','928 22nd Ave','Longview','WA','UNITED STATES','98632-2246','(360) 577-0814','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 16:23:46',0,NULL,3,1,1,1,'\\  ','wbryanl\r发盒装P2100X 带封口签带碟'),(4764,716504008011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',110,'eastar4','vidumshik','vidumshik@rambler.ru','Anton Sorokin','Kantemirovskaya st., 18-2-378','Moscow','','RUSSIAN FEDERATION','115409','+7(495)765-05-44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 16:31:58',0,NULL,3,1,3,1,'RA117734272CN\r ','vidumshik\rGLOT001*2\r'),(4765,716605426011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','sunflower170979','sunflower170979@aol.com','Claudia Behr','Im Buttermoor 2','Ahlerstedt','','GERMANY','21702','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 16:33:06',0,NULL,3,1,2,1,'\\  ','sunflower170979'),(4766,795795123012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',15.95,'eastar4','al_ne','nevalennyi@yandex.ru','Alexander Nevalennyi','st.Nofar,13','Yoak-Naam','','ISRAEL','20692','+972545573316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 16:39:51',0,NULL,3,1,2,1,'\\ ','al_ne'),(4767,795798463012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','heatherandqc','heather.heiser@yahoo.com','Heather Heiser','1025 S Semoran Blvd<br>Ste 1083','Winter Park','FL','UNITED STATES','32792','(407) 919-8390','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 16:48:03',0,NULL,3,1,1,1,'\\ ','heatherandqc'),(4768,795802371012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','irishshodan','irishshodan@hotmail.com','Rich T. O\'Neill','1326 Sunset Rd','Butte','MT','UNITED STATES','59701','(406) 491-1279','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 16:56:42',0,NULL,3,1,1,1,'\\  ','irishshodan'),(4769,587771671013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','hpooni','hpooni@rogers.com','Harry Pooni','1558 Wintergrove Gardens','Mississauga','ON','CANADA','L5M 3Z8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 16:59:40',0,NULL,3,1,2,1,'\\  ','hpooni'),(4770,716622651011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','billw2708','bward1@adelphia.net','Bill Ward','2708 Craig Cir','Fullerton','CA','UNITED STATES','92835-2902','(714) 256-2464','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 17:15:19',0,NULL,3,1,1,1,'\\  ','billw2708\r发盒装P2100X 带封口签带碟'),(4771,540705828004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','bob_wood','rwood54741@yahoo.com','Bob Wood','3610 N 12th Ave','Pensacola','FL','UNITED STATES','32503-3102','(850) 255-1505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 17:37:36',0,NULL,3,1,1,1,'\\  ','bob_wood'),(4772,795825190012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',5,'WLAT007',74.75,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 17:45:06',0,NULL,3,1,3,1,'RA117724859CN\r ','saiajin77\rWLAT007'),(4773,716494700011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','fandazzlejaz','jazzy1991@live.co.uk','philip sole','10 Whitfield Road','haslemere','Surrey','UNITED KINGDOM','gu271dy','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 17:53:09',0,NULL,3,1,2,1,'\\  ','fandazzlejaz'),(4774,795837993012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',2,'HSPL014',73.98,'eastar4','stkandrdr','steven.keith@comcast.net','Steven Keith','2690 Nevada Ct','Placerville','CA','UNITED STATES','95667-3837','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 18:05:43',0,NULL,3,1,1,1,'\\ ','stkandrdr'),(4775,716653936011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','mark_duddridge','markduddridge@gmail.com','Mark Duddridge','503 Sabourin Street','St-Pierre-Jolys','MB','CANADA','R0A 1V0','(204) 887-6468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 18:20:44',0,NULL,3,1,3,1,'RA117724947CN\r ','mark_duddridge\rBR3D001'),(4776,795857578012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','jackie1849','gjmiller2002@yahoo.com','jackie','33 quebec','lovell','WY','UNITED STATES','82431','(307) 548-6827','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 18:41:08',0,NULL,3,0,1,1,'\\  ','jackie1849'),(4777,716676876011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','pouch32004','couch1356@yahoo.com','Scott Rosenberg','22 Albany Rd','Marlton','NJ','UNITED STATES','08053-3516','(856) 874-0370','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 19:05:23',0,NULL,3,1,4,1,'YW865717043CN ','pouch32004'),(4778,716678666011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','benoitwoo','benoit@intnet.mu','Benoit Woo Show Wing','Appt. 66, Domaine de L\'Intendance<br>Avenue Pere Laval','Rose Hill','','MAURITIUS','NA','(230)2511660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 19:10:02',0,NULL,3,1,2,1,'\\  ','benoitwoo'),(4779,587818982013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','netmeanderer','molloys.business@gmail.com','John Molloy','PO Box 207','Loveland','OH','UNITED STATES','45140-0207','(425) 941-1576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 19:25:54',0,NULL,3,1,1,1,'\\ ','netmeanderer'),(4780,795889894012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','dpowell179','dougonline@powellplanet.com','Douglas Powell','5417 Lancelot Dr','Charlotte','NC','UNITED STATES','28270','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 19:37:38',0,NULL,3,1,1,1,'\\ ','dpowell179'),(4781,716713908011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','boarding29','gailyouens@hotmail.com','richard rees','29 gobowen road','oswestry','Shropshire','UNITED KINGDOM','sy111ht','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 20:15:27',0,NULL,3,1,3,1,'RA117724845CN\r ','boarding29\rWLAP002\r旧的'),(4782,795925776012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','killa-cam31044','cameronmims@hotmail.com','Ernestine Mims','1093 District rd','jeffersonville','GA','UNITED STATES','31044-7134','(478) 945-6237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 20:47:29',0,NULL,3,0,1,1,'\\ ','killa-cam31044'),(4783,795934037012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','fiero','thane@midco.net','Thane Williams','2500 w bailey st','sioux falls','SD','UNITED STATES','57104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 21:02:25',0,NULL,3,1,1,1,'\\ ','fiero'),(4784,795933243012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','urbi220365','janurbanek@gmx.de','Jan Urbanek','10 Guthrie Rd','Bedford','IN','UNITED STATES','47421-6906','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 21:07:38',0,NULL,3,1,1,1,'\\  ','urbi220365'),(4785,716732913011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','vann113','vannharbin@comcast.net','Vann Harbin','6179 Windflower Dr','powder springs','GA','UNITED STATES','30127-8332','(678) 602-2267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 21:08:25',0,NULL,3,1,1,1,'\\  ','vann113'),(4786,795934952012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','keeman23','kbthacarter@gmail.com','Shirley Wilson','PO Box 1236','Roseland','LA','UNITED STATES','70456-1236','(985) 517-2244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 21:14:37',0,NULL,3,1,1,1,'\\ ','keeman23'),(4787,795955902012,220681620511,'New SAMSUNG WMN1000B ULTRA SLIM WALLMOUNT LED TV 40-50\'',1,'MOSA002',47.89,'eastar4uk','fone-phone','kevinlukkk@oceanfree.net','k-phone','unit 1, 10e,<br>albert walk','Bray,','CoWicklow','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 21:53:01',0,NULL,3,1,3,1,'RA117724955CN\r ','fone-phone\rMOSA002'),(4788,716766929011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',157,'eastar4','marshall8976','damarshall@bigpond.com.au','Amy Marshall','5 Mine Road','Blinman','South Australia','AUSTRALIA','5730','0886484370','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-31 22:26:55',0,NULL,3,0,3,1,'RA117724933CN\r ','marshall8976\rOTSO004*2'),(4789,716767618011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','2008-p-morin','philippemorin11@hotmail.com','Philippe Morin','1233 perigny<br>CP 5007','Chambly','QC','CANADA','j3l 0a0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 22:29:19',0,NULL,3,1,2,1,'\\  ','2008-p-morin'),(4790,791143277012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','pmbintx','pmbintexas@aol.com','Patti Bennington','27878 Riley Rd','Waller','TX','UNITED STATES','77484-6124','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 22:38:16',0,NULL,3,1,1,1,'\\  ','pmbintx'),(4791,716783583011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','bob_yall','bobk@cips.ca','Robert Kacso','28 West Terrace Drive','Cochrane','AB','CANADA','T4C1R5','(403) 932-6077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 23:32:08',0,NULL,3,0,2,1,'\\  ','bob_yall'),(4792,716790355011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','rammanmac','rammanmac@msn.com','Richard Mc Cann','2863 Big Bear Hwy','Benton','KY','UNITED STATES','42025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 23:57:33',0,NULL,3,1,1,1,'\\  ','rammanmac\r发盒装P2100X 带封口签带碟'),(4793,716640444011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','haert','bhaertling@yahoo.com','Barbara Haertling','697 Hollyridge Ln','Fort Worth','TX','UNITED STATES','76108-9004','(817) 448-8959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 00:29:49',0,NULL,3,1,1,1,'\\ ','haert'),(4794,796013943012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',25.98,'eastar4','jullio2010','juliozamorano@vtr.net','julio zamorano lobos','avenida general velasquez 10701','santiago','San Bernardo','CHILE','8060047','(56) 2 5408982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 01:15:50',0,NULL,3,1,2,1,'\\ ','jullio2010'),(4795,796016652012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','jutynes','julietynes@me.com','Julie Tynes','9386 Windmill Pointe Drive','Frisco','TX','UNITED STATES','75034','(469) 964-2414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 01:25:06',0,NULL,3,1,1,1,'\\ ','jutynes'),(4796,583843605013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',11.99,'eastar4','gitw4mst','gitw4m@ms.metrocast.net','shaquita tables','1098 bratton rd','new albany','MS','UNITED STATES','38652-9417','(662) 507-5063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 01:35:55',0,NULL,3,1,1,1,'\\ ','gitw4mst'),(4797,716820660011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','dennisrrm','drivas1067@aol.com','Dennis Rivas','1378 Sierra Cir','kissimmee','FL','UNITED STATES','34744-3659','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 02:03:04',0,NULL,3,1,1,1,'\\ ','dennisrrm'),(4798,716822901011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','kfhassan','kfhassan@yahoo.com','Khurram Farhan Hassan','House No. 62, Street No. 4,<br>CMA Officers Colony','Lahore Cantt.','Punjab','PAKISTAN','54810','(042) 366-6243 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 02:11:49',0,NULL,3,1,2,1,NULL,'kfhassan\r'),(4799,716168076011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','silviapostigo','silvia_postigo@hotmail.com','silvia aparecida postigo','491,rua gregorio souza<br>vila dalila','Sao Paulo','São Paulo','BRAZIL','03531-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 02:21:50',0,NULL,3,1,2,1,'\\ ','silviapostigo'),(4800,796041510012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','tfauch68','todd.faucher68@gmail.com','Todd Faucher','4123 Hill St','San Diego','CA','UNITED STATES','92107-4103','(619) 224-9274','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-01 02:55:19',0,NULL,3,1,1,1,'\\ ','tfauch68'),(4801,716835608011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','ctaylor831','ctaylor831@tds.net','Christopher Taylor','1212 Elisha Ct','La Vergne','TN','UNITED STATES','37086','(615) 213-0208','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 03:05:49',0,NULL,3,1,1,1,'\\ ','ctaylor831\r旧的'),(4802,587942129013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rolfb5234','rolfb@netscape.ca','Rolf Buschow','Box 150','Silton','SK','CANADA','S0G 4L0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 03:39:36',0,NULL,3,1,2,1,'\\  ','rolfb5234'),(4803,716842788011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','garneau0','andre.garneau@videotron.ca','André Garneau','1640 8e avenue','Québec','QC','CANADA','G1J 3N5','(418) 525-8127 ext.: 5924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 03:42:08',0,NULL,3,1,2,1,'\\  ','garneau0'),(4804,587944165013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','nkpark-gr8','signal24@dreamwiz.com','Nam-kyu Park','9th F, CRMS dept.<br>SCFirstbank Building, #100,KongPyung-dong, Chongro-gu','Seoul','','KOREA,REPUBLIC OF','110-702','82-19-286-0085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 03:53:05',0,NULL,3,1,2,1,'\\ ','nkpark-gr8'),(4805,716850220011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','chora.jhn','chorajhn@gmail.com','Eugene Chernyshov','Aviatorov, 1A, 79','Yekaterinburg','Sverdlovsk region','RUSSIAN FEDERATION','620025','+79630337200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 04:23:23',0,NULL,3,1,2,1,'\\ ','chora.jhn'),(4806,716850969011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',12.5,'eastar4uk','ianw1468','ian.johnwilliams@tiscali.co.uk','IAN WILLIAMS','24 burge meadow<br>cotford st luke','TAUNTON','Somerset','UNITED KINGDOM','ta41qn','01823433937','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 04:24:42',0,NULL,3,1,3,1,'RA117724862CN\r ','ianw1468\rRELO003\r红边优联'),(4807,716856548011,320441575635,'2.1 Acer TM 4210 4270 4670 Bluetooth Module EDR+cable',1,'BTAC2124',12.4,'eastar4','427blk','sejero@adam.com.au','Sejere Bob','PO Box 20','Salisbury South.','South Australia','AUSTRALIA','5106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 04:56:21',0,NULL,3,1,2,1,'\\ ','427blk\racer 8pin1.00 15cm'),(4808,540857234004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','tjwall01','tjwall01@embarqmail.com','THOMAS J WALL','PO Box 3','MAXTON','NC','UNITED STATES','28364-0003','(910) 844-1445','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-01 05:21:56',0,NULL,3,1,1,1,'\\  ','tjwall01'),(4809,796071796012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','novacoder','novacoder@iprimus.com.au','Mr Chris Raynor','13 Chloe Close','Kilsyth South','Victoria','AUSTRALIA','3137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 05:23:14',0,NULL,3,1,2,1,'\\ ','novacoder'),(4810,796105560012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','teisit71','teisit@abv.bg','Todor Stoev','Ivan Vazov 9','Zlataritsa','Veliko Tarnovo','BULGARIA','5090','0889672150','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 08:11:46',0,NULL,3,1,3,1,'RA117734555CN\r ','teisit71\rHSNO006'),(4811,716895041011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.75,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 08:24:26',0,NULL,3,1,3,1,'RA117734547CN\r ','flashy69\rMOSA001'),(4812,716897408011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','freefisheater27','oz.arcilla@gmail.com','Michael Arcilla','25 Bb. Librada Avelino Street<br>Circulo Doce Subdivision, BF Homes','Paranaque City','Metro Manila','PHILIPPINES','1720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 08:29:57',0,NULL,3,1,2,1,'\\ ','freefisheater27'),(4813,796111795012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',25.98,'eastar4','dkiss-2009','dkiss@yandex.ru','Denis Kiselev','Krasnobogatyrskaya st. 79-120','Moscow','RU','RUSSIAN FEDERATION','107076','79104096927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 08:36:32',0,NULL,3,1,2,1,'\\ ','dkiss-2009'),(4814,795031271012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','davidt1299','david.turnbull12@hotmail.com','David Turnbull','1 Wilson Crescent Gilesgate Moor<br>Co Durham','Durham','Durham','UNITED KINGDOM','DH11PF','01913863444','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 09:06:56',0,NULL,3,1,3,1,'RA117736052CN\r ','davidt1299\rHSPL005\r英标'),(4815,587997284013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.75,'eastar4','neo-123','schmudee@hotmail.de','Servion Service & Support GmbH','Schelmenwasenstr. 32<br>z. Hd. Marcus Schmidt','Stuttgart','','GERMANY','70567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 10:04:12',0,NULL,3,1,3,1,'RA117733847CN\r ','neo-123\rMOSA001'),(4816,716935146011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 11:06:41',0,NULL,3,1,11,1,NULL,'dorit710\rANYA001'),(4817,716945058011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','tracker_s','burnitburn@gmail.com','Victor Manuel Estevez Mc.Donald','C/ Ansar 4<br>Bajo A','Madrid','Madrid','SPAIN','28047','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 11:45:44',0,NULL,3,1,2,1,'\\ ','tracker_s\r旧的'),(4818,588013855013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','tuchka_tuchka','maxim.kleshchev@dnainternet.net','Maxim Kleshchev','Ritosentie 1','Kuopio','','FINLAND','70340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 11:48:28',0,NULL,3,1,2,1,'\\ ','tuchka_tuchka'),(4819,588023881013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','nationalavs2011','accounting@priotechs.com','Brian Hatcher','1040 Forestwood Dr','Ferguson','MO','UNITED STATES','63135-3013','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 12:23:44',0,NULL,3,1,1,1,'\\ ','nationalavs2011'),(4820,796174829012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','antires','scuba99@mail.ru','Andrey Pak','Abramcevskaya st.<br>h.9, build. 2, fl.529','Moscow','Moscow','RUSSIAN FEDERATION','127572','+79261952483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 12:24:43',0,NULL,3,1,2,1,'\\ ','antires'),(4821,796175256012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','mikem4038','mwmarchio@earthlink.net','mike marchio','907 ROWELL AVE','joliet','IL','UNITED STATES','60433-2526','(815) 482-0945','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 12:26:31',0,NULL,3,1,1,1,'、 ','mikem4038\r红边优联'),(4822,716966902011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','smcgregor76','shadowscollide@iprimus.com.au','Scott McGregor','10 Kuiters Close','COORANBONG','New South Wales','AUSTRALIA','2265','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:00:12',0,NULL,3,1,3,1,'RA117734414CN ','smcgregor76\r发盒装P2100X 带封口签带碟\rGLSG001*2'),(4823,716973763011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:25:26',0,NULL,3,1,6,1,'EE520583423CN ','latiendadelsotano\r发盒装P2100X 带封口签带碟\r一共买了四副，等于两个盒装。'),(4824,716977389011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',2,'MOCN001',9.32,'eastar4','shouck_entyre','shouck@live.com','Steve Houck','624 N Milford Rd Ste 2','Milford','MI','UNITED STATES','48381','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 13:35:23',0,NULL,3,1,1,1,'\\ ','shouck_entyre'),(4825,583508756013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','ecla4576','sporadicmotion@gmail.com','Edward Clark','1652 E 3rd Ave<br>Apt 203','Vancouver','BC','CANADA','V5R1G9','(778) 828-2947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:40:07',0,NULL,3,1,2,1,'\\ ','ecla4576'),(4826,790264778012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',39.99,'eastar4','mhillaby','mhillaby@gmail.com','Michael Hillaby','500-5 Alfred St','Pembroke','ON','CANADA','K8A 3B5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:45:01',0,NULL,3,1,3,1,'RA117734476CN ','mhillaby\rOTHP001'),(4827,716982081011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','woneal10412nkb','woneal1041@aol.com','William L. O\'Neal','16585 SE 252nd Ave','Umatilla','FL','UNITED STATES','32784-7100','(352) 669-9559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 13:51:21',0,NULL,3,1,1,1,'、 ','woneal10412nkb'),(4828,793258975012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','saaron11','saaron1022@gmail.com','Steve Aaron','562 Kings Hwy','Mickleton','NJ','UNITED STATES','08056-1405','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 14:03:18',0,NULL,3,1,1,1,'、 ','saaron11'),(4829,716987711011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','itriy59','itriy@perm.ru','Dmitriy Ponomarev','34 Stroiteley Street, Appartment 198','Perm','Dzerzinskiy','RUSSIAN FEDERATION','614097','79024713227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 14:07:38',0,NULL,3,1,2,1,'\\ ','itriy59'),(4830,716993866011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',17.88,'eastar4','yurofree','yurofree@yahoo.com.hk','yu tat wai','Room 505, Fai Wah House, Lok Wah Estate, Ngau Tau Kok','Kowloon','Hong Kong','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 14:27:24',0,NULL,3,1,2,1,'\\ ','yurofree'),(4831,796216436012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','desh','desh15@hotmail.com','Dmitry Sharkov','3933 1st Ave NE<br>Apt 211','Seattle','WA','UNITED STATES','98105-6833','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 14:30:01',0,NULL,3,1,1,1,'、 ','desh'),(4832,796218016012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',2,'HSPL010',47.8,'eastar4','brent4man67','brent4man@sbcglobal.net','Brent Foreman','17466 E 106th Pl N','Owasso','OK','UNITED STATES','74055-6160','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 14:35:20',0,NULL,3,1,1,1,'\\ ','brent4man67'),(4833,796218885012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','quanfey2025','ananyamanush@gmail.com','Tarik Mohammed','Quantum Foundation, 119P Shantinagar, (Ground Floor)<br>Paltan','Dhaka','Dhaka','BANGLADESH','1217','+8801711400092','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 14:39:32',0,NULL,3,1,2,1,'、 ','quanfey2025'),(4834,795337476012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',3,'HSPL011',69,'eastar4','solopo2009','info@soloportatiles.com.ar','Carlos Scarpin','Lambare 1023 Piso 8 Dto D<br>Almagro','Argentina','Capital federal','ARGENTINA','1185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 14:41:11',0,NULL,3,1,3,1,'RA117724964CN ','solopo2009\rHSPL011\r只发耳机'),(4835,534868709003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','gromilin','rt_embedded@mail.ru','Oleg Gromilin','Sirenevaya 26','Berdsk','','RUSSIAN FEDERATION','633010','+7 (913) 912 5546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 15:01:55',0,NULL,3,1,3,1,'RA117724981CN\r ','gromilin\rWWSI005+ANCN001'),(4836,796229573012,220761694645,'New Logitech IO Digital Notebook for IO/ IO2 pen',1,'NTLO001',17.25,'eastar4','lindherst','paperdo116@yahoo.com','linda araya','19-15 Kipp St','Fair Lawn','NJ','UNITED STATES','07410-2159','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 15:08:05',0,NULL,3,1,1,1,'、 ','lindherst'),(4837,535271173003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',66.94,'cnfaner','cristiangpetrache','cristian.g.petrache@gmail.com','Cristian-George Petrache','Str. Rotunda, Nr. 8, Bl. Y2C, Sc.A<br>et.7, Ap.32, sector 3','Bucharest','','ROMANIA','032703','0040721709094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 15:14:56',0,NULL,3,1,3,1,'RA117724995CN ','cristiangpetrache\rWWOT003\r再发一个DELL1510'),(4838,539964060004,140482633357,'New genuine NOKIA HS-12W BLUETOOTH HEADSET track#',1,'HSNO025',58.9,'cnfaner','elvladox','vladox@gmail.com','Luis Vladimir Londoño Lozano','Calle 51 No 29-50 Apto 103<br>Barrio Buenos Aires','Medellin','Antioquia','COLOMBIA','110011','+573004817000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 15:19:44',0,NULL,3,1,3,1,'RA117724916CN\r ','elvladox\rHSNO025'),(4839,587029541013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','tareg2008','bamer2@ukr.net','Taras Dranik','645 W 1st Ave','Roselle','NJ','UNITED STATES','07203-1027','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 16:13:34',0,NULL,3,1,1,1,'\\ ','tareg2008'),(4840,716906621011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',18.98,'eastar4','williboy1978','williboy78@gmail.com','william kopelovich','bruria 15','tel aviv','israel','ISRAEL','67454','972-5781939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:31:20',0,NULL,3,1,2,1,'\\ ','williboy1978\r一共买了两个'),(4841,717047156011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','sharijohnston','sharijohnston921@msn.com','Shari Johnston','181 Hillendale Ave.<br>Apt 303','Kingston','ON','CANADA','K7M 1S6','(613) 544-8703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:56:56',0,NULL,3,1,2,1,'\\ ','sharijohnston'),(4842,540982353004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','hodeilives','davidriobar@hotmail.com','DAVID RIO BARRIGON','C/ ANGELA FIGUEROA AYMERICH 1 2º E','VITORIA-GASTEIZ','País Vasco','SPAIN','01010','652747390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:58:07',0,NULL,3,1,3,1,'RA117725001CN ','hodeilives\rWLAP002\r旧的'),(4843,717058088011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','sam9293','sbench5464@aol.com','Sam Benchimol','2018 N Flamingo Rd','Pembroke Pines','FL','UNITED STATES','33028-3500','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 17:23:36',0,NULL,3,1,1,1,'\\ ','sam9293\r发盒装P2100X 带封口签带碟'),(4844,717067195011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','expatjen','patrickdaly64@yahoo.com','patrick daly','688 S Van Ness Ave','san francisco','CA','UNITED STATES','94110-1306','(408) 410-7653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 17:44:32',0,NULL,3,1,1,1,'\\ ','expatjen'),(4845,588105171013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','prb4t','pbhathena@yahoo.com','Percy Bhathena','1505 Crest Rd','Cleveland Heights','OH','UNITED STATES','44121-1721','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 17:44:42',0,NULL,3,1,1,1,'\\ ','prb4t'),(4846,588106247013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',16.99,'eastar4','fireandy.de.vu','andreas_stecher@web.de','Andreas Stecher','Arndtstr. 56/2/3','Wien','','AUSTRIA','1120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 17:48:15',0,NULL,3,1,2,1,'\\ ','fireandy.de.vu'),(4847,796305963012,220704209256,'NEW PLANTRONICS EXPLORER 340 headset E340 w/charger',1,'HSPL007',20.9,'eastar4','shaabin','faixal_s@hotmail.com','mohamed faisal','handhuvareege/sh.funadhoo','sh.funadhoo','shfunadhoo','MALDIVES','03150','+9609781940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:13:10',0,NULL,3,1,2,1,'\\ ','shaabin'),(4848,796322896012,220792285628,'NIB Samsung SSG-2200AR Rechargeable Adult 3D Glasses',1,'GLSG005',96,'eastar4','ruccino','blackdragon0977@hotmail.com','Alexander Torres Rucci','URB JARDINES DE CAROLINA  E-48<br>CALLE E','CAROLINA','PR','UNITED STATES','00987','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 18:46:39',0,NULL,3,1,1,1,'、 ','ruccino\r三星原装眼镜\r盒装的'),(4849,717097219011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','caruanalinn','caruana@live.com','Linn Caruana','No8, Caruana flats,<br>Edgar Bernardh street,','Gzira','','MALTA','GZR06','27318194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:47:32',0,NULL,3,1,2,1,'\\ ','caruanalinn\r欧标'),(4850,717098324011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','mikecaswell08','mikecaswell@hotmail.com','Michael Caswell','1030 NE Indiana St.','Pullman','WA','UNITED STATES','99163','(360) 421-5293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 18:52:53',0,NULL,3,1,1,1,'、 ','mikecaswell08'),(4851,717099712011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.99,'eastar4','ring-ding-dong','markus@schmola.de','Dr. Markus Schmola','Talbreitenweg 4','Regensburg','','GERMANY','93055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:53:46',0,NULL,3,1,4,1,'YW865717172CN ','ring-ding-dong'),(4852,588137232013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',5,'CACN004',65,'eastar4','gregkras','greg@zg.com','Greg Kras','11001 W 120th Ave<br>Ste 315','Broomfield','CO','UNITED STATES','80021-3493','(303) 619-4043','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 19:25:48',0,NULL,3,1,1,1,'、 ','gregkras'),(4853,796347065012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','wnettrends','forextech@safe-mail.net','Ryan MILLS','2A Arlington Gardens','Ilford','Essex','UNITED KINGDOM','IG1 3HH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 19:27:36',0,NULL,3,1,2,1,'\\ ','wnettrends'),(4854,717118254011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 19:31:11',0,NULL,3,1,17,0,' ','latiendadelsotano\r发盒装P2100X 带封口签带碟'),(4855,796364057012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.4,'eastar4','kopsiasnik','kopsiasnik@hotmail.com','Nikon Kopsias','Nea agora 161','Rhodes','dodekanese','GREECE','85100','+306932277414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 20:00:44',0,NULL,3,1,2,1,'\\ ','kopsiasnik\rHP 6pin 1.0 12cm'),(4856,796378266012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','starcat1313','ruslanp@ruslanp.com','Ruslan Petrenko','20 S Clark St<br>STE 2150','Chicago','IL','UNITED STATES','60603-1849','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 20:28:49',0,NULL,3,1,1,1,'、 ','starcat1313\r红边优联'),(4857,796407908012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','ordutrans','ordutrans@hotmail.com','Eugenio Garcia Calderon','Paseo La Antigua 34 interior 1º izquierda','Orduña','País Vasco','SPAIN','48460','657796022','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 21:35:34',0,NULL,3,1,2,1,'\\ ','ordutrans'),(4858,717158931011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','thrilla25','thanakaran_k@hotmail.com','Thanakaran Kunaratnam','12 Constantia street','Markham','ON','CANADA','L3S4J2','(416) 831-9273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 21:45:02',0,NULL,3,1,2,1,'、 ','thrilla25'),(4859,796420383012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','quentinob','quentinob2458@yahoo.com','andrew brown','118 Sky Manor Rd','maple hill','NC','UNITED STATES','28454-8602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 22:06:06',0,NULL,3,1,1,1,'、 ','quentinob'),(4860,588189923013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','robertreport','robertdooleyjr@yahoo.com','Bob Dooley','3256 E Downing Cir','Mesa','AZ','UNITED STATES','85213-7012','(480) 201-3743','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-01 22:11:27',0,NULL,3,1,1,1,'\\ ','robertreport'),(4861,541077832004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','fabio10118','fabio.fredi@hotmail.com','Fabio Fredi','Rua Tucuna, 10 - Apt 61<br>Bairro: Perdizes','São Paulo','São Paulo','BRAZIL','05021-010','11-82742980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 22:19:44',0,NULL,3,1,3,1,'RA117736021CN\r ','fabio10118\rOTCR001'),(4862,796437707012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','mikecuz42','mikecuz@hotmail.co.uk','mike cousins','1 norwood close<br>saffrondale, anlaby,','HULL','East Riding of Yorkshire','UNITED KINGDOM','hu10 6qg','01482651976','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 23:02:58',0,NULL,3,1,3,1,'RA117736035CN ','mikecuz42\rOTCN003'),(4863,541086260004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','arthur999s','chantecler2@gmail.com','Arthur Voskov','49 Sherman Ln','Hamden','CT','UNITED STATES','06514','(203) 708-8686','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-01 23:04:19',0,NULL,3,1,1,1,'\\ ','arthur999s'),(4864,717208593011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','goldflshturtle','rangerjaxdr@gmail.com','Lina Khalil','20019 Mammoth Falls Dr','Tomball','TX','UNITED STATES','77375-2695','(281) 764-3544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 23:43:01',0,NULL,3,1,1,1,'、 ','goldflshturtle'),(4865,680551552001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','alberto1999','albertom44@live.com','jose minjarez','10710 madison way','northglenn','CO','UNITED STATES','80233-4480','(720) 929-1210','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 00:05:25',0,NULL,3,1,1,1,'、 ','alberto1999\r黑色的'),(4866,588212287013,230623983391,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'',74.99,'eastar4','c_lama_e-bay','c_lama@vtr.net','Cristian Lama','Freire 889','Concepción','Concepción','CHILE','00000','56 41 2911690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 00:07:17',0,NULL,3,0,3,1,'RA117736049CN ','c_lama_e-bay'),(4867,588214878013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','myfamilyonline','normablount@yahoo.com','Norma Blount','43252 Bradley Ln','Hammond','LA','UNITED STATES','70403-0810','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 00:21:59',0,NULL,3,1,1,1,'\\ ','myfamilyonline'),(4868,796469196012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','uwjohnsr','rjohnson@navg.com','Russell Johnson','2646 Neptune Ave','Seaford','NY','UNITED STATES','11783','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 01:05:48',0,NULL,3,1,1,1,'\\ ','uwjohnsr'),(4869,717234410011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','a_fedorenko','alex@fedorenko.net','Oleksandr Fedorenko','132 Shawbrooke Close SW','Calgary','AB','CANADA','T2Y 3A6','(403) 251-5759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 01:33:05',0,NULL,3,1,2,1,'\\ ','a_fedorenko'),(4870,717236512011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',139.99,'eastar4','lincntrace1703','tracnlinc@bigpond.com','Tracey Duck','9 Toona Place','METFORD','New South Wales','AUSTRALIA','2323','0249347759','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-02 01:41:46',0,NULL,3,0,3,1,'RA117734480CN ','lincntrace1703\r发盒装P2100X 带封口签带碟\rGLSG001*2'),(4871,796483434012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',25.45,'eastar4uk','opastoor','opastoor@hotmail.com','Olaf Pastoor','Munster 3','Woldendorp','','NETHERLANDS','9946RR','0628092835','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 02:06:53',0,NULL,3,1,3,1,'RA117724978CN\r ','opastoor\rANCN001\r再发一个 GTM382 +3G antenna'),(4872,588241242013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',12.99,'eastar4','trigem1','steveetten@yahoo.com','John Etten','PO Box 1137<br>187 County Rd 463','Grand Lake','CO','UNITED STATES','80447-1137','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 02:52:06',0,NULL,3,1,1,1,'\\ ','trigem1'),(4873,588242186013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',79.99,'eastar4','codyman5000','codyman5000@westnet.com.au','Cody Jarrett','PO box 1868<br>Kulkyne Street','Renmark West','South Australia','AUSTRALIA','5341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 02:57:35',0,NULL,3,1,3,1,'RA117733833CN\r ','codyman5000\rMOSA003'),(4874,796500397012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','f10166','private.raiden@gmail.com','Ting-Yen Lin','516 Martha St<br>Unit 209','San Jose','CA','UNITED STATES','95112-2476','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 03:06:29',0,NULL,3,0,1,1,'\\ ','f10166'),(4875,588251868013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',148.99,'eastar4','sdelgadilloa','sebastian.delgadillo@gmail.com','sebastian delgadillo','villaseca 75<br>depto 1207','ñuñoa','santiago, RM','CHILE','7750613','92000975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 04:01:11',0,NULL,3,1,3,1,'RA117736358CN\r ','sdelgadilloa\rRCLO003'),(4876,588255589013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','bruceregenthal','tritopaz@comcast.net','Bruce Regenthal','394 E Briarwood Dr','Centennial','CO','UNITED STATES','80122-1005','(303) 798-5933','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-02 04:32:13',0,NULL,3,1,1,1,'\\ ','bruceregenthal'),(4877,717274498011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jeromepat2011','jerrypatp@yahoo.com','jerome pielago','4282 Cavitt Stallman Rd','granite bay','CA','UNITED STATES','95746-9400','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 04:59:51',0,NULL,3,1,1,1,'\\ ','jeromepat2011'),(4878,588258637013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',3,'OTCN001',11.97,'eastar4','igoralexb','loggerbin@gmail.com','Igor Bushnev','47/4 Entuziastov str.','Volgodonsk','Rostovskaya oblast\'','RUSSIAN FEDERATION','347360','7(8639)237814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 04:59:58',0,NULL,3,1,2,1,'\\ ','igoralexb'),(4879,535462459003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'cnfaner','linojanco','lino.janco@gmail.com','Lino Janco','Ekgarden 43','Angered','Vastra Gotaland','SWEDEN','42439','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 06:30:19',0,NULL,3,1,3,1,'RA117736070CN\r ','linojanco\r欧标\rHSNO004'),(4880,717289482011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','spacir007','spacir@spacir.cz','Jiri Prochazka','Sochorova 23<br>AutoCont CZ, a.s.','Brno','Czech Republic','CZECH REPUBLIC','61600','724132149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 06:34:43',0,NULL,3,1,2,1,'\\ ','spacir007'),(4881,541153191004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','valdis2010','kamatoz2003@yahoo.ca','Valdis Linde','94-41 Kr.Valdemara str.','Riga','','LATVIA','LV1013','0037129452602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 07:22:17',0,NULL,3,1,3,1,'RA117736066CN\r ','valdis2010\r欧标\rHSNO022'),(4882,717298702011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',21.95,'eastar4','francozaff','zaffa@iprimus.com.au','M   F   ZAFFINO','BELLCITY, ROOM 422E<br>205-215 BELL STREET, PRESTON,','MELBOURNE','Victoria','AUSTRALIA','3072','0394851422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 07:31:45',0,NULL,3,1,2,1,'\\ ','francozaff\r澳标'),(4883,717303869011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.49,'eastar4','offer2me','f.sythoff@optusnet.com.au','Frits Sythoff','Unit 8C<br>8 Gas Works Road','Wollstonecraft','New South Wales','AUSTRALIA','2065','0421051744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 07:49:23',0,NULL,3,1,2,1,'\\ ','offer2me'),(4884,717312207011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',59.99,'eastar4','pucanokky','nok_nok_nokky@hotmail.com','atichart potipunt','52/86 navamin107<br>khlongkum','bungkum','bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 08:26:04',0,NULL,3,1,3,1,'RA117736185CN\r ','pucanokky\rRCLO006'),(4885,717305006011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','gnikolay05','grabchuk@gmail.com','Anton Koryakov','st. Ochakovcev 39 apt#23','Sevastopol','Ukraine','UKRAINE','99011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 08:30:09',0,NULL,3,1,3,1,'RA117736199CN\r ','gnikolay05\r欧标\rHSNO019'),(4886,587619825013,230623983391,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'',74.99,'eastar4','vitaliy69','v-777-v@yandex.ru','ВИТАЛИЙ КУЛИНЧЕНКО','ул.КОЛЕСНИЧЕНКО, д.32, кв. 2.','СОВЕТСКАЯ ГАВАНЬ','ХАБАРОВСКИЙ КРАЙ','RUSSIAN FEDERATION','682800','+7(42138)41288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 08:30:50',0,NULL,3,0,3,1,'RA117736145CN\r ','vitaliy69'),(4887,717313566011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',110,'eastar4','binnyv66','verhagenps@hotmail.com','Peter Verhagen','22 Wootoona ave','Christies Beach','South Australia','AUSTRALIA','5165','0883844941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 08:35:36',0,NULL,3,1,3,1,'RA117736313CN\r ','binnyv66\rGLOT001*2'),(4888,588289384013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',4,'WLIN014',151.96,'eastar4','kohandirect','kohan@palm-book.com','Roman Kokhanovskiy','1-st Smolenskiy pereulok,<br>dom 13, kvartira 20','Moscow','','RUSSIAN FEDERATION','121099','+7(495)761-2274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 08:48:50',0,NULL,3,1,3,1,'RA117736123CN\r ','kohandirect\rWLIN014'),(4889,717333919011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','megabytes67','megbytes@gmail.com','Bruno MOLET','4 rue saint hubert','Strasbourg','Alsace','FRANCE','67100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 09:58:24',0,NULL,3,1,2,1,'、 ','megabytes67'),(4890,541196534004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',43.58,'cnfaner','henrykarming','estravel@hot.ee','Henry Karming','Tammsaare tee 85-71','Tallinn','IN','ESTONIA','13416','+37253814024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 11:48:15',0,NULL,3,1,3,1,'RA117736137CN\r ','henrykarming\rWWOT001'),(4891,796630369012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.98,'eastar4','piperian','dpetrak@earthlink.net','David Petrak','245 Maplewood Dr','Maitland','FL','UNITED STATES','32751-3424','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 12:24:30',0,NULL,3,1,1,1,'、 ','piperian\r美标'),(4892,796639210012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','putsli81','putsli@gmail.com','Alexander Birukov','Str. Zhivopisnaya, 6-72','Balashikha','RU','RUSSIAN FEDERATION','143900','+7 905 7824091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 12:53:37',0,NULL,3,1,2,1,'、 ','putsli81'),(4893,796640718012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','castileandleon','lawrie.bowles@tiscali.co.uk','lawrence bowles','23 canal walk','croydon','Surrey','UNITED KINGDOM','CR06BY','02086554338','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-02 12:55:56',0,NULL,3,1,3,1,'RA117736208CN\r ','castileandleon\rHSPL010\r英标'),(4894,717389167011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.1,'eastar4','milkmade1','milkmade@zoominternet.net','Julie Yarrington','401 Glasgow Rd','Street','MD','UNITED STATES','21154','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 13:13:17',0,NULL,3,1,1,1,'、 ','milkmade1'),(4895,717389714011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','jamarla3','jamala3@optusnet.com.au','Jason Lamtzes','12 Fernwren Place','CARRUM DOWNS','Victoria','AUSTRALIA','3201','0397704175','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jamarla3'),(4896,717389929011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','paterson_1','apaterson@exemail.com.au','Andrew Paterson','Greater Building Society. Level 4<br>103 Tudor Street','Hamilton','New South Wales','AUSTRALIA','2303','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:17:46',0,NULL,3,1,2,1,'、 ','paterson_1'),(4897,796649177012,220778910015,'NIB Samsung SSG-P2100S Starter Kit Two 3D Glasses',1,'GLSG002',148.99,'eastar4','mah279','m.hengen@hotmail.com','Luke Milburn','P.O. Box 182','Innisfree','AB','CANADA','T0B 2G0','(306) 930-7557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:28:20',0,NULL,3,1,3,1,'RA117736260CN\r ','mah279\rGLSG002'),(4898,717393585011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:29:00',0,NULL,3,1,3,1,'RA117736273CN\r ','latiendadelsotano\rGLSG001*2\r发盒装P2100X 带封口签带碟'),(4899,717394196011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','doradojr','jrp_buster@yahoo.com','Jorge R. Ruiz','PO Box 16621','San Juan','PR','UNITED STATES','00908-6621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 13:30:06',0,NULL,3,1,1,1,'、 ','doradojr\r发盒装P2100X 带封口签带碟'),(4900,796652782012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',38.97,'eastar4','demetrisam','demetris-a@cytanet.com.cy','Jimmy AM','12 Stasinou, Anthoupolis','Nicosia','Nicosia','CYPRUS','2350','22380044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:35:51',0,NULL,3,1,3,1,'RA117736168CN\r ','demetrisam\r欧标\rHSMO018\r一共买了三个'),(4901,796653938012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','ivrankic','ivan.vrankic@t.ht.hr','Ivan Vrankic','Emanuela Vidovica 7','Zagreb','','CROATIA','10000','+38598357785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:37:28',0,NULL,3,1,2,1,'、 ','ivrankic'),(4902,588342758013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',12.59,'eastar4','tac78','tacee78@gmail.com','Laszlo Toth','Csertő u. 18-20. VIII/199.','Budapest','','HUNGARY','1144','36306381708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:37:49',0,NULL,3,1,2,1,'、 ','tac78'),(4903,717396870011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','dean.l.moran','dean@themorans.com.au','D Moran','42 Hampden Rd','Pennant Hills','New South Wales','AUSTRALIA','2120','0418622978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:41:11',0,NULL,3,1,2,1,'、 ','dean.l.moran'),(4904,716951488011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','inviertacr','tavosol@gmail.com','Solis Hidalgo Gustavo','7979 NW 21st St<br># SJO-25136','Doral','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 13:41:16',0,NULL,3,1,1,1,'、 ','inviertacr'),(4905,796660545012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','9523474','patrick@margaretm.ca','Patrick Harroch','225 Chabanel<br>Suite 805','Montreal','QC','CANADA','H2N2C9','(514) 926-3474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:58:36',0,NULL,3,1,3,1,'RA117736242CN\r ','9523474\rHSPL014'),(4906,717402246011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','canondean','skylife019@naver.com','HyunSub Choi','85 Radford Rd. Manly West','Brisbane','Queensland','AUSTRALIA','4179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 14:02:24',0,NULL,3,1,2,1,'、 ','canondean'),(4907,796662555012,220792285628,'NIB Samsung SSG-2200AR Rechargeable Adult 3D Glasses',1,'GLSG005',96,'eastar4','jakecolt300','colt300@gmail.com','jacob broussard','2549 Garrie Cutoff','VINTON','LA','UNITED STATES','70668-5605','(337) 853-6403','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 14:05:21',0,NULL,3,1,1,1,'、 ','jakecolt300\r原装的三星眼镜'),(4908,796672280012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','jaras_cro','josiparas@gmail.com','Josip Aras','Obala palih omladinaca 11','Šibenik','Croatia','CROATIA','22000','+38598816414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 14:33:06',0,NULL,3,1,3,1,'RA117722172CN\r ','jaras_cro\rOTCN004*10'),(4909,588360030013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',2,'OTRA003',67.9,'eastar4','scharon87','masterofpuppets9@gmail.com','Anton Sharypin','ulica Akademika Koroleva, dom 4, korp. 1, kv. 42','Moscow','Moscow','RUSSIAN FEDERATION','129515','89032152816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 14:45:54',0,NULL,3,0,3,1,'RA117736300CN\r ','scharon87\rOTRA003'),(4910,680749741001,110695104704,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',69.99,'buysia','so_rob','saurabh.chimote@gmail.com','Saurabh Chimote','715 N 40th St<br>Apt 108J','Grand Forks','ND','UNITED STATES','58203-8509','(701) 213-4488','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 15:13:57',0,NULL,3,1,1,1,'、 ','so_rob'),(4911,588367467013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','misterruskie','ruskie67@gmail.com','Denis Petrov','3 Yolanta Place<br>Sunshine West','Melbourne','Victoria','AUSTRALIA','3020','0383386029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 15:17:39',0,NULL,3,1,2,1,'、 ','misterruskie'),(4912,716360694011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',17.4,'eastar4','sdhanwada','dhanwada.s@gmail.com','Sandilya Dhanwada','1640 Worcester Rd Apt 129D','Framingham','MA','UNITED STATES','01702','(213) 304-7010','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 15:24:16',0,NULL,3,1,1,1,'、 ','sdhanwada\rCAB-SS-2660'),(4913,717435787011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','kpmm2004','pbowler@sbcglobal.net','Kelly Bowler','654 Bellaire Ave','Madison Heights','MI','UNITED STATES','48071','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 15:47:28',0,NULL,3,1,1,1,'、 ','kpmm2004'),(4914,796715990012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.9,'eastar4','jeanet19poet','inter_traduc.prw@sympatico.ca','Paulette Racine Walden','1320 State Route 9 #40','Champlain','NY','UNITED STATES','12919','(518) 578-3121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 16:35:06',0,NULL,3,1,1,1,'、 ','jeanet19poet'),(4915,715186118011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','kezihallal','ssomer@triad.rr.com','Shubert Somer','CMR 420 Box 971','APO','AE','AA','09063','(336) 784-4416','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 16:49:31',0,NULL,3,1,1,1,'、 ','kezihallal'),(4916,588393638013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','emclusk','emclusk@bigfoot.com','Ed McLuskie','1919 W Verna Ln','Boise','ID','UNITED STATES','83706-3150','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 17:02:38',0,NULL,3,1,1,1,'、 ','emclusk'),(4917,717465065011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','jkya8740','jagadeesh@seamicro.com','Jagadeesh Kyathsandra','5225 Betsy Ross Drive','Santa Clara','CA','UNITED STATES','95054','(408) 380-7008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 17:08:45',0,NULL,3,1,1,1,'、 ','jkya8740\r新地址\rJagadeesh Kyathsandra\rSeamicro, 1237 East Arques Avenue, Sunnyvale, CA 94085'),(4918,535582541003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',5,'WWOT003',249.95,'cnfaner','fabio.amano','fabioamano@hotmail.com','Fabio Amano','Rua Cristovao Lins 446','Sao Paulo','Sao Paulo','BRAZIL','02083-000','+55 11 2201 8644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 17:11:50',0,NULL,3,1,3,1,'RA117736707CN\r ','fabio.amano\rWWOT003\r发两个C680R 申报50美金'),(4919,796752226012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','vertoninatali','verto77@mail.ru','Vildanov Rustem','56-17 Aksakov st','Ufa','Bashkortostan','RUSSIAN FEDERATION','450076','(917)-3434777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 17:58:24',0,NULL,3,1,2,1,'、 ','vertoninatali'),(4920,588410687013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',3,'BALO001',31.47,'eastar4','xyz-xyz','lowerfranz@gmail.com','eric lindenberg','c/o red ball radio ltd.<br>6 north front st','belleville','ON','CANADA','k8p3a7','(800) 363-1100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 18:01:38',0,NULL,3,1,3,1,'RA117736256CN\r ','xyz-xyz\rBALO001'),(4921,796759593012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','juniornsmg','teniskelsen@gmail.com','Walter Junior','Rua Nazare, 456<br>Sao Marcos','Nova Serrana','Minas Gerais','BRAZIL','35519-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 18:15:54',0,NULL,3,1,2,1,'、 ','juniornsmg'),(4922,717493108011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','terrell_williams40','artezisnjm1@yahoo.com','Artez  McRae','3200 Stonypointe Dr','Greensboro','NC','UNITED STATES','27406-5420','(410) 926-5522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 18:17:47',0,NULL,3,1,1,1,'、 ','terrell_williams40'),(4923,717492812011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','bubblepuppy7','tolbert51571@hotmail.com','Ronald Tolbert','148 John Rolfe Ln','Williamsburg','VA','UNITED STATES','23185','(757) 220-8737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 18:18:08',0,NULL,3,1,1,1,'、 ','bubblepuppy7'),(4924,716984079011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','tarbh77','sean_mccatterson@yahoo.com','charles mccausland','4479 Ide Rd','Wilson','NY','UNITED STATES','14172-9642','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 18:27:27',0,NULL,3,1,1,1,'、 ','tarbh77\r新的'),(4925,717497937011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',4,'OTSO004',335.96,'eastar4','coltsray','ray@oehlerking.us','oehlerking','15880 prince frederick rd','hughesville','MD','UNITED STATES','20637-2506','(301) 274-3803','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 18:28:59',0,NULL,3,1,6,1,'EE520583542CN ','coltsray'),(4926,541294111004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','pigchaser','mitchellmark@alltel.net','J L Mitchell','902 Sugardale Ct','Sugar Land','TX','UNITED STATES','77498-2760','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-02 18:55:03',0,NULL,3,1,1,1,'、 ','pigchaser'),(4927,717518376011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY001*3',3.58,'eastar4','darthr2','vxiannts@yahoo.com','Xian Lu','20875 E Girard Pl','Aurora','CO','UNITED STATES','80013','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 19:18:47',0,NULL,3,0,1,1,'、 ','darthr2\r黄膜天线'),(4928,535627293003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','msimon_777','msimon-777@fijalkowski.de','Manfred Fijalkowski','Jahntr. 46 CC','Wadgassen','','GERMANY','66787','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 19:48:18',0,NULL,3,1,3,1,'RA117736171CN\r ','msimon_777\rWWOT003'),(4929,541312677004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.95,'cnfaner','joe7eleven','joe.estabrooks@gmail.com','Joseph Estabrooks','10002 Spring Lake Ter','Fairfax','VA','UNITED STATES','22030-2036','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-02 19:55:58',0,NULL,3,1,4,1,'YW865717216CN ','joe7eleven'),(4930,717538006011,320694423879,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',2,'GLSG003',178,'eastar4','maumaqui2908','maumaqui@uol.com.br','jose mauricio maquieira','raul amaro nim ferreira<br>180/301','rio de janeiro','rio de janeiro','BRAZIL','22795-175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 19:57:15',0,NULL,3,1,3,1,'RA117736432CN\r ','maumaqui2908\rGLSG003'),(4931,588449280013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','pengguj','pengguj2000@yahoo.com','pengguang jiang','2860 Geer Rd','turlock','CA','UNITED STATES','95382-1141','(209) 668-9988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 19:57:41',0,NULL,3,1,1,1,'、 ','pengguj'),(4932,796813865012,220782958082,'New Jabra BT135 BT 135 wireless Bluetooth Headset',1,'HSJA007',14.85,'eastar4','way0417','wjkcpatterson45@yahoo.com','Wayne Patterson','318 E 6th St','West Lafayette','OH','UNITED STATES','43845-1418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 20:08:13',0,NULL,3,1,1,1,'、 ','way0417'),(4933,717542606011,320441567733,'2.1 Acer Aspire 5680 5630 3690  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','fordmach169','fordguyms2@hotmail.com','mike slack','PO BOX 5316','Spanaway','WA','UNITED STATES','98387-4087','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 20:08:36',0,NULL,3,1,1,1,'、 ','fordmach169\racer 8pin1.00 8cm '),(4934,796826153012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',7.98,'eastar4uk','joel72_fr','molasar.keep@neuf.fr','Gil-Barroqueiro joel','487 rue Cancellieri','SALLANCHES','Haute Savoie','FRANCE','74700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 20:29:10',0,NULL,3,1,2,1,'、 ','joel72_fr'),(4935,796831687012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',110,'eastar4','eduardca','educarulla@hotmail.com','Eduard Carulla','Joan Blanques 22 Entlo 2','BARCELONA','Barcelona','SPAIN','08012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 20:42:13',0,NULL,3,1,3,1,'RA117722858CN ','eduardca\rGLOT001*2\r\r'),(4936,680877956001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK001',106,'buysia','zisch01','albert.payer@vetifant.at','Albert Payer','Erlenweg 6','Deutschlandsberg','','AUSTRIA','8530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 20:52:25',0,NULL,3,0,3,1,'RA117736327CN\r ','zisch01\rHSAK001'),(4937,796843205012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',3,'HSMO018',26.97,'eastar4uk','atakan12','hasantakaoglu@googlemail.com','Hasan Takaoglu','11A  Fisgard road<br>Elson','Gosport','Fareham / hampshire','UNITED KINGDOM','PO12 4HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-02 21:06:04',0,NULL,3,1,3,1,'RA117736211CN\r ','atakan12\r英标\rHSMO018'),(4938,796750455012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',5,'HSNO006',74.85,'eastar4','akoock','mespanak@gmail.com','Marcelo España','Bernardino 1994<br>Puerto Montt','Puerto Montt','Region, Los Lagos','CHILE','5665','320634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 21:21:07',0,NULL,3,1,3,1,'RA117736344CN\r ','akoock\rHSNO006'),(4939,796859877012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','u2daveuk','davezrx@hotmail.com','dave warren','10 sisley way<br>holly lodge','hinckley','Leicestershire','UNITED KINGDOM','le10 0gj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-02 21:47:43',0,NULL,3,1,3,1,'RA117736225CN\r ','u2daveuk\rHSPL010\r英标'),(4940,796863174012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','dskirvin','dskirvin@uiuc.edu','Danny Skirvin','8770 W Athens St','Peoria','AZ','UNITED STATES','85382-3059','(623) 399-8130','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 21:56:39',0,NULL,3,1,1,1,'、 ','dskirvin'),(4941,796869446012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4uk','snghrobn','robnsngh@gmail.com','ROBIN SINGH','HOSTEL B -321 , BITS PILANI , DUBAI CAMPUS<br>DUBAI INTERNATIONAL ACADEMIC CITY','DUBAI','DUBAI','UNITED ARAB EMIRATES','345055','+971552205480','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 22:21:12',0,NULL,3,1,3,1,'RA117736239CN\r ','snghrobn\rWLAP008'),(4942,717605957011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','dluna0980','dluna0980@hushmail.com','Daniel  Luna','18 Salem Dr','Joliet','IL','UNITED STATES','60436','(815) 791-5751','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 23:11:37',0,NULL,3,1,1,1,'、 ','dluna0980\r发盒装P2100X 带封口签带碟'),(4943,796894428012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','magoatbay','magomob@gmail.com','MARIO GODOY','RUA 401, 260','BALNEARIO CAMBORIU','SANTA CATARINA','BRAZIL','88330-696','041 9615-9298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 23:57:10',0,NULL,3,1,3,1,'RA117736110CN\r ','magoatbay\rWWOT003'),(4944,535689618003,130504141009,'NEW Red Genuine Lowepro Topload Zoom Mini Camera Bag!',1,'',19.98,'cnfaner','pamoroll','p.morolli@tin.it','Pier Andrea  Morolli','Via Cirene 6','RIMINI','RN','ITALY','47900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 00:48:55',0,NULL,3,0,3,1,'RA117722190CN\r ','pamoroll\r红色的'),(4945,717638929011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','lsr702','lsr702@aol.com','Larry S. Rogers','702 Woodview Way','Bradenton','FL','UNITED STATES','34212-9014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 01:39:31',0,NULL,3,1,1,1,'、 ','lsr702'),(4946,717642565011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','ramaswar','ramaswar@yahoo.com','Ramanathan Ramaswamy','2854 Balforn Tower Way','Winter Garden','FL','UNITED STATES','34787-4761','(407) 654-8879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 01:53:41',0,NULL,3,1,1,1,'、 ','ramaswar'),(4947,717652009011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','mhas9863','jaodad@yahoo.com.au','Md jaodad Hasan','17 John Armstrong Cl','Taree','New South Wales','AUSTRALIA','2430','0265518547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 02:37:10',0,NULL,3,1,2,1,'、 ','mhas9863'),(4948,588542632013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','coachsavvy','skyshannie@yahoo.com','Law Wei Kee','16 Jalan Puteri 11/18<br>Bandar Puteri Puchong','Puchong','Selangor','MALAYSIA','47100','0123386379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 03:19:49',0,NULL,3,0,3,1,'RA117736401CN\r ','coachsavvy\rOTRA003'),(4949,717663851011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','fat5fin','paulf49@optusnet.com.au','Paul Finney','34 Willow Crescent','Ryde','New South Wales','AUSTRALIA','2112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 03:36:05',0,NULL,3,1,3,1,'RA117736389CN\r ','fat5fin\rBR3D001'),(4950,717667339011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','tempo_232009','tempopr2009@yahoo.com','dennis vargas','hc 58 box 12650<br>bo jaguey','aguada','PR','UNITED STATES','00602-9801','(787) 431-9093','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 03:53:58',0,NULL,3,1,1,1,'、 ','tempo_232009'),(4951,535728375003,130522141367,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card+antenna',1,'WLIN012+ANTY002',51.5,'cnfaner','racerx427','carracing@gmail.com','William Desjardins','100 NE 80th Ter<br>Ethernext Inc.','Miami','FL','UNITED STATES','33138-4415','(305) 373-5960','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 05:09:26',0,NULL,3,1,1,1,'、 ','racerx427'),(4952,588562212013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',43.5,'eastar4','techies25','milton_uts@hotmail.com','md robiul islam','3/101, Gerard Street<br>cremorne','sydney','New South Wales','AUSTRALIA','2090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 05:49:31',0,NULL,3,1,3,1,'RA117736392CN\r ','techies25\rCASS003'),(4953,796980345012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',166.99,'eastar4','dima.prosvirkin','d.prosvirkin@gmail.com','Dmitriy Prosvirkin','Aksai 3b, house 11, apt.2','Almaty','Almaty oblysi','KAZAKHSTAN','050000','+7 777 2170700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 06:03:16',0,NULL,3,0,3,1,'RA117736375CN\r ','dima.prosvirkin\rOTSO004*2'),(4954,796985780012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','stansmomma','stansmomma@yahoo.com','Susan Thomason','1053 Wrigley Cir','Warrenton','MO','UNITED STATES','63383','(636) 456-7724','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 06:28:14',0,NULL,3,1,1,1,'、 ','stansmomma'),(4955,588577527013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',71.75,'eastar4','mabahok','karlwisse@gmx.ch','Rosi Ketzer','Iliffe Street 61<br>Southwark','London','London','UNITED KINGDOM','SE173LL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 07:51:36',0,NULL,3,1,3,1,'RA117736361CN\r ','mabahok\rMOSA001'),(4956,717710684011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','centurycontainbers','andyh@centurycontainers.com','Century Container Services Ltd','Century Yard, Newfields Ind. Estate<br>Hedon Road','Hull','Humberside','UNITED KINGDOM','HU12 8FB','01482307755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 07:59:36',0,NULL,3,1,2,1,'\\ ','centurycontainbers'),(4957,797015442012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','bag_kr','aliwu085@gmail.com','ALINA BARABASH','20/3-326 Parusnaya st.','Krasnodar','Krasnodar aria','RUSSIAN FEDERATION','350061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 08:46:40',0,NULL,3,1,2,1,NULL,'bag_kr'),(4958,717722610011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','vitkud2010','vitkud@gmail.com','Vitaliy Kudryavtsev','Buharestskaya 146-1-367','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192289','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 08:56:37',0,NULL,3,1,2,1,NULL,'vitkud2010'),(4962,797038897012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','discostorenet','phil@plsl.co.uk','Phil Laycock','P&L Sound & Lighting<br>Barrys Lane','Scarborough','North Yorkshire','UNITED KINGDOM','YO12 4HA','01723378888','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 10:27:11',0,NULL,3,1,3,1,'RA117725094CN\r','discostorenet\rOTCN004*10'),(4959,797032022012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','arbi3655','arbi365@gmail.com','Arbi Voskanian','1436 W Glenoaks Blvd<br># 118','Glendale','CA','UNITED STATES','91201','(818) 951-7650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 09:56:05',0,NULL,3,0,1,1,'\\ ','arbi3655\r白色的'),(4960,541449254004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','herman77guerrero','hermanguerrero18@yahoo.com','Herman Arias','1043 Lakeside Pl','baldwin','NY','UNITED STATES','11510-3312','(516) 859-0272','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 10:13:42',0,NULL,3,1,1,1,NULL,'herman77guerrero\r一共买了两个'),(4961,797038099012,220788697050,'New genuine Plantronics Voyager pro Bluetooth Headset',1,'HSPL013',51.9,'eastar4','ronigon','roni.ramon@gmail.com','dror gonen','Palmah 20','Herzliya','Herzliya','ISRAEL','46793','972-99574359','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:17:28',0,NULL,3,1,3,1,'RA117725925CN\r ','ronigon\rHSPL013'),(4963,717744417011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','spaderb','ben@benspader.com','Ben Spader','1402 Landsdown Rd','Buffalo','MN','UNITED STATES','55313-1372','(651) 967-4144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 10:30:35',0,NULL,3,1,1,1,NULL,'spaderb\\'),(4964,588606520013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','alexalwaysright','webdesigner@ukr.net','Alex Okhrimenko','Pravdy prospect 8A<br>apt. #101','Kiev','UA','UKRAINE','04108','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:02:41',0,NULL,3,1,2,1,'\\ ','alexalwaysright'),(4965,588608525013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','cccip_44','ascherbachenko@gmail.com','Alex Scherbachenko','Dzhandosov street 11A<br>Flat 7','Almaty','','KAZAKHSTAN','050057','(701) 786-0870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:14:36',0,NULL,3,1,3,1,'RA117725015CN\r ','cccip_44\rMOLO004\r华硕限量版'),(4966,717754471011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','tetta4*737242','tttaabo311@gmail.com','TETAUA TAABO','ROBINVALE ACCOMMODATION VILLAGE (room 15)<br>5ADCOCK ROAD','ROBINVALE/VICTORIA','Victoria','AUSTRALIA','3549','0401859709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:15:22',0,NULL,3,1,2,1,'\\ ','tetta4*737242\r澳标\r再发一个NEW GENUINE NOKIA BH-202 '),(4967,717756631011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','tetta4*737242','tttaabo311@gmail.com','TETAUA TAABO','ROBINVALE ACCOMMODATION VILLAGE (room 15)<br>5ADCOCK ROAD','ROBINVALE/VICTORIA','Victoria','AUSTRALIA','3549','0401859709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:20:53',0,NULL,3,1,17,0,' ','tetta4*737242'),(4968,588621154013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','cykocl2008','cykocl@yahoo.com.sg','Chan YK','374 Lorong Chuan','Singapore','','SINGAPORE','556800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 12:27:23',0,NULL,3,1,11,1,'RA117736928CN\r ','cykocl2008\rOMHJ001'),(4969,541472660004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',73.95,'cnfaner','bolotelewidz','ekai@free.fr','Irénée Valachie','105 rte Nationale','Gambsheim','Alsace','FRANCE','67760','06.08.70.61.81','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 12:32:50',0,NULL,3,1,3,1,'RA117725032CN\r ','bolotelewidz\rOTSO001'),(4970,717775363011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',84.99,'eastar4','robrga01','rigo20014@hotmail.com','Rodrigo Bedoya','1901 Kennedy Blvd<br>Apt 308','North Bergen','NJ','UNITED STATES','07047-6318','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 12:41:54',0,NULL,3,0,1,1,'\\ ','robrga01\r再发一个New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR'),(4971,717778879011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','arielgenut','a1212g@gmail.com','ariel genut','harav zinger<br>14','givat shmoel','AL','ISRAEL','54420','035326373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 12:51:10',0,NULL,3,1,2,1,'\\ ','arielgenut'),(4972,588630268013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','e_uzh','oleshka_best@mail.ru','Oleg Tyshchuk','Legotskogo 40/11','Uzhgorod','Transcarpathia','UKRAINE','88015','+380504327231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 13:13:07',0,NULL,3,1,2,1,'\\ ','e_uzh'),(4973,797087214012,220705174913,'Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO014',16.95,'eastar4uk','wendy_cariad','wendysunshine@hotmail.co.uk','Ms W Cosford','54 Parc Hafod<br>Four Crosses','LLanymnech','Powys','UNITED KINGDOM','SY22 6NZ','07791033351','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 13:15:26',0,NULL,3,1,3,1,'RA117725050CN\r ','wendy_cariad\r旧的\r英标\rHSMO014\r'),(4974,797092477012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','marcoseyona','marcosrosignoli@hotmail.co.uk','marcos aurelio rosignoli','5 tilehurst court<br>kersal way','salford','Greater Manchester','UNITED KINGDOM','m73st','01618702399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 13:31:18',0,NULL,3,1,3,1,'RA117725029CN\r','marcoseyona\rHSMO018\r英标'),(4975,717743824011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','ensiekei','nickv@telenet.be','Nicky Vandebeek','Spurkerweg 13','Bilzen','','BELGIUM','3740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 13:39:53',0,NULL,3,1,2,1,'\\ ','ensiekei'),(4976,717799552011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','brainiac5.0','chris.izere@yahoo.com','Christian Tuyizere','447 14th St<br>Uppr','Buffalo','NY','UNITED STATES','14213-2207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 13:59:28',0,NULL,3,1,1,1,'\\ ','brainiac5.0\racer 4pin1.25 6cm'),(4977,588645636013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-03 14:24:02',0,NULL,3,1,1,1,NULL,'edpsychdoc\\'),(4978,797110851012,220759911881,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',41.9,'eastar4','fernyusa13','fernyusa@hotmail.com','Christian Peralta','Bragado 4878','Buenos Aires','Capital Federal','ARGENTINA','C1407HBH','0054111561720976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:25:35',0,NULL,3,1,3,1,'RA117736874CN\r ','fernyusa13\rHSMO020'),(4979,717634172011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',2,'BR3D001',71.98,'eastar4','2010alexbrazil','tankraised@hotmail.com','Alexandre Cunha','Rua Piracicaba 40 - Valparaiso','Santo André','SP','BRAZIL','09060-180','551149941554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:28:01',0,NULL,3,1,3,1,'RA117736914CN\r','2010alexbrazil\rBR3D001'),(4980,797116516012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',10.49,'eastar4','ultimaratio','mortai@gmx.de','Hans-Dirk Schacke','Schmittstr. 36','Bonn','','GERMANY','53123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:42:58',0,NULL,3,1,2,1,'\\ ','ultimaratio'),(4981,797118540012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',2,'BALO005',14.2,'eastar4','darkprincessnakita','cat_girl49@hotmail.com','Naomy Charette','506 place Daviault<br>box 453','Fermont','QC','CANADA','G0G 1J0','(705) 920-6293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:49:13',0,NULL,3,1,2,1,'\\ ','darkprincessnakita\r旧的'),(4982,797120066012,220747230811,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',12.2,'eastar4uk','tomboy5186','susaneverard@hotmail.com','Susan Everard','6 Green Way','Bromley','Kent','UNITED KINGDOM','BR2 8EY','02082892969','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 14:53:23',0,NULL,3,1,3,1,' RA117725593CN\r','tomboy5186\r英标\rHSSA001'),(4983,588529632013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','tofazakie','tofa.zakie99@gmail.com','Bagas Gigih','Jln. Ki Hajar Dewantoro No.7 Sumurpanggang','Tegal','Jawa Tengah','INDONESIA','52141','085642633373','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-03 15:00:24',0,NULL,5,0,18,0,NULL,'tofazakie  paypal 退款\rHSNO019'),(4984,717823686011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','artictech','paul.peltola@mcgill.ca','Paul Peltola','60-49th. Ave.','Lachine','QC','CANADA','H8T2S5','(514) 634-4660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 15:18:40',0,NULL,3,1,2,1,'\\ ','artictech'),(4985,588661698013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','juampa81','jpve81@gmail.com','Juan Pablo Varas Escalona','Travesera de las Corts nº 352 entresuelo 8º','Barcelona','Barcelona','SPAIN','08029','652966595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 15:33:32',0,NULL,3,1,3,1,'RA117736891CN\r ','juampa81\rOTES001'),(4986,717838313011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',3,'HSMO008',35.85,'eastar4','rubyredruby2','ruby@hay.net','LaRue Brenner','Rural Route #2<br>10270 Mary Ave.','Grand Bend','ON','CANADA','N0M 1T0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:03:03',0,NULL,3,1,3,1,'RA117736534CN\r ','rubyredruby2\rHSMO008'),(4987,797147262012,220792287518,'New HuaWei EM770W 3G WWAN Mini PCI-E Card HSDPA GPS',1,'WWHU003',49.99,'eastar4','diegodemarco','diego@diegodemarco.com','Diego De Marco','Quintanilla 841<br>Barrio San Jorge, Lote 19','Don Torcuato','Buenos Aires','ARGENTINA','B1611ESE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:11:35',0,NULL,3,1,3,1,'RA117736548CN\r ','diegodemarco\rWWHU003'),(4988,797155124012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','mwplagge','mwplagge@hotmail.com','Mike Plagge','638 40th ST SE','Cedar Rapids','IA','UNITED STATES','52403-4344','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 16:30:50',0,NULL,3,1,1,1,'\\ ','mwplagge'),(4989,588674673013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','webwebes','alejandro_spa@hotmail.com','Apolinar Martinez Sio','C/ Manuel Rodriguez Nº 8, 2º dcha','Porriño - Pontevedra','Galicia','SPAIN','36400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:31:45',0,NULL,3,0,3,1,'RA117736551CN\r ','webwebes\rOTRA003'),(4990,717853188011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',4,'CASS002',34.8,'eastar4','davidba80','deebee8@gmail.com','David Bachar','471 Mundet Pl','Hillside','NJ','UNITED STATES','07205-1115','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 16:47:00',0,NULL,3,1,1,1,'\\ ','davidba80'),(4991,797160889012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','mhhhy','coins.abouzeid@gmail.com','Mohammad AbouZeid','13, Ebn-Saod str<br>Cleopatra','Alexandria','Alexandria','EGYPT','21311','+20145127721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:50:13',0,NULL,3,1,3,1,'RA117722521CN\r','mhhhy\rWWOT003\r做一份invoice放进去  申报wireless card  50美金'),(4992,717855637011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','acctima','duel@inbox.lv','Eduard Lvov','Morica 20b-71','Riga','','LATVIA','1083','+37129549232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:52:48',0,NULL,3,1,2,1,'\\ ','acctima\r欧标'),(4993,535850783003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','romanroh8338','romanroh@gmail.com','Roman Rohberg','Aba Ahimeir 38','Gedera','Israel','ISRAEL','70700','972506778338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 17:19:49',0,NULL,3,1,3,1,'RA117736463CN\r ','romanroh8338\rHSPL005'),(4994,797176420012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','patriciapattiux','arq_pattiux@hotmail.com','patricia delgadillo','4932 Burnt Oak Dr<br>Apt 102','richmond','VA','UNITED STATES','23234-2996','(804) 400-6923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 17:29:10',0,NULL,3,1,1,1,'\\ ','patriciapattiux'),(4995,717873065011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','iislam86','irfan86usa@aol.com','MD ISLAM','508 McDonald Ave<br>Rupali Exchange Inc.','Brooklyn','NY','UNITED STATES','11218-3812','(347) 419-6770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 17:40:22',0,NULL,3,1,1,1,NULL,'iislam86\\'),(4996,588693866013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','cyrano64','mr_cholsh@hotmail.com','Alex Cholsh','Unit 4<br>2 Leader Avenue','Toorak Gardens','South Australia','AUSTRALIA','5065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 17:40:48',0,NULL,3,1,2,1,'\\ ','cyrano64\r澳标\r银色的'),(4997,588697053013,230552652688,'New PHILIPS Salon HP8309 ULTRA-SLIM HAIR STRAGHTENER',1,'OTPH002',19.99,'eastar4','detroit12311','dearborn321@yahoo.com','habiba karimi','4981 Kenilworth St','dearborn','MI','UNITED STATES','48126-3159','(313) 915-8082','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 18:00:49',0,NULL,3,1,1,1,'\\ ','detroit12311'),(4998,717882014011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','vicemo','rodrigo.monteiro@itau-unibanco.com.br','Rodrigo Monteiro','Conego Januario, 165 - Edificio Jatoba - Ap96<br>Ipiranga','Sao Paulo','São Paulo','BRAZIL','04201-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 18:03:31',0,NULL,8,1,17,0,NULL,'vicemo'),(4999,717883284011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','vicemo','rodrigo.monteiro@itau-unibanco.com.br','Rodrigo Monteiro','Conego Januario, 165 - Edificio Jatoba - Ap96<br>Ipiranga','Sao Paulo','São Paulo','BRAZIL','04201-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 18:06:28',0,NULL,3,1,3,1,'RA117725148CN\r ','vicemo\rGLSG001+GLOT004\r再发一个New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR兼容型3D眼镜  samsung 专用'),(5000,797203467012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×4',235.99,'eastar4','mvidemexico4045','carlosb@mvidemexico.com','CARLOS BANUELOS','6630 CAMINO MAQUILADORA','SAN DIEGO','CA','UNITED STATES','92154-7521','(619) 245-4522 ext.: 103','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 18:29:18',0,NULL,3,0,6,1,'EE520583539CN ','mvidemexico4045'),(5001,797140592012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','dgoff99','david@oceansports.com','David Goff','2716 N OCEAN BLVD','FORT LAUDERDALE','FL','UNITED STATES','33308','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 19:06:49',0,NULL,3,1,1,1,'\\ ','dgoff99'),(5002,717907921011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','icefisher47','nikjs47@itstriangle.com','Gene A Harris','PO Box 613<br>309 W Hampton','WHITE SULPHUR SPRINGS','MT','UNITED STATES','59645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 19:08:04',0,NULL,3,1,1,1,'\\ ','icefisher47'),(5003,717924144011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','galas','stevegalas@earthlink.net','Steven Galas','105 Brookstone Ct','Jupiter','FL','UNITED STATES','33458-5535','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 19:48:46',0,NULL,3,1,1,1,'\\ ','galas'),(5004,797243523012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.9,'eastar4','suaveeee23','asi51197@gmail.com','Sharon Eyal','420 Lombard St','Oxnard','CA','UNITED STATES','93030-5100','(818) 521-2492','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 19:59:58',0,NULL,3,1,1,1,'\\ ','suaveeee23'),(5005,541575173004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',3,'HSPL010',71.4,'cnfaner','stevedl83','steve@sjlogan.com','Steve Logan','13818 Shavano Rdg','San Antonio','TX','UNITED STATES','78230-5802','(210) 670-7637','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 20:03:20',0,NULL,3,1,1,1,'\\  ','stevedl83'),(5006,797248127012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','haterpb','info@haterpaintball.com','Brandon Buddenhagen','527 7th Ave','Gotha','FL','UNITED STATES','34734-4700','(317) 354-5201','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 20:10:30',0,NULL,3,1,1,1,NULL,'haterpb\r红边优联\\'),(5007,717962871011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','godspeedoakland','dan@godspeedoakland.com','Dan Mather','21 Alondra Rd','Santa Fe','NM','UNITED STATES','87508-8702','(505) 466-1066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 21:30:03',0,NULL,3,1,1,1,NULL,'godspeedoakland\\'),(5008,717964110011,320700134667,'New GENUINE Plantronics Discovery 610 Bluetooth Headset',1,'HSPL016',19.9,'eastar4','erezza','erez_zamir@yahoo.com','Erez Zamir','Aaron David Gordon 14<br>A.D Gordon 14','Tel Aviv','Israel','ISRAEL','63407','972 54 522 41 58','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 21:33:59',0,NULL,3,1,2,1,'\\ ','erezza'),(5009,797289952012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','d_k_allen','dave.allen07@yahoo.com','Dave Allen','37 Deene Court<br>Westwood','Peterborough','Cambridgeshire','UNITED KINGDOM','PE3 7AY','01733267090','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 21:58:30',0,NULL,3,1,3,1,'RA117736494CN\r ','d_k_allen\r旧的黑色的\rHSMO014'),(5010,541603851004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','herman77guerrero','hermanguerrero18@yahoo.com','Herman Arias','1043 Lakeside Pl','baldwin','NY','UNITED STATES','11510-3312','(516) 859-0272','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 22:02:53',0,NULL,3,1,17,0,NULL,'herman77guerrero'),(5011,717997766011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','sidsells','suminda@aol.com','suminda sellahewa','5324 Montemalaga Dr','Rancho Palos Verdes','CA','UNITED STATES','90275-1741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 23:37:26',0,NULL,3,1,1,1,'\\ ','sidsells'),(5012,588797525013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','valdevino','biodevino@bol.com.br','Valdevino Ramos','Rua Altino Gonçalves de Farias<br>1441','Curitibanos','Santa Catarina','BRAZIL','89520000','04991029999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 00:57:02',0,NULL,3,1,2,1,'\\ ','valdevino'),(5013,796131314012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',23.9,'eastar4','mandalorian269','lironido@hotmail.com','Ido Liron','2425 S Norfolk St<br>Apt 102','San Mateo','CA','UNITED STATES','94403','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 01:29:02',0,NULL,3,1,1,1,'\\ ','mandalorian269'),(5014,718025791011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','kalam_sg','kalam_sg@yahoo.com','Abul Kalam Azad','BLK 642, #12-58<br>Jurong West St 61','Jurong','Singapore','SINGAPORE','640642','98516725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 01:57:08',0,NULL,3,1,11,1,'RA117736962CN\r ','kalam_sg\rCCGR001'),(5015,797359681012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',20,'OTAP001',189.8,'eastar4','rhinobr','contato@rhinotec.com.br','M. H. ZORTEA RHINOTEC ME','Desembargador Vieira Cavalcanti 292 ap 11 subsolo','Curitiba','Paraná','BRAZIL','80510-090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 02:42:41',0,NULL,3,0,3,1,'RA117725430CN\r ','rhinobr\rOTAP001'),(5016,797367445012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','flyboi2','flyboiwife@gmail.com','Stephen Smetana','42 Sunny View Lane','Kimberling City','MO','UNITED STATES','65686','(417) 739-4853','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 03:18:05',0,NULL,3,1,1,1,'\\ ','flyboi2'),(5017,792459882012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','hunnyscoots','kirkylurk@hotmail.com','Kirsten Joy Blankenship','12611 N Gentle Rain Dr','Marana','AZ','UNITED STATES','85658-4394','(520) 869-4401','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'hunnyscoots'),(5018,718052533011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','yllui5','yllui@graduate.hku.hk','Yuk Lung Lui','Flat E, 11/F, Tower 3<br>Ocean Shores, Tseung Kwan O','default','','HONG KONG','default','(852) 92263207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 04:32:52',0,NULL,3,1,2,1,'\\ ','yllui5'),(5019,797394198012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','martyfly1965','martyfly65@gmail.com','martin shillabeer','1 Marks Street<br>pascoevale','melbourne','Victoria','AUSTRALIA','3044','0411042352','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 05:53:06',0,NULL,3,1,2,1,'\\ ','martyfly1965'),(5020,797398156012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','falestiny78','haitham.saqallah@gmail.com','Haitham A. Saqallah','P.O. Box 39561','Doha','Dhahran','SAUDI ARABIA','31942','(966) 505-1660 ext.: 01','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 06:21:33',0,NULL,3,1,3,1,'RA117736741CN\r ','falestiny78\rWWOT003'),(5021,588840787013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','niqmk','niqmk10@gmail.com','Michael','Jl. Brigjen Katamso No. 8, 9','Jakarta Barat','DKI Jakarta','INDONESIA','11420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 06:24:52',0,NULL,3,0,2,1,'\\ ','niqmk 客户想换成ASUS N554 bluetooth mouse,补差价6.91 '),(5022,588843328013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','hayder313','hydr87@gmail.com','Hayder Mousawi','8817 Coulter St','Dearborn','MI','UNITED STATES','48126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 06:45:28',0,NULL,3,1,1,1,'\\ ','hayder313'),(5023,797444639012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','9724kuki240','kuki240@gmail.com','ofer tamsut','atzmaut 90/8','qiryat ata','israel 972','ISRAEL','28219','97248447861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 09:37:05',0,NULL,3,1,2,1,'\\\r ','9724kuki240'),(5024,536019261003,130460438605,'New Plantronics Explorer 340 BLUETOOTH HEADSET track#',1,'HSPL007',19.9,'cnfaner','14krunal','kpatel122591@gmail.com','krunal patel','1668 W High St','stowe','PA','UNITED STATES','19464-3759','(484) 792-1556','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 10:07:05',0,NULL,3,1,1,1,'\\ ','14krunal'),(5025,718129613011,320679575380,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',9.45,'eastar4uk','jamesbond007trevor','trevhines2009@hotmail.com','trevor hines','9 stanley ave<br>chiswell green','st.albans','Hertfordshire','UNITED KINGDOM','al2 3aa','01727842986','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 10:48:03',0,NULL,3,1,3,1,'RA117736738CN\r ','jamesbond007trevor\rWLAP001'),(5026,797464773012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jerry_andrius','andriusa@kis.lt','Andrius Laukaitis','Pramones pr. 41 - 33','Kaunas','','LITHUANIA','50464','+37063026666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 10:50:39',0,NULL,3,1,2,1,'\\ ','jerry_andrius\r欧标'),(5027,797480023012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','nasalabama','stoddart@hiwaay.net','Stoddart Electric Inc','7119 Jones Valley Dr SE','Huntsville','AL','UNITED STATES','35802-1921','(256) 533-0835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 11:44:55',0,NULL,3,1,1,1,'\\ ','nasalabama'),(5028,718159027011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','ton559','tonykwon@tpg.com.au','Tony Kwong','55 Nemies Road Runcorn','Brisbane','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 12:37:06',0,NULL,3,1,2,1,'\\ ','ton559\r澳标'),(5029,797499066012,220502333404,'2.1 HP 8710w nw9440 nx9420 Bluetooth Module EDR +cable',1,'BTHP2105',12.4,'eastar4','anywax','levieil.nicolas@gmail.com','Nicolas LEVIEIL','24 rue d\'Hautpoul<br>Bat. C','Paris','Île-de-France','FRANCE','75019','0153191539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 12:46:48',0,NULL,3,1,2,1,'\\ ','anywax\rHP 8pin 1.0 20cm'),(5030,797506651012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','masjodon','cuchocastro23@gmail.com','Hector Castro','PO Box 273','Salinas','PR','UNITED STATES','00751','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 13:10:19',0,NULL,3,1,1,1,'\\ ','masjodon'),(5031,718175838011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','vtengls','vtengls@hotmail.com','Vincent Teng','Blk 408C, Fernvale Road, #22-02','Singapore','Singapore','SINGAPORE','793408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 13:32:31',0,NULL,3,1,11,1,'RA117736993CN\r ','vtengls\rHSJA005'),(5032,718183138011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','410mark5519','mjmiller0502@hotmail.com','Mark Miller','5519 RItter Ave','Baltimore','MD','UNITED STATES','21206-3336','(410) 325-5323','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 14:06:41',0,NULL,3,1,1,1,'\\ ','410mark5519\rHP 8pin 1.25 25cm '),(5033,797532378012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','ftoman10','steveoz56@btinternet.com','stephen austin','7 Elmleigh Road','Havant','Hampshire','UNITED KINGDOM','PO9 2AA','07806541534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 14:27:30',0,NULL,3,1,3,1,'RA117736667CN\r ','ftoman10\rHSMO014\r英标 旧的'),(5034,588926478013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',2,'BAZA001',139.96,'eastar4','worrawat','jillm5n@yahoo.com','WORRAWAT MOOLSIN','88/9 Kathathon Road<br>Tumbol Namueang','Amphoe Mueang Ratchaburi','Ratchaburi','THAILAND','70000','+66818679039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:32:32',0,NULL,3,1,3,1,'RA117736429CN\r ','worrawat\rBAZA001'),(5035,588926922013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','stevenstpierre','stevenstpierre@hotmail.com','Steven St-Pierre','2-5740 rue Corneille','Brossard','QC','CANADA','J4Z 0K5','(438) 881-1814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:34:12',0,NULL,3,1,2,1,'\\ ','stevenstpierre'),(5036,536048480003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','shbailey620527','shbailey@mweb.co.za','Sidney Bailey','113 Victoria Street, Windsor Park<br>Kraaifontein','Cape Town','Western Cape','SOUTH AFRICA','7570','0845552552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:36:09',0,NULL,3,1,3,1,'RA117736619CN\r ','shbailey620527\rBALO007'),(5037,541750536004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','lawrence9644','larryyanney@comcast.net','lawrence yanney','9414 ridgely ave','baltimore','MD','UNITED STATES','21234-3317','(410) 241-2776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 14:36:13',0,NULL,3,1,1,1,'\\ ','lawrence9644'),(5038,541753788004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','sproggus','eoin.d.griffin@gmail.com','Eoin Griffin','39, Elm Park,<br>Renmore','Galway','Galway','IRELAND','NA','0876356149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:48:32',0,NULL,3,1,3,1,'RA117736636CN\r ','sproggus\rWLAP002\r旧的'),(5039,797548515012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',13.99,'eastar4uk','raksone','drrashidshahidi@gmail.com','Rashid Shahidi','16 Cato Street<br>Sidmouth House','London','London','UNITED KINGDOM','W1H 5HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 15:11:58',0,NULL,3,1,3,1,'RA117736755CN\r ','raksone\rOTGR002'),(5040,797550875012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ernawati_hidayat','ernawati.hidayat@gmail.com','ERNAWATI H. SUYATA','MetroTV Biro Yogyakarta<br>Jalan Cendana 16 Semaki Gede','Yogyakarta','','INDONESIA','55166','628157937881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:25:33',0,NULL,3,1,2,1,'\\ ','ernawati_hidayat'),(5041,588941077013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','ti-po','ropika80@gmail.com','TI-PO KFT','Fiumei út 25<br>3.emelet 5','Budapest','Budapest','HUNGARY','1081','+36205190901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:31:32',0,NULL,3,1,2,1,'\\ ','ti-po'),(5042,797556158012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','christoph.mayrhofer','436601111880@drei.at','Christoph Mayrhofer','Michael-Rottmayrstr. 9','Oberndorf','','AUSTRIA','5110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:33:25',0,NULL,3,1,2,1,'\\ ','christoph.mayrhofer'),(5043,797573489012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','helderhguia','hguia@msn.com','helder guia','rua maria jose guia lote 18 5ºD','lisboa','lisboa','PORTUGAL','1750-358','916707963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 16:16:03',0,NULL,3,1,2,1,'\\ ','helderhguia'),(5044,718229768011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','zazzer12','fran.liesch@sbcglobal.net','Francis Liesch','604 W Wisconsin Ave','Kaukauna','WI','UNITED STATES','54130-1934','(920) 766-9260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 16:16:41',0,NULL,3,1,1,1,'\\ ','zazzer12'),(5045,718240744011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','mike814u','mlc9752@hughes.net','michael carter','727 S Farm Road 89','springfield','MO','UNITED STATES','65802-8714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 16:47:35',0,NULL,3,1,1,1,NULL,'mike814u\\'),(5046,718262274011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',119.99,'eastar4','sg1junkie2','foxmcb@msn.com','Kenneth Baldwin','44853 Overland Trl','Elizabeth','CO','UNITED STATES','80107','(303) 646-4746','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 17:42:19',0,NULL,3,1,1,1,'\\ ','sg1junkie2'),(5047,718278703011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','martinwhxx','martinwhxx@hotmail.com','Martin Wren-Hilton','28 Arwenack Avenue','Falmouth','Cornwall','UNITED KINGDOM','TR11 3JW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 18:19:34',0,NULL,3,1,3,1,'RA117736640CN\r ','martinwhxx\rUDAP001'),(5048,797629258012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',15.95,'eastar4','ltolosa','ltolosa@pazfroimovich.cl','Sebastian Aising R.','Avda. Apoquindo 6275 Of 107<br>Las Condes','Santiago','Region Metropolitana','CHILE','7570014','562 2020956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 18:26:20',0,NULL,3,1,2,1,'\\ ','ltolosa'),(5049,718285705011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','x_wasted_time_x','i_am.killing_time@yahoo.com','jim ketchum','1211 bradd st','sumter','SC','UNITED STATES','29150-7811','(803) 778-0380','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 18:38:04',0,NULL,3,1,1,1,'\\ ','x_wasted_time_x'),(5050,718291635011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','atreeinmygarden','thegreenprincess@ntlworld.com','Andrew Green','9 Denbury Avenue<br>Stockton Heath','Warrington','Cheshire','UNITED KINGDOM','WA4 2BL','01925261932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 18:51:07',0,NULL,3,1,3,1,'RA117736931CN\r ','atreeinmygarden\rOMHJ001'),(5051,718293435011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',2,'OTHP004',39.98,'eastar4','austinwill','waustin0@gmail.com','William Austin','407 Eagle Pond Dr','Winter Haven','FL','UNITED STATES','33884-1315','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 18:55:42',0,NULL,3,1,1,1,'\\ ','austinwill'),(5052,797642525012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','nscrespo09','nscrespo@gmail.com','nickolas de souza crespo','AV PRESIDENTE VARGAS, 400 <br>PECUARIA','campos dos goytacazes','RIO DE JANEIRO','BRAZIL','28055293','55 22 92210494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 18:56:09',0,NULL,3,1,2,1,'\\ ','nscrespo09'),(5053,795382019012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','felixvalverde','frvm_tru@hotmail.com','Felix R. Valverde Merino','Jiron Orbegoso 312<br>Trujillo - Cercado','Trujillo','La Libertad','PERU','Trujillo 01','(51)949339452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 19:18:17',0,NULL,3,1,2,1,'\\ ','felixvalverde'),(5054,718311179011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','hsein312','ktef_druze@hotmail.com','hsein tafish','P.O.BOX 507 GALIL ALION<br>KFAR BAIT GAN 24990','GALIL ALION','','ISRAEL','24990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 19:46:24',0,NULL,3,1,3,1,'RA117773673CN\r ','hsein312\rHSPL015'),(5055,797674427012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','dianez171','dianezoel@yahoo.co.uk','diane zoel','88, conduit way, stonebridge','london','London','UNITED KINGDOM','NW10 0SH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 20:05:03',0,NULL,3,1,2,1,'\\ ','dianez171'),(5056,718325525011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','seashoreaudio_com','slperry1988@yahoo.com','Sean Perry','21 Illinois St<br>Unit 503','Worcester','MA','UNITED STATES','01610-1682','(617) 688-1322','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 20:12:58',0,NULL,3,1,1,1,'\\ ','seashoreaudio_com'),(5057,797694926012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','marquinez61','marquinez61@yahoo.ca','Jose Miguel Marquinez Fleitas','1060 Caven St<br>apt 214','Mississauga','ON','CANADA','L5G4J5','(905) 278-8923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 20:55:10',0,NULL,3,1,2,1,'\\ ','marquinez61'),(5058,718354840011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','pontios78','pontios1978@mycosmos.gr','GEORGIOS KELEMOURIDIS','THRAKIS 4','NAOUSSA','IMATHIA','GREECE','59200','+306977751702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 21:37:32',0,NULL,3,1,2,1,'\\ ','pontios78'),(5059,589054467013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','pupik_remenar','pupik@pupik.sk','Daniel Remenar','Holleho 10','Nove Mesto nad Vahom','SK','SLOVAK REPUBLIC','91501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 22:21:50',0,NULL,3,1,3,1,'RA117725103CN\r ','pupik_remenar\rMOLO009'),(5060,718379829011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','danrazz','danrazz18@gmail.com','John Rasmussen','509 Dorothy Pl','Brick','NJ','UNITED STATES','08723-8042','(732) 447-5986','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 22:57:32',0,NULL,3,1,1,1,NULL,'danrazz\\'),(5061,797745296012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','jnchesebrough','jchesebrough@live.ca','John Chesebrough','89 kensington ave s','hamilton','ON','CANADA','l8m 3h1','(905) 545-7217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 23:19:50',0,NULL,3,1,3,1,'RA117736830CN\r ','jnchesebrough\rHSPL014'),(5062,797760753012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','xanax11315','ccorey84@yahoo.com','Christopher Corey','372 Gertrude St<br>Apt 1','Syracuse','NY','UNITED STATES','13203-2910','(315) 560-9173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 00:21:43',0,NULL,3,1,1,1,'\\ ','xanax11315'),(5063,718400127011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','tonyskj','tonyskj@yahoo.com','Anthony Skjellum','2926 Smyer Rd','Vestavia Hills','AL','UNITED STATES','35216','(205) 870-8324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 00:23:59',0,NULL,3,1,1,1,NULL,'tonyskj\\'),(5064,589082752013,230430138806,'New Logitech Harmony 890 LCD Remote Control US +RF',1,'RCLO003',148.99,'eastar4','no_wake_zone','tmabe@me.com','Tony Mabe','2112 Cook School Rd','Pilot Mountain','NC','UNITED STATES','27041-7269','(336) 351-3499','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 00:53:41',0,NULL,3,0,1,1,'、 ','no_wake_zone'),(5065,797778888012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','krow3389','kimmy082704@yahoo.com','Kimeisha Rowe','3806 Arbutus Ave','Gwynn Oak','MD','UNITED STATES','21207-6354','(410) 484-2836','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 01:42:51',0,NULL,3,1,1,1,'\\ ','krow3389'),(5066,0,230630353379,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',121.99,'eastar4','wnatolijr','wnatoli@verizon.net','Will Natoli','403 Fulton St','Middlesex','NJ','UNITED STATES','08846','(732) 803-2701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 01:51:36',0,NULL,3,1,1,1,'\\ ','wnatolijr'),(5067,718421834011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','yiam_20','yiam20@yahoo.com','william enriquez','7322 21st St<br>Apt 15','westminster','CA','UNITED STATES','92683','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 02:06:03',0,NULL,3,1,1,1,'\\ ','yiam_20'),(5068,536228213003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',21.99,'cnfaner','one_name','wannaberichr2002@yahoo.com','Lyle Griffith','18 Azalea Dr','Smithfield','NC','UNITED STATES','27577','(919) 320-3191','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-05 02:49:23',0,NULL,3,1,1,1,NULL,'one_name\\'),(5069,718431024011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','azmansaad','azman_saad@hotmail.com','Azman Mohamed Saad','7 Jalan Wawasan 3/7<br>Pusat Bandar Puchong','Puchong','Selangor','MALAYSIA','47100','0193300362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 02:50:18',0,NULL,3,1,3,1,'RA117725077CN\r ','azmansaad\rGLSG001'),(5070,718437108011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','kenc0628','wai6281977@yahoo.com','Ken Chan','10 Paddock Ct','Edison','NJ','UNITED STATES','08820-2985','(732) 322-9222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 03:19:35',0,NULL,3,1,1,1,NULL,'kenc0628\\'),(5071,796966594012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.9,'eastar4','blackandgold2004','supermansupercat@yahoo.com','clyde dear','114 strong rd','proctor','AR','UNITED STATES','72376-9480','(901) 262-4450','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 04:15:10',0,NULL,3,1,1,1,'\\ ','blackandgold2004'),(5072,589114456013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','rmirakyan','anna_mirakyan@yahoo.com','Anna Mirakyan','Leningradyan str. 31/2, apt.6','Yerevan','Armenia','ARMENIA','0031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 04:32:03',0,NULL,3,1,3,1,'RA117725620CN\r','rmirakyan\rHSNO019'),(5073,718453991011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','yyoo6535','younghanyoo@gmail.com','young han yoo','32 Vanity Cr.','Richmond Hill','ON','CANADA','l4b4e5','(416) 892-8197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 04:59:14',0,NULL,3,1,2,1,'\\ ','yyoo6535'),(5074,589121956013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',20.98,'eastar4','davidmjw','davidmjwiebe@gmail.com','David Wiebe','6524 Whitaker Ave','Lake Balboa','CA','UNITED STATES','91406','(818) 988-3229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 05:27:59',0,NULL,3,1,1,1,'\\ ','davidmjw'),(5075,588998344013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','emre9999','ekutlu99@gmail.com','EMRE KUTLU','Ankara caddesi, No:147 Avukat Ramazan Kutlu Burosu<br>TURKEY/ANKARA/Sereflıkochısar','ANKARA/ Sereflıkochısar','','TURKEY','06950','03126871364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 06:20:01',0,NULL,3,1,2,1,'\\ ','emre9999'),(5076,715359415011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','omarpontiac','gael_uziel@yahoo.com','omar gomez','955 E State St<br>Lot D9','sycamore','IL','UNITED STATES','60178-9573','(224) 659-5995','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 06:30:21',0,NULL,3,1,1,1,'\\ ','omarpontiac'),(5077,589129437013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','jcobbster','jcobb@ix.netcom.com','Jason Cobb','10109 Arches Way','Elk Grove','CA','UNITED STATES','95757-4356','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 06:36:22',0,NULL,3,1,1,1,'\\ ','jcobbster'),(5078,797868925012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','derekr3791','freedomhealth@me.com','Derek Robert','c/o Staddon House','North Tawton','Devon','UNITED KINGDOM','EX20 2DP','08448004975','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 08:37:22',0,NULL,3,1,3,1,'RA117736857CN\r ','derekr3791\rHSPL011\r英标'),(5079,797868952012,220785302187,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',35.5,'eastar4uk','2768julia','juliabromfield@yahoo.co.uk','julia bromfield','114 sheering lower road','sawbridgeworth','Hertfordshire','UNITED KINGDOM','cm21 9lh','01279724540','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 08:38:10',0,NULL,3,1,3,1,'RA117725063CN\r ','2768julia\rMOLO001'),(5080,797869963012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','derekr3791','freedomhealth@me.com','Derek Robert','Postbus 93','Stolwijk','','NETHERLANDS','2820 AB','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-05 08:40:55',0,NULL,3,1,2,1,'\\ ','derekr3791\r欧标'),(5081,797879712012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','raafat91','arabwiddaattitude@hotmail.com','Raafat Akkad','61 Banim Street<br>Hammersmith','London','London','UNITED KINGDOM','w6 0dn','02087485098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 09:08:20',0,NULL,3,1,2,1,'\\ ','raafat91'),(5082,718516516011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','copierserv','kalata76@gmail.com','Kaloyan Atanasov','jk Drujba 2 bl 413 vh b ap 52 et 7','Sofia','','BULGARIA','1582','35929739395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 09:32:14',0,NULL,3,1,2,1,'\\ ','copierserv\r欧标\r'),(5083,797892752012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','ruedufrout','appuyezsurlebouton@gmail.com','MEVELLEC Gilles','LE SAINT TUGDUAL<br>6, place Pierre Briand','LANDUDAL','Bretagne','FRANCE','29512','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 09:45:01',0,NULL,3,1,2,1,'\\ ','ruedufrout'),(5084,589189781013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','wibblert','abebooks@mrfroon.co.uk','Christopher Rands','10 Kingsway West<br>Newton','Chester','Cheshire','UNITED KINGDOM','CH2 2LA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 11:14:50',0,NULL,3,1,2,1,'\\ ','wibblert'),(5085,589190844013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.58,'eastar4','yutarosuzuki','yutaro1008yutaro1008@yahoo.co.jp','Yutaro Suzuki','Room #807 605 Nippa chou kouhoku ku','Yokohama city','Kanagawa','JAPAN','223-0057','045-548-0722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 11:18:22',0,NULL,3,1,2,1,'\\ ','yutarosuzuki'),(5086,797978684012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','gael420','moirah42@hotmail.com','moira hairsine','Byre End<br>Burgh by sannds','carlisle','cumbria','UNITED KINGDOM','CA5 6AW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 13:14:51',0,NULL,3,1,2,1,'\\ ','gael420'),(5087,797841102012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','odklein121','klein121@walla.co.il','klein eliezer','P.O.B 1032<br>Tel. 972-4-8758705','Kiryat Bialik','Israel','ISRAEL','27110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 13:24:37',0,NULL,3,1,2,1,'\\ ','odklein121'),(5088,797986912012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','nancy0374','mike_nan@xplornet.com','Nancy Provoost','1009 Hazen Road','Walsingham','ON','CANADA','N0E1X0','(519) 586-8171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 13:33:55',0,NULL,3,1,3,1,'RA117736769CN\r ','nancy0374\rOTSO001'),(5089,718621565011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','larsbarl','barlindh@gmail.com','Lars Barlindhaug','Solligrenda 36','Oslo','Oslo','NORWAY','0491','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:08:39',0,NULL,3,1,2,1,'\\ ','larsbarl'),(5090,798004504012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','bigpapa162','m.oudenaarden@orange.nl','M Oudenaarden','Pampasgras 47','Spijkenisse','','NETHERLANDS','3206RD','+31646485430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:11:18',0,NULL,3,1,2,1,'\\ ','bigpapa162'),(5091,718624523011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','fuffa1992','aberboichris@hotmail.co.uk','christopher perrett','the manse<br>ty bryn hill','abertillery','Blaenau Gwent','UNITED KINGDOM','np131rr','01495214548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:14:11',0,NULL,3,1,2,1,'\\ ','fuffa1992\r英标'),(5092,798020800012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','hopar9090','n-gage@mail.am','Ashot Kirakosyan','Minas Avetisyan 1<br>51,21','Yerevan','Yerevan','ARMENIA','0069','+37455244468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:44:26',0,NULL,3,1,2,1,'\\ ','hopar9090'),(5093,798022562012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.9,'eastar4','probik93','kiki-kor@mail.ru','Vitaly Kikin','Vostochniy m-r 23-42','Tuchkovo','Moscow state, Tuchkovo','RUSSIAN FEDERATION','143130','+79629940124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:48:38',0,NULL,3,1,2,1,'\\ ','probik93\r欧标'),(5094,589253793013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','schizkoske','sandrasch@sympatico.ca','sandra schizkoske','360 lakeview drive','waterloo','ON','CANADA','N2L4Z6','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'schizkoske'),(5095,589251822013,230395559651,'2.1 Acer AS aspire D250 Bluetooth Module EDR+cable',1,'BTAC2107',12.4,'eastar4','javyhurtado','javi.vva@gmail.com','José Ramón Hurtado Corredera','C/Teide, 15','Villanueva de la Serena','Extremadura','SPAIN','06700','924844301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:51:35',0,NULL,3,1,2,1,'\\ ','javyhurtado\rAcer 4pin 1.25 15cm '),(5096,589256325013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','spulletjeskoperrrr','ilja.spierings@gmail.com','Ilja Spierings','Willembarendszstraat 114','Utrecht','','NETHERLANDS','3572PR','0610939096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:57:18',0,NULL,3,1,2,1,'\\ ','spulletjeskoperrrr'),(5097,589271582013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','asahi_kicks','nikesnk@yahoo.com','SANGJIN OH','Danch 28-4-426,2-Choume,Takashimadaira','Itabashi-ku','Tokyo','JAPAN','1750082','(080)3367-0404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 15:36:53',0,NULL,3,1,2,1,'\\ ','asahi_kicks'),(5098,798057695012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','joe44407','joe444@orange.fr','Jonathan CHARDON','533 route de Bégut','Peaugres','Rhône-Alpes','FRANCE','07340','04.75.34.88.52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 15:48:24',0,NULL,3,1,2,1,'\\ ','joe44407'),(5099,718688451011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','dany24592','dani24592@gmail.com','Daniel Cohen','10/2 Pier Kenig st.','Holon','','ISRAEL','58316','+972776626605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 16:16:26',0,NULL,3,1,2,1,'\\ ','dany24592'),(5100,798091050012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','zassy_girl','cjjbet@hotmail.com','Cheryl J Jenkins','12 Betworthy Coaley','Dursley','Gloucestershire','UNITED KINGDOM','GL115EF','01453890779','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 16:38:31',0,NULL,3,1,3,1,'RA117736772CN\r ','zassy_girl\rHSMO018\r英标\r'),(5101,542096440004,140516496368,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',82,'cnfaner','bthworld088','bthworld088x@gmx.com','Sahar Talat','36 FINCHLEY CRES','BRAMPTON','ON','CANADA','L6T3P6','(416) 828-6376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 16:43:25',0,NULL,3,1,3,1,'RA117736503CN\r ','bthworld088\rTRTS001*10'),(5102,718699612011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','crow6318','babybluebird@live.co.uk','Christine Rowley','21 Clement Street','Nuneaton','Warwickshire','UNITED KINGDOM','CV11 5PH','07772222267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 16:46:12',0,NULL,3,1,3,1,'RA117736653CN\r ','crow6318\rOMHJ001'),(5103,588991666013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.58,'eastar4','dmitrybyhovski','dsbyhovski@gmail.com','Dmitry Byhovski','D. Serdicha 7-83','Minsk','BR','BELARUS','220082','+375-29-755-11-96','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 16:51:43',0,NULL,3,1,2,1,'\\ ','dmitrybyhovski\r欧标'),(5104,797827483012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','fullmoonbad','fullmoonbad@aol.com','Brad TABIT','1 rue Leo Trouilhet<br>4Etg Droit','LYON','Rhône-Alpes','FRANCE','69008','0660933038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 17:11:13',0,NULL,3,1,2,1,'\\ ','fullmoonbad'),(5105,798119630012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',3,'BALO005',21.3,'eastar4','jarmasson123','lucade.j@laposte.net','luc jarmasson','les toubeaux impasse des alpilles','eyguieres','Provence-Alpes-Côte d\'Azur','FRANCE','13430','0490598520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 17:33:54',0,NULL,3,1,2,1,'\\ ','jarmasson123'),(5106,718355050011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','hagshur','moshe@matrix.co.il','Moshe Hagshur','Heshvan 14/1','Modiin','Israel','ISRAEL','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 17:49:21',0,NULL,3,1,2,1,'\\ ','hagshur'),(5107,798174626012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','electricalstrawberries','rgreytak@gmail.com','Ryan Greytak','500 W University Pkwy<br>Apt 4K1','Baltimore','MD','UNITED STATES','21210-3200','(352) 256-8228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 18:14:58',0,NULL,3,1,1,1,'\\ ','electricalstrawberries'),(5108,718802494011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','zurabxx','zurabx@hotmail.com','Zurab Nukayev','26, rue DUCOURNEAU','AGEN','Aquitaine','FRANCE','47000','06.30.17.91.41.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 18:41:24',0,NULL,3,1,2,1,'\\ ','zurabxx\racer 8pin1.00 8cm'),(5109,718813716011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','anibal.martins','anibalmartins@yahoo.com.br','Anibal Martins','SQN 105 bloco J apto 505','Brasilia','Distrito Federal','BRAZIL','70734100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-05 18:55:19',0,NULL,3,1,3,1,'RA117736582CN\r ','anibal.martins\rOTSO001'),(5110,536501342003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',34.99,'cnfaner','popov982','optimizerapp@mtu-net.ru','Andrey Popov','Perervinskiy bulvar, Dom 22, Korpus 2<br>Kvartira 27','Moscow','Moscow','RUSSIAN FEDERATION','109469','+7(962) 960-4367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 19:21:06',0,NULL,3,1,3,1,'RA117736565CN\r ','popov982\rWWSI005+ANCN001'),(5111,589401794013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',2,'HSPL005',27.16,'eastar4','wmcneal99','geanboy99@yahoo.com','Warren G McNeal','1000 N 64th St','Philadelphia','PA','UNITED STATES','19151-3316','(215) 878-8303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 19:31:17',0,NULL,3,1,1,1,'\\ ','wmcneal99'),(5112,718861659011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','krasniy2010','i_kras@yahoo.com','Krasniy Ilya','Bolshaya Tatarskaya str. 30 fl.48','Moscow','Moscow Region','RUSSIAN FEDERATION','115184','+7(495)9512041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 19:54:14',0,NULL,3,1,3,1,'RA117736579CN\r ','krasniy2010\rUDAP001'),(5113,798263529012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',15.65,'eastar4uk','joshua130158','lessmith-13@hotmail.co.uk','leslie smith','centurion installations ltd.<br>45-47 church rd,lawrence hill','bristol','Avon','UNITED KINGDOM','bs5 9jj','01179551451','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 19:55:01',0,NULL,3,1,3,1,'RA117736596CN\r ','joshua130158\rHSPL010\r英标'),(5114,718864376011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','rangtex','trog_1@sbcglobal.net','Travis L. Rogers','610 Wayland Rd','Ranger','TX','UNITED STATES','76470','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 19:57:18',0,NULL,3,1,1,1,'\\ ','rangtex\racer 6pin1.25 23cm'),(5115,718885030011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','anarchy1515','anarchy15@hotmail.com','Mark Barrett','49 Ulalia Road','Newquay','Cornwall','UNITED KINGDOM','tr7 2pz','00000000000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 20:28:36',0,NULL,3,1,3,1,'RA117736605CN\r ','anarchy1515\rOTSO001'),(5116,718889987011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','reddekopp2005','gcred@sasktel.net','Gary Reddekopp','111 Skeena Cres','Saskatoon','SK','CANADA','S7K 4G6','(306) 382-0292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 20:38:27',0,NULL,3,1,2,1,'\\ ','reddekopp2005'),(5117,542231816004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'cnfaner','korogui','alexandrekorogui@hotmail.com','Alexandre Korogui','Av. Cerro Azul, 968. Bairro Zona 2.','Maringá','PR','BRAZIL','87010-000','(46)84127015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 21:08:28',0,NULL,3,1,3,1,'RA117736525CN\r ','korogui\rOTSO002'),(5118,589450727013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','vg2290','violagirl2290@yahoo.com','Sarine Thomas','2430 Arbor Ct','Irving','TX','UNITED STATES','75060-6568','(469) 438-6824','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-05 22:14:49',0,NULL,3,1,1,1,NULL,'vg2290\\'),(5119,542252983004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','clarke171a','jamestoh@myivy.com','Lim Wee Cheong','171A Edgedale Plains<br>#17-430','Singapore','Singapore','SINGAPORE','821171','(065) 900-1984 ext.: 6','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 22:26:15',0,NULL,3,1,3,1,'RA117736945CN\r ','clarke171a\rOTCR001'),(5120,798360201012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',2,'BTDE2101',24.8,'eastar4','oowinkyoo','oowinkyoo@charter.net','Christopher Oicles','1220 N Fair Oaks Ave<br>Apt 4305','Sunnyvale','CA','UNITED STATES','94089-1766','(408) 910-2441','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 23:10:58',0,NULL,3,1,1,1,NULL,'oowinkyoo\\'),(5121,718957168011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','7191catherinerich','rwoellmer@comcast.net','Richard Woellmer','7191 Catherine Dr','Harrisburg','PA','UNITED STATES','17112','(717) 443-4233','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 23:36:26',0,NULL,3,1,4,1,'YW865717393CN ','7191catherinerich'),(5122,798369095012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','digiok','xli@hotmail.com','Xueping Li','1238 Evergreen Ave.','Des Plaines','IL','UNITED STATES','60016','(517) 303-1014','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 23:39:05',0,NULL,3,1,1,1,'\\ ','digiok'),(5123,718965239011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','nicholascope','nickcope@yahoo.com','Nicholas Cope','27 Old Gloucester Street','London','London','UNITED KINGDOM','WC1N 3AF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 00:05:47',0,NULL,3,1,2,1,'\\ ','nicholascope'),(5124,589455598013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','ahojman','alejandro.hojman@csiclosures.com','Alejandro Hojman','Saravi 2850 - UF37','Pilar','Buenos Aires','ARGENTINA','B1629NWN','541140069140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 00:14:32',0,NULL,3,0,3,1,'RA117736790CN\r ','ahojman\rOTRA003'),(5125,798389733012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','o2bnobx','alawrence4@cox.net','Alan Lawrence','3259 Pony Ridge Way','Oakton','VA','UNITED STATES','22124-2352','(703) 620-0282','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 00:44:04',0,NULL,3,1,1,1,'\\ ','o2bnobx'),(5126,798391441012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×4',235.99,'eastar4','alexis10990','angelafarmer@hotmail.com','Angela Farmer','88083 3rd St','Veneta','OR','UNITED STATES','97487-8765','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 00:51:42',0,NULL,3,0,6,1,'EEE520583525CN  ','alexis10990'),(5127,718979516011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','h.guzella','h.guzella@gmail.com','Henrique Guzella','Av. Queiros Filho 442<br>Pq. Industriário','Santo André','São Paulo','BRAZIL','09110-260','(55 11) 75140010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 00:58:56',0,NULL,3,1,2,1,'\\ ','h.guzella'),(5128,542284362004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',95.95,'cnfaner','paczo_2004','paczek.grzegorz@gmail.com','Gregory Paczek','38 SORAUREN AVE','Toronto','ON','CANADA','M6R 2C7','(416) 666-9925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 01:01:26',0,NULL,3,1,3,1,'RA117725457CN\r ','paczo_2004'),(5129,798399489012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','rogeriogalinari','rogerio.galinari@gmail.com','ROGÉRIO ALEXANDRE GALINARI','RUA HERCULANO DE FREITAS, 73 - APTO 64<br>BELA VISTA','SÃO PAULO','SP','BRAZIL','01308-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 01:10:57',0,NULL,3,1,3,1,'RA117736809CN\r ','rogeriogalinari\rWWOT003'),(5130,542288219004,140515700891,'GENUINE Plantronics Voyager 510 Bluetooth Headset trac#',1,'HSPL010',23.8,'cnfaner','t4fnbe','fnbe@sasktel.net','Lester  Henry','35 Burgess Street','Regina','SK','CANADA','S4X 1J5','(306) 924-2109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 01:17:40',0,NULL,3,1,3,1,'RA117736715CN\r ','t4fnbe\rHSPL010'),(5131,719000130011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','jmsdmrt','jmsmrt@clearwire.net','James Merritt','1964 N Star Ln','Jacksonville','FL','UNITED STATES','32246-0507','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 02:06:09',0,NULL,3,1,1,1,'\\ ','jmsdmrt'),(5132,719005076011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.75,'eastar4','mspolto','marcio.polto@bakernet.com','Marcio Polto','Avenida Dr. Chucri Zaidan, 920<br>7º andar, Vila Cordeiro','São Paulo','São Paulo','BRAZIL','04583-904','5511 3048-6923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 02:26:04',0,NULL,3,1,3,1,'RA117736724CN\r ','mspolto\rMOSA001'),(5133,589524348013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','xelaice','lxndr_angeles@yahoo.com','Alex Angeles','1818 Lakeview Rd','Clearwater','FL','UNITED STATES','33764-3662','(727) 403-3524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 02:28:19',0,NULL,3,1,1,1,'\\ ','xelaice'),(5134,798428241012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.9,'eastar4','ishannagar89','ishan_nagar@hotmail.com','Ishan Nagar','279 Secaucus Rd','Secaucus','NJ','UNITED STATES','07094-2117','(201) 800-5544','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 02:43:14',0,NULL,3,1,1,1,'\\ ','ishannagar89'),(5135,798434209012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','mikaxoxo','ellery@fashioncollective.net.au','kendall Casey','25 Palm Lily Cres','Bangalow','New South Wales','AUSTRALIA','2479','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 02:59:04',0,NULL,3,1,3,1,'RA117736786CN\r ','mikaxoxo\rOTSO001'),(5136,798436910012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','pkl728','salsa728@yahoo.com','Patrick Lind','4302 Chesapeake Dr<br>Apt 3C','Aurora','IL','UNITED STATES','60504-7125','(317) 709-0543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 03:08:05',0,NULL,3,1,1,1,'\\ ','pkl728'),(5137,719014942011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','stevenbjah2010','stevenbjah@gmail.com','steven Ronaldo','2760 nw cannon way','Portland','OR','UNITED STATES','97229-4093','(503) 989-4123','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 03:09:02',0,NULL,3,1,1,1,NULL,'stevenbjah2010\\'),(5138,589540540013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','johannawu','johannawu@gmail.com','Johanna Wu','722 Bexley Road','West Lafayette','IN','UNITED STATES','47906','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-06 04:03:29',0,NULL,3,1,1,1,'\\ ','johannawu'),(5139,589542828013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.4,'eastar4','j2tha0e','joel.rabe@gmail.com','joel rabe','292 Jones Rd','uvalda','GA','UNITED STATES','30473-3511','(916) 508-9703','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 04:13:33',0,NULL,3,1,1,1,'\\ ','j2tha0e'),(5140,589543670013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 04:27:52',0,NULL,3,1,2,1,'\\ ','dcwholesale'),(5141,589197039013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','mishijacob','michellejacob@live.com.au','Eileen Jacob','Unit 5/51-53 Nelson Street','Fairfield','New South Wales','AUSTRALIA','2165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 04:41:10',0,NULL,3,1,3,1,'RA117725695CN\r ','mishijacob\r澳标\rHSNO019'),(5142,589547329013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','shavoyah123','watchout4thatfox@yahoo.com','SHAVOYAH FOX','1016 Haven Hollow Way','Durham','NC','UNITED STATES','27713','(910) 364-3037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 04:49:58',0,NULL,3,1,1,1,'\\ ','shavoyah123'),(5143,589548730013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',2,'BTHP2107',24.8,'eastar4','xxx-753951','dsidlo@ramifyinc.com','David Sidlo','1563 Lincoln Ave','Alameda','CA','UNITED STATES','94501-2446','(510) 864-0431','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 05:00:38',0,NULL,3,1,1,1,'\\ ','xxx-753951\rHP 8pin 1.0 23cm '),(5144,719043594011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',157,'eastar4','federalgc','mark@nmprint.com.au','Mark Delmenico','40 Ebden street, Ainslie','Canberra','Australian Capital Territory','AUSTRALIA','2602','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-06 05:34:47',0,NULL,3,0,3,1,'RA117725085CN\r ','federalgc\rOTSO004*2'),(5145,589295315013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',16.99,'eastar4','dimonix77','dmitry@avdeev.net','Dmitry Avdeev','Filevskij Bulvar<br>dom 23, kv 161','Moscow','','RUSSIAN FEDERATION','121601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 06:18:21',0,NULL,3,1,2,1,'\\ ','dimonix77'),(5146,716018327011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',68.95,'eastar4','pl550','lcd993@hush.com','Bernd Winkens','Deichstraße 2','Heinsberg','','GERMANY','52525','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 07:22:05',0,NULL,3,1,3,1,'RA117736675CN\r ','pl550\rHSSE006\r欧标'),(5147,719066998011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',2,'HSJA005',35.98,'eastar4','amperel2011','amperel1@017.net.il','Amperel ltd. (EB)','Shderot Jerusalem 168 Street','Holon','Israel','ISRAEL','58829','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 07:47:18',0,NULL,3,1,3,1,'RA117736843CN\r ','amperel2011\rHSJA005'),(5148,589570885013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',5,'CASS001',43.5,'eastar4','has.2009','mete@eosbil.com.tr ','METE GURCAN','PERPA B BLOK KAT 6 NO 653','ISTANBUL','','TURKEY','34384','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 07:57:02',0,NULL,3,1,3,1,'RA117736415CN\r ','has.2009\rCASS001\rCAB-SS-2626'),(5149,589573030013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','roter_*','bernd.ottlik@web.de','Ottlik, Bernd','Sinnersdorfer Feld 128','Pulheim','','GERMANY','50259','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:11:31',0,NULL,3,1,2,1,'\\ ','roter_*'),(5150,536665147003,130460438605,'New Plantronics Explorer 340 BLUETOOTH HEADSET track#',1,'HSPL007',19.9,'cnfaner','australiasteve','stevejackson@stevejackson.com.au','Steve Jackson','532 Brighton Road','Brighton','South Australia','AUSTRALIA','5048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:26:12',0,NULL,5,1,18,1,NULL,'australiasteve\r澳标\rHSPL007\r由于无货已退款'),(5151,589576516013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','zmrleealex','izmirleealex@hotmail.com','Emre Akoglu','kılınc is merkezi kat:2 no:226<br>urla','Izmir','IL','TURKEY','35430','+905553439101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:45:27',0,NULL,3,1,3,1,'RA117736976CN\r ','zmrleealex\rOTES001'),(5152,589579700013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.48,'eastar4','ashotavetisyan','syunik@gmail.com','Ashot Avetisyan','Erkatugainer 9 3','Kapan','Syunik','ARMENIA','3301','(0374)94771108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:55:39',0,NULL,3,1,2,1,'\\ ','ashotavetisyan'),(5153,719081273011,320610174303,'New HuaWei EM660 3G WWAN Mini PCI-E Card CDMA EV-DO Mod',1,'WWHU001',46.9,'eastar4','joeblack385','hrvoje.katic@unicreditgroup.zaba.hr','Hrvoje Katic','Zvonimira Rogoza 3','Zagreb','','CROATIA','10000','385-1-6111-782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:59:13',0,NULL,5,0,18,0,NULL,'joeblack385\rWWHU001\r客户要撤单 已经退款'),(5154,719086075011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','djpav','pavlos@che.utexas.edu','Pavlos Tsiartas','2130 42nd St','Astoria','NY','UNITED STATES','11105','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 09:12:09',0,NULL,3,1,1,1,NULL,'djpav\\'),(5155,798256712012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',5,'HSSE005',69.5,'eastar4uk','bogunovic46','zulee46@yahoo.com','Milos Djuric','Balkanska 12','Belgrade','Serbia','SERBIA','11000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 09:12:33',0,NULL,3,1,3,1,'RA117736485CN\r ','bogunovic46\rHSSE005\r欧标'),(5156,798517054012,220697786937,'New 3.0 Bluetooth BCM2070 Module+cable HP probook 4321S',1,'BTHP3002',19.99,'eastar4','saykoshey','frylord@gmail.com','Mehmet Aksakal','Altstraat 20','UDEN','','NETHERLANDS','5402AK','0646067155','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'saykoshey'),(5157,719092540011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 09:38:20',0,NULL,3,1,11,1,NULL,'dorit710\rANYA001'),(5158,536676778003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','helmuts1','hs@sevenheck.de','Helmut Sevenheck','Ströer AG  IDC<br>An der Wachsfabrik 23','Köln','','GERMANY','50996','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 09:41:13',0,NULL,3,1,3,1,'RA117736477CN\r ','helmuts1\rWWOT003'),(5159,589605188013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','firstprotos','taliotisp@aol.com','Prodromos Taliotis','PO. BOX 24118<br>Nicosia (tel 357-99-352449)','Nicosia','Nicosia','CYPRUS','1701','0035799352449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 11:18:08',0,NULL,3,1,2,1,'\\ ','firstprotos'),(5160,589615402013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',16.99,'eastar4','hybird25','info@pc-doktor-bonn.de','Marco Wolff','Siemensstraße 227','Bonn','','GERMANY','53121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 12:06:02',0,NULL,3,1,2,1,'\\ ','hybird25'),(5161,719133640011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','erizoperez','hugoadrian@telefonica.net','Hugo Arnas Sanz','Alfonso Solans 3 casa 3 3b','Zaragoza','Aragón','SPAIN','50014','652088716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 12:09:38',0,NULL,3,1,2,1,'\\ ','erizoperez'),(5162,719143532011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',119.99,'eastar4','jacallphase1','jcsallphase@bellsouth.net','Jac Coker','505 Moultrie Wells Rd','Saint Augustine','FL','UNITED STATES','32086-5449','(904) 794-0090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 12:41:34',0,NULL,3,1,1,1,'\\ ','jacallphase1'),(5163,719166068011,320475111586,'2.0 New ASUS Bluetooth Module +cable for V1S E99 F8 N80',1,'BTHU2002',12.5,'eastar4','njgura87','nathan.gura@live.com','Nathan Gura','1921 N Sedgwick St<br>Apt 1R','Chicago','IL','UNITED STATES','60614-5434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 13:55:07',0,NULL,3,1,1,1,NULL,'njgura87\r华硕10pin 0.8 10cm \\'),(5164,589645819013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','w-factor','ajelveh@physnet.uni-hamburg.de','Ali Jelveh protonet','Grosse Brunnenstr. 56','Hamburg Ottensen','','GERMANY','22763','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 14:21:33',0,NULL,3,1,3,1,'RA117773510CN\r ','w-factor\rWLAP008'),(5165,589648541013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','lavern67-75','lavern67@bright.net','Joe L Hancock','2038 Rosewood Ln','Lima','OH','UNITED STATES','45806-2024','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 14:33:17',0,NULL,3,1,1,1,'\\ ','lavern67-75'),(5166,719183395011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','sgeshikter','slavikge@gmail.com','Viacheslav Geshikter','Ha rav silbert<br>12','Beer-sheva','south','ISRAEL','84625','972 522760738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 14:48:03',0,NULL,3,1,3,1,'RA117725704CN\r ','sgeshikter\rHSNO019+CCNO001'),(5167,589654012013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.58,'eastar4','mariobengoa','mario_bengoa@yahoo.com.mx','MARIO BENGOA GARCIA','CALZADA DEL SOL No. 9<br>FUENTES DE SATELITE','ATIZAPAN DE ZARAGOZA','Estado de Mexico','MEXICO','52998','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 14:53:00',0,NULL,3,1,2,1,'\\ ','mariobengoa'),(5168,798628991012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',19.99,'eastar4uk','ferrum','ferrum@mauve.plus.com','Ian Stirling','Cottar Acre<br>Knowehead','Star','Fife','UNITED KINGDOM','KY7 6LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 15:09:59',0,NULL,3,1,3,1,'RA117736622CN\r ','ferrum\rWWSI002'),(5169,798629870012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',23.9,'eastar4','youche','ybm2004@comcast.net','Yibo Mo','2407 Warm Springs Ln','Naperville','IL','UNITED STATES','60564-8439','(630) 904-6032','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 15:12:59',0,NULL,3,1,1,1,'\\ ','youche'),(5170,719194799011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','elpitlum222','chartfield2@tx.rr.com','Tom Hartfield','4502 Rosemont Ave','Grand Prairie','TX','UNITED STATES','75052','(972) 263-6213','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 15:19:10',0,NULL,3,1,1,1,NULL,'elpitlum222\\'),(5171,797732664012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','otlkin','diaper84@gmail.com','Seung Kim','310 S Michigan Ave','Chicago','IL','UNITED STATES','60604','(312) 607-7260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 15:35:04',0,NULL,3,1,1,1,'\\ ','otlkin'),(5172,798642412012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','xaivincent','xaimaileng@yahoo.com','Xai Thao','2370 S. Adler Ave','Fresno','CA','UNITED STATES','93725','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 15:41:10',0,NULL,3,1,1,1,'\\ ','xaivincent'),(5173,719204080011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',37.99,'eastar4','kavirdak','dima@satcontrol.su','Dmitrij Chaunin','20 LET RKKA STR,BLD210,APT53','Omsk','Omskaja  obl','RUSSIAN FEDERATION','644009','73812483171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 15:43:57',0,NULL,3,1,3,1,'RA117736517CN\r ','kavirdak\r欧标\rHSNO015'),(5174,719204603011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','dr8van','shaun.a.singh@gmail.com','Shaun Singh','5300 Holmes Run Pkwy<br>Unit 104','Alexandria','VA','UNITED STATES','22304','(571) 277-3360','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 15:50:35',0,NULL,3,1,1,1,'\\ ','dr8van'),(5175,798660671012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×4',235.99,'eastar4','llonatan2002','rafaondaradio@yahoo.es','RAFAEL FELIX JIIMENEZ DE LOS GALANES','C/ AGOSTO 4 BAJO C','ALBACETE','Castilla-La Mancha','SPAIN','02006','625324840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 16:23:55',0,NULL,3,1,6,1,'EE520583454CN ','llonatan2002'),(5176,798661463012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',10.5,'eastar4uk','krob6805','ddrz@fsmail.net','Kenny Roberts','39 Teresa Rd<br>Stalham','Norwich','Norfolk','UNITED KINGDOM','NR129EB','01692543786','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 16:24:19',0,NULL,3,1,3,1,'RA117725046CN\r ','krob6805\rHSPL002'),(5177,798671555012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',4,'CASS002',34.8,'eastar4','charlesnadeau1','charles.nadeau@gmail.com','Charles Nadeau','32 Arundel avenue','Ottawa','ON','CANADA','K1K 0B6','(613) 744-1424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 16:58:18',0,NULL,3,1,3,1,'RA117736698CN\r ','charlesnadeau1\rCASS002'),(5178,798686246012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','sonofmarch','swordofmarch@yahoo.com','Tolu  Lacroix','9733 BURKE VIEW CT','BURKE','VA','UNITED STATES','22015-3009','(571) 249-0423','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 17:19:51',0,NULL,3,1,1,1,'\\ ','sonofmarch'),(5179,536783554003,130458644539,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET track#',1,'HSNO021',14.9,'cnfaner','stevemickhq','stevemickhq@yahoo.com.au','mick lamaro','15 primrose circuit','claremont meadows','New South Wales','AUSTRALIA','2747','0413938656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 17:30:39',0,NULL,3,1,3,1,'RA117736905CN\r ','stevemickhq\rHSNO021\r澳标'),(5180,589704552013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','chris-storey','chris.storey@gmail.com','Chris Storey','1 stratton terrace','falmouth','Cornwall','UNITED KINGDOM','tr112sy','07875014161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 17:40:15',0,NULL,3,1,2,1,'\\ ','chris-storey'),(5181,719263205011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',12.5,'eastar4','stupsimaus1977','stupsimaus77@live.de','Jana Haufert','Behringstraße.32b','Dresden','','GERMANY','01159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 18:02:08',0,NULL,3,1,2,1,'\\ ','stupsimaus1977\r华硕 10 pin 1.0 5cm'),(5182,798712193012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','sbenn491','sbenn492@yahoo.com','Stephen Bennett','1945 Goldfinch Way','Manteca','CA','UNITED STATES','95337','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 18:04:52',0,NULL,3,1,1,1,'\\ ','sbenn491'),(5183,719269683011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','jsea6640','jseaborg@psfmech.com','Jeff Seaborg','PSF Mechanical<br>9322 14th Ave S','Seattle','WA','UNITED STATES','98108','(206) 812-7652','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 18:09:34',0,NULL,3,1,1,1,'\\ ','jsea6640'),(5184,682471115001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',89.99,'buysia','dgul2712','diana_gulya@hotmail.com','Diana Gulyavskaya','6569 Copley Ave','Solon','OH','UNITED STATES','44139-4109','(440) 248-1110','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 18:09:41',0,NULL,3,1,1,1,NULL,'dgul2712\\'),(5185,719271221011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','laith3','laith3@yahoo.com','Laith Sinawi','914 Samuel Dr','Petaluma','CA','UNITED STATES','94952-1830','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 18:36:21',0,NULL,3,1,1,1,'\\ ','laith3'),(5186,719286145011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','dh17','darren.harlow@o2.co.uk','Darren Harlow','8 Cherrywood Green','March','Cambridgeshire','UNITED KINGDOM','PE15 9SR','01354658102','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 18:41:43',0,NULL,3,1,3,1,'RA117736812CN\r ','dh17\rOTSO001'),(5187,589730056013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','codaja63','codaja63@comcast.net','Dana Cooper','PO Box 32633','Palm Beach Gardens','FL','UNITED STATES','33420-2633','(561) 210-5531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 18:50:29',0,NULL,3,1,1,1,'\\ ','codaja63'),(5188,798764435012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','8881666','trafficpayout@aim.com','TrafficPayOut','9-612 20th Street NE','Medicine Hat','AB','CANADA','T1C1H5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 19:34:53',0,NULL,3,1,2,1,'\\ ','8881666'),(5189,719318232011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','artg1954','artg14@yahoo.com','Arthur Guertin','10 patriot cir','plymouth','MA','UNITED STATES','02360-2106','(781) 982-4500 ext.: 207','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 19:40:33',0,NULL,3,1,1,1,'、 ','artg1954\r兼容型3D眼镜  samsung 专用'),(5190,719325633011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','struppimoppi','red_socks@gmx.de','DYNAmore GmbH','George-BährStr. 20<br>Frank Hempel','Dresden','','GERMANY','01069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 19:54:58',0,NULL,3,1,2,1,'\\ ','struppimoppi'),(5191,798786116012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','rogerwhale','mrsmoby2000@yahoo.co.uk','maxine whale','38 liberty Rd<br>glenfield','leicester','Leicestershire','UNITED KINGDOM','LE3 8JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 20:10:45',0,NULL,3,1,3,1,NULL,'rogerwhale\rOTGR001'),(5192,798787095012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',96.9,'eastar4uk','irmakali','ali_irmak@hotmail.com','ali irmak','yeni mah. eren yildirim sk. 1/3 d:10<br>silivri eml','silivri','istanbul','TURKEY','34570','902127285209','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 20:12:23',0,NULL,3,0,3,1,'RA117736980CN\r ','irmakali\rOTSO004*2\r盒装'),(5193,798781666012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',56.99,'eastar4','mr.homo','81554@mail.ru','Oleg Shishkov','ulica Yubileynaya, dom 7, kv.14','Zapolyarniy','Murmansk region','RUSSIAN FEDERATION','184430','+79062892075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 20:13:34',0,NULL,3,1,3,1,'RA117725151CN\r ','mr.homo\rREPL001+OTPL001\r再发一个PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906\r'),(5194,589773956013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','xispas7','xispas7@gmail.com','Xavier Ayerbe Garcia','C/Castilla Nº11','Martorellas','BARCELONA','SPAIN','08107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 20:39:59',0,NULL,3,1,2,1,'\\ ','xispas7'),(5195,798804748012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','tescoworker2009','lucy290@op.pl','Lucyna Kucharek','69 Derby Square Basement','Douglas','Isle of Man','UNITED KINGDOM','IM1 3LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 20:51:52',0,NULL,3,1,3,1,'RA117736826CN\r ','tescoworker2009\r英标\rHSNO005'),(5196,542540497004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','yvonne3722','ywashington@fuse.net','yvonne washington','1226 brushwood ave','cincinnati','OH','UNITED STATES','45224-1180','(513) 521-7288','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-06 20:56:37',0,NULL,3,1,1,1,'\\ ','yvonne3722'),(5197,798813120012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','vonnegut511','dwillcox67@aol.com','Doug Willcox','PO Box 48554','Saint Petersburg','FL','UNITED STATES','33743-8554','(727) 204-5854','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-06 21:03:36',0,NULL,3,1,1,1,'\\ ','vonnegut511'),(5198,717864956011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','mannoiaj','mannoiaj@msu.edu','Jeff Mannoia','4639 Salzburg Cir','Portage','MI','UNITED STATES','49024-3041','(269) 216-3168','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mannoiaj'),(5199,798801495012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','jill6179','jillw4@gmail.com','Jill Ward','67 Woodland Hill<br>Whitkirk','Leeds','West Yorkshire','UNITED KINGDOM','LS15 7BX','07773500768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 21:46:45',0,NULL,3,1,3,1,'RA117736865CN\r ','jill6179\rHSPL011\r英标'),(5200,719387160011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','sgiwest010','clee@sgiwest.com','Woo Lee','36 Technology Dr<br>Ste 100','Irvine','CA','UNITED STATES','92618-5307','(714) 260-1828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 22:17:00',0,NULL,3,1,1,1,NULL,'sgiwest010\\'),(5201,589803492013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','markpena','mark@neglectedrecords.com','mark pena','5402 Coral Ribbon Ave','Las Vegas','NV','UNITED STATES','89139-5663','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 22:26:21',0,NULL,3,1,1,1,'\\ ','markpena'),(5202,798856765012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','nickd_101','nickg.drew@googlemail.com','Nick Drew','92 Harleyford Road','London','London','UNITED KINGDOM','SE11 5SN','07747536781','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 22:59:03',0,NULL,3,1,3,1,'RA117736888CN\r ','nickd_101\rOTHP003'),(5203,719404516011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jambnx','akilbury@aol.com','Angela Harmon','1817 W 21st St','Erie','PA','UNITED STATES','16502-2007','(814) 873-6248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 23:26:00',0,NULL,3,1,1,1,'\\ ','jambnx'),(5204,719406381011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','dbui9739','dungbui_04@yahoo.com','Dung Bui','4007 England CT E','Houston','TX','UNITED STATES','77021','(713) 505-4924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 23:27:27',0,NULL,3,1,1,1,NULL,'dbui9739\\'),(5205,798867171012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','m13a8','derkaderkadoo@gmail.com','Aaron Hoffman','2913 Cottonwood Ln','Hays','KS','UNITED STATES','67601-1706','(785) 259-6822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 23:37:48',0,NULL,3,1,1,1,'\\ ','m13a8'),(5206,719410226011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','marysuresh2','suresh_srini@hotmail.com','Suresh Srinivasan','12919 Bramford Point Ln','houston','TX','UNITED STATES','77070-2645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 23:45:19',0,NULL,3,1,1,1,'\\ ','marysuresh2'),(5207,798869986012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','gibbyxr2i','sdgibbins211@aol.com','simon gibbins','7 coultas avenue<br>deepcar','sheffield','South Yorkshire','UNITED KINGDOM','s36 2pt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 23:47:23',0,NULL,3,1,3,1,'RA117736959CN\r ','gibbyxr2i\rHSMO018\r英标'),(5208,589827963013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','jambaj0oze','xianne@gmail.com','lara bonifacio','2260 Easy Ave','Long Beach','CA','UNITED STATES','90810-3533','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 00:36:31',0,NULL,3,1,1,1,'\\ ','jambaj0oze'),(5209,798888104012,220744018281,'Genuine Logitech G7 Rechargeable Battery good condition',1,'BALO005',7.1,'eastar4','bilbic936','bilbic@gmail.com','matthew carpenter','2207 West Settlers Way','The Woodlands','TX','UNITED STATES','77380','(936) 446-0234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 00:57:27',0,NULL,3,1,1,1,'\\ ','bilbic936'),(5210,589840013013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','mimibijak','mimi_8006@yahoo.com','syamimi md jamal','220, JOHN STREET<br>APT 51021','rochester','NY','UNITED STATES','14623','(585) 278-6899','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 01:37:33',0,NULL,3,1,1,1,'\\\r ','mimibijak\r罗技M705鼠标外壳  '),(5211,719447371011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',2,'HSMO008',23.9,'eastar4','desiloverboy','desiloverboy@yahoo.com','smokers of  Auburn hills','3029 E Walton Blvd','auburn hills','MI','UNITED STATES','48326-2368','(248) 373-7174','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 02:22:52',0,NULL,3,1,1,1,'\\ ','desiloverboy'),(5212,719451426011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','blueburrd','janelleray@stx.rr.com','janelle ray','2186 Goat Creek Rd','Kerrville','TX','UNITED STATES','78028','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 02:38:43',0,NULL,3,1,1,1,'\\ ','blueburrd'),(5213,719450734011,320701927743,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',65.9,'eastar4','mimaiolli','mi.maiolli@gmail.com','Michelle Maiolli','Rua Dr. Faivre, n 340, apartamento 72','Curitiba','Paraná','BRAZIL','80060-140','(55)4133198915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 02:44:46',0,NULL,3,1,3,1,'RA117737000CN\r ','mimaiolli\r蓝色的\rHDSG001'),(5214,589855321013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',12.59,'eastar4','pumamv','biggiemv@hotmail.com','tzahi konstabler','shimshon<br>47','haifa','','ISRAEL','34678','972544800666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 03:01:18',0,NULL,3,1,2,1,'\\ ','pumamv'),(5215,719464175011,320480799619,'New original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',148.99,'eastar4','dewaltdude','dewaltrules@gmail.com','Ryan  Alexander','7321 Old Pascagoula Rd','Theodore','AL','UNITED STATES','36582','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 03:37:31',0,NULL,3,1,1,1,'、 ','dewaltdude'),(5216,719471793011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','hoo340340','randallhoo374@msn.com','RANDALL HOO','2207 Apache St','ADELPHI','MD','UNITED STATES','20783-1617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 04:21:46',0,NULL,3,1,1,1,'\\ ','hoo340340\rHP 8pin 1.25 25cm '),(5217,798954169012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','strategemaven','jon_mendoza@hotmail.com','Jonathan Mendoza','3299 Alpaca Avenue','Mississauga','ON','CANADA','L5M 7V4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 05:43:21',0,NULL,3,1,3,1,'RA117725372CN\r ','strategemaven\rOTSO001'),(5218,542628468004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','stingraybw','nezhurin@gmail.com','Dmitry Nezhurin','Teplichnaya 4-25','Voronezh','RU','RUSSIAN FEDERATION','394070','+7 920 2190099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 05:48:31',0,NULL,3,1,3,1,'RA117725386CN\r ','stingraybw\rOTCR001'),(5219,798957319012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','xaros2','xaros@skynet.be','Xavier Rossey','Rue du CHENE 71','Noirchain','','BELGIUM','7080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 06:02:58',0,NULL,3,1,2,1,'\\ ','xaros2\r红边优联'),(5220,719499146011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',69.9,'eastar4','edec9920','euclerysystems@hotmail.com','euclery de carvalho','44 claymill house<br>raglan road','london/woolwich','London','UNITED KINGDOM','se18 7hx','02083168790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 06:58:37',0,NULL,3,1,3,1,'RA117725409CN\r ','edec9920\r英标\rHSPL009'),(5221,798973165012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','solegv','sov@me.com','Oleg Salov','ul.Krupskoy d.58 kv.38','Beloretsk','Bashkortostan','RUSSIAN FEDERATION','453501','+7(927)0827711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 07:19:02',0,NULL,3,1,2,1,'\\ ','solegv\r旧的'),(5222,589891927013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','jortsutopi','hannu.nikkila@luukku.com','Hannu Nikkila','Rautajarventie 359','PADASJOKI','VESIJAKO','FINLAND','17630','358-400-231828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 07:46:06',0,NULL,3,1,3,1,'RA117725647CN\r ','jortsutopi\r欧标\rHSNO019'),(5223,798980593012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.99,'eastar4','rayen030','rayen.ramsodit@hotmail.com','Rayen Ramsodit','Talmalaan 9','ZEIST','','NETHERLANDS','3705VK','0647087523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 07:53:22',0,NULL,3,1,2,1,'\\ ','rayen030\r红边优联'),(5224,719515312011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',28.47,'eastar4','sirgoliat','daniel.p@telia.com','Daniel Persson','Engelbrektsgatan 46','ÖREBRO','','SWEDEN','70213','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 08:19:41',0,NULL,3,1,2,1,'\\ ','sirgoliat'),(5225,719526192011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','zorin-foto','u-mka@mail.ru','Svyatoslav Zorin','Obedineniya<br>96 kv. 10 +79139146378','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 09:14:24',0,NULL,3,1,2,1,'\\ ','zorin-foto'),(5226,798855013012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','libandcath','dehavillan@hotmail.co.uk','Elizabeth deHavillan','13 Tolls Lane<br>Holbeach','Spalding','Lincolnshire','UNITED KINGDOM','PE12 7PR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 09:52:22',0,NULL,3,1,2,1,'\\ ','libandcath'),(5227,798912901012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.4,'eastar4','joaovoss89','joaovoss@live.com','Joao Eduardo Voss','Av Iguacu, 3001 Ap 1503','Curitiba','Parana','BRAZIL','80240031','+55 4133423399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 11:57:16',0,NULL,3,0,2,1,'\\ ','joaovoss89\r换成2.1 Bluetooth Module + cable for DELL mini10\r'),(5228,589933398013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','aurinojunior','aurinojr@hotmail.com','Aurino Alves dos Santos Junior','Rua Alberto Maranhão 522<br>TIROL','NATAL','Rio Grande do Norte','BRAZIL','59020-330','558499420489','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 11:58:33',0,NULL,3,1,2,1,'\\ ','aurinojunior'),(5229,799044965012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','joeblack385','hrvoje.katic@unicreditgroup.zaba.hr','Hrvoje Katic','Zvonimira Rogoza 3','Zagreb','','CROATIA','10000','385-1-6111-782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:05:01',0,NULL,3,1,3,1,'RA117725845CN\r ','joeblack385\rWWOT003'),(5230,799053474012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','kpaul97','paulosk97@gmail.com','Kouramas Paulos','Kounoupidiana  post box  269<br>post box  269','Chania','Chania Crete Greece','GREECE','71042','6983514906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:28:50',0,NULL,3,1,2,1,'\\ ','kpaul97\r欧标'),(5231,537009108003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','cvdexter82','cvdexter@hotmail.com','Cristian Fabian Vermeersch Bermudez','Felipe Ojeda 0228','Tocopilla','Antofagasta','CHILE','1340000','(56)9 91337743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:43:09',0,NULL,3,1,3,1,'RA117725854CN\r ','cvdexter82\rWWOT003\r'),(5232,718616555011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','freyrw','freyrw@lsn.se','Freyr Waage','Hansagränd 1A','Hjärup','none','SWEDEN','24565','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 13:51:30',0,NULL,3,1,2,1,'\\','freyrw'),(5233,537029305003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.95,'cnfaner','wwwavdesigncom','robert@avdesign.com','Robert Graham','6941 Twin Aspen Cv','Salt Lake City','UT','UNITED STATES','84121-3478','(801) 362-7017','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-07 14:18:25',0,NULL,3,1,1,1,'\\  ','wwwavdesigncom\r旧的'),(5234,719622233011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',69.9,'eastar4','anemoscope','sose2431@sakura.vu','Hiroki Mabuchi','2-34-117 Hongu-Cho Minato-Ku','Nagoya-City','Aichi','JAPAN','4550064','+81-52-651-7937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 14:54:12',0,NULL,3,1,3,1,'RA117725770CN ','anemoscope\rHSPL009'),(5235,717916236011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','ap2873','andre.pleasance@sky.com','Andre Pleasanc','18st johns close','Brinsley','Nottinghamshire','UNITED KINGDOM','Ng16 5bh','01773530229','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 14:55:49',0,NULL,3,1,3,1,'RA117725783CN\r ','ap2873\rMOAP001\r'),(5236,799107168012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','yarmen71','yarik71@yahoo.com','Armen Eritsyan','Gorkogo st.  104-92','Vladimir','Vladimir region','RUSSIAN FEDERATION','600026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 15:10:08',0,NULL,3,1,2,1,'\\ ','yarmen71\r欧标'),(5237,719648906011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','prolifictech','prolifictech@stjoelive.com','Prolific Technologies','2013 S Belt Hwy Suite 300','Saint Joseph','MO','UNITED STATES','64507','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 16:06:44',0,NULL,3,1,1,1,'\\  ','prolifictech\r罗技 USB receiver no shell'),(5238,799135192012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','jaras_cro','josiparas@gmail.com','Josip Aras','Obala palih omladinaca 11','Šibenik','Croatia','CROATIA','22000','+38598816414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 16:20:19',0,NULL,3,1,3,1,'RA117725823CN\r ','jaras_cro\rOTCN004*10'),(5239,587259321013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',2,'BAZA001',139.96,'eastar4','shadow-x9999','jayhoskins2@hotmail.com','Jason Hoskins','189 Simcoe Way','Fort McMurray','AB','CANADA','T9H3B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 16:24:15',0,NULL,3,1,3,1,'RA117725908CN\r ','shadow-x9999\rBAZA001'),(5240,799147812012,220765478569,'New PLANTRONIC Calisto pro Bluetooth Headset  only',1,'HSPL014',36.99,'eastar4','bgle4220','gletten3@aol.com','Bernard Gletten','829 Lake Terrace Dr','Nashville','TN','UNITED STATES','37217-4274','(615) 306-3099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 16:50:58',0,NULL,3,1,1,1,'\\  ','bgle4220'),(5241,542749759004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.95,'cnfaner','powercoreeng','dwubs@powercoreeng.com','PowerCore Engineering','110 Riverside dr<br>Unit 203B','London','ON','CANADA','N6H 4S5','(519) 474-1175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 16:52:47',0,NULL,3,1,3,1,'RA117773038CN\r ','powercoreeng\r美标\rMOMI001'),(5242,590004527013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','webwebes','alejandro_spa@hotmail.com','Alberto Ortega Martin','C/ Camarena 199; 3d','Madrid','Madrid','SPAIN','28047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 16:56:28',0,NULL,3,1,3,1,'RA117725797CN\r ','webwebes\rOTRA003'),(5243,590006578013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','qlaj321','simond@paran.com','SE JUN PARK','105Dong-902Ho,Sunkyung Apt,Yeonsan 9-dong,Yeonje-gu','Busan','Busan','KOREA,REPUBLIC OF','611-763','82-51-751-3566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 17:02:10',0,NULL,3,1,3,1,'RA117725868CN\r ','qlaj321\rWLIN002\rIBM 6250 ANX'),(5244,719670136011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','cbri3088','briencar@hotmail.com','Caroline Brien','57 Pierre-Nolin','St-Jean-sur-Richelieu','QC','CANADA','J2W3B4','(514) 758-4688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 17:04:01',0,NULL,3,1,2,1,'\\ ','cbri3088'),(5245,719687633011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','edelstahlklaus','klauskilian-edelstahldesign@t-online.de','Klaus Kilian','Königsbergerstr. 10','Lorsch','','GERMANY','64653','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 17:42:43',0,NULL,3,1,2,1,'\\ ','edelstahlklaus'),(5246,799174683012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','nagyattila75','attilnagy75@gmail.com','Attila Nagy','Karancs utca 12','Törökszentmiklós','','HUNGARY','5200','0036203363585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 17:47:01',0,NULL,3,1,2,1,'\\ ','nagyattila75'),(5247,719710544011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','jazzinatl','jeffjohnson49@gmail.com','Jeffrey C Johnson','3879 Stratford Park Drive NE','Atlanta','GA','UNITED STATES','30342-4301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 18:29:33',0,NULL,3,1,1,1,'\\  ','jazzinatl'),(5248,719714811011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','p.lina.rz','lina_rz@hotmail.com','Paulina Rzeczkowska','3208 - 21 Carlton Street','Toronto','ON','CANADA','M5B1L3','(647) 299-5462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 18:37:41',0,NULL,3,1,2,1,'\\ ','p.lina.rz'),(5249,542782042004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','ardechos','patrick.arsac@gmail.com','Patrick ARSAC','BURIANNE','Saint BARTHELEMY le MEIL','Rhône-Alpes','FRANCE','07160','0699551595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 18:38:37',0,NULL,3,1,3,1,'RA117725806CN\r ','ardechos\rOTCR001'),(5250,537100068003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','daray1946','darjkaz@verizon.net','darryl kazmierczak','608 richmond ave','buffalo','NY','UNITED STATES','14222','(716) 881-3759','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-07 18:41:55',0,NULL,3,1,1,1,'\\  ','daray1946'),(5251,799210312012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','pprafa2','rauf7@web.de','Rauf Gambarov','B.Nuriyev 15/9 app.15','Baku','Baku','AZERBAIJAN','AZ 1119','+994552500758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 18:54:51',0,NULL,3,1,3,1,'RA117725718CN\r ','pprafa2\rOTSO001'),(5252,799235031012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','sodhisandeep','sodhisandeep@hotmail.com','Sandeep Sodhi','12, Vauxhall Gardens, Oakham','Dudley','West Midlands','UNITED KINGDOM','DY28AH','01384252079','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 19:37:07',0,NULL,3,0,3,1,'RA117725960CN\r ','sodhisandeep\rGLSG001*2'),(5253,799235385012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','jonathanzaleski','jonathanzaleski@gmail.com','Jonathan W. Zaleski','222 3rd St<br>Ste 2300','Cambridge','MA','UNITED STATES','02142-1122','(617) 455-7595','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 19:41:44',0,NULL,3,0,1,1,'\\  ','jonathanzaleski'),(5254,799242730012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',18.8,'eastar4uk','rodoudou22','rodolphe.chavanne@wanadoo.fr','CHAVANNE COURSES','Rodolphe CHAVANNE<br>6 rue PAUL FEVAL','PLERIN','Bretagne','FRANCE','22190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-07 19:55:38',0,NULL,3,1,3,1,'RA117725721CN\r ','rodoudou22\rHSNO022\r欧标\r'),(5255,719759582011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','zzzfour','candikid_1@yahoo.com','nic bobo','PO Box 1012<br>1403 Cotton Dale Rd.','springtown','TX','UNITED STATES','76082-1012','(817) 323-7774','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 20:05:42',0,NULL,3,1,1,1,'\\ ','zzzfour'),(5256,542812172004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'',16.95,'cnfaner','sbismal123','thuggangsta564@hotmail.co.uk','Sohaib Bismal','143 Titwood Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G41 4BN','07812715851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:06:34',0,NULL,3,0,3,1,'RA117725735CN\r ','sbismal123'),(5257,799255661012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','2009miller18','zorik72@gmail.com','MILLER ZORIK','BAYT V GAN 8/5','KIRYAT ATA','','ISRAEL','28000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:14:06',0,NULL,3,1,2,1,'\\ ','2009miller18'),(5258,799261315012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','trevor272000','tashworth@cogeco.ca','trevor Ashworth','804 brant','windsor','ON','CANADA','n9a3g1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:24:30',0,NULL,3,1,3,1,'RA117725939CN\r ','trevor272000\rGLSG001*2'),(5259,719767959011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','ruaro2005','noelruaro@gmail.com','Rafael Ruaro','Rua Gaivota n° 665 Apartamento 54','São Paulo','São Paulo','BRAZIL','04522031','551194947705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:25:14',0,NULL,3,1,3,1,'RA117773041CN\r ','ruaro2005\rGLOT004\r兼容型3D眼镜  samsung 专用'),(5260,719769912011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','malex42','malex2001@blueyonder.co.uk','Michael Walker','5 Gabriel Close','Frome','Somerset','UNITED KINGDOM','BA11 2XJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 20:26:35',0,NULL,3,1,3,1,'RA117725749CN\r ','malex42\rMOAP001'),(5261,799258983012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','rdmagrey','rdmagrey1@att.net','Robert Magrey','20705 Centre Pointe Pkwy','Santa Clarita','CA','UNITED STATES','91350','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 20:30:02',0,NULL,3,1,1,1,'\\ ','rdmagrey'),(5262,799267141012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','it_ace','it@acemotoracceptance.com','Ron Ferrell','111 Cupped Oak Dr<br>Ste F','Matthews','NC','UNITED STATES','28104-8823','(704) 882-7118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 20:37:54',0,NULL,3,1,1,1,'\\  ','it_ace'),(5263,719777408011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','i-one99','a@stokkermans.net','Ton Stokkermans','Hooikamp 140','LEIDSCHENDAM','','NETHERLANDS','2264 JW','(070) 3271595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:44:13',0,NULL,3,1,2,1,'\\ ','i-one99'),(5264,799275126012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','alfahad1','alfahad_tnt@hotmail.com','ahmed qassim','althafra','DOHA','','QATAR','1488','009745606954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:53:08',0,NULL,3,1,3,1,'RA117725752CN\r ','alfahad1\rMOLO002'),(5265,719783571011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','jeninatx*','jeninatx21@gmail.com','Jennifer Beale','506 Sage Boot Dr','Pflugerville','TX','UNITED STATES','78660-4303','(512) 567-8183','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 20:56:00',0,NULL,3,1,1,1,'\\  ','jeninatx*\rHP 8pin 1.25 25cm '),(5266,590088188013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','surdy_us','leoharpreet@gmail.com','Harpreet Singh','277 Morning Glory Dr','Monroe','NJ','UNITED STATES','08831-5339','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 20:57:35',0,NULL,3,1,1,1,'\\ ','surdy_us'),(5267,719784290011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','karljanson','kjans123@gmail.com','Karl Janson','Ehitajate 2-7','Tootsi','Pärnumaa','ESTONIA','87501','+3725205190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:58:45',0,NULL,3,1,2,1,'\\ ','karljanson'),(5268,542834069004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCY001',53.99,'cnfaner','ggomax','gomax1@gmail.com','Paul Max','2 Frances Crt','Fish Creek','Victoria','AUSTRALIA','3959','0428469369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 21:19:09',0,NULL,3,0,3,1,'RA117725837CN ','ggomax\rWWOT003+ANCY001'),(5269,799286926012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',27.7,'eastar4uk','nasenbaer5386801133','andreas.malik@t-online.de','Andreas Malik','Am Gosekamp 36','Sprockhövel','','GERMANY','45549','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-07 21:19:56',0,NULL,3,1,3,1,'RA117725810CN\r ','nasenbaer5386801133\rHSPL011\r英标'),(5270,799289769012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','770857','fionamaclellan@hotmail.com','Fiona Maclellan','3 Crosslaw Gardens,','Lanark','South Lanarkshire','UNITED KINGDOM','ML11 9DL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 21:25:01',0,NULL,3,1,3,1,'RA117725766CN\r ','770857\r英标\rHSPL011'),(5271,590097543013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','irstuck','irstuck@cox.net','Ray Stuck','11422 Kansas Cir','Omaha','NE','UNITED STATES','68164','(402) 431-0475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 21:28:36',0,NULL,3,1,1,1,'\\  ','irstuck'),(5272,799293095012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','zaktwohig','zakdj@live.co.uk','zak twohig','c/o Bauhaus<br>Bakers row','Cardiff','Cardiff','UNITED KINGDOM','cf10 1al','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 21:33:28',0,NULL,3,0,3,1,'RA117725973CN\r ','zaktwohig\rGLSG001*2'),(5273,590106545013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.49,'eastar4','vasvickk','vasvick@gmail.com','Vasiliy Koltsov','Pogorelova street 3, kv.29','Sevastopol','','UKRAINE','99703','+380503930924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:02:21',0,NULL,3,1,2,1,'\\ ','vasvickk'),(5274,719807930011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','xx6723003','ilfytxy@sohu.com','xie xin','1403 State St','La Crosse','WI','UNITED STATES','54601-3651','(608) 738-9933','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 22:03:20',0,NULL,3,1,1,1,'\\ ','xx6723003'),(5275,590106706013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','luiz.nardi','luiz_nardi@yahoo.com.br','Luiz Nardi','Rua Pamplona 237 Apt 33<br>Jardim Paulista','São Paulo','São Paulo','BRAZIL','01405-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:05:37',0,NULL,3,1,3,1,'RA117725678CN\r ','luiz.nardi\rMOLO004\r华硕限量版'),(5276,719816943011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',34.99,'eastar4','nguyenvinhhao','vinhhao77@yahoo.com','NGUYEN VINH HAO','Truong Dai Hoc Bach Khoa TP.HCM<br>Khoa Dien Dien Tu','268 Ly Thuong Kiet, Quan 10,','TP Ho Chi Minh','VIET NAM','7000','(84)1217486149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:27:02',0,NULL,3,1,3,1,'RA117725681CN\r ','nguyenvinhhao\rWWSI004'),(5277,799312828012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',36.9,'eastar4','burnie351','bwilliams2@bcps.k12.md.us','burnelle williams','2701 Baker St','baltimore','MD','UNITED STATES','21216-4003','(410) 945-0421','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 22:27:35',0,NULL,3,1,1,1,'\\  ','burnie351'),(5278,798517054012,220697786937,'New 3.0 Bluetooth BCM2070 Module+cable HP probook 4321S',1,'BTHP3002',19.99,'eastar4','saykoshey','frylord@gmail.com','Mehmet Aksakal','Altstraat 20','UDEN','','NETHERLANDS','5402AK','0646067155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:38:29',0,NULL,3,1,2,1,'\\ ','saykoshey\rHP 6pin1.0 3cm'),(5279,537177680003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',47.58,'cnfaner','vincenzo2007','vincenzo2007ebay@gmail.com','Carlo Buccinnà','via Leonardo da vinci 10','Lamezia Terme','CZ','ITALY','88046','096824685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 23:31:54',0,NULL,3,1,3,1,'RA117725664CN\r ','vincenzo2007\rWWOT001+ANCN001\r'),(5280,542865334004,140481827924,'New Plantronics Explorer 220 BLUETOOTH HEADSE+carcharge',1,'HSPL001+CCPL001',15.8,'cnfaner','crisa71','carmel777@yahoo.com','Clarissa Scott','5018 Kenton Rpds','San Antonio','TX','UNITED STATES','78240','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-07 23:55:57',0,NULL,3,1,1,1,'\\  ','crisa71'),(5281,719838928011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',3,'HSNO006',44.91,'eastar4','emaranhao','ely.maranhao@gmail.com','ely maranhao filho','area octogonal 8<br>bl b ap 301','brasilia','distrito federal','BRAZIL','70660082','+556133628335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 23:58:29',0,NULL,3,0,3,1,'RA117725899CN\r ','emaranhao\rHSNO006'),(5282,717389714011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','jamarla3','jamala3@optusnet.com.au','Jason Lamtzes','12 Fernwren Place','CARRUM DOWNS','Victoria','AUSTRALIA','3201','0397704175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 00:14:58',0,NULL,3,1,2,1,'\\ ','jamarla3\rCAB-6060'),(5283,719844009011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',52.98,'eastar4','muckluck89','alexmcc89@gmail.com','Alex McCulloch','40 Warrender ave.','Toronto','ON','CANADA','M9B5Z2','(416) 207-0253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 00:15:24',0,NULL,3,1,3,1,'RA117725885CN\r ','muckluck89\rWLAP002'),(5284,719851867011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','stephenmiki','stephenmiki@yahoo.com','Stephen Wallace','2358 Cory Ave','San Jose','CA','UNITED STATES','95128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 00:49:33',0,NULL,3,1,1,1,'\\ ','stephenmiki'),(5285,719852008011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','bruno42878','bruno428@hotmail.com','Mark Kearns','1806 Seward St','Evanston','IL','UNITED STATES','60202-1906','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 00:51:07',0,NULL,3,1,1,1,'\\  ','bruno42878'),(5286,718392193011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','rafil65','rafil_hussain@yahoo.ca','Mohamed Hussain','46 Nightstar Rd','Scarborough','ON','CANADA','M1X1Z8','(416) 297-7506','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 01:38:03',0,NULL,3,1,2,1,'\\ ','rafil65'),(5287,719867379011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',119.99,'eastar4','albertineitor2009','albertineitor@hotmail.com','ALBERTO BRAVO','1941W Blossom Pl','BREA','CA','UNITED STATES','92821-2718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 01:58:20',0,NULL,3,1,1,1,'、 ','albertineitor2009'),(5288,0,220794611656,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',124.49,'eastar4','severalyears','cltemecula@aol.com','gary griffith','33141 poppy st','temecula','ca','UNITED STATES','92592-1340','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 02:03:49',0,NULL,3,1,1,1,'\\ ','severalyears\r盒装的'),(5289,537202481003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',12.99,'cnfaner','ylgp','yl.gp@hotmail.com','Yves Lanteigne','613-1 chemin riviere a la truite','Riviere a la truite','NB','CANADA','E1X 2M4','(506) 395-6921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 02:05:33',0,NULL,3,1,3,1,'RA117725871CN\r ','ylgp\rHSMO018'),(5290,537215064003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','kbradford3','kbradford@gmail.com','Kevin Bradford','6108 Buena Vista St','Fairway','KS','UNITED STATES','66205-3228','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-08 03:28:31',0,NULL,3,1,1,1,'\\ ','kbradford3'),(5291,719899423011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','sc20k7','sc20k1@hotmail.com','Simon Caron','14 Montaigne','Lévis','QC','CANADA','g6v8k3','(418) 833-3792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 04:29:12',0,NULL,3,1,3,1,'RA117726007CN\r ','sc20k7\rUDAP001'),(5292,799405067012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','payulito','peabad34@hotmail.com',' Paul Abad','Higueras 5520, Av. Eloy Alfaro casa # 15','Quito','Pichincha','ECUADOR','1701','(229) 230-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 04:43:16',0,NULL,3,1,3,1,'RA117773015CN\r ','payulito\rOTSO004*2'),(5293,537228337003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.9,'cnfaner','sacdalan','sacdjas@yahoo.com','Jason J Sacdalan','8328 Valley View Cir','Riverside','CA','UNITED STATES','92508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-08 05:21:17',0,NULL,3,1,1,1,'\\ ','sacdalan'),(5294,0,220796317364,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',121.99,'eastar4','doneval32','doneval2001@gmail.com','DANIEL OLIVA ARTIAGA','TORROX, Nº16,5ºA','MADRID','Madrid','SPAIN','28041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:23:27',0,NULL,3,1,3,1,'RA117725995CN\r ','doneval32\rGLSG001*2\r盒装的'),(5295,719909249011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','roman.dorovik','rdorovik@gmail.com','Roman Dorovik','Proletarskaya street<br>3A apartment 9','Magadan','','RUSSIAN FEDERATION','685000','+79148645559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:41:24',0,NULL,3,1,2,1,'\\ ','roman.dorovik'),(5296,719910918011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','barnhambooks','richmid@yahoo.com','Richard Middleton','5 Trundle View Close','Barnham','West Sussex','UNITED KINGDOM','PO22 0JZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:51:35',0,NULL,3,1,3,1,'RA117773055CN\r ','barnhambooks\rBR3D001'),(5297,719913436011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','lucasmbotelho','lukinhaix@hotmail.com','Lucas Botelho','QI 03 Lote 960/980','Gama','DF','BRAZIL','72445-030','61 9926-6688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:51:47',0,NULL,3,1,3,1,'RA117773024CN\r ','lucasmbotelho\rUDAP001'),(5298,799417532012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',2,'MOLO006',53.98,'eastar4','saintia0','saintia@hanmail.net','EunBum Cho','Softnet, 5F Jinsung B/D,<br>150 Samseong 1-dong, Gangnam-gu,','Seoul','','KOREA,REPUBLIC OF','135-878','+82-2-3446-2502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:51:54',0,NULL,3,1,3,1,'RA117725987CN\r ','saintia0\rMOLO006'),(5299,719929523011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','todi962','t.dienhold@freenet.de','Torsten Dienhold','Merianstraße 3','Weinheim','','GERMANY','69469','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 07:16:54',0,NULL,3,1,3,1,'RA117773090CN\r ','todi962\rBR3D001'),(5300,719932822011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','hampster2k','a0551816@hud.ac.uk','Chris Humphries','Flat 8, Kendal House<br>51, Bowness Avenue','Headington, Oxford','Oxfordshire','UNITED KINGDOM','OX3 0AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 07:33:40',0,NULL,3,1,3,1,'RA117773086CN\r ','hampster2k\rMOAP001'),(5301,590190456013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','beegrons','brett@paintmypicture.com','Brett','Suite 2, 150 Chestnut Street','Richmond','Victoria','AUSTRALIA','3121','0401794935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 07:39:28',0,NULL,3,1,2,1,'\\ ','beegrons'),(5302,719938079011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','yueytan','yuktan@deloitte.com.au','Yu Kwang Tan','58/8 Little Capper Street<br>Kent Town','Adelaide','South Australia','AUSTRALIA','5067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 08:01:12',0,NULL,3,1,3,1,'RA117773109CN\r ','yueytan\rBR3D001'),(5303,719934138011,320610174303,'New HuaWei EM660 3G WWAN Mini PCI-E Card CDMA EV-DO Mod',10,'WWHU001',469,'eastar4','manoj1979manojkumar','manoj@novatium.com','S.manojkumar','Sp infocity,Block A,2 nd floor,40,M.G.R .Salai,kandanchavadi,','chennai','TN','INDIA','600096','918800796615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 08:10:36',0,NULL,3,1,3,1,'RA117773205CN\r ','manoj1979manojkumar\rWWHU001\r客户就要两个'),(5304,796316971012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',25.98,'eastar4','trojanjoe1025','trojanjoe1@yahoo.com','Joe cedillo','1245 Old Williamsport Pike','Columbia','TN','UNITED STATES','38401-5660','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 08:27:35',0,NULL,3,1,1,1,'、 ','trojanjoe1025'),(5305,719955930011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','dodo4206','dodo@midos-cheb.cz','Jakub Dolejš','Antala Staška 47','Cheb','cz','CZECH REPUBLIC','35002','+420604255982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 09:19:47',0,NULL,3,1,2,1,'\\ ','dodo4206\r欧标'),(5306,590215370013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','tadaimasanjo','magicman_in_vegas@hotmail.com','JOHNNY  LAYCO','1554 DAWLEY ST','LAS VEGAS','NV','UNITED STATES','89104-5422','(702) 431-1204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 09:40:56',0,NULL,3,1,1,1,'\\ ','tadaimasanjo'),(5307,799469942012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','ckostas2009','ckostas@freemail.gr','KOSTAS CHATZICHRISTOS','KEDRON 12<br>EVOSMOS','THESSALONIKI','','GREECE','56224','+306948066624','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 09:45:21',0,NULL,3,1,3,1,'RA117773188CN\r ','ckostas2009\r盒装的\rGLSG001*2'),(5308,719962321011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','hbilkut2','hbilkut@gmail.com','Huseyin Sihmanoglu','2120 Creekside Pkwy<br>Borderlinx/Dhl 0715-7509','Lockbourne','OH','UNITED STATES','43137-8500','937 353 7943','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 09:50:25',0,NULL,3,1,1,1,'\\ ','hbilkut2'),(5309,799475707012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','shapochkin','a.shapochkin@gmail.com','Anton Shapochkin','Geroev 2 -76','Kirishi','Leningradskaya oblast','RUSSIAN FEDERATION','187110','(7906)2625000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 10:08:17',0,NULL,3,1,2,1,'\\ ','shapochkin\r欧标'),(5310,799468331012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','adol2005','avaldesloz@yahoo.com','Adolfo Valdes','avenida de america 44 2 derecha','madrid','Madrid','SPAIN','28028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 10:12:57',0,NULL,3,1,3,1,'RA117773072CN\r ','adol2005\r盒装的\rGLSG001*2'),(5311,590227728013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','restrict_s','restrict@bk.ru','Dmitriy Malahovskiy','Kashirskoe highway 122-118','Moscow','Moscow','RUSSIAN FEDERATION','115582','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 10:51:02',0,NULL,3,1,3,1,'RA117722977CN\r ','restrict_s\rWLIN014'),(5312,799491644012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',2,'OTTP001',51.6,'eastar4','h203513882','meshibitonn@walla.co.il','hen biton','en ofarim 5/6','mizpe ramon','darom','ISRAEL','80600','0525991192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 11:05:13',0,NULL,3,1,3,1,'RA117773130CN\r ','h203513882\rOTTP001'),(5313,719983908011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','hotdog1827','jk31@talktalk.net','Jodie Kelly','16 Lower Green Road<br>Pembury','Tunbridge Wells','Kent','UNITED KINGDOM','TN2 4HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 11:10:36',0,NULL,3,1,3,1,'RA117722929CN\r ','hotdog1827\rOTSO001'),(5314,799504056012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','pwroth','paul.wroth@westnet.com.au','Paul Wroth','GHD Pty Ltd<br>239 Adelaide Tce','Perth','Western Australia','AUSTRALIA','6000','0862228349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 11:46:47',0,NULL,3,1,3,1,'RA117773165CN\r ','pwroth\r盒装的\rOTSO004*2'),(5315,720001150011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','perks4000','lucyperks@hotmail.com','Lucy Ewart-Perks','Sports Vision<br>5 Blythe Mews','London','London','UNITED KINGDOM','W14 0HW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 12:11:16',0,NULL,3,1,3,1,'RA117722932CN\r ','perks4000\rMOAP001'),(5316,720003746011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','narmynaz','nasreenhassan@msn.com','nasreen hassan','30 cherry cresent','Brentford','Middlesex','UNITED KINGDOM','Tw8 8nn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 12:20:17',0,NULL,3,1,3,1,'RA117722994CN\r ','narmynaz\rOTSO001'),(5317,720007794011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','drakos017','sir.drakos@gmail.com','Artur Lesiak','Romańska 1/14','Warszawa','mazowieckie','POLAND','01451','602 369612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 12:35:08',0,NULL,3,1,2,1,'\\ ','drakos017\rCCGR001'),(5318,590251077013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','mirza.za','amirza500@yahoo.co.uk','Aziz Patel','48 Gladstone Ave<br>Manor Park','London','London','UNITED KINGDOM','E126NS','442085522351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 12:57:40',0,NULL,3,1,2,1,'\\ ','mirza.za\r英标\rHSNO022'),(5319,683153145001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',89.99,'buysia','bernsal51','bmarsolais1@cogeco.ca','bernie marsolais','1339<br>lisieux st.','cornwall','ON','CANADA','k6j4z3','(613) 936-9244','NoPaymentFailure','CheckoutComplete','NotSelected','2011-06-08 13:05:29',0,NULL,3,1,3,1,'RA117773157CN\r ','bernsal51\rBR3D003'),(5320,799528501012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',23.9,'eastar4','woody-wombat','woody1404@yahoo.com','john  wood','p.o.box1053<br>rozelle','sydney','New South Wales','AUSTRALIA','2039','0418410310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 13:08:11',0,NULL,3,1,2,1,'\\ ','woody-wombat\r澳标\r一共买了两个'),(5321,720027377011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','kevinminutoli','kevin@minutoli.net','Kevin Minutoli','81 Woodbine St','Attleboro','MA','UNITED STATES','02703','(509) 208-8272','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 13:38:41',0,NULL,3,1,1,1,'\\ ','kevinminutoli'),(5322,799542396012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.4,'eastar4','demoncy10','demoncy@hotmail.com','Dimitris Dimitriou','104rd No40,P.Polemidia','Limassol','','CYPRUS','4130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 13:44:38',0,NULL,3,1,2,1,'\\ ','demoncy10\rHP 6pin 1.0 12cm'),(5323,799542546012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','millbill2006','chiepyeo@yahoo.com.sg','Victor Koh','35 Eunos Crescent<br>#08-276','default','','SINGAPORE','400035','(968) 130-88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 13:47:30',0,NULL,3,1,11,1,NULL,'millbill2006\rHSPL011'),(5324,720031052011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','szlachev','simonuca@gmail.com','Simon Zlachevsky','Av. Circunvalacion #1859<br>Pob. Huaytiquina','Calama','II REGION','CHILE','1394045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 13:50:36',0,NULL,3,1,2,1,'\\ ','szlachev'),(5325,799557936012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','garrichello','okladnik@frascati.enea.it','Igor Okladnikov','Sovetskaya 84-22','Tomsk','Tomskaya oblast','RUSSIAN FEDERATION','634034','79039508029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 14:25:15',0,NULL,3,1,3,1,'RA117773143CN\r ','garrichello\rOTPL001'),(5326,720049269011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','96svtcobra','controlledav@optonline.net','Josie Eschweiler','34 Tyler City Rd','Orange','CT','UNITED STATES','06477-2536','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 14:54:57',0,NULL,3,1,1,1,'\\ ','96svtcobra'),(5327,799570846012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','parthaarti','parthasengupta@gmail.com','Ena rastogi','H.No-806, Sector - 5 Double Storey<br>Rachna, Vaishali','Ghaziabad','UP','INDIA','201010','(997) 197-3174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 15:02:23',0,NULL,3,1,2,1,'\\ ','parthaarti'),(5328,799575412012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',35.99,'eastar4','alex.kuleshov','abysmo666@mail.ru','Alexey Kuleshov','Flat #94, 8 Himkinskiy boulevard','Moscow','','RUSSIAN FEDERATION','125364','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 15:14:19',0,NULL,3,1,3,1,'RA117722946CN\r ','alex.kuleshov\rWLIN001'),(5329,720060551011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','jabuenog','jabuenog@hotmail.com','JUAN ANTONIO BUENO GOMEZ','TRAVESIA DE FELIPE DE DIEGO Nº 25 PISO 9º A','MADRID','Madrid','SPAIN','28018','917854888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 15:20:00',0,NULL,3,1,2,1,'\\ ','jabuenog\r欧标'),(5330,720062584011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','sloc9422','slocke@brandeis.edu','Steve Locke','495 Swains Pond Ave','Melrose','MA','UNITED STATES','02176','(781) 736-7591','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 15:24:03',0,NULL,3,1,1,1,'\\ ','sloc9422'),(5331,720064012011,320627302363,'New Genuine Cisco PVDM2-32 32 Channel Voice DSP Module',2,'OTIN006',308,'eastar4','sell_buy_usa','natev@comp-sol.com','Nate Vanderweide','327 Kirkwood Ave','Iowa City','IA','UNITED STATES','52240','(319) 351-7549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 15:28:36',0,NULL,3,1,4,1,'YW865717496CN ','sell_buy_usa'),(5332,543027621004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',4,'WLAP002',101.96,'cnfaner','(i)','h5n1@live.ca','Gun Janetzki','#3 310 10th Street East','Saskatoon','SK','CANADA','s7n0c7','(306) 652-8164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 16:20:06',0,NULL,3,1,3,1,'RA117722915CN\r ','(i)\rWLAP002\r旧的'),(5333,590313694013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','gonzalonganiza','gonzalo.adp@gmail.com','Gonzalo Diaz Paiva','Exequiel Fernandez 419<br>Ñuñoa','Santiago','Santiago','CHILE','8320000','56022748346','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 16:53:38',0,NULL,3,1,2,1,'\\ ','gonzalonganiza'),(5334,590333590013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','kibergenii','typ-2011@mail.ru','Aliaksei pakhilka','Alex Pahilko Denisovskaya 6-200','Minsk','Minsk','BELARUS','220006','80293405166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 17:56:09',0,NULL,3,1,2,1,'\\ ','kibergenii'),(5335,799216683012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','andydunton','firstchoicedecs@aol.com','Andy Dunton','2 Thorney Lane North','Iver','Buckinghamshire','UNITED KINGDOM','SL0 9JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 18:03:42',0,NULL,3,1,3,1,'RA117723005CN\r ','andydunton\rHSPL011\r英标'),(5336,720134317011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','alex696alexeyalexey','assassin.85@list.ru','ALEXEY GALKIN','P.Savielievoj d. 52 kor 4 kv 52','Tver','Russia','RUSSIAN FEDERATION','170039','+7 920 1752224','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-08 18:16:50',0,NULL,3,1,3,1,'RA117722985CN\r ','alex696alexeyalexey\rHSNO019\r欧标'),(5337,720148325011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',44.79,'eastar4uk','palhinhas1975','luismpalhinhas@hotmail.com','luis vieira','flat 2 2 le geyt terrace<br>springfiled road','st helier','Channel Islands','UNITED KINGDOM','je2 4le','07797753744','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 18:42:04',0,NULL,3,1,3,1,'RA117773174CN\r ','palhinhas1975\rGLSG001'),(5338,799683406012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','oit_computing','nzych@oitc.ca','Outsource IT Inc NZYCH','3001 New Street<br>Unit 2','Burlington','ON','CANADA','L7R1K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:58:11',0,NULL,3,1,3,1,'RA117722963CN\r ','oit_computing\rGLSG001*2\r盒装的'),(5339,720162765011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','typhoon1251','milksds@hotmail.com','daniel mielke','1251 107th LN NE','blaine','MN','UNITED STATES','55434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 19:10:05',0,NULL,3,1,1,1,'\\ ','typhoon1251'),(5340,720196012011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',104.97,'eastar4','car.roberto','roberto.car@yandex.ru','Telechi Nicolae','Stefan cel Mare','Varzaresti','Nisporeni','MOLDOVA, REPUBLIC OF','6493','+(373) 79392189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 20:17:28',0,NULL,5,1,18,0,NULL,'car.roberto\rUDAP001  paypal 有问题'),(5341,799729274012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','jmoon476','jmoon476@aol.com','Josh Moon','411 Windridge Dr','Deatsville','AL','UNITED STATES','36022-2687','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 20:18:43',0,NULL,3,1,1,1,'\\ ','jmoon476\rGLSG001*2\r盒装的'),(5342,590400604013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','submaster-1979','submaster@mail.ru','Dmitry Vasiliev','5th line 46-28','St.-Petersburg','Russia','RUSSIAN FEDERATION','199004','+79219425334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 21:03:13',0,NULL,3,1,2,1,'\\ ','submaster-1979'),(5343,720228570011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',12.5,'eastar4','cru0gen_00','cru0gen@gmail.com','Dmitry Kepko','Svobody ave. 34 flat 208','Kyiv','','UKRAINE','04215','+380507448129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 21:31:33',0,NULL,3,1,2,1,'\\ ','cru0gen_00\rHP 8pin 1.0 3cm '),(5344,543125562004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',127,'cnfaner','veylor_pl','veylor@gmail.com','Michal Rojek','Komandorska 10','Gdansk','pomorskie','POLAND','80299','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 21:39:12',0,NULL,3,1,3,1,'RA117773069CN\r ','veylor_pl\rRCMA001'),(5345,720252472011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','lifesizestatue_com','bronzehorses@op.pl','Peter Soroka','1547 County Road 39<br># 27','Southampton','NY','UNITED STATES','11968-5201','(631) 255-9975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 22:44:22',0,NULL,3,1,1,1,'\\ ','lifesizestatue_com'),(5346,720254429011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',2,'ANYA001',28.9,'eastar4','tudijaidem','tomislav.radovic@gmail.com','Tomislav Radovic','Put Sv. Izidora 80<br>Croatia / Europe','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 22:51:46',0,NULL,3,1,3,1,'RA117773126CN\r ','tudijaidem\rANYA001'),(5347,720261690011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','2005brucev','bvarnerin@comcast.net','Bruce Varnerin','48 Bobbys Ct','Ridgefield','CT','UNITED STATES','06877','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 23:22:35',0,NULL,3,1,1,1,'\\ ','2005brucev'),(5348,799785796012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','janieco1962','janieco62@hotmail.com','Jane Copeland','435 Pico Avenue','San Simeon','CA','UNITED STATES','93452','(805) 765-7386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 23:38:43',0,NULL,3,1,1,1,'\\ ','janieco1962'),(5349,720267449011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','doran1','doran1@comcast.net','Doran Hoskins','73 Indigo Ln','Goose Creek','SC','UNITED STATES','29445','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 23:50:40',0,NULL,3,1,3,1,'RA117773276CN\r ','doran1\rANYA001'),(5350,720268544011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','weeeeple','natkiel@hotmail.com','Natalie Kiel','17211 Gardenland Ave','Bellflower','CA','UNITED STATES','90706-6819','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 23:54:07',0,NULL,3,1,1,1,'\\ ','weeeeple\r新地址\r228 S. Heliotrope Ave.\rMonrovia, CA 91016\r'),(5351,799823369012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','wandye','trevino@choicecable.net','Arthur O. Trevino','PO Box 3194','Mayaguez','PR','UNITED STATES','00681','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 00:59:23',0,NULL,3,1,1,1,'\\ ','wandye'),(5352,720286761011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','zahirabdiel','dmuriente@hotmail.com','David Muriente','PO Box 581','Anasco','PR','UNITED STATES','00610-0581','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 01:22:19',0,NULL,3,1,1,1,'\\ ','zahirabdiel'),(5353,590456327013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.49,'eastar4','3xrace','kevinmartin413@hotmail.com','Kevin Martin','3138 Jenkins Dr','Regina','SK','CANADA','S4N 6Y1','(306) 539-6946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 01:32:06',0,NULL,3,1,2,1,'、 ','3xrace\r新地址\rKevin Martin\r805 Fairford st East\rMoose Jaw, SK\rS6H 0G3\rCANADA\r'),(5354,720295057011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','armadillo85641','scottmc85641@msn.com','John McCartney','1021 N Solar Dr','Vail','AZ','UNITED STATES','85641-9745','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 01:53:48',0,NULL,3,1,1,1,'\\ ','armadillo85641'),(5355,799835327012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','bbelectric60','bbelectric57@yahoo.com','Benjamin Brown','111 Highway 39','Ingram','TX','UNITED STATES','78025-3275','(830) 367-7374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 01:56:34',0,NULL,3,1,1,1,'\\ ','bbelectric60'),(5356,720298065011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','oakland68','rick@truckncrane.com','rick reyes','2558 Scenic Ave','Oakland','CA','UNITED STATES','94602-3025','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 02:05:28',0,NULL,3,1,1,1,'\\ ','oakland68'),(5357,720304500011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mrtonimontana','palushi@hotmail.co.uk','S Palushi','59 brixham drive','coventry','West Midlands','UNITED KINGDOM','cv2 3la','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 02:35:46',0,NULL,3,1,2,1,'\\ ','mrtonimontana'),(5358,543186842004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCY001',53.99,'cnfaner','amssantanna71','amssantanna@yahoo.com.br','Alessandro Sant\'Anna','Rua Sergio Luiz Guimaraes Aguiar 242','Sao Jose dos Campos','Sao Paulo','BRAZIL','12246007','1239226353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 03:42:33',0,NULL,3,0,3,1,'RA117773435CN ','amssantanna71\rWWOT003+ANCN001'),(5359,720323200011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','belanjar61','dsaus61@iprimus.com.au','Don U A Schulz','PO Box A2398','Sydney South','New South Wales','AUSTRALIA','1235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 04:13:56',0,NULL,3,1,3,1,'RA117773395CN ','belanjar61\rKBNO001\rNOKIA SU-8W蓝牙键盘'),(5360,720332839011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','bigmike01star','robersonmr@gmail.com','Michael Roberson','2011 Chapel Heights Dr','Wharton','TX','UNITED STATES','77488-4463','(281) 532-5101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 05:12:42',0,NULL,3,1,1,1,'、 ','bigmike01star'),(5361,590498533013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','wessun96','ghost282@yandex.ru','Pavel Skobelkin','Truda st.<br>50-120','Izhevsk','Udmurt Republic','RUSSIAN FEDERATION','426067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 06:34:07',0,NULL,3,1,3,1,'RA117773758CN\r ','wessun96\rOTES001'),(5362,799904278012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','cjgilalv','cjgilalv@hotmail.com','Carlos Gil Alvarez','c/ Las Palmeras, núm. 5 (MRL)','*','Zaragoza','SPAIN','50011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 07:20:16',0,NULL,3,1,3,1,'RA117773320CN ','cjgilalv\rOTSO001'),(5363,590506577013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','ochki2011','kurpatich137@gmail.com','Yevgeniy Grozin','Shishkina d.16 kv.30','Irkutsk','Irkutskaya oblast','RUSSIAN FEDERATION','664020','79027677475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 07:38:03',0,NULL,3,1,3,1,'RA117773506CN\r ','ochki2011\r欧标\rHSNO019'),(5364,590513621013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:24:11',0,NULL,5,0,18,1,NULL,'pose19\r'),(5365,590514181013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:27:12',0,NULL,5,0,18,0,NULL,'pose19'),(5366,590514364013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:28:30',0,NULL,5,0,18,0,NULL,'pose19'),(5367,590514880013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:32:07',0,NULL,5,0,18,0,NULL,'pose19'),(5371,590530767013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',39.95,'eastar4','pws_wilson','helpmehell@hotmail.com','8b, Block 18','Villa Rhapsody,Symphony Bay<br>Sai Kung, N.T.','default','','HONG KONG','default','61964778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 10:14:41',0,NULL,3,1,14,1,'010911047062 ','pws_wilson\r盒装的\rMOLO008\r新地址\rwai shun pak\r8b, Block 18\rVilla Rhapsody,Symphony Bay\rSai Kung, N.T.\rdefault  default\rHONG KONG\r61964778\r'),(5368,590515081013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:34:17',0,NULL,5,0,18,0,NULL,'pose19'),(5369,590515505013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:36:20',0,NULL,5,0,18,0,NULL,'pose19'),(5370,590515772013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','pose19','soojo19@hotmail.com','SooJo Park','528-1, Joan-nyj, Joan-myeon','Namyangju-si, Gyeonggi-do','','KOREA,REPUBLIC OF','472-870','010-9108-8231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:38:09',0,NULL,5,0,18,0,NULL,'pose19'),(5372,720395249011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','ngahun','boxair@gmail.com','Nagy Gabor Attila','Korosi Cs. S. u. 6/b','Pecs','Hungary','HUNGARY','H-7633','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 10:20:05',0,NULL,3,1,2,1,'\\ ','ngahun\racer 8pin1.00 15cm'),(5373,543238153004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',15.55,'cnfaner','gff_mirj','gff_mirj@hotmail.com','Fahrim Guluzade','Ismayil Hidayatzada str. 20A, app 37','Baku','Narimanov','AZERBAIJAN','AZ1154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 10:27:45',0,NULL,3,1,3,1,'RA117773585CN\r ','gff_mirj\rHSPL002'),(5374,543239999004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','artworld','ebaywest@verizon.net','michael westreich','18 madison ave','madison','NJ','UNITED STATES','07940','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 10:38:45',0,NULL,3,1,1,1,'\\ ','artworld'),(5375,590539955013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',22,'eastar4','tamo3103','a-s-hakim@gmx.de','Ahmad Shah Hakim','Karl-Marx-Ring 24','München','','GERMANY','81735','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 11:05:09',0,NULL,3,1,2,1,'\\ ','tamo3103'),(5376,720412088011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','021francois','fjordaan@deloitte.co.za','Francois Jordaan','PO Box 587','cape Town','Western Cape','SOUTH AFRICA','8001','021 4275383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 11:26:24',0,NULL,3,1,2,1,'\\ ','021francois'),(5377,720416983011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','rysenko','rysenko@gmail.com','Alexander Rysenko','Frunze 36-16','Simferopol','Crimea','UKRAINE','95017','+380506314485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 11:47:23',0,NULL,3,1,2,1,'\\ ','rysenko'),(5378,590548628013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','mirocere','miro@wircom.sk','miroslav  ceresnik','ludovitova 45','ludovitova','slovakia','SLOVAK REPUBLIC','95144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 11:51:37',0,NULL,3,1,2,1,'\\ ','mirocere'),(5379,720421897011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','rdep2086','depaolarobert@gmail.com','Robert de Paola','807 Rosa St.','Celebration','FL','UNITED STATES','34747','(321) 402-9176','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 11:59:33',0,NULL,3,1,1,1,'\\ ','rdep2086'),(5380,720425264011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','mczolbe','dekan@web.de','Martin Czolbe','Am Trog 9','Würzburg','','GERMANY','97076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 12:12:47',0,NULL,3,1,2,1,'\\ ','mczolbe'),(5381,720433724011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',12.5,'eastar4','frikadelleweck92','janjakobfries@web.de','Jan Jakob Fries','Schulstr. 4','Hoppstädten','','GERMANY','67744','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 12:44:23',0,NULL,3,1,2,1,'\\ ','frikadelleweck92\racer 4pin1.25 15cm'),(5382,799996945012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',2,'HSMO018',25.98,'eastar4','palmer4545','williampalmerproperties@yahoo.com','kristen metcalf','911 Queen Annes Rd','houston','TX','UNITED STATES','77024-3304','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 13:10:16',0,NULL,3,1,1,1,'\\ ','palmer4545'),(5383,800001897012,220786829840,'New SonyEricsson HBH-PV703 Bluetooth Headset flower ver',1,'HSSE004',21.9,'eastar4','ml_teclacenter','gustavo@teclacenter.com.br','Gustavo Henrique dos Santos','Avenida Guarulhos, 3904/3954','Guarulhos','São Paulo','BRAZIL','07030-001','5511 24141940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 13:28:22',0,NULL,3,1,2,1,' \\','ml_teclacenter\r带花的'),(5384,798599008012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','incyte01','incyte@gmail.com','Jose Carrero','2170 2nd Ave<br>Apt 4N','New York','NY','UNITED STATES','10029-2943','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 14:01:03',0,NULL,3,0,1,1,'\\ ','incyte01'),(5385,720464758011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','javaduda','javaduda@yahoo.com','Thao Gregory','345 Chelsey Ct','Alpharetta','GA','UNITED STATES','30004-1182','(678) 634-9650','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 14:25:45',0,NULL,3,1,1,1,'\\ ','javaduda'),(5386,800026341012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.37,'eastar4','jaras_cro','josiparas@gmail.com','Josip Aras','Obala palih omladinaca 11','Šibenik','Croatia','CROATIA','22000','+38598816414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 14:38:56',0,NULL,3,1,3,1,'RA117773523CN\r ','jaras_cro\rOTCN004*10'),(5387,590583971013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',12.5,'eastar4','pkbuynsell','pius.kyan@gmail.com','Pius Kyan','2-F Frederick Street<br>Hornsby','Sydney','New South Wales','AUSTRALIA','2077','61418206637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 14:41:55',0,NULL,3,1,2,1,'\\ ','pkbuynsell\r华硕 8pin 1.0 6cm '),(5388,590586107013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.49,'eastar4','switz','steve@switzland.com','Steven Switzer','11858 Cement Hill Road','Nevada City','CA','UNITED STATES','95959','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 14:46:22',0,NULL,3,1,1,1,'\\ ','switz'),(5389,720153258011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ebiinc','bmaheux@electrobeauce.com','Barbara Maheux','2250, 90E RUE','SAINT-GEORGES','QC','CANADA','G5Y 7J7','(418) 228-5505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 14:55:24',0,NULL,3,1,2,1,'\\ ','ebiinc\r红边优联'),(5390,543290011004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.95,'cnfaner','robo-bay','robophone@live.com','Stephen James','91-024 Pohakupuna Pl','Ewa Beach','HI','UNITED STATES','96706-2319','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 14:57:31',0,NULL,3,1,1,1,'\\ ','robo-bay\r美标'),(5391,720476070011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',3,'ANTY002',10.74,'eastar4','erasmius','paulfpan@comcast.net','Paul F. Panadero','148 Washington St','Medford','MA','UNITED STATES','02155-4740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 14:57:40',0,NULL,3,1,1,1,'\\ ','erasmius'),(5392,543294663004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',2,'WWSI006',118,'cnfaner','atco22','atco22@yahoo.com.sg','Stanley Cheng','Blk 336 Tampines St.32 #06-478','Singapore','Singapore','SINGAPORE','520336','94750022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 15:18:52',0,NULL,3,1,3,1,'RA117773571CN\r ','atco22\rWWSI006'),(5393,717864956011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','mannoiaj','mannoiaj@msu.edu','Jeff Mannoia','4639 Salzburg Cir','Portage','MI','UNITED STATES','49024-3041','(269) 216-3168','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 15:32:05',0,NULL,3,1,1,1,'\\ ','mannoiaj'),(5394,720496861011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','russrezek','blackenedchaos@gmail.com','Russell Rezek','5931 Bertram Ave','Baltimore','MD','UNITED STATES','21214-2002','(410) 206-3830','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 15:57:04',0,NULL,3,1,1,1,'\\ ','russrezek'),(5395,800057586012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','ubiquity808','ubiquity808@hotmail.com','Jo Coring','2122 8th Ave N<br>Apt 102','Seattle','WA','UNITED STATES','98109-2406','(206) 228-3010','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 15:58:42',0,NULL,3,1,1,1,'\\ ','ubiquity808\r红边优联'),(5396,720501420011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','whbxj','buckjee@gmail.com','Buck Jee','5 Haynes Ave','Dobbs Ferry','NY','UNITED STATES','10522','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 16:08:14',0,NULL,3,1,1,1,'\\ ','whbxj'),(5397,720528286011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',158,'eastar4','vonofas','safamm76@gmail.com','Aleksey Safonov','193 Karla Libknehta Str. App.53.','Irkutsk','Irkutskaya oblast','RUSSIAN FEDERATION','664047','+79021777717','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-09 17:16:23',0,NULL,3,1,3,1,'RA117773801CN\r ','vonofas\rOTSO004*2'),(5398,800092269012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','irene*ibow3102','ibowden1@hotmail.com','irene bowden','11 mill road<br>insch','aberdeen','Aberdeenshire','UNITED KINGDOM','ab526ja','01224821799','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-09 17:19:04',0,NULL,3,1,3,1,'RA117773735CN\r ','irene*ibow3102\rGLSG001*2'),(5399,720557500011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',2,'OTGR001+OTGR002+OTGR003',119.98,'eastar4','2bb6896','aileenhsiao@hotmail.com','aileen hsiao','17360 Colima Rd<br># 115','rowland heights','CA','UNITED STATES','91748-1628','(626) 780-2262','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 18:20:51',0,NULL,3,1,4,1,'YW865717570CN ','2bb6896\r带花洒座的'),(5400,590482983013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',79.99,'eastar4','nelson.i.rosa','nelson.i.rosa@hotmail.com','Nelson Rosa','10 St O#1<br>Castellana Gardens','Carolina','PR','UNITED STATES','00983','(787) 237-5353','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 18:23:19',0,NULL,3,1,1,1,'\\ ','nelson.i.rosa'),(5401,800142897012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','missouritools','hcourtney@uniteone.net','Heath Courtney','1004 Erica Ct','Kearney','MO','UNITED STATES','64060','(816) 560-2611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 18:56:05',0,NULL,3,1,1,1,'\\ ','missouritools'),(5402,720575275011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.96,'eastar4','ehoosterbaan','ehoosterbaan@hotmail.com','Erik Oosterbaan','4359 Aster Blvd','Howell','MI','UNITED STATES','48843-6629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 18:57:35',0,NULL,3,1,1,1,'\\ ','ehoosterbaan'),(5403,800145025012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','1bigpapabear','facman213@aol.com','Russell Bryant','134 Clarendon Ave','Baltimore','MD','UNITED STATES','21208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 18:59:29',0,NULL,3,1,1,1,'\\\r ','1bigpapabear'),(5404,800147101012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','shahndavid','metabutch@gmail.com','Shahn Dickson','241 Main St','Montpelier','VT','UNITED STATES','05602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 19:02:59',0,NULL,3,1,1,1,'\\ ','shahndavid\r红边优联'),(5405,720578433011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','roadwan','radowan@post.cz','Radek Pauli','Na Jarove 2067/30','Prague','Czech Republic','CZECH REPUBLIC','13000','+420775012916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:19:56',0,NULL,3,1,2,1,'\\ ','roadwan'),(5406,800162101012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','tuger_inceler','tuger@softhome.net','Tuger Inceler','G.M.K BULVARI 23/B<br>DOGU MOBILYA KIZILAY','Ankara','Ankara','TURKEY','06420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:30:48',0,NULL,3,1,3,1,'RA117773727CN\r ','tuger_inceler\r盒装的\rOTSO004*2'),(5407,720599018011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',18.99,'eastar4','peter880705','peter8875@naver.com','Peter gloex','601 Penhorn Ave<br>Ste 2','Secaucus','NJ','UNITED STATES','07094-2137','(201) 583-1500 ext.: 821047308875','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 19:43:37',0,NULL,5,0,18,0,NULL,'peter880705\r客户要撤单'),(5408,720603556011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','vespucio2000','vespucio2000@hotmail.com','Valeriano Pereira da Silva','Rua dos Campineiros<br>26','Sao Paulo','SP','BRAZIL','03167-020','55 11 35712007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:52:28',0,NULL,3,1,3,1,'RA117773713CN\r ','vespucio2000\rGLSG001'),(5409,543385463004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.45,'cnfaner','xto.xc2z','henrik_winter@web.de','Henrik Winter','Wickenhohle 2','Rosenthal','','GERMANY','35119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 20:36:40',0,NULL,3,1,3,1,'RA117773568CN\r ','xto.xc2z\rWLIN010+ANTY002'),(5410,800200868012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','latchman2007','melissa.headley07@my.northampton.ac.uk','melissa latchman','40 chalcombe avenue<br>kingsthorpe','northampton','Northamptonshire','UNITED KINGDOM','nn2 8jq','01604820085','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-09 20:45:00',0,NULL,3,1,3,1,'RA117773608CN\r ','latchman2007\rHSMO018\r英标'),(5411,800204903012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',69.99,'eastar4','virtualsudip','f66459092@gmail.com','Dinesh Hinduja (c/o Enprocon Enterprise Ltd.)','A/4 8th Floor, Safal Profitaire<br>Corporate Road, Prahlad Nagar','Ahmedabad','GJ','INDIA','380015','9725573100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 20:52:54',0,NULL,3,1,3,1,'RA117773687CN\r ','virtualsudip\rKBLO001'),(5412,590713645013,230504995230,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',16.99,'eastar4','ms.crysta03','culclager2003@sbcglobal.net','Crystal Culclager','702 Union','Altheimer','AR','UNITED STATES','72004','(870) 766-8340','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 21:31:24',0,NULL,3,1,1,1,'\\ ','ms.crysta03'),(5413,720647993011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','gioiah','gioia.heiser@gmail.com','Gioia Heiser','40340 Wood Ct','Palmdale','CA','UNITED STATES','93551','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 21:32:17',0,NULL,3,1,1,1,'\\ ','gioiah'),(5414,800234553012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','beechcraft86','rodriguez7808@bellsouth.net','Jose L. Rodriguez','11016 SW 124th Ct','Miami','FL','UNITED STATES','33186-4815','(305) 342-5153','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 22:01:20',0,NULL,3,1,1,1,'\\ ','beechcraft86\r红边优联'),(5415,683771611001,110698278066,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',79.99,'buysia','jonbader9377','jonbader@magic.fr','Dr Jon Bader','952 Chemin de St Etienne','St Paul de Vence','','FRANCE','06570','(334) 933-2044 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 22:04:48',0,NULL,3,1,3,1,'RA117773660CN\r ','jonbader9377\rBR3D002'),(5416,720665069011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',119.99,'eastar4','julitrape','julitrapero@hotmail.com','julian martinez trapero','c/ramon y cajal,29','catral','Comunidad Valenciana','SPAIN','03158','610753566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 22:23:14',0,NULL,3,0,3,1,'RA117773744CN\r ','julitrape\rGLSG001*2'),(5417,800245696012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','willlovekaycee','willsmith01220@yahoo.com','William T Smith Sr','1 Marietta St','North Adams','MA','UNITED STATES','01247-2636','(413) 672-1744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 22:35:27',0,NULL,3,1,1,1,'\\ ','willlovekaycee'),(5418,800246998012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',22.59,'eastar4','gafar65','gafar@yandex.ru','Oleg Tarasov','ul.Zoi Kosmodemyanskoy,d.12,kv.90','Vladivostok','RU','RUSSIAN FEDERATION','690063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 22:40:24',0,NULL,3,1,2,1,'\\ ','gafar65\r再发一个New Atheros AR9287 \r一个Bracket of half intel 5300 半高卡架子\r'),(5419,543430770004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','chihanchiou','cchiou2@jhu.edu','Chi-Han Chiou','2905 N Charles St<br>Apt 1','Baltimore','MD','UNITED STATES','21218-4046','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 23:44:55',0,NULL,3,1,1,1,'\\ ','chihanchiou'),(5420,537752883003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','mox1980','moxiebay@gmail.com','Nicolas Brown','Unit 42, 3482 Main Beach Pde.<br>Main Beach','Gold Coast','Queensland','AUSTRALIA','4217','04131863893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 23:48:17',0,NULL,3,1,3,1,'RA117773656CN\r ','mox1980\rWWOT003'),(5421,800271792012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','vic246812','vsikka@atmc.net','Vic Sikka','1027 Marshside Way','Belville','NC','UNITED STATES','28451-7418','(910) 383-2136','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 00:11:21',0,NULL,3,1,1,1,'\\ ','vic246812'),(5422,590753894013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','leighb1993','leighb0103@live.com.au','Leigh Brownfield','4 Tara Close','Croydon','Victoria','AUSTRALIA','3136','0400766119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 00:52:31',0,NULL,3,1,2,1,'\\ ','leighb1993\rCAB-SS-2626'),(5423,720704871011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','caseybmxer','caseybassett@sbcglobal.net','Casey Bassett','1000 N Lemoore Ave.<br>Apt. #18','Lemoore','CA','UNITED STATES','93245','(831) 676-6211','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 01:07:58',0,NULL,3,1,1,1,'\\ ','caseybmxer'),(5424,683814961001,110698278066,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',79.99,'buysia','arcadiacomponents','f.caporusso@arcadiacomp.com','Frank Caporusso','455 White Pine Dr','Salt Lake City','UT','UNITED STATES','84123-4634','(801) 261-5300 ext.: 225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 01:14:23',0,NULL,3,1,1,1,'\\ ','arcadiacomponents'),(5425,537768404003,130490963329,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.45,'cnfaner','dantti85','dantti85-ebay@yahoo.com.br','Daniel Nicoletti','Rua Dr. Gabriel Piza, 636<br>Apto 54','Sao Paulo','Sao Paulo','BRAZIL','02036011','1182683318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 01:44:16',0,NULL,3,1,3,1,'RA117773642CN\r ','dantti85\rWLIN010'),(5426,540588206004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','ranieri_prado','ranieri_p@hotmail.com','Ranieri Prado','Av. Carlos Kuntz Busch, nº 851 (fundos)<br>Pq. Egisto Ragazzo','Limeira','São Paulo','BRAZIL','13485-346','55(19)3495-4840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 02:02:11',0,NULL,3,1,3,1,'RA117773639CN\r ','ranieri_prado\rOTCR001'),(5427,800299977012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',10.5,'eastar4uk','gl07focus','sensamdut@yahoo.co.uk','Samuel Dutch Sentongo','2 Granary Road<br>Off Selby Street','Whitechapel','London','UNITED KINGDOM','E1 5DF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 02:02:57',0,NULL,3,1,3,1,'RA117773625CN\r ','gl07focus\rHSPL002'),(5428,590768424013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','fury-161','furyonesixone@gmail.com','Andrew Scott','Centre for Science Communication<br>303a Great King Street','Dunedin','Otago','NEW ZEALAND','9016','01201242827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 02:11:14',0,NULL,3,1,2,1,'\\ ','fury-161'),(5429,590770153013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.58,'eastar4','shoppinglilmama13','galloway1@cox.net','Lawrence Houston','217 N B St','Pensacola','FL','UNITED STATES','32502-4663','(850) 346-0722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 02:24:28',0,NULL,3,1,1,1,'\\ ','shoppinglilmama13'),(5430,800310499012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','zemlyanin','mayerav@gmail.com','Alexander Mayer','Fedorova, 59 - 4','Surgut','HMAO - Ugra','RUSSIAN FEDERATION','628400','922-659-7424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 02:47:25',0,NULL,3,1,2,1,'\\ ','zemlyanin'),(5431,720729321011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',2,'HSPL015',105.8,'eastar4','marcel_alves','marcelr90@gmail.com','marcel alves dias paes','estr. M. Miguel Salazar M. de Morais<br>n:291 venus 805','rio de janeiro','rio de janeiro','BRAZIL','22770-330','0021552133420994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 02:55:30',0,NULL,3,1,3,1,'RA117773792CN\r ','marcel_alves\rHSPL015'),(5432,720734626011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','simightelecommunications','simightelecoms@yahoo.com.au','Simon Leigh','126 Greville Street','Chatswood','New South Wales','AUSTRALIA','2067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 03:27:52',0,NULL,3,1,2,1,'\\ ','simightelecommunications'),(5433,800360552012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',10.99,'eastar4uk','brentcot','sshuttleworth@hotmail.co.uk','Beth Shuttleworth C/O BCD Travel ltd','Bell Tower House<br>Bell Street','Maidenhead','Berkshire','UNITED KINGDOM','SL61BU','07515478199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 06:55:52',0,NULL,3,1,3,1,'RA117773789CN\r ','brentcot\rHSMO011+CCMO001'),(5434,590809427013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','indieinkkid','neshcoleman11@gmail.com','Anesha Rogers','6688 Balsam Dr','bedford Heights','OH','UNITED STATES','44146-4805','(440) 715-5254','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 07:05:23',0,NULL,3,1,1,1,'\\ ','indieinkkid'),(5435,720787149011,320394905532,'Acer Aspire 7110 7000 9300 Bluetooth Module 2.0 +cable',1,'BTAC2008',12.5,'eastar4','bohrok2610','martti.kauppinen@saunalahti.fi','Martti Kauppinen','Hämeenapajantie 20 B','Helsinki','','FINLAND','00850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 08:07:09',0,NULL,3,1,2,1,'\\ ','bohrok2610\racer 4pin1.25 18cm'),(5436,590820795013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','solanoesen30','josovi@telefonica.net','JOSE MARTIN SOLANO VIDAL','C CORTIJO DE ABAJO Nº1','LA UNIÓN','Murcia','SPAIN','30360','968337564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 08:23:01',0,NULL,3,1,3,1,'RA117773965CN ','solanoesen30\rOTRA003'),(5437,800386520012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','gatosanluka18','gato_sanluka@hotmail.com','Ruben Caravaca Martin','Avenida de Sevilla,11<br>Junto al Lavacoche RaYca','Sanlucar de Barrameda','Andalucía Ceuta y Melilla','SPAIN','11540','691118082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 08:54:50',0,NULL,3,1,2,1,'\\ ','gatosanluka18'),(5438,800392602012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','malik.nurbol','nurbol.malik@gmail.com','Nurbol Malik','Auezov str 165a, room 42','Almaty','Almaty','KAZAKHSTAN','050057','+77077982663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 09:17:06',0,NULL,3,1,2,1,'\\ ','malik.nurbol'),(5439,800393351012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','randulforoi','nana@josecperez.jazztel.es','jose carlos perez fernandez','Juan de Luna 8<br>Urb. SigloXXI','Zamora','Zamora','SPAIN','49029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 09:20:15',0,NULL,3,1,2,1,'\\','randulforoi\r红边优联'),(5440,590836164013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',20,'eastar4','firo_cz','firo@centrum.cz','HiProject - Marek Netuka','Stankova 8a','Brno','CZ','CZECH REPUBLIC','60200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 10:02:03',0,NULL,3,1,2,1,'\\ ','firo_cz\r棕色的 欧标'),(5441,720823397011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','dkorbee','dkorbee@tiscali.nl','Duncan Korbee','Leeghwaterstraat 15','Schoonhoven','','NETHERLANDS','2871 PC','06-55196193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 10:46:32',0,NULL,3,1,2,1,'\\ ','dkorbee'),(5442,800424029012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.6,'eastar4','eldaky','eldaky@msn.com','Abellir Sabates','C/ masia de la cova 1 bajo','Manises','Comunidad Valenciana','SPAIN','46940','961531373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:14:03',0,NULL,3,1,2,1,'\\ ','eldaky\r旧的'),(5443,720831886011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','funmpvs','funmpvs@yahoo.com','Tharsimon Sapuan','Blk 132 Choa Chu Kang Ave 1 #07-02','Singapore','','SINGAPORE','680132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:18:34',0,NULL,3,1,11,1,NULL,'funmpvs\rRELO002'),(5444,590851144013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','ko5ma','akniespo@gmail.com','Andrzej Kosma Niespodziewany','Ostatnia 2D/10','Krakow','małopolskie','POLAND','31-444','600 001713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:24:29',0,NULL,3,1,2,1,'\\ ','ko5ma'),(5445,800430936012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','tonykw89','tonywong89@yahoo.com','Tony Wong','8 Westminster Close','Sale','Cheshire','UNITED KINGDOM','M335WZ','07710230991','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 11:38:33',0,NULL,3,1,3,1,'RA117721438CN\r ','tonykw89\rANCN001'),(5446,720839554011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',69.9,'eastar4','garca69','apgarca@mac.com','adriano ponta garca','kita ku fujiwaradai minami machi 2-7-11','kobe','Hyogo','JAPAN','651-1303','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:48:35',0,NULL,3,1,3,1,'RA117721424CN\r ','garca69\rHSPL009'),(5447,720842863011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','tarciana.melo','tarcianamelo@gmail.com','Tarciana Gomes','Rua General Polidoro, 100<br>Apto 201','Recife','Pernambuco','BRAZIL','50740-050','081-99736517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:58:29',0,NULL,3,1,3,1,'RA117721676CN\r ','tarciana.melo\rKBNO001'),(5448,800439858012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','goldengreek0','peterp@exemail.com.au','Peter Panagaris','22 Epping Road','Epping','New South Wales','AUSTRALIA','2121','0414471738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 12:07:55',0,NULL,3,1,3,1,'RA117721755CN\r ','goldengreek0\rOTSO004*2'),(5449,590861000013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','alchik77','varalla@rambler.ru','Alla Maslova','Svobody 51-8','Ryazan','Ryazanskaya oblast\'','RUSSIAN FEDERATION','390006','903-693-4733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 12:20:11',0,NULL,3,1,3,1,'RA117721486CN\r ','alchik77\rHSNO019\r欧标'),(5450,720860994011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',36.99,'eastar4','gerizaldo.maia','gerizaldo@gmail.com','Gerizaldo Maia','Rua Silvino Lopes 480, Apto. 804<br>Tambaú','João Pessoa','PB','BRAZIL','58039-190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 13:00:28',0,NULL,3,1,3,1,'RA117721319CN ','gerizaldo.maia\rWWSI005+ANCN001'),(5451,720883341011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','ems_pilot','matthewpellegrino@yahoo.com','Matthew Pellegrino','110 Aberdeen Ave','Enterprise','AL','UNITED STATES','36330-2306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 14:11:55',0,NULL,3,1,1,1,'\\  ','ems_pilot'),(5452,716647497011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','hansa1102','vashist.jalim@gmail.com','Hansa Jalim','Ramsoondar Lane<br>Solferino','Vacoas','','MAURITIUS','742CU001','2307885858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 14:19:22',0,NULL,3,1,2,1,'\\ ','hansa1102'),(5453,590890838013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','tripikotiko','sara_jul_vernet@hotmail.com','sara jul vernet','doctor modrego 18 3º 1º','badalona','Cataluña','SPAIN','08918','933831299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 14:42:06',0,NULL,3,1,3,1,'RA117721407CN\r ','tripikotiko\rOTRA003'),(5454,800522707012,220778513744,'NIB AUI Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRMX004',67.96,'eastar4','ipodamou','arnaud-b@optionplus.com','Patrick Hope TCC','350 Lear Ave','Costa Mesa','CA','UNITED STATES','92626-6015','800 832 2225 121','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-10 16:05:24',0,NULL,3,1,1,1,'\\  ','ipodamou\r一共买了四个\r盒装的'),(5455,590920691013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','rezaben','studio193@free.fr','Lemonnier Antoine','193, rue St Denis Boite 52','Paris','Île-de-France','FRANCE','75002','06.50.00.90.67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 16:22:37',0,NULL,3,1,3,1,'RA117721530CN\r ','rezaben\rMOSA002'),(5456,800525120012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',2,'OTCN005*10',31.58,'eastar4','sterrero','santoterrero@gmail.com','Santo Terrero','8400 NW 25th St<br>Ste 110','Doral','FL','UNITED STATES','33122-1530','829 960 6666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 16:24:22',0,NULL,3,1,1,1,'\\  ','sterrero\r白色的'),(5457,590930891013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','andvari3d','kaito3d@gmail.com','Bruno Camousseigt','Av. Jose Pedro Alessandri #1827','Santiago','Metropolitana','CHILE','7780266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 16:57:57',0,NULL,3,1,3,1,'RA117721659CN\r ','andvari3d\rOTRA003'),(5458,800546991012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','billym361','roctek@yahoo.com','William Mullins','8806 N Navarro St<br># 180 Ste 600','Victoria','TX','UNITED STATES','77904','(361) 652-9635','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 17:00:19',0,NULL,3,0,1,1,'\\  ','billym361\r盒装的'),(5459,800551390012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','christiandream','christiandream@live.com','christian gillman','4575 N Reynolds Rd','lake ann','MI','UNITED STATES','49650-9702','(231) 590-8401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 17:09:42',0,NULL,3,1,1,1,'\\  ','christiandream\r红边优联'),(5460,720949679011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',4,'CASS001',34.8,'eastar4','sunvus','regvus@gmail.com','Yevgeniy Demyan','Entuziastov st. 24/124','Dubna','RU','RUSSIAN FEDERATION','141983','79265978962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 17:17:23',0,NULL,3,1,3,1,'RA117721565CN ','sunvus\rCASS001'),(5461,720967167011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','antoniocarlosmiro','antoniomiro@globo.com','ANTONIO CARLOS GRAS MIRO DE CAMARGO','RUA ARNALDO VICTALIANO, 150 APTO 104<br>BAIRRO: JD PALMA TRVASSOS','RIBEIRÃO PRETO','SÃO PAULO','BRAZIL','14091220','55-16-81657310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 17:59:28',0,NULL,3,1,3,1,'RA117721733CN\r ','antoniocarlosmiro\rGLSG001'),(5462,800571374012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',18.98,'eastar4','raup.silva','raupsessim@gmail.com','Raup Silva','Rua General João Telles, 542/503 Bom Fim<br>Bom Fim','Porto Alegre','Rio Grande do Sul','BRAZIL','90035-120','51-99785548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 18:01:24',0,NULL,3,1,2,1,'\\','raup.silva'),(5463,590956098013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',64.98,'eastar4','josh728','balloonguyinc@yahoo.com','Michael Novak','4032 Morning Star Dr','Huntington Beach','CA','UNITED STATES','92649-3010','(714) 403-4131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 18:21:04',0,NULL,3,1,1,1,'\\  ','josh728'),(5464,800592799012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','cx500-2008','adrian.holmes6@btinternet.com','Adrian Holmes','17 Beech Avenue','Attleborough','Norfolk','UNITED KINGDOM','NR17 2ET','01953452747','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 18:36:36',0,NULL,3,1,3,1,'RA117721588CN ','cx500-2008\rHSPL011\r英标'),(5465,720994952011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT004',118,'eastar4','cmackproductions','christianmack@me.com','Christian Mack','2519 2nd ST<br>2','Santa Monica','CA','UNITED STATES','90405','(646) 752-4926','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 19:00:05',0,NULL,3,1,1,1,'\\  ','cmackproductions'),(5466,800605391012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','lucyg50','lucyg50@aol.com','Anastacia Loftus','2304 Brownsville Rd<br>Trlr A46','Langhorne','PA','UNITED STATES','19053-2502','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 19:02:35',0,NULL,3,0,1,1,'\\  ','lucyg50\r盒装的'),(5467,590981808013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','raul_ghiran18209','raul_ghiran@yahoo.com','Raul Samuel Ghiran','Abrud 35A','Arad','Arad','ROMANIA','310317','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 19:38:47',0,NULL,3,1,2,1,'\\ ','raul_ghiran18209'),(5468,590983945013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','hanskafred','u-hoehl@t-online.de','Uwe Höhl','Theresienstr.5','Hückelhoven-Baal','','GERMANY','41836','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 19:45:48',0,NULL,3,1,3,1,'RA117721526CN\r ','hanskafred\rWWOT001+ANCN001'),(5469,591002763013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','antoinen','leflate@gmail.com','Antoine Nguyen','905 Plymouth Apt. 213','Mont-Royal','QC','CANADA','H4P1B2','(514) 999-1222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 20:45:39',0,NULL,3,1,3,1,'RA117721968CN\r ','antoinen\rMOSA005'),(5470,800679672012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',21.9,'eastar4uk','incarvr6','incar@balticom.lv','Girts Burnauskis','20 Cunningham walk','Thetford','Norfolk','UNITED KINGDOM','IP24 2TH','07858940128','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 21:49:43',0,NULL,3,1,3,1,'RA117721605CN\r ','incarvr6\rWWSI005+ANCN001'),(5471,721068356011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','jvoetsch','jspikejlv@gmail.com','Jeff Voetsch','10477 Ambassador Dr','Rancho Cordova','CA','UNITED STATES','95670-2278','(916) 990-8847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 21:57:10',0,NULL,3,1,1,1,'\\  ','jvoetsch'),(5472,721080272011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','jgraf91','jgraf1991@gmail.com','jacob Graf','27725 w drake dr<br>appt. 202','channahon','IL','UNITED STATES','60410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 22:37:09',0,NULL,3,1,1,1,'、 ','jgraf91'),(5473,721091930011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','athoroughguy','okmeister@aol.com','A Thorough Guy, Inc.','913 Yosemite Dr.','Placentia','CA','UNITED STATES','92870','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-10 23:25:47',0,NULL,3,1,1,1,'\\  ','athoroughguy'),(5474,800719188012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',1,'HSMO007',15.9,'eastar4','lorri5-8008','lorrihughes@yahoo.com','lorri hughes','PO Box 47<br>280 Rolling Way','smiths grove','KY','UNITED STATES','42171-0047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-11 00:12:27',0,NULL,3,1,1,1,'\\  ','lorri5-8008'),(5475,721120527011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','bobbiandoscar','oscarevelasco@gmail.com','Oscar Velasco','7560 Mandan Rd','Greenbelt','MD','UNITED STATES','20770-2168','(301) 220-0767','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 01:45:16',0,NULL,3,1,1,1,'\\  ','bobbiandoscar'),(5476,591062460013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','msenn77','matthew.senn@gmail.com','Matthew Senn','221 Avenue E','Billings','MT','UNITED STATES','59101','(406) 534-2255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 01:51:07',0,NULL,3,1,1,1,'\\  ','msenn77\rHP 8pin 1.25 18cm'),(5477,591069609013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',12.99,'eastar4','castlegarlabs','castlegarlabradors@gmail.com','Stan McLean','403351 Grey Rd 4,RR1','Priceville','ON','CANADA','N0C 1K0','(519) 369-2443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 02:37:36',0,NULL,3,1,2,1,'\\','castlegarlabs'),(5478,591074644013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','farez1826','fauzan1975@yahoo.com.au','Fauzan Azima','142 Juno Parade','Greenacre','New South Wales','AUSTRALIA','2190','0434587699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 03:14:10',0,NULL,3,1,2,1,'\\ ','farez1826'),(5479,721138176011,320698823427,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'eastar4','josh_malpas','joshua.malpas@three.com.au','Joshua Malpas','813 Tarneit Road','Tarneit','Victoria','AUSTRALIA','3029','0424260726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 03:17:12',0,NULL,3,1,3,1,'RA117721985CN\r ','josh_malpas\rHSPL015\r澳标'),(5480,591075797013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','302502','aklc@iowatelecom.net','Karrie A Cochenour','703 W Old Main St','Milton','IA','UNITED STATES','52570-9687','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 03:23:16',0,NULL,3,1,1,1,'\\  ','302502'),(5481,721141894011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','aneye_4abuy','bobcooke@comcast.net','Robert Cooke','9636 Brunswick Drive','Brentwood','TN','UNITED STATES','37027','(615) 776-1697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 03:37:20',0,NULL,3,1,1,1,'\\  ','aneye_4abuy'),(5482,800765318012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.74,'eastar4','dnk2427','dnkmcerlean@verizon.net','Dennis McErlean','230 Owen Ave','Lansdowne','PA','UNITED STATES','19050','(610) 284-5352','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 03:44:56',0,NULL,3,1,1,1,'\\  ','dnk2427'),(5483,800764847012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','nochecanaria','waterplanet@gmail.com','JOSE MANUEL ALVAREZ BATISTA','JOSE MANUEL MOTAS PEREZ Nº 6 1-B','LAS PALMAS DE GRAN CANARIA','Canarias','SPAIN','35016','660281428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 03:56:42',0,NULL,3,1,2,1,'\\ ','nochecanaria'),(5484,721148557011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','tseldon','xdoomsdayx666@hotmail.com','Tim Seldon','722 Birch rd','Lake Bluff','IL','UNITED STATES','60044-2108','(312) 203-3785','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 04:15:40',0,NULL,3,1,1,1,'\\  ','tseldon'),(5485,721148897011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','vladimirn46','vnedbaylo@bellsouth.net','Volodymyr Nedbaylo','1443 SE Grapeland Ave','Port Saint Lucie','FL','UNITED STATES','34952-4949','(772) 528-5879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 04:20:18',0,NULL,3,1,1,1,'\\  ','vladimirn46'),(5486,591083656013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ladynm','erindiane@mail.com','Erin Jackson','2611 Dakota St NE<br>Apt# 28','Albuquerque','NM','UNITED STATES','87110','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-11 04:22:40',0,NULL,3,1,1,1,'\\  ','ladynm'),(5487,800780773012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','ylapas','paulius_yla@yahoo.com','Paulius Yla','Erfurto g. 18-39','Vilnius','','LITHUANIA','LT-04115','(370)61600855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 05:10:48',0,NULL,3,1,2,1,'\\ ','ylapas'),(5488,538077730003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','pberry10','exp1orer@optusnet.com.au','Paul Berry','Focus Hair Care<br>11a Misten Avenue','Altona North','Victoria','AUSTRALIA','3025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 06:29:06',0,NULL,3,1,3,1,'RA117721512CN\r ','pberry10\rWWOT003');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (5489,800798338012,220786264520,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',161.96,'eastar4','kobinoah','kobin@orange.net.il','Kobi Noah','5 Beer-Ora ST.','RAMAT GAN','','ISRAEL','52273','+972.542731828','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-11 06:46:05',0,NULL,3,1,3,1,'RA117721662CN\r ','kobinoah\rOTSO004'),(5490,721175835011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','susceptance','susceptance@hotmail.com','Jesse Villarreal','PO Box 58261','Houston','TX','UNITED STATES','77258-8261','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 07:01:30',0,NULL,3,1,1,1,'\\  ','susceptance'),(5491,800812732012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','iarsen','iarsen@mail.ru','Arsen Israpilov','Plot 309/310 (building of Remax)<br>Udyog Vihar, Phase IV','Gurgaon','HR','INDIA','122001','+919136854489','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 08:00:58',0,NULL,3,1,2,1,'\\ ','iarsen\r红边优联'),(5492,684006514001,110672308966,'10pcs New 3M Particulate Respirator valve 9332 N99 FFP3',1,'OT3M001*10',74,'buysia','vall2000','ossan@vall.jpn.org','akiyuki okada','1-1-5-1101, chigasaki-higashi','tsuzuki-ku, yokohama-city','Kanagawa','JAPAN','224-0033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 09:45:37',0,NULL,3,1,3,1,'RA117770535CN ','vall2000\rOT3M001*10'),(5493,721219000011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','techno-kingdom','pawdesign@gmail.com','Jitender Gahlawat','Flat # 007, G-Block, Upper Ground Floor<br>Devashri Garden, Porovorim','Bardez','Goa','INDIA','403501','9665387570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 09:58:14',0,NULL,3,1,2,1,'\\ ','techno-kingdom'),(5494,800849892012,220759953524,'New APPLE iMac G6  Bluetooth Wireless Keyboard',1,'KBAP003',85,'eastar4','moxamedali','mohdcat8886@hushmail.com','Ahmed Muzhid','H.Mahinoor<br>Sosan Magu','Male\'','Male\'','MALDIVES','20071','+9609888800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 10:13:25',0,NULL,3,1,3,1,'RA117721910CN ','moxamedali\rKBAP003'),(5495,721248836011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mediencult','p.oelschner@macde.de','Peggy Oelschner','Wilhelmshavener Strasse 18<br>medienCult','Fürth','','GERMANY','90766','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 11:42:44',0,NULL,3,1,2,1,'\\ ','mediencult'),(5496,800904129012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','shailesh.patil','shaileshpatil1@gmail.com','Shailesh Patil','Shriram Nagar 2, Flat no. 22, Bldg. D, S 138 1A,<br>Near Gaikwad Petrol Pump, D.P. Road, Aundh','Pune','MH','INDIA','411007','9922443303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 13:01:00',0,NULL,3,1,3,1,'RA117721716CN\r ','shailesh.patil\r'),(5497,796374273012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','paulocunha1974','paulotarso2003@yahoo.com.br','Paulo Cunha','Rua Desembargador Burle, 73 - Apt 603<br>Botafogo','Rio de Janeiro','Rio de Janeiro','BRAZIL','22271-060','(5521) 9781-0426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 14:12:44',0,NULL,3,1,2,1,'\\ ','paulocunha1974'),(5498,721297793011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','rwd1954','rwddoc@hotmail.com','Randy Dutton','1937 Shady Hollow Ln','Knoxville','TN','UNITED STATES','37922-8808','(321) 292-4649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 14:14:06',0,NULL,3,1,1,1,'\\  ','rwd1954'),(5499,591190723013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','fgloureiro','fgl_formacao@sapo.pt','Fernando Loureiro','Bairro Escola Tecnica<br>5º Bloco 1º Dto','Viana do Castelo','Viana do Castelo','PORTUGAL','4900-348','967447344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 14:25:38',0,NULL,3,0,2,1,'\\ ','fgloureiro'),(5500,721309476011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','ihtarlikx','ihtarlik@gmail.com','Anthony Accurso','1605 NE 69th St','Kansas City','MO','UNITED STATES','64118-2822','(816) 349-9616','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 14:41:42',0,NULL,3,1,1,1,'\\  ','ihtarlikx'),(5501,721327133011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','mamabaker22','bakerdog22@yahoo.com','Sandee Baker','513 Mockingbird<br># A','Troy','IL','UNITED STATES','62294-2146','(618) 505-0285','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 15:32:51',0,NULL,3,1,1,1,'\\  ','mamabaker22'),(5502,721334948011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','nallamothusridhar','sridharcera@gmail.com','Sridhar Nallamothu','Flat No: 303, Sai Pavan Nivas, H.No: 5-6-122/5, Near Rao\'s High School, Daieerguda,<br>Near Kukatpally BJP Office, KUKATPALLY','Hyderabad.','AP','INDIA','500072','9000239948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 15:50:14',0,NULL,3,1,3,1,'RA117770938CN\r ','nallamothusridhar'),(5503,800984336012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',37.96,'eastar4','mikeymalibu','mslik84@aol.com','Michael Del Borrello Jr.','1531 84th St','Brooklyn','NY','UNITED STATES','11228-3131','(718) 232-7332','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 16:20:43',0,NULL,3,1,1,1,'\\  ','mikeymalibu'),(5504,591226905013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','meshsmith','adrianburger.za@gmail.com','Adrian Burger','17 Garfield Road<br>Claremont','Cape Town','Western Cape','SOUTH AFRICA','7708','+2772 738 2707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 16:32:43',0,NULL,3,1,2,1,'\\ ','meshsmith'),(5505,799556027012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','loys_fr','loysalquier@hotmail.com','EARL ALQUIER','route de l\'aérodrome','MIMIZAN','Landes','FRANCE','40200','06 85 41 73 33','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 16:51:44',0,NULL,3,1,2,1,'\\ ','loys_fr\rAcer 5pin1.25 3cm'),(5506,591234659013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','klaasdc','klaasdc@gmail.com','Klaas De Craemer','Stationsstraat 77','Tielt','','BELGIUM','8700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 16:58:51',0,NULL,3,1,2,1,'\\ ','klaasdc'),(5507,801003702012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',36.9,'eastar4','followrubyrabbit','tuneout@mac.com','Liann Lim','Westfield Towers<br>100 William Street, L22','Sydney','New South Wales','AUSTRALIA','2011','0293587094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 17:00:31',0,NULL,3,1,3,1,'RA117721398CN\r ','followrubyrabbit\rHSPL010\r澳标'),(5508,801029199012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',18.98,'eastar4','tcef316','tcef316@aol.com','TONY CEFALO','9017 5TH AVE','Brooklyn','NY','UNITED STATES','11209-5907','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 17:53:17',0,NULL,3,1,1,1,'\\  ','tcef316'),(5509,591270235013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',25.98,'eastar4','rtop3196','robert.toporowicz@videotron.ca','ROBERT TOPOROWICZ','124 RUE DES ECUEILS','TERREBONNE','QC','CANADA','J6W 6B2','(450) 492-8057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 18:45:10',0,NULL,3,1,2,1,'\\ ','rtop3196'),(5510,801068859012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',36.9,'eastar4','marty7767','martynyc03@yahoo.com','Mark Miller','52 Relihan Road','Darien','CT','UNITED STATES','06820','(917) 575-9045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 19:08:46',0,NULL,3,1,1,1,'\\  ','marty7767'),(5511,801069579012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','karrots8850','georgekaracrazy@yahoo.com.au','George karamitsios','28 Dempster street','Wollongong','New South Wales','AUSTRALIA','2500','0403535235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 19:09:52',0,NULL,3,1,2,1,'\\ ','karrots8850'),(5512,538250411003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.95,'cnfaner','clement044','clement1024@msn.com','Clement Chapelet','5 Ard Patrick, The Close<br>Assumption Rd.','Cork','Cork','IRELAND','0','0851 191215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 19:23:04',0,NULL,3,1,3,1,'RA117721415CN\r ','clement044\rMOAP001'),(5513,721438234011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','krickly','krickly@gmail.com','Vladimir M. Bien-Aime','12 W Wayne Terr<br>Apt A','Collingswood','NJ','UNITED STATES','08108','(609) 284-1417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 19:37:07',0,NULL,3,1,1,1,'\\  ','krickly\r新地址\r3 S Harley Ave\rGloucester City, NJ 08030\r\r'),(5514,721459494011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','easttroybob','bbmmtt12045@earthlink.net','Robert Taubert','W2667 Friemoth Rd','East Troy','WI','UNITED STATES','53120','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 20:22:53',0,NULL,3,1,1,1,'\\  ','easttroybob'),(5515,721459597011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','coloradojack_2000','4hfam@comcast.net','Jason Heck','629 Pine Mountain Dr','Fayetteville','PA','UNITED STATES','17222-9518','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 20:23:59',0,NULL,3,1,1,1,'\\  ','coloradojack_2000'),(5516,801106318012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','monsignori','mauromonsignori@yahoo.com','mauro monsignori','2376 Sovron Ct','Dublin','OH','UNITED STATES','43016-9209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 20:24:20',0,NULL,3,1,1,1,'\\  ','monsignori\r红边优联'),(5517,721467475011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',20.98,'eastar4','finchboy00','cschiele@comcast.net','Amanda Phillips','4733 Solano Way','Fair Oaks','CA','UNITED STATES','95628','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 20:43:08',0,NULL,3,1,1,1,'\\  ','finchboy00'),(5518,591313416013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','nestt5','nests40tt4@hotmail.com','Romeo Sekulovski','C/o Strimer<br>Storskiftesvägen 55A','HUDDINGE','','SWEDEN','14139','0706812612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 20:59:23',0,NULL,3,1,3,1,'RA117722005CN\r\r ','nestt5\rMOLO009\r申报8美金'),(5519,721484664011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','rtarant1852b7a','rtarant185@aol.com','ROBERT F. TARANTINO','30 Satuit Trl','SCITUATE','MA','UNITED STATES','02066-3727','(781) 545-9515','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 21:26:43',0,NULL,3,1,1,1,'\\  ','rtarant1852b7a'),(5520,801134808012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',2,'BALO008',13.2,'eastar4','bigfatloser81','clay_job@yahoo.ca','Ian Grant','60 C Line (Unit 406)','Orangeville','ON','CANADA','L9W 0A9','(519) 410-3132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 21:29:24',0,NULL,3,1,2,1,'\\ ','bigfatloser81'),(5521,591318818013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 21:40:27',0,NULL,3,0,2,1,'\\ ','dcwholesale'),(5522,591338993013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','eliatlas','eliatlas699@aol.com','ELIAS MOROS','14933 15th Rd','WHITESTONE','NY','UNITED STATES','11357-2535','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 22:42:49',0,NULL,3,1,1,1,'\\  ','eliatlas'),(5523,721527303011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','losfinches','losfinch@yahoo.com','Anthony Finch','10101 Dellwood Dr','El Paso','TX','UNITED STATES','79924-3236','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 23:53:39',0,NULL,3,1,1,1,'\\  ','losfinches'),(5524,591356357013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','mrzolo','medo1724@gmail.com','Mohamed Barrabah','BD KASER E KABIR NO 64<br>Selouane','nador','Nador','MOROCCO','62702','212611130292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 00:19:35',0,NULL,3,1,2,1,'\\ ','mrzolo'),(5525,721545794011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','blancserge38950','blancserge@gmail.com','SERGE BLANC','282 rue felix faure','Saint Martin Le Vinoux','Rhône-Alpes','FRANCE','38950','0678698209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 01:14:03',0,NULL,3,1,2,1,'\\ ','blancserge38950'),(5526,801208946012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','dsouzanj','njdsouza@hotmail.com','Nigel DSouza (W3.A6.W.09)','Woolworths Ltd<br>1 Woolworths Way, Bella Vista','Sydney','New South Wales','AUSTRALIA','2153','0288852963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 01:48:31',0,NULL,3,1,3,1,'RA117721322CN\r ','dsouzanj\rOTSO001'),(5527,0,230630870649,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',124.49,'eastar4','sid1952ca','sfong@shaw.ca','sidney fong','2202-6088 Willingdon Ave','Burnaby','BC','CANADA','V5H4V2','(604) 438-3866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 03:14:01',0,NULL,3,0,3,1,'RA117773877CN\r ','sid1952ca\r盒装的\rGLSG001*2'),(5528,591389171013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',20,'eastar4','welshfarm','awan_usa07@yahoo.com','shafqat malik','1449 US 41 N<br>US Food Mart','Calhoun','GA','UNITED STATES','30701-1645','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-12 03:43:18',0,NULL,3,1,1,1,'\\  ','welshfarm'),(5529,721577258011,320441564467,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',12.4,'eastar4','crazy-stu','admin@crazystu.com.au','Crazy Stu','58 Taylor St','Woy Woy Bay','New South Wales','AUSTRALIA','2256','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 03:47:52',0,NULL,3,1,2,1,'\\ ','crazy-stu\racer 4pin1.25 4cm'),(5530,721597988011,320701428027,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.99,'eastar4','specul_8','michael@glennon.com.au','Glennon Investments','Glennon Investments<br>Level 11, 131 Macquarie Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-12 05:50:07',0,NULL,3,1,3,1,'RA117721455CN\r ','specul_8\rOTSO001'),(5531,538361135003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','neutralizer2004','nipun1@hotmail.com','Nipun Dureja','317 112th Ave NE<br>Apt 461','Bellevue','WA','UNITED STATES','98004','(425) 443-4971','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-12 05:54:55',0,NULL,3,1,1,1,'\\  ','neutralizer2004'),(5532,544045135004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.95,'cnfaner','peteywatto','peterwatto@hotmail.com','Peter Watson','53/22 Archibald St','Lyneham','Australian Capital Territory','AUSTRALIA','2602','0416065592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 06:22:44',0,NULL,3,1,3,1,'RA117721441CN\r ','peteywatto\rOTSO001'),(5533,591430700013,230452710244,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET HS 3W',1,'HSNO021',15.9,'eastar4','gardener_66','kertesztibor@hotmail.com','Metalholding Zrt. Kertesz Tibor','Kereszturi ut 39-41.','Budapest','','HUNGARY','1106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 08:33:38',0,NULL,3,1,2,1,'\\ ','gardener_66'),(5534,591449114013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',16.98,'eastar4','kalix68','calixto.calderon@gmail.com','Calixto Calderon Rodriguez','Calle Frigola,4-20, VALTERNA','PATERNA','Comunidad Valenciana','SPAIN','46980','676334955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 09:44:26',0,NULL,3,1,2,1,'\\ ','kalix68'),(5535,798330062012,220747230858,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',14.95,'eastar4uk','davidlbooker','davidbooker@vodafone.net','David Booker','15, Westfield Road','Beaconsfield','Bucks','UNITED KINGDOM','HP9 1EG','01494673939','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 09:56:26',0,NULL,3,1,3,1,'RA117721375CN\r ','davidlbooker\rHSMO016\r英标'),(5536,721668622011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','iamalian','ajazbiyabani@gmail.com','ajaz','flat 135B, Mahaveer Tuscan, 1st floor<br>hoodi circle','bangalore','Karnataka','INDIA','560048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 09:59:06',0,NULL,3,1,2,1,'\\ ','iamalian'),(5537,801347968012,220704730634,'New Plantronics Explorer220 BLUETOOTH HEADSET+carcharge',1,'HSPL001+CCPL001',10.88,'eastar4uk','2828chomza','chomza2828@wp.pl','mariusz matuszewski','204 masser road','Coventry','West Midlands','UNITED KINGDOM','cv64jt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 10:31:33',0,NULL,3,1,3,1,'RA117721509CN\r ','2828chomza\rHSPL001+CCPL001'),(5538,801355441012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','crucifiedbaby','steve.threlfall@virgin.net','Stephen Threlfall','Garden Cottage,Possingworth Park,, Cross-in-Hand','Heathfield','East Sussex','UNITED KINGDOM','TN210TJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 10:48:55',0,NULL,3,1,3,1,'RA117721384CN\r ','crucifiedbaby\rBAZA001'),(5539,721693248011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','hartyzan','harty@ntlworld.com','Roger Hart','15 Curzon Street<br>Long Eaton','Nottingham','Nottinghamshire','UNITED KINGDOM','NG10 4FG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 10:58:16',0,NULL,3,1,3,1,'RA117721367CN\r ','hartyzan\rMOAP001'),(5540,721697389011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','snellie95','gfuz@optusnet.com.au','Grant Furzer','25 Romford Road, Frenchs Forest','Sydney','New South Wales','AUSTRALIA','2086','0294513651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:08:53',0,NULL,3,1,3,1,'RA117721490CN\r\r ','snellie95\rBR3D001'),(5541,721703131011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','ncheedella','sricnk@gmail.com','Narendra Cheedella','sh zayed road','dubai','','UNITED ARAB EMIRATES','6519','055 9127811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:23:41',0,NULL,3,1,2,1,'\\ ','ncheedella'),(5542,591477437013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','rasko1nikoff','sephirothx96@mail.ru','Vadim Ahmetzianov','Eremenko, 58/1-93','Rostov-na-Donu','Rostovskaya oblast','RUSSIAN FEDERATION','344015','89885159878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:30:25',0,NULL,3,1,3,1,'RA117721720CN ','rasko1nikoff\rOTES001'),(5543,801374767012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','kostenkiller','die-streuner@gmx.de','Christian Altendorf','Konrad-Adenauer-Str. 23a','Rosbach','','GERMANY','61191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:30:59',0,NULL,3,1,2,1,' \\','kostenkiller\r红边优联'),(5544,719614953011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',10,'TRMX002',95.5,'eastar4','garbasouley','habibou_tenerefm@yahoo.fr','RADIO TELEVISION DOUNIA GARBA ABIBOU','RUE DE L\'ISLAM, KALLEY SUD','NIAMEY','NIAMEY','NIGER','11206','+227 20 74 0085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:58:48',0,NULL,3,0,3,1,'RA117770544CN ','garbasouley\rTRMX002\r\r\r\r\r'),(5545,801394195012,220792323071,'New Intel 5100 AGN half size wireless Mini PCI-E Card',1,'WLIN008',10.9,'eastar4','0l0f','ebay@olof.ws','Olof Strandberg','Syster Ainas Gata 3','Gothenburg','','SWEDEN','41323','0317135141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 12:15:51',0,NULL,3,1,2,1,'\\ ','0l0f'),(5546,721741167011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',24.95,'eastar4','raybthefridgie','raythefridgie@hotmail.fr','Ray Bouche','7 Vista Close','Edgewater','Western Australia','AUSTRALIA','6027','0433234570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 12:52:19',0,NULL,3,1,2,1,'\\ ','raybthefridgie\r无线蓝牙二合一'),(5547,721750444011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','jpri2241','jacc1800@verizon.net','Jack Prichard','501 Turner Road','Grapevine','TX','UNITED STATES','76051','(817) 442-0793','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 13:11:30',0,NULL,3,1,1,1,'\\  ','jpri2241'),(5548,591505766013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','silvana6145','fcba.signs@gmail.com','Fabio Carvalho','Rua Narbal Matias Ferreira, nº 49','Florianopolis','Santa Catarina','BRAZIL','88095630','48 99457599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 13:13:56',0,NULL,3,1,3,1,'RA117721574CN\r ','silvana6145\rMOLO004\r华硕限量版\r'),(5549,591520859013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 13:47:09',0,NULL,3,1,3,1,'RA117721469CN\r ','small.mac\rWLAP008'),(5550,591517259013,230463775032,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',12.99,'eastar4','didyoueishens','yedizion@gmail.com','yedidya zion','haadmor miroz\'in 5<br>har shalom','bnei barak','','ISRAEL','51421','0527135340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 13:47:55',0,NULL,3,1,2,1,'\\ ','didyoueishens'),(5551,721781462011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','retlaw79','tijmes@yahoo.com','Walter R Tijmes','13811 Duran Falls Ct','Houston','TX','UNITED STATES','77044-5948','(281) 225-4484','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 14:17:36',0,NULL,3,1,1,1,'\\  ','retlaw79'),(5552,544166764004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.95,'cnfaner','larryp3587','larry_judy@telus.net','larry Painchaud','7 Westside Rd','Invermere','BC','CANADA','V0A1K5','(250) 342-6602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 14:33:26',0,NULL,3,1,3,1,'RA117721472CN\r ','larryp3587\rOTSO001'),(5553,801470546012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jmarjem','jmarjem@msn.com','James Marrisette','570 Arbor Ridge Dr','Stone Mountain','GA','UNITED STATES','30087-6604','(770) 465-1691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 14:43:18',0,NULL,3,1,1,1,'\\  ','jmarjem'),(5554,538505585003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',17.99,'cnfaner','jaydiii','jaydiii@hotmail.com','Jimmie Parr','54 S Branch Ln','Eldon','MO','UNITED STATES','65026-4454','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-12 15:16:09',0,NULL,3,1,1,1,'\\  ','jaydiii'),(5555,591565299013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','tmediaman','bristolmedia@gmail.com','S A MANNE','1755 York Ave<br>Apt 23G','New York','NY','UNITED STATES','10128-6872','(212) 245-5462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 15:42:43',0,NULL,3,1,1,1,'\\  ','tmediaman'),(5556,721847811011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',71.75,'eastar4','albertootal','albertootal44@hotmail.com','ALBERTO OTAL HERRERO','C/ILLUECA Nº5, ESC.1ª, 8ºA','ZARAGOZA','Zaragoza','SPAIN','50008','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117771258CN ','albertootal\rMOSA001'),(5557,591581669013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',20,'eastar4','shakkee30','krishakeesen@gmail.com','Kamalanathan Krishakeesen','No 56, Rudra Mawatha,<br>Colombo-06','default','Western','SRI LANKA','00600','+94777700377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:17:49',0,NULL,3,1,2,1,'\\ ','shakkee30'),(5558,801560834012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','zokret','lrdschile@yahoo.es','Luis Donoso','Martinez Cruz #475','Placilla de Peñuelas','Valparaiso','CHILE','475','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:58:28',0,NULL,3,0,3,1,'RA117721971CN\r ','zokret\r盒装\rGLSG001*2'),(5559,801589027012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',159.99,'eastar4','ufaavey','ufaa@msn.com','Ali Shareef','G.Valencia, Neeloafarumagu','Malé','K','MALDIVES','20138','+9607775556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 17:35:32',0,NULL,3,1,3,1,'RA117721764CN\r ','ufaavey\rOTSO004*2\r盒装的\r'),(5560,591655696013,230393137066,'2.1 Acer Aspire 4520 4520G Bluetooth Module EDR+cable',1,'BTAC2115',12.4,'eastar4','postadm','yamaksimka@mail.ru','Максим Соловьев','Уральская, 22A','Пермь','Новые Ляды','RUSSIAN FEDERATION','614105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 18:31:12',0,NULL,3,1,2,1,'\\ ','postadm\racer 5pin1.25 20cm '),(5561,591661763013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','andreslook','andreslook@mail.ru','ANDREI KUDRJASOV','GAGARINI 9 - 16','SILLAMAE','IDA-VIRUMAA','ESTONIA','40233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 18:40:08',0,NULL,3,1,2,1,'\\ ','andreslook\r欧标'),(5562,591666793013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','bavoljak','darko@bavoljak.hr','DARKO BAVOLJAK','JAKICEVA 4','ZAGREB','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 18:49:02',0,NULL,3,1,2,1,'\\ ','bavoljak'),(5563,544289525004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','sliced-t','sliced-t@att.net','Chris C. DeWitt','1927 town fork rd','evington','VA','UNITED STATES','24550-2368','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-12 18:50:34',0,NULL,3,1,1,1,'\\  ','sliced-t\r旧的'),(5564,591660106013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',95.99,'eastar4','richard1966vwbug','rstrong89@gmail.com','richard strong','7652 W Donald Dr','peoria','AZ','UNITED STATES','85383-3143','(623) 815-1542','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 19:04:20',0,NULL,3,1,1,1,'\\  ','richard1966vwbug'),(5565,721991434011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','ckronenber','chriskronenb@gmail.com','chris kronenberger','634 Upson St','akron','OH','UNITED STATES','44305-1521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 19:13:32',0,NULL,3,1,1,1,'\\  ','ckronenber'),(5566,722011346011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',1,'CASS001',8.7,'eastar4','robert.deveric','robertdeveric@gmail.com','Robert Deveric','Baburicina<br>20','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 19:37:43',0,NULL,3,1,2,1,'\\ ','robert.deveric'),(5567,801716409012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','bigj7810','jtaylor78@hotmail.co.uk','james taylor','74 mond street<br>Barnton','Northwich','Cheshire','UNITED KINGDOM','CW8 4LA','07748250979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 19:52:42',0,NULL,3,1,3,1,'RA117721557CN\r ','bigj7810\r英标\rHSMO014'),(5568,801753457012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','wrobley2009','ecbill@fsmail.net','Bill Robley','Sencia Ltd. 3rd Floor, Queens Moat House<br>22 St Edwards Way','Romford','Essex','UNITED KINGDOM','RM1 4LQ','07875056252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 20:45:10',0,NULL,3,1,3,1,'RA117721543CN\r ','wrobley2009\rOTCN002'),(5569,722059271011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','jacoboconte','jacoboconte@hotmail.com','jacobo conte','C/Pintor Pedro Flores, 10 esc 1, 3H1, Edificio Luz Carmen','Murcia','Murcia','SPAIN','30002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 20:47:04',0,NULL,3,1,3,1,'RA117721781CN ','jacoboconte\rGLSG001'),(5570,722068671011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',27.99,'eastar4','goldoro5','selim2love@yahoo.com','nabil  selim','2B Brookside Hts','Wanaque','NJ','UNITED STATES','07465-1617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 21:06:19',0,NULL,3,1,1,1,'\\  ','goldoro5'),(5571,722077555011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','stylewearbrazil','stylewearbrazil@yahoo.com','Nubia Salgado','57 Lantern Rd','Revere','MA','UNITED STATES','02151-5617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 21:22:38',0,NULL,3,1,1,1,'\\  ','stylewearbrazil'),(5572,591744106013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',10.49,'eastar4','donbinator','donbymathieu@hotmail.com','Donby Mathieu','26148 SE 39th Way','Issaquah','WA','UNITED STATES','98029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 21:24:18',0,NULL,3,1,1,1,'\\  ','donbinator'),(5573,722080222011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','pampers_brazil','tendresse321@hotmail.com','Fábio Lasalvia','210 172 Street<br>ap 327','Miami','FL','UNITED STATES','33160','786 387 0287','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 21:27:33',0,NULL,3,1,1,1,'\\  ','pampers_brazil'),(5574,722084459011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','joudajouda','lkanak@volny.cz','Ludek Kanak','Kladenska 44','Prague 6','Prague','CZECH REPUBLIC','16000','733519187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 21:36:27',0,NULL,3,1,2,1,'\\ ','joudajouda'),(5575,719717279011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','nauta037','nauta036@upcmail.nl','Jildert Nauta','Zeisvoorde 7','SPIJKENISSE','','NETHERLANDS','3204EN','0627249548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 21:44:19',0,NULL,3,1,3,1,'RA117721795CN\r ','nauta037\rGLOT004'),(5576,801788276012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','bipz17','biplabwagle@gmail.com','biplab wagle','5550 Central Ave<br>Apt 10','el cerrito','CA','UNITED STATES','94530-3401','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 21:50:50',0,NULL,3,1,1,1,'\\  ','bipz17'),(5577,720922179011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',2,'HSNO017',39.96,'eastar4','1010diablo','10diablo@mail.ru','Alexander Leonov','post box 4','Moscow','Russia','RUSSIAN FEDERATION','125424','+7 (495) 5002583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 22:01:11',0,NULL,3,1,3,1,'RA117721645CN\r ','1010diablo\rHSNO017\r欧标'),(5578,591759529013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','heidismom2003','ldhsmith@verizon.net','Debbie Smith','PO Box 13144','Charleston','WV','UNITED STATES','25360-0144','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'heidismom2003\r'),(5579,722111421011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','ttumullet04','shanebowles13@yahoo.com','Shane Bowles','3421 Laurel Ln','Plano','TX','UNITED STATES','75074-3174','(806) 790-1285','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 22:45:14',0,NULL,3,1,1,1,'\\  ','ttumullet04'),(5580,722109180011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',239.98,'eastar4','cool3412','mohideen.saleem@gmail.com','Mohideen Saleem','King Faisal Street, Arab National Bank, Treasury Department<br>2nd Flr, P O Box 56921','Riyadh','','SAUDI ARABIA','11564','+966555269022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 22:49:10',0,NULL,3,0,3,1,'RA117721897CN\r ','cool3412\rGLSG001*2'),(5581,722114000011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',12.5,'eastar4','va3gjg','va3gjg@rogers.com','Graham J. Gillespie','33 Falby Court, Penthouse #1','Ajax','ON','CANADA','L1S 3R3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 22:53:17',0,NULL,3,1,2,1,'\\ ','va3gjg\racer 4pin1.25 15cm '),(5582,544388988004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','duk700','dimaabramov@yahoo.com','Eleonor  Tregub','7121 Hillside Ave<br>Apt 3','Los Angeles','CA','UNITED STATES','90046-2388','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-12 23:12:09',0,NULL,3,1,1,1,'\\  ','duk700'),(5583,591784234013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',60.99,'eastar4','weberio','maldico@terra.es','DAVID Maldonado Muelas','c/ Ancha, 25C','Motril (GR)','Andalucía Ceuta y Melilla','SPAIN','18600','678521060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 23:55:41',0,NULL,3,1,3,1,'RA117721693CN\r ','weberio\rCACN004\r再发一个New Apple 8GB USB PEN KEY FLASH DRIVE U disk\r'),(5584,722141218011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001×2',239.98,'eastar4','divintias','cahillclan@me.com','PJ Cahill','3324 White Bark Pine St','las vegas','NV','UNITED STATES','89129-8117','(702) 285-6875','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 00:21:45',0,NULL,3,0,6,1,'EE520583499CN ','divintias'),(5585,722155707011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','pbyfind','chuck.larkin@verizon.net','Charles Larkin','411 Wharton Blvd','Exton','PA','UNITED STATES','19341-1166','(610) 458-7884','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 01:08:36',0,NULL,3,1,1,1,'\\ ','pbyfind'),(5586,801861307012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','vivianvivianaa','vivianbarrera@hotmail.com','Vivianaa Barrera','Tulcan 1906 y Ayacucho<br>Ecuador','Guayaquil','Guayas','ECUADOR','1140','2373520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 01:15:00',0,NULL,3,1,2,1,'\\ ','vivianvivianaa'),(5587,801863256012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001×2',125.99,'eastar4','ricardo7896','fausto_becer2006@yahoo.com','Yolanda Appiah/Fausto Becerra','3450 Wayne Ave<br>Apt 21E','Bronx','NY','UNITED STATES','10467-2513','(347) 216-6831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 01:18:14',0,NULL,3,0,1,1,'\\  ','ricardo7896\r盒装的'),(5588,722167497011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','itarareinfo','itarare.info@uol.com.br','Sergio Lucas de Almeida','Rua Pero Correa, 122 - Apto. 17<br>Itarare','Sao Vicente','Sao Paulo','BRAZIL','11320-140','+55 13 91195090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 01:46:14',0,NULL,3,1,2,1,'\\ ','itarareinfo'),(5589,722170504011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jilleannamontana','jvansleet@msn.com','Jim Van Sleet','8326 SE Woodcrest Pl','Hobe Sound','FL','UNITED STATES','33455-4110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 01:56:33',0,NULL,3,1,1,1,'\\  ','jilleannamontana'),(5590,544428961004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','4salter','grierm@telus.net','Michael Grier','554 Hawkford Way NW','Calgary','AB','CANADA','T3G3G3','(403) 239-0786','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 02:20:31',0,NULL,3,1,2,1,'\\ ','4salter'),(5591,722184234011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','leo.agustinmagno','almacenesmagno@hotmail.com','Leonardo Agustin Magno','Eloy Alfaro S5-15<br>Toctiuco (Conocoto) Valle de los Chillos','Quito','Pichincha','ECUADOR','00000','(593) 223-4997 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 02:49:40',0,NULL,3,1,2,1,'\\ ','leo.agustinmagno'),(5592,801895137012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','camery_j','claudia_mery@hotmail.com','Claudia Mery','1416 Del Vale Ave','Modesto','CA','UNITED STATES','95350-3852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 02:50:05',0,NULL,3,1,1,1,'\\  ','camery_j'),(5593,722185295011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','josemerc','jam_tyan@yahoo.com.ar','Jose A. Mercado','Irigoyen SUR 317','Tunuyan','Mendoza','ARGENTINA','5560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 02:52:39',0,NULL,3,1,3,1,'RA117721631CN\r ','josemerc\rBR3D001'),(5594,591785857013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','teubbi62','teubbi@yahoo.com','Bill Teubel','118 Sheridan Ave','Lisbon','IA','UNITED STATES','52253-9647','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-13 03:14:01',0,NULL,3,1,1,1,'\\  ','teubbi62'),(5595,538764271003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','vincentf46','vincent.foissac@wanadoo.fr','Vincent FOISSAC','13-15 Av. Georges CLEMENCEAU<br>Appt 103D','FIGEAC','Midi-Pyrénées','FRANCE','46100','0681210524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 03:27:16',0,NULL,3,1,3,1,'RA117721628CN\r ','vincentf46\rWWOT003'),(5596,544449331004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','fairsystems','drocino@gmail.com','Daniel Rocino','julian alvarez 1055 Dto A','capital Federal','Buenos Aires','ARGENTINA','1414','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 04:38:49',0,NULL,3,1,3,1,'RA117721702CN\r ','fairsystems\rWLAP002'),(5597,801623371012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','technikfreund_de','service@technikfreund.de','Nicky Pögelt','Salinenchaussee 9','Stotternheim','','GERMANY','99195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 06:13:10',0,NULL,3,1,2,1,'\\ ','technikfreund_de\racer 8pin1.00 15cm'),(5598,722224394011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','jubalee01','jubalee01@bellsouth.net','JUDY WILLIAMS','1226 W MINNESOTA AVE','DELAND','FL','UNITED STATES','32720','(386) 734-1440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 06:21:20',0,NULL,3,1,1,1,'\\','jubalee01'),(5599,721385424011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',21.99,'eastar4','tipitapito','miser11@gmail.com','Mikhail Sazonov','Borovaya street, d.6 kv. 35','Petrozavodsk','','RUSSIAN FEDERATION','185013','+79114001044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 06:23:37',0,NULL,3,1,2,1,'\\ ','tipitapito\r欧标'),(5600,538786693003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','ezerkar78','ezerkar@gmail.com','Ezer Karash','Mota Gur 10/12','Givaat Shmuel','','ISRAEL','54422','972779303364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 06:46:28',0,NULL,3,1,3,1,'RA117770972CN\r ','ezerkar78\rBALO007'),(5601,591861765013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','galraphael','gal.raphael@gmail.com','Raphael Gal','Hasavion 11','Even Yehuda','','ISRAEL','40500','972-50-7265651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 07:15:27',0,NULL,3,1,3,1,'RA117770941CN\r ','galraphael\rMOSA005'),(5602,544469562004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.95,'cnfaner','yogeshkr931','yalavani@msn.com','Yogesh K. Alavani','C/O Dr. Vaman K. Alavani<br>Near - Electricity office, Dada Vaidya Chawk','Ponda','Goa','INDIA','403401','2313306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 07:28:59',0,NULL,3,1,3,1,'RA117770986CN\r ','yogeshkr931\rOTSO001'),(5603,801960117012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','omer-sub','andreas.ferrari@gmail.com','Andreas Michaelides','Daidalou 3B','Nicosia','Aglantzia','CYPRUS','2107','99761323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 08:00:55',0,NULL,3,1,2,1,'\\ ','omer-sub\r红边优联'),(5604,801957193012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','tittytwister007','cantelguvenlik@gmail.com','serdar işcan','saray mahallesi sugözü <br>caddesi şerifalizade apartmanı 33/A Alanya','antalya','antalya','TURKEY','07400','+905326822014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 07:48:01',0,NULL,3,1,2,1,'\\ ','tittytwister007'),(5605,801965578012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','evil_starscream','mevens@blueyonder.co.uk','Matthew Evans','10 Annan Avenue<br>Bushbury','Wolverhampton','West Midlands','UNITED KINGDOM','WV10 9BH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 08:21:01',0,NULL,3,1,3,1,'RA117770990CN\r ','evil_starscream\rBAZA001'),(5606,801965509012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',87.99,'eastar4','seiichi7820','big-55@ca2.so-net.ne.jp','seiichi ooishi','1-18<br>miyagawa','miura city','Kanagawa','JAPAN','238-0231','81-46-882-5326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 08:21:52',0,NULL,3,1,3,1,'RA117771006CN\r ','seiichi7820\rWWOT003+WLIN014\r再发一个New Intel Centrino Advanced N WiMAX 6250 622ANXHMW\r'),(5607,801965674012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',43.4,'eastar4','runetbj','runetbj@online.no','Rune Bjørge','Strandgaten 41','Svelvik','Svelvik','NORWAY','3060','+4798872439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 08:22:00',0,NULL,3,1,3,1,'RA117770884CN\r ','runetbj\rSCLO002+MOLO004\r再发一个New Logitech Asus MX518 Mousel\r华硕限量版\r'),(5608,801981208012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','dfa_pt','dalb@sapo.pt','Daniel Albuquerque','Rua do Porto N.º 17','Malhapao','Oia','PORTUGAL','3770-058','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 09:16:14',0,NULL,3,1,2,1,'\\ ','dfa_pt'),(5609,591900437013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',39.95,'eastar4','paul10011','ptkennedy@live.com.au','paul kennedy','10 colville street<br>N/A','bathurst','New South Wales','AUSTRALIA','2795','0202633168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 11:00:46',0,NULL,3,1,3,1,'RA117770527CN ','paul10011\rMOLO008'),(5610,802020635012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 11:18:43',0,NULL,3,1,3,1,'RA117770629CN\r ','latiendadelsotano\rGLSG001*2\r盒装的'),(5611,591908085013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','pembe_panter','sifa_ozen@yahoo.com','Sifa Serdar Ozen','Sistas Sayisal Iletisim A.S.<br>Cinnah Caddesi Farabi Sokak No:35','Çankaya','Ankara','TURKEY','-','90 5554473519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 11:16:05',0,NULL,3,1,2,1,'\\ ','pembe_panter\rCAB-6060'),(5612,802029558012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','colomapascual','f.coloma@ua.es','Fernando Coloma Pascual','Edificio SSTTI. Ampliación Campus<br>Universidad de Alicante','San Vicente del Raspeig','Alicante','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 11:45:27',0,NULL,3,1,3,1,'RA117770632CN ','colomapascual\rGLSG001*2'),(5613,802044642012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','eric.schmiess','erschmiess@hotmail.com','eric schmiess','610 Main St','Munich','ND','UNITED STATES','58352-4005','(701) 682-5209','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 12:29:00',0,NULL,3,1,1,1,'\\ ','eric.schmiess\r盒装的'),(5614,591942366013,230432186015,'NEW PLANTRONICS EXPLORER 330 Bluetooth headset E330',1,'HSPL005',13.58,'eastar4','jmaxemax','jmaxfl@bellsouth.net','John Maxwell','1830 Eagle Ln','Navarre','FL','UNITED STATES','32566-8307','(850) 936-5288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 13:41:19',0,NULL,3,1,1,1,'\\ ','jmaxemax'),(5615,591943610013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','zlatkaeon','zlatoto_zig@yahoo.com','Zlatka Gospodinova','26 Boyan Magesnik Street<br>apartment 1','Sofia','Sofia','BULGARIA','1505','00359888344147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 13:47:13',0,NULL,3,1,3,1,'RA117770779CN ','zlatkaeon\rWLAP008'),(5616,722351595011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','marimafa','superlider@hotmail.com','Miguel Mendes','praca da republica 98','loule','algarve','PORTUGAL','8100-269','289462193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 13:48:04',0,NULL,3,1,3,1,'RA117770694CN ','marimafa\rUDAP001'),(5617,802076672012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','albert3162','berghmansalbert@hotmail.com','Albert Berghmans','Walstraat 86','Gentbrugge','','BELGIUM','B-9050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 13:58:12',0,NULL,3,1,3,1,'RA117770589CN\r ','albert3162\rGLSG001*2\r盒装的'),(5618,722360942011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','njbyrne','audrey_jaynes@brown.edu','Nancy Byrne','715 Lake St','NEWARK','NJ','UNITED STATES','07104-2217','(973) 230-3101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 14:15:33',0,NULL,3,1,1,1,'\\ ','njbyrne\r旧的'),(5619,591951383013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',87,'eastar4','larrynezar','larryn@nda.agric.za','Laurence Nezar','657 Besembiesie Road<br>Montana Park','Pretoria','Gauteng','SOUTH AFRICA','0182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 14:17:43',0,NULL,3,1,3,1,'RA117770805CN ','larrynezar\rCASS003\rCAB-6060'),(5620,538877777003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','joeleilao','jg_reis@hotmail.com','João Gabriel Reis','Rua Pinto Alpoim, 486 - BL2 / Apt 203','Rio de Janeiro - RJ','Rio de Janeiro','BRAZIL','21940-230','55 21 8270 5005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 14:28:12',0,NULL,3,1,3,1,'RA117770734CN ','joeleilao\rWWOT003'),(5621,722370664011,320679575403,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.5,'eastar4uk','aqua_buddie','robinloveridge@sky.com','Robin Loveridge','29 matai rd','wanaka','','NEW ZEALAND','9305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 14:42:38',0,NULL,3,1,2,1,'\\ ','aqua_buddie'),(5622,544563418004,140550602687,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',75.95,'cnfaner','stefano0465','stepatico@yahoo.com','stefano  canale','apt.388<br>camino viejo de la mola s/n S.F.co Javier','formentera','Baleares','SPAIN','07860','629944515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 15:03:23',0,NULL,3,1,3,1,'RA117770685CN ','stefano0465\rOTSO001'),(5623,722380777011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','akandrew2007','drayekyaw@yahoo.com','Andrew Aye Kyaw','#02-1917, BLK 333<br>Ang Mo kio Ave 1','Singapore','','SINGAPORE','560333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 15:11:52',0,NULL,3,1,11,1,' ','akandrew2007\rHSJA005\r英标'),(5624,591973793013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','ironwing_123','passol_2004@ybb.ne.jp','MASAAKI FURUKAWA','Shimizu-Ku Tomoe-Cho 13-16<br>Nakamura bldg. 205','Shizuoka','Shizuoka','JAPAN','4240829','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 15:37:01',0,NULL,3,1,2,1,'\\ ','ironwing_123'),(5625,722397250011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','berkshire_uk','ebay@treeby.biz','Jason Treeby','Nasz Dom<br>20 Odell Close','Lower Earley','Reading','UNITED KINGDOM','RG6 4DU','01189795533','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 15:52:23',0,NULL,3,1,3,1,'RA117770748CN ','berkshire_uk\rRELO003\r红边优联'),(5626,591970116013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',105.44,'eastar4','jshtan','jshtan@hotmail.com','James Tan','52 Tanah Merah Kechil Avenue<br>#05-07 Casa Merah','default','','SINGAPORE','465525','(65) 81275292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 15:57:29',0,NULL,3,1,3,1,'RA117770592CN ','jshtan\rMOSA005+CCGR001\r再发一个Griffin Dual USB Car Charger'),(5627,802129150012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',12.5,'eastar4','convenientlynuts8','convenientlynuts8@gmail.com','Michael Hering','Po Box 40243','Denver','CO','UNITED STATES','80204-0243','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 16:05:49',0,NULL,3,1,1,1,'\\ ','convenientlynuts8\racer 8pin1.00 6cm'),(5628,722408450011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','niawnh','evajoros@hotmail.com','Eva Loureiro','C/ Barbera, 77<br>1º 2ª','Cerdanyola del Vallés','Cataluña','SPAIN','08290','626225657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 16:22:43',0,NULL,3,1,2,1,'\\ ','niawnh'),(5629,802152285012,220770080684,'Logitech Harmony RF extender 890 pro 1000 1100 90% new',1,'RCLO007',29.99,'eastar4','gabrielegmollica','g.mollica@gmail.com','Gabriele Mollica','45 Farrell St<br>APT 3','Dartmouth','NS','CANADA','B3A4B2','(902) 440-6066 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 16:52:36',0,NULL,3,1,2,1,'\\ ','gabrielegmollica'),(5630,544600047004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','jonnydeep','eliotescajadillo@hotmail.com','Eliot Escajadillo','C/ Issac Peral 18 local B','Madrid','Madrid','SPAIN','28015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 17:08:26',0,NULL,3,1,3,1,'RA117770751CN ','jonnydeep\rWLAP002\r旧的'),(5631,802162259012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','matthinsh','matthew.hinshelwood@googlemail.com','Mr Matthew Hinshelwood','1 Kingslyn crescent','London','London','UNITED KINGDOM','SE19 3DG','02087711535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 17:16:06',0,NULL,3,1,3,1,'RA117770677CN ','matthinsh\rRELO002'),(5632,722448764011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','esch8327','easoaps@hotmail.com','Elizabeth Schultz','2053 Anacada Court','Atwater','CA','UNITED STATES','95301','(209) 723-0095','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 17:40:27',0,NULL,3,1,1,1,'\\ ','esch8327\r旧的'),(5633,722451344011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','carlosbbb11','cea20@hotmail.com','Carlos Macedo','Rua Dona Antônia de Queirós<br>435 apt 114','Sao Paulo','SP','BRAZIL','01307010','11 67663332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 17:51:34',0,NULL,3,1,3,1,'RA117770725CN ','carlosbbb11\rBR3D001'),(5634,802182773012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','thomas_cdr700','thomas_cdr700@yahoo.com.hk','Kwan Chiu Wan Thomas','Flat 2106, 21/F, Tse On House, Block D,<br>Yue On Court, Apleichau','default','','HONG KONG','default','(852)6484-6781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 17:54:00',0,NULL,3,1,2,1,'\\ ','thomas_cdr700'),(5635,544622513004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',53.99,'cnfaner','emde107','dreherm@web.de','Matthias Dreher','Tuebinger Str. 107','Stuttgart','','GERMANY','70178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 18:12:35',0,NULL,3,1,3,1,'RA117770782CN ','emde107\rWWOT003+ANCN001'),(5636,592045502013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',16.99,'eastar4','djyuramicrosoft_11091987','djyuramicrosoft@gmail.com','Yura Stetsula','c.Pintor Sabater 4 13','Valencia','Valencia','SPAIN','46013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 18:53:49',0,NULL,3,1,2,1,'\\ ','djyuramicrosoft_11091987'),(5637,538971861003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',17.99,'cnfaner','linojanco','lino.janco@gmail.com','Lino Janco','Ekgarden 43','Angered','Vastra Gotaland','SWEDEN','42439','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 19:22:03',0,NULL,3,1,3,1,'RA117770765CN ','linojanco\r欧标\rHSNO004'),(5638,802251706012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','ren81','unger81@web.de','René Unger','Hochschulstr. 28','Dresden','','GERMANY','01069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 19:39:24',0,NULL,3,1,2,1,'\\ ','ren81'),(5639,722530823011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','casper-usa','casperusa@gmail.com','Gary Bettes','6313 Vaughn Dr NE','Rio Rancho','NM','UNITED STATES','87144-6379','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 20:07:52',0,NULL,3,1,1,1,'\\ ','casper-usa'),(5640,544673772004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','mr.lustr','01072018@karneval.cz','Jiri Hruban','Miksickova 2','Brno','Czech Republic','CZECH REPUBLIC','615 00','+420 604 359583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 20:27:48',0,NULL,3,1,3,1,'RA117770717CN ','mr.lustr\rWLAP002\r旧的'),(5641,722544587011,320701907364,'Plantronics Voyager 851/855 Bluetooth Headset',3,'HSPL017',107.7,'eastar4','monetary','monetary@rexwyon.com','Francis Shashaty','420 Lexington Ave<br>Rex Wyon * Monetary System Rm 632','New York','NY','UNITED STATES','10170','(212) 697-2533 ext.: 14','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 20:35:08',0,NULL,3,1,1,1,'\\ ','monetary\r旧的'),(5642,802297399012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','darko098','darko.takac@gmail.com','Mihaela Spajić','Marina Držića 1','Đakovo','','CROATIA','31400','+38598813816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:03:29',0,NULL,3,1,2,1,'\\ ','darko098'),(5643,722558714011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','altap23','altap@oricom.ca','Alain Tapin','800 rue de la Sorbonne','Quebec','QC','CANADA','G1H 1H1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:06:43',0,NULL,3,1,2,1,'\\ ','altap23'),(5644,802303786012,220502333507,'2.1 HP DV2000 DV2100 DV2200  Bluetooth Module+ cable',1,'BTHP2103',12.4,'eastar4','cheyenne39cs','aleymau.ebay@gmail.com','Claudia Cisneros','Genaro Garcia Ret. 29 Edif. 1 Int. 138<br>Col. Jardin Balbuena Del. Venustiano Carranza','Mexico, D.F.','Distrito Federal','MEXICO','15900','(52) 55-55712722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:16:01',0,NULL,3,1,2,1,'\\ ','cheyenne39cs\rHP 8pin 1.0 12cm '),(5645,592100882013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','leilizarbe002','leilizarbe001@gmail.com','Fares Garrafa','Calle 2 de Mayo 450 Dpto. 1004','Miraflores','Lima','PERU','Lima 18','(511) 996-2097 ext.: 20','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:21:41',0,NULL,3,1,3,1,'RA117770615CN ','leilizarbe002\rMOSA002'),(5646,722567101011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','auroremes','abelleflamme@hotmail.com','Aurore Belleflamme','Rue de la Poste 1','Cerfontaine','','BELGIUM','5630','071311268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:27:39',0,NULL,3,1,2,1,'\\ ','auroremes\r再发一个黄膜天线tyco antenna*3  \rANTY002'),(5647,722564298011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','free-marc','mphenke@gmx.net','Marc-Philipp Henke','Auf dem Brink 4','Weyhe','','GERMANY','28844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:27:47',0,NULL,3,1,2,1,'\\ ','free-marc'),(5648,722568417011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','auroremes','abelleflamme@hotmail.com','Aurore Belleflamme','Rue de la Poste 1','Cerfontaine','','BELGIUM','5630','071311268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 21:30:01',0,NULL,3,1,17,0,NULL,'auroremes'),(5649,802313997012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','boulderacupuncture','monicaedlauer@yahoo.com','Monica Edlauer','112 S Buchanan Ct','Louisville','CO','UNITED STATES','80027-9501','(303) 859-7556','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 21:41:12',0,NULL,3,1,1,1,'\\ ','boulderacupuncture'),(5650,592113599013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','passionotes82','passionotes@gmail.com','BIN ZAINI ABDUL HAFEEZ','Blk 178 Boon Lay Drive<br>#04-416','Singapore','','SINGAPORE','640178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 22:08:45',0,NULL,3,1,11,1,' ','passionotes82\rWLAP005'),(5651,592117009013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','jwil32103','jordwil@gmail.com','Jordan Wilheim','Baggins End<br>#11','Davis','CA','UNITED STATES','95616','(310) 733-6567','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 22:19:08',0,NULL,3,1,1,1,'\\ ','jwil32103'),(5652,722586735011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','jrobio','jordan_robichaud@live.com','Jordan Robichaud','4 Shore Road','Dartmouth','NS','CANADA','B3A1A1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 22:22:22',0,NULL,3,1,2,1,'\\ ','jrobio'),(5653,722591827011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','iprovide99','jr185@hotmail.com','Jason Rosenthal','78 Harrison Garden Blvd<br>Suite 1008','Toronto','ON','CANADA','M2N 7E2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 22:40:56',0,NULL,3,1,3,1,'RA117770513CN ','iprovide99\rRCLO007+POLO001+RCLO008*4'),(5654,722600966011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','aguilarmacedobr','aguilarfmacedo@gmail.com','Aguilar Macedo','Rua Margem da Estrada de Ferro, 41<br>Centro','Catalao','Goias','BRAZIL','75701180','55 6499851825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 23:14:01',0,NULL,3,1,2,1,'\\ ','aguilarmacedobr'),(5655,722604818011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','piratewtg','wgrice2@gmail.com','William Grice','105 Hamby Ct','Garner','NC','UNITED STATES','27529','(919) 609-9851','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 23:29:06',0,NULL,3,1,1,1,'\\ ','piratewtg'),(5656,544721776004,140516170648,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.98,'cnfaner','forkbomb','ebay@lid.cc','Thomas Shanks','332357 Georgia Tech Station','Atlanta','GA','UNITED STATES','30332-0001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-14 00:11:04',0,NULL,3,1,1,1,'\\ ','forkbomb'),(5657,802363531012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','taiyo20','kaleb20@gmail.com','Luis Fernandes','Rua Augusto Figueiredo nº 3, 2º esquerdo','Carnaxide','','PORTUGAL','2790-031','+351912721038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 00:20:27',0,NULL,3,0,2,1,'\\ ','taiyo20'),(5658,589253793013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','schizkoske','sandrasch@sympatico.ca','sandra schizkoske','360 lakeview drive','waterloo','ON','CANADA','N2L4Z6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 00:45:58',0,NULL,3,1,2,1,'\\ ','schizkoske'),(5659,722626258011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','peterchil','peterchil@bigpond.com','Bernard Chilcott','61 Waruda St','Bracken Ridge','Queensland','AUSTRALIA','4017','0732699992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 01:00:51',0,NULL,3,1,3,1,'RA117770796CN ','peterchil\rWLAP009'),(5660,802380776012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','jfmtiz','jfmtiz@une.net.co','Jose Mejia','7922 Pines Blvd','PEMBROKE PINES','FL','UNITED STATES','33024-6907','(954) 963-3339','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 01:26:43',0,NULL,3,1,1,1,'\\ ','jfmtiz\r盒装的'),(5661,802382307012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','jtro','jamtro@aol.com','James L Troyer','25 Alda Rae Ct','Stafford','VA','UNITED STATES','22554-2840','(540) 659-0930','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 01:34:13',0,NULL,3,0,1,1,'\\ ','jtro'),(5662,722648947011,320601204302,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','liban95','warsame2@hotmail.com','Mohamed Warsame','4153 Kelly Farm Drive','Ottawa','ON','CANADA','K1T 4H8','(613) 822-7700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 02:32:56',0,NULL,3,1,2,1,'\\ ','liban95\r只发耳机 \r不带电源'),(5663,722658467011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','thanapato','pornphuo@gmail.com','THANAPAT ONSAKON','4 Soi 12  Seri1 Soi.Ramkhamhang24 Yak20<br>Ramkhamhang Rd. Hua Mark','Bangkapi','Bangkok','THAILAND','10250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 03:20:34',0,NULL,3,1,2,1,'、 ','thanapato'),(5664,544759448004,140516860407,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.45,'cnfaner','aaron_provost','aaron_provost@baylor.edu','Aaron Provost','1818 S 2nd St<br>Apt 58','Waco','TX','UNITED STATES','76706','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-14 03:51:21',0,NULL,3,1,1,1,'、 ','aaron_provost'),(5665,722667561011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','pedro1miguel','villavicencio.pedro@yahoo.com','pedro villavicencio','1000 Pine Ave<br>Apt 125','redlands','CA','UNITED STATES','92373-4597','(909) 206-3191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 04:02:20',0,NULL,3,1,1,1,'、 ','pedro1miguel\r旧的'),(5666,802421040012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','blackleyd','darren.blackley@gmail.com','Darren Blackley','5 Centennial Ave','Bertram','Western Australia','AUSTRALIA','6167','0894197656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 04:12:36',0,NULL,3,1,2,1,'、 ','blackleyd\r红边优联'),(5667,722634059011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',110,'eastar4','royalcarriagelv','roywong@earthlink.net','roy wong','8970 Lansberry Ct','las vegas','NV','UNITED STATES','89147','(702) 341-8431','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 04:47:46',0,NULL,3,1,1,1,'、 ','royalcarriagelv'),(5668,722700680011,320624475346,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',69.9,'eastar4','azztal23','azztal@gmail.com','Tal Azogui','Hanurit 5','Ganot Hadar','Israel','ISRAEL','42930','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 07:15:57',0,NULL,3,1,3,1,'RA117770045CN ','azztal23\rHSPL009'),(5669,802457462012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.65,'eastar4','axengusi','andelcampo@gmail.com','ANDRES DEL CAMPO MARTÍNEZ','C/ SOMADILLA 13-B','AYORA','Comunidad Valenciana','SPAIN','46620','606119906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 07:23:13',0,NULL,3,1,2,1,'、 ','axengusi\rMX20T'),(5670,802475834012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',39.99,'eastar4uk','asisois','antonissisois@gmail.com','Antonis Sisois','Viziinou 9','Thessaloniki','40 ekklisies','GREECE','54636','2314000393','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-14 08:45:35',0,NULL,3,1,3,1,'RA117770133CN ','asisois\rBAZA001'),(5671,592218139013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','falklandtim','timothy.morrison@mac.com','Timothy Morrison','5/251 Beaconsfield Parade<br>Middle Park','Melbourne','Victoria','AUSTRALIA','3206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 08:48:28',0,NULL,3,1,2,1,'、 ','falklandtim'),(5672,802481538012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','petr1923','pvg@it4navi.cz','Petr Vagera','Prazska 1','Braskov-Toskanka','','CZECH REPUBLIC','27351','+420777087140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 09:21:27',0,NULL,3,1,2,1,'\\ ','petr1923'),(5673,722727764011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','odd_zymosis','thedeep@fbi-rocks.de','Björn Uhlig','Vogelpothsweg 26','Dortmund','','GERMANY','44149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 09:28:40',0,NULL,3,1,2,1,'\\ ','odd_zymosis'),(5674,802489205012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','numinato','sebastian@goebl.net','Sebastian Goebl','Bauschneiderstr. 17','München','','GERMANY','81241','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 09:43:11',0,NULL,3,1,2,1,'\\ ','numinato\r红边优联'),(5675,802492502012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','wiccanurffue','urffue@gmail.com','David Griveau','18 rue Gabriel Goudy','Nantes','Pays de la Loire','FRANCE','44200','0632580550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 09:54:26',0,NULL,3,1,2,1,'\\ ','wiccanurffue'),(5676,802483375012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','deepbluesnow','deepbluesnow@yahoo.co.uk','Antonis Angelopoulos','eydoksou 7','Patras','Perivola','GREECE','26335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 10:16:50',0,NULL,3,1,2,1,'\\ ','deepbluesnow'),(5677,802086556012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',204.99,'eastar4','knopa2006','bmg2006@yandex.ru','Nikolay Pavlov','Keramicheskiy proezd, 49-2-4.','Moscow','','RUSSIAN FEDERATION','127540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 10:18:03',0,NULL,3,1,6,1,'EE520583485CN ','knopa2006'),(5678,722757046011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','francisfranz','djfranz97@hotmail.com','FRANCIS TAN','BLK 665, JALAN DAMAI<br>#08-117','SINGAPORE','SINGAPORE','SINGAPORE','410665','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 11:29:16',0,NULL,3,1,11,1,NULL,'francisfranz'),(5679,592249915013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','electronicsnow-2008','wireallinc@hotmail.com','Aleksey Mamet','1819 Old Post Ter','Woodbridge','VA','UNITED STATES','22191-3809','(703) 897-8246','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 11:46:49',0,NULL,3,1,1,1,'\\ ','electronicsnow-2008'),(5680,722763593011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','patijnhendrichs','patijn@gmail.com','P Hendrichs','Waldecklaan 25','Hilversum','','NETHERLANDS','1213 XV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 11:51:27',0,NULL,3,1,2,1,'\\ ','patijnhendrichs'),(5681,592252441013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','annmary2006','aroberts@radford.edu','Ann Mary Roberts','317 Mystic Ln NW','Willis','VA','UNITED STATES','24380','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-14 11:58:16',0,NULL,3,1,1,1,'\\ ','annmary2006'),(5682,592253028013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','palma12_5','palmita53@sbcglobal.net','Palma Hernandez','2015 Oates Dr','Dallas','TX','UNITED STATES','75228-3826','(214) 797-0004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 12:03:28',0,NULL,3,1,1,1,'\\ ','palma12_5'),(5683,802517967012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',15,'WLAT009',134.7,'eastar4','max-tech-09','max-tech@gmx.de','Maxim Ganz','Rostocker Straße 69','Wismar','','GERMANY','23970','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 12:22:26',0,NULL,3,1,3,1,'RA117770252CN ','max-tech-09\rWLAT009\r客户电话号码\r017647074053\r\r'),(5684,802545725012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','fitzsteve','steven.fitzgerald@ntlworld.com','Steven Fitzgerald','118 Otford Road','Sevenoaks','Kent','UNITED KINGDOM','TN14 5DP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 12:55:01',0,NULL,3,1,2,1,'\\ ','fitzsteve'),(5685,533489046003,130466041816,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',10,'WWOP003',329,'cnfaner','brownboxcomputers','jostro2@gmail.com','ShipTu (Mariusz Stachurski)','40347 US Highway 19 N<br>Ste 122','Tarpon Springs','FL','UNITED STATES','34689-4842','(847) 414-2399','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-14 13:09:31',0,NULL,3,1,4,1,'YW865717846CN ','brownboxcomputers'),(5686,802573480012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','tenerifesc','josejrh@gmail.com','Tomas Peraza Gonzalez','C/ Alejandro Magno,nº5<br>edif. Idaira 3º-dcha.','Sta Cruz de Tenerife','STA CRUZ DE TENERIFE','SPAIN','38010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 14:26:03',0,NULL,3,1,3,1,'RA117770345CN\r ','tenerifesc\rGLSG001*2\r盒装的'),(5687,592287728013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','vollpfostenbier','michael_vollpfosten@gmx.de','Michael Gerdts','Talstr. 4','Wallenhorst','','GERMANY','49134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 14:40:12',0,NULL,3,1,3,1,'RA117770297CN\r ','vollpfostenbier\rMOSA005'),(5688,722820020011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','mayoroff','ileesment@gmail.com','Illimar Leesment','23 Backmuir road','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 0LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 14:51:04',0,NULL,3,1,3,1,'RA117770487CN\r ','mayoroff\rRELO003\r红边优联'),(5689,802586313012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','ntenk1','ntk@compaqnet.nl','Nicholas ten Kleij','Verspronckweg 97','HAARLEM','','NETHERLANDS','2023BD','0641964999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 14:54:10',0,NULL,3,1,2,1,'\\ ','ntenk1'),(5690,722823026011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','nighty183','nighty183@hotmail.com','Dominique Sabourin','2519 Pierre-Bernard','Montréal','QC','CANADA','H1L4P8','(514) 354-2209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 14:59:24',0,NULL,3,1,2,1,'\\ ','nighty183'),(5691,802597244012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','hwrms','shishi727co@gmail.com','Stephen Shi','7 Norbury Crescent','Scarborough','ON','CANADA','M1P 3J7','(647) 347-5788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 15:32:02',0,NULL,3,1,2,1,'\\ ','hwrms'),(5692,590737683013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','expat53z','expat53@yahoo.com','Jo Neal','1555 State St','Garner','IA','UNITED STATES','50438-8758','(520) 623-2033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 15:38:59',0,NULL,3,1,1,1,'\\ ','expat53z'),(5693,592307002013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','joseph537762','jiayang@yahoo.com','Chen Jiayang','46 Jalan Mastuli','Singapore','Singapore','SINGAPORE','537762','62852066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 15:56:47',0,NULL,3,1,11,1,' ','joseph537762\rANCN001'),(5694,802609957012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',2,'OTIN002',112,'eastar4','comstex','kontakt@comstex.com','Comstex GmbH & CO. KG','Rheinstr. 8A','Teltow','','GERMANY','14513','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 15:56:55',0,NULL,3,1,3,1,'RA117770270CN\r ','comstex\rOTIN002\r客户要INVOICE'),(5695,722845784011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','ettacnapier','awdoeng@gmail.com','Etta Napier','58 Geneva Ave','Irvine','KY','UNITED STATES','40336','(606) 723-4082','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 16:04:25',0,NULL,3,1,1,1,'\\ ','ettacnapier'),(5696,592294331013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','8590maurice','power_move2000@yahoo.com','Maurice Rogers','1399 Crest Lake Ct<br>Maurice Rogers','Lithonia','GA','UNITED STATES','30058-7036','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 16:24:57',0,NULL,3,1,1,1,'\\ ','8590maurice\rCAB-6060'),(5697,722867018011,320701927743,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',65.9,'eastar4','firebird911228','madaraszsolt@ymail.com','Madaras Zsolt','Aleea Dumbravei, 3/13','Odorheiu Secuiesc','Romania','ROMANIA','535600','0740289925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 16:58:30',0,NULL,5,0,18,0,NULL,'firebird911228\rHDSG001\r黑色的\rpaypal付款已经撤回\r'),(5698,722878934011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','cristizbuzau','cristian_zegheru@yahoo.com','Cristian Zegheru','Unirii<br>39B Ap 17','Buzau','Buzau','ROMANIA','120238','40722615491','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 17:31:49',0,NULL,3,1,3,1,'RA117770283CN\r ','cristizbuzau\rGLOT004'),(5699,802661688012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','tedbink','tedbink@pacbell.net','Ted Binkley','12652 Groveview St','Garden Grove','CA','UNITED STATES','92840','(713) 534-0107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 17:51:55',0,NULL,3,1,1,1,'\\ ','tedbink'),(5700,592346125013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','shafiik','shafik.k.p@gmail.com','Muhammed Shafeeque','Muroor Road','Abu Dhabi','Abu Dhabi','UNITED ARAB EMIRATES','00000','+971509709922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 18:09:21',0,NULL,3,1,2,1,'\\ ','shafiik\r客户新地址\rMuhammed Shafeeque\rMuroor Road\rP.O Box: 44881,\rAbu Dhabi Abu Dhabi 00000\rUNITED ARAB EMIRATES\r+971509709922'),(5701,802677849012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','johnmorsley','ebay@morsley.co.uk','John Morsley','42 Tenby Grove<br>Kingsmead','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK4 4HN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 18:21:33',0,NULL,3,1,3,1,'RA117770473CN\r ','johnmorsley\rRELO002'),(5702,802681446012,220539231556,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','ohcan123','zeplon@sbcglobal.net','Ignacio Lopez','1205 Tyler Ave','Corpus Christi','TX','UNITED STATES','78404-3739','(361) 563-7154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 18:27:47',0,NULL,3,1,1,1,'\\ ','ohcan123'),(5703,802682733012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','jan.koz','kozlowskijan@hotmail.com','Jan Kozlowski','44 clerks acre','hassocks','West Sussex','UNITED KINGDOM','bn6 8be','07920096662','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 18:29:25',0,NULL,3,1,3,1,'RA117770460CN ','jan.koz\rRELO002'),(5704,539267555003,130490602150,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',25.95,'cnfaner','devicons','k.mochalov@mail.ru','Konstantin Mochalov','163 Sverdlovskaya str. App. 20.','Kuzneck-12','Penzenskaya oblast','RUSSIAN FEDERATION','442542','+7(927)289-8867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 19:43:31',0,NULL,3,1,3,1,'RA117770500CN\r ','devicons\rWLIN004'),(5705,544951994004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','mvotre','marcelo.votre@gmail.com','Marcelo Votre','Rua Raul Pompeia 131, AP 611<br>Copacabana','RIO DE JANEIRO','RJ','BRAZIL','22080001','+55212140092847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 19:59:06',0,NULL,3,1,3,1,'RA117770306CN\r ','mvotre\rRCLO006\r新的'),(5706,802748306012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 20:22:35',0,NULL,3,1,3,1,'RA117770354CN\r ','javier197900\rGLSG001*2\r盒装的'),(5707,592399433013,230503851837,'NEW PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',12.59,'eastar4','alondavi','alon4d@gmail.com','Alon Davidzon','gissin 3/2','Rishon Le Zion','','ISRAEL','75281','972-54-2428285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 20:25:00',0,NULL,3,1,2,1,'\\ ','alondavi'),(5708,802774953012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',25.99,'eastar4uk','bevanrl','riku.shop@kolumbus.fi','Richard Bevan','askarintie 69','nurmijarvi','','FINLAND','01900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-14 21:21:14',0,NULL,3,1,3,1,'RA117770221CN\r ','bevanrl\r欧标\rHSNO019'),(5709,723000786011,320700149725,'New SonyEricsson HBH-PV705 Bluetooth Headset flower ver',1,'HSSE005',21.9,'eastar4','arshed786mohammad','arshed786@hotmail.co.uk','mohammad arshed','127 oxford street<br>totterdown','bristol','Bristol','UNITED KINGDOM','bs34rh','01179099755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 21:38:31',0,NULL,3,1,2,1,'、 ','arshed786mohammad\r英标\r\r客户同意不要带花的可以发了'),(5710,723003595011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','saulyte1','gredute@yahoo.com','reda Grevyte','836 log lodge ct','baraboo','WI','UNITED STATES','53913-9273','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 21:44:53',0,NULL,3,1,1,1,'\\ ','saulyte1\r旧的'),(5711,802795340012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',25.99,'eastar4uk','jdlife','nickjburger@hotmail.com','Nick Burger','John D Wood<br>53 High Street','Esher','Surrey','UNITED KINGDOM','KT10 9RQ','01372462211','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 22:03:00',0,NULL,3,1,3,1,'RA117770235CN\r ','jdlife\rHSNO019\r英标'),(5712,802802972012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',33.98,'eastar4','jedi_gsxr','jedi_gsxr@yahoo.com','jed johnson','6122 Magnolia Dr','bryan','TX','UNITED STATES','77807-7630','(979) 571-5524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 22:25:37',0,NULL,3,0,1,1,'\\ ','jedi_gsxr'),(5713,592436177013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','hoschek1502','hoschenkova@gmx.de','Ingo Staps','Ziegeleiweg 11','Klein Nordende','','GERMANY','25336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 22:33:45',0,NULL,3,1,2,1,'\\ ','hoschek1502'),(5714,802807556012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',31.9,'eastar4','derpreisistnice','andre.samo@gmx.de','Andre Samofalow','Koppeldamm 31','Elmshorn','','GERMANY','25335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 22:40:31',0,NULL,3,1,3,1,'RA117770249CN ','derpreisistnice\r欧标\rHSNO005\r客户电话\r004917640223351'),(5715,802809974012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','ludy_tratch','ludytratch@gmail.com','Ludmila Tratch de Barros','Rua do Rocha 152 ap 108 - Rocha','Rio de Janeiro','Rio de Janeiro','BRAZIL','20960090','552136243634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 22:47:19',0,NULL,3,1,2,1,'\\ ','ludy_tratch'),(5716,802820081012,220741062544,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'eastar4','erykemil','eryk_emil@wp.pl','Eryk Kaczmarek','46 Exchange Hall<br>Belgard Square North','Tallaght','Dublin','IRELAND','24','85 1009051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 23:22:19',0,NULL,3,1,2,1,'\\ ','erykemil\r英标'),(5717,592460750013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','sarkeizen','altheion@yahoo.com','Jonathan Graham','19 - 5110 Fairview St','Burlington','ON','CANADA','L7L7H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 00:40:28',0,NULL,3,1,2,1,'\\ ','sarkeizen'),(5718,802841594012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','amfernan61','amfernandes61@gmail.com','Antonio Marcos Fernandes','Rua Antonio Pietruza n 211 ap 143','Curitiba','Parana','BRAZIL','80610320','554188324244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 00:44:48',0,NULL,3,1,6,1,'EE506555554CN','amfernan61'),(5719,802842524012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','rios.ernesto','rios.rios.04@gmail.com','carlos ernesto rios','genaro codina #4','villanueva','Zacatecas, Villanueva','MEXICO','99540','4941017186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 00:46:21',0,NULL,3,1,2,1,'\\ ','rios.ernesto'),(5720,685998970001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','neal7349','nealrodefer@yahoo.com','neal rodefer','1100 fiddlers way','kingsport','tn','UNITED STATES','37664-5468','(423) 292-5175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 00:59:24',0,NULL,3,1,1,1,'\\ ','neal7349\rBR3D004+BR3D005\r再发一个3D Blu-ray Alice in wonderland'),(5721,685999594001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',19.99,'buysia','neal7349','nealrodefer@yahoo.com','neal rodefer','1100 fiddlers way','kingsport','tn','UNITED STATES','37664-5468','(423) 292-5175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 01:01:26',0,NULL,3,1,17,0,NULL,'neal7349'),(5722,723061231011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','julia72376','julescalifornia@yahoo.com','Julia Wambolt','2540 Country Hills Rd<br>Apt 292','Brea','CA','UNITED STATES','92821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 01:24:53',0,NULL,3,1,1,1,'、 ','julia72376'),(5723,723073583011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','cruizer298','raynordodd@msn.com','Raynor Dodd','7911 Annapolis Rd','lanham','md','UNITED STATES','20706-1334','(347) 724-2815','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 02:16:05',0,NULL,3,1,1,1,'\\ ','cruizer298'),(5724,802875956012,220640475896,'NEW in box AuthenTec BioReader slide sensor base',2,'OTAU001',25.38,'eastar4','cjtk','aron@shvarts.net','Aaron Shvarts','2901 Avenue I<br>Apt 4B','Brooklyn','NY','UNITED STATES','11210-2917','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 02:52:58',0,NULL,3,1,1,1,'\\ ','cjtk\rAuthenTec 指纹仪 指纹加密识别器'),(5725,723091638011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','beerfect','dtakev@gmail.com','Dieter Takev','62 Albert St.','St. Catharines','ON','CANADA','L2R2G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 03:38:30',0,NULL,3,1,2,1,'\\ ','beerfect'),(5726,802887852012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','maliksoban143','aamir_sajjad786@yahoo.com','AAMIR MAQSOOD','16 HOLBEACH MEWS','BALHAM','London','UNITED KINGDOM','SW12 9QX','07816958908','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 03:48:42',0,NULL,3,1,3,1,'RA117770218CN\r ','maliksoban143\r英标\rHSNO016'),(5727,723099626011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','joealanb915v','joealanb@yahoo.com','Joe or Ann Bedale','1426 Woodmont Dr','Allen','TX','UNITED STATES','75002-5871','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 04:22:27',0,NULL,3,1,1,1,'\\ ','joealanb915v'),(5728,723101731011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT011',33.8,'eastar4','trmt','trmtesq@gmail.com','Timothy Thomas','444 Brickell Ave<br>Suite 650','Miami','FL','UNITED STATES','33131-2406','(305) 377-5441','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 04:37:16',0,NULL,3,1,1,1,'\\ ','trmt'),(5729,802917492012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','sapper648','ben.648@btinternet.com','younadam bullock','41 disraeli crescent','ilkeston','Derbyshire','UNITED KINGDOM','de7 5bu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 06:22:55',0,NULL,3,1,3,1,'RA117770323CN\r ','sapper648\r英标\rHSPL011'),(5730,592514700013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','desertcomputersolutions','info@desertcomputersolutions.net','Christopher Barry','16213 S 33rd St','Phoenix','AZ','UNITED STATES','85048-7255','(602) 295-5918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 06:27:10',0,NULL,3,1,1,1,'\\ ','desertcomputersolutions'),(5731,723121943011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','2011-sarmad','sarmad.photo@yahoo.com','sarmad nasir','346 s mollison ave<br>apt 21','el cajon','CA','UNITED STATES','92020-5450','(619) 306-5548','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-15 06:29:45',0,NULL,3,1,1,1,'\\ ','2011-sarmad'),(5732,590306340013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','hamyachi','mail@alexsin.com','Oleksiy Synyaschok','ul. Schuseva, 36, kv 80','Kiev','Kievskaya oblast','UKRAINE','04060','380934736965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 07:35:31',0,NULL,3,1,2,1,NULL,'hamyachi'),(5733,802937411012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','bluetransistor11','tnguyen11@gmail.com','Thong Nguyen','16406 Lakewood Field Dr','Tomball','TX','UNITED STATES','77377-8790','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 07:56:33',0,NULL,3,0,1,1,'\\ ','bluetransistor11'),(5734,723149571011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','vicbri14','bbaranski@virginbroadband.com.au','Brian Baranski','14 Darian Road','Torquay','Victoria','AUSTRALIA','3228','0352616156','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 08:46:30',0,NULL,3,1,2,1,' \\','vicbri149\r红边优联'),(5735,802950106012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','turbobestia','ifernandez@redsauce.net','IVAN FERNANDEZ','CARRETERA SABADELL 10<br>ATICO 3','RUBI','Barcelona','SPAIN','08191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 08:52:12',0,NULL,3,1,2,1,' \\','turbobestia\r红边优联'),(5736,723159773011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','earlyewing2270','benjamin.early.ewing@gmail.com','Benjamin Ewing','2119 Springtide Dr','Baton Rouge','LA','UNITED STATES','70810-7766','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 09:30:24',0,NULL,3,1,1,1,'、 ','earlyewing2270'),(5737,723171096011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',110,'eastar4','redtfsi','zevgolisemman@hotmail.com','ZEVGOLIS EMMANOUIL','VOULIS 22<br>(1st Floor)','ATHENS - SYNTAGMA','GREECE','GREECE','10563','00306945401852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:22:31',0,NULL,3,1,3,1,'RA117774299CN ','redtfsi\rGLOT004*2'),(5738,802973953012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',25.98,'eastar4','djspy-area51','djspy@pochta.ru','Sergey Spirin','Mihnevsky proezd 8/2-306','Moscow','','RUSSIAN FEDERATION','115547','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:23:33',0,NULL,3,1,2,1,'、 ','djspy-area51'),(5739,802976549012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','axis.gs','fastkitnos@hotmail.com','Ghislain Stapelle','rue bontemps 55','ROCOURT','','BELGIUM','4000','0474465639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:32:25',0,NULL,3,1,2,1,'、 ','axis.gs'),(5740,723176071011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','kalviits88','kalvis_druseiks@inbox.lv','Kalvis Druseiks','Jūrmalas gatve 91-43','Rīga','Rīga','LATVIA','LV-1029','+37129328075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:35:42',0,NULL,3,1,2,1,'、 ','kalviits88\r欧标'),(5741,592554147013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.49,'eastar4','mcpkeene1975','mcpkeene@comcast.net','Cathy Wong','4259 Lakeshore Ave','Oakland','CA','UNITED STATES','94610-1159','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 10:39:52',0,NULL,3,1,1,1,'、 ','mcpkeene1975'),(5742,802991988012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','nijole09','nijolebeka@gmail.com','Nijole Bekampiene','K. Genio str. 16 - 18','Kaunas','','LITHUANIA','LT50167','+370 680 74985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 11:24:15',0,NULL,3,1,2,1,'、 ','nijole09'),(5743,802992895012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',25.98,'eastar4','peeper1950','sachafer@hotmail.com','Lucia Alandi Alapont','C Luis Cendoya Nº79','Puerto de Sagunto','Valencia','SPAIN','46520','656342327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 11:28:25',0,NULL,3,1,2,1,'、 ','peeper1950'),(5744,723192873011,320602988656,'2.1 HP DV6300 DV6400 DV6500 Bluetooth ModuleEDR+cable',2,'BTHP2110',24.8,'eastar4','finnamu','finnamundsen@online.no','Finn Amundsen','Vargveien 3','Nannestad','','NORWAY','N-2030','4792034549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 11:36:29',0,NULL,3,1,2,1,'、 ','finnamu\rHP 8pin 1.25 18cm '),(5745,723201173011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','avtor79','master79@list.ru','Juri Antonov','Veeru 8-28','Maardu','Harjumaa','ESTONIA','74113','+37256263043','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 12:06:05',0,NULL,3,1,2,1,'、 ','avtor79\r欧标'),(5746,803002855012,220501826426,'2.1 New Acer Aspire 3810 3810T  Bluetooth Module+cable',1,'BTAC2118',12.4,'eastar4','wenzikstanislav','swenzik@gmail.com','Stanislav Venzik','Pyatnickoye sh., d6 k7, kv75','Moscow','Moscow','RUSSIAN FEDERATION','125464','+79264146708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 12:10:06',0,NULL,3,1,2,1,'、 ','wenzikstanislav\racer 8pin1.0 3cm'),(5747,592572632013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','will752','will@will-it-rain.com','Will Anderson','65 Best Street','Fitzroy North','Victoria','AUSTRALIA','3068','0416883150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 12:14:12',0,NULL,3,1,2,1,'、 ','will752'),(5748,802018999012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','selectgametienda','gusmlg86@hotmail.com','Agustín Manuel Almagro Rojas','C/de Aragonito 7-A','puerto de la torre (Málaga)','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 12:20:09',0,NULL,3,1,3,1,'RA117774223CN ','selectgametienda\rGLSG001*2\r盒装的'),(5749,803018595012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','farny','shutterman@gmail.com','Rob Fahnestock','8534 Senda Cir','Sandy','UT','UNITED STATES','84093','(801) 809-0444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 12:47:29',0,NULL,3,1,1,1,'、 ','farny'),(5750,592579268013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','vasilkovatv','vasilkova_tv@mail.ru','Татьяна Василькова','улица Ленина, дом 36, квартира 57','Анадырь','Чукотский АО','RUSSIAN FEDERATION','689000','(924)3045198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 13:02:38',0,NULL,3,1,2,1,'、 ','vasilkovatv'),(5751,723220978011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',121.99,'eastar4','mazjac','markvdav@gmail.com','Mark Davis','Mitsubishi Electric,<br>Unit 1E, 77-79 Ashley Street','Braybrook','Victoria','AUSTRALIA','3019','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-15 13:10:11',0,NULL,3,1,3,1,'RA117774237CN ','mazjac\rGLSG001*2'),(5752,803028201012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','schnappi-usa','klaus@schoeke.us','Klaus Schoeke','260 Creekside Park Dr','Alpharetta','GA','UNITED STATES','30022','(770) 752-3131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 13:15:30',0,NULL,3,1,1,1,'、 ','schnappi-usa\r盒装的'),(5753,592587199013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','lswappp','swappp@gmail.com','Nikita Kochetkov','Nikulinskaja ul., d. 23, korp.1, kv. 108','Moscow','','RUSSIAN FEDERATION','119602','+79262326237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 13:20:59',0,NULL,3,1,3,1,'RA117774197CN ','lswappp\rWLIN002'),(5754,803033204012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','nlysoy','nlyates@comcast.net','Nichole Yates','244 Scarlet Cir','Greencastle','PA','UNITED STATES','17225-8756','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 13:31:10',0,NULL,3,1,1,1,'、 ','nlysoy'),(5755,803046322012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',1,'RELO003',11.98,'eastar4','momoplayrs','momoplay@hotmail.fr','aurelien breillat','2 rue du puit de lavau','fontenay le comte','Pays de la Loire','FRANCE','85200','0251007349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 14:10:26',0,NULL,3,1,2,1,'、 ','momoplayrs\r红边优联'),(5756,592601133013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','221bbakerresident','dannygold@gmail.com','Daniel Goldfine','10 West St','Somerville','MA','UNITED STATES','02144-2915','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 14:17:42',0,NULL,3,1,1,1,'、 ','221bbakerresident'),(5757,803048871012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',3,'HSPL014',59.97,'eastar4uk','sdarrylsmith1111','sdarrylsmith501@aol.com','Darryl Smith','1218 N Marquette St','Davenport','IA','UNITED STATES','52804-3765','(563) 517-8187','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 14:22:08',0,NULL,3,1,1,1,'、 ','sdarrylsmith1111'),(5758,803055057012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.74,'eastar4','rinatbirk','rinatbk@gmail.com','Rinat Birk','17 Grinberg st.<br>K. Ben Gurion','Holon','','ISRAEL','58670','+972-54-8093451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 14:32:20',0,NULL,3,1,2,1,'、 ','rinatbirk'),(5759,803066559012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',3,'HSPL010',80.85,'eastar4','bishop10220517','bishop1022@yahoo.com','George Bishop','500 Sam Davis Rd<br>B-09','Smyrna','TN','UNITED STATES','37167','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 15:20:35',0,NULL,3,1,1,1,'、 ','bishop10220517'),(5760,723272953011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','kellafrance3','kellafrance@gmail.com','Kelly Arbia','44 5th Ave','Kings Park','NY','UNITED STATES','11754','(631) 241-1601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 15:44:56',0,NULL,3,1,1,1,'、 ','kellafrance3\r新的'),(5761,792459882012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',26.99,'eastar4','hunnyscoots','kirkylurk@hotmail.com','Kirsten Joy Blankenship','12611 N Gentle Rain Dr','Marana','AZ','UNITED STATES','85658-4394','(520) 869-4401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 15:51:28',0,NULL,3,1,1,1,'、 ','hunnyscoots'),(5762,803094935012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',59.9,'eastar4','kiljanee','christian.muenz@netcologne.de','Compass Private Pflegeberatung GmbH Christian Münz','Gustav-Heinemann-Ufer 74 C','Köln','','GERMANY','50968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 16:20:45',0,NULL,3,1,3,1,'RA117774206CN ','kiljanee\rWWOT002\r旧的\r加一个收货人的名字\rMr. Muenz'),(5763,803104323012,220534610421,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','pimpinlincoln93','pimpinlincoln@yahoo.com','xavier chirichella','181 Pikeview Ln','woodbridge','NJ','UNITED STATES','07095-1018','(201) 213-3660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 16:34:32',0,NULL,3,1,1,1,'、 ','pimpinlincoln93'),(5764,545183480004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','n_tdm900','seitanidisnikos@windowslive.com','NIKOLAOS SEITANIDIS','ANATOLIKIS ROMILIAS 3, NEAPOLI','THESSALONIKI','','GREECE','56728','00302313010247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 16:53:21',0,NULL,3,1,3,1,'RA117774254CN ','n_tdm900\rHSNO022\r欧标\r银色的'),(5765,802994564012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','carandil','carandil@libero.it','Jose Antonio Garcia','C/ Luis Vives 1 casa 33','Cadrete','Aragón','SPAIN','50420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 16:56:23',0,NULL,3,1,3,1,'RA117774210CN ','carandil\rRCLO002\r旧的'),(5766,723301032011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',32.8,'eastar4','andrii.susel','admin@ontimecontractors.com','Andrii Susel','12 Bukovinska Str<br>Ap.147','Rivne','Rivne','UKRAINE','33027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 16:57:04',0,NULL,3,1,3,1,'RA117774166CN ','andrii.susel\r新的\rWLAP003'),(5767,591759529013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','heidismom2003','ldhsmith@verizon.net','Debbie Smith','PO Box 13144','Charleston','WV','UNITED STATES','25360-0144','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-15 16:58:18',0,NULL,3,1,1,1,'、 ','heidismom2003'),(5768,723312210011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','evgeniyaramil','evgen@npau.ru','Evgeniy Legalov','ul. Elektrikov, 22-207','Yekaterinburg','Sverdlovskay obl','RUSSIAN FEDERATION','620017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 17:22:32',0,NULL,3,1,2,1,'、 ','evgeniyaramil'),(5769,803006484012,220640447133,'New Plantronics Voyager 520 Multi-Point Bluetooth Heads',1,'HSPL011',23,'eastar4','jayseiler2525','lseiler@spyglass.net','Larry Seiler','23811 E Oakland Rd','Bay Village','OH','UNITED STATES','44140-2826','(440) 823-1891','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 17:32:05',0,NULL,3,1,1,1,'、 ','jayseiler2525'),(5770,723318044011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','felipem28','felipem28@yahoo.com','FELIPE AVILA','344 RIO DULCE<br>Ste 871-236','EL PASO','TX','UNITED STATES','79932-2359','915 892 5915','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 17:35:10',0,NULL,3,1,1,1,'、 ','felipem28\r新的'),(5771,592656378013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','niburaju','nibupraju@yahoo.com','Nibu  P Rajoo','Bajaj Allianz,,3rd Floor<br>Kalias Plaza,Pattom P.O,Pattom','Trivandrum','Kerala','INDIA','695004','9633303550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 17:52:32',0,NULL,3,1,2,1,'、 ','niburaju'),(5772,592683298013,230537364357,'2.1 HP DV9700t DV9700z  Bluetooth Module+cable',1,'BTHP2111',12.4,'eastar4','harishd101','d_harishkumar@msn.com','Harish Daboley','225 Saint Pauls Ave<br>Apt 7E','Jersey city','NJ','UNITED STATES','07306-3728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 18:45:36',0,NULL,3,1,1,1,'、 ','harishd101\rHP 8pin 1.25 25cm'),(5773,545222574004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.99,'cnfaner','mwidman','david_widman@hotmail.com','David Mauro Widman','r. Carlos Weber, 457 ap192b','Sao Paulo','SP','BRAZIL','05303-000','1199788851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 18:51:23',0,NULL,3,1,3,1,'RA117774118CN ','mwidman\rWLAP008'),(5774,592685234013,230503806133,'NEW PLANTRONICS EXPLORER 330 headset E330 w/charger',1,'HSPL005',13.58,'eastar4','ibuyandselltools','sicily2829@yahoo.com','Melody Rypstra','12445 W 105th St','Saint John','IN','UNITED STATES','46373-9217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 18:51:27',0,NULL,3,1,1,1,'、 ','ibuyandselltools'),(5775,545232813004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','gloncare12','gloncare@gmail.com','Goran Lončarević','Jure Turića 29 a','Zagreb','Sesvete','CROATIA','10360','00385915853078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 19:20:35',0,NULL,3,1,3,1,'RA117774121CN ','gloncare12\rOTCR001'),(5776,592696963013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','thermostat55','tomkingjr@rcn.com','Thomas King','29 Cherubs Way','Hampstead','NH','UNITED STATES','03841','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 19:20:52',0,NULL,3,1,1,1,'、 ','thermostat55'),(5777,723362123011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',68.95,'eastar4','45852697','roni0586@gmail.com','aharon  rozenberg','harav kaniel 5','Haifa','israel','ISRAEL','33199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 19:26:57',0,NULL,3,1,3,1,'RA117774183CN ','45852697\rHSSE006\r美标'),(5778,803202734012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','ulysse4504','brigitte.gagnon@hotmail.com','Brigitte Gagnon','116, rue Lafontaine','Rivière-du-Loup','QC','CANADA','G5R 3A2','(418) 867-8989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 19:37:46',0,NULL,3,1,2,1,'、 ','ulysse4504'),(5779,803229481012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',12.5,'eastar4','memphis0227','memphis027@freemail.hu','Ibolya Gajdán','Szabadhajdú utca 47.','Hajdúböszörmény','','HUNGARY','4220','+36204509204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 20:24:56',0,NULL,3,1,2,1,'、 ','memphis0227\racer 5pin1.25 6cm  '),(5780,803233065012,220778489462,'NEW Logitech Unifying Nano Receiver 4  M505 M510 M705',2,'RELO003',23.96,'eastar4','yravid4u','yravid78@gmail.com','yaniv ravid','nachal zavital 1a','kfar yona','','ISRAEL','40350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 20:34:09',0,NULL,3,1,2,1,'、 ','yravid4u\r红边优联'),(5781,803246442012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','peterb4134','pembrae@talktalk.net','Janet Bacon','Sinclair Collis Ltd, Unit 4,<br>Laches Close, Four Ashes','Wolverhampton','West Midlands','UNITED KINGDOM','WV10 7DZ','01902797272','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 21:00:00',0,NULL,3,1,3,1,'RA117774285CN ','peterb4134\rOTHP003'),(5782,545271401004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','thunderbirdmi','ssoblas@gmail.com','Stephen Soblaskey','10 S State St','Saint Ignace','MI','UNITED STATES','49781-1616','(906) 643-8900','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-15 21:18:44',0,NULL,3,1,1,1,'、 ','thunderbirdmi'),(5783,723430301011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','1202brandon','chileconcarne1@msn.com','Brandon Moore','62 Dick Trefz St','Pueblo','CO','UNITED STATES','81001-1938','(719) 406-9864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 21:21:24',0,NULL,3,1,1,1,'、 ','1202brandon'),(5784,539592944003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',27.9,'cnfaner','bnzfixr','mmtkbss@yahoo.com','Attn: Mark Manuel','4000 Telegraph Ave<br>Import Motors','Oakland','CA','UNITED STATES','94609','(415) 832-9704','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-15 21:29:14',0,NULL,3,1,1,1,'、 ','bnzfixr'),(5785,686359373001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','fierocarl','fierocarl@msn.com','carolyn a. beebe','4 Dale Ct','Binghamton','NY','UNITED STATES','13901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 21:51:28',0,NULL,3,1,1,1,'、 ','fierocarl'),(5786,803270187012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','cichetti54','jlcichetti@verizon.net','Joanne Cichetti','608 Evans Rd','Springfield','PA','UNITED STATES','19064','(610) 543-3288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 21:53:45',0,NULL,3,1,1,1,'、 ','cichetti54'),(5787,803300254012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','domodomains','fer@rrieta.com','JUAN FERNANDO ARRIETA MARTINEZ','CALLE IXTAPA 262<br>COLONIA VILLAS DE LA HACIENDA','TORREON','COAHUILA','MEXICO','27276','(018) 717-3232 ext.: 08','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 23:33:00',0,NULL,3,1,2,1,'、 ','domodomains'),(5788,723474371011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','blind_fu','jon.will.mail@gmail.com','Jonathan Williamson','Senetas Security<br>Level 1 / 11 Queens Road','Melbourne','Victoria','AUSTRALIA','3004','61424172632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 00:01:54',0,NULL,3,1,2,1,'、 ','blind_fu'),(5789,723483307011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','rick6510p','ajfallu@msn.com','Éric Fallu','1289, rue Boréale','Havre-saint-Pierre','QC','CANADA','G0G1P0','(418) 538-3784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 00:24:54',0,NULL,3,1,3,1,'RA117774245CN ','rick6510p\r新的\rRCLO006'),(5790,723488573011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','sadaosh','sadaoshmail-2005@yahoo.com.br','Lilson Oshiro','R. Carneiro da Cunha<br>1228 - AP 134','São Paulo','SP','BRAZIL','04144001','1135259107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 00:48:09',0,NULL,3,1,2,1,'、 ','sadaosh'),(5791,803323379012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','a912x','ebay@akl.clara.co.uk','Andrew Lincoln','Linleys, Drove Close<br>Twyford','Winchester','Hampshire','UNITED KINGDOM','SO21 1QN','07850554608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 01:04:19',0,NULL,3,1,2,1,'\\ ','a912x'),(5792,545314139004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','batoh613','batoh@sibmail.com','Pavel Timoshin','st. Kommunisticheskiy 151-252','Seversk','Tomsk','RUSSIAN FEDERATION','636037','+79539118172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 01:13:00',0,NULL,3,1,3,1,'RA117774308CN ','batoh613\rMOOE001\r发OEM的'),(5793,803330689012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',1,'KBLO001',69.99,'eastar4','bargains_bonanzas','pc_sales@live.com.au','peter damcevski','31 kimpton street','rockdale','New South Wales','AUSTRALIA','2216','0415897002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 01:33:37',0,NULL,3,1,3,1,'RA117774427CN ','bargains_bonanzas\rKBLO001'),(5794,723504593011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.49,'eastar4','smxphil','smxphil@hotmail.com','Shawn Phillips','604 Erica Ln','Euless','TX','UNITED STATES','76039','(817) 684-1241','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 01:56:40',0,NULL,3,1,1,1,'\\ ','smxphil\r'),(5795,723514354011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','l2berzins','lorebuy@gmail.com','Lorena Berzins','Rua Ipanema, 99/902','Rio de Janeiro','RJ','BRAZIL','22631390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 02:39:35',0,NULL,3,1,3,1,'RA117774135CN ','l2berzins\rWLAP009'),(5796,803348763012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','brunocoutoaguiar','brunonatal@hotmail.com','Bruno do Couto Aguiar','Rua Quixabeira, Quadra H-03, Lte- 12, Resid. dos Ipes,<br>Alphaville Flamboyant','Goiania','Goias','BRAZIL','74884676','(062) 3246 - 0767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 02:42:43',0,NULL,3,1,3,1,'RA117774387CN ','brunocoutoaguiar\r盒装的\rGLSG001*2'),(5797,723518178011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','pyronikki','nicochi@socal.rr.com','Nikki Alexander','3220 Sepulveda Blvd<br>Ste 203','Torrance','CA','UNITED STATES','90505-8161','(310) 200-1638','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 02:56:45',0,NULL,3,1,1,1,'、 ','pyronikki'),(5798,803359636012,220704222400,'Logitech diNovo Bluetooth ultra-flat Keyboard+mediapad',2,'KBLO001',139.98,'eastar4','peter-t-melb','ptilmanis@gmail.com','Peter Tilmanis','4/14 Souter St','Eltham','Victoria','AUSTRALIA','3095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 03:29:25',0,NULL,3,1,4,1,'YW866011301CN ','peter-t-melb'),(5799,592814403013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',95,'eastar4','som_au','som.au1@gmail.com','Mr S Omelaenko','66 Darnley St<br>Gordon','Sydney','New South Wales','AUSTRALIA','2072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 03:58:02',0,NULL,3,1,3,1,'RA117774356CN ','som_au\rMOSA006'),(5800,803373660012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','cvuong1984','acuratl1984@gmail.com','Cuong Vuong','14705 Saint Germain Dr','CENTREVILLE','VA','UNITED STATES','20121-2303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 04:41:55',0,NULL,3,1,1,1,'、 ','cvuong1984\rCAB-6060'),(5801,686448867001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',89.99,'buysia','sarahdao','ndao@shaw.ca','ngan  dao','#621-744 west Hastings street','vancouver','BC','CANADA','V6C1A5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 04:50:32',0,NULL,3,1,3,1,'RA117774395CN ','sarahdao\rBR3D003'),(5802,592826610013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',22,'eastar4','klauzcold','cklauz@hotmail.com','Claudio Lértora','Viena con Ines de Suarez 217','Villa Alemana','Valparaiso','CHILE','2450090','56985785553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 05:43:09',0,NULL,3,1,2,1,'、 ','klauzcold'),(5803,803392678012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','shpendel911','shpendel2002@mail.ru','Alexander Bashkov','Kosareva str., 14-157','Chelyabinsk','Chelyabinskaya obl','RUSSIAN FEDERATION','454106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 06:29:18',0,NULL,3,1,2,1,'、 ','shpendel911'),(5804,722787053011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',3,'RELO002',38.94,'eastar4','htcostrovskogo30','toropetz@mail.ru','Mikhail Ivanov','Ostrovskogo 30','Tayci','Leningraskaya obl','RUSSIAN FEDERATION','188340','+7 921-980-01-81','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 07:02:12',0,NULL,3,1,3,1,'RA117774444CN ','htcostrovskogo30\rRELO002'),(5805,723561979011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','jjon6986','jjones@umth.com','Jeremy Jones','1301 Municipal Way<br>Ste 110','Grapevine','TX','UNITED STATES','76051','(817) 835-0650 ext.: 157','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 07:04:59',0,NULL,3,1,1,1,'、 ','jjon6986'),(5806,723561603011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',20,'eastar4','3574erik','ebay@rauchhouse.com','Erik Rauch','1014 Windermere Ave','Menlo Park','CA','UNITED STATES','94025','(650) 279-1324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 07:19:06',0,NULL,3,0,1,1,'、 ','3574erik'),(5807,803403804012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','irufan4070','irufan_@hotmail.com','Ibrahim Irufan','G.Haven<br>Raidhebai Magu','Male','','MALDIVES','20145','9607911999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 07:22:25',0,NULL,3,1,3,1,'RA117774435CN ','irufan4070\rOTSO004*2'),(5808,592848946013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','bunyakin','2592130@mail.ru','Dmitriy Bunyakin','Demina<br>39','Krasnodar','Краснодарский край','RUSSIAN FEDERATION','350039','+79184383632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 08:36:55',0,NULL,3,1,2,1,NULL,'bunyakin'),(5809,803422711012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','s1cker666','slipknot11@narod.ru','Edgar Oshs','Novatorov street, 36-5-360','Moscow','','RUSSIAN FEDERATION','119421','+7(926)328-95-52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 08:49:52',0,NULL,3,1,3,1,'RA117774696CN\r ','s1cker666\rOTSO001'),(5810,592866459013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','aliakin','akinali84@gmail.com','Faik Ali','SISMANOGLOU 52A','KOMOTINI','RODOPI','GREECE','69100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 10:26:11',0,NULL,3,1,2,1,'、 ','aliakin'),(5811,723607939011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','amitsparow','amithasanka@yahoo.com','Amith Asanka','No.52, 4th Lane<br>Ananda Housing Place, Andagala Road','Matugama','','SRI LANKA','12100','+94718290246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 10:42:13',0,NULL,3,1,3,1,'RA117774617CN\r ','amitsparow\rUDAP001'),(5812,803472076012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',2,'HSMO014',33.9,'eastar4uk','ericcadenel','k2autoplus@free.fr','eric cadenel','10 boulevard charlemagne','marseille france','Provence-Alpes-Côte d\'Azur','FRANCE','13012','0491661924','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 11:57:59',0,NULL,3,1,3,1,'RA117774648CN\r ','ericcadenel'),(5813,803475210012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',27.99,'eastar4uk','robertstoncity','conquerking@hotmail.co.uk','Michael Roberts','104 Mackintosh Place Roath','Cardiff','Cardiff','UNITED KINGDOM','CF24 4RR','02920198215','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 12:08:17',0,NULL,3,1,3,1,'RA117775881CN\r ','robertstoncity\rHSNO019+CCNO001'),(5814,723631161011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','patijnhendrichs','patijn@gmail.com','P  Hendrichs','Waldecklaan 25','Hilversum','Holland','NETHERLANDS','1213 XV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 12:11:59',0,NULL,3,1,2,1,'、 ','patijnhendrichs'),(5815,539729756003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.9,'cnfaner','matlaclass','maththefirst@hotmail.fr','claude queinnec','40 rue quater rue de la republique','pleyber christ','Bretagne','FRANCE','29410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 12:31:02',0,NULL,3,1,3,1,'RA117775878CN\r ','matlaclass\rHSNO019+CCNO001'),(5816,539734364003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',13.45,'cnfaner','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 12:55:26',0,NULL,3,1,3,1,'RA117774634CN ','hue_bui\rHSUE004'),(5817,803492360012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',32.9,'eastar4uk','sevy_tt','ayvs@yahoo.com','Yves Rilloraza','28th st cor 3rd ave net2 20th floor, the fort, global city<br>Taguig, Metro Manila','Taguig','Metro Manila','PHILIPPINES','1634','9175748721','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 13:05:25',0,NULL,3,1,3,1,'RA117774625CN\r ','sevy_tt\r美标\rHSSE006'),(5818,592897819013,230622774836,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','eminokichi','hempeisoku@yahoo.co.jp','KOHICHI EYA','HA-16  1-834<br>TATSUZAWAHIROHARA FUJIMI-MACHI','SUWA-GUN','Nagano','JAPAN','3990212','090-1867-0851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 13:10:32',0,NULL,3,1,3,1,'RA117774784CN\r ','eminokichi\rMOLO005\r蓝牙版'),(5819,803502302012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','klee1391','klee33ny@optonline.net','Kevin Lee','1907 Jackson Ave','West Islip','NY','UNITED STATES','11795-1931','(631) 755-5818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 13:36:27',0,NULL,3,1,1,1,'\\ ','klee1391'),(5820,592905009013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','gsrel','medeiros81@gmail.com','Michael   Medeiros','3189 Plum Tree Cres','Mississauga','ON','CANADA','L5N4X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 13:43:06',0,NULL,5,1,18,0,NULL,'gsrel\r已经退款 '),(5821,545418692004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','dprunk2010','prunk@globo.com','DANTE PRUNK','SQSW 300 BLOCO A APTO 606','BRASILIA','DISTRITO FEDERAL','BRAZIL','70673022','+(55)61 84868046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 14:04:46',0,NULL,3,1,3,1,'RA117774705CN\r ','dprunk2010\rBALO007'),(5822,803527861012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',21.9,'eastar4uk','duke_748r','duke_748r@hotmail.com','Martin Isaac','22 Ballyhannon Lodge<br>Portadown','Craigavon','Armagh','UNITED KINGDOM','BT63 5YT','078097016111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 14:52:34',0,NULL,3,1,3,1,'RA117774682CN ','duke_748r\rWWSI005+ANCN001'),(5823,803539195012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','evgalichev','evg001@mail.ru','Evgeny Galichev','st.Lakina, d.187, kv.35','Vladimir','Vladimir reg','RUSSIAN FEDERATION','600028','9206278557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 15:23:39',0,NULL,3,1,3,1,'RA117774679CN ','evgalichev\rWWOT003'),(5824,545448098004,140490323561,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.3,'cnfaner','sasesase99','sase_mitevski@yahoo.com','Saso Mitevski','Mis Ston 25 Djorce Petrov','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 15:40:26',0,NULL,3,1,3,1,'RA117774665CN\r ','sasesase99\rOTCR001'),(5825,592935773013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',2,'WLAT001',33.98,'eastar4','hybird25','info@pc-doktor-bonn.de','Marco Wolff','Siemensstraße 227','Bonn','','GERMANY','53121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 15:50:57',0,NULL,3,1,3,1,'RA117774753CN\r ','hybird25\rWLAT001'),(5826,723717105011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',4,'WLAT006',63.92,'eastar4','thompel7','lo_heindrich@hotmail.com','Hendrik Lo','Melodi Mas IV blok A 6 No.16<br>Kelapa Gading Pratama','Jakarta','DKI Jakarta','INDONESIA','14250','021-68985757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 16:37:45',0,NULL,3,1,3,1,'RA117774736CN\r ','thompel7\rWLAT006'),(5827,592952102013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','tolis1979','hlektrismos@hotmail.com','APOSTOLOS TSESMETZHS','GALATINHS 18-20','THESSALONIKH','KORDELIO','GREECE','56334','6973302298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 16:51:36',0,NULL,3,1,6,1,'EE506555571CN ','tolis1979'),(5828,803586338012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',76.44,'eastar4','benmlewis','bml5252@msn.com','ben lewis','7777 Coldwater Rd','Fort Wayne','IN','UNITED STATES','46825-3407','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 17:20:57',0,NULL,3,1,1,1,'\\ ','benmlewis\r再发一个Logitech Harmony Rechargeable battery 890 880 930mAh旧的\r一个Logitech Harmony RF extender+4 emitter for 890 pro 1000\r'),(5829,803588184012,220798704687,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',74.99,'eastar4','biketrial0','jordirubio1@hotmail.com','Jordi Rubio Nuñez','Paisos Catalans,7, 1º 1ª<br>Castellbisbal','Barcelona','Cataluña','SPAIN','08755','647745074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 17:21:52',0,NULL,3,1,3,1,'RA117774740CN\r ','biketrial0\rOTSA001'),(5830,803595142012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','xtrigerx','alandavies26@btinternet.com','Alan Davies','2 Frongoch<br>Gorrig Road','LLANDYSUL','Dyfed','UNITED KINGDOM','SA44 4LE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 17:37:00',0,NULL,3,1,3,1,'RA117774722CN\r ','xtrigerx\rHSMO017\r英标'),(5831,723759930011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',24.9,'eastar4uk','5939tracy','tracy.emsley2@ntlworld.com','tracy emsley','13 suggitts lane','cleethorpes','Lincolnshire','UNITED KINGDOM','dn357jg','01472234419','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 18:15:07',0,NULL,3,1,3,1,'RA117774719CN ','5939tracy\r英标\rHSJA002'),(5832,592982242013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','sethhardley','shardley@aero.und.edu','Seth Hardley','215 Northwestern Dr','Grand Forks','ND','UNITED STATES','58203-2795','(352) 242-7753','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\ ','sethhardley\rNew address: Seth Hardley\r911 Cottonwood St Apt 102\rGrand Forks, ND 58201\rUnited States\r\r\r'),(5833,803619136012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','johnnyjoef','john_fazio@yahoo.com','John J Fazio','194 Cody Dr','Troy','MO','UNITED STATES','63379','(636) 399-5270','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-16 18:27:23',0,NULL,3,1,1,1,'\\ ','johnnyjoef'),(5834,803642077012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','prowler-rep','mark.bitterlich@navy.mil','Mark Bitterlich','4626 Old Cherry Point Rd','New Bern','NC','UNITED STATES','28560-8007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 19:13:27',0,NULL,3,1,1,1,'\\ ','prowler-rep\r MX20T'),(5835,803658907012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','probuzz','probuzz@hotmail.com','Ravinder Chatha','132 Bath Rd','Hounslow','London','UNITED KINGDOM','TW3 3ET','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 19:37:38',0,NULL,3,1,3,1,'RA117774775CN\r\r ','probuzz\rOTGR001'),(5836,723803233011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','sarahsundogsam','cascadia@q.com','Sarah McMahan','92 Lewis Ave','Port Townsend','WA','UNITED STATES','98368-9594','(360) 379-9159','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 19:49:41',0,NULL,3,1,1,1,'\\ ','sarahsundogsam'),(5837,803670876012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','sisternetty','annettecambridge@blueyonder.co.uk','Annette Cambridge','10 Rubery Farm Grove','Birmingham','West Midlands','UNITED KINGDOM','B459RN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 20:00:35',0,NULL,3,1,3,1,'RA117774807CN ','sisternetty\rHSNO016\r英标'),(5838,803685105012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','vividvew','vividvew@gmail.com','Ben Lovell','4407 HOPSON RD<br>APT 2305','Morrisville','NC','UNITED STATES','27560-8336','(203) 768-1212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 20:27:32',0,NULL,3,1,1,1,'\\ ','vividvew'),(5839,591837750013,230520975297,'New  Motorola H500 Bluetooth Wireless Headset H 500',1,'HSMO006',14.3,'eastar4','ogiser9176','ogiser@bezeqint.net','oren giser','moshav nir yafe<br>meshek 43','afula','','ISRAEL','19210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 20:31:37',0,NULL,3,1,2,1,'、 ','ogiser9176'),(5840,803698791012,220681549785,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',19.55,'eastar4uk','kudlinux','sshameem@gmail.com','Shameem Sheik','Moosa tower 1, KBR, Floor No. 8<br>Sheik Zayed Road','Dubai','Dubai','UNITED ARAB EMIRATES','120727','971505447569','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 20:59:41',0,NULL,3,1,3,1,'RA117775113CN\r ','kudlinux\rOTCR001\r'),(5841,803707154012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',12.5,'eastar4','sonep80','sonep@mail.ru','Sergey Buzin','Pavlovsky-3 per.  dom 14, kv. 17.','Moskva','','RUSSIAN FEDERATION','115093','(792) 653-1021 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 21:14:44',0,NULL,3,1,2,1,'、 ','sonep80\r华硕10pin 0.8 6cm '),(5842,723853708011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','kretsinger123','wwallin77@yahoo.com','Wendy M Kretsinger','4408 E Cascio Dr','Byron','IL','UNITED STATES','61010-9182','(815) 275-0020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 21:42:00',0,NULL,3,1,1,1,'\\ ','kretsinger123'),(5843,723861568011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','choctaw-al','tebritt@bellsouth.net','Thomas E. Britton','2529 Altadena Forest Cir','Vestavia','AL','UNITED STATES','35243-4618','(205) 979-6978','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 22:07:26',0,NULL,3,1,1,1,'\\ ','choctaw-al'),(5844,803729829012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.74,'eastar4','paulogentil10','paulogentil@hotmail.com','Paulo Gentil','SQN 216 bl.A apt.223','Brasilia','DF','BRAZIL','70875-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 22:13:24',0,NULL,3,1,2,1,'、 ','paulogentil10'),(5845,721716038011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','alexriesen','alexrizen@mail.ru','Alexey Riesen','ul. Gastello 41, kv 58','Moscow','Russia','RUSSIAN FEDERATION','107014','+79851667997','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 22:43:12',0,NULL,3,1,2,1,'、 ','alexriesen'),(5846,803740281012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','rodrigovieira1976','rodrigogvieira@gmail.com','Rodrigo Gomes Vieira','Rua Cel. Alberto Rosa, 430','Pelotas','Rio Grande do Sul','BRAZIL','96010770','555384016113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 22:48:08',0,NULL,3,1,2,1,'、 ','rodrigovieira1976\rAcer 5pin1.25 3cm '),(5847,593072986013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.4,'eastar4','marsomaehn','marsoman@arcor.de','Stefan Hopfinger','Karolingerring 42','Minden','','GERMANY','32425','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 23:53:11',0,NULL,3,1,2,1,'、 ','marsomaehn\racer 4pin1.25 15cm '),(5848,803760544012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','reasonable_shopper','shopper@mpowercom.net','ISS c/o Robert Kellohen','13941 Falcon Ridge Dr','Chino Hills','CA','UNITED STATES','91709-1756','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 00:02:57',0,NULL,3,1,1,1,'\\ ','reasonable_sho白色的'),(5849,723891529011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','conillet10000','joseconejo1000@gmail.com','Jose Javier Conejo Ortiz','C/ José María Martínez Aviñó 32','Manises','Valencia','SPAIN','46940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 00:06:36',0,NULL,3,1,3,1,'RA117774594CN\r ','conillet10000\rGLSG001*2'),(5850,723891999011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','pcsosuk','info@pcsos.us','Angelo Cilento','24 Crampton House<br>Patmore Street','Wandsworth','London','UNITED KINGDOM','SW8 4JQ','02077208550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 00:07:02',0,NULL,3,1,2,1,'、 ','pcsosuk'),(5851,593084787013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','onomecracing','onomec@hotmail.com','Marco Aurélio Juvêncio','Rua Teófilo Nóbrega 80','Mauá','São Paulo','BRAZIL','09320-040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 00:46:53',0,NULL,3,1,3,1,'RA117774798CN ','onomecracing\rMOSA002'),(5852,723939559011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','cgrass222','cgrass222@sbcglobal.net','Charles A Grassini Jr','168 Kingston Rd.','Bolingbrook','IL','UNITED STATES','60440-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 03:45:24',0,NULL,3,1,1,1,'、 ','cgrass222'),(5853,593124239013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','hoya1304','khoya1304@nate.com','Kyung-ho Min','Shinjeong-dong I-Park 104-1703<br>1296 Shinjeong2-dong, Yangcheon-gu','Seoul','Seoul','KOREA,REPUBLIC OF','158792','010-9492-0823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 04:43:53',0,NULL,5,0,18,0,NULL,'hoya1304'),(5854,593125497013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','hoya1304','khoya1304@nate.com','Kyung-ho Min','Shinjeong-dong I-Park 104-1703<br>1296 Shinjeong2-dong, Yangcheon-gu','Seoul','Seoul','KOREA,REPUBLIC OF','158792','010-9492-0823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 04:54:24',0,NULL,3,1,3,1,'RA117775864CN\r ','hoya1304\rWLIN002'),(5855,723957206011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','playmakeram','garam.heo@gmail.com','Garam Heo','3415 Smithtown Rd','Suwanee','GA','UNITED STATES','30024','(678) 230-0454','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 05:30:59',0,NULL,3,1,1,1,'、 ','playmakeram'),(5856,545624835004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','mayakovskiy','m_m_ivanov@mail.ru','Michail Ivanov','Mayakovskiy st. 6-126','Gelendjik','Krasnodarskiy kray','RUSSIAN FEDERATION','353460','+79184312813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 07:07:01',0,NULL,3,1,3,1,'RA117774767CN ','mayakovskiy\rWWSI005'),(5857,593148539013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','d0rbik','tvister@gmail.com','Sergii Lytvynenko','Filosofska 8 ap 4','Dnipropetrovsk','Dnipropetrovsk','UKRAINE','49000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 07:58:20',0,NULL,3,1,2,1,' \\','d0rbik'),(5858,723984143011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','ar$razrbk','wpzusnr@yahoo.com','Wilbur Zelk','189 Zelk Ln','Mountain Home','AR','UNITED STATES','72653-6406','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 08:00:31',0,NULL,3,1,1,1,' \\','ar$razrbk'),(5859,723987648011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','simberel','oboltus@me.com','Konstantin Zolotavin','Alleya Zhemchugovoy 5, korp 4, kv 28','Moscow','Moscow','RUSSIAN FEDERATION','111402','89263899494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 08:14:51',0,NULL,3,1,2,1,' \\','simberel'),(5860,803884909012,220759518100,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',37,'eastar4uk','michaelfainer','mfainer@gmail.com','Michael Fainer','Feinstein 4 appt. 1','Tel-Aviv','','ISRAEL','69123','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 09:20:05',0,NULL,3,1,3,1,'RA117775665CN\r ','michaelfainer\rRELO004'),(5861,724026759011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','aoslan','oslan.bg@gmail.com','Alexander Oslan','Sredna Trakata N3<br>apartment N3','Varna','','BULGARIA','9000','+359879433333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 11:10:37',0,NULL,3,1,3,1,'RA117775569CN\r ','aoslan \rGLSG001\rnew address:\rAlexander Oslan\rSredna Trakata N4\rapartment N3\rVarna 9000\rBulgaria\r+359879433333\r'),(5862,0,110702679725,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',65.34,'buysia','four2three','rzachman@new.rr.com','Robert Zachman','353 1st St','Menasha','WI','UNITED STATES','54952-3040','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 11:18:18',0,NULL,3,1,1,1,'\\ ','four2three'),(5863,724027154011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',17.1,'eastar4','pembe_panter','sifa_ozen@yahoo.com','Sifa Serdar Ozen','Sistas Sayisal Iletisim A.S.<br>Cinnah Caddesi Farabi Sokak No:35','Çankaya','Ankara','TURKEY','-','90 5554473519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 11:19:14',0,NULL,3,0,2,1,'\\ ','pembe_panter'),(5864,724035660011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',34.99,'eastar4','nadeemthufail','nadeemtt@rediffmail.com','Nadeem Thufail T','A. R. Building<br>Mulamkadakam, Thirumullavaaram P.O.','Kollam','Kerala','INDIA','691012','9495950199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 12:14:58',0,NULL,3,1,3,1,'RA117775127CN\r ','nadeemthufail\rWWSI004  送螺丝'),(5865,540017715003,130466041816,'New UNLOCKED Option GTM382 PCI-E 7.2Mbps WWAN GTM 382',1,'WWOP003',32.9,'cnfaner','krzy_s','krzyss@gmail.com','Krzysztof Pietrzak','Szeligowskiego 79/6','Szczecin','Zachodniopomorskie','POLAND','71-051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 13:42:15',0,NULL,3,1,3,1,'RA117775135CN\r ','krzy_s\rWWOP003'),(5866,803963387012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','oledjan2k','oledjan@mail.ru','Oleg Marin','Vernadskogo, 101-8, 141','Moscow','','RUSSIAN FEDERATION','119526','(916) 5965836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 13:51:49',0,NULL,5,1,18,1,NULL,'oledjan2k\rOTSO001'),(5867,592954385013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','mattasas','mattsasa@aol.com','Matthew Linder','11108 12th st n','lake elmo','MN','UNITED STATES','55042-9600','(651) 323-7229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 14:11:10',0,NULL,3,1,1,1,'\\ ','mattasas'),(5868,592428308013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','apgstpavel','apgpavel@gmail.com','Pavel Grabinsky','str. Ukrainska 26','Uzhgorod','TR','UKRAINE','88000','380500445782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 14:23:30',0,NULL,3,1,2,1,'\\ ','apgstpavel'),(5869,803580461012,220691771312,'New Plantronics Voyager 510 Multi-Point Bluetooth Heads',1,'HSPL010',26.95,'eastar4','primaris_2hd','df.fillion@gmail.com','Diane Fillion','1230, 17e rue','Roxton Pond','QC','CANADA','J0E 1Z0','(450) 991-2653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 14:29:22',0,NULL,3,1,2,1,'\\ ','primaris_2hd'),(5870,804021625012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','blythe56','kbstrand@dslextreme.com','Kerry Strand','1451 S Lorena St','Los Angeles','CA','UNITED STATES','90023-3718','(805) 813-2094','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 16:29:45',0,NULL,3,1,1,1,'\\ ','blythe56'),(5871,804023842012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','rmisti63','rmisti@optonline.net','Richard MISTICHELLI','63 Broadway Rd','WARREN','NJ','UNITED STATES','07059-5001','(908) 350-3598 ext.: 73274111219083503598','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 16:37:49',0,NULL,3,1,6,1,'EE506555608CN ','rmisti63'),(5872,593278185013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','e.joles','jimolesis@tctwest.net','Jim Oles','631 Cedarwood Dr','Powell','WY','UNITED STATES','82435-1749','(307) 254-9674','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 18:03:30',0,NULL,3,1,1,1,'\\ ','e.joles'),(5873,804069652012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','tt120r','t120r650@hotmail.com','Robert Brooks','210 N Robson','Mesa','AZ','UNITED STATES','85201-6611','(406) 366-3984','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 18:15:12',0,NULL,5,0,18,0,NULL,'tt120r  已经退款'),(5874,593290747013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',10,'HSSA002',159,'eastar4','cle4346','yuliana_suwito@yahoo.com','cindy le','6741 crown ridge','rockford','IL','UNITED STATES','61103','(779) 552-8094','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 18:39:14',0,NULL,3,1,4,1,'YW865908014CN ','cle4346\r黑色的'),(5875,593290520013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','bubabang','bubabang63@yahoo.de','Uwe Miedbrodt','Steinröhrenweg 4','Stuttgart','','GERMANY','70499','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 18:39:26',0,NULL,3,1,3,1,'RA117775144CN\r ','bubabang\rMOSA002'),(5876,803925353012,220799731617,'New AC3 DTS DD 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',68.5,'eastar4','silinvv','silinw@gmail.com','Vjatcheslav Silin','ul.Jona Rida 1/1 kv.411','Saint-Petersburg','','RUSSIAN FEDERATION','193231','911-784-4176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 18:49:29',0,NULL,3,1,3,1,'RA117776365CN ','silinvv\rHDGE001'),(5877,804086201012,220786784268,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',76.97,'eastar4','gmesika','mesika.guy@gmail.com','guy mesika','hatzmaot 68','ashkelon','ashkelon','ISRAEL','78000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 18:50:23',0,NULL,3,1,3,1,'RA117775555CN\r ','gmesika\rOTSO001'),(5878,593295142013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','nikolay.titov','t1518673@yandex.ru','Nikolay Titov','Zorge Str. 12-218','St.-Petersburg','RU','RUSSIAN FEDERATION','198328','+7-9215927271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 18:57:41',0,NULL,3,1,2,1,'\\ ','nikolay.titov'),(5879,804108271012,220682405866,'2.1 HP DV6500 DV6800 DV6900 Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','raslex14','raslex14@yahoo.com','Radu Alex','Mun. Constanta Jud. Constanta<br>Str. Eliberarii nr. 3 bl. IV42 sc. B et. 3 ap. 18','Constanta','','ROMANIA','900292','(+40)0341-413800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 19:35:00',0,NULL,3,1,2,1,'\\ ','raslex14\rHP 8pin 1.25 18cm '),(5880,724214766011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','grantbowden1','grantbowden1@aol.com','Grant Bowden','32 high view<br>hempsted','gloucester','Gloucestershire','UNITED KINGDOM','GL2 5LN','01452501540','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-17 19:57:45',0,NULL,3,1,3,1,'RA117775541CN\r ','grantbowden1\rOTSO001'),(5881,545801482004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','mauiarchitect','johnlyle@hawaii.rr.com','John Lyle','1192 Lauli Pl','Kihei','HI','UNITED STATES','96753-9237','(808) 281-8771','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-17 20:19:06',0,NULL,3,1,1,1,'\\ ','mauiarchitect'),(5882,804134432012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','starexplosive2113','napoleongeter@yahoo.com','Ernest Luera','4718 W 29th Ln','Yuma','AZ','UNITED STATES','85364-9754','(928) 257-7212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 20:32:07',0,NULL,3,1,1,1,'、 ','starexplosive2113\r'),(5883,540128546003,130498755181,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.89,'cnfaner','hemichae','hemi.michaeli@gmail.com','Hemi Michaeli (BOLD)','11 Great Meadow Ln<br>TOP43756 # C','East Hanover','NJ','UNITED STATES','07936-1703','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-17 20:36:09',0,NULL,3,1,3,1,'RA117775419CN\r ','hemichae\rPOLO001\r新地址\rHemi Michaeli\r6 Ha Haruv street APT#2\rHerzeliya 46629\rISRAEL\r'),(5884,724232712011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','pienforkids','flapdael2@tiscali.nl','Pauline Bos','Eemnesserweg 231','Hilversum','Noord-Holland','NETHERLANDS','1223 GG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 20:38:02',0,NULL,3,1,2,1,'\\ ','pienforkids'),(5885,804129334012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','ojitoslindos12','moradiegohernan@gmail.com','Diego Mora','calle 80 # 115-25 Bloque 8 Apto 102','Bogota','Cundinamarca','COLOMBIA','11001000','2271566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 20:52:29',0,NULL,3,1,3,1,'RA117775626CN\r ','ojitoslindos12\rRCLO002'),(5886,804176801012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','hifidreamer','ggottardi@gmail.com','Gianni Gottardi','ch. de la Maison Jean 14','Le Mont-Pèlerin','','SWITZERLAND','1801','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 22:24:50',0,NULL,3,1,3,1,'RA117775396CN\r ','hifidreamer\rWWOT003'),(5887,804188085012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.4,'eastar4','iluvovelhina','eoviedo@yahoo.com','Edgar J. Oviedo','2855 Mangum Rd<br>Ste 312','Houston','TX','UNITED STATES','77092-7486','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 23:03:04',0,NULL,3,1,1,1,'\\ ','iluvovelhina\rHP 8pin 1.0 18cm 4线连'),(5888,804187763012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 23:03:26',0,NULL,3,1,3,1,'RA117775351CN\r ','grandizom\rOTCN004*10'),(5889,722391970011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','showachan','shadowofshowa@hotmail.com','Meagan Harvey','11 Middlebranch Ln','Brewster','NY','UNITED STATES','10509-2536','(845) 279-8295','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 23:28:30',0,NULL,3,1,1,1,'\\ ','showachan'),(5890,804198053012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',59,'eastar4','dangelito76','danielangelito@yahoo.com','daniel angelillo','almafuerte 361','bahia blanca','buenos aires','ARGENTINA','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 23:43:14',0,NULL,3,1,3,1,'RA117776445CN ','dangelito76\rKBFF001'),(5891,593373592013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.2,'eastar4','ezoccoli','everson@zoccolinformatica.com.br','everson zoccoli','caixa postal 4113','curitiba','BRAZIL- Paraná - curitiba','BRAZIL','82501-970','4191025077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 00:19:43',0,NULL,3,1,3,1,'RA117775189CN\r ','ezoccoli\rCASS001\rCAB-SS-2626'),(5892,724300731011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','samanes18','c_calbesi@hotmail.com','cristian calbesi','1129 Napolean Way','Zephyrhills','FL','UNITED STATES','33544','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 00:43:48',0,NULL,3,1,1,1,'\\ ','samanes18'),(5893,686377828001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',19.99,'buysia','1whitman1','praying4all@gmail.com','Paul Whitman','PO Box 154<br>135 Shealy Drive','Prosperity','SC','UNITED STATES','29127-0154','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 00:58:33',0,NULL,3,1,1,1,'\\ ','1whitman1'),(5894,724308540011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','kazuzapaiva','kazuza_comp@yahoo.com.br','Kazuza Paiva','Av. Joao pessoa, 58<br>Centro','Mossoró','RN','BRAZIL','59600900','84 88016199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 01:25:27',0,NULL,3,1,3,1,'RA117775612CN\r ','kazuzapaiva\rGLSG001'),(5895,804226927012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','aditya_dube','aditya_dube@yahoo.com','Aditya Dube','17934 NE 90th St','Redmond','WA','UNITED STATES','98052-0848','(425) 869-8791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 01:43:44',0,NULL,3,1,1,1,'\\ ','aditya_dube'),(5896,724321211011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',121.99,'eastar4','lemo_21','rob_colby@live.com','robert denko','33 stephens street','mallabula','New South Wales','AUSTRALIA','2319','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-18 02:25:42',0,NULL,3,1,3,1,'RA117775609CN\r ','lemo_21\rGLSG001*2'),(5897,593398480013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','alfonso.vacaflores','avacaflores@gmail.com','Alfonso Vacaflores','Junin 1940 PB (UNICEF)','Capital Federal','Buenos Aires','ARGENTINA','1113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 02:47:36',0,NULL,3,1,2,1,'\\ ','alfonso.vacaflores'),(5898,724332491011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','passiniproductions','mattpassini@gmail.com','Matt Passini','2221 Kensington Ave','Plymouth','WI','UNITED STATES','53073-4914','(920) 946-8446','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 03:25:11',0,NULL,3,1,1,1,'\\ ','passiniproductions'),(5899,724335124011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',3,'RCLO007+POLO001+RCLO008*4',107.97,'eastar4','kaye3203','rektait@bigpond.net.au','Mrs Kaye Tait','21 Phillips-Fox Terrace','WOODVALE','Western Australia','AUSTRALIA','6026','61893093113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 03:42:24',0,NULL,3,1,3,1,'RA117775688CN\r ','kaye3203\rRCLO007+POLO001+RCLO008*4'),(5900,593407850013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','witenberg','j_witenberg@hotmail.com','Joel witenberg','327 Alma Rd','Caulfield North','Victoria','AUSTRALIA','3161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 03:54:00',0,NULL,3,1,2,1,'\\ ','witenberg'),(5901,724344699011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',52.98,'eastar4','arkool62','arkool@ihug.co.nz','Adrian Koolaard','30 highbury Ave','Palmerston North','Manawatu','NEW ZEALAND','4412','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 04:39:32',0,NULL,3,1,3,1,'RA117775334CN\r ','WLAP002\r旧的'),(5902,804270290012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','lopukh','lopukhebay@yandex.ru','Dmitry Lopukhov','6/2 Vyacheslav Shishkov Str. App.49','Nizhny Novgorod','Nizhni Novgorod Region','RUSSIAN FEDERATION','603122','+7950-603-36-28','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 05:28:50',0,NULL,3,1,3,1,'RA117775475CN\r ','OTSO004*2\r盒装的'),(5903,724353595011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','keesje_smit','kees_smit@yahoo.com','Kees Smit','1620 NE 52nd Street','Fort Lauderdale','FL','UNITED STATES','33334','(954) 547-9816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 05:39:41',0,NULL,3,1,1,1,'\\ ','keesje_smit'),(5904,804275969012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','globulius','j.b.inc@free.fr','BOCLET JOHN','202 BIS CANZAC','DONGES','Pays de la Loire','FRANCE','44480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 06:03:11',0,NULL,3,1,2,1,'\\ ','globulius'),(5905,724363497011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',3,'BAIN001',23.97,'eastar4','fobara','gregonat@sbcglobal.net','Attn. Grigori Stefanioutine','Frank\'s Foreign Car Srvice<br>3303 S.Winchester Blvd , Ste # 4','Campbell','CA','UNITED STATES','95008','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 06:38:33',0,NULL,3,1,1,1,'、 ','fobara'),(5906,804300674012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','dayvancowboy9','stefanmagnolia@yahoo.com','stephen  Pastore','15 winfield dr','Manalapan','NJ','UNITED STATES','07726-8706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 08:18:38',0,NULL,3,1,1,1,'\\ ','dayvancowboy9'),(5907,724390395011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','manolo_ender','manuel.rodriguez@ua.es','Manuel Rodriguez Pastor','Calle camino del Carril, 48 A','Elda','Comunidad Valenciana','SPAIN','03600','662000110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 08:42:44',0,NULL,3,1,2,1,'\\ ','manolo_ender'),(5908,804232300012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','onegear1','gziroli@yahoo.com','Gary Ziroli','2168 route 29','Galway','NY','UNITED STATES','12074','(518) 424-4811','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 09:02:10',0,NULL,3,1,1,1,'\\ ','onegear1'),(5909,545935401004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','tamako0070','taka-s@u01.gate01.com','TAKAYOSHI  SUZUKI','amphora meguro SUZUKI Bldg#802<br>3-13-11 Nishigotanda','Shinagawa-ku','Tokyo','JAPAN','141-0031','03-5437-4777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 10:44:29',0,NULL,3,1,3,1,'RA117775348CN\r ','tamako0070\rHSNO022'),(5910,724428917011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','mgeoffrey2011','mgeoffrey@me.com','Mukiibi Geoffrey','P.O. BOX 2269 KAMPALA  UGANDA','Kampala','','UGANDA','256','+256791400480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 11:14:57',0,NULL,3,1,3,1,'RA117775263CN\r ','mgeoffrey2011\rUDAP001'),(5911,724431067011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','patriciaoz','peterhooton@hotmail.com','Peter Hooton','26 Arthur Street','Ashwood','Victoria','AUSTRALIA','3147','0414928670','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 11:45:24',0,NULL,3,1,3,1,'RA117775422CN\r ','patriciaoz\rBR3D001'),(5912,540272402003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','wolfskrimskrams','wolfacker@googlemail.com','Claudia Dillmann Vermietung und Verpachtung','Longericher Str.175','Köln','','GERMANY','50739','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 12:08:02',0,NULL,3,1,3,1,'RA117775277CN\r ','wolfskrimskrams\rWWOT003'),(5913,540273701003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','marinecorps4ever','fmf@3024v.com','Frank Fonfara','- SELBSTVERZOLLER -<br>Eschenstrasse 7','Untergolding','','GERMANY','84184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 12:12:44',0,NULL,3,1,3,1,'RA117775285CN\r ','marinecorps4ever\rWLAT007'),(5914,724175807011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',32.94,'eastar4','ori8759','ori901@netvision.net','elad sinay','vered 28/16','kiryat motzkin','.','ISRAEL','26358','0506347102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 12:15:23',0,NULL,3,1,3,1,'RA117775294CN\r ','ori8759\rHSNO003'),(5915,724452438011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','maxum_media','orders@maxummedia.com','Tina Phan','1522 Centre Pointe Dr','Milpitas','CA','UNITED STATES','95035-8011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 12:25:46',0,NULL,3,1,1,1,'\\ ','maxum_media'),(5916,724457283011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','yonitseru','yonitseru@gmail.com','Yoni tseru','Be\'eri 64','Rehovot','','ISRAEL','76351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 12:44:08',0,NULL,3,1,2,1,'\\ ','yonitseru'),(5917,593494441013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','skrudj','skrudjandry@gmail.com','Andrey Deryabin','m-n.50a,Altay-2, App.22','Almaty','Kasakhstan','KAZAKHSTAN','050039','+7(727)2527335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 12:48:42',0,NULL,3,1,6,1,'EE506555599CN ','盒装的'),(5918,724476465011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',3,'TRMX001',25.65,'eastar4','has.2009','mete@eosbil.com.tr ','METE GURCAN','PERPA B BLOK KAT 6 NO 653','ISTANBUL','','TURKEY','34384','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 13:39:04',0,NULL,3,0,2,1,'\\ ','has.2009'),(5919,804413899012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','123pradeep0_3','goyal_accounts@yahoo.co.in','Pradeep Goyal','BG-6, Flat No. 63 - C,<br>Paschim Vihar,','New Delhi','DL','INDIA','110063','919711368952','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-18 14:03:26',0,NULL,3,1,2,1,'\\ ','123pradeep0_3\r'),(5920,804415975012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',3,'BAZA001',119.97,'eastar4uk','oldie$1948','bobcaruth@hotmail.com','Robert M. Caruth','6700 Caruth Ranch Blvd','Lone Oak','TX','UNITED STATES','75453-6214','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-18 14:09:16',0,NULL,3,1,1,1,'\\ ','oldie$1948'),(5921,545981548004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','jalokala','jukka.ruuth@gmail.com','Jukka Ruuth','Kiilletie 5 A 9','Helsinki','','FINLAND','00710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 14:24:21',0,NULL,3,1,3,1,'RA117775303CN\r ','jalokala\rHSNO022\r银色的\r欧标'),(5922,724261968011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','rogermarishomerunking','embalmer88@hotmail.com','Chris Garske','5226 9th Ave N','Grand Forks','ND','UNITED STATES','58203','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 15:01:25',0,NULL,3,1,1,1,'\\ ','rogermarishomerunking'),(5923,804436047012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',17.1,'eastar4','kalidasu1982','1800.24.7.4u@gmail.com','narendra kalidasu','16/7<br>eldridge st','footscray','Victoria','AUSTRALIA','3011','0393184920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:02:28',0,NULL,3,1,2,1,'\\ ','一共买了两个\rMX20T'),(5924,804441622012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','aristeu','aristeu.bernardes@gmail.com','Aristeu Bernardes Neto','SQS 116, Bloco I, Apto. 304<br>Asa Sul','Brasilia','Distrito Federal','BRAZIL','70386-090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:13:51',0,NULL,3,1,2,1,'\\ ','aristeu\rAcer 5pin1.25 3cm '),(5925,593531889013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','kwek2','shopsnakey@gmail.com','Michael Cheung','Drapiersteeg 2','Gouda','','NETHERLANDS','2801VX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:14:27',0,NULL,3,1,3,1,'RA117775705CN\r ','kwek2\rMOSA005'),(5926,724510737011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',5.55,'eastar4uk','roymond59','a.roythomason@googlemail.com','Roy Thomason','8 Malhamdale Road','Congleton','Cheshire','UNITED KINGDOM','CW122DA','01260279493','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-18 15:18:00',0,NULL,3,1,3,1,'RA117775215CN\r ','roymond59\rBAIN001'),(5927,724518811011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','galeev_mr','marik22@mail.ru','Марсель Галеев','Ул. Островского д.10 кв.65','Сургут','ХМАО','RUSSIAN FEDERATION','628417','+79129057523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:39:08',0,NULL,3,1,2,1,'\\ ','galeev_mr'),(5928,540326976003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','smario10','mario.brameshuber@gmx.net','Mario Brameshuber','Mario Brameshuber<br>Aubrunnerweg 41a/6','Linz','','AUSTRIA','4040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:58:53',0,NULL,3,1,3,1,'RA117775229CN\r ','smario10\rWWOT003'),(5929,0,130532972755,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',2.21,'cnfaner','furysystems','leewdaugherty@gmail.com','Lee Daugherty','4123 Cedar Springs Rd<br>Apt 2165','Dallas','TX','UNITED STATES','75219-3548','(214) 621-3179','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-18 16:12:16',0,NULL,3,1,1,1,'\\ ','furysystems'),(5930,801716513012,220455488027,'HP TX1000 TX1000z TX1200 Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',12.5,'eastar4','manic_bananas','manicbanana@gmail.com','derek morton','65 wolftone square west','bray','Wicklow','IRELAND','default','857777758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 16:44:45',0,NULL,3,1,2,1,'\\ ','manic_bananas\rHP 8pin 0.8 3cm'),(5931,593570479013,230546985871,'New Motorola H700 Bluetooth Wireless Headset+carcharger',1,'HSMO011+CCMO001',17.99,'eastar4','dank4120','dkadyk@shaw.ca','Dan Kadyk','5824-64 Avenue Close','Rocky Mountain House','AB','CANADA','T4T1N5','(403) 845-4710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 17:22:08',0,NULL,3,1,2,1,'\\ ','dank4120'),(5932,724564512011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','blaatur','blaatur@online.no','Knut Holm','Atriumsveien 29','Gamle Fredrikstad','','NORWAY','1639','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 17:24:56',0,NULL,3,1,2,1,'\\ ','blaatur'),(5933,593581214013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','dr_paparazzi','robert.gardner@theiet.org','Robert Gardner','Network Rail, Buchanan House, Floor 3 Desk 167<br>58 Port Dundas Road','Glasgow','Glasgow','UNITED KINGDOM','G4 0LQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 17:55:58',0,NULL,3,1,2,1,'\\ ','dr_paparazzi\rCAB-6060'),(5934,0,130532984725,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',0.06,'cnfaner','ssd99chd','ssd99chd@gmail.com','Dhillon','8900 Research Park Dr<br>Apt 1823','The Woodlands','TX','UNITED STATES','77381-5255','(650) 469-3171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-18 19:00:51',0,NULL,3,1,1,1,'\\ ','ssd99chd\r一共买了六个'),(5935,591564284013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',9,'BTDE2002',112.5,'eastar4','timrudy','timrudy@tranet.com','Tim Rudy','2592 Arborwood Dr','Loveland','OH','UNITED STATES','45140-5649','(513) 459-8700 ext.: 1713','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 19:23:35',0,NULL,3,1,1,1,'\\ ','timrudy'),(5936,804561840012,220799731617,'New AC3 DTS DD 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',68.5,'eastar4','pooonstarr','pooonstarr@hotmail.com','Jed Veluz','5 kings cross Apt:203.<br>Buzzer #:118','Brampton','ON','CANADA','l6t3x6','(416) 302-6568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 19:24:06',0,NULL,3,1,3,1,'RA117775674CN\r ','pooonstarr\rHDGE001'),(5937,724635745011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','stiller1982','estiller@gmail.com','Eran Stiller','153 Jerusalem Av.<br>3rd Entrance','Tel-Aviv','Israel','ISRAEL','68152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 20:05:42',0,NULL,3,1,2,1,'\\ ','stiller1982'),(5938,724614130011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','s_yuichi','yuichi-shimizu@max.jrnet.ne.jp','Yuichi Shimizu','Dormitory Musashi-Urawa 330, 6-6-24<br>Uchiya, Minami-ku','Saitama','Saitama','JAPAN','336-0034','048-816-5215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 20:15:10',0,NULL,3,1,2,1,'\\ ','s_yuichi'),(5939,804597483012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','lotickets','metroliving1@gmail.com','Metro Living L.L.C','14289 winding pond ln','Belleville','MI','UNITED STATES','48111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 20:39:44',0,NULL,3,1,1,1,'、 ','盒装的'),(5940,724693501011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',121.99,'eastar4','kinggurney','gurneykingb@aol.com','Bobby Gurney','PO BOX 1320','COOLANGATTA','Queensland','AUSTRALIA','4225','0755992569','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-18 22:49:42',0,NULL,3,1,3,1,'RA117775586CN\r ','kinggurney\rGLSG001*2'),(5941,724711164011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ezjeff1100','gogetjeff2003@yahoo.com','Gerardo Rodriguez Jr.','5155 Havering Way','Woodbridge','VA','UNITED STATES','22193-4932','(703) 869-3872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 00:16:47',0,NULL,3,1,1,1,'\\ ','ezjeff1100'),(5942,724716537011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jrlafoll99','dpr2007@yahoo.com','Jeremy LaFollette','2008 N Woodbine Rd<br>Apt 5','Saint Joseph','MO','UNITED STATES','64506-4896','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 00:31:21',0,NULL,3,1,1,1,'\\ ','jrlafoll99'),(5943,804177653012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',2,'HSPL014',39.98,'eastar4uk','mikey-will-eat-it','sawdustorbust@aol.com','Mike Beesley','3324 W University Ave<br># 152','Gainesville','FL','UNITED STATES','32607','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 01:10:44',0,NULL,3,1,1,1,'\\ ','mikey-will-eat-it'),(5944,593690331013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',95.95,'eastar4','jay7581','jay7581@hotmail.com','Jason A Hamman','955 Dempster St','Temperance','MI','UNITED STATES','48182','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 01:23:58',0,NULL,3,1,1,1,'\\ ','jay7581'),(5945,593691563013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','desertcomputersolutions','info@desertcomputersolutions.net','Christopher Barry','16213 S 33rd St','Phoenix','AZ','UNITED STATES','85048-7255','(602) 295-5918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 01:33:46',0,NULL,3,1,1,1,'\\ ','desertcomputersolutions'),(5946,593697312013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','eilliac1','eilliac@telus.net','Chris Caillie','865 Marguerite Rd','Campbell River','BC','CANADA','V9W 3K4','(250) 287-7717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 02:07:04',0,NULL,3,1,2,1,'\\ ','eilliac1'),(5947,593698049013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',34.8,'eastar4','wood.jake','jakeadamwood@gmail.com','Jake Wood','35/1 cowlishaw street<br>Greenway','Canberra','Australian Capital Territory','AUSTRALIA','2900','0488586162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 02:11:13',0,NULL,3,1,3,1,'RA117775161CN\r ','wood.jake\rCASS001\rCAB-SS-2626'),(5948,724742726011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','gdfiander','dfiander@netlantek.com','Duncan Fiander','4281 Express Ln<br>Ste L1061','Sarasota','FL','UNITED STATES','34238-2602','(408) 398-3001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 02:39:59',0,NULL,3,1,1,1,'、 ','gdfiander   \rnew address: Duncan Fiander \r330 Elan Village Lane, Apt 411, San Jose CA. 95134.\rUNITED STATES'),(5949,724768930011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',121.99,'eastar4','gibbo281','markgibson1971@yahoo.com','Mark Gibson','119/23 George Street','North Strathfield','New South Wales','AUSTRALIA','2137','0420905604','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-19 05:05:09',0,NULL,3,1,3,1,'RA117775657CN\r ','gibbo281\rGLSG001*2'),(5950,546175546004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','macjag1999','allenpchan@yahoo.com','A. Chan','2425 Ortega St','San Francisco','CA','UNITED STATES','94122-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-19 06:06:15',0,NULL,3,1,1,1,'\\ ','macjag1999'),(5951,593741454013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',79.99,'eastar4','ento007','entomoio@gmail.com','Theo Franco','Rua Jeronimo Durski, 599 BATEL','Curitiba','PR','BRAZIL','80440-180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 07:44:15',0,NULL,3,1,3,1,'RA117775691CN\r ','ento007 \rMOSA003\r客户再买一个，US$77  一共发两个'),(5952,593744447013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','flashbangsmoke','stephenkensett@gmail.com','STEPHEN KENSETT','4 Spencer Street','Apple Tree Creek','Queensland','AUSTRALIA','4660','0411959438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 07:56:05',0,NULL,3,1,2,1,'\\ ','flashbangsmoke\r澳标'),(5953,724805657011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','brokedownwilly','brokedownwilly@aol.com','Eric Williamson','408 Minden St','Ruston','LA','UNITED STATES','71270-3714','(318) 251-3487','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 08:09:05',0,NULL,3,1,1,1,'\\ ','brokedownwilly'),(5954,724824501011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','gangakiero','pepematias@msn.com','José Miguel Matías Fernández','Av. Isidor Macabich, 28, 4º, 1ª','Ibiza','Baleares','SPAIN','07800','659963137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 09:09:29',0,NULL,3,1,3,1,'RA117775572CN\r ','gangakiero\rGLSG001*2'),(5955,724829896011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',17.1,'eastar4','dohawkins2','daveohawkins@btinternet.com','Dave Hawkins','4th Floor, St. Clements House<br>Marsh Street','Bristol','Avon','UNITED KINGDOM','BS1 4AY','07793534091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 09:30:28',0,NULL,3,0,2,1,'\\ ','dohawkins2'),(5956,593769620013,230620799040,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',3,'HSSA004',59.97,'eastar4','sharon.segal1972','sharon.segal@gmail.com','Sharon Segal','Hyakinton 1<br>POB - 6870','Oranit','Israel','ISRAEL','44813','972-50-4014273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 09:47:00',0,NULL,3,1,3,1,'RA117775759CN\r ','sharon.segal1972\rHSSA004'),(5957,593781690013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','moodangz','moo145@gmail.com','Worawut Hirunsethawat','394, U-Charoen 29 Village<br>Ratchadapisek Road, Samsennok','Huaykwang','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 10:31:49',0,NULL,3,1,2,1,'\\ ','moodangz'),(5958,593805737013,230393139939,'2.1 Acer Aspire 5560 5562 Bluetooth Module EDR + cable',1,'BTAC2102',12.4,'eastar4','flow77770','leow@iprimus.com.au','Leo Wolf','Leo Wolf<br>P.O. Box 340','Manunda','Queensland','AUSTRALIA','4870','0407621039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 12:02:54',0,NULL,3,1,2,1,'\\ ','flow77770\racer 4pin1.25 4cm'),(5959,724902397011,320700561477,'New genuine Samsung 3D Active Glasses SSG-2100AB ',1,'GLSG001',68.99,'eastar4','stevos259','lstevoski67@optusnet.com.au','luke stevoski','13 carisbrook court','taylors hill','Victoria','AUSTRALIA','3037','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTracking','2011-06-19 12:31:32',0,NULL,3,1,3,1,'RA117775643CN\r ','stevos259\rGLSG001'),(5960,540582342003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','burky83','burks06092006@yahoo.com','Jusitn Burk','PSC 41 Box 6033','APO','AE','AA','09464','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'burky83'),(5961,804876494012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','lindstromd','lindstromd@gmail.com','Dan Lindstrom','Edison A<br>Ericsson Software Campus','Athlone','Co Westmeath','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 12:43:28',0,NULL,3,1,3,1,'RA117775630CN\r ','lindstromd\rOTHP003'),(5962,724909522011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','niklasniklebee','djnoxx@gmx.net','Dominik  Weyers','Flasbloem 30','Kleve','','GERMANY','47533','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 12:50:06',0,NULL,3,1,3,1,'RA117775246CN\r ','niklasniklebee\rUDAP001'),(5963,724918577011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','kairatsmatov','smatovkairat@yahoo.com.au','Kairat SMATOV','51 Fourth Avenue','Blacktown','New South Wales','AUSTRALIA','2148','0298810228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 13:14:22',0,NULL,3,1,6,1,'EE506555611CN ','kairatsmatov\rGLSG001*2+GLOT004*2\r再发一个2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR\r\r'),(5964,724920177011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','wlgmhun9','urishova.yana@gmail.com','Andrey Urishov','Moscow 9, 123','Kremenchuk','UA','UKRAINE','39600','+30937555139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 13:15:04',0,NULL,3,1,2,1,'\\ ','wlgmhun9\r欧标\rHSJA005'),(5965,804892718012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','leeleelee1','llbray@btopenworld.com','Lee Braybon','9 Laurel Close','Worthing','West Sussex','UNITED KINGDOM','BN133PY','01903830522','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 13:19:50',0,NULL,3,1,3,1,'RA117775250CN\r ','leeleelee1\rOTCN003'),(5966,724923955011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',110,'eastar4','kairatsmatov','smatovkairat@yahoo.com.au','Kairat SMATOV','51 Fourth Avenue','Blacktown','New South Wales','AUSTRALIA','2148','0298810228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 13:24:22',0,NULL,3,1,17,0,NULL,'kairatsmatov'),(5967,724925963011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','lee_marshall','ebay@lee-marshall.co.uk','Lee Marshall','27 Avington<br>Great Holm','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK8 9DG','01908267306','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 13:28:31',0,NULL,3,1,3,1,'RA117775232CN\r ','lee_marshall\rRELO003\r红边优联'),(5968,724927298011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','ddea4090','dmdeall@hotmail.com','David Deall','6/4 Jaques Avenue','Bondi Beach','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-19 13:30:46',0,NULL,3,1,3,1,'RA117775484CN\r ','ddea4090\rOTSO004*2'),(5969,724932651011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','betinho2605','ry_betinho@hotmail.com','PRISCILA YOSHIDA','UGASE-CHO TAKASE MINAMI MINE 2-16','TOYOTA-SHI','Aichi','JAPAN','4442204','0565585257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 13:44:30',0,NULL,3,1,2,1,'\\ ','betinho2605'),(5970,724935721011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','amorrortu8','j_amorrortu8@hotmail.com','Javier Amorrortu Barreda','Urb. Monte claro nº 54<br>cancello cabo vilaño','laracha - la coruña','Galicia','SPAIN','15145','618311774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 13:56:32',0,NULL,3,1,3,1,'RA117775590CN\r ','amorrortu8\rGLSG001*2'),(5971,724953160011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','masterhl','masterniu@gmail.com','Lei He','22/1-9 Andover Street','Carlton','New South Wales','AUSTRALIA','2218','0295878604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 14:30:41',0,NULL,3,1,3,1,'RA117775175CN\r ','masterhl\rWLAP009'),(5972,540630143003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',39.9,'cnfaner','aliabdulahi01033545','aliabdulahi79@yahoo.com','ali abdulahi','3545 waldrop trl','decatur','GA','UNITED STATES','30034-7463','(678) 549-3154','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-19 15:15:00',0,NULL,3,1,1,1,'\\ ','aliabdulahi01033545'),(5973,546316869004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',31.95,'cnfaner','chilirider','maierg@gmx.net','Ingrid Rudolph','Boslerstr. 6/1','Böblingen','','GERMANY','71032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 15:42:25',0,NULL,3,1,3,1,'RA117775192CN\r ','chilirider\rWWSI002'),(5974,804980118012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','paulmusat','nnsese@gmail.com','Sergiu Neamt','Petru Rares 2/8','Dej','Cluj','ROMANIA','405200','+40744-873103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 16:04:08',0,NULL,3,1,2,1,'\\ ','paulmusat'),(5975,804990796012,220763418811,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',5.8,'eastar4uk','ganc2005','miras58@vp.pl','MIROSLAW KOWAL','43 GRAHAM AVENUE','LONDON','London','UNITED KINGDOM','CR4 2HJ','07521306535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 16:18:36',0,NULL,3,1,3,1,'RA117775201CN\r ','ganc2005\rPOLO001'),(5976,725032666011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','atrialis','atrialis@gmail.com','Alejandro Contreras','Cauda 763<br>Jardines del Bosque','Guadalajara','Jalisco','MEXICO','44520','5233-31225513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 16:49:00',0,NULL,3,1,2,1,'\\ ','atrialis'),(5977,805014495012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','misterblacktie','miguel.martin@gmail.com','Miguel Martin Nieto','Avda Mesa y Lopez 77, 3C','Las Palmas de Gran Canaria','Canarias','SPAIN','35010','622792221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 16:51:20',0,NULL,3,1,3,1,'RA117776374CN ','misterblacktie\rOTSO004*2\r盒装的'),(5978,725036686011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','jackyleijackylei','jackylei10@hotmail.com','Lik Hong Lei','10/F,35,Wong Nai Chung Rd,Happy Valley,Hong Kong','default','','HONG KONG','default','852-90384540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 16:56:19',0,NULL,3,1,2,1,'\\ ','jackyleijackylei'),(5979,805039350012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','sf6440','stevenfelton@bellsouth.net','Steven  Felton','644 Queen Cir','Jackson','MS','UNITED STATES','39209-2213','(601) 922-6910','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 17:27:03',0,NULL,3,1,1,1,'\\ ','sf6440'),(5980,725070485011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',3,'BAIN001',23.97,'eastar4','sheilakm','sheilackm@gmail.com','Sheila Macedo','R Aluysio Simoes, 173, Bento Ferreira<br>apto 201, ed. Zurbaran','Vitoria','Espirito Santo','BRAZIL','29050010','(027)88667936','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 17:40:22',0,NULL,3,1,2,1,'\\ ','sheilakm'),(5981,725108113011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','yordankai123','viki108@abv.bg','Yordanka Ihtimanliyska','18 Cromer Road<br>Sale','Manchester','Cheshire','UNITED KINGDOM','M33 3EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 18:24:03',0,NULL,3,1,3,1,'RA117775538CN\r ','yordankai123\rOTSO001'),(5982,805098842012,220501825899,'2.1 Acer Aspire 4720 4720G 4720Z Bluetooth Module+cable',1,'BTAC2115',12.4,'eastar4','sandroap','sandroap_2002@hotmail.com','sandro petronilia','kaja renak #29 desaan','curacao','netherlandse antillen','NETHERLANDS ANTILLES','*******','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 18:26:58',0,NULL,3,1,2,1,'\\ ','sandroap\racer 5pin1.25 20cm '),(5983,805110834012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',2,'OTAP001',18.98,'eastar4','cagrund2011','cagrund@t-online.de','Carsten Grund','36560195<br>Packstation 101','Siegen','','GERMANY','57072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 18:38:48',0,NULL,3,1,2,1,'\\ ','cagrund2011'),(5984,593989862013,230622774836,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','mm1bxf','gnesbitt@orange.net','Gavin Nesbitt, IOTAS Ltd','4 Quy Court<br>Colliers Lane','Stow-cum-Quy','Cambridgeshire','UNITED KINGDOM','CB259AU','07780008882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 19:06:11',0,NULL,3,1,3,1,'RA117775524CN\r ','mm1bxf\rMOLO005\r 蓝牙版 '),(5985,805134435012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','lockie1970','paullock@ntlworld.com','Paul Lock','85 Carnforth Gardens','Hornchurnch','Essex','UNITED KINGDOM','RM12 5DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 19:09:48',0,NULL,3,1,3,1,'RA117775158CN\r ','lockie1970\rHSPL011\r英标'),(5986,725145966011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',105.99,'eastar4','eul481','dkresge@kresgelink.net','David Kresge','6614 Fountains Cir','Lake Worth','FL','UNITED STATES','33467-5754','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 19:13:16',0,NULL,3,1,4,1,'YW865717835CN ','eul481'),(5987,725138016011,320691247780,'NIB SONY UWA-BR100 BRAVIA USB WIRELESS LAN ADAPTER',1,'OTSO001',47.99,'eastar4uk','yacov51','gechtler@013.net.il','yacov gechtler','even danan 526/16','netivot','','ISRAEL','87722','*972545445266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 19:20:15',0,NULL,3,1,3,1,'RA117775498CN\r ','yacov51\rOTSO001'),(5988,805144319012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','sergiozin','ebay@sergioz.com','Sergio Zingerevitz','Pardes St., 114/44<br>Neve Yaakov','Jerusalem','','ISRAEL','97471','+972-52-7662057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 19:27:25',0,NULL,3,1,2,1,'\r\\ ','sergiozin\r新地址\rIsrael Meir Zimrat\rBroier St., 19\rBnei Brak 51388\rIsrael\r'),(5989,725164639011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','imalooser','brucek@outhouseinc.com','Cassie Keesee','4711 Regency Dr','Durham','NC','UNITED STATES','27713','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 19:33:22',0,NULL,3,1,1,1,'\\ ','imalooser'),(5990,725166088011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',18.99,'eastar4','jms_2k1','teh.guru.jms@gmail.com','jon silva','3 virginia ave','beverly','MA','UNITED STATES','01915-3935','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 19:38:10',0,NULL,3,1,1,1,'\\ ','jms_2k1'),(5991,725167955011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','fearhq','fearhq@hotmail.com','Artur Sidorowicz','4965 Bonny apt 5','Pierrefonds','QC','CANADA','H8Y 2A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 19:38:16',0,NULL,3,1,3,1,'RA117775060CN\r ','fearhq\rHSLO001'),(5992,725181582011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','corne67','cornevanleeuwen@kpnmail.nl','Corné van Leeuwen','Wintervlinderhof 5','Oosterhout','','NETHERLANDS','4904 XK','0162-422954','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 19:56:45',0,NULL,3,1,2,1,'\\ ','corne67\r红边优联'),(5993,724360678011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','carlie4671','carlie.beattie@gmail.com','Carlie Beattie','8 Abate Place<br>Midway Point','Hobart','Tasmania','AUSTRALIA','7171','0439732840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 20:01:14',0,NULL,3,1,2,1,'\\ ','carlie4671'),(5994,805190710012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','scoobie5scoobie','scoobiewayne@aol.com','wayne pascoe','80 Cornish crescent<br>Malabar','Truro','Cornwall','UNITED KINGDOM','tr13pe','01872275508','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 20:13:12',0,NULL,3,1,3,1,'RA117775382CN\r ','scoobie5scoobie'),(5995,540789518003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',22.99,'cnfaner','atomino206','alessandro.fellin@vivoscuola.it','Armando Fellin','Viale Verona, 89','Trento','TN','ITALY','38123','3358441747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 20:42:13',0,NULL,3,1,3,1,'RA117775073CN\r ','atomino206\rWLIN013'),(5996,725225036011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA004',47.98,'eastar4','zoomzpro','zoomdepro@hotmail.com','Kirill Garnets','Schipholtstraat 154','Enschede','','NETHERLANDS','7534 dc','0031634825823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 21:09:35',0,NULL,3,1,3,1,'RA117775436CN\r ','zoomzpro\rHSJA004\r欧标'),(5997,805224057012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',87.9,'eastar4','6494jrap','jrap6494@gmail.com','JUAN RAMON ALVAREZ PEREZ','APARTADO DE CORREOS 17','ADEJE','Canarias','SPAIN','38670','668864635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 21:13:38',0,NULL,3,1,3,1,'RA117776198CN ','6494jrap\rOTSO002'),(5998,725242729011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','gav1280','gav1201@hotmail.co.uk','MR G WARR','RAYSONS RADIATORS<br>UNIT 25, VENTURE 20, BRYMPTON WAY','YEOVIL','Somerset','UNITED KINGDOM','BA20 2HP','01935428058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 21:51:03',0,NULL,3,1,2,1,'\\ ','gav1280\r英标'),(5999,688034098001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','ampickup','ampickup@comcast.net','Angela M Pickup','25 Harbor Mist Dr','Fairhaven','MA','UNITED STATES','02719-1900','(508) 676-1971','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 22:28:55',0,NULL,3,1,1,1,'\\ ','ampickup'),(6000,725256960011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','dorit710','rvnsh@walla.com','reuven shloosh','kikar zabotinski 7/10','tiberias','','ISRAEL','14227','052-4236738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 22:28:56',0,NULL,3,1,11,1,NULL,'dorit710\rANYA001'),(6001,540828460003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',27.16,'cnfaner','winebrand1','emilio1234@gmail.com','Emil Winebrand','27A, Weissburg','Tel Aviv','','ISRAEL','69358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 23:09:34',0,NULL,3,1,3,1,'RA117775405CN\r ','winebrand1\rHSPL005'),(6002,805277139012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','dragon21808','matt@hantgin.com','Matt Hantgin','774 Forest Loop Dr','Port Hueneme','CA','UNITED STATES','93041-2619','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 23:23:18',0,NULL,3,1,1,1,'\\ ','dragon21808\r旧的'),(6003,805281804012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','chungsiwel91','siwelchungster@gmail.com','Lewis Chung','1000 Ashland Ave<br>Apt 7','Santa Monica','CA','UNITED STATES','90405-4647','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 23:41:24',0,NULL,3,1,1,1,'\\ ','chungsiwel91'),(6004,805298423012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','jairobotassi123','jairo.botassi@hotmail.com','Jairo Botassi dos Santos','Rua Prof. Belmiro Siqueira, 85<br>apto 1701, Torre 2, Enseada do Suá','Vitoria','Espirito Santo','BRAZIL','29050-580','(+5527) 3324-5889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 00:32:08',0,NULL,3,1,3,1,'RA117775515CN\r ','jairobotassi123\r盒装的\rOTSO004*2'),(6005,805305817012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.74,'eastar4','jjndi','jjndishire@gmail.com','JOHN SHIRE','501 Porpoise Cv','Patrick AFB','FL','UNITED STATES','32925-3149','(662) 352-6953','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 00:54:28',0,NULL,3,1,1,1,'\\ ','jjndi'),(6006,594105999013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',22,'eastar4','honeydust','mf_tucanu@yahoo.com','Mihaela Tucanu','11700 rue Pasteur app 307','Montreal','QC','CANADA','H3M 2P3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 01:03:50',0,NULL,3,1,2,1,'\\ ','honeydust'),(6007,540853949003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',27.16,'cnfaner','arlequino444','deski444@hotmail.com','Maria Eugenia Delaloye','Quintino Bocayuva 252','Buenos aires, Capital Federal','Argentina','ARGENTINA','1181','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 01:18:43',0,NULL,3,1,3,1,'RA117776184CN\r ','arlequino444\rHSPL005\r欧标'),(6008,725314271011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','sandyphuan','nydc_sandy@hotmail.com','Sandy Phuan','81 Middle Street','Cooper Plains','Queensland','AUSTRALIA','4108','61430300960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 01:46:24',0,NULL,3,1,2,1,'\\ ','sandyphuan'),(6009,546536194004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','silver8313','silvercam817@aol.com','Ken Antongiorgi','1108 Harvest Grove Trl','Dover','DE','UNITED STATES','19901-2782','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 01:49:45',0,NULL,3,1,1,1,'\\ ','silver8313'),(6010,725320728011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','vibeq2','vibeq2@aol.com','Kenya McCarty','8710 NW 44th St','Lauderhill','FL','UNITED STATES','33351-6000','(954) 899-1532','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 02:08:26',0,NULL,3,1,1,1,'\\ ','vibeq2'),(6011,805331102012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','jackkodak','gainesjp@comcast.net','Jeff Gaines','89 Pratt Dr','Enterprise','AL','UNITED STATES','36330-2293','(253) 209-4192','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 02:09:47',0,NULL,3,1,1,1,'\\ ','jackkodak'),(6073,805886782012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','ambrodk','diabloa86@gmail.com','Carlos Zamora','1671 ardmore ave','Glendale heights','IL','UNITED STATES','60139-2507','(630) 808-7676','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 06:52:18',0,NULL,3,1,1,1,'、 ','ambrodk'),(6012,724239514011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','songkhla78','tinalam_49@yahoo.com','Mai  Tran','604-7415 Beaubien Est','Anjou','QC','CANADA','H1M 3R5','(514) 352-6091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 03:09:54',0,NULL,3,1,2,1,'\\ ','songkhla78'),(6013,805359033012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','sdimcg1','sdimcg@gmail.com','Dianna McGaughey','132 Shadow Creek Lane','Medina','TN','UNITED STATES','38355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 03:51:06',0,NULL,3,1,1,1,'\\ ','sdimcg1'),(6014,805359721012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','tp.613','tai_pham@hotmail.com','Tai Pham','1188 Rockingham Ave','Ottawa','ON','CANADA','K1H8A7','(613) 820-9193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 03:58:11',0,NULL,3,1,3,1,'RA117775467CN\r ','tp.613\rOTSO004*2'),(6015,688122128001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',19.99,'buysia','macibank','shanmaci@yahoo.com','shanel neal','322 oakshire dr','houma','LA','UNITED STATES','70364','(985) 855-0896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 04:07:00',0,NULL,3,1,1,1,'\\ ','macibank'),(6016,805363272012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','ballesteros_10','ballesterosat@state.gov','Vili Kuruyawa','American Embassy Majuro 4380 Majuro Place','Washington','DC','UNITED STATES','20521-4380','202 536 4143','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 04:11:38',0,NULL,3,1,1,1,'\\ ','ballesteros_10\rMX20T'),(6017,805370528012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',7.98,'eastar4','daihatsu95','w.vale81@live.com.au','wayne vale','po box 483','riverwood','New South Wales','AUSTRALIA','2210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 04:48:25',0,NULL,3,1,2,1,'\\ ','daihatsu95\rBTAC2000'),(6018,543136734004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','gihad1995','preetyprincess62@yahoo.com','gihad hussein','14314 w e st','kerman','CA','UNITED STATES','93630-1961','(559) 842-5551','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 05:47:52',0,NULL,3,1,1,1,'\\ ','gihad1995'),(6019,805381380012,220546791970,'Yagi 16dBi 2.4 GHz 802.11b/g Wifi Antenna RP-SMA',1,'ANYA001',57.8,'eastar4','ksy_com','ksycom@gmail.com','KSY.Computer','43 Sangchuto Rd.<br>T.Tamakam','Moung','Kanchanaburi','THAILAND','71000','6634624422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 05:48:51',0,NULL,3,1,3,1,'RA117775895CN\r ','ksy_com\rANYA001\r一共买了四个'),(6020,540909033003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','shanzq28','shanzq28@hotmail.com','zhi qiang shan','3256 william st','vancouver','BC','CANADA','v5k 2z1','(604) 710-7766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 07:22:55',0,NULL,3,1,3,1,'RA117775802CN\r ','shanzq28\rHSSE003'),(6021,725392728011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','infinity0609','infinity99@hanmail.net','son kwang wook','seonbuk-gu office 3 floor Land Registration Division<br>samsundong5ga seonbuk-gu','seoul','','KOREA,REPUBLIC OF','136-706','82-02-920-3235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 08:05:43',0,NULL,3,1,2,1,'\\ ','infinity0609'),(6022,805415843012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',9.99,'eastar4','andre06nice','andre06@edengo.com','ANDRE GORDEAUX-REMY','127,B CHEMIN DE LA COSTIERE','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06000','0609500387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 08:24:06',0,NULL,3,1,2,1,'\\ ','andre06nice'),(6023,805422428012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','senyabazarov','galaher@mail.ru','Konstantin Bazarov','Triumfalnaya 8-101','Volgograd','','RUSSIAN FEDERATION','400123','+7-905-391-12-91','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 08:50:52',0,NULL,3,1,3,1,'RA117776312CN\r ','senyabazarov\rOTGR001+OTGR002'),(6024,805427868012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','ricfilbrad','graham.allmond@pluswork.org','Graham Allmond','Wiswell Eaves Barn<br>Pendleton Road, Wiswell','Clitheroe','Lancashire','UNITED KINGDOM','BB7 9BZ','01254824427','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 09:12:07',0,NULL,3,1,3,1,'RA117776238CN\r ','ricfilbrad\rOTGR001'),(6025,805440695012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','enoshteoh','gentat@gmail.com','Teoh Gen Tat','53 Jln SS 15/8A','Subang Jaya','Selangor','MALAYSIA','47500','0163399896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 10:08:50',0,NULL,3,1,2,1,'\\ ','enoshteoh'),(6026,725426979011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','v.hill','vasiliy.hill@gmail.com','Vasiliy Hill','2g Temiryazev','Almaty','','KAZAKHSTAN','050013','+77012111025','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 10:24:34',0,NULL,3,1,3,1,'RA117776309CN\r ','v.hill\rWWSI006'),(6027,0,110703669154,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','msrotherham','marksmith34@googlemail.com','Mark Smith','26 Netherfield View','Rotherham','South Yorkshire','UNITED KINGDOM','S65 3RB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 10:58:45',0,NULL,3,0,3,1,'RA117776326CN\r ','msrotherham\rBR3D007'),(6028,546618686004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','viewizard','viewizard@viewizard.com','Michael Kurinnoy','kvartal Zhukova, dom 10, kvartira 79','Lugansk','','UKRAINE','91051','+380642410102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:03:50',0,NULL,3,1,3,1,'RA117776343CN\r ','viewizard\rWWSI005'),(6029,0,110703616522,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',66,'buysia','bres1001','rinus@email-ons.nl','Frans Davids','Escamplaan 625','Den Haag','','NETHERLANDS','2547 ED','0645472916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:23:10',0,NULL,3,1,3,1,'RA117776357CN\r ','bres1001\rBR3D003'),(6030,725422174011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','raulahmed','9184531661@mail.ru','Михаил Воронков','ул.Калинина 13, корпус 60, квартира 41','г.КРАСНОДАР','Краснодарский край','RUSSIAN FEDERATION','350000','89184531661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:36:11',0,NULL,3,1,3,1,'RA117776272CN\r ','raulahmed\rUDAP001'),(6031,594216054013,230634873074,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',36.95,'eastar4','agnerms','agner7@msn.com','AGNER MELO SILVA','RUA DOMINGOS MAZZA, Nº 207<br>VILA BOAÇAVA','SÃO PAULO','SÃO PAULO','BRAZIL','05170-280','+551180175926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:53:14',0,NULL,3,1,3,1,'RA117776286CN\r ','agnerms\rOTRA003'),(6032,725452797011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','skjojo01','jojokomnoun@yahoo.com','Sorakai Komnoun','111/522 Soi.15 Sirisuk\'Village Seegun','Donmung','Bangkok','THAILAND','10210','+66853636276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:54:52',0,NULL,3,1,2,1,'\\ ','skjojo01'),(6033,594221299013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','all-colours-of-life','allcoloursoflife@gmail.com','Аnton Кulagin','ulitsa Flagmanskaya, dom 3, kvartira 2','Sevastopol','Crimea','UKRAINE','99040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 12:08:10',0,NULL,3,1,3,1,'RA117776405CN\r ','all-colours-of-life\rWLIN014'),(6034,725460136011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','rayista38','alcazarrayito@wanadoo.es','Alejandro Alcazar Sanchez','cl. Gerardo Diego, 11 4ºG','Madrid','Madrid','SPAIN','28018','913034319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 12:18:10',0,NULL,3,1,2,1,'\\ ','rayista38'),(6035,805491176012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',3,'HSMO011+CCMO001',32.97,'eastar4uk','lilyandannie','rmckenzie4drains@aol.com','Mr Ryan Mckenzie Business Mr R Mckenzie','Ellandaye House<br>The Shore','Gravesend','Kent','UNITED KINGDOM','DA11 9NL','07971513354','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 12:39:06',0,NULL,3,1,3,1,'RA117776330CN\r ','lilyandannie\rHSMO011+CCMO001'),(6036,594236389013,230634873074,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',36.95,'eastar4','aebustaj09','aebustaj@hotmail.com','Ariel Bustamante','EMILIA TELLEZ 4732<br>NUNOA','Santiago','Region Metropolitana','CHILE','7790912','056984568732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 13:17:53',0,NULL,3,1,3,1,'RA117776215CN\r ','aebustaj09\rOTRA003'),(6037,725485507011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','dandondelyus','mcdemir@gmail.com','Metin Celikdemir','Akbank Bankacılık Merkezi Cumhuriyet Mah Plevne Cad Dereli Sok<br>No:1 Sekerpinar','Cayirova/Kocaeli','','TURKEY','41420','+902626862127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 13:37:53',0,NULL,3,1,2,1,'\\ ','dandondelyus'),(6038,688260365001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','lan2731','leo.niehoff@eon-us.com','Leo Niehoff Jr.','5252 Cane Run Rd','Louisville','KY','UNITED STATES','40216','(502) 939-5993','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 14:17:15',0,NULL,3,1,1,1,'\\ ','lan2731'),(6039,688111594001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','mrpiccolo','donhow@comcast.net','Don Howell','19020 46th Ave S','Seatac','WA','UNITED STATES','98188-5033','(206) 241-6810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 14:33:24',0,NULL,3,1,1,1,'\\ ','mrpiccolo'),(6040,725528930011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','kcarr1883','kcarr1883@eircom.net','Kevin Carr','53 Duncombe Road South','Liverpool','Merseyside','UNITED KINGDOM','L191QH','0851561898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 15:40:43',0,NULL,3,1,2,1,'、 ','kcarr1883'),(6041,805567784012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',12.5,'eastar4','jontemple1','jontemple01@gmail.com','Jonathan Temple','23018 Walderford Dr','Katy','TX','UNITED STATES','77450-1488','(713) 289-0133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 16:02:56',0,NULL,3,1,1,1,'\\ ','jontemple1\r华硕10pin 0.8 6cm '),(6042,725538461011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','balcum','jimmybalcum@gmail.com','Balcum Appliance','724 n 8th st','Superior','WI','UNITED STATES','54880-1373','(715) 392-4808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 16:04:12',0,NULL,3,1,1,1,'\\ ','balcum'),(6043,805583033012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','badiondima','badion@narod.ru','Dima Badion','Sholom-Alejhem st 14/5','Lviv','Lviv','UKRAINE','79-82','+380976652787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 16:37:13',0,NULL,3,1,2,1,'\\ ','badiondima'),(6044,725284830011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',18.98,'eastar4','drmrsguild','drmrsguild@cox.net','Scott T Wheeler','4216 W Eva St','Phoenix','AZ','UNITED STATES','85051-3243','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 16:39:48',0,NULL,3,1,1,1,'\\ ','drmrsguild'),(6045,725558264011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','guit_fiddler','feylya@gmail.com','Paul O\'Connor','1 Glenbourne Green<br>Leopardstown Valley','Leopardstown','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-20 16:51:01',0,NULL,3,1,3,1,'RA117776269CN\r ','guit_fiddler\rWLAP002\r旧的'),(6046,725576931011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','hasni57','to.hasni@gmail.com','hasni mohamed','eagle street','Ipswich','Suffolk','UNITED KINGDOM','ip4 1ja','07412459885','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 17:31:15',0,NULL,3,1,3,1,'RA117776255CN\r ','hasni57\rUDAP001'),(6047,723980190011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','mireydae','d291964@yahoo.com','david espinoza','15885 harvest moon st','la puente','CA','UNITED STATES','91744','(626) 523-2311','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 17:51:50',0,NULL,3,1,1,1,'\\ ','mireydae'),(6048,541045803003,130490976205,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',15.99,'cnfaner','pretoriaxn','egor_filatov@ymail.com','Filatov Egor','Severnoe Chertanovo 5V/26','Moscow','RU','RUSSIAN FEDERATION',' 117648 ','915-001-0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 18:01:09',0,NULL,3,1,3,1,'RA117776290CN\r ','pretoriaxn\r\rWLAP008+WLAT010\r再一个apple AR9280 AR5BXB92'),(6049,725595800011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','731big','bigmanmu@gmail.com','yura kostuk','hateina 4/5','netivot','darom','ISRAEL','87831','972547925559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 18:05:01',0,NULL,3,1,2,1,'\\ ','731big'),(6050,546724771004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.99,'cnfaner','pretoriaxn','egor_filatov@ymail.com','Filatov Egor','Severnoe Chertanovo 5V/26','Moscow','RU','RUSSIAN FEDERATION',' 117648 ','915-001-0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 18:06:31',0,NULL,3,1,17,0,' ','pretoriaxn'),(6051,594324224013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','dhitee2010','dhitiwass@gmail.com','Dhitiwass Suvagandha','International Students\' Dormitory Room 311<br>Kanazawa Medical University, 1-1 Daigaku,','Uchinada','Ishikawa','JAPAN','920-0293','(66) 865-719717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 18:10:10',0,NULL,3,1,2,1,'\\ ','dhitee2010'),(6052,805655506012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','6768jeff','tcjrhodes@ameritech.net','Jeff Rhodes','3145 W Clark Rd<br>Ste 401','Ypsilanti','MI','UNITED STATES','48197-1120','(734) 528-5767 ext.: 85767','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 18:49:00',0,NULL,3,1,1,1,'、 ','6768jeff'),(6053,725626469011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','moonbeam9999','thetuffster99@yahoo.co.uk','Richard Taylor','60 Holdenhurst Avenue','London','London','UNITED KINGDOM','n120hx','02083490022','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 18:58:15',0,NULL,3,1,3,1,'RA117776241CN\r ','moonbeam9999\rWLAP002'),(6054,725632377011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','julia-caxo','caxo_sc@mail.ru','Юлия Музалевская','ул. Кубанская 15а, кв. 34','Волгоград','Волгоградская область','RUSSIAN FEDERATION','400131','89093886636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 19:08:19',0,NULL,3,1,2,1,'\\ ','julia-caxo'),(6055,594350905013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',70.95,'eastar4','warnshuze','warnshuze@yahoo.com','Steven Lazar','PO Box 7061','Eureka','CA','UNITED STATES','95502','(707) 476-8681','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 19:15:48',0,NULL,3,1,1,1,'、 ','warnshuze'),(6056,594360066013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','dykjocke','jwcbr600@hotmail.com','Joakim wiklander','Sandgränd 14','Ekerö','','SWEDEN','17840','+46707760077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 19:36:49',0,NULL,3,1,3,1,'RA117776391CN\r ','dykjocke\rMOSA005'),(6057,805692456012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','goniveseli','agves@albmail.com','AGRON VESELI','LAGJA 6 RRUGA MALIQ MUCO<br>PALLATI 973 AP.6','DURRES','DURRES','ALBANIA','2001','355682033567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 19:48:48',0,NULL,3,1,3,1,'RA117776388CN\r ','goniveseli\rOTSO004*2'),(6058,594364811013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','camilabca','camibca@gmail.com','Camila Almeida','Rua Coronel Ferraz 76<br>Apto 201 - Centro','Fortaleza','CE','BRAZIL','60060-150','(55) 85 8711-2414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 19:52:23',0,NULL,3,1,2,1,'\\ ','camilabca'),(6059,805693576012,220619800390,'New Motorola HS820 Bluetooth Wireless Headset HS 820',1,'HSMO018',12.99,'eastar4','roey1206','roeyazroel@gmail.com','Roey Azroel','Brazil 3','Tel Aviv','','ISRAEL','20100','0578189693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 19:53:00',0,NULL,3,1,2,1,'\\ ','roey1206'),(6060,725678002011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','vegerano','vegerano21@msn.com','Pedro-Leo Vegerano','2321 Powell Ave','Bronx','NY','UNITED STATES','10462','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 20:32:13',0,NULL,3,1,1,1,'、 ','vegerano'),(6061,594393521013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.99,'eastar4','johnbeatzz','ebayjohnbeatzz@hotmail.com','Jonathan Ruest','136 de la Toundra','Breakeyville','QC','CANADA','G0S 1E1','(418) 832-9567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 21:07:45',0,NULL,3,1,2,1,' 、','johnbeatzz\r红边优联\r'),(6062,805736926012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',22.59,'eastar4uk','bomikabomika','mihaly.jozsef@invitel.hu','József Mihály','Dunadulo ut 5/A 8.49.','Budapest','','HUNGARY','1212','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-20 21:11:40',0,NULL,3,1,3,1,'RA117776224CN\r ','bomikabomika\rUDAP002'),(6063,725703152011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.81,'eastar4','jmpacio','pacio@vodafone.es','José Manuel Pacio','Calle Sol 20, 1ºA','A Coruña','Galicia','SPAIN','15003','669880453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 21:34:18',0,NULL,3,1,2,1,'\\ ','jmpacio'),(6064,725712825011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','wspi','spindler@spindler24.de','Wolfgang Spindler','Tulpenstr.12','Dorsten','','GERMANY','46284','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 21:56:29',0,NULL,3,1,2,1,'\\ ','wspi'),(6065,805796708012,220782473002,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',58.78,'eastar4','5688richardf','rickfarina65@yahoo.com.au','richard farina','8 michael street','north richmond','New South Wales','AUSTRALIA','2754','0403334049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 00:18:02',0,NULL,3,1,3,1,'RA117776167CN\r ','5688richardf\r澳标\r一共买了两个\rHSMO021\r新的'),(6066,0,110705132956,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',59.99,'buysia','bkfk','bkfk@aol.com','OWEN KANE','20731 Chappell Knoll Dr','CYPRESS','TX','UNITED STATES','77433-5511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 02:24:40',0,NULL,3,1,1,1,'、 ','bkfk'),(6067,805833909012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','roberturiahpatrick','robert_patrick@bellsouth.net','Robert Patrick','4500 Burgess Hill Ln','Alpharetta','GA','UNITED STATES','30022-1019','(770) 410-0924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 02:39:36',0,NULL,3,1,1,1,'\\ ','roberturiahpatrick\r'),(6126,806319270012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','metaphysicalmind','junkinternetmail@gmail.com','Ronald Zawora','2151 Lexington Ave','Pennsauken','NJ','UNITED STATES','08110-1957','(856) 324-4711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 03:57:55',0,NULL,3,0,1,1,'、 ','metaphysicalmind'),(6068,688530586001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',75.99,'buysia','07baltsssc','matt060488@yahoo.com','Matthew Schmitz','357 S Grant St','Seymour','WI','UNITED STATES','54165-1448','(920) 915-6741','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 03:05:15',0,NULL,3,1,1,1,'、 ','07baltsssc\r再发一个AVATAR New sealed Panasonic exclusive 3D Blu-ray'),(6069,594467314013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','kaiyang3','kai.yang@cba.com.au','Kai Yang','Level 12, 52 Martin Place<br>Sydney','Sydney','New South Wales','AUSTRALIA','2000','0293037226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 03:07:27',0,NULL,3,1,3,1,'RA117776502CN ','kaiyang3\rMOSA003'),(6070,805841371012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.4,'eastar4','paulacortes2010','paula1mgs@hotmail.com','Paula Cortes Costa','Baltazar Carneiro, 100, Centro','Campos Dos Goytacazes','Rio De Janeiro','BRAZIL','28035-273','22-98178309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 03:08:26',0,NULL,3,1,2,1,'、 ','paulacortes2010\racer 5pin1.25 15cm'),(6071,805857947012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','russty1978','russty1978@hotmail.com','Russell Kokegei','40 Randell St','Mannum','South Australia','AUSTRALIA','5238','0885691872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 04:23:34',0,NULL,3,1,2,1,'、 ','russty1978'),(6123,547139089004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',29.5,'cnfaner','sonys1991','glemme@optusnet.com.au','sonya lemme','53 brockman ave, revesby heights','sydney','New South Wales','AUSTRALIA','2212','0297724560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 02:22:51',0,NULL,3,1,3,1,'RA117776856CN\r ','sonys1991\r澳标\rHSNO005'),(6072,725813061011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','spalding30','gary@xyris.com','Gary Hunter','73 Six House Bank','West Pinchbeck','Lincolnshire','UNITED KINGDOM','PE11 3QG','(017) 756-4034 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 05:07:36',0,NULL,3,1,3,1,'RA117776493CN ','spalding30\rWLAP009'),(6074,541212601003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.9,'cnfaner','ska797','ska-sam@mail.ru','Aleksey Archibasov','Sovetskoy Army, 99-37','Samara','','RUSSIAN FEDERATION','443066','937-200-3090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 07:07:27',0,NULL,3,1,3,1,'RA117776520CN ','ska797\rHSNO019+CCNO001'),(6075,805889707012,220761694645,'New Logitech IO Digital Notebook for IO/ IO2 pen',1,'NTLO001',17.25,'eastar4','batizsystems','joseluisbatizlopez@gmail.com','Jose Luis Batiz Lopez','237 Rockwood Ave<br>Ste 120 PMB 2-350','Calexico','CA','UNITED STATES','92231-2762','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 07:08:15',0,NULL,3,1,1,1,'、 ','batizsystems'),(6076,541215750003,130490601966,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'',17.85,'cnfaner','broset','181079@gmail.com','Bas Roset','Palmstraat 43','Nijmegen','','NETHERLANDS','6542JW','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'broset'),(6077,725858515011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','jonstatt1','jonathan@statt.org','Jonathan Statt','33 Beningfield Drive','London Colney','Hertfordshire','UNITED KINGDOM','AL21UX','01727821561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 09:00:52',0,NULL,3,1,3,1,'RA117776808CN\r ','jonstatt1\rBR3D001'),(6078,725860133011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','kazza195','karren@djnelectrical.com.au','Karren Newbert','PO Box 3037','Rouse Hill','New South Wales','AUSTRALIA','2155','0407665630','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-21 09:07:38',0,NULL,3,1,3,1,'RA117776900CN\r ','kazza195\rOTSO004*2'),(6079,725860767011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','igor.radenovic','iradenovic@gmail.com','Igor Radenovic','Slavonska 21','Samobor','','CROATIA','10430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 09:13:39',0,NULL,3,1,2,1,'\\ ','igor.radenovic'),(6080,594523219013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',69.6,'eastar4','aka_smiley','andy.robinson@ciscosecurity.co.uk','Andy Robinson','NextiraOne UK Limited<br>Darwin House, Lichfield South, Birmingham Road','Lichfield','Staffordshire','UNITED KINGDOM','WS14 0QP','07971224215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 09:43:17',0,NULL,3,1,3,1,'RA117776754CN\r ','aka_smiley\rCASS003\r一共买了八个'),(6081,725916022011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',2,'HSUE004',26.98,'eastar4','modelbuilder1','kgb_corvette@hotmail.com','Karl Bengtsson','Börringegatan 1 B','Malmö','Sweden','SWEDEN','21772','+46-40-120827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 12:44:32',0,NULL,3,1,3,1,'RA117776799CN\r ','modelbuilder1\rHSUE004\r需要发四个'),(6082,725920014011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',26.8,'eastar4','spiffyimports','kevin.homer@gmail.com','Kevin Homer','1330 Jodi Dr','Layton','UT','UNITED STATES','84041','(801) 513-1753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 12:58:24',0,NULL,3,1,1,1,'\\ ','spiffyimports'),(6083,805977069012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','jana.silveira','jana.silveirarp@gmail.com','Janaína Oliveira Silveira','Rua Guilherme Schimidt, 581<br>Vila Tibério','Ribeirão Preto','São Paulo','BRAZIL','14050-150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:03:58',0,NULL,3,1,2,1,'\\ ','jana.silveira'),(6084,725921648011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','jimkel2001','jimkel@mail.com','James Kelly','20888 Conesus Sq','Ashburn','VA','UNITED STATES','20147-7153','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 13:05:06',0,NULL,3,1,1,1,'\\ ','jimkel2001'),(6085,594559792013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','molchoon1969','mol4oon@gmail.com','Юрий Яровой','ул. Родонитовая, дом 4А, кв. 111','Екатеринбург','Свердловская область','RUSSIAN FEDERATION','620073','(902) 9022799927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:08:31',0,NULL,3,1,6,1,'EE506555625CN ','molchoon1969\r盒装的\r\r620073, the Russian Federation\rStreet Rodonitovaja, the house 4А, apartment 111\rEkaterinburg, Sverdlovsk area \r\rYarovoy Yury Efimovich\r\r'),(6086,725922910011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','ironcamaro','xmen_cordero@hotmail.com','HERMES LAFITA','1121 E 7TH CT','HIALEAH','FL','UNITED STATES','33010-3629','(786) 457-0349','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 13:09:56',0,NULL,3,1,1,1,'\\ ','ironcamaro'),(6087,725934963011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','biggs_auto_and_atv','biggsjunk@yahoo.com','Biggs Auto & ATV','4100 w marshall ave','Longview','TX','UNITED STATES','75604','(903) 720-6012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 13:46:59',0,NULL,3,1,1,1,'\\ ','biggs_auto_and_atv'),(6088,594576673013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','wollviehh','ebay1@gipmans.net','Wolfgang Gipmans','Kanzlei 95','Meerbusch','','GERMANY','40667','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 14:12:33',0,NULL,3,1,3,1,'RA117776785CN\r ','wollviehh\rWLAP005+WLAP008\r再发一个apple AR9280 AR5BXB92'),(6089,594578513013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','wollviehh','ebay1@gipmans.net','Wolfgang Gipmans','Kanzlei 95','Meerbusch','','GERMANY','40667','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 14:20:56',0,NULL,3,1,17,0,NULL,'wollviehh'),(6090,592982242013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','sethhardley','shardley@aero.und.edu','Seth Hardley','215 Northwestern Dr','Grand Forks','ND','UNITED STATES','58203-2795','(352) 242-7753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 14:28:15',0,NULL,5,0,18,0,NULL,'sethhardley\r'),(6091,541290223003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',16.75,'cnfaner','jamat2010','jamat17@hotmail.com','Javier Antonio Amat','Thomas Martínez 102 y Malecon','Guayaquil','Guayas','ECUADOR','090111764','04-2311144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 14:36:39',0,NULL,3,1,3,1,'RA117776771CN\r ','jamat2010\rHSNO005+CCNO001'),(6092,806014903012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',78.7,'eastar4uk','gatenrostov','gaten@aaanet.ru','Vladimir Gatenadze','4-KOLCEVAJA, 26','Rostov-on-Don','Rostovskaia obl','RUSSIAN FEDERATION','344004','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-21 14:37:03',0,NULL,3,1,3,1,'RA117776839CN\r ','gatenrostov\rRCMA001'),(6093,725955749011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','estebanp','aurelie.imhoff@bbox.fr','IMHOFF AURELIE','161 RUE DE PARIS','SOTTEVILLE LES ROUEN','Haute-Normandie','FRANCE','76300','0981872679','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 14:55:13',0,NULL,3,1,2,1,'\\ ','estebanp'),(6094,594588058013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','jben2452','johnbenson@embarqmail.com','John Benson','4183 North 500 West','Bargersville','IN','UNITED STATES','46106','(317) 422-1445','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 15:02:49',0,NULL,3,1,1,1,'\\ ','jben2452'),(6095,541300636003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.95,'cnfaner','israeln43','israeln3@hotmail.co.il','israel naim','ha\'alia, 1637/1<br>1637/1','dimona','IL','ISRAEL','86000','(+972)547799873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 15:24:27',0,NULL,3,1,3,1,'RA117776768CN\r ','israeln43\rMOAP001\r新的'),(6096,806040924012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','bigxrob75','bigxrob75@aol.com','Rob Rossi','169 Commack Rd<br>Box 148 Ste H','Commack','NY','UNITED STATES','11725-3442','(631) 513-1606','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 15:48:19',0,NULL,3,1,1,1,'\\ ','bigxrob75\r盒装的'),(6097,802273766012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',3,'OTIN005',252,'eastar4','joyston2009','joyston07@gmail.com','Joyston Dsouza','Diyar United Company, 1st Floor, WAHA Mall<br>Block 1, Sector 49 Dhajeej, Farwaniya','Farwaniya','Kuwait','KUWAIT','44240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 15:51:57',0,NULL,3,1,3,1,'RA117776811CN\r ','joyston2009\rOTIN005'),(6098,806059722012,220799731617,'New AC3 DTS DD 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',68.5,'eastar4','pveltk','matadorr@gmail.com','Pavel Tkačenko','A. P. Kavoliuko 16-27','Vilnius','Vilnius','LITHUANIA','04326','+37068711179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 16:33:54',0,NULL,3,1,3,1,'RA117776887CN\r ','pveltk\rHDGE001'),(6099,725996764011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','doc78','leo.juzbasic@gmail.com','Leo Juzbasic','Deklici 2a<br>Kastelir','default','','CROATIA','52464','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 16:47:22',0,NULL,3,1,2,1,'\\ ','doc78'),(6100,725997136011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','benoitdd77','benoit.cathelineau@gmail.com','benoit cathelineau','1, rue du Parc','DONNEMARIE-DONTILLY','Île-de-France','FRANCE','77520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 16:48:26',0,NULL,3,1,2,1,'\\ ','benoitdd77\r欧标'),(6101,541326016003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.99,'cnfaner','angiospermophytina.cz','angiospermophytina@seznam.cz','Pavel Nesetril','Sadova<br>298','Jistebnice','','CZECH REPUBLIC','391 33','+420774041486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 17:03:26',0,NULL,3,1,3,1,'RA117776895CN\r ','angiospermophytina.cz\rMOOE002\r发OEM的'),(6102,726003265011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','ciffy1968','ciffy1@btinternet.com','christopher mitcheison','23 woodstock rise','sutton','Surrey','UNITED KINGDOM','sm39je ','02086410178','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-21 17:03:36',0,NULL,3,1,3,1,'RA117776737CN\r ','ciffy1968\rHSUE001'),(6103,806091407012,220786834052,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',35.99,'eastar4','kalash19','kalash_7@msn.com','igor zecevic','15 rue curial','paris','Île-de-France','FRANCE','75019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 17:40:27',0,NULL,3,1,3,1,'RA117776745CN','kalash19\rMOMI003\r新地址\rZecevic Igor \r15 rue curial  \rParis  75019 \rFRANCE\r\r\r'),(6104,726032167011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.49,'eastar4','999lex','lex-off@mail.ru','Aleksey Podshibyakin','140170, Rossiya, Moskovskaya oblast, gorod Bronnitsy, pos. Gorka, d. 7, kv. 36','Bronnitsy','Moskovskaya oblast','RUSSIAN FEDERATION','140170','8(926)3945625','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 18:12:20',0,NULL,3,1,2,1,'\\ ','999lex\r'),(6105,726055032011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','rschomb','rschomb@hotmail.com','Ralph Schomberg','23 Locust St<br>cross st Soundway DR','Rocky Point','NY','UNITED STATES','11778-9565','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 18:55:35',0,NULL,3,1,1,1,'\\ ','rschomb'),(6106,726057983011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','kegan','anthem85@gmail.com','Jeremy Jones','1301 Municipal Way<br>Ste 110','Grapevine','TX','UNITED STATES','76051-8521','(682) 233-3275','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 19:01:12',0,NULL,3,1,1,1,'\\ ','kegan'),(6107,726058836011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',3,'RELO002',38.94,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 19:03:12',0,NULL,3,1,3,1,'RA117776723CN\r ','masteroll2010\rRELO002'),(6108,594680819013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.99,'eastar4','marac55555','marko.koscevic@hotmail.com','marko koscevic','travanjska 5','zagreb','zagreb','CROATIA','10000','+385997449724','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 19:55:46',0,NULL,3,1,2,1,'\\ ','marac55555\r红边优联'),(6109,726111503011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','churchead','david.whitchurch@hotmail.com','David Whitchurch','5,chepstow road<br>clifton','nottingham','Nottinghamshire','UNITED KINGDOM','NG11 9GP','07779322198','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-21 20:51:07',0,NULL,3,1,3,1,'RA117776710CN\r ','churchead\rUDAP001'),(6110,805830293012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','nanonano30','lsanchez012@elp.rr.com','luis olea','447 S Schutz Dr<br>Apt 142','el paso','TX','UNITED STATES','79907-6408','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 21:15:11',0,NULL,3,1,6,1,'EE506555761CN ','nanonano30'),(6111,726122748011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',4.66,'eastar4','den_haag','goeran@gmx.de','Göran Müller','Wolfenbütteler Str. 28','Magdeburg','','GERMANY','39112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 21:17:23',0,NULL,3,1,2,1,'\\ ','den_haag'),(6112,726117554011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','jessiychester83','jessibcn69@hotmail.com','Jessica Lopez Aparicio','C/gran via de Lluis companys, 246<br>6º 3ª','Premia de Mar ( Barcelona)','Cataluña','SPAIN','08330','687407800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 21:23:53',0,NULL,3,1,3,1,'RA117776873CN\r ','jessiychester83\rGLSG001'),(6113,806224073012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','sheryla827','sherylarichter@gmail.com','Sheryl Auerbach','827 Oxford Crst','Villanova','PA','UNITED STATES','19085-2055','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 21:58:13',0,NULL,3,1,1,1,'\\ ','sheryla827\r新的\r'),(6114,594722947013,230490512845,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','gary_in_sac','garyferrell24@gmail.com','Gary or Susan Ferrell','2421 59th St','Sacramento','CA','UNITED STATES','95817-1700','(916) 613-8759','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 22:18:24',0,NULL,3,1,1,1,'\\ ','gary_in_sac'),(6115,594726950013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',70.95,'eastar4','shvoldum','shvoldum@hotmail.com','Sven H. Voldum','Sofienberggata 9','Oslo','','NORWAY','0551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 22:42:26',0,NULL,3,1,3,1,'RA117776842CN\r ','shvoldum\rMOSA001\r申报35美金'),(6116,806239798012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','irlelvin','elwinltc@yahoo.com','Tow Chuan Elvin Lim','5, Glenlara Park,<br>Carrowbeg','Westport','Mayo','IRELAND','default','3539856865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 22:45:20',0,NULL,3,1,2,1,'\\ ','irlelvin'),(6117,541439958003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','jcmatl01','ted.lindayen.38@gmail.com','Ted Lindayen','311 Benton Way','American Canyon','CA','UNITED STATES','94503-1146','(650) 296-5161','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-22 00:11:13',0,NULL,3,1,1,1,'\\ ','jcmatl01'),(6118,0,110703662223,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',54.99,'buysia','ironrodent','ironrodent@verizon.net','RYAN OLTMAN','3053 Brianna Ave','Lancaster','CA','UNITED STATES','93535-2997','(661) 946-8712','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 00:53:54',0,NULL,3,1,1,1,'\\ ','ironrodent'),(6119,726185787011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ziya06','ziya2@gmx.de','Hülya Degiz','Venloer Str. 350a','Köln','','GERMANY','50825','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-22 01:02:11',0,NULL,3,1,2,1,'\\ ','ziya06\r红边优联'),(6120,726193151011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','jefersonalberto','jeferson.alberto@gmail.com','Jeferson Alberto da Silva','Rua Mauá<br>266 - Apto 107B','Curitiba','Paraná','BRAZIL','80030200','4130148110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 01:34:47',0,NULL,3,1,3,1,'RA117776825CN\r ','jefersonalberto\rGLSG001*2'),(6121,547131295004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',2,'OTHP004',39.9,'cnfaner','oly*kurt','kmeeder@bigpond.com','kurt meeder','8 makaha dr.<br>birkdale','brisbane','Queensland','AUSTRALIA','4159','0738222252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 01:37:44',0,NULL,3,1,3,1,'RA117776860CN\r ','oly*kurt\rOTHP004'),(6122,806286930012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','andrea_borghi','andreab@compuserve.com','Andrea Borghi','720 Holly St','North Lauderdale','FL','UNITED STATES','33068-3938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 01:40:20',0,NULL,3,1,1,1,'\\ ','andrea_borghi\r盒装的'),(6124,726210114011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','jtorres_2001','jt2001.ebay@gmail.com','White Eagle Media','2918 SW 153rd Dr<br>Attn: M. Padonavi/J. Torres','Beaverton','OR','UNITED STATES','97006-5157','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 02:44:00',0,NULL,3,1,1,1,'\\ ','jtorres_2001'),(6125,806305451012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','winaramirez','win_aramirez@hotmail.com','Alvaro Andres Ramirez Mejias','Serrano 69b Melipilla<br>Melipilla','Melipilla','REGIÓN METROPOLITANA MELIPILLA','CHILE','9581099','068292517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 02:51:52',0,NULL,3,1,2,1,'\\ ','winaramirez'),(6127,726227180011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','tomk6','ebay@kadien.net','T. Kadien','341 Estrelita Dr','Vista','CA','UNITED STATES','92084','(760) 519-9400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 04:06:52',0,NULL,3,1,1,1,'、 ','tomk6'),(6128,688940538001,110699752183,'Clear Transparent Dome Birdcage Rain Umbrella with trim',1,'UMTR001',19.99,'buysia','nienor3','immortal-fear@hotmail.com','geraldine sandoval','av. acueducto #19<br>san lucas, xochimanca','Mexico','xochimilco, Mexico DF','MEXICO','16300','5521561048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 04:20:40',0,NULL,3,1,3,1,'RA117720083CN ','nienor3\rUMTR001   带黑边的透明伞'),(6129,725859957011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','kerustyone','selandy@internode.on.net','Neil Slurry','PO Box 256','Bridgewater','South Australia','AUSTRALIA','5155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 04:47:59',0,NULL,3,1,3,1,'RA117776989CN ','kerustyone\rWLAP009\r旧的'),(6130,594795122013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','worrawat','jillm5n@yahoo.com','WORRAWAT MOOLSIN','88/9 Kathathon Road<br>Tumbol Namueang','Amphoe Mueang Ratchaburi','Ratchaburi','THAILAND','70000','+66818679039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 05:05:49',0,NULL,3,1,3,1,'RA117720097CN\r ','worrawat\rBAZA001'),(6131,594795680013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','verbitskiy','verbickiy@mail.ru','Dmitriy Verbitskiy','Bratislavskaya 19-2-165','Moscow','Moscow','RUSSIAN FEDERATION','109451','9151871070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 05:09:25',0,NULL,3,1,2,1,'\\ ','verbitskiy'),(6141,547203194004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.99,'cnfaner','mipalo99','mipalo99@hotmail.com','Marcos Pastoriza López','Outeiro - Balea, 25','Cangas del Morrazo','Galicia','SPAIN','36940','986306640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 10:19:48',0,NULL,3,1,3,1,'RA117772094CN\r ','mipalo99\rWLAP008'),(6132,806336606012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','warezmatteo','mattscomputerproducts@gmail.com','Matthew Cash','16939 W 69th Ter<br>Apt 228','Shawnee','KS','UNITED STATES','66217-9678','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 05:32:06',0,NULL,3,1,1,1,'、 ','warezmatteo'),(6133,594800845013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','ellobo35','nyck28@yahoo.com','nicolae luchian','fundatura eroilor 1 nr.8','braila','braila','ROMANIA','810358','0034675010166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 05:52:48',0,NULL,3,1,2,1,'\\ ','ellobo35'),(6134,0,110703616528,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',66,'buysia','trzeb51','trzeb51@gmail.com','Lucas Trzebiatowski','2093 Dowell Rd<br>Bunkhouse','Grants Pass','OR','UNITED STATES','97527-9169','(541) 471-3386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 06:10:13',0,NULL,3,1,1,1,'、 ','trzeb51'),(6135,806352249012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','i-m-a-r','ramilup@gmail.com','Rami Lupovici','9 Migdal Ha Levanon St.','Modiin','ISRAEL','ISRAEL','71700','972-507325238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 06:54:37',0,NULL,3,1,11,1,NULL,'i-m-a-r\rANYA002'),(6136,594814243013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',32.99,'eastar4','abdfarae2009','abdfarae@hotmail.com','abdulla salih mohd','al-madra<br>gsm 92955775','Samail','oman','OMAN','219/620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:34:26',0,NULL,3,1,3,1,'RA117772032CN\r ','abdfarae2009\rWWSI005'),(6137,806362209012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',3,'HSNO019',77.97,'eastar4uk','brianstewart1234','bstewart_labac@hotmail.co.uk','b stewart','22-24 old liston road<br>newbridge','edinburgh','Midlothian','UNITED KINGDOM','eh28 8ss','7880658618','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 07:41:44',0,NULL,3,1,3,1,'RA117772029CN\r ','brianstewart1234\rHSNO019\r英标'),(6138,594821110013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','apeiries','angelo101_7@hotmail.com','Angelo Peries','5 Lawson Street','Nuwara Eliya','','SRI LANKA','22200','00940522222703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 08:23:04',0,NULL,3,1,3,1,'RA117772015CN\r ','apeiries\rMOSA005'),(6139,806370763012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',33.98,'eastar4','antoniomoises','antoniomoises0@gmail.com','Antonio Espinosa','C/ Lo Gaiter del Llobregat 103 bj 1ª','El Prat de Llobregat','Cataluña','SPAIN','08820','656316336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 08:34:31',0,NULL,3,0,3,1,'RA117772046CN\r ','antoniomoises\rWLDE002'),(6140,726283078011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','klavis1','pzyborg7167@yahoo.com','Dwayne Harris','709 Prospect St','Brackenridge','PA','UNITED STATES','15014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 09:01:54',0,NULL,3,1,1,1,'\\ ','klavis1'),(6142,806404137012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','algol_66','algol66@front.ru','Oleg Prokofiev','Primorsky pr. 145/2 74','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','197374','+7-911-914-07-84','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 10:42:10',0,NULL,3,1,2,1,'\\ ','algol_66'),(6143,806405858012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','howardhsu118','howardhsu118@hotmail.com','Howard Hsu','9 Hillside Road','Bulleen','Victoria','AUSTRALIA','3105','0431313000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 10:44:23',0,NULL,3,1,3,1,'RA117772125CN\r ','howardhsu118\rOTGR001+OTGR002'),(6144,726323820011,320700560826,'2 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',243.98,'eastar4','kezfog2469','fogden@optusnet.com.au','Sean and Kerrie Fogden','18A Bishopsgate Street','Lathlian','Western Australia','AUSTRALIA','6100','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTrackingAndSignature','2011-06-22 11:44:38',0,NULL,3,1,6,1,'EE506555735CN ','kezfog2469'),(6145,726335022011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','jazz0_4','cjarrett@manx.net','Charles Jarrett','9 Hillcrest Grove','Onchan','Isle of Man','UNITED KINGDOM','IM33HZ','01624625185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 12:23:57',0,NULL,3,1,2,1,'\\ ','jazz0_4'),(6146,723369715011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ddr141','davidhargrave@ddrail.com','Paul Mayhew DD Rail Ltd','Time House<br>Time Square','BASILDON','Essex','UNITED KINGDOM','SS14 1DJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 12:31:27',0,NULL,3,1,3,1,'RA117772196CN\r ','ddr141\rRELO003\r红边优联'),(6147,726339102011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','allwillbejazz','anbilous@gmail.com','Anton Bilous','Chaadaeva 2v<br>fl. 32','Kyiv','','UKRAINE','03146','+380503550493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 12:38:02',0,NULL,3,1,2,1,'\\ ','allwillbejazz'),(6148,726354809011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',83,'eastar4','revikom','revikom1@gmail.com','BayRu, Inc','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 13:31:48',0,NULL,3,1,1,1,'\\ ','revikom'),(6149,594891918013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','arkalis1968','arkalis.e@gmail.com','Evangelos Arkalis','89-91, Lefkon Oreon Str','Chalandri','Athens','GREECE','15234','6977837693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 14:31:16',0,NULL,3,1,3,1,'RA117772063CN\r ','arkalis1968\rWWOT001+ANCN001'),(6150,689075812001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','meytoo123','alacha1@msn.com','Alain Champagne','1340 Emond','Québec','QC','CANADA','G3K1R4','(418) 561-2728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 14:51:10',0,NULL,3,1,3,1,'RA117772151CN\r ','meytoo123\rBR3D005'),(6151,726392622011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','yexbox','tadbar1@gmail.com','Obaro Odoh-Tadafe','7 Bampton Street','Loughborough','Leicestershire','UNITED KINGDOM','LE11 2DR','07586757735','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 15:26:39',0,NULL,3,1,3,1,'RA117772134CN\r ','yexbox\r红边优联\rRELO003'),(6152,689102747001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','snamiotka83','snamiotka@me.com','Stephen Namiotka','60 Colony Sq<br>Apt A','Pittsburgh','PA','UNITED STATES','15239-2761','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 15:59:29',0,NULL,3,1,1,1,'\\ ','snamiotka83'),(6153,726418045011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','stanghp','david.z.rodriguez@gmail.com','David Rodriguez','15301 Hayter Ave','Paramount','CA','UNITED STATES','90723','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 16:33:11',0,NULL,3,1,1,1,'、 ','stanghp'),(6154,726421851011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','cdsl2000','slemm@lemm.org','Lemm Stefan','Forstamtstrasse 2 C','Staufenberg','','GERMANY','34355','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 16:41:48',0,NULL,3,1,2,1,'\\ ','cdsl2000'),(6155,806575830012,220799731617,'New AC3 DTS DD 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',68.5,'eastar4','cisjpdep63','cisjpdep@yahoo.com','CECILIA  PETERSEN','4256 S Germantown Rd','MEMPHIS','TN','UNITED STATES','38125-2906','(901) 730-4598','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 18:21:17',0,NULL,3,1,1,1,'\\ ','cisjpdep63'),(6156,594970254013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','pkrikard','paulrikard@comcast.net','Paul Rikard','125 N Patton St','Florence','AL','UNITED STATES','35630-3946','(256) 767-3150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 18:58:05',0,NULL,3,1,1,1,'\\ ','pkrikard'),(6157,806595118012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','mc0913','michel_cuesta@hotmail.com','Michel Cuesta','7105 Miami Lakes Dr<br>Apt N11','Hialeah','FL','UNITED STATES','33014-6927','(305) 318-4985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 19:00:12',0,NULL,3,1,1,1,'\\ ','mc0913'),(6158,806600983012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',22.59,'eastar4uk','milan_uk','milankikanovic@yahoo.co.uk','milan kikanovic','65 curlew crescent','bedford','Bedfordshire','UNITED KINGDOM','mk417hy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 19:04:22',0,NULL,3,1,3,1,'RA117772386CN\r ','milan_uk\rUDAP002'),(6159,726496902011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','evgeny280185','5171@gonen.org.il','Evgeny Chernous','default','kibuz Gonen','Galil Elion','ISRAEL','12130','972549793136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 19:24:07',0,NULL,3,1,2,1,'\\ ','evgeny280185\racer 4pin1.25 8cm'),(6160,540582342003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','burky83','burks06092006@yahoo.com','Jusitn Burk','PSC 41 Box 6033','APO','AE','AA','09464','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-22 19:30:44',0,NULL,3,1,1,1,'\\ ','burky83\r新的'),(6161,726513694011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','garyw2944','gary@vtiproductions.com','Gary Wright','3276 Old Chisholm Rd<br>Apt 1115I','Florence','AL','UNITED STATES','35630-1083','(256) 856-6042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 19:58:03',0,NULL,3,1,1,1,'\\ ','garyw2944'),(6162,806627398012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',22.59,'eastar4uk','shafiq786110','shafiq786110@gmail.com','Shafiq Pradhan','1 Wedgewood Close','Epping','Essex','UNITED KINGDOM','CM16 4QD','01992575064','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 20:05:21',0,NULL,3,1,3,1,'RA117772148CN\r ','shafiq786110\rUDAP002'),(6163,806639617012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','cdipch','cdi5@wanadoo.fr','Patrick Chauffaut','322 bd belles portes','herouville saint clair','Basse-Normandie','FRANCE','14200','02.31.43.63.32','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 20:16:12',0,NULL,3,1,2,1,'\\ ','cdipch'),(6164,805806386012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*4',471.98,'eastar4','buccip2','p_bucciol@yahoo.ca','Paul Bucciol','4 Vata Crt<br>Unit 14','Aurora','ON','CANADA','L4G4B6','(416) 838-1513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 20:37:34',0,NULL,3,1,12,1,' BJ8823402','buccip2'),(6165,806665434012,220459525292,'Acer Aspire 5550 5551 5552 Bluetooth Module 2.0 +cable',1,'BTAC2006',12.5,'eastar4','ronkrc','rkesslar@neo.rr.com','Ronald Kesslar','301 8th Ave','Greenville','PA','UNITED STATES','16125-1308','(724) 588-4173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 21:10:56',0,NULL,3,1,1,1,'\\ ','ronkrc\racer 4pin1.25 15cm '),(6166,806698378012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',17.65,'eastar4uk','7768_milne','markmilne99@yahoo.co.uk','mark milne','80 portal crescent<br>tillydrone','aberdeen','Aberdeen City','UNITED KINGDOM','ab24 2sp','07523507768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 22:40:36',0,NULL,3,1,3,1,'RA117772205CN\r ','7768_milne\rHSPL010\r英标'),(6167,806693175012,220681620511,'New SAMSUNG WMN1000B ULTRA SLIM WALLMOUNT LED TV 40-50\'',1,'MOSA002',43.98,'eastar4uk','sggothic','amy1962@live.co.uk','anthony joy','14 st peters way','bury st edmunds','Suffolk','UNITED KINGDOM','ip31 3rz','01359231436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 22:42:47',0,NULL,3,1,3,1,'RA117772117CN\r ','sggothic\rMOSA002'),(6168,541710814003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','justmaer2','justmaer@yahoo.com','MaryAlice Garcia','610 W Daggett Ave','Fort Worth','TX','UNITED STATES','76104-1103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-22 22:52:35',0,NULL,3,1,1,1,'\\ ','justmaer2'),(6169,726579318011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',239.98,'eastar4','bbcostarica','brent@trustservicesltd.com','Brent Beckley','2011 NW 79th Ave<br>Jbc Sjo 41602','Doral','FL','UNITED STATES','33122-1612','(416) 625-8171','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 23:24:04',0,NULL,3,1,6,1,'EE506555758CN ','bbcostarica'),(6170,806715311012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','lewiss32','oakland32@yahoo.com','steven lewis','2071 pawlet dr','crofton','md','UNITED STATES','21114-1679','(703) 623-6261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 23:45:32',0,NULL,3,1,1,1,'\\ ','lewiss32'),(6171,0,110703616516,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',59.52,'buysia','chill20022','chill2002@comcast.net','Michael R cox','5084new ext.','Hollywood','SC','UNITED STATES','29449','(843) 906-4677','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 00:04:36',0,NULL,3,1,1,1,'\\ ','chill20022'),(6172,726606067011,320438964226,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','la_damita','agonzalez_786@yahoo.com','Alexandra  Gonzalez','calle 23 AG 8<br>Urb Interamericana','trujillo alto','PR','UNITED STATES','00976','(787) 234-5066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 00:41:22',0,NULL,3,1,1,1,'\\ ','la_damita'),(6173,541730759003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA002',70.9,'cnfaner','mr-satchmo','jochen.kraus@t-online.de','J.Kraus-Wirtz ROYAL IMAGES','Via S. Stefano 2','Lucinasco','IM','ITALY','18020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 00:56:40',0,NULL,3,1,3,1,'RA117772103CN\r ','mr-satchmo\r1000C\r'),(6174,806739791012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','ofernander','oliverfernander@gmail.com','Oliver Fernander','907 E Spruce St','Sault Sainte Marie','MI','UNITED STATES','49783','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 01:19:42',0,NULL,3,0,1,1,'\\ ','ofernander'),(6175,541742969003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','eric7647','eric7647@msn.com','Eric Gagnon','296-A Notre-Dame Est','Victoriaville','QC','CANADA','g6p 4a3','(819) 352-0031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 02:07:22',0,NULL,3,1,3,1,'RA117772077CN\r ','eric7647\rHSMO011+CCMO001'),(6176,806757660012,220716842449,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','doug815','doug_field@comcast.net','Douglas Field','3824 Switchgrass Ct','Springfield','IL','UNITED STATES','62712-5869','(217) 529-2899','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 02:29:16',0,NULL,3,1,1,1,'\\ ','doug815\r新的'),(6177,726632085011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','khang22','t-khang@hotmail.com','Tou Khang','2210 N 6th St<br># 2','Minneapolis','MN','UNITED STATES','55411-2723','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 02:31:42',0,NULL,3,1,1,1,'\\ ','khang22'),(6178,726638457011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',83,'eastar4','hypernetwork','ciscocampus.com@gmail.com','Andrew','81 Division Ave','Garfield','NJ','UNITED STATES','07026-3621','(646) 270-9236','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 03:02:03',0,NULL,3,1,1,1,'\\ ','hypernetwork'),(6179,595087524013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',16.99,'eastar4','nhienhuong','quanghaihcm@gmail.com','Tran Quang Hai','201A No Trang Long. Phuong 12.  Quan Binh Thanh','Ho Chi Minh City','Viet Nam','VIET NAM','717066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 03:20:54',0,NULL,3,1,2,1,'\\ ','nhienhuong\r新的'),(6180,689324962001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','kamilo04','kam_7@autograf.pl','kamil dabrowski','6805 60th St<br>Apt 2R','ridgewood','NY','UNITED STATES','11385-5178','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 03:50:20',0,NULL,3,1,1,1,'\\ ','kamilo04'),(6181,726648831011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',2,'HSNO017',39.96,'eastar4','ngocnguyen123456','darkdjmaster@yahoo.com','ngoc nguyen','2270 E Fry Blvd<br>Ste E6','sierra vista','AZ','UNITED STATES','85635-2761','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-23 03:58:46',0,NULL,3,1,1,1,'\\ ','ngocnguyen123456'),(6182,547441853004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','christine_cross','cross.family@paradise.net.nz','Christine Cross','138 Seatoun Heights Road<br>Miramar','Wellington','','NEW ZEALAND','6022','6449735068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 04:33:33',0,NULL,3,1,3,1,'RA117772182CN ','christine_cross\rWLAP002\r旧的'),(6183,726663010011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','yap75','yap_fei@yahoo.com.sg','Roland Yap','Blk 682, Hougang Ave 4, #03-328','Singapore','Singapore','SINGAPORE','530682','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 05:27:39',0,NULL,3,1,11,1,NULL,'yap75\rHSJA006'),(6184,726686635011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','ingemar2010','alex_jmaster@hotmail.com','Ingemar Johansson','Lönnvägen. 3','Hässleholm','Skåne','SWEDEN','28149','0709586801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 07:38:25',0,NULL,3,1,2,1,'\\ ','ingemar2010\r'),(6185,547463053004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','grimace-mccheese','sesmith@post.harvard.edu','STEPHEN ELIOT SMITH','52 PERTH STREET','MOSGIEL','','NEW ZEALAND','9024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 07:40:06',0,NULL,3,1,3,1,'RA117720327CN\r ','grimace-mccheese\rWLAP002\r旧的'),(6186,541781681003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.95,'cnfaner','ghost-flame','info@andreas-hancock.de','Andreas Hancock','Kollostraße 32','Bielefeld','','GERMANY','33647','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 08:21:25',0,NULL,3,1,3,1,'RA117772275CN\r ','ghost-flame\rMOAP001'),(6187,806852235012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','gallaxya1','gallaxya@yahoo.com','Aurel Eugen Mucenicu','Strada Muntisor, nr. 1, Bl. 12<br>Sc. D, Ap. 8','Codlea','Brasov','ROMANIA','505100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 09:47:26',0,NULL,3,0,2,1,'\\ ','gallaxya1'),(6188,806850773012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','freestylermaxim','o997348162@gmail.com','Zhan Votus','ap 48 5A Patona str','Kherson','','UKRAINE','73021','+380997348162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 09:49:27',0,NULL,3,1,2,1,'\\ ','freestylermaxim'),(6189,806857590012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','acvilago15','acvilago@yahoo.com','mihaita gogoana','Str.Progresului , nr. 42 , Bl.D16 , Ap.6','Piatra-Neamt','','ROMANIA','610161','004.0723.585.579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 10:04:37',0,NULL,3,1,2,1,'\\ ','acvilago15'),(6190,726687404011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','timothy.ostle','timostle@gmail.com','Tim Ostle','L\'Oreal 4th Floor<br>255 Hammersmith Road','London','London','UNITED KINGDOM','w6 8az','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 10:06:22',0,NULL,3,1,3,1,'RA117772284CN\r ','timothy.ostle\r旧的\rWLAP002'),(6191,726403035011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',4,'OTSO004',303.96,'eastar4','jundaad','pmbkta@greennet.gl','Jonathan Ignatiussen','Naasuliartarpimmut B-961-A<br>Postboks 5','Tasiilaq','Greenland','GREENLAND','3913','(299)598677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 10:25:17',0,NULL,3,1,12,1,'BJ8823601\r\r2737935491 ','jundaad\r盒装的\r'),(6192,595151928013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','vortex_rus','v_soft@microfor.ru','Roman Scherbakov','Panfilovskiy prospect<br>korp. 160, kv. 192','Moscow','Zelenograd','RUSSIAN FEDERATION','124482','(916) 537-6263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 10:30:36',0,NULL,3,1,2,1,'\\ ','vortex_rus'),(6193,541814052003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',2,'WWOT003',99.98,'cnfaner','paul.van.hoof','paul.van.hoof@xs4all.nl','Paul van Hoof','Specht 25','Fijnaart','','NETHERLANDS','4793HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 10:46:34',0,NULL,3,1,3,1,'RA117772267CN\r ','paul.van.hoof\rWWOT003'),(6194,726739006011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','11sarge','sargetheguy@hotmail.co.uk','glenn lanphier','Beaulieu Convent School<br>Wellington road, st helier','jersey','Channel Islands','UNITED KINGDOM','JE2 4RJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 11:07:26',0,NULL,3,1,3,1,'RA117772298CN\r ','11sarge\rRELO003\r红边优联'),(6195,726745790011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','krillnecks09','krillnecks@hotmail.com','kristoffer nygren','bäckgatan 13C<br>93047','byske','SC','SWEDEN','93047','073-8161881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 11:31:37',0,NULL,3,1,3,1,'RA117772528CN\r ','krillnecks09\rGLSG001*2'),(6196,726707866011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',37.99,'eastar4','secretagent_69','mnyacct@gmail.com','Emmanuel Ferrante  (DOH 1159)','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413','718 553 8740','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-23 11:38:28',0,NULL,3,1,1,1,'\\ ','secretagent_69\r一共买了两个'),(6197,726749435011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',37.99,'eastar4','secretagent_69','mnyacct@gmail.com','Emmanuel Ferrante  (DOH 1159)','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413','718 553 8740','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-23 11:42:53',0,NULL,3,1,17,0,NULL,'secretagent_69'),(6198,726757656011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','kevinmm4','kevinmm4@hotmail.com','Kevin Meehan','29 Chowilla St','Eden Hills','South Australia','AUSTRALIA','5050','0872257822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 12:10:17',0,NULL,3,1,2,1,'\\ ','kevinmm4\r澳标'),(6199,806910865012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','waveydavey4','david.cavanagh@ed.ac.uk','David Cavanagh','Ashworth Laboratories<br>KIngs Buildings','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH16 6NT','01316507316','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 12:51:33',0,NULL,3,1,3,1,'RA117772355CN\r ','waveydavey4\rOTGR001'),(6200,806914283012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','rabbiscott','scott@bethadonai.com','Scott Sekulow','4115 Commanche Dr','Tucker','GA','UNITED STATES','30084-4425','(770) 403-4467','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 13:01:29',0,NULL,3,1,1,1,'\\ ','rabbiscott'),(6201,726775651011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',69.98,'eastar4','ani0505','anetaszer@o2.pl','Robert Mikulski','aleja sw.jakuba 25','Łeba','pomorskie','POLAND','84360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 13:08:35',0,NULL,3,1,3,1,'RA117772341CN\r ','ani0505\rUDAP001'),(6202,595113629013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','aedesanctis','tonydesanctis@gmail.com','Anthony E. DeSanctis','1 Dove Pl','Camden','DE','UNITED STATES','19934-9539','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'aedesanctis'),(6203,595216204013,230606464769,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',19.98,'eastar4','jmirandaherrera','jorge@creativecorner.cl','Jorge Miranda Herrera','Fernando Lazcano 1340 Departamento 203','Santiago','Metropolitana','CHILE','8900000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 15:12:41',0,NULL,3,1,2,1,'\\ ','jmirandaherrera'),(6204,547569322004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','bbpacer','bbpacer@optonline.net','Gary Guarino','125 Sequams Lane East','West Islip','NY','UNITED STATES','11795','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-23 16:22:32',0,NULL,3,1,1,1,'\\ ','bbpacer'),(6205,0,110703662219,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',55,'buysia','gizmosully','kschad13@verizon.net','karen schad','2204 Superior St','bethel park','PA','UNITED STATES','15102-2138','(412) 851-9711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 16:47:26',0,NULL,3,1,1,1,'\\ ','gizmosully'),(6206,726880627011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','sinne_00','sinne_2642@hotmail.com','Mohamed Sinah','4283 Express Ln<br>Ste K3183','Sarasota','FL','UNITED STATES','34238-2602','941 538 6941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 17:44:56',0,NULL,3,1,1,1,'\\ ','sinne_00'),(6207,726883075011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT011',33.8,'eastar4','technojack0303','karl.dums@t-online.de','Karl Dums','Lilienstr. 10','Renningen','','GERMANY','71272','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 17:49:22',0,NULL,3,1,3,1,'RA117772338CN\r ','technojack0303\rWLAT011\r盒装的'),(6208,726890261011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','burk828','wegaburk@yahoo.com','Hakki Burak çikirkan','Bahcelievler Basinsitesi elvan sok.<br>fatih apt. no=18/8','istanbul','bahcelievler','TURKEY','34590','02125540093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 18:04:03',0,NULL,3,1,2,1,'\\ ','burk828'),(6209,726911018011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','bgra5737','bebe@homeintsolutions.com','Beth Graham','49 Hull Streeet','Tallassee','AL','UNITED STATES','36078','(334) 283-2420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 18:42:48',0,NULL,3,1,1,1,'\\ ','bgra5737'),(6210,807100610012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','panauct','peternelson94025@yahoo.com','Peter Nelson','4 White Oak Ct','Menlo Park','CA','UNITED STATES','94025-6127','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 19:51:53',0,NULL,3,1,1,1,'\\ ','panauct'),(6211,807113715012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','race-s60r','tjsumme@aol.com','Todd Summerville','5258 Alexander Pl','Oak Lawn','IL','UNITED STATES','60453-1326','(773) 742-3367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 20:15:30',0,NULL,3,1,1,1,'\\ ','race-s60r'),(6212,807118458012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','ple5437','phuhungle@yahoo.com','phu le','639 Thornton Rd<br>Ste 105','lithia springs','GA','UNITED STATES','30122-4457','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 20:26:38',0,NULL,3,1,1,1,'\\ ','ple5437\r盒装的'),(6213,807136902012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','frenger8879','gigil125@yahoo.fr','frenger pascal','14, rue de neufchateau','pfaffenhoffen','Alsace','FRANCE','67350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 21:02:31',0,NULL,3,1,2,1,'\\ ','frenger8879\racer 8pin1.00 15cm '),(6214,726991137011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','kondrasov','hwegent@googlemail.com','Harry Wegent','Am Mauerfeld  15','Lahr  (Schwarzwald)','','GERMANY','77933','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 21:34:24',0,NULL,3,1,2,1,'\\ ','kondrasov\r红边优联'),(6215,689642823001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','jrussell0_2','gerald.russell@honeywell.com','Gerald Russell','784 E Joan D Arc Ave','Phoenix','AZ','UNITED STATES','85022-5323','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 21:40:14',0,NULL,3,1,1,1,'\\ ','jrussell0_2'),(6216,807156116012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','joyandpain0','sheafamily@suddenlink.net','joy shea','3414 Bain Pl','Tyler','TX','UNITED STATES','75701-8855','(903) 581-2024','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 21:50:02',0,NULL,3,1,1,1,'\\ ','joyandpain0'),(6217,807157316012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','waverjt','sleeplessinn@gmail.com','Ryan Retone','1058 Rimrock Rd','Greensburg','PA','UNITED STATES','15601-1161','(724) 858-5680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 21:53:00',0,NULL,3,1,1,1,'\\ ','waverjt'),(6218,727002481011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','discountguy101','wisecasemobile@yahoo.com','Nathan Huynh','592 N abel st','Milpitas','CA','UNITED STATES','95035-4208','(408) 942-7501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 22:04:11',0,NULL,3,1,1,1,'\\ ','discountguy101'),(6219,807170223012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','wllmsnt5','wllmsnt5@hotmail.com','Tommy  Williams','2226 Spring Crk','Spencer','WV','UNITED STATES','25276-8014','(304) 927-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 22:45:01',0,NULL,3,1,1,1,'\\ ','wllmsnt5'),(6220,0,110705132860,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',58.52,'buysia','keitht636','terschluseks@yahoo.com','Keith Terschluse','8048 Germantown Rd','Washington','MO','UNITED STATES','63090','(636) 239-5723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 00:14:55',0,NULL,3,1,1,1,'\\ ','keitht636'),(6221,807237502012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','colka-co','colka9497@yahoo.com','Julie Walsh','42454 county rd. 55','otis','CO','UNITED STATES','80743','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 02:59:46',0,NULL,3,1,1,1,'、 ','colka-co'),(6222,727076668011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','garth3901','gazman_4@yahoo.com.au','Garth May','23 hoyle rd','Medina','Western Australia','AUSTRALIA','6167','0894191131','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-24 03:08:22',0,NULL,3,1,3,1,'RA117772372CN ','garth3901\rOTSO004*2'),(6223,727088911011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','amar_hafeez','amar_hafeez@msn.com','Amar Hafeez','291 Wells Road<br>Upper Knowle','Bristol','Avon','UNITED KINGDOM','BS4 2PP','01179713607','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 04:13:59',0,NULL,3,1,3,1,'RA117772409CN\r ','amar_hafeez\rUDAP001'),(6224,689741782001,110699752183,'Clear Transparent Dome Birdcage Rain Umbrella with trim',2,'UMTR001',39.98,'buysia','19091958','uwaeser@telus.net','Uwe Waeser','909 Geikie App211      POBox 2458','Jasper','AB','CANADA','T0E1E0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 05:08:19',0,NULL,3,1,3,1,'RA117772545CN ','19091958\rUMTR001'),(6225,807266507012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','awagers31','floyd.wagers@earthlink.net','Floyd Wagers','4903 Rialto Ridge Dr','West Chester','OH','UNITED STATES','45069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 05:09:19',0,NULL,3,1,1,1,'、 ','awagers31'),(6226,688621138001,110699752183,'Clear Transparent Dome Birdcage Rain Umbrella with trim',1,'UMTR001',39.98,'buysia','ghanem_jad','dgr132@hotmail.com','Jad Ghanem','65 brittany (309)','Montreal','QC','CANADA','H3p1a4','(514) 961-3033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 05:15:09',0,NULL,3,1,3,1,'RA117772559CN ','ghanem_jad\rUMTR001\r一共买了两个'),(6227,727101246011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',59,'eastar4','willb8705','willb.hawaii@gmail.com','William Burkett','23048 Holgar Ct NE','Poulsbo','WA','UNITED STATES','98370-9108','(714) 475-4173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 05:30:00',0,NULL,3,1,1,1,'、 ','willb8705'),(6228,0,110703616537,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',71,'buysia','elyria59','luwyn.tan@gmail.com','Luwyn Tan','214 Loyang Ave<br>#03-05 Loyang Valley','default','','SINGAPORE','509065','(659) 424-4429','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 06:59:59',0,NULL,3,1,3,1,'RA117772315CN ','elyria59\rBR3D003'),(6229,807308358012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','albet04','eko-audioline@hotmail.com','eko adi purnomo','UD. ABC<br>jenderal sudirman 344','salatiga','central java','INDONESIA','50732','628164247919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 08:30:14',0,NULL,3,1,3,1,'RA117772474CN ','albet04\r盒装的\rOTSO004*2'),(6232,727176726011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',194.97,'eastar4','luismax27','luisma_ss@hotmail.com','luis manuel sosa suarez','juan de palma nº6','moron de la frontera','Andalucía Ceuta y Melilla','SPAIN','41530','669436073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 11:16:55',0,NULL,3,1,3,1,'RA117771156CN\r ','luismax27\rGLSG001'),(6230,807339312012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','bobhillx','bobhilla@aol.com','Robert Hill','210 West 150th Street<br>Apt 2A','New York','NY','UNITED STATES','10039-2511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 10:32:39',0,NULL,3,1,1,1,'、 ','bobhillx'),(6231,807340149012,220704730766,'New Plantronics Voyager 855 Bluetooth Headset+carcharge',1,'HSPL009+CCPL001',25,'eastar4uk','paperdragon1964df','butmonkey64@googlemail.com','david fishwick','flat 14,hardy court<br>weyhill road','andover','Hampshire','UNITED KINGDOM','sp10 3nn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 10:35:13',0,NULL,3,1,3,1,' RA117771108CN\r','paperdragon1964df\rHSPL009+CCPL001 从旧的里面挑一个成色好的 不给配件'),(6233,727177623011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','wikne89','andreaswikne@hotmail.com','Andreas Wikne Ulvenes','Storskarhaugen 3','Florvåg','Hordaland','NORWAY','5305','47263341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 11:22:29',0,NULL,3,1,3,1,' RA117772885CN\r','wikne89\rBR3D001'),(6234,807357782012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','dardanielec','dddamptour@wp.pl','Dariusz Danielec','Bobrecka 10','Cieszyn','śląskie','POLAND','43-400','33 8524556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 11:53:06',0,NULL,3,1,3,1,'RA117772580CN\r ','dardanielec\rOTSO004*2'),(6235,542127127003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','dthibault89','davidthibault89@yahoo.fr','David  Thibault','7 rue du jardin','Ste-Catherine de la Jacques-Cartier','QC','CANADA','g3n 2j3','(418) 802-7173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 12:47:25',0,NULL,3,1,3,1,'RA117772942CN\r ','dthibault89\rHSMO011+CCMO001'),(6236,595505457013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','betty92954','bmeyer@tecstra.com','Betty Meyer, Tecstra Systems','21966 State Highway 56','Austin','MN','UNITED STATES','55912-6457','(507) 437-1042','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 13:57:14',0,NULL,3,1,1,1,'、 ','betty92954'),(6237,547821828004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',104.99,'cnfaner','mapp_1','ebay@midampp.com','Mid-America Precision Products, LLC','1927 W 4th St','Joplin','MO','UNITED STATES','64801-3202','(417) 623-2285 ext.: 349','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-24 14:11:10',0,NULL,3,1,4,1,'YW865908320CN ','mapp_1'),(6238,727236060011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','clabbyd','darren_clabby@hotmail.com','Darren Clabby','21 Woodlawn View<br>Santry','Dublin','Dublin','IRELAND','9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 14:35:19',0,NULL,3,1,3,1,' RA117772925CN\r','clabbyd\rGLSG001*2'),(6239,807440419012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','vaflan','vaflancher@gmail.com','Ruslan Jermakovics','Skolas 34-166','Jurmala','','LATVIA','LV2016','+37129952466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 15:40:24',0,NULL,3,1,2,1,' \\','vaflan'),(6240,727266365011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','cacotte57','laurent.launer@laposte.net','Laurent Launer','3, rue de Queuleu','Metz','Lorraine','FRANCE','57070','0631291353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 15:58:18',0,NULL,3,1,2,1,'\\  ','cacotte57'),(6241,595546773013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',12.5,'eastar4','raketa001','eduard_tuman@hotmail.com','Eduard Tuman','Marshal Gukov 22 Str. Apt.62','Odessa','Odessa Region','UKRAINE','65121','+380973598345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 16:08:28',0,NULL,3,1,2,1,' \\','raketa001\r华硕 8pin 1.0 6cm '),(6242,807457530012,220747230811,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',12.2,'eastar4uk','tomboy5186','susaneverard@hotmail.com','Susan Everard','6 Green Way','Bromley','Kent','UNITED KINGDOM','BR2 8EY','02082892969','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 16:27:30',0,NULL,3,1,3,1,'RA117772620CN\r ','tomboy5186\r英标\rHSSA001'),(6243,727278565011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','rtmurphy2779','rtmurphy27@comcast.net','Ryan Murphy','97 Grant Ave','Medford','MA','UNITED STATES','02155-4040','(781) 874-9779','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 16:57:28',0,NULL,3,1,1,1,'、 ','rtmurphy2779'),(6244,727289943011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.49,'eastar4','vangelm1','vangelm@gmail.com','Michal Vangel','Zahumenice 169/48','Jarok','CT','SLOVAK REPUBLIC','95148','00421904598715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 17:00:41',0,NULL,3,1,2,1,'\\  ','vangelm1'),(6245,807508285012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','amahgoub','a.mahgoub@hotmail.com','Ahmed Mahgoub','29 SchlotWeg<br>Asseln-Mitte','Dortmund','','GERMANY','44319','015778488464','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'amahgoub  paypal撤款'),(6246,727360780011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','genuinecfa','dsalwathura123@gmail.com','Darshan Nakandala','No 17, Somaananda Mawatha','Panadura','','SRI LANKA','12500','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-24 19:41:08',0,NULL,3,1,3,1,'RA117772783CN\r ','genuinecfa\rHSNO019+CCNO001\r'),(6247,542083094003,130466041446,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',34.9,'cnfaner','cujo_2008','d-mail@mail.ru','Denis Kondratiev','Marshal Zakharov Str., 12-1-395','St-Petersburg','','RUSSIAN FEDERATION','198328','007(911)279-5105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 19:43:12',0,NULL,3,1,3,1,'RA117772514CN\r ','cujo_2008\rWWSI004'),(6248,727374361011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.98,'eastar4','boogiedahmer','bangboogiepayup@gmail.com','Patrice Swygert','2325 Prince St','Fort Myers','FL','UNITED STATES','33916-4355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 20:07:25',0,NULL,3,1,1,1,'、 ','boogiedahmer'),(6249,807561920012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','skmoon1','skmoon11@gmail.com','Aekyung Lee','941 Muirfield Dr','Marietta','GA','UNITED STATES','30068-2643','(770) 973-0069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 20:09:46',0,NULL,3,1,1,1,'、 ','skmoon1'),(6250,0,110706777444,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',60.06,'buysia','xn2ishnx','cata2d@gci.net','Michelle Ruthe','8238 Peck Ave<br># A','Anchorage','AK','UNITED STATES','99504-1424','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 20:10:48',0,NULL,3,1,1,1,'、 ','xn2ishnx'),(6251,727390291011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',2,'WWSI006+ANCN001',126,'eastar4','pljubas1806','pljubas@vip.hr','Petar Ljubas','Dankovecka 3','Zagreb','Zagreb','CROATIA','10040','+385 91 2293388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 20:44:59',0,NULL,3,1,3,1,'RA117772845CN\r ','pljubas1806\rWWSI006+ANCN001'),(6252,807139426012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',7,'TRMX003',59.85,'eastar4','dreamw41','dreamw88@hotmail.com','Lee Weaver','5420 Eagle Cloud Trl<br>Apt 302','Raleigh','NC','UNITED STATES','27606-3789','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 21:11:01',0,NULL,3,1,1,1,'\\ ','dreamw41\r发210TS'),(6253,807590933012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',17.65,'eastar4uk','lukaspp','winco2@zmail.sk','Lukas Winnicki','Bide A while<br>Ballycurren Road,Frankfield','Cork','Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-24 21:12:29',0,NULL,3,1,3,1,'RA117771244CN ','lukaspp\rHSPL010\r英标'),(6254,807597631012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',17.4,'eastar4','rajithamd','rajithamd@gmail.com','RAJITH M DISSANAYAKA','208,<br>STAINES ROAD','HOUNSLOW','Middlesex','UNITED KINGDOM','TW3 3LR','07515808829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 21:28:28',0,NULL,3,1,2,1,' \\','rajithamd\rCASS002\rCAB-SS-2660'),(6255,727406934011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','raymond.1223','lisachawkins@yahoo.co.uk','lisa hawkins','6 whitehouse court','barkway, cambridge','Herefordshire','UNITED KINGDOM','sg8 8ea','01763849358','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 21:28:44',0,NULL,3,1,3,1,' RA117772797CN\r','raymond.1223\rRELO003\r红边优联'),(6256,727408362011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',239.98,'eastar4','mag-dad','john.thielens@post.harvard.edu','John Thielens','2775 Manor Bridge Dr','Alpharetta','GA','UNITED STATES','30004','(678) 551-2226','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 21:31:38',0,NULL,3,1,6,1,'EE506555700CN ','mag-dad'),(6257,726100198011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','ueree','adriano_shinoda@hotmail.com','Adriano Shinoda','rua fernando de araujo goes, 123<br>pernambués','salvador','Bahia','BRAZIL','41100-200','71-88796177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 21:42:23',0,NULL,3,1,2,1,'\\  ','ueree\racer 4pin1.25 6cm'),(6258,807616485012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','snu9','jshellard@optusnet.com.au','Jonathan shellard','3 Burdon Street<br>Keperra','Brisbane','Queensland','AUSTRALIA','4054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 22:21:38',0,NULL,3,1,2,1,'\\  ','snu9'),(6259,595502313013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',17.98,'eastar4','super-heavyweight','torpedospurs@gmail.com','Chan Kok Hoe','690D Woodlands Drive 75<br>#10-196','Singapore','','SINGAPORE','734690','(65)67631262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 23:52:26',0,NULL,3,1,11,1,' RA117772752CN\r','super-heavyweight\rWLIN009'),(6260,690069207001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',32.99,'buysia','bjorn5509','bjorkris@bbnett.no','Bjorn Kristiansen','Torgerstuvegen 436','Elverum','','NORWAY','2411','+47 91542763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 00:05:53',0,NULL,3,1,3,1,'RA117772823CN\r ','bjorn5509\rBR3D006'),(6261,595676752013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','hsol8105','sochina87@aol.com','Cristanty Solian','1829 Battle Born Dr','Las Vegas','NV','UNITED STATES','89128-3002','(702) 416-2030','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 00:08:44',0,NULL,3,1,1,1,'、 ','hsol8105'),(6262,547979174004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','vicka94','gitelmanalexandr@comcast.net','lana gitelman','118 Brookmoor Rd','west hartford','CT','UNITED STATES','06107','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-25 01:15:15',0,NULL,3,1,1,1,'、 ','vicka94'),(6263,727479264011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.1,'eastar4','kurtis4575','kurtis4575@yahoo.com','William Cleverly','37 3rd St','Fremont','IN','UNITED STATES','46737-8011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 02:29:52',0,NULL,3,1,1,1,'\\ ','kurtis4575'),(6264,727481601011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',26.8,'eastar4','louiejnub','lgiffels@gbcdesign.com','Louis Giffels','3378 W Market St','Fairlawn','OH','UNITED STATES','44333-3306','(330) 603-0019','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 02:41:24',0,NULL,3,1,1,1,'、 ','louiejnub'),(6265,547992086004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.95,'cnfaner','nimsiri_1978','nimsiri@gmail.com','Mr. Nimsiri Abhayasinghe','Dept. of Electronic and Computer Eng.<br>Sri Lanka Institute of Information Technology','New Kandy Road','Malabe','SRI LANKA','10115','+94-71-4401309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 02:52:00',0,NULL,3,1,3,1,'RA117772766CN\r ','nimsiri_1978\rHSNO006\r'),(6266,727484198011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','alafontaine87','alafontaine2@gmail.com','Andrew LaFontaine','14 Highpoint Dr','North Smithfield','RI','UNITED STATES','02896-8017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 02:58:21',0,NULL,3,1,1,1,'\\ ','alafontaine87'),(6267,547994263004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','ab52866','ab7698@aol.com','Aaron Barson','1580 W Antelope Dr<br>Ste 250','Layton','UT','UNITED STATES','84041','(801) 776-2002','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-25 03:10:27',0,NULL,3,1,1,1,'\\ ','ab52866'),(6268,727498034011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','lacombehome','greg794855@live.com','Greg Arabie, Jr.','27337 Jackson St','Lacombe','LA','UNITED STATES','70445-4661','(985) 290-4917','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 04:15:11',0,NULL,3,1,1,1,'、 ','lacombehome\r新地址\rPO Box 1015\rLacombe, LA 70445\r\r'),(6269,690115011001,110699752183,'Clear Transparent Dome Birdcage Rain Umbrella with trim',2,'UMTR001',39.98,'buysia','emo1983','lifecandle_164@hotmail.com','Eman Ismail','33 chareles st. E','Toronto','ON','CANADA','M4Y 0A2','(647) 860-0019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 04:35:11',0,NULL,3,1,3,1,'RA117771142CN\r ','emo1983\rUMTR001\r黑色的'),(6270,0,110705971232,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',67,'buysia','nunzflip','nunzio88@live.com','patricia filippino','103 Camp Ave','Braddock','PA','UNITED STATES','15104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 06:41:21',0,NULL,3,1,1,1,'、 ','nunzflip'),(6271,727522515011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','armedpaintballcom','ebay@armedpaintball.com','John Pham','190 S Capitol Ave','San Jose','CA','UNITED STATES','95127-2843','(408) 834-5138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 06:48:10',0,NULL,3,1,1,1,'、 ','armedpaintballcom'),(6272,726426391011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','conecty71','danielxhorvath@gmail.com','Daniel Horvath','91 Louisa Park<br>Station Road','Leixlip','Kildare','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 07:31:51',0,NULL,3,1,3,1,'RA117772576CN\r ','conecty71\rGLSG001'),(6273,807734031012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','bugroza','diman_hacker@yahoo.com','Dmitry Petrov','107-6 Kalinin str.','Taganrog','Rostov Region','RUSSIAN FEDERATION','347913','+7108634648607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 07:39:53',0,NULL,3,1,3,1,'RA117772633CN\r ','bugroza\rRCLO002\r旧的'),(6274,0,110706777447,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',51.36,'buysia','malemanct','ideliver4you@hotmail.com','Donald Siering Jr','119 Seymour St<br>Back Breezeway','waterbury','CT','UNITED STATES','06708-3707','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 07:59:39',0,NULL,3,1,1,1,'、 ','malemanct'),(6275,727540649011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','akash_78692','akash_7869@hotmail.com','Abdul Hafiz','Saiba Medical Centre (P) Ltd. Yapa complex<br>damkal mode ,pulchowk','lalitpur','bagmati','NEPAL','00977','009779813520947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 08:18:03',0,NULL,3,1,2,1,'\\  ','akash_78692\racer 4pin1.25 6cm'),(6276,807746428012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','mkuhn211','mkuhn211@web.de','Michael Kuhn','Hohe Str. 50','Düsseldorf','','GERMANY','40213','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 08:30:41',0,NULL,3,1,3,1,'RA117772655CN\r ','mkuhn211\r盒装的\rOTSO004*2'),(6277,595771971013,230495606381,'New in box NOKIA HS-11W BLUETOOTH HEADSET HS 11W',1,'HSNO024',17.7,'eastar4','zanzarkanico','eudociot@hotmail.com','Eudócio R. Silva','Av. Joana Angelica, 135 - Centro','Eunápolis','Bahia','BRAZIL','45820-330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 10:38:01',0,NULL,3,1,2,1,'\\  ','zanzarkanico\r盒装的'),(6278,595740477013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.4,'eastar4','bobarn','bob_arn@mail.ru','Vladimir Arnautov','Akademika Koroleva 26 13','Chelyabinsk','Chelyabinskay oblast\'','RUSSIAN FEDERATION','454004','+79058303633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 11:41:34',0,NULL,3,1,2,1,'\\  ','bobarn\racer 4pin1.25 15cm '),(6279,807815646012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','123geller','geller.emanuel@gmx.de','Geller Emanuel','Untere Muhlbachstr 5','Friedrichshafen','','GERMANY','88045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 12:06:05',0,NULL,3,1,2,1,' \\','123geller'),(6280,727643215011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',5,'TRMX001',42.75,'eastar4','networkindia','networkstore2011@gmail.com','vinit jain','DVS LTD ,44 anup nagar<br>OPP CHIL HOSPITAL','INDORE','Madhya Pradesh','INDIA','452008','9926634639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 13:49:16',0,NULL,3,0,3,1,'RA117772718CN\r ','networkindia\rTRMX001'),(6281,727651142011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','y.vishniavetski','y.vishniavetsk@gmail.com','Yauheni Vishniavetski','30/57 st. Skripnikova','Minsk','Minsk','BELARUS','220000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 14:10:14',0,NULL,3,1,2,1,'\\ ','y.vishniavetski'),(6282,595822546013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',101.8,'eastar4','studio193fr','studio193@free.fr','Lemonnier Antoine','193, rue St Denis Boite 52','Paris','Île-de-France','FRANCE','75002','06.50.00.90.67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 14:11:40',0,NULL,3,1,3,1,' RA117771099CN\r','studio193fr\rMOSA004'),(6283,727660956011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','marcelobyms','byms@hotmail.com','Marcelo Siqueira','Rua Aiuba, 89<br>Anchieta','Rio de Janeiro','RJ','BRAZIL','21630-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 14:37:22',0,NULL,3,1,2,1,'\\ ','marcelobyms'),(6284,546980761004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','bv_vic','vic.bog@gmail.com','Viktor Bogatyryov','Pr. M. Zhukova 24 - 83<br>Pr. M. Zhukova 24 - 83','Odessa','UA','UKRAINE','65121','380503167133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 15:42:40',0,NULL,3,1,3,1,'RA117772721CN\r ','bv_vic\rBALO007'),(6285,807914402012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','torrentmt','minhtam.luong@gmail.com','Minh-Tam Luong','epancheurs 11','Neuchatel','','SWITZERLAND','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 16:17:16',0,NULL,3,1,2,1,'\\ ','torrentmt'),(6286,807916050012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','indianspirit4sioux','simonin.c@neuf.fr','cynthia simonin','149C rue des vallées','Ladon','Centre','FRANCE','45270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 16:20:07',0,NULL,3,1,6,1,'EE506555695CN ','indianspirit4sioux'),(6287,548141415004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','dimitris3615','mitritsakisd@gmail.com','Dimitris Mitritsakis','Sof. Venizelou 4','Hania-Souda','Crete','GREECE','73200','00302821076278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 16:31:34',0,NULL,3,1,3,1,'RA117772806CN\r ','dimitris3615\rHSPL001\r\r'),(6288,807940366012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','dawn_mel','dawn_mel@hotmail.com','Tommy Huff','700 N Newby Ln','Bloomfield','NM','UNITED STATES','87413-6753','(505) 632-9219','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 17:09:18',0,NULL,3,1,6,1,'EE506555713CN ','dawn_mel'),(6289,727744000011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',10,'OTCN002',39.9,'eastar4','danmeijer','dan_meijer@hotmail.com','Dan Meijer','goedewerf<br>111','almere haven','','NETHERLANDS','1357as','0639040303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 17:49:59',0,NULL,3,1,3,1,'RA117772704CN\r ','danmeijer\rOTCN002'),(6290,727765394011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',59,'eastar4','lgaak','gus@gaak.org','Gustavo Portales','Av. Antenor Orrego J 6<br>Urb. Trupal','Trujillo','La Libertad','PERU','13011','948531712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 18:35:55',0,NULL,3,1,3,1,'RA117772770CN\r ','lgaak\rWWSI006'),(6291,727793662011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','protedu','protedu@yahoo.ca','José Muñoz Santiago','Arcos de Jalón, 90, 1º A','Madrid','Madrid','SPAIN','28037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 19:34:13',0,NULL,3,1,3,1,'RA117772908CN\r ','protedu\rGLSG001*2'),(6292,590849834013,230566335290,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA003',33.95,'eastar4','barriquero2010','barriquero@hotmail.com','daniel di iorio','av. independencia 2612','mar del plata','buenos aires','ARGENTINA','7600','542236091452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 20:02:19',0,NULL,5,1,18,1,' ','barriquero2010\rOTRA003  已经退款'),(6293,595939691013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','schrotti1980','schrotti3000@hotmail.com','Florian   Huber','Kurpfalzstr.1','Pirmasens','','GERMANY','66954','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 20:16:36',0,NULL,3,1,2,1,'\\  ','schrotti1980'),(6294,727807953011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','srmarchetti','arqsrm@uol.com.br','SERGIO RICARDO MARCHETTI','AV. ARMANDO SALLES DE OLIVEIRA, 1000<br>APTO 13 BL SF','SUZANO','SÃO APULO','BRAZIL','08673000','0551174610685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 20:17:30',0,NULL,3,1,2,1,'\\  ','srmarchetti'),(6295,808063526012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','01edrock','rocket.eddie127@gmail.com','Eugene Kennedy','120 Dara Court','Celbridge','Kildare','IRELAND','default','0852884002','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-25 21:14:10',0,NULL,3,1,3,1,'RA117772899CN\r ','01edrock\rHSPL011\r英标'),(6296,727844578011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','kilvington26','kilvington26@hotmail.com','William Kilvington','338 NE 36th Avenue Rd','Homestead','FL','UNITED STATES','33033-7102','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 21:37:47',0,NULL,3,1,1,1,'、 ','kilvington26'),(6297,808102212012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',3,'REPL001',32.97,'eastar4','sdarrylsmith1111','sdarrylsmith501@aol.com','Darryl Smith','1218 N Marquette St','Davenport','IA','UNITED STATES','52804-3765','(563) 517-8187','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 23:11:16',0,NULL,3,1,1,1,'、 ','sdarrylsmith1111'),(6298,542584832003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','cinder713','kim.smith@cs.oag.state.tx.us','Kim Smith','17319 Canton Frst','Richmond','TX','UNITED STATES','77407-8574','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-25 23:54:39',0,NULL,3,1,1,1,'\\ ','cinder713'),(6299,595996998013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','twistedmind1974','mr.twist@gmx.de','Klaus Stürzenbecher','Nappenhorn 19','Barmstedt','','GERMANY','25355','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 00:20:05',0,NULL,3,1,2,1,' \\','twistedmind1974'),(6300,808120985012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','jamjam','johnmesner3000@yahoo.com','john mesner','3501 Brynhurst ct','clovis','NM','UNITED STATES','88101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 00:25:02',0,NULL,3,1,1,1,'、 ','jamjam'),(6301,542589937003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','r_thiele','r_thiele@yahoo.com','Ricardo Thiele','Ampl. P. Hurtado Pje. 11 #2056','Puerto Montt','','CHILE','5502277','56-9-98871638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 00:47:23',0,NULL,3,1,3,1,'RA117772871CN\r ','r_thiele\rWWOT003'),(6302,727897341011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','wmkates','w.mark.kates@gmail.com','Mark Kates','10 Ocean Breeze Dr','Jensen Beach','FL','UNITED STATES','34957-7216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 01:03:15',0,NULL,3,1,1,1,'、 ','wmkates'),(6303,808136812012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','tutfellyla','andyfell.fell@googlemail.com','C Thornton','5 Coed-Y-Glyn<br>Glyn Ceiriog','Nr Llangollen','Wrexham','UNITED KINGDOM','LL20 7NR','0169171848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 01:27:52',0,NULL,3,1,2,1,'\\  ','tutfellyla\racer 8pin1.00 8cm'),(6304,727931123011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','dr4ter','schanbackii@yahoo.com','James Schanback II','13048 Brule Pl','Poway','CA','UNITED STATES','92064-3808','(858) 243-3153','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 03:52:18',0,NULL,3,1,1,1,'\\ ','dr4ter'),(6305,596035826013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','lui_0209','lui_0209@yahoo.com.sg','Lui Kwok Heng','Blk 239 Compassvale Walk #10-562','Singapore','Singapore','SINGAPORE','540239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 04:36:56',0,NULL,3,1,11,1,NULL,'lui_0209\rANCN001'),(6306,727944262011,320665699105,'Logitech Harmony Rechargeable battery 890 880 930mAh',1,'BALO002',10.5,'eastar4','leonm2312','leon.mathews@atlasgeo.com.au','Leon Mathews','4281 Express Ln<br>Ste L8652','Sarasota','FL','UNITED STATES','34238-2602','9415386941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 05:14:46',0,NULL,3,1,1,1,'、 ','leonm2312'),(6307,727946431011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'eastar4','sergewash','sergestg@gmail.com','SERGE BAUER','4615 N Park Ave<br>Apt 1113','CHEVY CHASE','MD','UNITED STATES','20815','(301) 312-8077','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 05:25:54',0,NULL,3,1,1,1,'、 ','sergewash'),(6308,727966915011,320693967541,'New Motorola HS850 Bluetooth Wireless Headset HS 850',1,'HSMO019',26.8,'eastar4','kramiset','kishore_ramisetty@yahoo.com','Kishore Ramisetty','A-303, Shradda Gardenia, 16/2 Rahat Bagh<br>Off Old Madras Road, C.V. Raman Nagar','Bangalore','KA','INDIA','560093','919845118951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 07:21:02',0,NULL,3,1,2,1,' \\','kramiset'),(6309,727975268011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','avitrondean','avitrondr@yahoo.com','Dean Rossi','3750 Lyell rd','Rochester','NY','UNITED STATES','14606-4408','(585) 426-2542','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 07:48:44',0,NULL,3,1,1,1,'、 ','avitrondean'),(6310,808229232012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','andrei.yazik','aayazik84@yahoo.com','Andriy Yazik','59 23-GO SERPNYA STR. APT.75','Kharkiv','Kharkiv','UKRAINE','61103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 08:26:28',0,NULL,3,1,3,1,'RA117772647CN\r ','andrei.yazik\r盒装的\rOTSO004*2'),(6311,728016305011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','akybuer','nigel.buer@british-energy.com','Nigel Buer','25 Topiary Gardens','Preston','Lancashire','UNITED KINGDOM','PR31YF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 09:46:39',0,NULL,3,1,3,1,' RA117772749CN\r','akybuer\rWLAP002\r旧的'),(6312,728025091011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',22.49,'eastar4','cragatar','cragatar@hotmail.com','Craig Shelley','178 Mackenzie Drive','TWIZEL','South Canterbury','NEW ZEALAND','7901','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 10:09:14',0,NULL,3,1,2,1,' \\','cragatar'),(6313,808283435012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','acimates','acimate@gmail.com','Mr. CHIN (ACE Peripherals Pte Ltd)','33, Ubi Ave 3, #07-11,<br>Vertex (Tower B),','default','','SINGAPORE','408868','+65 6100 2232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 10:39:09',0,NULL,3,1,11,1,'\r ','acimates\rMOSA001'),(6314,808291744012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','markkoerts','mkoerts@hotmail.com','Mark Koerts','Ringweg Randenbroek 56a','Amersfoort','','NETHERLANDS','3816 CK','06-51708313','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 10:58:04',0,NULL,3,1,2,1,'\\  ','markkoerts\r欧标'),(6315,548378698004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',2,'HSPL001',23.6,'cnfaner','gadgestopia','mr.computerman86@yahoo.com','larry  williams','2-419 Lamoine Vlg','Macomb','IL','UNITED STATES','61455-4119','(847) 293-4399','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-26 11:38:00',0,NULL,3,1,1,1,'、 ','gadgestopia'),(6316,807696068012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','hphablo','phablohenrique@hotmail.com','PHABLO HENRIQUE CASTANHO','RUA PINHAL, 115<br>SANTO ANTONIO','CATANDUVA','SAO PAULO','BRAZIL','15801220','+551735214375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 11:42:54',0,NULL,3,1,3,1,'RA117772562CN\r ','hphablo\rOTSO004*2\r盒装的'),(6317,728092942011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','522lambourne','sheesh1@aol.com','stacie  presser','522 Lambourne Ave','worthington','OH','UNITED STATES','43085-2417','(614) 563-8320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 12:51:29',0,NULL,3,1,1,1,'、 ','522lambourne'),(6318,542209247003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','holy-soul','wyndorf@gmail.com','Antoni Baeza Ruiz','C/ Sardenya 499 6-2','Barcelona','Cataluña','SPAIN','08024','609584530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 12:56:27',0,NULL,3,1,3,1,' RA117772837CN\r','holy-soul\rWLAT007'),(6319,808348586012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','runebarstad','runebyre@hotmail.com','Rune Byre Bårstad','Nordahl Griegs Veg 33','Gjøvik','Gjøvik','NORWAY','2819','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 13:00:40',0,NULL,3,1,2,1,'\\  ','runebarstad'),(6320,808347628012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',17.65,'eastar4uk','922jay','jprice33@supanet.com','Jason Price','5, Wentworth Road,<br>Bloxwich,','Walsall,','West Midlands','UNITED KINGDOM','WS3 3UN','01922111024','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 13:01:33',0,NULL,3,1,3,1,'RA117771292CN ','922jay\r英标\rHSPL010'),(6321,728111214011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','gredmy','dmytro.grebnev@freenet.de','Dmytro Grebnev','Müllerstr. 23','Chemnitz','','GERMANY','09113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 13:34:10',0,NULL,3,1,2,1,'\\ ','gredmy\racer 4pin1.25 8cm'),(6322,596159689013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',75.98,'eastar4','kohandirect','kohan@palm-book.com','Roman Kokhanovskiy','1-st Smolenskiy pereulok,<br>dom 13, kvartira 20','Moscow','','RUSSIAN FEDERATION','121099','+7(495)761-2274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 13:37:06',0,NULL,3,1,3,1,'RA117772854CN\r ','kohandirect\rWLIN014'),(6323,728113398011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',12.5,'eastar4','ck2635','ck2635@hotmail.com','Chris Kennedy','104 Washington St','Hyde Park','MA','UNITED STATES','02136-3429','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 13:41:04',0,NULL,3,1,1,1,'、 ','ck2635\rHP 8pin 1.25 25cm '),(6324,728118518011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT011',33.8,'eastar4','m0db0xx','aptichkin@verizon.net','Aleksey ptichkin','162 dugdale st','staten island','NY','UNITED STATES','10306-5553','(718) 351-9632','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'m0db0xx'),(6325,808383496012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','sirussco','haggiscatcher@blueyonder.co.uk','David Mitchell','84 Stenhouse Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH11 3HU','01314783007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 14:14:15',0,NULL,3,1,2,1,'\\  ','sirussco'),(6326,728156192011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','d.ianprice','dpdaiprice@googlemail.com','Dave Price','11 Tan House Meadows','Kington','Herefordshire','UNITED KINGDOM','HR5 3TD','07811089351','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 15:09:03',0,NULL,3,1,3,1,'RA117772956CN\r ','d.ianprice\rMOAP001'),(6327,808415297012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',12.99,'eastar4uk','9420adrian','andy-47@live.com','adrian higgs','28 bracken close','hednesford','Staffordshire','UNITED KINGDOM','ws124du','01543877291','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 15:12:05',0,NULL,3,1,3,1,'RA117772735CN\r ','9420adrian\rHSMO017\r英标'),(6328,808359957012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','hahongkhanh2011','hahongkhanh@gmail.com','ha hong khanh','Tram VTN Binh Duong, Buu dien tinh Binh Duong, 324 Dai lo Binh Duong, F. Phu Hoa , TDM,Binh Duong','default','BI','VIET NAM','72000','0944031627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 15:12:29',0,NULL,3,1,2,1,'\\  ','hahongkhanh2011'),(6329,596201729013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','12xarcher','fhwinter@msn.com','Frederick   Winter','45 Mill Dr','Mastic Beach','NY','UNITED STATES','11951','(631) 281-4024','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 15:34:08',0,NULL,3,1,1,1,'、 ','12xarcher\r华硕限量版'),(6330,728187103011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','den-777','9172242158@mail.ru','Denis Gajanov','Gorsovetskaya 17-2-33','Kazan','','RUSSIAN FEDERATION','420124','(960) 030 - 8703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 16:02:31',0,NULL,3,1,2,1,'\\  ','den-777'),(6331,596215892013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','aruba4unme','fkbinetti@gvtc.com','Frank Binetti','104 River Bluff Dr','Boerne','TX','UNITED STATES','78006-7322','(830) 537-4401','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-26 16:06:40',0,NULL,3,1,1,1,'、 ','aruba4unme'),(6332,728190950011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',239.98,'eastar4','swar8690','sgwarner@comcast.net','seth warner','5725 durbin road','bethesda','MD','UNITED STATES','20817','(301) 263-0363','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 16:06:59',0,NULL,3,1,6,1,'EE506555673CN ','swar8690\r'),(6333,728259991011,320679565893,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',24.9,'eastar4uk','nita78','nitacharles31@yahoo.co.uk','Andrew Cosker','Pigeon House Farm<br>Ledbury Road','Ross-on-Wye','Herefordshire','UNITED KINGDOM','HR97QH','07545703565','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 17:51:05',0,NULL,3,1,3,1,'RA117772695CN\r ','nita78\r英标\rHSJA002'),(6334,727218439011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','kochegin87','kochegin@gmail.com','Mikhail Kochegin','mkrn. Aksai-2, d.7, kv.19','Almaty','KZ','KAZAKHSTAN','050031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 18:10:21',0,NULL,3,1,2,1,'\\  ','kochegin87'),(6335,728334514011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',110,'eastar4','labsupply002','panayiote73@gmail.com','Peter Poulopoulos','1002 Washington St','Holliston','MA','UNITED STATES','01746-1667','(508) 277-3290','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 19:07:59',0,NULL,3,1,1,1,'\\','labsupply002\r兼容型3D眼镜  samsung 专用'),(6336,596365421013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.99,'eastar4','cexinu2','glenndamian@hotmail.com','Glenn Damian','147 Main St<br>Primerica 2nd Fl.','Lodi','NJ','UNITED STATES','07644-1717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 20:31:36',0,NULL,3,1,1,1,'、 ','cexinu2\r红边优联'),(6337,808704272012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','patolj','patolj2@gmail.com','patricio allendes','Lo Cruzat 67, Quilicura','Santiago','Santiago','CHILE','872-0727','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 21:26:10',0,NULL,3,1,2,1,'\\  ','patolj'),(6338,542964068003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.95,'cnfaner','arthurgingras','ici_mick@hotmail.com','Mick Pelletier','305 Rue des Roses','Trois-Rivières','QC','CANADA','G8V1T1','(819) 370-1411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 21:43:54',0,NULL,3,1,3,1,'RA117772593CN\r ','arthurgingras\rWLAP009\r旧的'),(6339,596397467013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','fepedasil','fernando.analista@gmail.com','Fernando Pereira da Silva','Av. Engenheiro George Corbisier, 691<br>casa: 10','São Paulo','São Paulo','BRAZIL','04345000','551150118634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 22:00:35',0,NULL,3,1,2,1,'\\  ','fepedasil'),(6340,596404797013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','gustafsonroger','rogergus@verizon.net','roger gustafson','26180 Windsor Dr','Loma Linda','CA','UNITED STATES','92354-4100','(909) 855-5080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 22:28:24',0,NULL,3,1,1,1,'\\ ','gustafsonroger'),(6341,808736548012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','shebadis','olasheba@mac.com','Olaoluwa Sheba','13817 Castle Blvd<br>Apt 24','Silver spring','MD','UNITED STATES','20904-7336','(973) 420-5388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 22:42:43',0,NULL,3,1,1,1,'、 ','shebadis\r发210TS'),(6342,808749120012,220759518517,'New Logitech H555 Headset 981-00026 Stereo for laptop',2,'HSLO001',51.2,'eastar4uk','mbailey290','richb@wtdr.net','Charlotte Bailey','19<br>Petra Way','Mahana','Nelson','NEW ZEALAND','7173','021345181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 23:21:25',0,NULL,3,1,3,1,'RA117772681CN\r ','mbailey290\rHSLO001'),(6343,596421942013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','rittnerb2','writtner1067@wowway.com','william rittner','22491 Lakeland St','Saint Clair Shores','MI','UNITED STATES','48081-2323','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-26 23:44:20',0,NULL,3,1,1,1,'、 ','rittnerb2'),(6344,596433770013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','poplyra','poplyra@gmail.com','Christian Lyra','R. Inacio Lustosa 205 ap15','Curitiba','Parana','BRAZIL','80510000','55-41-336103343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 00:37:50',0,NULL,3,1,3,1,' RA117772810CN\r','poplyra\rBAZA001'),(6345,728492776011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','danielv915','danielvelps@aol.com','Daniel Valencia','10317 Biscaine St','El Paso','TX','UNITED STATES','79924-2903','(915) 857-6555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 00:59:44',0,NULL,3,1,1,1,'、 ','danielv915'),(6346,548675668004,140481828568,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',11.8,'cnfaner','ash757699','mendozash992000@live.com','jose m mejicanos','37 fairtown Rd','bay shore','NY','UNITED STATES','11706-1749','(631) 612-8227','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-27 01:27:27',0,NULL,3,1,1,1,'、 ','ash757699'),(6347,808809468012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',5,'OTAP001',47.45,'eastar4','jb_nercadorias','jefinhooo@yahoo.com.br','Vilma stella','Alexandre ennes nº 74','Rio grande','RS','BRAZIL','96206160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 02:26:14',0,NULL,3,1,3,1,'RA117772602CN\r ','jb_nercadorias\rOTAP001\r给客户发追踪号'),(6348,596466213013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','darksteelforce','steelforce.bb@gmail.com','Rafael Del Santoro','Rua Piratininga 136','Sorocaba','SP','BRAZIL','18080723','551532241044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 02:57:50',0,NULL,3,1,3,1,' RA117772868CN\r','darksteelforce\rBAZA001'),(6349,548696149004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','zenorb','sean@ledge.net.au','Sean Smith','17 Inverness Way','Parkwood','Queensland','AUSTRALIA','4214','0755715000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 03:13:11',0,NULL,3,1,3,1,' RA117771037CN\r','zenorb\r银色的\r澳标\rHSNO022'),(6350,808825240012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','kei1988','akhapones@gmail.com','Akhapone K Singta','3333 Lincoln Ave','Ogden','UT','UNITED STATES','84401','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 03:21:45',0,NULL,3,0,1,1,'\\ ','kei1988\r发210TS'),(6351,596475908013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','shamrox44','billsmail@billandkaysplace.com','William Mullen','4801 NW 91st Way','Coral Springs','FL','UNITED STATES','33067','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 03:54:08',0,NULL,3,1,1,1,' \\','shamrox44'),(6352,0,130536794237,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',3.86,'cnfaner','bathunters','christhepoolguy@gmail.com','Chris Hunter','136 WENNEKER DR','SAINT LOUIS','MO','UNITED STATES','63124-2032','(314) 757-4374','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-27 04:06:42',0,NULL,3,0,1,1,' \\','bathunters\r一共买了三十九条'),(6353,596481243013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','shaddyb','shaddyberry@hotmail.com','Sheryl Brown','16928 44th Ave W','Lynnwood','WA','UNITED STATES','98037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 04:31:33',0,NULL,3,1,1,1,'\\ ','shaddyb\rHP 8pin 1.25 18cm '),(6354,728550609011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','dale810','dconnor@suddenlink.net','Dale J. Connor','311 Mount Pleasant Rd','New Bern','NC','UNITED STATES','28560-7023','(252) 636-6241','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 05:02:09',0,NULL,3,1,1,1,' \\','dale810'),(6355,0,140567788325,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',0.06,'cnfaner','prodaja1985','prodajaebay@gmail.com','Ruzica Stanić','Vinski<br>Put 4','Jablanovec Donja Bistra','','CROATIA','10298','0038598587099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 06:48:57',0,NULL,3,1,3,1,' RA117771023CN\r','prodaja1985\rANTY001'),(6356,728568543011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.55,'eastar4','arsen.simonyan.1993','arsen9393@mail.ru','Arsen Simonyan','Schedrin Street 8Shenq 27Bnakaran<br>827','Gyumri','Shiraki Marz /Gyumri','ARMENIA','3103','031234421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 06:50:34',0,NULL,3,1,2,1,'\\ ','arsen.simonyan.1993'),(6357,808884305012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','9seven20','frank.kehoe@gmail.com','Frank Kehoe','Apartment 97<br>20 Christchurch Place','Dublin','Dublin','IRELAND','8','012142974','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-27 08:25:45',0,NULL,3,1,3,1,'RA117771068CN\r ','9seven20\rRELO002'),(6358,595476119013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',47.68,'eastar4','anatolykt','anatoly.krinitsyn@gmail.com','Anatoliy Krinitsyn','Filatova Street Dom 19/2  Kvartira 90','Krasnodar','Krasnodar Region','RUSSIAN FEDERATION','350038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 08:55:03',0,NULL,3,1,3,1,'RA117771071CN\r ','anatolykt\rWWOT001+ANCN001'),(6359,596518394013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','2435edgarb','islandboyedgarb@hotmail.com','Edgar Bolosan','2435 N School St','Honolulu','HI','UNITED STATES','96819-2518','(808) 256-4444','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-06-27 09:17:02',0,NULL,3,1,6,1,'EE506555687CN ','2435edgarb'),(6360,542649581003,130490976197,'New Atheros AR9281 802.11N WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',17.99,'cnfaner','igtrax','sbuenaposada@gmail.com','SATURNINO BUENAPOSADA CANO','EL PEDROSO, Nº 23 (PEÑACASTILLO)','SANTANDER','CANTABRIA','SPAIN','39011','620591467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 10:05:11',0,NULL,3,0,3,1,'RA117720769CN\r ','igtrax\r改发成    Atheros AR5008 802.11N 300M PCI-E+ 3 antenna\r'),(6361,596527688013,230393139939,'2.1 Acer Aspire 5560 5562 Bluetooth Module EDR + cable',1,'BTAC2102',12.4,'eastar4','p.magnus','paul_magnus40@hotmail.com','Paul CARASSOU','16 rue des lazaristes','Dax','Aquitaine','FRANCE','40100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 10:13:29',0,NULL,3,1,2,1,'\\ ','p.magnus\racer 4pin1.25 4cm'),(6362,808936811012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','hrnciarm','m3sofistic@gmail.com','Michal Hrnciar','Nitrianska 15','Hlohovec','','SLOVAK REPUBLIC','92001','+421911277638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 11:44:49',0,NULL,3,1,2,1,'、 ','hrnciarm'),(6363,728636857011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','krzaszuk','krzaszuk@wp.pl','Krzysztof Szukalski','Zielonka,ul. Kielecka 35','Białe Błota','kujawsko-pomorskie','POLAND','86005','05 5828384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 12:05:22',0,NULL,3,1,3,1,'RA117771139CN ','krzaszuk\rBR3D001'),(6364,728643049011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','comnetsl','gestion@comnetonline.net','ComNET - Jaime García-Miña','Avd.San Francisco Javier nº 24<br>Edificio Sevilla 1, Planta 6, Módulo 3','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 12:24:05',0,NULL,3,1,2,1,'、  ','comnetsl'),(6365,728645474011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.1,'eastar4','frgsnvctr','victorferguson@btinternet.com','Victor Ferguson','51 Ballynargan Road<br>Stewartstown','Dungannon','Tyrone','UNITED KINGDOM','BT71 5NF','02886737077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 12:34:29',0,NULL,3,1,2,1,'\\ ','frgsnvctr\r英标'),(6366,689850881001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','4749bsce','charles@bobshawce.com','Charles Wheeler','4749 N Twin City Hwy<br>Bob Shaw Consulting Engineers Ste 305','Port Arthur','TX','UNITED STATES','77642-5839','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 13:21:44',0,NULL,3,1,1,1,'、  ','4749bsce'),(6367,805566082012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','pablosilvagilyan','pablo@ascensa.com.ar','Pablo Silva Gilyan','Caseros 3015','San Andres - San Martin','Buenos Aires','ARGENTINA','1651','+541147135437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 13:54:05',0,NULL,3,1,2,1,'、  ','pablosilvagilyan'),(6368,543131276003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.95,'cnfaner','paulam.613','paulamarquis@distributel.net','Paula Marquis','1474 Clayton Rd, RR1','Almonte','ON','CANADA','K0A 1A0','(613) 256-9435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 14:26:46',0,NULL,3,1,3,1,'RA117771125CN ','paulam.613\rWLAP009\r旧的'),(6369,728679886011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','jorvik54','jorvik@aol.com','Jonathan Lucas','2711 N Saddlebrook Ln','Katy','TX','UNITED STATES','77494-5686','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 14:31:41',0,NULL,3,1,1,1,'\\ ','jorvik54'),(6370,809003643012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','patrickcouzins1976','patrickcouzins1976@yahoo.com','Patrick Couzins','123 Savannah Ct','Glen Carbon','IL','UNITED STATES','62034-4068','(618) 307-5029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 15:11:03',0,NULL,3,1,1,1,'、  ','patrickcouzins1976\r盒装的'),(6371,0,110705971300,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',63.5,'buysia','partytwins','edgarasaenz@yahoo.com','Edgar  A Saenz','3517 Colleen Meadows Cir','Houston','TX','UNITED STATES','77080-1892','(832) 922-1589','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 15:24:45',0,NULL,3,1,1,1,'、  ','partytwins'),(6372,809009412012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','user24mu','peter@pmyers.net','Peter Myers','3-5 Swallow Place<br>Inclarity Communications','London','London','UNITED KINGDOM','W1B 2AF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 15:28:21',0,NULL,3,1,2,1,'、  ','user24mu\r发210TS'),(6373,809042662012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','second-hard','kili@mundo-r.com','Jose A. Infante','Calle San Sebastian nº 7<br>A Coruña','La Coruña','Galicia','SPAIN','15007','981278620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 16:47:42',0,NULL,3,1,3,1,'RA117771111CN ','second-hard\rWWOT003'),(6374,809054753012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',55.96,'eastar4uk','renavate','raj@abcxyz.plus.com','Raj Mistry','18 The Meadway<br>Syston','Leicester','Leicestershire','UNITED KINGDOM','LE7 2BD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-27 17:20:49',0,NULL,3,1,3,1,'RA117777573CN ','renavate\r一共买了两个花洒两个水管'),(6375,0,110707909891,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',55,'buysia','hadaub','daubh@comcast.net','Harold Daub','481 Mountain House Rd','Halifax','PA','UNITED STATES','17032-9201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 17:36:12',0,NULL,3,1,1,1,'、  ','hadaub'),(6376,728752572011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','dbbowman','darren_bowman@pacbell.net','Darren Bowman','1230 Thurston Ave','Los Altos','CA','UNITED STATES','94024-6864','(650) 961-9061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 17:55:18',0,NULL,3,1,1,1,'\\ ','dbbowman'),(6377,728760579011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','limasamurai','patchin25@gmail.com','Ricardo Malaga','PO Box 1658','West Caldwell','NJ','UNITED STATES','07007','(973) 483-4302','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 18:07:52',0,NULL,3,1,1,1,'\\ ','limasamurai\r新地址\rRicardo Malaga\rAPT 1\r 318 7th ave. Newark, New Jersey 07107 \rUNITED STATES\r(973) 483-4302'),(6378,809091201012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','odilardoneto','odilardo@hotmail.com','Odilardo Neto','Rua Barão de Indaiá N 639 Laranjeiras Premium casa 66','Manaus','Amazonas','BRAZIL','69058-448','092-81145706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 18:30:29',0,NULL,3,1,3,1,'RA117771200CN ','odilardoneto\r旧的\rBALO008+UDAP001\r再发一个New Apple 8GB USB PEN KEY FLASH DRIVE U disk'),(6379,809097434012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','amartinas','alm.ebay@spamex.com','Aaron Martinas','605 Mananai Pl<br>Apt V','Honolulu','HI','UNITED STATES','96818-5381','(843) 552-7660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 18:42:46',0,NULL,3,1,1,1,'、  ','amartinas\racer 8pin1.00 15cm '),(6380,728783790011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','odilardoneto','odilardo@hotmail.com','Odilardo Neto','Rua Barão de Indaiá N 639 Laranjeiras Premium casa 66','Manaus','Amazonas','BRAZIL','69058-448','092-81145706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 18:53:38',0,NULL,3,1,17,0,NULL,'odilardoneto'),(6381,0,110707909747,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',56,'buysia','river0','pauldiehl@mchsi.com','Paul Diehl','221 E College St<br>Plaza Towers, Unit 701','Iowa City','IA','UNITED STATES','52240-1699','(319) 338-5754','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 20:58:31',0,NULL,3,1,1,1,'、  ','river0'),(6382,728843180011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',239.98,'eastar4','shihabmk','shihabmak@live.com','Shihabalden Khairalden','2814 Lake Villa Dr','Missouri City','TX','UNITED STATES','77459-7651','(281) 798-2296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 21:30:40',0,NULL,3,1,6,1,'EE506555639CN ','shihabmk'),(6383,728886244011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',2,'HSNO017',39.96,'eastar4','ngocnguyen123456','darkdjmaster@yahoo.com','ngoc nguyen','2270 E Fry Blvd<br>Ste E6','sierra vista','AZ','UNITED STATES','85635-2761','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-06-27 23:06:29',0,NULL,3,1,1,1,'、  ','ngocnguyen123456'),(6384,596747622013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','tkri5762','timkrc@aol.com','tim krich','418 s walnut st','janesville','WI','UNITED STATES','53548-4544','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 00:28:49',0,NULL,3,1,1,1,'、  ','tkri5762\r旧的'),(6385,809240048012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',15,'SCLO002',82.5,'eastar4','pc-cam_nl','groningen@pc-cam.nl','PC-CAM','Grienkamp 7','DE WESTEREEN','','NETHERLANDS','9271JG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 00:29:09',0,NULL,5,0,18,0,NULL,'pc-cam_nl\rSCLO002\r买错了估计要撤单 款已经退'),(6386,543290368003,130521745982,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',53,'cnfaner','brian1969cars','brianstoy3@comcast.net','brian bottiglieri','1054 eaton ct','pottstown','pa','UNITED STATES','19465','(610) 327-4957','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 00:47:31',0,NULL,3,1,1,1,'\\','brian1969cars\r翻新的'),(6387,728920107011,320407653218,'Acer Extensa 5420 5420G  Bluetooth Module 2.0+cable',1,'BTAC2006',12.5,'eastar4','7w**b***3','jmann1810@hotmail.com','Joe Mann','810 Fordham St','Delran','NJ','UNITED STATES','08075-1210','(856) 764-1810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 01:42:04',0,NULL,3,1,1,1,'、  ','7w**b***3\racer 4pin1.25 15cm'),(6388,548973514004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','ionel222','cirestoration@gmail.com','IONEL  COROAMA','721 S Webster Ave<br>Apt 17','ANAHEIM','CA','UNITED STATES','92804-3360','(714) 527-7237','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 02:30:45',0,NULL,3,1,1,1,NULL,'ionel222\r客户想要三天之内收到'),(6389,809283538012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','eddychecker','dhschumann@gmail.com','Dirk Schumann','1639 Brower Pl','SYCAMORE','IL','UNITED STATES','60178','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 03:15:12',0,NULL,3,1,1,1,'\\ ','eddychecker'),(6390,548982579004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.95,'cnfaner','tarjan_rj','alexandremtr@yahoo.com.br','Alexandre Monteiro de Almeida','Rua Hist. Werneck da Silva, 235<br>Bl. 1, Apto. 302, ed. Marseille, Recreio','Rio de Janeiro','RJ','BRAZIL','22790832','55-21-85477417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 03:32:38',0,NULL,3,1,3,1,'RA117771173CN ','tarjan_rj\r美标\rMOMI001'),(6391,809294296012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','dchang0','dchang@silverlakecorp.com','Dennis Chang','913 Ocean Ave<br>Apt C','Seal Beach','CA','UNITED STATES','90740','(562) 773-7427','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 04:04:18',0,NULL,3,1,1,1,'\\ ','dchang0\r4pin 1.25'),(6392,728960025011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','ceciliakong','cecelia_kong@nbt-brunei.com','Cecilia Kong','c/o Cecilia Kong (Lexus Division)<br>NBT (Brunei) Sdn Bhd','Km 4 Jalan Gadong','','BRUNEI DARUSSALAM','BE4119','+6738803979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 04:23:25',0,NULL,3,1,2,1,'\\ ','ceciliakong\r欧标\r白色的'),(6393,728956574011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',4,'HSUE004',53.96,'eastar4','thejoekid1000','joerey@sbcglobal.net','Rachel Rey','2861 Baylis Dr','Ann Arbor','MI','UNITED STATES','48108-1705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 04:23:26',0,NULL,3,1,1,1,'\\','thejoekid1000'),(6394,596784039013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',2,'OTIN003',120,'eastar4','lazsergei','xsaturn@ya.ru','Sergei Lazutochkin','Baramzinoi, 43-3','Perm','Perm region','RUSSIAN FEDERATION','614046','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 04:58:50',0,NULL,3,1,3,1,'RA117771187CN ','lazsergei\rOTIN003'),(6395,596794388013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','klinkh03','justus.klinkhamer@gmail.com','Justus Klinkhamer','PO Box 1236','Bunbury','Western Australia','AUSTRALIA','6231','04 35238668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 05:01:00',0,NULL,3,1,2,1,'\\ ','klinkh03'),(6396,809305816012,220516394703,'New Motorola H700 Bluetooth Wireless Headset H 700',1,'HSMO011',15.99,'eastar4','valcne10','valcne@oi.com.br','Eliovaldo Nascimento Cunha','Rua:Direta da Terezinha Nº 820 É<br>Bairro: Alto da TErezinha','Salvador','Bahia','BRAZIL','40711-160','(71)-32185655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 05:04:32',0,NULL,3,1,2,1,'\\ ','valcne10'),(6397,809312152012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','z.groups','zen.group.au@gmail.com','Swaroop Ghimire','7/38 French Street','kogarah','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 05:41:51',0,NULL,3,1,2,1,'\\  ','z.groups\r澳标'),(6398,549000473004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','turquoise-web','turquoise.web@gmail.com','AHMET OCAL','GENERAL ZEKIDOGAN MAH. 508. CADDE<br>46A DAIRE:6 MAMAK','ANKARA - 532-7694476','TR','TURKEY','6630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 06:14:50',0,NULL,3,1,3,1,'RA117771350CN ','turquoise-web\r银色的\rHSNO022'),(6399,728979777011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','alexatlarge3m9w','alexatlarge@aol.com','Alex Reeves','BAM Design Ltd<br>Centrium, Griffiths Way','St Albans','Herefordshire','UNITED KINGDOM','AL1 2RD','07859820096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 06:20:56',0,NULL,3,1,2,1,'\\  ','alexatlarge3m9w'),(6400,805874924012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',25.99,'eastar4uk','farfalle74zsorzs','banfalvizsolt@gmail.com','Zsolt Banfalvi','44 Clarendon Gardens','Wembley','Middlesex','UNITED KINGDOM','HA9 7QW','07861749729','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 06:56:27',0,NULL,3,1,3,1,'RA117771346CN ','farfalle74zsorzs\rHSNO019\r英标'),(6401,809330835012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','completo21','completo.srl@gmail.com','popa nicolae','8 cloutsham street','northampton','Northamptonshire','UNITED KINGDOM','NN13LN','01604750048','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 07:24:35',0,NULL,3,1,3,1,'RA117771261CN ','completo21\rHSPL011\r英标'),(6402,728993891011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','rcornell2010','roxieminx@yahoo.com','Rachel Cornell','4563 W McLellan Rd','Glendale','AZ','UNITED STATES','85301-4225','(602) 920-8617','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 07:32:38',0,NULL,3,1,1,1,'\\  ','rcornell2010'),(6403,809360764012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','digerdrivergraham','graham-reid4@sky.com','graham','40 cornwall drive brimington','chesterfield','Derbyshire','UNITED KINGDOM','s43  1ef','01246629734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 09:31:37',0,NULL,3,1,3,1,'RA117771363CN\r ','digerdrivergraham\rRELO002'),(6404,809382838012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',25.99,'eastar4uk','astawfik','astawfik@gmail.com','Tawfik Abu-Suad','61A Edgehill Road','Bournemouth','Dorset','UNITED KINGDOM','BH9 2PF','07784900532','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 10:57:31',0,NULL,3,1,3,1,'RA117771332CN\r ','astawfik\rHSNO019\r英标'),(6405,543401534003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','luis_hernandez-2008','l005hernandez@aol.com','luis Hernandez','8916 centerway rd','Gaithersburg','MD','UNITED STATES','20879','(240) 432-9359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 13:11:09',0,NULL,3,1,1,1,'\\ ','luis_hernandez-2008'),(6406,809427996012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',5,'ANTY001',40.02,'eastar4','hans_ameel','hans@interserve.be','Hans E Ameel','Hogeweg 194','Menen','','BELGIUM','8930','0475228430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 13:51:52',0,NULL,3,0,3,1,'RA117771425CN\r ','hans_ameel\rANTY001+ANTY002+WLAT009\r再发两个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r两个New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card\r\r'),(6407,729090944011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','iliya77','iliyakrapchatov@gmail.com','Iliya Krapchatov','Gorkogo 5, kv. 89','Berdsk','Novosibirsk','RUSSIAN FEDERATION','633010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 14:00:34',0,NULL,3,1,2,1,'\\ ','iliya77\racer 8pin1.00 15cm'),(6408,809453185012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',15.99,'eastar4uk','osvatha79','osvatha@gmail.com','Árpád Osváth','Gyula 92','Érd','Pest','HUNGARY','2030','+36702457571','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 14:44:58',0,NULL,3,1,2,1,'\\ ','osvatha79\r欧标'),(6409,809454919012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','right_to_resist','alsho3a3@gmail.com','Jacob saber','studie vagen 34D','Borlänge','ID','SWEDEN','78454','46736922035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 14:48:18',0,NULL,3,1,2,1,'\\ ','right_to_resist'),(6410,729116874011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','viscount_of_funk','apearsonagain@yahoo.com','Aaron Pearson','2634 Hwy 595','Neebing','ON','CANADA','P7L0G4','(807) 577-3628','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','viscount_of_funk'),(6411,809484989012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',39,'eastar4uk','2826denise','denise_nisbet@hotmail.com','Denise Nisbet','c/o LloydsTSB Bank PLC<br>21/22 High St','Uxbridge','Middx','UNITED KINGDOM','UB8 1JD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 16:07:45',0,NULL,3,1,3,1,'RA117771315CN\r ','2826denise\r英标\rHSPL009'),(6412,596936050013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','hadeerpoliss','r.poliss@gmail.com','hadeer poliss','2106 Limestone Ct','Sterling heights','MI','UNITED STATES','48314-3779','(586) 726-8884','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 17:12:59',0,NULL,3,1,1,1,'\\ ','hadeerpoliss'),(6413,596958085013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','fan_seventies','herve.lemartret@orange-ftgroup.com','Herve Le Martret appt 239','164 Bd de Stalingrad','Ivry sur Seine','Île-de-France','FRANCE','94200','0146708177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 18:23:07',0,NULL,3,1,2,1,'\\ ','fan_seventies\rCAB-6060'),(6414,596968440013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',12,'CASS003',104.4,'eastar4','sinam_fr','motamed@free.fr','sina motamed','207 impasse  guerin','marck','Nord-Pas-de-Calais','FRANCE','62730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 18:52:46',0,NULL,3,1,4,1,'YW866128373CN\r ','sinam_fr\rCASS003\rCAB-6060\r'),(6415,729203078011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',3,'HSSA001',47.7,'eastar4','phillipnguyen6','philnguyen714@yahoo.com','phillip nguyen','72840 Highway 111<br>Ste A100','palm desert','CA','UNITED STATES','92260-3324','(714) 585-9568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 18:56:56',0,NULL,3,1,1,1,'\\ ','phillipnguyen6'),(6416,729218597011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','jacinter','jcastilla@lanacion.com.ar','Jacinto Em Castilla','Quiros 3077, Dto.5','Ciudad Autónoma de Buenos Aires','Capital Federal','ARGENTINA','1427','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 19:28:53',0,NULL,3,1,2,1,'\\ ','jacinter'),(6417,809579648012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',25.99,'eastar4uk','bevanrl','riku.shop@kolumbus.fi','richard bevan','askarintie 69','Nurmijarvi','','FINLAND','01900','+358505770325','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 19:29:01',0,NULL,3,1,3,1,'RA117771377CN\r ','bevanrl\rHSNO019\r欧标'),(6418,809601516012,220727593036,'NEW Plantronics Voyager 510 Bluetooth Headset track#',1,'HSPL010',17.65,'eastar4uk','pkuslondon','mkus74@yahoo.co.uk','przemyslaw Kus','\'\'syngenta\'\'  30 priestley road<br>surrey research park','guildford','Surrey','UNITED KINGDOM','gu27yh','07888726635','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 20:07:26',0,NULL,3,1,2,1,'\\ ','pkuslondon\r英标\rHSPL010'),(6419,809602325012,220799731617,'New AC3 DTS DD 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',68.5,'eastar4','gaa460cdi','fiandhol@ntlworld.com','Andrew Simon Holman','9 Sussex Avenue','ASHFORD','KENT','UNITED KINGDOM','TN248ND','01233634441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 20:09:39',0,NULL,3,1,3,1,'RA117771434CN\r ','gaa460cdi\rHDGE001\r英标'),(6420,596998005013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',34.8,'eastar4','charlesnadeau1','charles.nadeau@gmail.com','Charles Nadeau','32 Arundel avenue','Ottawa','ON','CANADA','K1K 0B6','(613) 744-1424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 20:14:22',0,NULL,3,1,3,1,'RA117771385CN\r ','charlesnadeau1\rCASS001\rCAB-SS-2626'),(6421,809632603012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',27.99,'eastar4uk','huberthubii11','hubii11@wp.pl','hubert adamiec','27 roseberry hill','newbridge','Kildare','IRELAND','default','0857439992','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 21:10:12',0,NULL,3,1,3,1,'RA117771403CN\r ','huberthubii11\rHSNO019+CCNO001'),(6422,597031507013,230393137337,'2.1 Acer Aspire 5235 5335 5535 Bluetooth Module +cable',1,'BTAC2105',12.4,'eastar4','yuk_tong_lee','yuk_tong_lee@hotmail.com','Yuk Tong Lee','NEC Europe Ltd<br>1 Victoria Road','Acton','London','UNITED KINGDOM','W3 6BL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 22:07:38',0,NULL,3,1,2,1,'\\ ','yuk_tong_lee\racer 4pin1.25 8cm'),(6423,595113629013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','aedesanctis','tonydesanctis@gmail.com','Anthony E. DeSanctis','1 Dove Pl','Camden','DE','UNITED STATES','19934-9539','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 22:47:34',0,NULL,3,1,1,1,'\\ ','aedesanctis'),(6424,541215750003,130490601966,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'',17.85,'cnfaner','broset','181079@gmail.com','Bas Roset','Palmstraat 43','Nijmegen','','NETHERLANDS','6542JW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 22:48:42',0,NULL,3,0,3,1,'RA117771394CN\r ','broset'),(6425,729317465011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','froggyprincess1','smarterthenaveragebear@gmail.com','rosalie santemma','1416 SW 30th St','fort lauderdale','FL','UNITED STATES','33315-2826','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 00:00:10',0,NULL,3,1,1,1,'\\ ','froggyprincess1\r旧的'),(6426,729316526011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','pnei2964','pneil582@gmail.com','paul neil','112 Stratton Ln','mount laurel','NJ','UNITED STATES','08054-3301','(856) 778-8616','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 00:02:27',0,NULL,3,1,1,1,'\\ ','pnei2964'),(6427,809697354012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','aliriyaz-2008','aliriyaz@aliriyaz.ws','ali riyaz','M. Goldenbones<br>Javaahiru magu','male\'','male\'','MALDIVES','20-02','00960 7900385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 00:31:02',0,NULL,3,1,2,1,'\\ ','aliriyaz-2008'),(6428,549236315004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','noel_69','noelg_69@yahoo.com','Noel Gunaratne','22A Grapeview drive','St Catharines','ON','CANADA','L2S2W5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 00:48:39',0,NULL,3,1,3,1,'RA117771329CN\r ','noel_69\rHSNO005'),(6429,809716998012,220706561624,'New  Motorola H550 Bluetooth Wireless Headset H 550',2,'HSMO007',31.8,'eastar4','chandradjones1','misspookiejones@bellsouth.net','Chandra Jones','205 Thurmond St','Palmetto','GA','UNITED STATES','30268-1421','(770) 463-2522','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-29 01:46:56',0,NULL,3,1,1,1,'\\ ','chandradjones1'),(6430,729357776011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','matt98686','matt@pacifier.com','Matt W Gortz','5108 NE 102nd ST','Vancouver','Wa','UNITED STATES','98686-5808','(360) 573-0551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 02:49:52',0,NULL,3,1,1,1,'\\ ','matt98686'),(6431,809751465012,220716106718,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',10,'ANWI001',559,'eastar4','auzimmie2011','auzimmie@hotmail.com','Cho Yiu Au','14743 38th Ave<br>Flushing Apt E11','Flushing','NY','UNITED STATES','11354-4829','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 04:09:16',0,NULL,3,1,4,1,'YW865908585CN ','auzimmie2011'),(6432,691859099001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','yummy95','wwhite18@cfl.rr.com','Will White','827 Grovesmere Loop','Ocoee','FL','UNITED STATES','34761','(407) 509-2255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 04:49:23',0,NULL,3,1,1,1,'\\ ','yummy95\r黑色的'),(6433,543610540003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',27.16,'cnfaner','ballbreaker29','dubem@ca.ibm.com','Martin Dube','9123 Ave Tourelles','Anjou','QC','CANADA','H1J2A5','(514) 353-8151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 04:49:50',0,NULL,3,1,3,1,'RA117771505CN\r ','ballbreaker29\rHSPL005'),(6434,729356351011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',18.99,'eastar4','acijfk','acihan2han@gmail.com','JASON KWON','16801 ROCKAWAY BLVD','JAMAICA','NY','UNITED STATES','11434-5247','(347) 273-3487','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 05:32:41',0,NULL,3,1,1,1,'\\ ','acijfk\r(JOYBAY#320693989145)\r\r'),(6435,809777406012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','jnquealy','jnq30@cox.net','John Quealy','3275 Indian Mills Ln','Jamul','CA','UNITED STATES','91935-1514','(619) 248-5304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 06:21:42',0,NULL,3,1,1,1,'\\ ','jnquealy'),(6436,0,110705971362,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',62,'buysia','rtsin08','royteo@gmail.com','Roy Teo','Blk 425 Pasir Ris Drive 6 #11-97 Singapore 510425','default','','SINGAPORE','510425','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 06:44:09',0,NULL,3,1,3,1,'RA117771540CN\r\r\r\r ','rtsin08\rBR3D003'),(6437,548143629004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','oli_6000','olivier.lefebvre071@gmail.com','Olivier Lefebvre','6 Rue Fréché','Charleroi','','BELGIUM','6000','0474395820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 07:31:56',0,NULL,3,1,3,1,'RA117771448CN\r ','oli_6000\rMOOE001\r发OEM的'),(6438,809818342012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','lemonize','fozir@hotmail.co.uk','Fozir Tafader','170 Mickelfield Road','High Wycombe','Buckinghamshire','UNITED KINGDOM','HP13 7HA','07886201403','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 09:19:46',0,NULL,3,1,3,1,'RA117771690CN\r ','lemonize\rHSPL011\r英标'),(6439,809829570012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','black*belt*jones','alpay@ymail.com','Ahmet Alpay Baunoglu','Spliedtring 20','Hamburg','','GERMANY','22119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 10:04:53',0,NULL,3,0,2,1,'\\ ','black*belt*jones'),(6440,808855051012,220786834052,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',35.99,'eastar4','beanjai','mustafizar.salleh@yahoo.co.uk','MOHD MUSTAFIZAR MD SALLEH','NO.21, STKRJ, SPG. 120-48-36-23,<br>KG. MUMONG','KUALA BELAIT','BELAIT','BRUNEI DARUSSALAM','KA1731','+6738200926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 10:07:48',0,NULL,3,1,3,1,'RA117771584CN\r ','beanjai\rMOMI003'),(6441,729447757011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','alex_intenso','a-lex_007@list.ru','Bykov Aleksandr Sergeevich','per. Lermontova dom. 10 kv. 4','Blagodarnyi','Stavropol\'skii krai Blagodarnenskii raion','RUSSIAN FEDERATION','356420','+79187572940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 10:25:30',0,NULL,3,1,2,1,'\\ ','alex_intenso'),(6442,549317692004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','patrikzbirka','patrik.zbirka@gmail.com','Patrik Gyepes','Klacany<br>461','Klacany','Slovak Republic','SLOVAK REPUBLIC','96611','00421944155937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 10:32:59',0,NULL,3,1,3,1,'RA117771575CN\r ','patrikzbirka\rHSNO005\r欧标'),(6443,729453336011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','miteshdesktop','mitesh_desktop@yahoo.com','Mitesh Kshatriya','138 Green Street, Upton Park<br>London','London','London','UNITED KINGDOM','E7 8JQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 10:46:42',0,NULL,3,1,3,1,'RA117777539CN\r ','miteshdesktop\rRELO003\r红边优联'),(6444,729456076011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','kertisfar','lgtn.s@mail.ru','Galina Lagutina','ul. Mehanizatorov d.31,  kv. 71','Togliatti','Samarskaya obl','RUSSIAN FEDERATION','445046','79270220342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 10:58:16',0,NULL,3,1,2,1,'\\ ','kertisfar\r欧标'),(6445,729467627011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','jeppystore','harveyit@gmail.com','Jeff Harvey','5640 Hwy 12<br>PO Box 146','New Ross','NS','CANADA','B0J 2M0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 11:41:48',0,NULL,3,1,2,1,'\\ ','jeppystore'),(6446,809615032012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',10.99,'eastar4','mayadiamonds','mayadiamondsandjewelry@gmail.com','Maya Gamzu','9 Mordechai Zeira St.<br>Apt. 6','Tel Aviv','','ISRAEL','69624','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:27:47',0,NULL,3,1,2,1,'、 ','mayadiamonds\r'),(6447,809878741012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','vanja-istra','vanja.luk@gmail.com','Vanja Luk','Torci 11','Novigrad','Istra','CROATIA','52466','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:50:53',0,NULL,3,1,2,1,'\\ ','vanja-istra'),(6448,729486611011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','blacksea1957','b.sea57@yahoo.com','stefan petrescu','427 bunkerhill dr','nashville','tn','UNITED STATES','37217-1401','(615) 367-6347','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 12:53:15',0,NULL,3,1,1,1,'\\ ','blacksea1957'),(6449,729492083011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','lucky_dog0','wing_hong@msn.com','Wing K Hong','254 Railway pde','Cabramatta','New South Wales','AUSTRALIA','2166','0421211191','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-29 13:05:19',0,NULL,3,1,3,1,'RA117771624CN\r ','lucky_dog0\rOTSO004*2'),(6450,729497566011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','sidiese','frankguit@yahoo.ca','Pierre Fournier','4040 St-Laurent #RC7','Montreal','QC','CANADA','H2W 1Y8','(514) 845-0676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:25:35',0,NULL,3,1,3,1,'RA117771638CN\r ','sidiese\rWLAP009\r旧的'),(6451,596561435013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','apberangerandre','apberanger@bol.com.br','ANDRE BERANGER','Quadra 207, lote 4, bloco F apto 1101<br>Residencial Imprensa IV - Aguas Claras','BRASILIA','DF','BRAZIL','71926250','61 33672942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:26:11',0,NULL,3,1,3,1,'RA117771598CN\r ','apberangerandre\rMOSA005'),(6452,809901363012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',39,'eastar4uk','nikolay7910','dn2000@mail.ru','Nikolay Dovgilov','3-i Dorozhnyi proezd<br>d. 9, kor. 1, kv. 137','Moscow','Moscow','RUSSIAN FEDERATION','117535','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 13:58:31',0,NULL,3,1,3,1,'RA117771655CN\r ','nikolay7910\rWWSI006+ANCN001\r'),(6453,729509190011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','lazzyvn','lazzyvn@yahoo.com','Nguyen Ngoc Bao','54 rue Henri Barbusse','Arcueil','Île-de-France','FRANCE','94110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 14:04:46',0,NULL,3,1,2,1,'\\ ','lazzyvn\racer 8pin1.00 15cm'),(6454,597203095013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.99,'eastar4','oagafonov','oleg.a.agafonov@gmail.com','Oleg Agafonov','microrayon Zapadniy 11-20','Urai','Russian Federation','RUSSIAN FEDERATION','628285','+7(908)8965073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 14:15:49',0,NULL,3,1,2,1,'\\ ','oagafonov\r红边优联'),(6455,729531007011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','mape1719nuria','ealfredommm@yahoo.com','Marco Pineda','Manuel Tamayo E14-10 y Victor Martillo. Conjunto Colinas del Edén. Casa 61','Quito','Pichincha','ECUADOR','EC170149','593-2-3264255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 15:08:16',0,NULL,3,1,3,1,'RA117771607CN\r ','mape1719nuria\r盒装的\rOTSO004'),(6456,597224503013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',83.6,'eastar4','odilardoneto','odilardo@hotmail.com','Odilardo Neto','Rua Barão de Indaiá N 639 Laranjeiras Premium casa 66','Manaus','Amazonas','BRAZIL','69058-448','092-81145706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 15:39:37',0,NULL,3,1,3,1,'RA117771615CN\r ','odilardoneto\rBAZA001'),(6457,809937429012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','camlann','ysmercury@hotmail.com','Yongsoo Kim','Daehak-dong 251-7, 302 ho<br>Gwanak-gu','Seoul','','KOREA,REPUBLIC OF','151-859','82-10-9414-0608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 15:43:32',0,NULL,5,0,18,0,NULL,'camlann\r已退款'),(6458,729545116011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','eyal_ch1','eyal@ptc.com','Eyal Chaki','17 Amirim St.','Tel-Aviv','Israel','ISRAEL','69357','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 15:48:48',0,NULL,3,1,2,1,'\\ ','eyal_ch1'),(6459,597232799013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',71.94,'eastar4','unclepe','real-ebby@web.de','Arne Sommerlad','Schildberg 13','Giessen','','GERMANY','35398','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 16:09:23',0,NULL,3,1,3,1,'RA117771641CN\r ','unclepe\rMOSA002'),(6460,729555929011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',32.94,'eastar4','tckrockz','desilva.mahesh@gmail.com','Mahesh De Silva','No 14, Dolosbage Road,<br>Back Lane,','Nawalapitiya','Central','SRI LANKA','20000','+94542222492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 16:17:32',0,NULL,3,1,3,1,'RA117771567CN\r ','tckrockz\rHSNO003'),(6461,597237559013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',10.98,'eastar4','salmannaqvi','snaqvi57@cyber.net.pk','Salman Naqvi','66/1.18th Street.Off Khayaban- E- Badban<br>DHA Phase 5','Karachi','','PAKISTAN','75500','(923) 002-1800 ext.: 01','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 16:27:15',0,NULL,3,1,2,1,'\\ ','salmannaqvi'),(6462,809959995012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','miroxm','georgi55@gmail.com','Georgi Ikonomov','112 Regina Dr','Sterling','VA','UNITED STATES','20165-5830','(240) 620-6411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 16:31:21',0,NULL,3,1,1,1,'\\ ','miroxm'),(6463,729569418011,320698317416,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.1,'eastar4','4958shelley','felishajdupuis@yahoo.ca','shelley mero','8667 county road 42<br>rr#3','Maidstone','ON','CANADA','n0r1k0','(519) 735-4958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 16:50:31',0,NULL,3,1,2,1,'\\ ','4958shelley'),(6464,597257983013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','izznot','mellotron2@optonline.net','Duane Sherwood','192 E 8th St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11218-3368','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 17:34:22',0,NULL,3,1,1,1,'\\ ','izznot'),(6465,729621495011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',12.5,'eastar4','aaronnore','aaron_nore@hotmail.com','Aaron Noronha','228/6005, B - Suraj Kiran<br>Pant Nagar, Ghatkopar East','Mumbai','Maharashtra','INDIA','400075','9892117163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 18:44:15',0,NULL,3,1,2,1,'\\ ','aaronnore\rHP 8pin 1.25 25cm'),(6466,597291208013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','sekario','ksigg@unitybox.de','Karl Sigg','Quellenstraße 25 a','Kassel','','GERMANY','34134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 19:07:55',0,NULL,3,1,2,1,'\\ ','sekario'),(6467,810045016012,220632574055,'New Motorola H555 Bluetooth Wireless Headset H 555',1,'HSMO008',11.95,'eastar4','diondria27','diondria@gmail.com','Diondria Clarke','7328 Creek Bend Dr','Memphis','TN','UNITED STATES','38125-3022','(901) 517-0263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 19:23:00',0,NULL,3,1,1,1,'\\ ','diondria27'),(6468,597306113013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',20,'WLAT001',339.8,'eastar4','ubiquitainc','ebay@ubiquita.com','Leith Martin','6971 Monte Rosa Ave','Las Vegas','NV','UNITED STATES','89120-3018','(702) 446-0901','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ubiquitainc'),(6469,729655617011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','dagusina','dagditus@wp.pl','Dagmara Kozlowska','10 Georgette Drive','Manchester','Lancashire','UNITED KINGDOM','M3 7AF','01616615392','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 19:51:28',0,NULL,3,1,3,1,'RA117771709CN\r ','dagusina\rRELO003\r红边优联'),(6470,728118518011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT011',33.8,'eastar4','m0db0xx','aptichkin@verizon.net','Aleksey ptichkin','162 dugdale st','staten island','NY','UNITED STATES','10306-5553','(718) 351-9632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 20:24:11',0,NULL,3,1,1,1,'\\ ','m0db0xx\r盒装的'),(6471,692128682001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','azkarol','scottdnk@cox.net','Karol Scott','16079 W Wildflower Drive','Surprise','AZ','UNITED STATES','85374-5056','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 20:24:52',0,NULL,3,1,1,1,'\\ ','azkarol'),(6472,810102395012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.98,'eastar4','technat21','sbafse@yahoo.com','Capt. Carlos Alberto Silva','511 Lexington Ave<br>Radisson Lexington Hotel','New York','NY','UNITED STATES','10017-2017','(954) 661-2883','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 21:18:18',0,NULL,3,1,1,1,'\\ ','technat21\r美标'),(6473,543825933003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',70.9,'cnfaner','surgrant','francesmharris@hotmail.com','Frances Harris','5325 Bob Smith Ave','Plant City','FL','UNITED STATES','33565-3501','(813) 986-1801','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-29 21:30:38',0,NULL,3,1,1,1,'\\ ','surgrant'),(6474,810110833012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','apbc84','apbc19@yahoo.com.br','André Paulo Barbosa de Carvalho','Rua Santa Maria Goreti n339 ap03<br>Vila Laura','Salvador','Bahia','BRAZIL','40270-210','07188270586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 21:38:26',0,NULL,3,1,2,1,'\\ ','apbc84'),(6475,729705154011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ssin9115','nechal.469@gmail.com','Sardar Nechal Singh','1265 Club Cir Apt 1','Brookfield','WI','UNITED STATES','53005','(479) 856-9265','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 21:47:02',0,NULL,3,1,1,1,'\\ ','ssin9115'),(6476,810145238012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','teoulides','teoulman@live.com','George Teoulides','Odyssea Elyti 14','Ayia Napa','','CYPRUS','5330','0035799454124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 23:24:57',0,NULL,3,1,2,1,'\\ ','teoulides'),(6477,729623637011,320666180879,'NIB Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',68.95,'eastar4','top_latim','sandro.amorim@redeamazonica.com.br','SANDRO SANTANA DE AMORIM','AV. PRINCESA ISABEL, 967<br>LIBERDADE','BOA VISTA','Rorâima','BRAZIL','69309-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 00:35:03',0,NULL,5,0,18,1,NULL,'top_latim\r盒装的\rHSSE006\r美标'),(6478,728533803011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','andropopolips','jack.d.watson@gmail.com','Jack Watson','208/12-32 Lux Way<br>Brunswick','Melbourne','Victoria','AUSTRALIA','3056','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 00:51:21',0,NULL,3,1,2,1,'\\ ','andropopolips'),(6479,692226136001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','nadielle153','nadielle153@hotmail.com','Danielle Rethmeier','933 Campfire Cir','Rocklin','CA','UNITED STATES','95765-5346','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 02:56:45',0,NULL,3,1,1,1,' 、','nadielle153'),(6480,729790558011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ig-bee','robert_tes@yahoo.com','Robert Tesoriero','41 Peate Avenue<br>Glen Iris','Melbourne','Victoria','AUSTRALIA','3146','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 04:03:27',0,NULL,3,1,2,1,'、 ','ig-bee'),(6481,729792395011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','edward.morales.jr','edward.moralesjr@gmail.com','Edward Morales','7310 Highway 140 W','Puryear','TN','UNITED STATES','38251','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 04:17:36',0,NULL,3,1,1,1,' 、','edward.morales.jr'),(6482,597417124013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','sokarsrb','arheopterics@gmail.com','Radko Vujanovic','Unit 39 7-9  Atkinson Street','Liverpool','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 04:50:57',0,NULL,3,1,2,1,'、 ','sokarsrb'),(6483,549556411004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','dan186s','ebay@dcpwebs.com.au','Push I.C.T.','PO Box 3469','Success','Western Australia','AUSTRALIA','6964','0427984465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 05:39:49',0,NULL,3,1,3,1,'RA117771805CN ','dan186s\rBALO007'),(6484,810235007012,220786834052,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',35.99,'eastar4','passajir_opasniy','amiugansk@mail.ru','Сергей Урянский','13 микрорайон дом 28 квартира 44','Нефтеюганск','Тюменская область','RUSSIAN FEDERATION','628311','89224348880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 06:15:49',0,NULL,3,1,3,1,'RA117771791CN ','passajir_opasniy\rMOMI003'),(6485,810247741012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','linas_kav','linas.kav@gmail.com','Linas Kavcinskas','sukilėliu g 100-3','Kaunas','Kaunas','LITHUANIA','LT49320','860382313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 07:19:01',0,NULL,3,1,2,1,'、 ','linas_kav'),(6486,810255111012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','amoundia','amoundia@hotmail.com','florian lemoine','les salettes','Saint Genest de Beauzon','Rhône-Alpes','FRANCE','07230','0623394464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 07:54:08',0,NULL,3,1,3,1,'RA117771788CN ','amoundia\rOTCR001'),(6487,729834899011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','dhaal_17','dhaal-mi@hotmail.com','Mohamed Ismail','Fathis','Dh.Kudahuvadhoo','Central Province','MALDIVES','13080','(+960) 794 - 3414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 08:17:40',0,NULL,3,1,3,1,'RA117771765CN ','dhaal_17\rUDAP001'),(6488,597444522013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','aslizerf','suelzmaster@gmail.com','Axel Fuhrig','Hochschulstraße 46 / W0303','Dresden','','GERMANY','01069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 08:21:44',0,NULL,3,1,3,1,'RA117771774CN ','aslizerf\rMOLO004'),(6489,810270153012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','draganstanar','smart@spinter.net','Dragan Stanar','Ostra Luka 39','Ostra Luka','Republika Srpska','BOSNIA AND HERZEGOVINA','79263','0038765667556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 09:01:37',0,NULL,3,1,2,1,'、 ','draganstanar'),(6490,810274432012,220785302187,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',33.5,'eastar4uk','nigelbufton','nigel@bufton.org','Nigel Bufton','The Old Forge<br>17 High Street','Milton-Under-Wychwood','Oxfordshire','UNITED KINGDOM','OX7 6LA','01993830031','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 09:19:49',0,NULL,3,1,3,1,'RA117771859CN ','nigelbufton\rMOLO001\r翻新的'),(6491,692302794001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','swiftyyy3','swiftyyy3@yahoo.com','steve swift','2402 appalachian dr','melbourne','FL','UNITED STATES','32935-3389','(321) 427-7792','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 10:15:23',0,NULL,3,1,1,1,'、 ','swiftyyy3'),(6492,809876266012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',7.88,'eastar4uk','maxior1972','maxi41@wp.pl','Mariusz Jonca','Cumberland Avenue 16<br>Intake','Doncaster','Yorkshire','UNITED KINGDOM','dn2 6lu','07872907715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 10:26:04',0,NULL,3,1,3,1,'RA117771902CN ','maxior1972\rHSPL001'),(6493,810288090012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','katovit_125','vcano@tinet.org','Victor Cano Farre','C/ Antoni de Bofarull num 8 3ro 3ra','Reus','Tarragona','SPAIN','43202','627757857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 10:17:14',0,NULL,3,1,3,1,'RA117771964CN ','katovit_125\rOTRA001'),(6494,543945940003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',3,'WWOT003',149.97,'cnfaner','paul.van.hoof','paul.van.hoof@xs4all.nl','Paul van Hoof','Specht 25','Fijnaart','','NETHERLANDS','4793HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 11:15:20',0,NULL,3,1,3,1,'RA117772001CN ','paul.van.hoof\rWWOT003'),(6495,729878028011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','itaim','itai@imonline.co.il','Itai Marcipar','Hagalil 30','Haifa','Haifa','ISRAEL','32684','975-524-224834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 11:28:54',0,NULL,3,1,2,1,'、 ','itaim'),(6496,810307469012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','red-five','ebay-bids@basterfield.com','Daniel Basterfield','Blackbury Farm<br>Southleigh','Colyton','Devon','UNITED KINGDOM','EX24 6JF','01404871600','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 11:32:40',0,NULL,3,1,3,1,'RA117771995CN ','red-five\rOTHP003'),(6497,729892255011,320590826661,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',129,'eastar4','rolinleon68','rolinleon@hotmail.com','Peter van Belkum','Hobbemalaan 12','Helmond','','NETHERLANDS','5702 VW','+31 6 14533073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 12:24:30',0,NULL,3,1,3,1,'RA117771920CN ','rolinleon68\rRCMA001'),(6498,729918908011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','mar_san_alon','moebius65@hotmail.com','Marcos Santana Alonso','Gran Parada,143 - Santa Brigida','Las Palmas','Canarias','SPAIN','35300','666074176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 13:55:28',0,NULL,3,1,2,1,'、 ','mar_san_alon'),(6499,597510966013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.99,'eastar4','yongho62','spjj@naver.com','yongho son','107-102 HYUNDAE HOME TOWN APT<br>DUCKYANG-GU','GOYANG','KYOUNGI','KOREA,REPUBLIC OF','412-761','82172038906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 14:20:27',0,NULL,3,1,3,1,'RA117771831CN ','yongho62\rWLIN014'),(6500,597514244013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',93.99,'eastar4','apberangerandre','apberanger@bol.com.br','ANDRE BERANGER','Quadra 207, lote 4, bloco F apto 1101<br>Residencial Imprensa IV - Aguas Claras','BRASILIA','DF','BRAZIL','71926250','61 33672942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 14:34:29',0,NULL,3,1,3,1,'RA117771916CN ','apberangerandre\rMOSA005'),(6501,810386056012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','beratp87','berat73@hotmail.com','Berat Poterqoj','Ekeroths Väg 4','Linghem','Östergötland','SWEDEN','585 62','(0046)013131028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:36:21',0,NULL,3,1,3,1,'RA117771955CN ','beratp87\rGLSG001*2\r盒装的'),(6502,597528856013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','gstar187nathan','gstar187@gmail.com','nathan webber','77 old south head rd<br>bondi junction','sydney','New South Wales','AUSTRALIA','2022','61404359439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:36:49',0,NULL,3,1,2,1,'、 ','gstar187nathan\r澳标'),(6503,810393693012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','epat3210','david.adair1402@googlemail.com','david adair','48 breda drive<br>newtownbreda','belfast','Antrim','UNITED KINGDOM','bt8 6ju','07989961251','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 15:56:40',0,NULL,3,1,3,1,'RA117771828CN ','epat3210\rRELO002'),(6504,729962113011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',77.98,'eastar4','lesunderwood','isellcingular@hotmail.com','Leslie R. Underwood','4050 Cascades Blvd<br>Ste B','kent','OH','UNITED STATES','44240','(330) 630-7244','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'lesunderwood'),(6505,729965029011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',2,'ANTY002',7.16,'eastar4','ozzyborr','ozzyborr_e@hotmail.com','Gungor SASMAZ','Barbaros Mh. Panorama Sit. B/2','CANAKKALE','Sekerpinar','TURKEY','17020','(286) 218-2803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 16:18:09',0,NULL,3,1,2,1,'、 ','ozzyborr'),(6506,729986721011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','goyso2010','soniamoron32@gmail.com','Sonia Moron Camacho','Camps blancs 105 4º2ª<br>Sant boi de llobregat','Barcelona','Cataluña','SPAIN','08830','665668751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 17:16:34',0,NULL,3,1,3,1,'RA117771947CN ','goyso2010\rGLSG001*2'),(6507,597560862013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',32.99,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','ulitsa Varshavskaya dom 19 korpus 1 kvartira 113','Sankt - Petersburg','','RUSSIAN FEDERATION','196128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 17:30:23',0,NULL,3,1,3,1,'RA117771814CN ','levbarkan\rWWSI005'),(6508,549684249004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',104.99,'cnfaner','chris_virtego','christian.berndorfer@web.de','Karl Berndorfer','Brandstetten 6','Taufkirchen','','AUSTRIA','4715','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 17:46:02',0,NULL,3,1,3,1,'RA117771933CN ','chris_virtego\rEXLO001'),(6509,597591214013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','ace5858','ace5858@hotmail.com','Jorge Gandara','10 Summercress Ln','Coram','NY','UNITED STATES','11727-2615','(631) 384-6171 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 18:58:13',0,NULL,3,1,1,1,'、 ','ace5858\r华硕限量版'),(6510,597605620013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','newyorkpaulie','eburgpaulie@verizon.net','Paul Quillin','429 E 52nd St<br>Apt 34G','New York','NY','UNITED STATES','10022','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 19:41:32',0,NULL,3,1,1,1,'、 ','newyorkpaulie'),(6511,692523161001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','flash2731steven','steve.gordon@oce.com','steven gordon','301 Fluvia Ave SE','Palm Bay','FL','UNITED STATES','32909-3879','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 21:19:08',0,NULL,3,1,1,1,'、 ','flash2731steven'),(6512,810180803012,220784829901,'New Philips SHB6102 Bluetooth Stereo Headset',1,'HSPH001',74.9,'eastar4','tturbo332','turbo332@yahoo.com','davin calhoun','3564 eaton st','baton rouge','LA','UNITED STATES','70805','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 21:20:26',0,NULL,3,1,1,1,'、 ','tturbo332\r美标'),(6513,810549934012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','azgard_strongarm','mark_claire@sky.com','Mark Donovan','16 Warrilow Close, Meir','Stoke On Trent','Staffordshire','UNITED KINGDOM','ST37RJ','01782310534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 21:30:54',0,NULL,3,1,3,1,'RA117771981CN ','azgard_strongarm\rHSPL011\r英标'),(6514,810219152012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','xkdlxks','spec314@daum.net','Jooyong Kim','211-1602, byuksan-Blooming.<br>Gocheok-1dong, Guro-gu.','Seoul','Seoul','KOREA,REPUBLIC OF','152784','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 22:16:59',0,NULL,3,1,2,1,'、 ','xkdlxks'),(6515,692548145001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','fleetber','ftemple@embarqmail.com','Fleet Temple','5245 Red Hill Church Road','Coats','NC','UNITED STATES','27521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 22:40:59',0,NULL,3,1,1,1,'、 ','fleetber'),(6516,730128516011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','matvey718','matvey@post.com','Gregory  Boguslavskiy','1874 W 11th St<br># 3','Brooklyn','NY','UNITED STATES','11223','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 23:06:20',0,NULL,3,1,1,1,'、 ','matvey718'),(6517,810591029012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','catdaddys8','findtobias@hotmail.com','T Gentry','4020 Glenn Knoll Ln','Winston Salem','NC','UNITED STATES','27107-3775','(336) 986-3198','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 23:44:56',0,NULL,3,1,1,1,'、 ','catdaddys8\r盒装的'),(6518,692569954001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','dino-victoria','dbettis@faihs.com','Donna  Bettis','30 Victoria Ln','Hot Springs Village','AR','UNITED STATES','71909-7851','(501) 922-7478','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 00:30:14',0,NULL,3,1,1,1,'、 ','dino-victoria'),(6519,597676868013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','copetti','racopetti@gmail.com','Rogério Copetti','Rua Venancio Aires, 806','Santa Maria','RS','BRAZIL','97010-000','55 9993 3792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 00:35:28',0,NULL,3,1,3,1,'RA117771978CN ','copetti\rMOLO004\r华硕限量版'),(6520,810609894012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','nickotomasini','nicolas@cecilgoitia.com.ar','Nicolás Tomasini','Ramon Castro 2640','Olivos','Vicente Lopez','ARGENTINA','1636','011-156744-1926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 01:02:47',0,NULL,3,1,3,1,'RA117771845CN ','nickotomasini\rOTSO004*2\r盒装的'),(6521,810647297012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',15.99,'eastar4uk','slik610','andrew@eastech.net.au','Andrew Hickman','5 Allendale Road','Croydon','Victoria','AUSTRALIA','3136','0411226370','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 03:34:41',0,NULL,3,1,2,1,'、 ','slik610\rHSMO019'),(6522,730187581011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','kemargrant','kemargrant@gmail.com','Christophe Grant','19 Housman Ct','Maplewood','NJ','UNITED STATES','07040','(973) 679-7108','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 03:35:35',0,NULL,3,1,1,1,'、 ','kemargrant'),(6523,730161998011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','mareeandaldof','aldoandmareef@gmail.com','Aldo Farfalla','74 Delbridge drive<br>Sydenham','Melbourne','Victoria','AUSTRALIA','3037','0393902176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 06:47:42',0,NULL,3,1,3,1,'RA117771876CN ','mareeandaldof\rBR3D001'),(6524,810687854012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','australiancomputersolutions','austcompso@hotmail.com','acs acs','3/14 barralong rd','Erina','New South Wales','AUSTRALIA','2250','0243652727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 07:10:59',0,NULL,3,1,2,1,'、 ','australiancomputersolutions\r发210TS'),(6525,597738367013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','mirialiah','catnipkit@aol.com','Ruzena Thibault','5643 Elmhurst Cir<br>Apt 211','Oviedo','FL','UNITED STATES','32765-4115','(315) 399-3367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 07:30:43',0,NULL,3,1,1,1,'\\ ','mirialiah\r草莓伞 '),(6526,549843715004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','turquoise-web','turquoise.web@gmail.com','MURAT BOZKIR','MEVLANA MAH.GAZI OSMAN PASA CAD.NO 3<br>TOROSLAR (TEL +90 324 2231974 )','MERSIN','TR','TURKEY','33500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 08:41:05',0,NULL,3,1,3,1,'RA117735349CN\r ','turquoise-web\rHSNO022'),(6527,810707865012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','andreev555','asvmailcard@gmail.com','Sergey Andreev','Kuybysheva 69-33','Chelyabinsk','','RUSSIAN FEDERATION','454138','89028654108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 08:45:29',0,NULL,3,1,3,1,'RA117735410CN\r ','andreev555\rGLOT001*2'),(6528,692627232001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','dlun','dlun90032@gmail.com','Daniel Lun','1608 sawyer ave','west covina','CA','UNITED STATES','91790-2629','(626) 283-2618','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 08:48:46',0,NULL,3,1,1,1,'\\  ','dlun'),(6529,544213553003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.9,'cnfaner','vek3726','vek@hot.ee','Valeri Kulitshkov','Linnamäe tee 9 - 64','Tallinn','Harjumaa','ESTONIA','13912','+3726370694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 10:44:27',0,NULL,3,1,3,1,'RA117735318CN\r ','vek3726\rHSNO019+CCNO001'),(6530,730274674011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.96,'eastar4','girranz','girranz@yahoo.es','carles ginesta','villarroel, 81, 4-1','barcelona','Cataluña','SPAIN','08011','629613838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:11:44',0,NULL,3,1,2,1,'\\  ','girranz'),(6531,594209546013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','kalidasu1982','1800.24.7.4u@gmail.com','r r kalidas','16/7<br>eldridge st','footscray','Victoria','AUSTRALIA','3011','0393184920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:23:03',0,NULL,3,1,3,1,'RA117735255CN\r ','kalidasu1982\rCASS003\rCAB-6060'),(6532,730281312011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','eb3rh4rd','tomweber@lavabit.com','Tom Weber','Gulskarsvagen 19','Lycke','','SWEDEN','44275','+46730667726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:37:08',0,NULL,3,1,2,1,'\\  ','eb3rh4rd'),(6533,730166415011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','aureliomjr','aureliomjr@yahoo.com.br','Aurelio Meneghello Junior','Av. Tres Marias, 1175 Casa 45<br>Sao Braz','Curitiba','Paraná','BRAZIL','82310-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:39:35',0,NULL,3,1,3,1,'RA117735600CN\r ','aureliomjr\rOTSO004\r盒装的'),(6534,730250980011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','amauta3000','info@sollatino.de','Sherley Robles Vargas Machuca','Jr. Lopez de Ayala 1568<br>Dpto. 202 - San Borja -','Lima','','PERU','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:54:23',0,NULL,3,1,2,1,'\\  ','amauta3000\r'),(6535,597787598013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','malb3c','dfarges@hotmail.com','Diego Arges','16 - 8 Victoria Parade','Manly','New South Wales','AUSTRALIA','2095','0299777289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 12:34:43',0,NULL,3,1,2,1,'\\  ','malb3c'),(6536,730302256011,320701927743,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',65.9,'eastar4','2011simranpal','jattana_simran@hotmail.com','Simran Pal Singh','Myrerskogveien 54 A','Oslo','Oslo','NORWAY','0495','(0047) 40053767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 12:58:04',0,NULL,3,1,3,1,'RA117735627CN\r ','2011simranpal\r盒装的\rHDSG001'),(6537,810775820012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','samin_v','samin_v@yahoo.com','Samin Vasli','8 Benjamin Court','Lenah Valley','Tasmania','AUSTRALIA','7008','0061432579502','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 13:00:53',0,NULL,3,1,3,1,'RA117735114CN\r ','samin_v\rHSPL014\r澳标'),(6538,549892125004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',14.55,'cnfaner','lnaush','kontakt@leifnaundorf.de','Leif Naundorf','Danckelmannstraße 46/47<br>82.00.00.18','Berlin','','GERMANY','14059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 13:37:57',0,NULL,3,1,3,1,'RA117735304CN\r ','lnaush\rWLAT008'),(6539,810589226012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',2,'REPL001',21.98,'eastar4','manuelin85','manumucci@hotmail.com','Nestor Jose Mucci','Alsina 2802','Mar del plata','Buenos Aires','ARGENTINA','7600','(+54)2234941444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 13:41:14',0,NULL,3,1,3,1,'RA117735613CN\r ','manuelin85\r'),(6540,730311792011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','westcoasteagles555','latics555@gmail.com','william thomas','56 aclare road<br>barragup','mandurah','Western Australia','AUSTRALIA','6209','0895827140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 13:31:32',0,NULL,3,1,2,1,'\\  ','westcoasteagles555'),(6541,549895276004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',2,'HSNO022',29.96,'cnfaner','hard-luck-lodge','hardlucklodge@yahoo.ca','John Jarrett','2520 Ritson,Road,North.<br>RR#5,','Oshawa,','ON','CANADA','L1H 8L7','(905) 723-7480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 13:55:06',0,NULL,3,1,3,1,'RA117735128CN\r ','hard-luck-lodge\rHSNO022'),(6542,730321185011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','pawnandhex','chriskice@gmail.com','Chris Kice','1122 Oakview Dr','Wheaton','IL','UNITED STATES','60187-3074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 14:04:38',0,NULL,3,1,1,1,'\\  ','pawnandhex'),(6543,597806375013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','neromester','banfai.gabor@freemail.hu','Gabor Banfai','30 Great Lynch<br>Middleton','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK10 9BF','07877161563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 14:06:27',0,NULL,3,1,2,1,'\\  ','neromester\rCAB-6060'),(6544,596960019013,230620420999,'NIB GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO029',38.9,'eastar4','robriones81','robriones@gmail.com','Rodrigo Briones','Av. José Pedro Alessandri 605<br>Depto 605','Santiago','Región Metropolitana, Ñuñoa','CHILE','7750358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 14:25:58',0,NULL,3,1,3,1,'RA117735057CN\r ','robriones81\rHSNO029\r盒装的'),(6545,730250979011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','ianianian54321','info@originsguesthouse.co.za','Ian Campbell','Wits Mechanical Engineering<br>Private Bag 3','Wits','Gauteng','SOUTH AFRICA','2050','+27117177360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 15:10:57',0,NULL,3,1,3,1,'RA117735525CN\r ','ianianian54321\rGLOT004\r兼容型3D眼镜  samsung 专用\r'),(6546,730351314011,320477029240,'New in box SAMSUNG WEP200 Bluetooth Headset WEP 200',1,'HSSA001',15.9,'eastar4','ami-36','amiami36@hotmail.com','amalija čulić','kranjčevićeva 43','split','','CROATIA','21000','0996822138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 15:41:54',0,NULL,3,1,2,1,'\\  ','ami-36'),(6547,597830185013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','reflex-08','ricardoharris@hotmail.co.uk','Richard Harris','48 Aldersmead Road<br>Westheath','Birmingham','West Midlands','UNITED KINGDOM','B31 3JG','07412792301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 15:46:31',0,NULL,3,1,2,1,'\\  ','reflex-08\rCAB-6060'),(6548,730360461011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',1,'HSSE009',55.99,'eastar4','porsche787','e_84_84@mail.ru','Yerbol Khamzin','Imanbayev street 8, apt. 103','Astana','','KAZAKHSTAN','010000','87075178715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 16:07:20',0,NULL,3,1,3,1,'RA117735468CN\r ','porsche787\rHSSE009\r美标'),(6549,730361726011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','paul_daley','pbdaley@rogers.com','Paul Daley','110 Biscay Rd.','London','ON','CANADA','N6H 3K9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 16:10:03',0,NULL,3,1,2,1,'\\  ','paul_daley'),(6550,810859081012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','bshort5613','bshort5@hotmail.com','Brad Shortell','33 Spruce Gardens','Belleville','ON','CANADA','K8N5Y6','(613) 966-0927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 17:00:20',0,NULL,3,1,2,1,'\\  ','bshort5613\r旧的'),(6551,730396264011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','vanja-istra','vanja.luk@gmail.com','Vanja Luk','Torci 11','Novigrad','Istra','CROATIA','52466','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 17:46:42',0,NULL,3,0,2,1,'\\  ','vanja-istra'),(6552,810881670012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','redwraith94','redwraith94@yahoo.com','Mike simon','5686 Broadview Rd<br>Apt 2325','Parma','OH','UNITED STATES','44134','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 17:55:28',0,NULL,3,1,1,1,'\\  ','redwraith94'),(6553,810600988012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','zebrit','nikdevine@hotmail.com','Nik Devine','39 Broadfields','East Molesey','Surrey','UNITED KINGDOM','KT8 0BW','07926159732','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 18:07:58',0,NULL,3,1,3,1,'RA117735233CN\r ','zebrit\rOTGR001'),(6554,730417787011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.4,'eastar4','hugoarri','arri.hugo@gmail.com','Hugo Tjong','3594 West King Edward Ave. West','Vancouver','BC','CANADA','V6S 1M6','(778) 994-2805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 18:39:37',0,NULL,3,1,2,1,'\\  ','hugoarri\rHP 8pin 0.8 3cm '),(6555,810926699012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','yuval7151','uv.peleg@gmail.com','Yuval Peleg','Nakar 3','Rosh Ha\'ain','','ISRAEL','48561','(972)50-8770996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 19:36:45',0,NULL,3,1,2,1,'\\  ','yuval7151'),(6556,810934084012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',79,'eastar4','omegatechrd','cristian@omega.com.do','Omega Tech (JP:200294)','8374 NW 64th St','Miami','FL','UNITED STATES','33166-2624','305 406 3922','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 19:56:23',0,NULL,3,1,1,1,'\\ ','omegatechrd'),(6557,810956654012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','france14072011','george.osborne@centrixia.com','George Osborne','9 Chamberlain Street','Wells','Somerset','UNITED KINGDOM','BA5 2PE','01749672311','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 20:45:40',0,NULL,3,1,3,1,'RA117735180CN\r ','france14072011\rHSPL014\r英标'),(6558,730471506011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',3,'HSJA010',116.97,'eastar4','bartsimposn','alexhefner@googlemail.com','Alexander Rothmüller','Goldammerweg 2','München','','GERMANY','80937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 20:54:02',0,NULL,3,1,3,1,'RA117735587CN\r','bartsimposn\r欧标\rHSJA010'),(6559,730480363011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','tabnaac','sgao8@rogers.com','Song Gao','1 Southgate Cres.','Richmond Hill','ON','CANADA','L4B 2E1','(647) 287-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 21:19:08',0,NULL,3,1,2,1,'\\  ','tabnaac'),(6560,597925471013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','pfranck62','franck.pollet@wanadoo.fr','Franck Pollet','422 rue Pierre Dupuy','SANGATTE','Nord-Pas-de-Calais','FRANCE','62231','03 21 82 70 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 21:26:38',0,NULL,3,1,2,1,'\\  ','pfranck62\rCAB-6060'),(6561,597937517013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','rb25zed','mark.jong@gmail.com','Mark Jong','160 Harbour Esplanade<br>Docklands','Melbourne','Victoria','AUSTRALIA','3008','0415042663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 22:17:26',0,NULL,3,1,3,1,'RA117735202CN\r ','rb25zed\rBAZA001'),(6562,810992268012,220807295612,'3 pair 3D Active Shutter Glasses for Samsung SSG-2200AR',1,'GLOT004*3',155,'eastar4','yoelocmin','yoelocmin@gmail.com','Yoel Ocmin','Calle Los Pensamientos 152<br>Vipol - Callao','Callao','Callao','PERU','Callao 01','+511997948794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 22:27:55',0,NULL,3,1,3,1,'RA117735595CN\r ','yoelocmin\rGLOT004*3'),(6563,730501958011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','p33doe','pierre.connor@gmail.com','Pierre Connor','2706 Roadside Ln','Chesapeake','VA','UNITED STATES','23325-4664','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-01 22:33:31',0,NULL,3,1,1,1,'\\ ','p33doe'),(6564,550021394004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.99,'cnfaner','kmarkle1','k_markle@cox.net','Kevin Markle','7819B Harrowgate Cir','Springfield','VA','UNITED STATES','22152-3818','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-01 22:50:48',0,NULL,3,1,1,1,'\\ ','kmarkle1'),(6565,597888192013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',18.98,'eastar4','venegasvilensky','felipe@venegas.com','Felipe Venegas','El Litre 1020<br>Vitacura','Santiago','Metropolitana','CHILE','7630539','56992333353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 22:51:43',0,NULL,3,1,2,1,'\\ ','venegasvilensky'),(6566,730530450011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',4,'GLOT004',215.96,'eastar4','bgod8629','brian.godwin@verizon.net','Brian Godwin','29875 Red Mountain Dr','Valley Center','CA','UNITED STATES','92082-4730','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 00:43:41',0,NULL,3,1,6,1,'EE495340966CN ','bgod8629'),(6567,730533374011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',24.95,'eastar4','jungabozu','jungabo@gmail.com','Gustavo Jun Yamaguchi','Rua das Uvaias 110, ap 141','Sao Paulo','Sao Paulo','BRAZIL','04055-110','55 11 99686551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 00:58:16',0,NULL,3,1,2,1,'\\  ','jungabozu\r无线蓝牙二合一'),(6568,597972492013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','jdcstudios','jdc-studios@hotmail.com','joe carella','6572 mary ellen ave','van nuys','CA','UNITED STATES','91401-1327','(631) 456-9077','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 01:54:46',0,NULL,3,1,1,1,'\\  ','jdcstudios'),(6569,730549015011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','lynchd7952','dlynch@bigpond.net.au','David Lynch','3 Ella Court','Doncaster','Victoria','AUSTRALIA','3108','0398481676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 02:20:05',0,NULL,3,1,2,1,'\\  ','lynchd7952'),(6570,730563128011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',2,'HSSE009',111.98,'eastar4','sylmarie10','s.cajigas@yahoo.com','Sylmarie Cajigas','URB CUPEY GDNS<br>I-10 CALLE 4','SAN JUAN','PR','UNITED STATES','00926-7316','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'sylmarie10'),(6571,692952275001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','dabmab777','davida1949@sbcglobal.net','David Brown','3330 W Beechwood Ct','Springfield','MO','UNITED STATES','65807','(417) 496-7336','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 03:53:41',0,NULL,3,1,1,1,'\\  ','dabmab777'),(6572,597995490013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','hello_kitty231281','madison2312009@yahoo.com','Vinh Ma','10919 malden dr','houston','TX','UNITED STATES','77075-5142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 04:47:00',0,NULL,3,1,1,1,'\\ ','hello_kitty231281'),(6573,810304598012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','neduet','tanveer.lodhi@gmail.com','NUzhat Lodhi','2123 Aza Dr','Santa Clara','CA','UNITED STATES','95050-3645','(818) 400-2200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 06:26:50',0,NULL,3,1,1,1,'\\  ','neduet'),(6574,598012409013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','bmb112781','bmb1127@hotmail.com','Brandon Brashear','3509 Jacksboro Ave','Snyder','TX','UNITED STATES','79549-5514','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-07-02 07:11:52',0,NULL,3,1,6,1,'EE495340952CN ','bmb112781\r盒装的'),(6575,730613407011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','ulanbulan','julia_berglund86@hotmail.com','Julia Berglund','Tollbugata 29B','Drammen','','NORWAY','3044','004799525359','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-02 08:35:17',0,NULL,3,1,2,1,'\\ ','ulanbulan\r黄色的'),(6576,730613028011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ldtgmbh','ml@event-ls.com','Dr.Leber DATENTECHNIK GmbH','Falkenring 8','Hanau','','GERMANY','63454','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 08:36:12',0,NULL,3,1,2,1,'\\  ','ldtgmbh'),(6577,598029727013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','arrabi','ali_arrabi@hotmail.com','Ali Al-Rabi','Prince Fasil Street<br>P.Box 31775','Al-Khobar','Eastern','SAUDI ARABIA','31952','00966569788400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 09:08:26',0,NULL,3,1,2,1,'\\  ','arrabi'),(6578,0,110708836966,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',50,'buysia','visionchr','christerj2008@yahoo.se','Christer Junflo','Skraeddartorpsvaegen 16','Upplands Vaesby','','SWEDEN','SE-19454','+46708707910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 10:33:04',0,NULL,3,1,3,1,'RA117735542CN\r ','visionchr\rBR3D007'),(6579,598066067013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',18,'eastar4','kporotchkin','kostap@gmail.com','Konstantin Porotchkin','19 Hadekel st., ap. 5<br>P.O.Box 15196','Bney Aish','','ISRAEL','60860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:22:59',0,NULL,3,1,2,1,'\\  ','kporotchkin'),(6580,811184584012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','adegtyarev','andrey.degtyarev@hotmail.com','Andrey Degtyarev','ul. Kuznetsova 12-6','Kopejsk','Cheljabinskaja oblast\'','RUSSIAN FEDERATION','456601','+79090762127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:31:42',0,NULL,3,1,2,1,'\\  ','adegtyarev'),(6581,811185636012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','jure2009','jure@bol.com.br','Vilma Terezinha de Andrade','PRACA DOS ANDRADAS 32 AP 801<br>Centro','Barbacena','Minas Gerais','BRAZIL','36200-008','32 33330282','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-02 12:37:00',0,NULL,3,1,2,1,'\\  ','jure2009'),(6582,550134274004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','sparkel_no_limit','amiradv1@gmail.com','amir saba','post office box 99707','haifa 31996','','ISRAEL','31996','+97254755889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:38:10',0,NULL,3,1,3,1,'RA117735321CN\r ','sparkel_no_limit\rRCLO006'),(6583,811154616012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.4,'eastar4','steven-hi','awake@iafrica.com','S L Naude','P.O. Box 3373<br>Matieland','Stellenbosch','Western Cape','SOUTH AFRICA','7602','27721966684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:50:12',0,NULL,3,1,2,1,'\\  ','steven-hi\rHP 8pin 1.0 18cm 4线连 '),(6584,730691035011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','adriacarlas','acarlas87@hotmail.com','Adrià Carlas Roig','Marinada,13','L\'Armentera','Cataluña','SPAIN','17472','619505427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 13:39:33',0,NULL,3,1,2,1,'\\  ','adriacarlas'),(6585,811233408012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','paulorcc','paulorobertorcc@gmail.com','PAULO ROBERTO RODRIGUES PAULORCC','QNP 10 CONJUNTO L CASA 29<br>CEILANDIA','BRASILIA','Distrito Federal','BRAZIL','72231-112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 14:54:14',0,NULL,3,1,2,1,'\\  ','paulorcc'),(6586,811248611012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',96.9,'eastar4uk','banff763','alextown@blueyonder.co.uk','alex town','32 abbey road','eastbourne','East Sussex','UNITED KINGDOM','bn20 8td','07970551886','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-02 15:32:28',0,NULL,3,1,3,1,'RA117735471CN\r ','banff763\r盒装的\rOTSO004*2'),(6587,730729750011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','yesok777','yes.ok777@gmail.com','rapeepong morakul','124/2   Bangkok-noonthaburi 7<br>Bangkok-noonthaburi Road','Muang','Noonthaburi','THAILAND','11000','66896666774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 15:37:41',0,NULL,3,1,2,1,'\\  ','yesok777'),(6588,549604696004,140490658273,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',38.9,'cnfaner','gzlazar','gzlazar@gmail.com','Gergo Zeta Lazar','Lovas u. 23.<br>Farbax','Szombathely','','HUNGARY','9700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 15:44:41',0,NULL,3,1,3,1,'RA117735905CN ','gzlazar\rWWSI004+ANCN001\r'),(6589,598134247013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','superdane1','pkjespersen@gmail.com','Preben Koefoed-jespersen','Turistvej 32<br>Snogebæk','Nexo','Bornholm','DENMARK','3730','004536976910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 17:07:42',0,NULL,3,1,2,1,'\\  ','superdane1'),(6590,0,180688358875,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',11,'au-buy','kasyan2006','oncur@mail.ru','Eduard Kasyan','Metallurgicheskaya, 48','Rostov on Don','','RUSSIAN FEDERATION','344029','+79282291470','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-02 17:27:25',0,NULL,8,1,3,1,'RA117735131CN\r ','kasyan2006\rRELO002\r已发货'),(6591,730775427011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','muthrodrigo','muth_2@hotmail.com','rodrigo narciso','Rua 14 lote 40 quadra 05 loteamento são bento da lagoa Itaipuaçu-maricá rj','maricá','rio de janeiro','BRAZIL','24900000','552178793712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 17:33:58',0,NULL,3,1,3,1,'RA117735370CN\r ','muthrodrigo\rGLSG001'),(6592,550203004004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','aviv1933','aviv193@gmail.com','Aviv Sharon','Haegoz 8','Givat Ada','','ISRAEL','37808','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 17:34:10',0,NULL,3,1,3,1,'RA117735193CN\r ','aviv1933\rRCLO006\r新的'),(6593,811326427012,220502333507,'2.1 HP DV2000 DV2100 DV2200  Bluetooth Module+ cable',1,'BTHP2103',12.4,'eastar4','cheyenne39cs','aleymau.ebay@gmail.com','Claudia Cisneros','Genaro Garcia Ret. 29 Edif. 1 Int. 138<br>Col. Jardin Balbuena Del. Venustiano Carranza','Mexico, D.F.','Distrito Federal','MEXICO','15900','(52) 55-55712722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 18:39:41',0,NULL,3,1,2,1,'\\  ','cheyenne39cs\rHP 8pin 1.0 12cm '),(6594,811336569012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',59.9,'eastar4','vaitomanocu001','ctalarico@uol.com.br','CARLOS ROBERTO MARANGONI TALARICO','RUA BENEDITA SILVANO CORREIA 136 - JD IPORANGA<br>CONDOMINIO VILA INGLESA','SOROCABA','SÃO PAULO','BRAZIL','18108-605','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 18:58:02',0,NULL,3,1,3,1,' RA117735247CN\r','vaitomanocu001\rWWOT002\rIBM版旧的'),(6595,730823144011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','coolproducts1','coolproducts1@yahoo.com','Jonathan Weiss','7420 McFettridge Ln','Coopersburg','PA','UNITED STATES','18036-3449','(484) 232-6642','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 19:28:24',0,NULL,3,1,1,1,'\\ ','coolproducts1'),(6596,811367087012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','tinchips2','tipnchips@hotmail.com','Pedro Miranda','7979 NW 21st St<br># SJO41930','Doral','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 20:06:30',0,NULL,3,1,1,1,'\\  ','tinchips2'),(6597,0,180688812693,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',10.49,'au-buy','digitrog','prolsson@iprimus.com.au','Paul Olsson','Box  46','Coober Pedy','South Australia','AUSTRALIA','5723','61886723049','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 20:56:30',0,NULL,8,1,3,1,'RA117735220CN\r ','digitrog\rRELO002\r已发货'),(6598,730863804011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','tangentuser','dibarnes@bigfoot.com','David Barnes','19, The Vineries','Wimborne','Dorset','UNITED KINGDOM','BH21 2PU','01202881702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 21:17:52',0,NULL,3,1,3,1,'RA117735508CN\r ','tangentuser\rKBNO001'),(6599,730867535011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','theccko','theccko@yahoo.es','miguel angel almeida morales','el ciruelo nº4, el palmital de guia','santa maria de guia de gran canaria , las palmas de g.c.','Canarias','SPAIN','35457','630504774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 21:29:33',0,NULL,3,1,2,1,'\\  ','theccko'),(6600,811405099012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',13.95,'eastar4','dougsistrunk','douglassistrunk@yahoo.com','doug sistrunk','8603 Church St','needville','TX','UNITED STATES','77461-8216','(281) 725-1824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 21:46:01',0,NULL,3,1,1,1,'\\  ','dougsistrunk'),(6601,598215463013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','miasoltero','tarasol62@yahoo.com','Maria A. Soltero','1790 Ashland Trl','Oviedo','FL','UNITED STATES','32765-4412','(407) 977-9482','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 22:12:04',0,NULL,3,1,1,1,'\\ ','miasoltero\r兼容型3D眼镜 通用型'),(6602,550274274004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.99,'cnfaner','alondavi','alon4d@gmail.com','Alon Davidzon','gissin 3/2','Rishon Le Zion','','ISRAEL','75281','972-54-2428285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 22:19:25',0,NULL,3,1,3,1,'RA117735485CN\r ','alondavi\rHSPL002'),(6603,730882517011,320641167233,'2.4GHz 16DBi Wifi Yagi Antenna RP-SMA and Moutning kit',1,'ANYA001',14.45,'eastar4','tinyfinery','debbie@hogan.com','Deborah Hogan','219 Cherry Dr','Melbourne Beach','FL','UNITED STATES','32951','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 22:24:13',0,NULL,3,1,3,1,' RA117735701CN','tinyfinery\rANYA001'),(6604,730891316011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','xybex69','rorland@bredband.net','John Rorland','Sodergatan 25','Marsta','','SWEDEN','19547','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 22:55:59',0,NULL,3,1,3,1,'RA117735335CN\r ','xybex69\rBR3D001'),(6605,550283496004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',14.75,'cnfaner','kudrosrbin','kudro.bl@gmail.com','Dejan Racic','Ljubice Gerovac 1','Banja Luka','Republic of Srpska','BOSNIA AND HERZEGOVINA','78000','0038765974450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 23:16:34',0,NULL,3,1,3,1,' RA117735556CN\r','kudrosrbin\r欧标\rHSNO005'),(6606,0,180688812683,'New Griffin PowerJolt Dual USB Micro Car Charger',1,'CCGR001',8.49,'au-buy','andrewc1957','info@architype.biz','Andrew Cronin','Unit 11, 155 Mt Alexander Road','Flemington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-03 00:20:49',0,NULL,8,1,3,1,'RA117735423CN\r ','andrewc1957\rCCGR001\r已发货'),(6607,0,110708209629,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',77,'buysia','d0dg3ram731','rick.westmoreland@yahoo.com','Rick Westmoreland','PO Box 471','Finley','TN','UNITED STATES','38030-1471','(731) 445-3456','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 04:03:56',0,NULL,3,1,1,1,'\\  ','d0dg3ram731'),(6608,811503131012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','zmule','manzocorp@gmail.com','Emil Manzo','711 Central Ave','Ellenton','FL','UNITED STATES','34222','(941) 721-9225','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-03 05:07:09',0,NULL,3,1,1,1,'\\  ','zmule'),(6609,730961921011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','bluecn2004','nhamc@yahoo.com','CUONG NHAM','43 PARASHIN BAY','WINNIPEG','MB','CANADA','R2R1B1','(204) 694-3900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 05:20:47',0,NULL,3,1,2,1,'\\  ','bluecn2004'),(6610,730962859011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','tharaka1985','tharakasoysa@gmail.com','Tharaka Soysa','No. 27, Madawilgoda,<br>Talpitiya North,','Wadduwa','Western','SRI LANKA','12560','+94773279156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 05:28:58',0,NULL,3,1,2,1,'\\  ','tharaka1985'),(6611,811519887012,220805890964,'New MOTOROLA H710 BLUETOOTH HEADSET H 710',1,'HSMO021',29.39,'eastar4','lilhottie_123','fox_racing_babe_86@hotmail.com','Lisa Taylor','33 Lake Cootharaba Place<br>Logan Reserve','Brisbane','Queensland','AUSTRALIA','4133','0411890640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 06:40:37',0,NULL,3,1,2,1,'\\  ','lilhottie_123\r澳标\r新的'),(6612,598292852013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','araphin','kollecti@otenet.gr','Alexandre A. Galinos','P.O. Box 3138','ATHENS','Attica','GREECE','10210','+302103305086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 06:56:57',0,NULL,3,1,2,1,'\\  ','araphin\r新的'),(6613,811528135012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','inyox','kirkshrader@gmail.com','Kirk Shrader','961 Sierra Vista St','Inyokern','CA','UNITED STATES','93527','(760) 377-4934','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 07:21:07',0,NULL,3,1,1,1,'\\  ','inyox'),(6614,811526011012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','gyapjas81','benedek.elek@hotmail.com','Zoltán Nagy','Péter Pál street 79','Budapest','','HUNGARY','1221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 07:25:33',0,NULL,3,1,2,1,'\\  ','gyapjas81\racer 5pin1.25 6cm  '),(6615,598297843013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','tausmc','jonlusmc@yahoo.com','Jonathan Louderback','705 Snowdon Ln','Glen Burnie','MD','UNITED STATES','21061','(410) 969-8340','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 07:31:30',0,NULL,3,1,1,1,'\\ ','tausmc\r兼容型3D眼镜 通用型'),(6616,693347953001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','jeepadie','jeepadie51@yahoo.co.uk','adie russell','47 queens drive<br>foxhill','bath','Avon','UNITED KINGDOM','ba2 5pa','01225678765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 07:53:23',0,NULL,3,1,3,1,'RA117735406CN\r ','jeepadie\rBR3D007'),(6617,811563708012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',2,'OTHP003',23,'eastar4uk','123thormagne','thor.magne@famokland.no','Thor Magne Økland','Lio 10','Auklandshamn','','NORWAY','5551','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 09:16:26',0,NULL,3,1,3,1,'RA117735366CN\r ','123thormagne\rOTHP003'),(6618,0,110708209610,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',63.29,'buysia','mudan','mudanantiques@yahoo.com','Dan Gould','4289 Rocky Glenn','Roswell','GA','UNITED STATES','30075','(770) 993-3023','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 09:27:44',0,NULL,3,1,1,1,'\\  ','mudan'),(6619,811590621012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','alandbridge14','adymond@bridgemarketinggroup.com','Alan Dymond','14 Dixon Street','Glen Iris','Victoria','AUSTRALIA','3146','0419547980','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 10:28:11',0,NULL,3,1,3,1,'RA117735454CN\r ','alandbridge14\rHSPL014\r澳标\r'),(6620,731060690011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','1004170850','paul.gadsby4@btinternet.com','Paul Gadsby','31 Mapleton Road','DRAYCOTT','Derbyshire','UNITED KINGDOM','DE72 3QQ','01332872939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 11:28:34',0,NULL,3,1,2,1,'\\  ','1004170850\racer 8pin1.00 15cm '),(6621,811616962012,220713846368,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET',1,'HSNO016',11.9,'eastar4uk','jaimie1507','jaimieremington@mac.com','J Remington','15 St Marys Road','Benfleet','Essex','UNITED KINGDOM','SS71NR','01491575704','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 11:30:33',0,NULL,3,1,3,1,'RA117735162CN\r ','jaimie1507\r英标\rHSNO016'),(6622,731066506011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','fussballkochbuch','itter16@unitybox.de','Peter Katzbach','Mettmannerstr. 54','Hilden','','GERMANY','40721','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 11:44:19',0,NULL,3,1,2,1,'\\  ','fussballkochbuch\r红边优联'),(6623,811641126012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','ccod85','pks-world@hanmail.net','Young Su Park','Garak 1-dong<br>Siyeong Apt 42-503','Seoul, Songpa-gu','','KOREA,REPUBLIC OF','138-741','82-10-7272-2857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 12:44:50',0,NULL,3,1,2,1,'\\  ','ccod85'),(6624,0,180688812690,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',12.5,'au-buy','ksliman','ksliman@cox.net','Keith J. Sliman','18068 Swamp Rd','Prairieville','LA','UNITED STATES','70769','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 13:01:56',0,NULL,3,1,1,1,'\\','ksliman\r已发货'),(6625,811689960012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',2,'REPL001',21.98,'eastar4','jnchesebrough','jchesebrough@live.ca','John Chesebrough','89 kensington ave s','hamilton','ON','CANADA','l8m 3h1','(905) 545-7217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:17:37',0,NULL,3,1,2,1,'\\  ','jnchesebrough'),(6626,598402209013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','joeridebon','joeridebonnaire@hotmail.com','Joeri De Bonnaire','Lencouet','Feugarolles','Aquitaine','FRANCE','47230','0553483407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:23:06',0,NULL,3,1,6,1,'EE495340949CN ','joeridebon\r盒装的'),(6627,550446050004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','jnchesebrough','jchesebrough@live.ca','John Chesebrough','89 kensington ave s','hamilton','ON','CANADA','l8m 3h1','(905) 545-7217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:36:45',0,NULL,3,1,3,1,'RA117735176CN\r ','jnchesebrough\rHSPL014'),(6628,598408721013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',32.99,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:42:35',0,NULL,3,1,3,1,'RA117735145CN\r ','update_marcelo\rWWSI005\r一共买了两个'),(6629,598411831013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',32.99,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:52:40',0,NULL,3,1,17,0,NULL,'update_marcelo'),(6630,731142207011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','fair_maid_of_kent','hayward.rosemary@gmail.com','Mr G Hayward','30 St Martins Road<br>Bilborough','Nottingham','Nottinghamshire','UNITED KINGDOM','NG8 3AR','01159678274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:55:05',0,NULL,3,1,2,1,'\\  ','fair_maid_of_kent\rCAB-6060'),(6631,811721995012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',11,'eastar4','fotisalex','fotisalexioy@gmail.com','FOTIS ALEXIOY','ARI VELOUCHIOTI 4','THESSALONIKI','προεπιλογή','GREECE','56430','+30 2310662005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 15:26:55',0,NULL,3,1,2,1,'\\  ','fotisalex\r一共买了两个'),(6632,731222032011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ttschia','thomas.tschiatschek@mnet-mail.de','Thomas Tschiatschek','Forststr. 5','Neuried','','GERMANY','82061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 17:15:46',0,NULL,3,1,2,1,'\\  ','ttschia'),(6633,731157706011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','mustieles','jsmustieles@yahoo.es','Julio Sanchez Mustieles','C/ Doctor Sanchis Sivera nº 18, 5º, puerta 20','Valencia','Comunidad Valenciana','SPAIN','46008','962087101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 17:33:05',0,NULL,3,1,3,1,'RA117735383CN\r ','mustieles\rBR3D001'),(6634,693578022001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','ronaldfiesta22','ronaberth@yahoo.com','Ronald  Berthiaume','10901 Kitten Trl','Hudson','FL','UNITED STATES','34669-2012','(727) 862-9365','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 17:40:29',0,NULL,3,1,1,1,'\\  ','ronaldfiesta22'),(6635,811845346012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','pmz1980','pmz1980@gmail.com','qiling shi','1116 Lincoya Bay Dr','Nashville','TN','UNITED STATES','37214-2685','(407) 446-0619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 18:34:14',0,NULL,3,0,1,1,'\\  ','pmz1980\r发210TS两个'),(6636,731298505011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',2,'RELO003',15,'eastar4uk','wig_tightener','bgarcha101@hotmail.com','Baljit Garcha','The Flat 22 High Northgate','Darlington','Durham','UNITED KINGDOM','DL1 1UP','07720348844','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 18:46:59',0,NULL,3,1,3,1,'RA117735264CN\r ','wig_tightener\r红边优联\rRELO003'),(6637,811900514012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',27.7,'eastar4uk','jill6179','jillw4@gmail.com','Jill Ward','67 Woodland Hill<br>Whitkirk','Leeds','West Yorkshire','UNITED KINGDOM','LS15 7BX','07773500768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 19:15:23',0,NULL,3,1,3,1,'RA117735352CN\r ','jill6179\rHSPL011\r英标'),(6638,598550576013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',9.49,'eastar4','topy-top','d@whiteweb.com.ua','Kilimchuk Denis Ruslanovich','Dneprovskaja naberezhnaja 26K, kv. 51','Kiev','','UKRAINE','02132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 19:25:49',0,NULL,3,1,2,1,'\\  ','topy-top'),(6639,598570826013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','appst92','tripp.mcgrath@yahoo.com','Frank McGrath','6138 Braidwood Ct','Raleigh','NC','UNITED STATES','27612-4947','(919) 624-3148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 20:11:00',0,NULL,3,1,1,1,'\\  ','appst92'),(6640,693303190001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','schoon987','sgtschoon@gmail.com','Bill Schoonmaker','5715 Hedgecrest Pl','Charlotte','NC','UNITED STATES','28269-0167','(704) 599-4070','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 20:23:23',0,NULL,3,1,1,1,'\\  ','schoon987'),(6641,550604690004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','jmen5090','jucemero@msn.com','Julio César Menes Rodríguez','Avenida de Alemania Nº71, 3ºF','Avilés','Asturias','SPAIN','33401','630487729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 20:29:12',0,NULL,3,1,3,1,'RA117735445CN\r ','jmen5090\rBALO007'),(6642,598586624013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23.5,'eastar4','bindelsn','stefan.bindel@web.de','Stefan Winkler','Seeadlerweg 42','Kiel','','GERMANY','24159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 20:47:09',0,NULL,3,1,2,1,'\\  ','bindelsn'),(6643,811976875012,220726727351,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',22.74,'eastar4','wpwswh','wwright@qk4.com','Wendell wright','5302 Mockingbird Valley Rd','LaGrange','KY','UNITED STATES','40031-8643','(502) 222-4404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 22:18:02',0,NULL,3,1,1,1,'\\  ','wpwswh'),(6644,731416238011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',104.97,'eastar4','jr_baz','baz@hartu.net','José Ramón Baz Toribio','Guatemala 5, 2Dcha','Vitoria-Gasteiz','País Vasco','SPAIN','01012','609900805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 22:21:12',0,NULL,3,1,3,1,'RA117735511CN\r ','jr_baz\rUDAP001'),(6645,731414789011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','ricgarcez2011','ricgarcez@infonet.com.br','RICARDO GARCEZ','RUA ANANIAS AZEVEDO, 95 APTO 602','ARACAJU','SERGIPE','BRAZIL','49020080','557932461970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 22:24:47',0,NULL,3,1,3,1,' RA117735437CN\r','ricgarcez2011\rGLSG001'),(6646,812015106012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','bmcg7982','b_mcguinness@hotmail.com','Brendon  McGuinness','3 Danyenah St','Loganholme','Queensland','AUSTRALIA','4129','0414602918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 22:28:49',0,NULL,3,1,2,1,'\\  ','bmcg7982'),(6647,812024299012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','djjc6717','djjc6717@yahoo.com','Judith Sullivan','18 Crestwood Cir','Westfield','MA','UNITED STATES','01085-1526','(413) 267-9934','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 22:56:25',0,NULL,3,1,1,1,'\\ ','djjc6717'),(6648,731429996011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY002',17.9,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 23:08:46',0,NULL,3,1,2,1,'\\  ','saiajin77'),(6649,598627252013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','carodin11','carsten.rodin@gmail.com','Carsten C S Rodin','15205 Deception Rd.','Anacortes','WA','UNITED STATES','98221','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 23:23:47',0,NULL,3,1,1,1,'\\  ','carodin11'),(6650,731435115011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*3',415.98,'eastar4','mal1619','budhu981@aol.com','KHAIRMALA BUDHU','1090 PARKWOOD BLVD','SCHENECTADY','NY','UNITED STATES','12308-2902','(518) 346-2732','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-07-03 23:30:55',0,NULL,3,1,6,1,'EE495340970CN ','mal1619\r盒装的'),(6651,731438030011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','eclaney','eclaney@earthlink.net','EARL LANEY','6449 S 209th East Ave','BROKEN ARROW','OK','UNITED STATES','74014-1933','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 23:43:05',0,NULL,3,1,1,1,'\\  ','eclaney'),(6652,731449336011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','jakdaniel007123','jakdaniel007@hotmail.com','Daniel St-Pierre','4781 rue St-Georges','Lévis','QC','CANADA','G6W 1C7','(418) 835-6628','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 00:28:38',0,NULL,3,1,2,1,'\\  ','jakdaniel007123'),(6653,812055824012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','sovelo30003','sovelo3003@hotmail.com','xuesong jin','98 Forest Park Rd','Woburn','MA','UNITED STATES','01801-1955','(617) 708-6454','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 00:46:01',0,NULL,3,1,1,1,'\\ ','sovelo30003'),(6654,693773261001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',29.9,'buysia','timmymin','tmminikel@hotmail.com','Debi Peterson','25833 26th Pl S','Kent','WA','UNITED STATES','98032-5505','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 00:50:35',0,NULL,3,1,1,1,'\\ ','timmymin'),(6655,812060441012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','valdevino','biodevino@bol.com.br','Valdevino Ramos','Rua Altino Gonçalves de Farias<br>1441','Curitibanos','Santa Catarina','BRAZIL','89520000','04991029999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 01:04:17',0,NULL,3,1,2,1,'\\  ','valdevino\rmicorsoft 极动鲨 mouse'),(6656,731451632011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','lozanojm','jmlozano@tecaeromex.com','Juan Manuel Lozano','Nva. Polonia # 189<br>Lomas de Cortes','Cuernavaca','Morelos','MEXICO','62240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 02:01:00',0,NULL,3,1,3,1,'RA117735539CN\r ','lozanojm\rBR3D001'),(6657,731475069011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'eastar4','murajp08','murajp@hotmail.com','jorge moraoka','rua dr rafael c. lancelot 41','sao paulo','sp','BRAZIL','04108010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 02:10:09',0,NULL,3,1,3,1,'RA117735295CN\r ','murajp08\rOTGR001+OTGR002+OTGR003'),(6658,812094010012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',15.99,'eastar4uk','fractil','fractil@msn.com','John Price','1411 West Jean Circle','Lincoln','NE','UNITED STATES','68522','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 03:15:09',0,NULL,3,1,1,1,'\\  ','fractil'),(6659,731497311011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','renatocbarros','velocidade@gmail.com','Renato Correia de Barros','Av. Antonio Requena Nevado, 899','Bauru','São PAulo','BRAZIL','17055040','551497999899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 03:56:45',0,NULL,3,1,3,1,'RA117717380CN ','renatocbarros\rKBNO001'),(6660,812108555012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','keneme2','bartleyd@sonic.net','David Bartley','1930 Yolo Court','Santa Rosa','CA','UNITED STATES','95405','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 04:28:42',0,NULL,3,1,1,1,' 、','keneme2\r发210TS'),(6661,731520957011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','jheltonau','jhelton@exemail.com.au','Jon E Helton','Telefix<br>1/96 Aerodrome Road','Maroochydore','Queensland','AUSTRALIA','4558','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 06:16:14',0,NULL,3,1,2,1,'\\ ','jheltonau'),(6662,598697816013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',36,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 06:39:07',0,NULL,3,1,3,1,'RA117735675CN\r ','small.mac\rWLAP008'),(6663,598700371013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',20.49,'eastar4','nhienhuong','quanghaihcm@gmail.com','Tran Quang Hai','201A No Trang Long. Phuong 12.  Quan Binh Thanh','Ho Chi Minh City','Viet Nam','VIET NAM','717066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 06:58:26',0,NULL,3,1,2,1,'\\ ','nhienhuong'),(6664,812137237012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','fredoreco','d.geeza@hotmail.co.uk','Daniel  Gyselynck','26 Southey Road','Rugby','Warwickshire','UNITED KINGDOM','CV22 6HF','01788833480','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-04 06:59:14',0,NULL,3,1,3,1,'RA117735661CN\r ','fredoreco\rGLSG001*2'),(6665,731531389011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','dvpsupermum1960','dvpcreate@bigpond.com','Dubravka Vukic-Presland','76 Glossop Road<br>Linden','Blue Mountains','New South Wales','AUSTRALIA','2778','0414240592','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-04 07:09:23',0,NULL,3,1,3,1,'RA117735689CN\r ','dvpsupermum1960\rOTSO004*2'),(6666,731534001011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','ora951','rdel_2@juno.com','David Delgado','315 Stardust Dr','San Antonio','TX','UNITED STATES','78228-2760','(210) 431-2684','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 07:23:25',0,NULL,3,1,1,1,' 、','ora951'),(6667,812146660012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','delrihamo_15','delrihamo@hotmail.com','Riham Alkhamisi','Rönnhagegatan 14','Malmö','Skåne','SWEDEN','21459','0046737022840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 07:44:01',0,NULL,3,1,3,1,'RA117735750CN\r ','delrihamo_15\rGLSG001*4\r新地址\rAyar Fadhil\rKolbottenvagen 2\r77 152 Ludvika\rSweden\r\r'),(6668,812149726012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','technology.systems','james_patterson@optusnet.com.au','James (Warren) Patterson','14 MacDougal St, Kurunjang','Melbourne','Victoria','AUSTRALIA','3337','610432713147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 08:03:12',0,NULL,3,1,2,1,'\\ ','technology.systems'),(6669,812163263012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',73.3,'eastar4','i.gabunia','igabunia@yandex.ru','Ilya Gabuniya','2-y Novopodmoskovnyy pereulok, 6, Ap.270','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 08:55:10',0,NULL,3,1,3,1,'RA117735746CN\r ','i.gabunia\rWLIN001+WLIN014+MOCN001\r再发一个622ANXHMW通用版\r一个Bracket of half intel 5300 \r\r'),(6670,812163480012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.4,'eastar4','pat1975','ebay@grubers.de','Patrick Gruber','Tannenberger Str. 62/125','Reutlingen','','GERMANY','72760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 08:55:45',0,NULL,3,1,2,1,'\\ ','pat1975\rHP 6pin 1.0 12cm '),(6671,731566602011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',44.79,'eastar4uk','sullegrisen','kell@khess.dk','Kell Hess','Vedbendvej 9','Hellerup','Hellerup','DENMARK','2900','4529236585','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 09:56:14',0,NULL,3,1,3,1,'RA117735984CN ','sullegrisen\rGLSG001'),(6672,731536255011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','ianefraser','ian@ianfraser.com','Ian Fraser','3 Hillcrest Rd<br>C/O Barkan','Manalapan','NJ','UNITED STATES','07726-4203','(646) 217-0951','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 10:11:03',0,NULL,3,1,1,1,'、 ','ianefraser'),(6673,545095024003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',29.8,'cnfaner','ilikedell','ziafarooq@ymail.com','Muhammad Farooq Zia','Goeschlgasse 12/7','WIEN','','AUSTRIA','1030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 10:20:19',0,NULL,3,1,3,1,'RA117735825CN ','ilikedell\rWLAT007'),(6674,812217423012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','llaurino09','luiz_laurino@hotmail.com','Luiz Laurino','Rua Historiador Werneck da Silva, 235<br>Bloco 02 apto 1008','Rio de Janeiro','RIO DE JANEIRO','BRAZIL','22790-832','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 12:28:09',0,NULL,3,1,3,1,'RA117735967CN ','llaurino09\rGLSG001*3'),(6675,812223562012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',5,'OTAP001',47.45,'eastar4','14594062','dav_a@mail.ru','Andrey Davydenko','Dzerjinskogo st., 4a-211','Kemerovo','','RUSSIAN FEDERATION','650000','(3842)45-31-15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 12:43:53',0,NULL,3,1,3,1,'RA117735777CN ','14594062\rOTAP001'),(6676,598761730013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',71.94,'eastar4','dchiong430','davidson_chiong@yahoo.com','Davidson Chiong','Grace Compound Bernad Subdivision','Ozamiz City','Misamis Occidental','PHILIPPINES','7200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 13:08:56',0,NULL,3,1,3,1,'RA117735732CN ','dchiong430\rMOSA002'),(6677,812248169012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','captqbec','captqbec@yahoo.com','Mike Barbaro','621 des Erables','Mascouche','QC','CANADA','J7L 3Z4','(450) 968-1199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 13:54:17',0,NULL,3,1,3,1,'RA117735848CN ','captqbec\rMOLO002\r新的'),(6678,731640537011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','duckwallystops','laaten@gmx.de','Peter van Laaten','Wesselyring 21','Hamburg','','GERMANY','22297','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 14:31:25',0,NULL,3,1,2,1,'、 ','duckwallystops'),(6679,0,110708836989,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',31.01,'buysia','rduff123','rduff@bellsouth.net','W Rex Duff','601 Doe Run Dr<br>Ste 2','Mount Sterling','KY','UNITED STATES','40353-9097','(859) 497-0800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 14:37:59',0,NULL,3,1,1,1,'、 ','rduff123'),(6680,598783762013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','proudcroat911','anankin.skywalker@gmail.com','Filip Kobi','Zagrebacka 61','Lekenik','Sisacko-moslavacka zupanija','CROATIA','44272','00385981939555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 14:43:21',0,NULL,3,1,2,1,'、 ','proudcroat911'),(6681,812251808012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'eastar4','honey130759','gunnar.bruhns@alice-dsl.net','Gunnar Bruhns','Saseler Str.90','Hamburg','Hamburg','GERMANY','22145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 14:43:30',0,NULL,3,1,3,1,'RA117736004CN ','honey130759\rGLOT001\r兼容型3D眼镜 通用型'),(6682,812270874012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','tconrado28','tconrado@hotmail.com','Thiago Conrado','Rua Harrisson José Borges 1962','Campo Mourão','Paraná','BRAZIL','87303-130','51 44 3016 3510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 15:06:04',0,NULL,3,1,2,1,'、 ','tconrado28'),(6683,0,110710654976,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',37.03,'buysia','hairymerkin','aaaction@bellsouth.net','Christopher Nadeau','5338 NW Lamoore Ln','Port Saint Lucie','FL','UNITED STATES','34983-5334','(954) 673-6606','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 15:40:36',0,NULL,3,1,1,1,'、 ','hairymerkin'),(6684,731669015011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',207.99,'eastar4','jeffreyxinlu','jeffreyxinlu@hotmail.com','Xin LU','6 Yorkton Blvd','Markham','ON','CANADA','L6C0J9','(905) 479-0096 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 15:53:15',0,NULL,3,1,3,1,'RA117717305CN ','jeffreyxinlu\rOTSO004*3\r盒装的'),(6685,812293016012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','mikejvf','hotmikej@hotmail.com','Mihhail Fjodorov','Anne 87-41','Tartu','','ESTONIA','50705','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 15:59:18',0,NULL,3,1,2,1,'、 ','mikejvf\r欧标'),(6686,545166799003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','flyinhgh','flyinhgh2002@gmail.com','Robert F. Smith','2 Dempsey Rd','Ansonia','CT','UNITED STATES','06401-2908','(203) 362-8920','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-04 16:12:56',0,NULL,3,1,1,1,'、 ','flyinhgh'),(6687,731675688011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','raxmaster1','rakesh@medspda.com','Rakesh Patel','50 upper Marshall Street','Birmingham','West Midlands','UNITED KINGDOM','b1 1la','07920884693','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-04 16:16:18',0,NULL,3,1,3,1,'RA117735729CN ','raxmaster1\r红边优联\rRELO003'),(6688,0,110710653955,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',30.01,'buysia','brernurse','supernurse911@gmail.com','Timothy Wolfe','444 Duval Cts','Twin Falls','ID','UNITED STATES','83301-5367','(208) 944-4426','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 16:36:33',0,NULL,3,1,1,1,'、 ','brernurse'),(6689,543879587003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',3,'MOOE002',149.97,'cnfaner','arthurreis','arthurrs@ig.com.br','Arthur Reis Santos','Rua Otto Bender, 137<br>Mandaqui','São Paulo','SP','BRAZIL','02418-030','(5511) 8119-6120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 16:42:41',0,NULL,3,1,3,1,'RA117717402CN ','arthurreis\rMOOE002\r发OEM的\r客户要分开发\rRA117717393CN\rRA117717314CN\r'),(6690,731689769011,320721819844,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',17.99,'eastar4','fglnyew','ch_0c@hotmail.com','FUNG LAN YEW','SIM YAW SHENG SDN BHD<br>NO 150 JALAN CHESTER','TAWAU','SABAH','MALAYSIA','91000','013-5528198','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-04 16:47:35',0,NULL,3,1,2,1,'\\ ','fglnyew\r草莓伞'),(6691,812330286012,220741062544,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'eastar4','champion5435','jsn_champion@yahoo.co.uk','Jason Champion','37 Upper Shott<br>Cheshunt','Waltham Cross','Hertfordshire','UNITED KINGDOM','EN7 6DR','07811345877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 17:22:37',0,NULL,3,1,2,1,'、 ','champion5435\r英标'),(6692,545196459003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',15,'cnfaner','850851a','adoni_g@hotmail.com','giorgos adoni','26 dimokratias','larnaca','','CYPRUS','7020','0035799595482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 17:56:14',0,NULL,3,1,3,1,'RA117735803CN ','850851a\rHSNO008\r欧标'),(6693,812352890012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','bigbb','jjaluf@yahoo.com','Javier Jaluf','Nestor Garat 378','Concordia','Entre Rios','ARGENTINA','3200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 18:08:04',0,NULL,3,0,2,1,'、 ','bigbb\r发210TS'),(6694,731726113011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','lethanhlam','lam@30sec.be','thanh Lam Le','Rue vandenboogaerde 29','bruxelles','','BELGIUM','1080','0497-539534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 18:09:28',0,NULL,5,0,18,0,' ','lethanhlam\r客户要撤单 已经退款'),(6695,598852612013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','darius13231','darius.z@splius.lt','Darius Zarauskas','Dariaus ir Girėno g. 44-11','Radviliskis','','LITHUANIA','LT-82139','+37061644848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 18:36:02',0,NULL,3,1,3,1,'RA117735851CN ','darius13231\r欧标\rHSNO019'),(6696,812373582012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','hbohbo','hbo2000@t-online.de','Horst Bormann  c/o Netzlink GmbH','Große Elbstraße 145b','Hamburg','','GERMANY','22767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 18:45:52',0,NULL,3,1,2,1,'、 ','hbohbo'),(6697,812378402012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','kochedolka1','kochedolka@gmail.com','Olga Kochedykova','Posadskogo, 215<br>app. 197','Saratov','Saratovskaya','RUSSIAN FEDERATION','410005','(7905)328-2098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 18:54:01',0,NULL,3,1,2,1,'\\ ','kochedolka1\r七色彩虹伞'),(6698,731768567011,320721457656,'New lady lace trim sun/rain stick Umbrella Brown',1,'UM00011',24.99,'eastar4','nina*engel','ninaengelstad@gmail.com','Nina Engelstad','Bergensgata 18','Oslo','','NORWAY','0468','0047 97676689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 19:34:23',0,NULL,3,1,2,1,'\\ ','nina*engel\r蕾丝花边伞 '),(6699,731775432011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','jelcompt','john.loscombe@btinternet.com','John Loscombe','16 St Mary\'s Road','Leamington Spa','Warwickshire','UNITED KINGDOM','CV31 1JW','01926434010','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-04 19:48:29',0,NULL,3,1,3,1,'RA117735817CN ','jelcompt\rWLAP002\r旧的'),(6700,550878702004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',104.99,'cnfaner','0digy','jorisslawinski@hotmail.com','Slawinski Mireille','34 rue de montbron','Angoulême','Charente','FRANCE','16000','0545957662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 19:50:24',0,NULL,3,1,3,1,'RA117735975CN ','0digy\rEXLO001'),(6701,731795224011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','s_g39','sergey.kudriakov@hotmail.com','Sergey Kudriakov','100 Stockton St<br>Apt 75','Chelsea','MA','UNITED STATES','02150-2243','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 20:32:22',0,NULL,3,1,1,1,'、 ','s_g39'),(6702,812436808012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','nerex58','dellbios@hotmail.com','MASTER SERVICES / ALLAN FLORES MARTINEZ PMB #81','MALL DE LAS AGUILAS 455 SOUTH BIBB STE 740','EAGLE PASS','TX','UNITED STATES','78852','864 618 1904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 20:44:33',0,NULL,3,1,1,1,'、 ','nerex58\r'),(6703,550900809004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',31.95,'cnfaner','noki_72','noki_72@yahoo.de','Marcus Tuppat','Nahestr 3','Recklinghausen','','GERMANY','45663','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:01:21',0,NULL,3,1,3,1,'RA117735865CN ','noki_72\rWWSI002'),(6704,812453667012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',3,'CASS002',60.9,'eastar4','silfides','pablo.romerogiron@hotmail.com','Enrique Romero-Giron Gomez-Pablos','C/ Luis Doreste Silva 52, 3º-1','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','928249978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:21:07',0,NULL,3,1,3,1,'RA117735794CN ','silfides\rCASS002+CASS001+CASS003\r一共买了三个CAB-SS-2660\r\r三个CAB-SS-2626\r \r四个CAB-6060\r'),(6705,598909429013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','silfides','pablo.romerogiron@hotmail.com','Enrique Romero-Giron Gomez-Pablos','C/ Luis Doreste Silva 52, 3º-1','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','928249978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:23:10',0,NULL,3,1,17,0,NULL,'silfides'),(6706,812463201012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','supep','prubio@stiv.es','Josep Rubio Vilà','C/ Matagalls, nº 15','La Roca del Vallès','Cataluña','SPAIN','08430','605647106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:42:13',0,NULL,3,1,3,1,'RA117735919CN ','supep\r盒装的\rGLSG001*2'),(6707,545268393003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.9,'cnfaner','dogmjy','dogmjy@mts.net','Joel Painter','540 Goodale Dr','Portage la Prairie','MB','CANADA','R1N 3M6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:43:54',0,NULL,3,1,3,1,'RA117735896CN ','dogmjy\rUDAP001'),(6708,731833754011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','uterrorista','agentbretman.site@gmail.com','João David Ramos Coelho Gonçalves','Pinheiro','Pinheiro','Soure','PORTUGAL','3130-544','912481685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 22:11:20',0,NULL,3,1,3,1,'RA117735882CN ','uterrorista\rUDAP001'),(6709,812478995012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','blade715','ryan.brittner@gmail.com','Ryan T Brittner','4429 Padwick Road','Regina','SK','CANADA','S4W 0C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 22:28:32',0,NULL,3,1,2,1,'、 ','blade715'),(6710,812487571012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',26.9,'eastar4uk','rhapsody-i-blue','devroet@hetnet.nl','J. de Vroet','Zwartsluisje 117','ZUID-BEIJERLAND','','NETHERLANDS','3284LM','0031642404496','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 23:03:07',0,NULL,3,1,3,1,'RA117735834CN ','rhapsody-i-blue\rOTGR001+OTGR002'),(6711,731860292011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT004',107.98,'eastar4','mulisha007','joshbuter@yahoo.com','Josh C Buter','303 Tecumseh Street','Brooklyn','MI','UNITED STATES','49230','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 23:57:08',0,NULL,3,1,1,1,'、 ','mulisha007\r兼容型3D眼镜  samsung 专用'),(6712,598943251013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','hugohugo94','lauren-s2@hotmail.com','Joanne Klymenko','4 Austin Cres<br>Pasoe Vale','Melbourne','Victoria','AUSTRALIA','3044','0393067023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 00:08:43',0,NULL,3,1,3,1,'RA117717212CN ','hugohugo94\rOTSO004*4'),(6713,598952414013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.4,'eastar4','debmalya_ghosh','debmalya@optonline.net','Debmalya Ghosh','28 Rachel Ter','Piscataway','NJ','UNITED STATES','08854-5326','(732) 543-1709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 01:07:00',0,NULL,3,1,1,1,'、 ','debmalya_ghosh\racer 4pin1.25 15cm '),(6714,731874887011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','jsk.capital','chrislee@jskcap.com','Chris Lee','c/o JSK Capital Partners<br>UOB Plaza 1, 80 Raffles Place, 35th Floor','default','','SINGAPORE','048624','6581984129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 01:11:02',0,NULL,3,1,3,1,'RA117735879CN ','jsk.capital\rHSLO001'),(6715,731876945011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','hhchua','lawrence.infinity@gmail.com','Chua Lawrence','68 Toh Tuck Road, Highgate Condo, #03-09','Singapore','','SINGAPORE','596733','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 01:22:29',0,NULL,3,1,11,1,'、 ','hhchua\rCCGR001'),(6716,812528317012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','kenhwang78','free_cloud33@hotmail.com','Zell','Blk 1003, Bukit Merah Central<br>#04-34','default','','SINGAPORE','159836','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 01:59:35',0,NULL,3,1,3,1,'RA117735763CN ','kenhwang78\rOTGR001+OTGR002'),(6717,731887982011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','kangpartners','richard@yoc.com.au','Zhexin  Kang','Unit 803 / 76 Rawson Street','Epping','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 02:16:22',0,NULL,3,1,3,1,'RA117735998CN ','kangpartners\rGLOT004\r兼容型3D眼镜  samsung 专用'),(6718,812532606012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',3,'HSNO006',44.91,'eastar4','emaranhao','ely.maranhao@gmail.com','ely maranhao filho','area octogonal 8<br>bl b ap 301','brasilia','distrito federal','BRAZIL','70660082','+556133628335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 02:20:40',0,NULL,3,1,3,1,'RA117735785CN ','emaranhao\rHSNO006'),(6719,694188535001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','boguslawsmr','boguslawsmorczewski@hotmail.com','Boguslaw Smorczewski','6418 Taylor Dr','Woodridge','IL','UNITED STATES','60517-1321','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 03:44:56',0,NULL,3,1,1,1,'、 ','boguslawsmr'),(6720,0,110708209641,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',63,'buysia','chazzjacobs','cadodgeguy@aol.com','Charles E. Jacobs','1817 Scenic View Dr','Bakersfield','CA','UNITED STATES','93307','(661) 303-9666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 03:58:49',0,NULL,3,1,1,1,'、 ','chazzjacobs'),(6721,731909563011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',2,'HSJA005',35.98,'eastar4','roadsters_3','robinson.araya.huerta@gmail.com','Robinson  Araya Huerta','Senador Raul Marin Balmaceda #167, Poblacion Cobresal','Ovalle','Ovalle','CHILE','1841733','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 04:19:46',0,NULL,3,1,3,1,'RA117717376CN ','roadsters_3\rHSJA005\r盒装的'),(6722,731910520011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',9.49,'eastar4','peterbuoi','peter.n.bui@gmail.com','Peter Bui','4708 Powder Mill Rd','Beltsville','MD','UNITED STATES','20705-1931','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 04:26:14',0,NULL,3,1,1,1,'、 ','peterbuoi'),(6723,731910901011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','oritime','cosenemoglu@hotmail.com','orhan senemoglu','meclisi mebusan caddesi no:45<br>findikli - kabatas - beyoglu','Istanbul','','TURKEY','34427','+90212 334 1014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 04:36:07',0,NULL,3,1,3,1,'RA117735922CN ','oritime\rGLSG001*2'),(6724,598983614013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','y2kkid','hat_guy39@yahoo.com','Hugh Reynolds','924 W Bower Ave','Harrison','AR','UNITED STATES','72601-3250','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-05 04:55:09',0,NULL,3,1,1,1,'、 ','y2kkid'),(6725,807508285012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','amahgoub','a.mahgoub@hotmail.com','Ahmed Mahgoub','29 SchlotWeg<br>Asseln-Mitte','Dortmund','','GERMANY','44319','015778488464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 05:32:02',0,NULL,3,1,3,1,'RA117735953CN ','amahgoub\rOTIN005'),(6726,694203792001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','hopsalots_toybox','s_kohlrusch@earthlink.net','Sheri Kohlrusch','11167 5th St NE','Blaine','MN','UNITED STATES','55434-1733','(763) 757-4881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 05:48:47',0,NULL,3,1,1,1,'、 ','hopsalots_toybox'),(6727,731936577011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','erwintoolman','erwinduffels@hotmail.com','Erwin Duffels','5757 Woodman Ave<br>Apt 102','Van Nuys','CA','UNITED STATES','91401-4488','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 07:02:51',0,NULL,3,1,1,1,'、 ','erwintoolman'),(6728,550984045004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',30.99,'cnfaner','wathitlim','wathityth@gmail.com','Wathit Chotimapruk (Yokogawa)','799 Rama9 Road.<br>Bangkapi, Huaykwang','Bangkok','','THAILAND','10310','662-7158600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 07:09:00',0,NULL,3,1,3,1,'RA117717504CN ','wathitlim\rWWSI005'),(6729,812594487012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','albin_prinz','pavel-haustov@pavel-haustov.com','Pavel Haustov','Bolshaya Akademicheskaya, d.15, k.1, kv.159','Moscow','','RUSSIAN FEDERATION','125130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 07:53:45',0,NULL,3,1,2,1,'、 ','albin_prinz'),(6730,731959233011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','gregdellas','dellas@cytanet.com.cy','Gregory Dellas','PO BOX 28160<br>STROVOLOS','NICOSIA','','CYPRUS','CY-2091','+35799364126','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 08:54:37',0,NULL,3,1,3,1,'RA117719071CN\r ','gregdellas\rUDAP001'),(6731,812609922012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','neiru37','neil_bantoc@yahoo.com','Neil Armand Bantoc','11017 Palm Drive Faculty Village','Los Baños','Laguna','PHILIPPINES','4031','0495366521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 09:02:45',0,NULL,3,1,3,1,'RA117719522CN\r ','neiru37\rOTPL001\r  '),(6732,694246697001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','stephenplummer','steve.plummer@kentz.com','Stephen Plummer DOH 3551','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 09:40:53',0,NULL,3,1,1,1,'\\ ','stephenplummer'),(6733,551003622004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',104.99,'cnfaner','burriach2004','jdavi2004@hotmail.com','Jordi Davi Salvaña','Pg. de Gracia 87, planta 6 (Avaya)','Barcelona','Barcelona','SPAIN','08008','609232291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 09:41:47',0,NULL,3,1,3,1,'RA117717478CN\r ','burriach2004\rEXLO001'),(6734,551013350004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','gatitopeke','djleo_86@hotmail.com','daniel diaz','san cosme y san damian 39','torredonjimeno','Andalucía Ceuta y Melilla','SPAIN','23650','600123456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 10:46:48',0,NULL,3,1,3,1,'RA117719045CN\r ','gatitopeke\rWLAT001+ANTY002'),(6735,812640435012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','jongankh2011','jongankh@yahoo.com','gan jon','341- jalan anggerik 9, tmn kulai utama<br>81000, kulaijaya.','johore','johore','MALAYSIA','81000','0176078178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 11:16:58',0,NULL,3,1,2,1,'、 ','jongankh2011'),(6736,551018567004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',104.99,'cnfaner','havanna1234','eichinger.daniel@web.de','Daniel Eichinger','Löffelholzweg 2','Heroldsbach','','GERMANY','91336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 11:20:07',0,NULL,3,1,3,1,'RA117717481CN\r ','havanna1234\rEXLO001'),(6737,812643618012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','haloxy','tadmef@gmail.com','Dmytro Tarasyuk','Zodchih str.<br>h.62, ap.323','Kyiv','','UKRAINE','03170','+38(063)4932481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 11:20:10',0,NULL,3,1,2,1,'\\ ','haloxy\r\r\r'),(6738,812645049012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','schumiferalx','alexandrosgar@gmail.com','Alexandros Garouniatis','Ag. Gerasimos Street, 18','Athens','','GREECE','15771','6944686292','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 12:11:36',0,NULL,3,1,3,1,'RA117719200CN\r ','schumiferalx\rHSSE004'),(6739,732007613011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','ultimate_gatsu8','ultimate_gatsu@hotmail.com','victor jose ladero covelo','C/Estadella 17 Atic2º','Barcelona','Cataluña','SPAIN','08030','618096129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 12:17:49',0,NULL,3,1,3,1,'RA117719054CN\r ','ultimate_gatsu8\rGLOT004\r兼容型3D眼镜  samsung 专用'),(6740,812662028012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','eduardofratari','lemeefp@yahoo.com.br','Eduardo Fratari Paes Leme','R antenor leite da Cunha 399, ap 35a, vila Partênio','Mogi das Cruzes','São Paulo','BRAZIL','08773-395','+551182172881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 12:34:00',0,NULL,3,1,2,1,'\\ ','eduardofratari'),(6741,597306113013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',20,'WLAT001',339.8,'eastar4','ubiquitainc','ebay@ubiquita.com','Leith Martin','6971 Monte Rosa Ave','Las Vegas','NV','UNITED STATES','89120-3018','(702) 446-0901','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 13:04:16',0,NULL,3,1,1,1,' 、','ubiquitainc'),(6742,732022648011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','xtrimal','xtrimal@gmail.com','Anatoliy Afinogenov','Kolomenskaya st. 9 -180','Moskva','','RUSSIAN FEDERATION','115142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 13:11:51',0,NULL,3,1,2,1,'\\ ','xtrimal'),(6743,732023989011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','microsvc','bob@microsvc.com','Robert O\'Neill','1900 W Macarthur St<br>St Gregory\'s University, BH308','Shawnee','OK','UNITED STATES','74804-2403','(405) 395-7111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 13:16:50',0,NULL,3,1,1,1,'、 ','microsvc\racer 6pin1.25 23cm'),(6744,599058491013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','nimalanimalaranepura21','nimalaranepura21@gmail.com','Nimala Ranepura','Block 130,Simei Street 1,<br>#02-234','Singapore','','SINGAPORE','520130','82181482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 13:25:36',0,NULL,3,1,3,1,'RA117719010CN\r ','nimalanimalaranepura21\rCASS003\rCAB-6060'),(6745,732042027011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','b8612','bohumil.izak@gmail.com','Bohumil Izak','3 Cecil Street<br>Apt. 1','Limerick','Limerick','IRELAND','default','0851323567','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 14:19:00',0,NULL,3,1,3,1,'RA117719068CN\r ','b8612\rUDAP001'),(6746,732041993011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',3,'GLOT004',161.97,'eastar4','riketsukirai','riketsukirai@hotmail.com','Jesus Rivera','Nueva St. E-10 Villa Clementina','Guaynabo','PR','UNITED STATES','00969-5006','(787) 365-8200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 14:19:14',0,NULL,3,1,1,1,'\\ ','riketsukirai\r兼容型3D眼镜  samsung 专用'),(6747,812718142012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','paulf2208','forstpf481@tiscali.co.uk','Paul Forster','2 Charlotte Court','Calne','Wiltshire','UNITED KINGDOM','sn11 9rg','01249811215','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 15:24:48',0,NULL,3,1,3,1,'RA117719156CN\r ','paulf2208\rHSPL011\r英标'),(6748,732064822011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','elzacateca','erickbaez_11@hotmail.com','Erick Baez','2861  DEWEY AVENUE APT 2','Bronx','NY','UNITED STATES','10465','(347) 293-6364','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 15:30:50',0,NULL,3,1,1,1,'\\ ','elzacateca\racer 8pin1.00 8cm'),(6749,551066118004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','alsur7','a.sursyakov@mail.ru','Andrey Sursyakov','Novosibirskaya<br>35 - 212','Krasnoyarsk','','RUSSIAN FEDERATION','660028','+79130303093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 15:33:36',0,NULL,3,1,3,1,'RA117719111CN\r ','alsur7\rRCLO006\r新的'),(6750,732069833011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','tomislav2606','tommy001@net.hr','Tomislav Plavšić','Fra Bonina 4b','Split','','CROATIA','21000','0038521386397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 15:46:28',0,NULL,3,1,2,1,'\\ ','tomislav2606\r欧标\r盒装的'),(6751,551070590004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','frogmoi','moifrog@cs.com','JP Carcenac','214 S Shannon Dr','Woodstock','IL','UNITED STATES','60098-9422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-05 15:53:04',0,NULL,5,1,18,1,NULL,'frogmoi 已经退款'),(6752,732078269011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','fat.kids.rus','fatkids4me@gmail.com','jonathan clark','33252 cherry ave','mission','BC','CANADA','v2v2v2','(604) 226-1520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 16:12:20',0,NULL,3,1,2,1,'\\ ','fat.kids.rus'),(6753,732077945011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',2,'CASS001',17.4,'eastar4','buy_and_buy_alot','romantic.handsome25@yahoo.com','saurabh joshi','b/10 om malayagiri<br>shantivan','borivali east','MH','INDIA','400066','09930993331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 16:12:25',0,NULL,3,1,2,1,'\\ ','buy_and_buy_alot'),(6754,694016603001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','1jpc-093','aherts@gmail.com','ANDRIY GERC','Poleva st. 7','Ternopil','','UKRAINE','46001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 16:41:18',0,NULL,3,1,3,1,'RA117719037CN\r ','1jpc-093\rOTAM001'),(6755,731670578011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','chrisjj1','spyrouchr@cablenet.com.cy','CHRISTOS SPYROU','ARISTOKYPROU 49, F401','STROVOLOS','','CYPRUS','2008','0035722463163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 16:45:03',0,NULL,3,1,3,1,'RA117719139CN\r ','chrisjj1\rGLSG001'),(6756,599110114013,230576481551,'10 pcs AUI Ethernet 10Base-T RJ45 Transceiver track#',1,'TRMX003*10',83,'eastar4','sureshmjoshi','sureshjoshi10@yahoo.com','Suresh Joshi','SM Networks<br>1225, Hemkunt Chambers , 89,','Nehru Place , New','Delhi','INDIA','110019','09810074538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 16:56:13',0,NULL,3,0,3,1,'RA117719142CN\r ','sureshmjoshi\rTRMX003*10\r发210TS'),(6757,732053016011,320665720437,'New Genuine Sony Ericsson HBH-608 Bluetooth  Headset',1,'HSSE007',21.95,'eastar4','fernand09fernand','fernranger@live.ca','FERNAND RANGER','1727 DES ECORES','TERREBONNE','QC','CANADA','J6X3K9','(450) 964-8924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 17:38:57',0,NULL,3,1,2,1,'\\ ','fernand09fernand'),(6758,812788191012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',258,'eastar4','ali-al.ali','ali.alali@terra.es','Alí Alali','C/Sant Bertran, 9- 2º 1ª','Barcelona','Cataluña','SPAIN','08001','677302796','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 18:09:02',0,NULL,3,1,4,1,'YW865908456CN ','ali-al.ali\r'),(6759,812796099012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','nurgle-sc','tonygannon@gmail.com','Tony Gannon','187 Lorfield Dr','Amherst','NY','UNITED STATES','14226-4916','(716) 200-0827','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 18:22:57',0,NULL,3,1,1,1,'\\ ','nurgle-sc\r新的'),(6760,732136362011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','opala41','juliocohen@gmail.com','Julio Cohen','Rua Mario Covas Jr 335<br>Apto 107','Rio de Janeiro','RJ','BRAZIL','22631030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 18:35:22',0,NULL,3,1,3,1,'RA117719125CN\r ','opala41\rUDAP001+BAZA001\r再发一个NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER'),(6761,812805722012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','ivandaudt','ivandaudt@yahoo.com.br','Ivan  Daudt','Rua Eng. Paul Werner, 936','Blumenau','Santa Catarina','BRAZIL','89030-101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 18:45:24',0,NULL,3,1,3,1,'RA117719108CN\r ','ivandaudt\rOTRA001'),(6762,599146266013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',59.99,'eastar4','opala41','juliocohen@gmail.com','Julio  Cohen','Rua Mario Covas Jr 335 - Apto 107 - Barra da Tijjuca','Rio de Janeiro','RJ','BRAZIL','22630-031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 18:59:02',0,NULL,3,1,17,0,NULL,'opala41'),(6763,812629242012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','gytax01','egagytis@gmail.com','Egidija Valentinaviciene','Kursiu takas 15','Palanga','','LITHUANIA','00317','869850099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 18:59:45',0,NULL,3,1,2,1,'\\ ','gytax01'),(6764,812826345012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','ilan_pal','ilan.palatnik@gmail.com','Ilan Palatnik','Keren Hayesod<br>3','Givat-Shmuel','tel aviv','ISRAEL','54051','+972 52332269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 19:22:20',0,NULL,3,1,2,1,'\\ ','ilan_pal'),(6765,599160498013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','iff27','ivo001@hot.ee','Ivo Hansing','Õuna 4-5','Elva','Tartumaa','ESTONIA','61503','3725117001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 19:34:53',0,NULL,3,1,2,1,'\\ ','iff27\r欧标'),(6766,812838455012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',21.9,'eastar4uk','bluefrogglum','toadface@rocketmail.com','Mr C Millis','54 Salisbury Road','Chatham','Kent','UNITED KINGDOM','ME4 5NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 19:44:53',0,NULL,3,1,3,1,'RA117719099CN\r','bluefrogglum\rWWSI005+ANCN001'),(6767,732208058011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','tarmo_renter','tarmo@saurus.ee','Tarmo Renter','Kunderi 19-11','Tallinn','Harjumaa','ESTONIA','10121','372 51 64 356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 21:07:35',0,NULL,3,1,2,1,'\\ ','tarmo_renter'),(6768,812889470012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','seosangyun','cordless01@hanmail.net','Sang Yun, Seo','313 3A Colleage of Engineering, CNU<br>300 YongBong-Dong, Buk-Gu','Gwangju','','KOREA,REPUBLIC OF','500757','82625300462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 21:31:04',0,NULL,3,1,2,1,'\\ ','seosangyun'),(6769,812902582012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','defis99','defis@quitomail.com','Dmitri Fissakov','Amazonas y NNUU<br>CC UNCORNIO, loc 243','Quito','pc','ECUADOR','593','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 21:58:03',0,NULL,3,1,3,1,'RA117719085CN\r ','defis99\rOTRA001'),(6770,732237609011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','653johnk','crazy4trolls@msn.com','John Kilgore','2160-74st','Brooklyn','NY','UNITED STATES','11204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 22:30:09',0,NULL,3,1,1,1,' \\','653johnk\r兼容型3D眼镜  samsung 专用'),(6771,732265205011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',39.99,'eastar4','zvikaross','zvika@rossnet.co.il','Zvika Ross','11 Emek Haella St.<br>P.O.Box 15125','Tzur Yigal','Kochav Yair','ISRAEL','44862','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 00:22:53',0,NULL,3,1,3,1,'RA117719023CN\r ','zvikaross\rHSJA011'),(6772,551211013004,140550602524,'New PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',35,'cnfaner','phantomswordfish','phantomswordfish@yahoo.com','Lee Smith','40 Gemstone Ln','Acworth','GA','UNITED STATES','30101','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 01:44:17',0,NULL,5,0,18,1,NULL,'phantomswordfish  已经退款'),(6773,732294197011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.99,'eastar4','ccopas','cwcopas@yahoo.com','Charles W. Copas','11905 Escalante Ct','Reston','VA','UNITED STATES','20191','(703) 391-8460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 02:29:24',0,NULL,3,1,1,1,'\\ ','ccopas'),(6774,812985554012,220775617210,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset',1,'HSPL014',19.99,'eastar4uk','doctorpatten','activehealthsystem@juno.com','Jim Patten','116 S 11th Ave','Yakima','WA','UNITED STATES','98902-3204','(509) 248-2321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 03:04:36',0,NULL,5,0,18,1,NULL,'doctorpatten 已经退款'),(6775,812181285012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',77.9,'eastar4','chestiwibowo','chrisma@ymail.com','Chrisma\'ali HESTIWIBOWO','Jakarta International School Jl. Terogong Raya No. 33<br>Cilandak','Jakarta Selatan','Jakarta Raya','INDONESIA','12430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 03:33:27',0,NULL,3,1,3,1,'RA117719187CN ','chestiwibowo\rOTSO002'),(6776,694557629001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','manoloandreu','manolo_69@msn.com','Manuel Andreu','5566 Aberdeen St.','Vancouver','BC','CANADA','v5r 4m6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 03:59:25',0,NULL,3,1,3,1,'RA117719195CN ','manoloandreu\rBR3D003'),(6777,732313240011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','auto-superstore','davids@sheroldsalmon.com','David Salmon','506 Turner McCall Blvd SW','Rome','GA','UNITED STATES','30165','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 04:03:19',0,NULL,3,1,1,1,'、 ','auto-superstore'),(6778,813009192012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','classic0228','classic0228@nate.com','DONGPIL YOO','Bukbyeon-dong<br>Pungnyeon Maeul Daelim Apt. 302- 704','Gimpo Si','Gyeonggi-Do','KOREA,REPUBLIC OF','415-712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 04:58:03',0,NULL,3,1,2,1,'、 ','classic0228'),(6779,813031687012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','lord_ratso','gary@extremegameservers.co.uk','Gary Spink','81 Woollin Avenue<br>West Ardsley','Wakefield','West Yorkshire','UNITED KINGDOM','WF31EP','01132532468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 06:57:58',0,NULL,3,1,2,1,'、 ','lord_ratso'),(6780,551256304004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','benkejan','benkej@t-online.hu','Benke Janos','Bercsenyi Miklos utca 92/a','Budapest','','HUNGARY','1188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 07:41:19',0,NULL,3,1,3,1,'RA117719227CN ','benkejan\rWLAT001+ANTY002'),(6781,812830608012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',50,'eastar4','mlendsaar','marek.lendsaar@gmail.com','Marek Lendsaar','Tiigi tee 7a-14<br>Rae vald','Harjumaa','','ESTONIA','75301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 07:58:42',0,NULL,3,1,3,1,'RA117717583CN \rRA117719289CN','mlendsaar\rWWOT003\r通用'),(6782,732355684011,320585234549,'New Intel 512ANX 5150 Half Mini PCI-E WIFI Card+antenna',1,'WLIN004+ANTY001',27.98,'eastar4','axk_2005','krylov@axkhost.net','Alexander Krylov','34 Plehanova str. Apt. 3','Lipetsk','RU','RUSSIAN FEDERATION','398050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 08:05:38',0,NULL,3,1,2,1,'、 ','axk_2005'),(6783,813055237012,220451372871,'Benq R55  Bluetooth Module 2.0 EDR+cable',1,'BTBE2004',12.5,'eastar4','rabe-fe','dr.m.lohse@t-online.de','Dr.Markus Lohse','Fliederstr.15','Kissing','','GERMANY','86438','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 08:46:11',0,NULL,5,1,2,1,' ','rabe-fe 先不发货了 等客户问起来 退款或者补发'),(6784,599310781013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','lrachel2007','lrachel2007@yahoo.com','Rachel Lei','329 S 6th St','Alhambra','CA','UNITED STATES','91801-3602','(626) 708-8838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 09:17:00',0,NULL,3,1,1,1,'. ','lrachel2007'),(6785,0,180689800364,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',17.6,'au-buy','miz.mira','miz.mira@yahoo.com','Mira  Budimlic','2/115 Crisp Circuit<br>Bruce','Canberra','Australian Capital Territory','AUSTRALIA','2617','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 09:44:11',0,NULL,5,0,18,0,'','miz.mira\r客户要撤单 已经退款'),(6786,732378652011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',3,'UDAP001',67.77,'eastar4uk','legofiend','ian@sackheads.org','Ian Phillips','19 Chaplains Avenue','Waterlooville','Hampshire','UNITED KINGDOM','PO8 8QL','07970807772','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 09:53:09',0,NULL,3,1,3,1,' RA117719363CN\r','legofiend\rUDAP001'),(6787,813079361012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','franjavi','furanshishouco@gmail.com','Francisco Javier Molina Mendoza','C/ Párroco Hernández Benítez<br>n 34 - San Isidro','Gáldar','Canarias','SPAIN','35460','680660538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 10:27:38',0,NULL,3,1,2,1,' 、','franjavi'),(6788,732387287011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',38.99,'eastar4','georgemckee','gmckee@profit-tech.com','george mckee','19915 Shearwater Point Dr','cornelius','NC','UNITED STATES','28031-7557','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 10:29:56',0,NULL,3,1,1,1,'\\  ','georgemckee'),(6789,732393058011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','lsamanidis2010','lsamanidis@gmail.com','Leandros Samanidis','Bouliagmenis 409','Ilioupoli Athens','Greece Athens','GREECE','16346','+302109941048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 10:53:28',0,NULL,3,1,3,1,'RA117719275CN ','lsamanidis2010\rGLSG001*2'),(6790,599326456013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','racerx311','racerx@htc.net','Kevin Caby','236 Charles St','Red Bud','IL','UNITED STATES','62278-1305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 10:54:00',0,NULL,3,1,1,1,'\\  ','racerx311'),(6791,599326175013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','dima17091970','dmitry17091970@mail.ru','Дмитрий Баранов','Пушкинская, д.130. кв.222.','Ижевск','','RUSSIAN FEDERATION','426077','8-912-856-74-24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 10:56:17',0,NULL,3,1,3,1,'RA117719394CN\r ','dima17091970\rOTSO004*4\r盒装的'),(6792,813092808012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','mrhandler','a.suatoni@gmail.com','Andrea Suatoni','Calle Santiago 36 2F','Alcalá de Henares','Madrid','SPAIN','28801','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 11:15:21',0,NULL,3,1,2,1,' 、','mrhandler'),(6793,732398240011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.7,'eastar4','ptilous58','jlpmv@wanadoo.fr','jean-louis potiron','4 rue jean moulin','auneau','Centre','FRANCE','28700','0623516729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 11:16:18',0,NULL,3,1,2,1,' 、','ptilous58'),(6794,732416205011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ufoounek','miroslav.pyszko@seznam.cz','Miroslav Pyszko','80 Raleigh Way','Peterborough','Cambridgeshire','UNITED KINGDOM','PE3 7LA','07595975616','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 12:22:08',0,NULL,3,1,3,1,' RA117719377CN\r','ufoounek\rRELO003\r红边优联'),(6795,0,180689800361,'New Griffin PowerJolt Dual USB Micro Car Charger',1,'CCGR001',7.99,'au-buy','stevenchensydney','burtonlin1@hotmail.com','Bo Hsu Lin','396 Anzac Pde','Kingsford','New South Wales','AUSTRALIA','2032','0438668078','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 12:23:14',0,NULL,3,1,3,1,'RA117719315CN\r','stevenchensydney\rCCGR001'),(6796,813130308012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','antrary1501','antrary@gmail.com','Alexey Chelnokov','Jurlovskij proezd, 7, 326','Moscow','','RUSSIAN FEDERATION','127490','+7 (916) 1492253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 13:19:04',0,NULL,3,1,3,1,'RA117719332CN\r ','antrary1501\rGLOT001*2\r兼容型3D眼镜 通用型'),(6797,732435275011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','digital_dawg','ddares1@yahoo.ca','Dwayne Myers','1268 Parker Ave NW','Medicine Hat','AB','CANADA','T1A 6X2','(403) 488-1170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 13:28:34',0,NULL,3,1,2,1,'、 ','digital_dawg'),(6798,813150814012,220704730723,'NEW Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','valeri103','radugagiessen@freenet.de','Meier  Valeri','Spenerweg 18b','Giessen','','GERMANY','35394','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 14:22:37',0,NULL,3,1,2,1,'、 ','valeri103\r欧标'),(6799,729962113011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',77.98,'eastar4','lesunderwood','isellcingular@hotmail.com','Leslie R. Underwood','4050 Cascades Blvd<br>Ste B','kent','OH','UNITED STATES','44240','(330) 630-7244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 14:50:24',0,NULL,3,1,1,1,'\\  ','lesunderwood'),(6800,813167838012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','maewest-2009','maewest.31@hotmail.com','miguel','terra alta n.31 La Secuita','TARRAGONA','Cataluña','SPAIN','43765','977623069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 15:12:21',0,NULL,3,1,2,1,'、 ','maewest-2009'),(6801,599388673013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','alisonduarte','alison.duarte@gmail.com','Alison Duarte','Av Lacerda Franco, 1136 apto 5A','São Paulo','São Paulo/Brazil/Centro','BRAZIL','01536001','55-11-32710797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 15:46:39',0,NULL,3,1,2,1,'、 ','alisonduarte'),(6802,599388738013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','nosperated','treblhooks@aol.com','John Landers','59 Evergreen Circle','Surfside Beach','SC','UNITED STATES','29575','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 15:49:45',0,NULL,3,1,1,1,'. 、','nosperated'),(6803,599388788013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',95,'eastar4','corwin32','amberyl32@gmail.com','Beudot cédric','8 Résidence le Coteau','Parcay Meslay','Centre','FRANCE','37210','0247291110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 15:49:53',0,NULL,3,1,3,1,'RA117719329CN ','corwin32\rMOSA006'),(6804,813148038012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','computermanpcslimited','manager@computerman.org.uk','Chris Hatton','6 Woodlands Parade','Ashford','Middlesex','UNITED KINGDOM','TW15 1QD','01784243800','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 15:50:45',0,NULL,3,1,3,1,'RA117719403CN\r ','computermanpcslimited\rOTCN004*10'),(6805,599406605013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','frank31crx','frankvanleeuwen@upcmail.nl','F.van Leeuwen','Steenakker 177','Druten','Gelderland','NETHERLANDS','6651 JD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 16:52:20',0,NULL,3,1,2,1,'、 ','frank31crx'),(6806,813210079012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',104.95,'eastar4','tritan408','tritan408@yahoo.com','Tan T. Nguyen','10085 Annie St','Elk Grove','CA','UNITED STATES','95757-4355','(408) 460-5237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 16:59:45',0,NULL,3,1,1,1,'\\ ','tritan408\r兼容型3D眼镜 通用型'),(6807,813219580012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','omar.avina1','omegarugal20@hotmail.com','OMAR AVIÑA ALVAREZ','Prol. Morelos #1, Col. Los Reyes Acaquilpan<br>Los Reyes La Paz, Estado de México','México','La Paz','MEXICO','56400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 17:20:27',0,NULL,3,1,2,1,' 、','omar.avina1'),(6808,732513892011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','jstrunk333','justinstrunk@gmail.com','Justin Strunk','1847 W 1885 S','Woods Cross','UT','UNITED STATES','84087-2191','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 17:22:12',0,NULL,3,1,1,1,'\\  ','jstrunk333'),(6809,813236750012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','picolezero','picohq@gmail.com','Andre Giovenazzio Buba','Rua Gomes Carneiro, 78 ap 502','Londrina','Parana','BRAZIL','86015240','+554333234808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 18:00:46',0,NULL,3,1,3,1,'RA117719730CN ','picolezero\r客户打了3美金挂号'),(6810,732538004011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','chris2335','t7farms@yahoo.com','chris thompson','561 W 75 S','blackfoot','ID','UNITED STATES','83221-6126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 18:15:15',0,NULL,3,1,1,1,'LK069135104CN ','chris2335、'),(6811,813267211012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','tomj59','tom.r.james@gmail.com','Tom James','24 Church St','Mountain View','CA','UNITED STATES','94041-2356','(650) 400-1641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 18:56:34',0,NULL,3,0,1,1,'. ','tomj59'),(6812,732570704011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','kewlmart','martynoel@gmail.com','Martin Noel','528 rue des Ormeaux','Montreal','QC','CANADA','H1L 4W8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:24:03',0,NULL,3,1,2,1,'、 ','kewlmart'),(6813,732571389011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','sanya_zh','azhigulskiy@gmail.com','Alexander Zhigulskiy','Orehovo-Zuevskiy proezd, 8-50','Moscow','','RUSSIAN FEDERATION','109202','+79265825256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:26:04',0,NULL,3,1,2,1,'、 ','sanya_zh'),(6814,599457939013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','makroel','zanakunur@hotmail.com','zana kunur','cudi mahallesi 5 nolu sokak door\'s no 8','sırnak','ŞIRNAK/SİLOPİ/CUDİ','TURKEY','73400','05437904424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:30:22',0,NULL,3,1,2,1,'、 ','makroel\r无壳的'),(6815,545782374003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','kmathisen','karelmathisen@gmail.com','Karel Mathisen','125 College Dr<br>AD 160','Casper','WY','UNITED STATES','82601-4699','(307) 258-9612','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 19:51:34',0,NULL,3,1,1,1,'\\  ','kmathisen'),(6816,732584446011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',45.18,'eastar4uk','nspiteriparis','nickspiteriparis@me.com','Nick Spiteri Paris','19<br>St Publius Street','Floriana','MA','MALTA','FRN1451','(+356) 9946 9172','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 19:53:22',0,NULL,3,1,3,1,'RA117719451CN\r ','nspiteriparis\rUDAP001'),(6817,599464238013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','joselpm1','joselpm@hotmail.com','Fernando Sanchez Lechuga','24207 Clocktower Dr<br>Franklin, Tn 37067 Apt 24207','Franklin','TN','UNITED STATES','37067-6198','(615) 935-7984','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 19:57:00',0,NULL,3,1,1,1,'\\  ','joselpm1'),(6818,813302983012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.4,'eastar4','dakirin','dkirin@gmail.com','Davor Kirin','Remetinecki gaj 21d','Zagreb','','CROATIA','10000','+38516141121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 20:04:21',0,NULL,3,1,2,1,' 、','dakirin\rHP 8pin 1.0 18cm 4线连 '),(6819,732595248011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','stianhumlekjar','humlekjar@gmail.com','Stian Humlekjær','Solengveien 13','Rolvsøy','Rolvsøy','NORWAY','1661','92458333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 20:15:37',0,NULL,3,1,2,1,'、 ','stianhumlekjar'),(6820,732605164011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','corcoya','corcoyano@gmail.com','luis cuadrado lopez','maestro cabezas,3','corcoya','sevilla','SPAIN','41599','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 20:37:48',0,NULL,3,1,3,1,'RA117719261CN ','corcoya\rGLSG001*2'),(6821,694831734001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','bmihobbies','heli@bmihobbies.com','Luke Yarbrough','4960 Martin View Lane','Winston Salem','NC','UNITED STATES','27104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 20:52:06',0,NULL,3,1,1,1,'\\  ','bmihobbies'),(6822,732611546011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','alexapple0999','b.m.alexapple@hotmail.com','Alexander Cabrera','7 Calle Baldorioty','Naguabo','PR','PUERTO RICO','00718-2537','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 20:53:59',0,NULL,3,1,1,1,'\\  ','alexapple0999\r盒装的\rOTSO004'),(6823,732616992011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','mthiago','mthiago@yahoo.com','Thiago Meneghello','Av Republica Argentina 2751 ap 805','Curitiba','Paraná','BRAZIL','80610260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:07:17',0,NULL,3,1,3,1,'RA117719350CN','mthiago\rGLSG001*2'),(6824,732432367011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','realaden82','realaden@yahoo.com','Holly Bofinger','7925 Capricorn Ter','Derwood','MD','UNITED STATES','20855-2568','(202) 758-4971','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 21:09:42',0,NULL,3,1,1,1,'\\  ','realaden82\racer 8pin1.00 15cm '),(6825,599499283013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','bajaneo','sarah.anderson@mac.com','Sarah Anderson','370 King Street West<br>Suite 504','Toronto','ON','CANADA','M5V1J9','(416) 586-1502 ext.: 227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:40:12',0,NULL,3,1,3,1,'RA117719434CN\r ','bajaneo\rMOAP001'),(6826,694853694001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','bansheejames','james.swetland@yahoo.com','james swetland','18104 seal ln','Spring Hill','FL','UNITED STATES','34610-7134','(352) 428-2584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 21:52:37',0,NULL,3,1,1,1,'\\  ','bansheejames'),(6827,599506776013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','pudge805','pudge805@gmail.com','william j velasquez','293 Rockrose Street','Soledad','CA','UNITED STATES','93960','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 22:06:49',0,NULL,3,1,1,1,'\\  ','pudge805'),(6828,732640011011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',104.95,'eastar4','h18gvm','george@themacnaughtons.co.uk','George D Macnaughton','Drummore Cottage,  Wallyford Toll','Musselburgh','East Lothian','UNITED KINGDOM','EH21 8JT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 22:12:01',0,NULL,3,1,3,1,'RA117719448CN\r ','h18gvm\rGLOT001*2\r一共买了四副\r兼容型3D眼镜 通用型'),(6829,813359458012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','h18gvm','george@themacnaughtons.co.uk','George D Macnaughton','Drummore Cottage,  Wallyford Toll','Musselburgh','East Lothian','UNITED KINGDOM','EH21 8JT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 22:14:58',0,NULL,3,1,17,0,NULL,'h18gvm'),(6830,599511400013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','approved_to_leave','frank.scherdel@albfahrschule.de','Frank Scherdel','Pichlerstraße 64','Laichingen','','GERMANY','89150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 22:28:31',0,NULL,3,1,2,1,' 、','approved_to_leave\r欧标'),(6831,813366755012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','ed_pilot','ed.szajniak@gmail.com','Ed Szajniak','1102 Redlands Rd','Penticton','BC','CANADA','V2A1X4','(250) 493-5036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 22:37:09',0,NULL,3,1,2,1,'、 ','ed_pilot\r旧的'),(6832,732649044011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','peruzzi2005','pixice2@westnet.com.au','Steven Peruzzi','3/25-27 Altin Street<br>P.O Box 1141','Griffith','New South Wales','AUSTRALIA','2680','0269622009','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-06 22:42:04',0,NULL,3,1,3,1,'RA117719385CN','peruzzi2005\rOTSO004*2'),(6833,694875573001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','fireworkskid','grandpops1@bellsouth.net','michael poerio','13721 Roanoke St','davie','fl','UNITED STATES','33325-1279','(954) 473-1141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 23:16:39',0,NULL,3,1,1,1,'\\  ','fireworkskid'),(6834,732686950011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','jorobaldo','pu2obd@hotmail.com','Marcelo Obed','R Rafael, 175<br>Jd Eusonia','Guarulhos','São Paulo','BRAZIL','07050-240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 01:24:08',0,NULL,3,1,3,1,'RA117719346CN\r ','jorobaldo\rGLOT004\r兼容型3D眼镜  samsung 专用'),(6835,732688180011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','pkapp2','kapp.kapp@verizon.net','Phil Kapp','316 Gifford Dr','Coppell','TX','UNITED STATES','75019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 01:29:57',0,NULL,3,1,1,1,'.','pkapp2'),(6836,599545904013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','huipakwoon','pakwoon_hui@yahoo.com.hk','Derrick','荃灣麗城花園3期7座14樓h室','default','','HONG KONG','default','(852) 620-0002 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 01:48:45',0,NULL,3,1,2,1,'、 ','huipakwoon\r客户电话(852)6200-0028\r'),(6837,599562892013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','akin1231','akin.utku@gmail.com','Akin Utku','Frame Group<br>Level 11, 189 Kent Street','Sydney','New South Wales','AUSTRALIA','2001','0293232887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 03:13:57',0,NULL,3,1,2,1,'、 ','akin1231\rCAB-6060'),(6838,732714890011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','orlonb','orlonb@msn.com','Orlon  Black','265 E 200 S','Salem','UT','UNITED STATES','84653-9452','(801) 423-2373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 03:31:40',0,NULL,3,1,1,1,'\\  ','orlonb'),(6839,813442964012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.4,'eastar4','milenmilev2','milenmilev@abv.bg','Milen Milev','37, Dragan Tzankov Blvd.','Sofia','Sofia','BULGARIA','1797','+359 888 605734','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 03:38:24',0,NULL,3,1,2,1,' 、','milenmilev2\r欧标'),(6840,599578224013,230395559651,'2.1 Acer AS aspire D250 Bluetooth Module EDR+cable',2,'BTAC2107',24.8,'eastar4','ade_rickus','ebay@rickus.co.uk','Adrian Rickus','Advanced Diagnostics LTD (6)<br>Eastboro Fields, Hemdale','Nuneaton','Warwickshire','UNITED KINGDOM','CV11 6GL','07973776193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 05:05:58',0,NULL,3,1,2,1,' 、','ade_rickus\rAcer 4pin 1.25 15cm '),(6841,694944472001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','ocalaras100473','ocalaras@yahoo.com','Oliver Alaras','501 SW 13th St<br>Apt 4','Ocala','FL','UNITED STATES','34471-0612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 05:12:07',0,NULL,3,1,1,1,'. ','ocalaras100473'),(6842,813464625012,220807319834,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',19.95,'eastar4','harrogatevalerie','thehainstocks@btinternet.com','i lofthouse','20 manor gardens<br>killinghall','harrogate','N Yorkshire','UNITED KINGDOM','hg32ds','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-07 05:30:51',0,NULL,3,1,2,1,'\\','harrogatevalerie\r多色伞 '),(6843,813465533012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','kurkarewicz','yurikurka@uol.com.br','Yuri Kurkarewicz','Rua Raymundo Cirino 254<br>Bairro Planalto','Sao Bernardo do Campo','Sao Paulo','BRAZIL','09890510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 05:38:20',0,NULL,3,1,3,1,'RA117719536CN\r ','kurkarewicz\rGLSG001*3\r申报40美金'),(6844,732739692011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','esther.chong','esther_chong84@hotmail.com','Wai Yee Chong','No.9, Jalan Puteri 2/5,<br>Bandar Puteri Puchong,','Puchong','Selangor','MALAYSIA','47100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 05:56:11',0,NULL,3,1,2,1,'、 ','esther.chong'),(6845,813471474012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','denissimo84','dionis3@gmail.com','Denis Chekryzhov','MO, Leninsky Raion, pos.Razvilka, dom.43 kv.306','Razvilka','Moscow Region','RUSSIAN FEDERATION','142717','9168561860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 06:22:36',0,NULL,3,1,3,1,'RA117719425CN\r ','denissimo84\rCMLO001'),(6846,813485666012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','duke_srg','dukesrg@gmail.com','Oleg Burdaev','Yasenevaya 17,188','Moscow','Moscow','RUSSIAN FEDERATION','115583','(916) 697-0524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 07:22:03',0,NULL,3,1,3,1,'RA117719519CN\r ','duke_srg\rOTRA001'),(6847,599598026013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','koreapost','ryu222@yahoo.com','Wonseok Ryu','203-204, e-Pyeonhansesang Apt.<br>Yangji-ri, Onam-eup','Namyangju-si','Gyeonggi-do','KOREA,REPUBLIC OF','472-940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 07:44:26',0,NULL,3,1,2,1,' 、','koreapost'),(6848,813489837012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','chinthakasl1976','chinthakasl@gmail.com','N.B.R.CHINTHAKA BANDARA','E-W INFORMATION SYSTEMS LTD<br>183C, 2 nd FLOOR,','COLOMBO ROAD','KURUNEGALA','SRI LANKA','60000','+94777360730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 07:45:24',0,NULL,3,1,2,1,' 、','chinthakasl1976'),(6849,813503546012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',21.5,'eastar4uk','ddes4358','david@davidandlucy.net','david de sousa','13a waterloo street','hove','East Sussex','UNITED KINGDOM','BN3 1AQ','01273779663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-07 08:44:33',0,NULL,3,1,3,1,' RA117719788CN\r','ddes4358\rWLAP009'),(6850,599625129013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','fantomaalpha','ross@fantoma.net','Ross Gladman','c/o Warrnambool Telephone Company<br>64 Banyan Street','Warrnambool','Victoria','AUSTRALIA','3280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 10:43:34',0,NULL,3,1,2,1,'. ','fantomaalpha'),(6851,732811336011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','hiron_p','ivchpavel@gmail.com','Pavel Ivchenkov','Kommunalnaj, dom 28, kv 101','Korolev','Moscow region','RUSSIAN FEDERATION','141070','+7-916-603-0145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 11:37:55',0,NULL,3,1,2,1,'\\ ','hiron_p'),(6852,599637962013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','jdoa6551','talesbyjed@yahoo.com','JAMES DOAN','7668 LOCUST CIR','NORTHFIELD','OH','UNITED STATES','44067-2964','(330) 468-5750','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 11:57:52',0,NULL,3,1,1,1,'\\  ','jdoa6551'),(6853,813556230012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',16.99,'eastar4','irex_de','rainer.eschrich@gmx.de','Dr. Rainer Eschrich','Drygalski Allee 118<br>App. 805','München','','GERMANY','81477','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 12:07:10',0,NULL,3,0,2,1,'\\ ','irex_de'),(6854,732822892011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','freef0rma','freeforma@gmail.com','Justin Rathbone','19 Crefeld Close','Hammersmith','London','UNITED KINGDOM','W6 8EL','02083865502','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-07 12:47:27',0,NULL,3,1,3,1,' RA117719765CN\r','freef0rma\rMOAP001'),(6855,545950453003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','rizal1976','rizal1976@gmail.com','Rizal Ahmad Nazim Bin Abd Raof','Felda Agricultural Svc. Sdn. Bhd.<br>P.P.P. Tun Razak','Jengka','Pahang','MALAYSIA','26400','0193875059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 13:02:52',0,NULL,3,1,3,1,'RA117719690CN\r ','rizal1976\rHSMO011\r英标'),(6856,545958599003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',14.99,'cnfaner','skywaydee','skywayd@ntlworld.com','David Gooding','62 Bernwell Road','Chingford','London','UNITED KINGDOM','E4 6HY','07532057386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 13:44:50',0,NULL,3,1,3,1,'RA117719624CN\r ','skywaydee\r英标\rHSNO007'),(6857,545968510003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.95,'cnfaner','pann4080','budhakitten@hotmail.com','ann-marie Provenh','1255 Beaubien','montreal','QC','CANADA','H2S1V1','(514) 880-4832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 14:32:53',0,NULL,3,1,3,1,'RA117719805CN\r ','pann4080\rWLAP009\r旧的'),(6858,695067272001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','giannisgreece1','itheodoropoul@yahoo.gr','IOANNIS THEODOROPOULOS','DOURIDOS 4-6','ATHENS','','GREECE','11634','00306974351401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 14:43:06',0,NULL,3,1,3,1,' RA117719774CN\r','giannisgreece1\rBR3D003'),(6859,695068079001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','513tina55','tinaletsche@zoomtown.com','Tina Letsche','3664 Tolbert Rd','Trenton','OH','UNITED STATES','45067-9620','(513) 726-5238','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 14:43:55',0,NULL,3,1,1,1,'\\  ','513tina55'),(6860,732864362011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','sdimos-gr','sdimos@yahoo.com','EFSTRATIOS DIMOPOULOS','Panafon - Vodafone SA<br>Tzavela 1-3 (Building K2)','Halandri, Athens','Attiki','GREECE','152 31','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 14:49:15',0,NULL,3,1,2,1,'\\ ','sdimos-gr'),(6861,599677812013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','twocatshouse','marius.anglickas@gmail.com','Marius Anglickas','Justiniskiu str. 103-46','Vilnius','','LITHUANIA','05253','(370) 698 31018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 15:05:29',0,NULL,3,1,2,1,'\\ ','twocatshouse'),(6862,732839951011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','epsilons1932','vane.franck@free.fr','Vanessa VAN DEN BROCK','67 rue Fanny duvivier','Rieux','Picardie','FRANCE','60870','0615724105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 16:28:20',0,NULL,3,1,3,1,'RA117719964CN ','epsilons1932\rGLSG001*2'),(6863,695100112001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','1985m998','libertyk@comcast.net','Liberty Krueger','62 Shattuck St','Greenfield','MA','UNITED STATES','01301-1904','(413) 475-3164','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 16:28:29',0,NULL,3,1,1,1,'\\  ','1985m998'),(6864,813644114012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',258,'eastar4','skywu','skywumac@gmail.com','Teresa Kuan (GoGo Realtors)','1200 S Diamond Bar Blvd<br>Ste 200','Diamond Bar','CA','UNITED STATES','91765-2298','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 16:43:48',0,NULL,3,1,4,1,'YW865589455CN ','skywu\r美标'),(6865,813662396012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','wcwchen','wcwchen@seed.net.tw','WILLIAM CHEN','4742 Centre Ave<br>Apt 506','Pittsburgh','PA','UNITED STATES','15213-1733','(215) 917-3878','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 17:10:38',0,NULL,3,1,1,1,'\\  ','wcwchen'),(6866,732921983011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','cyperbious','myboxx@hotmail.com','Bryan Haddock','1316 Decatur Cir','Franklin','TN','UNITED STATES','37067','(615) 465-2283','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 17:28:19',0,NULL,3,1,1,1,'\\  ','cyperbious'),(6867,813669667012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','zoetri','mktz@optonline.net','Kimberly d zedalis','2680 Bryant Dr','seaford','NY','UNITED STATES','11783-3524','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 17:32:49',0,NULL,3,1,1,1,'\\ ','zoetri'),(6868,599720095013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','afanasovm','afanasov@inbox.ru','Maxim Afanasov','Krasnoarmeyskaya, 62/2-54','Bryansk','','RUSSIAN FEDERATION','241050','+79191984125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 17:40:45',0,NULL,3,1,2,1,'\\ ','afanasovm'),(6869,732940125011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',3,'GLOT004',161.97,'eastar4','immob01','info@p-amkreutz.speedlinq.nl','Perry Amkreutz','Leienhuisweg 10','WIJLRE','','NETHERLANDS','NL-6321AV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 18:10:55',0,NULL,3,1,3,1,'RA117719638CN\r ','immob01\rGLOT004\r兼容型3D眼镜  samsung 专用'),(6870,732942683011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','nyguy7654321','waternyc@aol.com','V. TSOLAKIDIS','TAX. THIRIDA 8035','KAROUSADES','KERKYRA','GREECE','49081','(695) 506-4708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 18:15:59',0,NULL,3,1,2,1,'. ',' paypal 撤\r款nyguy7654321\r红遍优联\r'),(6871,732946208011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','kostasartasgr','kostastsiarta@gmail.com','konstantinos tsiatsos','agios spyridonas','arta','artas','GREECE','47 100','6946470122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 18:24:34',0,NULL,3,1,3,1,'RA117719743CN\r ','kostasartasgr\rBR3D001'),(6872,813711059012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',2,'OTCR001',57.7,'eastar4','vixaquga','victorquintero@cablevision.net.mx','Victor Quintero','Hda. de Puruagua #50<br>Fracc. Lomas de la Hda.','Atizapan de Zaragoza','Estado de Mexico','MEXICO','52925','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 18:50:06',0,NULL,3,1,3,1,'RA117719669CN ','vixaquga\rOTCR001'),(6873,813725778012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','genor004','genor@zahav.net.il','Evgeni Nepomniachtchi','Shik str. 4/15','Tel-Aviv','Israel','ISRAEL','68191','972-3-6824790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 19:17:52',0,NULL,3,1,2,1,'.','genor004'),(6874,546044298003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','stevestradingplace','stevelsoteros@yahoo.com','Steve Soteros','5505 Safari Trl','Arlington','TX','UNITED STATES','76018-1841','(817) 723-8786','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-07 19:19:19',0,NULL,3,1,1,1,'\\  ','stevestradingplace'),(6875,599754847013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','bet2win247','glennguyen71@gmail.com','Glen Nguyen','14417 Chase St<br>Unit 173','Panorama City','CA','UNITED STATES','91402-3017','(818) 835-2654','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 19:23:00',0,NULL,3,1,1,1,'\\  ','bet2win247'),(6876,813741520012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','getico','getico@getico.ee','Hindrek Juhanson/Getico OY','Kassi 4','Tallinn','','ESTONIA','12618','(+372) 503 3355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 19:48:09',0,NULL,3,1,2,1,'. ','getico'),(6877,813747961012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','twofeettal','twofeettal@comcast.net','Alfred Prasad','6726 Percival Way','Stockton','CA','UNITED STATES','95210-3458','(209) 475-9743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 20:00:53',0,NULL,3,1,1,1,'\\  ','twofeettal'),(6878,813761446012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','narojas','cl_nicolas@yahoo.com.br','Nicolas Alejandro Manzo Rojas','rua Iris Antonio Campos, 250<br>bl9 ap103','Curitiba','Parana','BRAZIL','81220370','554133143241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 20:28:07',0,NULL,3,1,3,1,'RA117719709CN\r ','narojas\rOTSO002'),(6879,813784101012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','silfides','pablo.romerogiron@hotmail.com','Enrique Romero-Giron Gomez-Pablos','C/ Luis Doreste Silva 52, 3º-1','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','928249978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 21:19:32',0,NULL,3,1,2,1,'\\ ','silfides\r发两个210TS'),(6880,546088084003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.95,'cnfaner','tito3620yenier','estherramirez1951@hotmail.com','esther ramirez','3620 nw 4th st<br>none','miami','FL','UNITED STATES','33125-4047','(305) 643-9938','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-07 21:45:44',0,NULL,3,1,1,1,'\\  ','tito3620yenier'),(6881,733037322011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','robertc76','robertcorbett@gmail.com','Robert Corbett','6-8 Waverley Drive','Unanderra','New South Wales','AUSTRALIA','2526','0242221555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 21:49:50',0,NULL,3,1,2,1,'\\ ','robertc76'),(6882,733047073011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','morpin','mmpdhc@gmail.com','Manuel Moreno','Panama 3, 5ºA','Madrid','Madrid','SPAIN','28036','914573387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 22:19:28',0,NULL,3,1,3,1,'RA117719978CN ','morpin\rGLSG001*2'),(6883,813814815012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',39.9,'eastar4uk','mad-damm','damian@hot.pl','W3A.PL','Niegolewskich 6/6','Poznan','','POLAND','60-232','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 22:41:24',0,NULL,3,1,3,1,' RA117719672CN\r','mad-damm\rHSSE006'),(6884,730563128011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',2,'HSSE009',111.98,'eastar4','sylmarie10','s.cajigas@yahoo.com','Sylmarie Cajigas','URB CUPEY GDNS<br>I-10 CALLE 4','SAN JUAN','PR','UNITED STATES','00926-7316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 22:44:33',0,NULL,3,1,1,1,'\\ ','sylmarie10\r美标'),(6885,733060197011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','b_s_enterprises1','toysareblakes@yahoo.com','Kennard % Charles H Hill','128 Easy Dr','Satsuma','FL','UNITED STATES','32189-3316','(386) 546-6774','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 23:08:55',0,NULL,3,1,1,1,'\\  ','b_s_enterprises1'),(6886,813827756012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',8.98,'eastar4','czljxtbay','jrkral@yahoo.com','Jiri Kral','6715 Fulton Ct','Troy','MI','UNITED STATES','48098-1768','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 23:23:58',0,NULL,3,1,1,1,'\\  ','czljxtbay'),(6887,733067088011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','starbuy2001','rbe4735744@aol.com','Richard Wexler','73 Caldwell Ter','Marlboro','NJ','UNITED STATES','07746-1780','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 23:36:06',0,NULL,3,1,1,1,'\\  ','starbuy2001'),(6888,551744054004,140490658273,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',38.9,'cnfaner','bengtsjolen','bengt@automata.se','Bengt Sjolen','Automata AB<br>Katarina Bangata 71 (garage)','Stockholm','SE','SWEDEN','11642','+46707404329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 00:35:17',0,NULL,3,1,3,1,' RA117719686CN\r','bengtsjolen\rWWSI004+ANCN001'),(6889,813847248012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','seedling11','yuna03@gmail.com','Retief Visser','24/210 Grote Street','Adelaide','South Australia','AUSTRALIA','5000','0406361622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 00:47:05',0,NULL,3,1,2,1,'\\ ','seedling11'),(6890,813853767012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','violet8087','yunjh0915@gmail.com','Yun JongHwan','103-1703 Songdo haemoro Apt<br>Songdo-dong, Yeonsu-gu','Incheon','','KOREA,REPUBLIC OF','406-742','8210-7109-8765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 01:08:14',0,NULL,3,1,2,1,'. ','violet8087'),(6891,733091911011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','cristiz24','cristiant@email.com','Cristian Tanase','1920 Rue Des Patriotes','Laval','QC','CANADA','H7L 2N8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 01:23:17',0,NULL,3,1,3,1,' RA117719726CN\r','cristiz24\rBR3D001'),(6892,733088659011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','rysiek.773','bchalupka@yahoo.com','Emil chalupka','6401 W Berteau Ave<br>Apt 206','Chicago','IL','UNITED STATES','60634-6216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 01:23:54',0,NULL,3,1,1,1,'\\  ','rysiek.773'),(6893,733107377011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.99,'eastar4','filipedb','filipedeporte@gmail.com','Filipe Bittencourt','AV. PRESIDENTE CASTELO BRANCO, 1285','SANTA CRUZ DO SUL','RIO GRANDE DO SUL','BRAZIL','96835666','555198143594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 02:28:32',0,NULL,3,1,3,1,'RA117719831CN\r ','filipedb\rUDAP001'),(6894,733107981011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','gaponds','bill@pondexpo.com','Bill Mason','5612 Hidden Harbor Dr','Gainesville','GA','UNITED STATES','30504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 02:31:17',0,NULL,3,1,1,1,'\\  ','gaponds\r新的'),(6895,733043865011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','gkm5000','firestorm@millerit.com','Greg Miller','2303 Galway Dr','Mansfield','TX','UNITED STATES','76063-7513','(817) 539-7447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 03:30:41',0,NULL,3,1,1,1,'\\  ','gkm5000'),(6896,599866280013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.4,'eastar4','emehlhar','emehlhar@telus.net','elliott mehlhart','308 - 4745 54A St','Delta','BC','CANADA','v4k 2z9','(604) 940-6367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 03:33:12',0,NULL,3,1,2,1,'. ','emehlhar'),(6897,813906108012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','zorin-foto','u-mka@mail.ru','Svyatoslav Zorin','Obedineniya<br>96 kv. 10 +79139146378','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 04:50:41',0,NULL,3,1,2,1,'\\ ','zorin-foto\r七色彩虹伞'),(6898,813916107012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','trasgufartonastur','jonatanlopezdel@yahoo.es','Jonatan Lopez del Alamo','Mayorazu 16 3C','Oviedo','Asturias','SPAIN','33010','615185553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 05:46:24',0,NULL,3,1,3,1,'RA117719859CN ','trasgufartonastur\rOTRA001'),(6899,733145582011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',10,'HSSE008',399.9,'eastar4','lord.32','jt@gforceaus.com','Joshua Thompson','24/15 Ricketts Road','Mount Waverley','Victoria','AUSTRALIA','3149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 05:52:35',0,NULL,3,1,4,1,'YW865589621CN ','lord.32\r澳标'),(6900,813932548012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',17.96,'eastar4','denon-dj','leo@epcomputers.nl','Eelco Pol','Sleutelbloem 23','Delden','','NETHERLANDS','7491LR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 07:05:45',0,NULL,3,1,2,1,'\\ ','denon-dj'),(6901,551800894004,140516496368,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',82,'cnfaner','den2028','lowprice_component@hotmail.com','Low Price Component','210/1 Chaiyakiet 2 Soi<br>Ngamwongwan Rd., Toongsonghong','Laksi','Bangkok','THAILAND','10210','6629555045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 07:38:08',0,NULL,3,1,3,1,' RA117719845CN\r','den2028\rTRTS001*10'),(6902,599900646013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','joergwindau','jwindau@optonline.net','Joerg Windau','352 Academy St','South Orange','NJ','UNITED STATES','07079','(212) 781-8178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 07:52:01',0,NULL,3,1,1,1,'\\  ','joergwindau'),(6903,599901408013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','fedorini2010','5073950@mail.ru','Sergey Fedorchuk','Lipeckaya 54/21-74','Moscow','','RUSSIAN FEDERATION','115598','+79255073950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 07:56:04',0,NULL,3,1,3,1,'RA117719567CN\r ','fedorini2010\rHSNO019\r欧标'),(6904,733171271011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','carborush','philipdeke@yahoo.com','Philip De keersmaecker','sint antoniuskaai 10b','Gent','','BELGIUM','9000','0485-660666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 08:09:02',0,NULL,3,1,2,1,'. ','carborush'),(6905,551807501004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','compralo2011ya','matcos2011@hotmail.com','costa mattias','calle josep pujol i montaner 17 3-2','torredembarra','Cataluña','SPAIN','43830','679401301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 08:24:28',0,NULL,3,1,3,1,'RA117719712CN ','compralo2011ya'),(6906,733197846011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','tripzgivan','ivan.zeger@email.t-com.hr','Ivan Žeger','Hodošanska 5','Zagreb','','CROATIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 10:09:37',0,NULL,3,1,2,1,'\\','tripzgivan'),(6907,813982023012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','specialmen123','specialmen240@hotmail.com','Asim Al-Hashmi','5170 Hudson Dr<br># 62039408 Ste I','Hudson','OH','UNITED STATES','44236-3797','440 339 2600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 10:33:10',0,NULL,3,1,1,1,'\\ ','specialmen123'),(6908,695387608001,110696245374,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',75.99,'buysia','ladydi-ky','dianacsouth@yahoo.com','Diana South','459 South Ln','Leitchfield','KY','UNITED STATES','42754-9688','(270) 257-0358','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 11:06:39',0,NULL,3,1,1,1,'\\ ','ladydi-ky'),(6909,733228182011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','ti-po','ropika80@gmail.com','TI-PO KFT','Fiumei út 25<br>3.emelet 5','Budapest','Budapest','HUNGARY','1081','+36205190901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 12:07:16',0,NULL,3,1,3,1,'RA117719880CN\r ','ti-po\rWWSI002+ANCN001'),(6910,599951993013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','lesnoyst','podlesnomu@gmail.com','Aleksey Podlesny','Centralny pereulok dom 4 kv.87','Stupino','Moscow region','RUSSIAN FEDERATION','142800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 12:47:01',0,NULL,3,1,2,1,'\\ ','lesnoyst'),(6911,814032152012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','alehandr10','a.kukharenko.s@gmail.com','Alehandr Kukharenko','kairbekova 375-33','Qostanay','Qostanay','KAZAKHSTAN','110000','+77773032527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 13:19:26',0,NULL,3,1,2,1,'\\ ','paypl 撤款 alehandr10'),(6912,733250148011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 13:24:02',0,NULL,3,1,2,1,'\\ ','masteroll2010'),(6913,814034888012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','sw042989','swinkinc@aol.com','Mark Swink','466 Monterey Pkwy','Orange Park','FL','UNITED STATES','32073-6733','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 13:28:55',0,NULL,3,1,1,1,'\\ ','sw042989\r新的'),(6914,599964748013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',2,'OTHP003',37,'eastar4','vzane2','vzane_ads@rogers.com','VIRGIL ZANE','15 CASHEW CRT','NORTH YORK','ON','CANADA','M2J 4W1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 13:44:25',0,NULL,3,1,3,1,'RA117719893CN\r ','vzane2\rOTHP003'),(6915,733256415011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','hs6twi','teoy_1@hotmail.com','Ritthirong Saengsoi','6/441 Riversdale RD.','Hawthron East','Victoria','AUSTRALIA','3123','0411166759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 13:45:31',0,NULL,3,1,2,1,'\\ ','hs6twi'),(6916,732500724011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','191937999','miss_watson@list.ru','Alice Shaporenko','ozernaya, 12 30','Kiev','','UKRAINE','04209','0631521272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 13:58:36',0,NULL,3,1,2,1,'\\ ','191937999'),(6917,814050290012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',15.95,'eastar4','thyrsomunhoz','thyrso_mecatronica_est@hotmail.com','Thyrso Munhoz','Rua Nova Prata Numero 235<br>Vieiralves','Manaus','Amazonas','BRAZIL','69053010','41011440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 14:12:46',0,NULL,3,1,2,1,'\\ ','thyrsomunhoz'),(6918,733279059011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','maaron34','michaeltaaron@gmail.com','Michael Aaron','80 Dekalb Ave<br>Apt 26B','Brooklyn','NY','UNITED STATES','11201-5470','(512) 584-0979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 14:59:41',0,NULL,3,1,1,1,'\\ ','maaron34'),(6919,729116874011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',34.98,'eastar4','viscount_of_funk','apearsonagain@yahoo.com','Aaron Pearson','2634 Hwy 595','Neebing','ON','CANADA','P7L0G4','(807) 577-3628','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 15:24:32',0,NULL,3,1,3,1,'RA117719876CN\r ','viscount_of_funk\rWLAP009\r旧的'),(6920,814079004012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','phneutral','hugo.m.rebelo@gmail.com','Hugo Rebelo','Rua enfermeiras da grande guerra<br>nº12, 2º andar','Lisboa','Lisboa','PORTUGAL','1170-119','916842623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 15:31:32',0,NULL,3,1,2,1,'\\ ','phneutral'),(6921,546262844003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','alexband52','b-rami@013.net.il','Alexnder Band','Taran 6/5','Rehovot','','ISRAEL','76248','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 15:35:33',0,NULL,3,1,3,1,'RA117719862CN\r ','alexband52\rHSPL005'),(6922,695196493001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','killeenbwoi','killeen_bwoi@yahoo.com','JERMAINE SMITH','Dyncorp Logcap IV','APO','AE','AA','09355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 15:40:20',0,NULL,3,1,1,1,'\\ ','killeenbwoi'),(6923,814100662012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','naveed84','moeeed@live.com','Moeed Khokhar','137 Victory Dr.<br>North York','Toronto','ON','CANADA','M3M2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 16:25:34',0,NULL,3,0,2,1,'\\ ','naveed84\r发210TS两个'),(6924,814103305012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','alpha1051pg','alpha10@gte.net','Sewell Pappas','1916 Brabant Dr','Plano','TX','UNITED STATES','75025-3325','(972) 527-0092','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 16:32:42',0,NULL,3,1,1,1,'\\ ','alpha1051pg'),(6925,733313345011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','dmdsoftware','webmaster@dmdsoftware.net','Dylan Durdle','1073 Alexandra Avenue','Mississauga','ON','CANADA','l5e2a1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 16:37:42',0,NULL,3,1,2,1,'\\ ','dmdsoftware'),(6926,733343308011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','shacharmazor','mazorshachar@hotmail.com','shachar mazor','Hatamar 5','Shoham','israel','ISRAEL','60850','(927) 578128974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 17:53:37',0,NULL,3,1,2,1,'\\ ','shacharmazor'),(6927,814139855012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.99,'eastar4uk','rehani','mosishari@hotmail.com','Nazia Kauser','34 baines street, Pellon lane','Halifax','West Yorkshire','UNITED KINGDOM','HX1 5PW','07870501221','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-08 18:02:53',0,NULL,3,1,3,1,'RA117719955CN\r ','rehani\rHSNO006\r英标'),(6928,814148781012,220759427746,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',7.88,'eastar4uk','johnboydnbobi','johnboyd2010@yahoo.co.uk','Mrs Aileen McKenzie','19 Torrington Crescent<br>Mount Vernon','Glasgow','Glasgow (City of)','UNITED KINGDOM','G32 9NU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-08 18:16:26',0,NULL,3,1,3,1,'RA117719920CN\r ','johnboydnbobi\rHSPL001'),(6929,814223509012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',22.59,'eastar4uk','poolbr','paulo.bruning@gmail.com','Paulo Brüning','XV de Novembro, 4191','Joinvillle','Santa Catarina','BRAZIL','89216-201','+55 47 3453 0666','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-08 20:56:58',0,NULL,3,1,3,1,'RA183610257CN\r ','poolbr\rUDAP002'),(6930,733423632011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','leon_deranger','leowieland@yahoo.com','Leonardo Wieland','29 Henley Road<br>Sandford-on-Thames','Oxford','Oxfordshire','UNITED KINGDOM','OX4 4YW','07920843097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 21:06:48',0,NULL,3,1,2,1,'\\ ','leon_deranger'),(6931,814253341012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*2',209.9,'eastar4','andreplourde','plourdeapl@hotmail.com','andre plourde','1040 rue cote','alma','QC','CANADA','g8b1x7','(418) 668-7097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 22:19:22',0,NULL,3,1,3,1,'RA183613531CN\r ','andreplourde\rGLOT001*2\r兼容型3D眼镜 通用型'),(6932,733451037011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','black-knight29','kytavinor@hotmail.com','Mr Ky Tavinor','27 Oulton Road','Rugby','Warwickshire','UNITED KINGDOM','CV21 1AE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-08 22:33:13',0,NULL,3,1,3,1,'RA117719916CN\r ','black-knight29\rRELO003\r红边优联'),(6933,599888975013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','dhsharp01','ucanbsharp2@gmail.com','Dave Sharp','9 Hall st','Council Bluffs','IA','UNITED STATES','51503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-08 22:40:03',0,NULL,3,1,1,1,'\\ ','dhsharp01'),(6934,733460465011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','cjgames-junior','cjgames@terra.com.br','Celso Junior','Rua Guarau 60<br>Mirandópolis','Sao Paulo','São Paulo','BRAZIL','04052-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 23:06:49',0,NULL,3,1,3,1,'RA183610243CN ','cjgames-junior\r一共买了两个兼容型3D眼镜  samsung 专用\rGLOT004\r'),(6935,600123369013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','phantomtd','ringen-m@online.no','Magnus Ringen','Bekkelagsterrassen 26','Oslo','Oslo','NORWAY','1177','95863747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 23:50:10',0,NULL,3,1,2,1,'\\ ','phantomtd'),(6936,733471160011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.99,'eastar4','mayet_be','roleroy@hotmail.com','ROGER LEROY','Avenue de la gare 91','Hotton','','BELGIUM','6990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 23:53:54',0,NULL,3,1,2,1,'\\ ','mayet_be\rHP 5pin1.0 20cm'),(6937,600125653013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','mr_zergus','zrg_@mail.ru','Konstantin Kuzmenko','1 Sribnokilska apt 478','Kyiv','','UKRAINE','02095','0635808817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 00:03:58',0,NULL,3,1,2,1,'\\ ','mr_zergus\r多色伞'),(6938,732727894011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','jagonz03','jjjgonz03@hotmail.com','jorge a gonzalez','56 Charlotte DR Unit F','chatsworth','GA','UNITED STATES','30705-8234','(706) 618-3711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 01:10:03',0,NULL,3,1,1,1,'\\ ','jagonz03'),(6939,733494490011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','gerryw22','gerryw2@clear.net.nz','Gerard Williams','3 Holly Road<br>St Albans','Christchurch','','NEW ZEALAND','8014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 01:48:08',0,NULL,3,1,3,1,'RA183613505CN\r ','gerryw22\rKBNO001'),(6940,733505889011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','micetigerdragonmonkey168','darrenscottyu@gmail.com','Lawrence Francis Yu','delta merchandising, 3rd floor, atrium mall, general luna st','Iloilo','Iloilo','PHILIPPINES','5000','(917) 300-2700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 04:07:22',0,NULL,3,1,2,1,'\\ ','micetigerdragonmonkey168\r '),(6941,733522136011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ericcsit','ericsit@pobox.com','Eric Sit','105 Serra Way<br># 448','Milpitas','CA','UNITED STATES','95035-5206','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-09 04:09:49',0,NULL,3,1,1,1,'\\ ','ericcsit\r红边优联'),(6942,733536907011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',207.99,'eastar4','sergeysm2010','krgcm2007@mail.ru','SERGEY MAISTRENKO','STEPNOY- 3st.  3/10','KARAGANDA','KZ','KAZAKHSTAN','100000','8 701 533 06 76','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 05:42:54',0,NULL,3,1,3,1,' RA183613616CN\r','sergeysm2010\rOTSO004*3'),(6943,733568762011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',129.98,'eastar4','kkfuty007','kkfuty007@hotmail.com','Luis Utrilla','mas del ribero nº4','Toledo','Castilla-La Mancha','SPAIN','45004','626511636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 08:42:53',0,NULL,3,1,3,1,'RA183613562CN\r ','kkfuty007\rGLSG001'),(6944,814405729012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','txen23','sendoa@vodafone.es','Sendoa Lusarreta','Av. madrid 21 3D','San Sebastian','País Vasco','SPAIN','20011','607325841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 09:43:39',0,NULL,3,1,2,1,'\\ ','txen23'),(6945,814411719012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','jurijsivanovs','jur4iks90@inbox.lv','Jurijs Ivanovs','Tvaika 16/54','Riga','','LATVIA','LV-1005','+37125938078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 10:04:52',0,NULL,3,1,2,1,'\\ ','jurijsivanovs'),(6946,600221365013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','glebon80','gleb.bogdanov@gmail.com','Gleb Bogdanov','Borisovskiy proezd, d. 1, korp. 2, kv. 360','Moscow','','RUSSIAN FEDERATION','115563','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 10:46:44',0,NULL,3,1,3,1,'RA183613341CN\r ','glebon80\rWLIN014\r通用版'),(6947,814425114012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','tuaninbox','tuan@hat.vn','Nguyen Ho Hiep','4th Floor. 404 D10 Giang Vo St.<br>Ba Dinh Dist.','Hanoi','','VIET NAM','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 11:07:26',0,NULL,3,0,2,1,'\\ ','tuaninbox\r发210TS一个'),(6948,0,110710655720,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',51.01,'buysia','2fast1matt','fast1matt@att.net','Matthew Park','1902 Willow Wisp ln','Spring','TX','UNITED STATES','77388-6243','(281) 350-4505','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 11:36:04',0,NULL,3,1,1,1,'\\ ','2fast1matt'),(6949,814455493012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','julie.grange01','julie.grange@sky.com','Julie Grange','47 Cherry Road','wisbech','Cambridgeshire','UNITED KINGDOM','pe133pl','01945587748','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 12:32:58',0,NULL,3,1,3,1,'RA183613491CN\r ','julie.grange01\rHSMO018\r英标'),(6950,814468700012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','siwoc75','krylov75@gmail.com','Oleg Krylov','Mamyr-3, house 22, flat 52','Almaty','Almaty','KAZAKHSTAN','050036','+77272261213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 13:14:48',0,NULL,3,1,3,1,'RA183613647CN\r ','siwoc75\rOTSO004*2'),(6951,733647577011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','mkurchina','mkurchina@mountaincable.net','Michael Kurchina','82 brentwood drive','Hamilton','ON','CANADA','L8T 3W3','(905) 388-3264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 13:26:24',0,NULL,3,1,2,1,'\\ ','mkurchina'),(6952,600262966013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',15.6,'eastar4','condor0710','condor701@web.de','sergej jeckel','Elisabethstr.9','bergisch gladbach','','GERMANY','51429','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 14:03:18',0,NULL,3,1,2,1,'\\ ','condor0710'),(6953,600269405013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 14:24:49',0,NULL,3,1,2,1,'\\ ','ibico1974'),(6954,733676900011,320721418293,'Genuin Samsung SSG-2200AR Rechargeable Adult 3D glasses',2,'GLSG006',151.98,'eastar4','rivardsy','sylvain.rivard@globetrotter.net','Sylvain Rivard','150, 181e rue','Beauceville','QC','CANADA','G5X3P3','(418) 774-3367 ext.: 656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 14:57:40',0,NULL,3,1,3,1,'RA183613465CN\r ','rivardsy\rGLSG006'),(6955,733689092011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','uticanpioneer','cirrincionea@roadrunner.com','Anthony Cirrincione','3883 Dawes Ave','Clinton','NY','UNITED STATES','13323','(315) 404-3653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 15:33:05',0,NULL,3,1,1,1,'\\ ','uticanpioneer'),(6956,814530499012,220807272239,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',19.99,'eastar4','boojalavelle','jaynelavelle@hotmail.com','Jayne Lavelle','Bee Cottage, , Elwick','Hartlepool','Cleveland','UNITED KINGDOM','TS27 3ED','07818001799','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-09 15:59:40',0,NULL,3,1,2,1,'\\ ','boojalavelle\r向日葵三折叠伞 '),(6957,600297261013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','canionteam','marcoslira@fsanet.com.br','Marcos Lira','Rua Gardenia 683, Ap 503<br>Edf Loft Soho Bairro Jockey','Teresina','Piaui','BRAZIL','64049200','55 086 88488686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 16:14:45',0,NULL,3,1,2,1,'\\ ','canionteam'),(6958,600314897013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','palmtree-nl','ebay@wijtwee.cjb.net','Wim Vuurpijl','Bijdorpstraat 14','SASSENHEIM','','NETHERLANDS','2172SJ','+31650680463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 17:10:09',0,NULL,3,1,2,1,'\\ ','palmtree-nl\rCAB-6060'),(6959,600318955013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',33.99,'eastar4','infocober','listas@infocober.com.ar','Fernando Boglioli','Sarmiento 859<br>8th floor app\"B\"','Rosario','Santa Fe','ARGENTINA','2000','54 11 5252 5215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 17:25:33',0,NULL,3,1,3,1,'RA183613355CN\r ','infocober\rWWSI004+ANCN001'),(6960,695888355001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','hugjw48','cherryw0802@gmail.com','Cong Wang','17104 SE 60th St','Bellevue','WA','UNITED STATES','98006-5900','(425) 276-6378','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 18:12:52',0,NULL,3,1,1,1,'\\ ','hugjw48'),(6961,600348508013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','thefrog123456','thefrog@thefrog.sk','Miroslav Farkas','Rumermatt 234','Oberbözberg','','SWITZERLAND','5225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 19:01:21',0,NULL,3,1,2,1,'\\ ','thefrog123456'),(6962,733772320011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','cjgames-junior','cjgames@terra.com.br','Celso Junior','Rua Guarau 60<br>Mirandópolis','Sao Paulo','São Paulo','BRAZIL','04052-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 19:02:31',0,NULL,3,1,17,0,NULL,'cjgames-junior\rGLOT004\r兼容型3D眼镜  samsung 专用'),(6963,600354186013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','k5789','ace69@bk.ru','Vladimir Berman','Makor Haim 6/3','Beer-Sheva','Negev','ISRAEL','84636','+97286423099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 19:16:37',0,NULL,3,1,2,1,'\\ ','k5789'),(6964,814629315012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',100.78,'eastar4','behc777','rey@spmi.ru','Evgeny Chorpita','55-18 Vosstaniya str<br>+7 911 712 9060','Saint-Peterburg','RU','RUSSIAN FEDERATION','191123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 19:43:12',0,NULL,3,1,3,1,'RA183610226CN ','behc777\r再发两个Unlocked NEW Sierra Wireless WWAN MC8780 \r'),(6965,600378700013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','vladimirua61','tuzi61@gmail.com','Vladimir Trebukhov','Heroiv Stalinhradu , h. 16-D, f. 60','Kyiv','','UKRAINE','04210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 20:41:06',0,NULL,3,1,2,1,'\\ ','vladimirua61'),(6966,814661887012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','henson1773','henson0115@msn.com','shane henson','6 evedon walk','nottingham','Nottinghamshire','UNITED KINGDOM','ng5 5qw','07725226764','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 20:58:23',0,NULL,3,1,3,1,'RA183613488CN\r ','henson1773\rOTHP003'),(6967,814668673012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','dermisane*com','info@dermisane.com','Osvaldo Glat','Tucuman 3302<br>casi esq. Gallo','Capital Federal','Buenos Aires','ARGENTINA','C1189AAN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 21:25:43',0,NULL,3,1,2,1,'\\ ','dermisane*com\r白色的'),(6968,733833170011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','cigarbufff','bramptoncomputing@rogers.com','Rob Salvo','41 Milford Cres','Brampton','ON','CANADA','L6S 3E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 21:36:15',0,NULL,3,1,2,1,'\\ ','cigarbufff'),(6969,600401397013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','azn-tuan','tuan_anh_vuong@yahoo.fr','Tuan anh Vuong','Bloemenveld 8','Zaventem','','BELGIUM','1930','0473 383802','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 22:09:01',0,NULL,3,1,2,1,'\\ ','azn-tuan'),(6970,0,180692062326,'New Griffin PowerJolt Dual USB Micro Car Charger',1,'CCGR001',7.49,'au-buy','lanced1981','ldanger@gmail.com','Lance Danger','10 Hastings Crescent','Broadmeadows','Victoria','AUSTRALIA','3047','0393091797','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-09 22:41:34',0,NULL,3,1,3,1,'RA183613275CN\r ','lanced1981\rCCGR001'),(6971,0,110710655710,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',71.01,'buysia','cteague77','cteague7@comcast.net','Carol Teague','549 E Main St<br>Apt D51','Hendersonville','TN','UNITED STATES','37075-2634','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 22:51:05',0,NULL,3,1,1,1,'\\ ','cteague77'),(6972,814724281012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','mimosin138','jr_vending@hotmail.es','jaime ramos sanchez','tenor paredes nº14','don benito','Extremadura','SPAIN','06400','605181061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 00:25:18',0,NULL,3,1,3,1,'RA183613593CN\r ','mimosin138\rGLSG001*3'),(6973,600427337013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',15.99,'eastar4','murciamen','murciamen@hotmail.com','PEDRO PARRA IBAÑEZ','CALLE LOS ROSALES NUM 53','SAN PEDRO DEL PINATAR','Murcia','SPAIN','30740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 00:26:17',0,NULL,3,1,2,1,'\\ ','murciamen'),(6974,733885477011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','ct1023','chong1023@yahoo.com','Chy Chong Taing','150 S Los Robles Ave<br>Ste 500','Pasadena','CA','UNITED STATES','91101-4611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 00:55:05',0,NULL,3,1,1,1,'\\ ','ct1023'),(6975,0,110713241789,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',56,'buysia','laval_28','arex_val@yahoo.com','Aries Valenton','34 Ferris Ave<br>Unit A1','Norwalk','CT','UNITED STATES','06854','(203) 918-0034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 01:16:24',0,NULL,3,1,1,1,'\\ ','laval_28'),(6976,814730718012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','ice0420','ice042082@yahoo.com','Brian Blocker','27 Brandy Ct','Greensboro','NC','UNITED STATES','27409-2300','(336) 676-3089','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 01:30:27',0,NULL,3,1,1,1,'\\ ','ice0420'),(6977,600440774013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dollface18','bnajishow@aol.com','Beth Naji','328 W 44th St<br>Apt 46','New York','NY','UNITED STATES','10036-5422','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 01:46:46',0,NULL,3,1,1,1,' \\','dollface18'),(6978,0,110712830563,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',66,'buysia','ljny9','lmontejr9@gmail.com','Louis E Monteforte Jr','4 Wellington Dr','Long Valley','NJ','UNITED STATES','07853-6116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 02:08:37',0,NULL,3,1,1,1,'\r\\ ','ljny9'),(6979,600463012013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','erwintoolman','erwinduffels@hotmail.com','Erwin Duffels','5757 Woodman Ave<br>Apt 102','Van Nuys','CA','UNITED STATES','91401-4488','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 04:08:54',0,NULL,3,1,1,1,'\\ ','erwintoolman'),(6980,814773478012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','iludany','iluminaciondany@hotmail.com','Daniel Perrino','Nogoya 3295','Bs.As.','Ciudad Autonoma de Buenos Aires','ARGENTINA','1417','541145028559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 04:08:56',0,NULL,3,1,3,1,'RA183613633CN\r ','iludany\r盒装的\rOTSO004*2'),(6981,600467848013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',43.5,'eastar4','dcwholesale','admin@dcwholesale.co.nz','DCWHOLESALE','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 04:45:57',0,NULL,3,1,3,1,'RA183613412CN\r ','dcwholesale\rCAB-6060\rCASS003'),(6982,0,110713241797,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',53,'buysia','jimmyjimbo79','ajmal_khan677@yahoo.com','ajmal khan','2309 S Branch Dr','arlington','TX','UNITED STATES','76001-5800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 04:56:48',0,NULL,3,1,1,1,'\\ ','jimmyjimbo79'),(6983,814783860012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','diallodjeri','diallo2074@gmail.com','Abdoulaye Diallo','5401 110th PL NE','Marysville','WA','UNITED STATES','98271-8811','(206) 715-8345','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 05:10:37',0,NULL,3,0,1,1,'\\ ','diallodjeri\r发210TS两个'),(6984,733942404011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','gubbgs','graham.gubb@btopenworld.com','Graham Gubb','3 Cheltenham Road','Porthcawl','Bridgend','UNITED KINGDOM','CF36 3PT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 06:02:39',0,NULL,3,1,3,1,'RA183613267CN\r ','gubbgs\rOMHJ001'),(6985,552329235004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','metaldetector','hv1andrea@gmail.com','Peter Woodland','38 Towerhill rd','Frankston','Victoria','AUSTRALIA','3199','0390175549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 06:58:21',0,NULL,3,1,3,1,'RA183613324CN\r ','metaldetector\rWLAT001+ANTY002'),(6986,600486248013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',39.95,'eastar4','reutnona204','nona204@walla.co.il','reut swid','Moshe sharet 51','netanya','israel','ISRAEL','42245','0525916171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 07:17:08',0,NULL,3,1,3,1,'RA117719995CN\r ','reutnona204\r盒装的\rMOLO008\r黑色的'),(6987,733960532011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','transductor111','transductor1@gmail.com','Jose Luis Alvarez','Rua da Ponte das Caieras, 230<br>Gamboa','Vera Cruz','Bahia','BRAZIL','44470000','(55)(71)87892070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 07:33:41',0,NULL,3,1,2,1,'\\ ','transductor111'),(6988,814805834012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','madebynokia','madebynokia@hotmail.com','Qais Qandil','18221 150th Ave<br>AUH 7966','Springfield Gardens','NY','UNITED STATES','11413-4010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 07:38:08',0,NULL,3,1,1,1,'\\ ','madebynokia'),(6989,733961491011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','buyontour','ebaybuyontour@gmail.com','Theerasak Kumanuwong','468 soi.sathupradit34 sathupradit road<br>bangpongpang yannawa','bangkok','','THAILAND','10120','(081)987-7115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 07:41:04',0,NULL,3,1,2,1,'\\ ','buyontour'),(6990,733965879011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','guilhermefcs','guilherme.fcs@gmail.com','Guilherme Felipe Costa e Silva','Rua: Luiz Bonetti, n1-149<br>Novo Jd. Pagani','Bauru','São Paulo','BRAZIL','17024-474','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 07:55:05',0,NULL,3,1,2,1,'\\ ','guilhermefcs'),(6991,733974837011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','teajay2009','psyco_0666@hotmail.com','Teagan Green','9 la estrada way','port kennedy','Western Australia','AUSTRALIA','6172','0413374421','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-10 08:27:23',0,NULL,3,1,3,1,'RA183613620CN\r ','teajay2009\rOTSO004*2'),(6992,814833982012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','thugbear','tapio@tapiola.nl','Tapio Fransen','Langswater 864','Amsterdam','','NETHERLANDS','1069 EH','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 08:43:23',0,NULL,3,1,2,1,'\\ ','thugbear'),(6993,733992211011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','bodef84','cezar94@freemail.hu','Ferenc Böde','Akaciagården 13.','Göteborg, Angered','','SWEDEN','42439','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 09:24:35',0,NULL,3,1,2,1,'\\ ','bodef84'),(6994,733992352011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','dragonfly250','peterbernstein@web.de','Peter Bernstein','Hubertusweg 16','Bad Hersfeld','','GERMANY','36251','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 09:24:42',0,NULL,3,1,2,1,'\\ ','dragonfly250'),(6995,600518193013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','teazp','tea.zpaviskov@gmail.com','Niksa Paviskov','Rooseveltova 12','Split','','CROATIA','21000','+385989806223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 09:48:50',0,NULL,3,1,2,1,'\\ ','teazp'),(6996,814893527012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','compuman1112','willem_jan_1991@hotmail.com','Willem Jan Waterman','Slufterplantsoen 77','ALMERE','','NETHERLANDS','1316KS','0365340788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 11:22:19',0,NULL,3,1,2,1,'\\ ','compuman1112'),(6997,734036847011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','jad58','john@davey.net.au','John Davey','PMB 22','Kadina','South Australia','AUSTRALIA','5555','0407791372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 11:29:14',0,NULL,3,1,2,1,'\\ ','jad58'),(6998,734033401011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','supersun7721','supersun_heng@hotmail.com','GAN GEN SAINT','UOB(M), 2-6 JALAN TENGAH','PETALING JAYA','SELANGOR','MALAYSIA','46200','0165140221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 11:30:30',0,NULL,3,1,2,1,'\\ ','supersun7721'),(6999,734043454011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','doblumwi','doblum@tds.net','David Blum','205 27th ST','Monroe','WI','UNITED STATES','53566-3511','(608) 325-5753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 11:48:06',0,NULL,3,1,1,1,'\\ ','doblumwi'),(7000,734051194011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','damystoryman','sjors_17@hotmail.com','Sjors Baeten','Calluna 63','Middelbeers','','NETHERLANDS','5091EN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 12:07:53',0,NULL,3,1,2,1,'\\ ','damystoryman'),(7001,0,110713242305,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',42.31,'buysia','1easytrader','craigr@cir-engineering.com','Craig  Rounds','Cir Engineering<br>4817 N Bell Ave','Chicago','IL','UNITED STATES','60625','(865) 405-6892','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 12:37:16',0,NULL,3,1,1,1,'\\ ','1easytrader'),(7002,696188635001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',29.9,'buysia','offtracks1','offtrack@fastmail.fm','Scott Hampton','PO Box 864<br>64130 Cattail Lane','Joseph','OR','UNITED STATES','97846-0864','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 13:24:32',0,NULL,3,1,1,1,'\\ ','offtracks1'),(7003,814951542012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',10.99,'eastar4uk','celtic196666','andyronald@live.co.uk','Andrew Ronald','16 Aldersyde','Taynuilt','Argyll and Bute','UNITED KINGDOM','PA35 1AG','01866822084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 13:41:33',0,NULL,3,1,3,1,'RA183613430CN\r ','celtic196666\rHSMO011+CCMO001'),(7004,552424123004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',129.99,'cnfaner','reggiedxb007','john@podaras.com','John Podaras','Office 312, Building 4, Emaar Business Park<br>Sheikh Zayed Road','Dubai','Dubai','UNITED ARAB EMIRATES','38455','00971508412942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 13:57:45',0,NULL,3,1,3,1,'RA183613695CN\r ','reggiedxb007\rEXLO001'),(7005,734129794011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','mongmunhow87','mongmunhow@hotmail.com','Loh Kar Lai','Blk 146 Rivervale Drive #15-507','default','','SINGAPORE','540146','97725000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 15:16:42',0,NULL,3,1,3,1,'RA183613338CN\r ','mongmunhow87\rCCGR001'),(7006,600628047013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','eurokampe','eurokampe965@hotmail.com','Raul Delgado','Santa Margarida 27, 1º - 4a','CASTELLGALI','Cataluña','SPAIN','08297','648617708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 15:55:09',0,NULL,3,1,2,1,'\\ ','eurokampe'),(7007,815024303012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','iain3294','iain-boyd-stirling@msn.com','Iain Stirling','Lochwood Cottage<br>Drumoak','Banchory','Aberdeenshire','UNITED KINGDOM','AB31 5HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 16:00:54',0,NULL,3,1,3,1,'RA117719933CN\r ','iain3294\rOTGR001'),(7008,815039696012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',63.9,'eastar4','danzzz777777','danziv@gmail.com','Dan Ziv','Haim Vital 9,<br>Apt. 7','Tel-Aviv','','ISRAEL','66088','972-52-4736050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 16:25:09',0,NULL,3,1,3,1,'RA183613559CN\r ','danzzz777777\rMOMI001\r美标'),(7009,546869348003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','geminig54','glyals@cfl.rr.com','GWENDOLYN L. LYALS-MAYS','6895 Powell Rd','WILDWOOD','FL','UNITED STATES','34785-4255','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-10 16:40:16',0,NULL,3,1,1,1,'\\ ','geminig54'),(7010,600664057013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',15.99,'eastar4','honda_rulez','k.teichmann@freenet.de','Klaus Teichmann','Am Heidelberg 7','Train','','GERMANY','93358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 17:25:32',0,NULL,3,1,2,1,'\\ ','honda_rulez\r半高卡'),(7011,734261906011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','rx72245','mshadzx@gmail.com','Mike Hartford','30 Florence st','Hudson','MA','UNITED STATES','01749-2031','(508) 562-2245','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 18:27:28',0,NULL,3,1,1,1,'\\ ','rx72245'),(7012,815159668012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','joseantonio7462','gresazulejo@gmail.com','JOSE ANTONIO GARCIA MARTINEZ','Gasometro 11<br>Portal H 6C','madrid','Madrid','SPAIN','28005','696479151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 18:50:39',0,NULL,3,1,3,1,'RA183613315CN\r ','joseantonio7462\rOTRA001'),(7013,734275715011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'eastar4','tigerred22','lwdigimon@msn.com','Annette Wong','16158 E Elgenia St','Covina','CA','UNITED STATES','91722','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 18:45:37',0,NULL,3,1,1,1,' \\','tigerred22'),(7014,815142983012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','tsmith918','toddchrysti3@sbcglobal.net','TODD SMITH','31 W Ridge Way','BRISTOW','OK','UNITED STATES','74010','(918) 720-5797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 18:29:49',0,NULL,3,1,1,1,'\\ ','tsmith918'),(7015,815145019012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',21.99,'eastar4uk','pjmfin','pekkamaki@kolumbus.fi','Pekka Mäki','Käkipolku 9','Vantaa','Finland','FINLAND','01450','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 18:30:53',0,NULL,3,1,3,1,'RA183613390CN\r ','pjmfin\rWWSI002+ANCN001'),(7016,734304561011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','flandres_xavier','xavier_hans@hotmail.fr','Xavier Hans','Appartement 224<br>24 rue Gabriel Péri','Marcq-En-Baroeul','Nord-Pas-de-Calais','FRANCE','59700','0612155633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 19:22:59',0,NULL,3,1,3,1,'RA183613409CN\r ','flandres_xavier\r\rUDAP002\r'),(7017,600747215013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','tregdos','tregdos@icpnet.pl','Tomasz Regdos','ul. Jugosłowiańska 54g/32','Poznań','wielkopolskie','POLAND','60-149','601 545464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 19:36:52',0,NULL,3,1,2,1,'\\ ','tregdos\r新的'),(7018,600822120013,230620799040,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',1,'HSSA004',13.99,'eastar4','agusta212','alezoyr@yahoo.gr','alevizakis ioannis','thessalonikis 19','voula athens','greece','GREECE','16673','00306937263898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 23:11:06',0,NULL,3,1,2,1,'\\ ','agusta212\r欧标\r银色的'),(7019,734422721011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','pbarrera','pedrobarrera@mac.com','Pedro Barrera','Paseo Zona Franca 142,3º,1ª','Barcelona','Cataluña','SPAIN','08038','654090070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 23:35:17',0,NULL,3,1,2,1,'\\ ','pbarrera'),(7020,600830823013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','ajkauffma','akauffma@q.com','Austin Kauffman','9278 W Vandeventor Dr','Littleton','CO','UNITED STATES','80128-7306','(720) 670-7979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 23:51:31',0,NULL,3,1,1,1,'\\ ','ajkauffma'),(7021,815332502012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','sergiostonecold','checho1973@hotmail.com','Sergio Miño','Ramon sotomayor 10685<br>la florida','santiago','','CHILE','8310005','56-2-3154502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 00:27:19',0,NULL,3,1,3,1,'RA183613284CN\r ','sergiostonecold\rOTRA001'),(7022,600845592013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',70.96,'eastar4','luccajr','cabaritti@uol.com.br','Messias Lucca Cabaritti Jr','Rua Joaquim de Almeida 55 apto 121','Sao Paulo','Sao Paulo','BRAZIL','04050-010','55-11-8254.6650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 00:54:47',0,NULL,3,1,3,1,'RA117720004CN\r ','luccajr\r\rMOSA002\r'),(7023,600846785013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','narinderkumar','kumar_narinder@hotmail.com','Narinder Kumar','3076 N Filbert Ave','Fresno','CA','UNITED STATES','93727','(559) 451-7546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 00:57:39',0,NULL,3,1,1,1,'\\ ','narinderkumar'),(7024,734445877011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','onepsycodad','onepsycodad@optonline.net','KEITH','839 Middle Country Rd','SELDEN','NY','UNITED STATES','11784-2507','(631) 698-4455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 00:58:53',0,NULL,3,1,1,1,'\\ ','onepsycodad'),(7025,815344995012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','dascottishginger','scottish.ginger@gmail.com','Ross Brown','57 Douglas Cres<br>Barrgarran','Erskine','Renfrewshire','UNITED KINGDOM','PA8 6BL','01418124533','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 01:05:24',0,NULL,3,1,3,1,'RA183613443CN\r ','dascottishginger\rOTHP003'),(7026,600849346013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','cl05012010','lil_chavy@yahoo.com','Lina N.','3201 Nottage Ln','Falls Church','VA','UNITED STATES','22042-3811','(571) 315-7904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 01:14:40',0,NULL,3,1,1,1,'\\ ','cl05012010'),(7027,0,180692062340,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',18.98,'au-buy','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 01:26:05',0,NULL,5,0,18,0,NULL,'segalu\rOrdered by Jiangang, No need to ship'),(7028,815394118012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','decorso1','decorso1@hotmail.com','Steven DeCorso','1A Ryan Avenue','Firle','South Australia','AUSTRALIA','5070','0884310713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 03:58:53',0,NULL,3,1,2,1,'\\ ','decorso1'),(7029,815396551012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','wongwong1205','cindyhui8@hotmail.com','Cindy Hui','6 Dogwood Ln<br>Apt B','Glen Cove','NY','UNITED STATES','11542-3986','(718) 219-9336','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 04:12:35',0,NULL,3,1,1,1,'\\ ','wongwong1205'),(7030,734507798011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','jeska_miller17','the_rundown34@hotmail.com','Jessica Wells','1 Anchor Close Ballajura','Perth','Western Australia','AUSTRALIA','6066','080430566634','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 05:19:20',0,NULL,3,1,2,1,'\\ ','jeska_miller17\r紫色的'),(7031,600899190013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',5,'CACN004',65,'eastar4','thai_vy','joliedinh@gmail.com','Vy  Dinh Thao','C45 Cu Xa Vinh Hoi, Phuong 5, Quan 4','Ho Chi Minh','Ho Chi Minh','VIET NAM','054','(+84) 938206866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 05:45:46',0,NULL,3,1,3,1,'RA183613474CN\r ','thai_vy\rCACN004'),(7032,734502730011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','boerdejb','nicojarm@hotmail.com','J.B. de Boer','Griftdijk 25','Nijmegen','','NETHERLANDS','6515AE','0243236383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 06:59:26',0,NULL,3,1,2,1,'\\ ','boerdejb'),(7033,0,180692062158,'New Griffin PowerJolt Dual USB Micro Car Charger',1,'CCGR001',14,'au-buy','radovan_h','radovan.hrebicek@gmail.com','Radovan Hrebicek','Vyšehradská 12','Bratislava','','SLOVAK REPUBLIC','85101','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 09:03:29',0,NULL,3,1,3,1,' RA183613205CN\r','radovan_h\rCCGR001'),(7034,600931841013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','cmchen0','jimmy.chen1013@gmail.com','Jimmy Chen','8329 Edgebrook Drive N.W','Calgary','AB','CANADA','T3A 4Z7','(403) 686-4717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 09:31:06',0,NULL,3,1,3,1,'RA183610190CN\r ','cmchen0\rOTSO004*4\r盒装的'),(7035,600937530013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','bighelmet1','ketzalsterling@gmail.com','Ketzal Sterling','2/25 Thatcher St<br>Mission Bay','Auckland','None','NEW ZEALAND','1071','6421536665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 10:02:43',0,NULL,3,1,2,1,'\\] ','bighelmet1'),(7036,815472681012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','bgeno','bgenostore@gmail.com','Tolo Genovard','Nuredduna 17, 10\'A','Palma','Baleares','SPAIN','07006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 10:06:29',0,NULL,3,1,2,1,'\\ ','bgeno'),(7037,815473613012,220705174913,'Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO014',16.95,'eastar4uk','shamu3264','moe2749@yahoo.com','shams azam','32 highfield drive','royton','oldham','UNITED KINGDOM','ol2 6af','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 10:08:32',0,NULL,3,1,3,1,'RA183610172CN\r ','shamu3264\rHSMO014'),(7038,815477042012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','gaelellon','mailtoalli@mail.ru','Alexey Likhachev','Otkrytoe shosse<br>3-4-57','Moscow','Moscow','RUSSIAN FEDERATION','107370','+79161613741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 10:26:51',0,NULL,3,1,2,1,'\\ ','gaelellon'),(7039,734571166011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','fishface1504','fishface1504@aol.com','Stephanie Lewis','CMR 427 Box 77','APO','AE','AA','09630 0001','702-516-4524','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 10:27:02',0,NULL,3,1,1,1,'\\ ','fishface1504\r红边优联'),(7040,815499156012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','sandrafan','al.ward@gmail.com','Allan C. Ward','30 Fidller\'s Green St','Kirkland','QC','CANADA','H9H 3G8','(514) 630-3787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 11:37:59',0,NULL,3,1,3,1,'RA183610155CN\r ','sandrafan\rGLSG001*4'),(7041,600960889013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ray260250','rel89556@bigpond.net.au','ray ellis','214 ritchie road','pallara','Queensland','AUSTRALIA','4110','0733723073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:05:34',0,NULL,3,1,2,1,'\\ ','ray260250'),(7042,733247186011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',239.98,'eastar4','hcapobianco11','hcapobianco@hotmail.com','hernan capobianco','Avenida Corrientes 1386<br>2','Buenos Aires','Capital Federal','ARGENTINA','C1043ABN','5911961287423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:11:29',0,NULL,3,1,3,1,'RA183610067CN\r ','hcapobianco11\rGLSG001*2'),(7043,600962408013,230623270363,'NIB 3D Active Shutter TV Glasses with IR emitter',2,'GLOT002+GLOT003',170,'eastar4','eug3d','panimaskin@gmail.com','Evgeniy Panimaskin','Lebedeva 105-127','Tomsk','Tomsk region','RUSSIAN FEDERATION','634021','+7-913-804-55-15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:19:10',0,NULL,3,1,3,1,'RA183619790CN ','eug3d\rGLOT002+GLOT003\r盒装的'),(7044,600964155013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',37.9,'eastar4','justruss413','justruss@gmail.com','Stefanie Beil C/O Russ Juskalian','Schumacherring 7','Munich','','GERMANY','81737','(413) 256-8017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:19:17',0,NULL,3,1,3,1,'RA183610141CN\r ','justruss413\rMOLO004\r华硕限量版\r'),(7045,734608091011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','jr_baz','baz@hartu.net','José Ramón Baz Toribio','Guatemala 5, 2Dcha','Vitoria-Gasteiz','País Vasco','SPAIN','01012','609900805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:40:53',0,NULL,3,1,3,1,'RA183610124CN\r ','jr_baz\rUDAP002'),(7046,600970431013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','ndterpstra','nate.terpstra@gmail.com','Nate Terpstra','6040 Carrollton Ave','Indianapolis','IN','UNITED STATES','46220-1921','(317) 250-9582','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 12:51:16',0,NULL,3,1,1,1,'\\ ',''),(7047,815530059012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','midders3','markmidderigh@gmail.com','Mark Midderigh','12 Ruthven Close, Cuckfield','Haywards Heath','West Sussex','UNITED KINGDOM','RH175HE','01444452602','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 13:15:15',0,NULL,3,1,3,1,'RA183610115CN\r ','midders3\rOTCN003'),(7048,734621424011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','pferic','richard.pfeffer@online.de','Richard Pfeffer','Moosweg 17','Karlsfeld','','GERMANY','85757','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:26:23',0,NULL,3,1,2,1,'\\ ','pferic'),(7049,600980095013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',1,'WLIN009',15.99,'eastar4','nhienhuong','quanghaihcm@gmail.com','Tran Quang Hai','201A No Trang Long. Phuong 12.  Quan Binh Thanh','Ho Chi Minh City','Viet Nam','VIET NAM','717066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:36:35',0,NULL,3,1,2,1,'\\ ','nhienhuong\r半高卡新的'),(7050,600981776013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.76,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:42:02',0,NULL,3,1,3,1,'RA183610138CN\r ','small.mac\rWLAP008'),(7051,600984085013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',11.99,'eastar4','dionissb','belkanov@gmail.com','Denis Belkanov','Strokina str. 12 flat 281','Nizhniy Novgorod','','RUSSIAN FEDERATION','603138','952-464-7657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:57:00',0,NULL,3,1,2,1,'\\ ','dionissb\r新的'),(7052,734198716011,320692106584,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',99.99,'eastar4','xxxvergilxxx','ff_freak@hotmail.es','Nicolas Ledesma','Cafferata 4745','Buenos Aires','Caseros','ARGENTINA','1678','01147166174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:57:32',0,NULL,3,1,3,1,'RA183610230CN ','xxxvergilxxx\rOTSO003'),(7053,734632615011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','amaritimer','chris@fuzz.ca','Christian Hochhold','221 Meadow View Way','Belnan','NS','CANADA','B2S 3K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 14:04:41',0,NULL,3,1,2,1,'\\ ','amaritimer'),(7054,814308585012,220456476892,'IBM Thinkpad 2nd HDD Caddy SATA SATA2 T60 T61 T42 T41',1,'CACN001',19.9,'eastar4','chowtw454','chowtw@gmail.com','Tuck Woh Chow','9 Rivervale Crescent<br>#04-29','default','','SINGAPORE','545086','65-97318851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 14:24:18',0,NULL,3,1,3,1,' RA183610915CN','chowtw454\rCACN001'),(7055,815558071012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','sunspark20','pcman101@verizon.net','lee eubanks','1841 lincoln ave','Northampton','PA','UNITED STATES','18067-1504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 14:37:43',0,NULL,3,0,1,1,'\\ ','sunspark20\r发210TS两个'),(7056,815573737012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','evoredy','aneesh.patel@us.army.mil','Aneesh Patel','B CO 615TH ASB, 1ACB, 1CD<br>CAMP MARMAL, AFGHANISTAN','APO','AE','AA','09368','(408) 997-7991','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 15:26:35',0,NULL,3,1,1,1,'\\ ','evoredy'),(7057,696476019001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','fussy1teacher','fussythe1@embarqmail.com','R Fuss','4012 Villa Flora St','Las Vegas','NV','UNITED STATES','89130','(702) 399-6689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 15:42:28',0,NULL,3,1,1,1,'\\ ','fussy1teacher'),(7058,601015844013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',79.98,'eastar4','darius13231','darius.z@splius.lt','Darius Zarauskas','Dariaus ir Girėno g. 44-11','Radviliskis','','LITHUANIA','LT-82139','+37061644848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 15:57:51',0,NULL,3,1,3,1,'RA183610186CN\r ','darius13231\r欧标\rHSNO019'),(7059,601023166013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','kaaron','kaaron2k2@aol.com','Kenny Adamides','40 Woodlawn St<br>Apt 1','New Bedford','MA','UNITED STATES','02744-1527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 16:23:28',0,NULL,3,1,1,1,'\\ ','kaaron'),(7060,547214292003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',70.9,'cnfaner','pokkjk','ebay@localtip.info','Jürgen Kopp','Am Kirschrain 9 a','Kassel','','GERMANY','34128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 16:36:09',0,NULL,3,1,3,1,'RA183611005CN ','pokkjk\rMOSA003'),(7061,734698377011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',45.8,'eastar4','julia_eugen','julia-eugen@rambler.ru','Eugen Fischer','Hederichsweg 6','Bergrheinfeld','','GERMANY','97493','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:09:02',0,NULL,3,1,3,1,'RA183610994CN ','julia_eugen\rHSSE004\r欧标\r'),(7062,815622460012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','jmiro1','jmirous@yahoo.com','James Mirous','4035 Crystal Lane Loop SE','Puyallup','WA','UNITED STATES','98372-4211','(253) 848-2421','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 17:16:17',0,NULL,3,1,1,1,'\\ ','jmiro1'),(7063,734707421011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',5,'HSJA006',69.75,'eastar4','ac-rnd','a-chernatinskiy@yandex.ru','A Chernatinskiy','ulica Stal\'skogo<br>dom 74A kv 9','Rostov-na-Donu','','RUSSIAN FEDERATION','344009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:30:49',0,NULL,3,1,3,1,'RA183611717CN ','ac-rnd\r欧标\rHSJA006'),(7064,734713194011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','fabien_666_667','fabien.champeau@gmail.com','fabien champeau','7 rue des prevoyants de l\'avenir','lyon','Rhône-Alpes','FRANCE','69003','08 70 62 68 82','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:47:19',0,NULL,3,1,2,1,'\\ ','fabien_666_667'),(7065,734723893011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','bam123glass','ian_bamforth@yahoo.co.uk','Ian Bamforth','208 Brettell Lane','Stourbridge','West Midlands','UNITED KINGDOM','DY8 4BG','01384357129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 18:03:43',0,NULL,3,1,2,1,'\\ ','bam123glass'),(7066,601055989013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','georgebit','george_bitloglou@yahoo.gr','Georgios Bitloglou (AVIN)','Giannitson 95-97<br>Thessaloniki','Thessaloniki','','GREECE','54628','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 18:11:22',0,NULL,3,1,2,1,'\\','georgebit'),(7067,601059405013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','ataraharari','ataradelicious@yahoo.com','atara harari','1612 gracie girl way','wake forest','NC','UNITED STATES','27587-5941','(713) 505-9172','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 18:16:38',0,NULL,3,1,1,1,'\\ ','ataraharari\r兼容型3D眼镜 通用型'),(7068,601029783013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',87,'eastar4','sinam_fr','motamed@free.fr','sina motamed','207 impasse  guerin','marck','Nord-Pas-de-Calais','FRANCE','62730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 18:21:54',0,NULL,3,1,3,1,'RA183610861CN ','sinam_fr\rCAB-6060\rCASS003'),(7069,815647057012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','i_am_steph','stephane.barthelemy@neuf.fr','stephane barthelemy','52 rue de Verdun','SURESNES','Île-de-France','FRANCE','92150','01.42.04.53.68','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 18:24:10',0,NULL,3,1,2,1,'\\ ','i_am_steph'),(7070,734736460011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','tlawler3','tim@lawlergroup.com','Tim Lawler','1333 W Towne Square Rd','Mequon','WI','UNITED STATES','53092-5047','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 18:39:25',0,NULL,3,1,1,1,'\\ ','tlawler3'),(7071,734753426011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','tarsis1997','tarsisjonas@gmail.com','Jeeva Muhanthan','Fabersvej 98','Holstebro','standard','DENMARK','7500','31726398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 19:03:33',0,NULL,3,1,2,1,'\\ ','tarsis1997\r罗技M950鼠标外壳'),(7072,734766841011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','dkorbee','dkorbee@tiscali.nl','Duncan Korbee','Leeghwaterstraat 15','Schoonhoven','','NETHERLANDS','2871 PC','06-55196193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 19:29:25',0,NULL,3,1,2,1,'\\ ','dkorbee'),(7073,815690157012,220640475896,'NEW in box AuthenTec BioReader slide sensor base',1,'OTAU001',37.18,'eastar4','roosta-boy','steve@jgntsteve.com','Steve Wright','14 Burghley Close','Ipswich','Suffolk','UNITED KINGDOM','IP2 9BX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 19:31:05',0,NULL,3,1,3,1,'RA183610022CN\r ','roosta-boy\rOTAU001\r再发一个 CAB-6060 \r和10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white白色的\r\r'),(7074,815695127012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',10,'OTAP001',142.35,'eastar4','virblue','eba@virtualblue.net','Elisabeth Ochoa','7290 NW 66th St','MIAMI','FL','UNITED STATES','33166-3008','(305) 471-0203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 19:32:04',0,NULL,3,1,1,1,'\\ ','virblue\r一共买了15个'),(7075,734774276011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','donkitch','donkitchen@gmail.com','Don Kitchen','5614 Catoctin Ridge Dr','Mount Airy','MD','UNITED STATES','21771-6010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 19:43:19',0,NULL,3,1,1,1,'\\ ','donkitch'),(7076,734785462011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','monster0k','monstry@gmail.com','Marina Makarenko','Pobediteley ave., 47-1-106','Minsk','','BELARUS','220035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 20:11:34',0,NULL,3,1,3,1,'RA183610963CN\r ','monster0k\rWWSI002+ANCN001'),(7077,734805393011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','norvet1','norvetone@norvet.com','Frank Virga','207 China Grade Loop','Bakersfield','CA','UNITED STATES','93308-1707','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 20:45:53',0,NULL,3,1,1,1,'\\ ','norvet1'),(7078,547304179003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','lee.anderson','pacecar1986@gmail.com','Lee Anderson','8851 N. Oracle Road # 48','Oro Valley','AZ','UNITED STATES','85704','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-11 21:06:42',0,NULL,3,1,1,1,'\\ ','lee.anderson'),(7079,601126298013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','kfjelle','kim_fjelle@hotmail.com','Kim Fjelle Hagen','Hjellbakkveien 1','sunndalsora','sunndalsora','NORWAY','6600','97619728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 21:25:23',0,NULL,3,1,2,1,'\\ ','kfjelle'),(7080,734824489011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',4,'RELO002',51.88,'eastar4','usr701','r.rainchot@aon.at','Rudolf Rain-Chot','Babenbergersee 180','Münchendorf','','AUSTRIA','2482','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 21:29:28',0,NULL,3,1,3,1,'RA183610209CN\r ','usr701\rRELO002'),(7081,734824807011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','nenifd','ffdadalto@gmail.com','Franchescolle Dadalto','Av Cel Manoel Nunes 55<br>Jardim Tropical','Serra','Espirito Santo','BRAZIL','29162-010','(321) 831-11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 21:30:35',0,NULL,3,1,2,1,'\\ ','nenifd'),(7082,696876381001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','josh6981','josh6981@hotmail.com','Joshua mohler','1453 Cantwell Ln<br>Apt 3','Swansea','IL','UNITED STATES','62226-7606','(618) 604-9091','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 22:04:32',0,NULL,3,1,1,1,'\\ ','josh6981'),(7083,815775030012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','heliojr-pe','heliojr@hotmail.com','Helio Ribeiro dos Santos Junior','Caixa Postal 142<br>Nossa Senhora das Dores','Caruaru','Pernambuco','BRAZIL','55002-970','+55 81 91221802','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:23:28',0,NULL,3,0,2,1,'\\ ','heliojr-pe\r发210TS一个'),(7084,734843237011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','vettemorkieguy','david.levin@live.ca','DAVID LEVIN','3525 KARIYA DRIVE APT 212','MISSISSAUGA','ON','CANADA','L5B 0C2','(416) 201-9277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:24:49',0,NULL,3,1,2,1,'\\ ','vettemorkieguy'),(7085,601144869013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',3,'HSNO019',119.97,'eastar4','nrs1873','nrs73@yandex.ru','Радик Наниев','ул.Палехская<br>дом 15,кв.73','Москва','','RUSSIAN FEDERATION','129337','(962)9997373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:26:27',0,NULL,3,1,3,1,'RA183611561CN\r ','nrs1873\rHSNO019\r欧标'),(7086,815785638012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','mczyngie','mczyngie@gsb.uchicago.edu','CHARLES R ZYNGIER','8395 SW 73rd Ave<br>C/O Carla Hala Apt 104','MIAMI','FL','UNITED STATES','33143-7526','(305) 515-6216','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 22:54:33',0,NULL,3,1,1,1,'\\ ','mczyngie\r盒装的'),(7087,734862020011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','2010*pavel','pavel.lazarov@gmail.com','Pawel Lazarow','Vasil Levski 248A/KORMORAN','Plovdiv','Plovdiv','BULGARIA','4000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 23:32:33',0,NULL,3,1,2,1,'\\ ','2010*pavel'),(7088,734602775011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'eastar4','monroe5','psheafive@aol.com','Patricia Shea','5 Monroe Pl','Cranbury','NJ','UNITED STATES','08512-2711','(609) 655-3293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 23:40:52',0,NULL,3,1,1,1,'\\ ','monroe5'),(7089,601164406013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','kgunn','kgunn20@yahoo.com','kenisha gunn','1807 s warren st','South Bend','IN','UNITED STATES','46613-1256','(574) 367-1320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 00:01:24',0,NULL,3,1,1,1,'\\ ','kgunn\r黑色的'),(7090,734883409011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',4,'CASS001',34.8,'eastar4','uberisuber','morbois@gmail.com','Adam Pavlov','Level 5/45 Jones Street<br>Ultimo','Sydney','New South Wales','AUSTRALIA','2007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 01:04:48',0,NULL,3,1,3,1,'RA183610929CN ','uberisuber\rCASS001'),(7091,734889596011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','ricojd001','tecnoseg@tecnoseg.com.br','Ricardo Jabra Daud','Rua Urimonduba 127 - 8<br>Tel. +55(11)3167-2121','Sao Paulo','Sao Paulo','BRAZIL','04530-080','+55(11)3167-2121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 01:31:13',0,NULL,3,1,2,1,'\\ ','ricojd001'),(7092,734890632011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','raymondcardwell','raymondcardwell@msn.com','Raymond Cardwell','616 Hihgland Avenue','Mullens','WV','UNITED STATES','25882','(304) 294-7178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 01:34:19',0,NULL,3,1,1,1,'\\ ','raymondcardwell'),(7093,734895884011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','vinh159','vinhha15@msn.com','Bao V Ha','25 Edward St','Bankstown','New South Wales','AUSTRALIA','2200','0297080386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 01:57:43',0,NULL,3,1,2,1,'\\ ','vinh159'),(7094,0,110712830657,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',61.09,'buysia','plocsworld','ploc14@midsouth.rr.com','Alex Jarrett','5194 warfield dr','memphis','tn','UNITED STATES','38117-2130','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 02:10:45',0,NULL,3,1,1,1,'\\ ','plocsworld'),(7095,815838639012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','assistedtravel','ceo@jjadvantage.com','James Ackley','24449 arrowhead dr','Manhattan','IL','UNITED STATES','60442-1452','(708) 362-8001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 02:18:47',0,NULL,3,1,1,1,'\\ ','assistedtravel'),(7096,547365735003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','1996bailey5','roselinereed@hotmail.com','Roseline Reed','64 Andrews Ct','Lewisburg','PA','UNITED STATES','17837-6509','(570) 522-9967','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-12 02:35:54',0,NULL,3,1,1,1,'\\ ','1996bailey5'),(7097,0,180692062173,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',8.99,'au-buy','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-12 02:43:54',0,NULL,5,0,18,0,NULL,'segalu\rjiangang下的单，不用发\r'),(7098,601196577013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','alesya1900','bestregards2u@gmail.com','Inna Stafeychuk','15 Royal Palm Way<br>Unit 108','Boca Raton','FL','UNITED STATES','33432-7807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 02:56:52',0,NULL,3,1,1,1,'\\ ','alesya1900'),(7099,734917520011,320679575651,'UNLOCKED DELL HS2300 MC8775 WWAN 3G not HP+antenna',1,'WWSI001+ANCN001',24.9,'eastar4uk','ghostfighter22','yugincruz22@yahoo.co.uk','Eugene Cruz','21 Conan Doyle Walk','Swindon','Wiltshire','UNITED KINGDOM','SN3 6JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 03:38:49',0,NULL,3,1,3,1,'RA183610985CN ','ghostfighter22\rWWSI001+ANCN001'),(7100,734917883011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'eastar4','luvdance2','nikki.aspiras@hotmail.com','Nicole Aspiras','8130 Crystal Walk Cir','Elk Grove','CA','UNITED STATES','95758','(916) 204-8831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 03:42:08',0,NULL,3,1,1,1,'\\\r ','luvdance2\r地图伞 '),(7101,734924246011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.81,'eastar4','alfatfat','alfatfat@gmail.com','Law Sek Lun','Flat M, 17/F, Century Centre<br>33-35 Au Pui Wan Street, Fotan','default','','HONG KONG','default','852 94920106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 04:14:43',0,NULL,3,1,2,1,'\\ ','alfatfat\r旧的'),(7102,734936511011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','kdm4549','k.messinger@flashcable.ch','Klaus Messinger','Geeracherstrasse 17','Spreitenbach','','SWITZERLAND','8957','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 05:26:03',0,NULL,3,1,2,1,'\\ ','kdm4549'),(7103,734942771011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','exfury92','lame.pimpi92@gmail.com','Bence Pimper','Ifjúság street 7/c','Balatonfüred','Veszprém','HUNGARY','8230','0036702469172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 06:04:22',0,NULL,3,1,2,1,'\\ ','exfury92'),(7104,815792754012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','davidaldrichb','davidaldrichblake@hotmail.com','David Aldrich-Blake','36E Nevern Square','London','London','UNITED KINGDOM','SW5 9PE','07736868973','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 06:35:40',0,NULL,3,1,3,1,'RA183610169CN\r ','davidaldrichb\rRELO002'),(7105,600979968013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',186.96,'eastar4','cc_ian','cchsieh.net@gmail.com','Chih-Cheng Hsieh','寶山鄉水仙路168巷95號','新竹縣','','TAIWAN','308','0932509321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 06:42:52',0,NULL,3,1,14,1,'301075660466 ','cc_ian\r\r再发一个2000C\r\r\r\r'),(7106,734950052011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','ekvilla','ekvilla85@hotmail.com','Eric Villaruz','31311 10th Ave S','Federal Way','WA','UNITED STATES','98003','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ekvilla'),(7107,734953544011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','um4ng','um4ng@msn.com','Umang Patel','9 Foxley Hill Road','Purley','Surrey','UNITED KINGDOM','CR8 2HD','02032512057','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 07:04:47',0,NULL,3,1,3,1,'RA183610977CN\r ','um4ng\rUDAP001'),(7108,601230268013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','cowboy_marlboro','cowboy.marlboro2@gmail.com','Yaskevich Pavel','Lyn\'kova str. 17a-21','Minsk','','BELARUS','220104','+375296567300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 07:09:01',0,NULL,3,1,3,1,' RA183611592CN\r','cowboy_marlboro\rHSNO019\r欧标'),(7109,553005961004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',129.99,'cnfaner','jcvitaux','jc.vitaux@hotmail.fr','jean-charles vitaux','56 grande rue','beauchamps','Picardie','FRANCE','80770','06 16 16 91 95','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 07:13:39',0,NULL,3,1,3,1,'RA183610053CN\r ','jcvitaux\rEXLO001'),(7110,734961329011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','johnlee-88','johnlee1988@gmail.com','John Lee','2055 Windemere Way','Upland','CA','UNITED STATES','91784','(909) 532-9968','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 07:43:32',0,NULL,3,1,1,1,'\\ ','johnlee-88'),(7111,601236126013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','sontin0','sandoraizer@gmail.com','Aleksandre Lasareishvili','Palachovo Namesti 2, AT&T','Brno','Moravia','CZECH REPUBLIC','625 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 07:49:54',0,NULL,3,1,2,1,'\\ ','sontin0\rCAB-6060'),(7112,734982744011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',8.99,'eastar4','leonardolalala','amityosuv@gmail.com','amit yosuv','Dr. Arthur Biram 11/36','Haifa','','ISRAEL','34986','+972549911968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 09:27:59',0,NULL,3,1,2,1,'\\ ','leonardolalala'),(7113,601252880013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','evcrest','sysadmin@kagazy.kz','Yevgeniy Kuzmenko','Zhetysu-3, 16, 21','Almaty','Almaty','KAZAKHSTAN','050063','+7 (727) 2262798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 09:38:53',0,NULL,3,1,3,1,'RA183610212CN\r ','evcrest\rGLOT001*2\r兼容型3D眼镜 通用型'),(7114,697022647001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','huubenewa','vlihuu@planet.nl','Huub Vlis van der','G. Bootsmastraat 35','Lemmer','','NETHERLANDS','8531EN','0514565168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 09:52:49',0,NULL,3,1,3,1,'RA183610773CN\r ','huubenewa\rBR3D005'),(7115,815950845012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','msw1478','msw1478@gmail.com','Mattias Greenbaum','Seedri 43<br>Karla küla','Harjumaa,','Rae vald,','ESTONIA','75326','(372)5182061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 10:53:14',0,NULL,3,1,3,1,'RA183610858CN\r ','msw1478\rWWOT002\r IBM版 二手'),(7116,601283514013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','22ptitsa11','22ptitsa@gmail.com','Andrii Gorobets','Kudryashova  7, kv 104','Kyiv','','UKRAINE','03035','+380672739494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 12:22:58',0,NULL,3,1,2,1,'\\ ','22ptitsa11'),(7117,601288142013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','unimaster30','oforestieri@hotmail.com','Omar Forestieri','Mendez de Andes<br>#460 Apt. ¨B ¨','buenos aires','capital','ARGENTINA','1405','541149042277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 12:50:54',0,NULL,3,1,3,1,'RA183610800CN\r ','unimaster30\rOTSO004*4\r盒装的'),(7118,815988080012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','haodred','basilemnsk@yahoo.com','Vasiliy Shatohin','ul. Timiryazeva d.9 kv.85','Minusinsk','Krasnoyarskiy Kray','RUSSIAN FEDERATION','662603','+79135214578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 13:01:10',0,NULL,3,1,2,1,'\\ ','haodred\r蕾丝蝴蝶结伞 '),(7119,553063778004,140550602407,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.9,'cnfaner','fatboyjez','jeremy@emailcrazy.net','Jeremy D Shepherd','33 ruddle way<br>Langham','Oakham','Rutland','UNITED KINGDOM','LE157NZ','01572722067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 13:18:53',0,NULL,3,1,3,1,'RA183610787CN\r ','fatboyjez\rUDAP002'),(7120,735042938011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','adrideb72','cutsiepie32@aol.com','Adriana Mitchell','10825 E Keswick Rd<br>Apt 228','Philadelphia','PA','UNITED STATES','19154-4133','(215) 280-6362','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 13:19:59',0,NULL,3,1,1,1,'\\ ','adrideb72'),(7121,601308134013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',33.99,'eastar4','gaansan1','gaansan@gmail.com','Antonio Bernhard','Strecia di Massari 1','Morcote','','SWITZERLAND','6922','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 14:17:02',0,NULL,3,1,3,1,'RA183610844CN\r ','gaansan1\rWWSI004+ANCN001'),(7122,735071485011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','delsnd','delsnd@wp.pl','dariusz lichacz','pulawska 465<br>IMS S.A.','warsaw','mazowieckie','POLAND','02-844','22 7578172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 14:57:12',0,NULL,3,1,3,1,'RA183610827CN\r ','delsnd\rWWSI002+ANCN001'),(7123,735072759011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','dantiques01','dparker224@aol.co.uk','daniel parker','48, prince arthur street,','barnsley','South Yorkshire','UNITED KINGDOM','s75 2ar','01226201399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 15:00:37',0,NULL,3,1,2,1,'\\ ','dantiques01'),(7124,735074086011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','amoeba1911','amoeba@cinci.rr.com','Emre Yucel','9713 Russline Dr','Loveland','OH','UNITED STATES','45140','(513) 886-1013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 15:05:14',0,NULL,3,1,1,1,'\\ ','amoeba1911'),(7125,601336742013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','grinccaffe','grinccaffe@gmail.com','damir gracin','srebrnjak 17','zagreb','','CROATIA','10000','+00385952333743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 16:11:01',0,NULL,3,1,3,1,'RA183610795CN\r ','grinccaffe\rMOLO009\r旧的  欧标'),(7126,601340847013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','rodneyrporter','rkaysville@aol.com','Rodney Porter','281 E 550 S','Kaysville','UT','UNITED STATES','84037-2569','(801) 546-4403','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 16:29:05',0,NULL,3,1,1,1,'\\ ','rodneyrporter\r兼容型3D眼镜 通用型'),(7127,553107759004,140482633073,'New GENUINE NOKIA BH-209 BLUETOOTH HEADSET track#',1,'HSNO011',19.99,'cnfaner','shiransbay','shiranfernan@gmail.com','Shiran Fernando','International Division, Level 18, HNB Towers,<br>No. 479, T B Jayah Mawatha,','Colombo 10.','WP','SRI LANKA','01000','+94773511955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 16:39:40',0,NULL,3,1,3,1,'RA183610892CN\r ','shiransbay\rHSNO011'),(7128,601346791013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','a_plaridel','a_plaridel@hotmail.com','arturo del pilar','201 Carmen Ln<br>Apt 17','Santa Maria','CA','UNITED STATES','93458-7730','(805) 287-9243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 16:47:22',0,NULL,3,1,1,1,'\\ ','a_plaridel\rCAB-6060'),(7129,816077649012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','kassol','kassol@uol.com.br','Ronaldo Mattiello','Rua Rio Grande do Sul, 445','São Caetano do Sul','São Paulo','BRAZIL','09510020','55-11-4227-4185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 17:08:09',0,NULL,3,1,3,1,'RA183610813CN\r ','kassol\rGLOT001*2\r兼容型3D眼镜 通用型'),(7130,601377638013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','katzs','4katzs@gmail.com','Shlomo and Gilit KATZ','Emek Haela 71/1','\'Modi\'in','ISRAEL','ISRAEL','71723','(+972)506212080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 18:25:15',0,NULL,3,1,2,1,'\\ ','katzs'),(7131,601379998013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','penfound2004','colin_penfound@yahoo.co.uk','Colin Penfound','21 Beechwood Ave<br>Bottisham','Cambridge','Cambridgeshire','UNITED KINGDOM','CB25 9BE','01223813553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 18:30:47',0,NULL,3,1,2,1,'\\ ','penfound2004\rCAB-6060'),(7132,735162259011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','billhinge','bill1664@hotmail.com','Bill Hinge','Southbrook<br>Redlake Lane Gardeners Green','Wokingham','Berks','UNITED KINGDOM','RG40 3BF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 18:46:55',0,NULL,5,0,18,0,NULL,'billhinge\r客户要撤单'),(7133,816138370012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','eitkin','emii@mail.ru','Evgeny Itkin','31 korp 1 kv 5<br>Bolshaya Serpukhovskaya ul.','Moscow','Moscow','RUSSIAN FEDERATION','115093','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 19:16:29',0,NULL,3,1,2,1,'\\ ','eitkin'),(7134,816143480012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','helicopter_eades','helicopter.eades@gmail.com','Jason Eades','899 Broad St','Summersville','WV','UNITED STATES','26651','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 19:24:05',0,NULL,3,1,1,1,'\\ ','helicopter_eades\r黑色的'),(7135,601406117013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','alexcms','alexsalame@gmail.com','Alex Cezar Silva','Tv. Mariz e Barros N 2685 apto 1401','Belém','PA','BRAZIL','66080-471','5509132269077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 19:43:21',0,NULL,3,1,2,1,'\\ ','alexcms'),(7136,547565256003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',15.99,'cnfaner','wlt_jr','wlt_jr@yahoo.com','Walt Travers','5637 Beach Haven Rd','East New Market','MD','UNITED STATES','21631-1637','(410) 228-6027','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-12 19:58:49',0,NULL,3,1,1,1,'\\ ','wlt_jr'),(7137,553171187004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','meirav2411','meirav24@hotmail.com','meirav feigenboim','topaz 47','adi','','ISRAEL','17940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 20:06:16',0,NULL,3,1,3,1,'RA183610889CN\r ','meirav2411\rOTGR002'),(7138,601413731013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',29.99,'eastar4','squash_cv84','squash.cv@gmail.com','Volodymyr Lukashchuk','9-49 Gaydara str.','Chernivtsy','','UKRAINE','58029','+380501490052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 20:05:11',0,NULL,3,1,2,1,'\\ ','squash_cv84'),(7139,816175748012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',53.96,'eastar4','taratonis','ilukha@pochta.ru','Ilya Taraton','Mikroraion 6, d.10, kv.69','Egorievsk','Moskovskaya obl','RUSSIAN FEDERATION','140300','905-779-6967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 20:24:05',0,NULL,3,1,3,1,'RA183610946CN\r ','taratonis\rOTRA001+WLDE001\r再发一个New DELL D630 D830 BCM4321 \r'),(7140,601427624013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','juniors321','my68camaro@hotmail.com','Jose Colon','132  Hoover Dr','Rochester','NY','UNITED STATES','14615','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 20:44:53',0,NULL,3,1,1,1,'\\ ','juniors321'),(7141,601433713013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','marcsil10','marcosassilveira@yahoo.com.br','Marcos Antonio Soares Silveira','Rua Cel. João Augusto Lima, 222 Ap. 201 Guararapes','Fortaleza','Ceará','BRAZIL','60810-321','(085) 3241-0275','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-12 21:03:40',0,NULL,3,1,3,1,'RA183611575CN\r ','marcsil10\rHSNO019'),(7142,697251394001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','lalancevilaine','lezardking19@hotmail.com','Laval Menard','465 7ième Avenue Nord, app.5','Sherbrooke','QC','CANADA','J1E 2S2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 21:21:24',0,NULL,3,1,3,1,'RA183610875CN\r ','lalancevilaine\rBR3D005'),(7143,601439294013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','awson50','shlomi.ohayon@gmail.com','shlomi Ohayon','Emek Ahula st building 1 app 15','Kfar Saba','Israel','ISRAEL','44622','(972) 575-6584 ext.: 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 21:27:59',0,NULL,3,1,2,1,'\\ ','awson50'),(7144,735241791011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','saularibarsh','strealty@comcast.net','Saul A Barsh','322 Boot Rd','Malvern','PA','UNITED STATES','19355-3314','(610) 644-5561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 21:36:54',0,NULL,3,1,1,1,'\\ ','saularibarsh'),(7145,0,110708837019,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',42.35,'buysia','mudan','mudanantiques@yahoo.com','Dan Gould','4289 Rocky Glenn','Roswell','GA','UNITED STATES','30075','(770) 993-3023','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 21:48:07',0,NULL,3,1,1,1,'\\ ','mudan'),(7146,735247739011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','bianca07*123','biancamcasey@hotmail.com','Bianca McAsey','1/17 Ballarter Street<br>Essendon','Melbourne','Victoria','AUSTRALIA','3040','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 21:58:01',0,NULL,3,1,2,1,'\\ ','bianca07*123\r紫色的'),(7147,816226067012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','hnvijay','hnvijay_jain@yahoo.com','Seema HN','#06-67, Block 312<br>Bukit Batok, ST 32','default','','SINGAPORE','650312','006585185874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 22:25:17',0,NULL,3,0,11,1,'\\ ','hnvijay\r\r'),(7148,697271457001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','jmillsales','jmillsale@gmail.com','Lee manela','3830 Vinton Ave<br>Apt 302','CULVER CITY','CA','UNITED STATES','90232-3138','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 22:26:18',0,NULL,3,1,1,1,'\\ ','jmillsales'),(7149,601470782013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','kwatoyo','kwatoyo@gmail.com','KWA Tong Yong','416 Ang Mo Kio Ave 10<br>#06-1003','Singapore','','SINGAPORE','560416','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 23:46:04',0,NULL,3,1,11,1,'\\ ','kwatoyo\rCCGR001'),(7150,816261693012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','marc2678','marc_r@videotron.ca','marc   rodrigue','1211 rue des cedres','ste-julienne','QC','CANADA','J0K2T0','(514) 886-9157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 00:20:51',0,NULL,3,1,2,1,'\\ ','marc2678'),(7151,553243304004,140519629061,'New Sony Ericsson HBH-DS220 BLUETOOTH HEADSET track#',1,'HSJA003',65.9,'cnfaner','drdamata','damatxinha@hotmail.com','joao neto','rua benjamin constant 935 alecrim','natal','Rio grande do norte','BRAZIL','59040-030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 01:50:32',0,NULL,3,0,3,1,'RA183610835CN\r ','drdamata\rHSSE006\r美标'),(7152,735312256011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mugenhonda89','cybercrx89@hotmail.com','navindra anand','308-365 Kennedy Rd S','Brampton','ON','CANADA','L6W 3H3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 02:02:09',0,NULL,3,1,2,1,'\\ ','mugenhonda89'),(7153,8881310522801207,111,'logitech 930mAh  white used',17,'BALO002',140,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia<br>Cove','Bee Cave','TX','UNITED STATES','78738','',NULL,NULL,NULL,NULL,0,NULL,3,1,1,1,'\\ ','补发的 \r需要改一个E邮宝\rLK071808612CN '),(7154,816291407012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','damian.5','damo_skyline@hotmail.com','Damian Maciszewski','7 Bushland ct<br>Wheelers Hill','Melbourne','Victoria','AUSTRALIA','3150','0395616675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 02:08:00',0,NULL,3,1,2,1,'\\ ','damian.5'),(7155,735315644011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','abcfubar','nj_fullyfaltooguy@yahoo.co.in','Niteesh Joshi','6E, Tower1, Euston Court, 6 Park Roak<br>Mid Levels, Central','default','','HONG KONG','default','97290239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 02:20:39',0,NULL,3,1,2,1,'\\ ','abcfubar\r新地址\rNiteesh Joshi\r6E, Tower1, Euston Court, 6 Park Road\rMid Levels, Central\rdefault  default\rHONG KONG\r97290239'),(7156,8881310527204647,111,'Ralink RT2870F',4,'OTRA001',140,'eastar4','universalmajor1970','javierx7@gmail.com','Javier Andres Manriquez Gebert','El Escorial 370 depto 603','Temuco Novena Region de la Araucania n/a','','CHILE','','0056997317446',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183610756CN ',' 补发的\rOTRA001\r'),(7157,0,110712388441,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',63,'buysia','efgtuan','tle2332@gmail.com','ANTOINE LE','8000 Comanche Ave','WINNETKA','CA','UNITED STATES','91306-1832','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 03:45:13',0,NULL,3,1,1,1,'、 ','efgtuan'),(7158,816317047012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','raptorx2','jmagee1@gmail.com','James Magee','261 Kensington Ln','Austin','TX','UNITED STATES','78737','(512) 659-0112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 03:52:22',0,NULL,3,1,1,1,'、 ','raptorx2'),(7159,816319332012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','rodigu69','rodigu77@gmail.com','Rodrigo Vieira','Rua Radio e Tv Gaucha, 189','Porto Alegre','Rio Grande do Sul/Morro Santa Tereza','BRAZIL','90850080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 04:03:48',0,NULL,3,1,3,1,'RA183610685CN ','rodigu69\rGLSG001*2'),(7160,553265289004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','rudi5431','rudi5431@tlen.pl','Andrzej Rudzinski','2036 av. De l\'Eglise','Montreal','QC','CANADA','H4E 1H3','(514) 762-4167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 04:19:26',0,NULL,3,1,3,1,'RA183610671CN ','rudi5431\rHANO003'),(7161,697349463001,110701383504,'NIB CBS High Pressure Portable Car Washer wash',1,'CAWA001',69.9,'buysia','edutxu','edutxu@hotmail.com','Eduardo Arteagabeitia Fernandez','C/ El Cid, 5, Bajo A','Barakaldo','País Vasco','SPAIN','48902','696153304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 04:31:33',0,NULL,3,1,4,1,'YW866475890CN ','edutxu\rCAWA001'),(7162,553273515004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','mitvet','maqf@hotmail.com','Miguel Angel Quiroz','av.Juan de aliaga 625 dpto 1201 Magdalena del mar','Lima','Lima','PERU','Lima 17','(519) 810-8435 ext.: 9','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 05:33:32',0,NULL,3,1,3,1,'RA183610668CN ','mitvet\rHSNO022'),(7163,735370107011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','erandahan85','erandahan@013net.net','eran dahan','bet lehem 95','haifa','israel','ISRAEL','35568','0503853020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 07:03:26',0,NULL,3,1,2,1,'、 ','erandahan85'),(7164,735373485011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','stondyeti','osamakhan007@hotmail.com','Mr. O  Khan','8 Beeston Road','Nottingham','Nottinghamshire','UNITED KINGDOM','NG7 2JR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 07:25:25',0,NULL,3,1,3,1,'RA183610708CN\r ','stondyeti\rRELO003\r红边优联'),(7165,816361172012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 07:34:30',0,NULL,3,1,3,1,'RA183610699CN ','avextra-co-uk\rOTCN004*10'),(7166,8881310543591835,111,'NEW Logitech Nano Receiv',1,'RELO003',11.98,'eastar4','alfredo_colin','alfredo.r.colin@gmail.com ','Ricardo Morales','2589 Hawthorne Dr.','Oakdale','PA','USA','15071','',NULL,NULL,NULL,NULL,0,NULL,3,1,1,1,'、 ','红边优联\r客户直接打钱的 \rLK016155668CN '),(7167,816367346012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.65,'eastar4','alex_in_wellington','alexinwellington@gmail.com','Alex Scott','128b Russell Tce<br>Berhampore','Wellington','','NEW ZEALAND','6023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 08:02:59',0,NULL,3,1,2,1,'、 ','alex_in_wellington\r发3个210TS'),(7168,735387027011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',2,'HSUE001',27,'eastar4uk','modelbuilder1','kgb_corvette@yahoo.co.uk','Karl Bengtsson','Börringegatan 1 B','Malmö','Sweden','SWEDEN','21772','+46-40-120827','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 08:27:27',0,NULL,3,1,3,1,'RA183610549CN\r ','modelbuilder1\rHSUE001'),(7169,553296359004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.99,'cnfaner','ice69bln','iceman.69@live.com','Andreas Rejmann','Földerichstr.2','Berlin','','GERMANY','13595','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 08:31:57',0,NULL,3,1,3,1,'RA183610535CN\r ','ice69bln\rHSPL002'),(7170,0,110712388560,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',33,'buysia','abigred38','bigred38@gmail.com','robin dunlap','27590 SW Pacific Hwy','sherwood','OR','UNITED STATES','97140','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 10:08:08',0,NULL,3,1,1,1,'\\ ','abigred38'),(7171,601573003013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','vasvickk','vasvick@gmail.com','Vasiliy Koltsov','Pogorelova street 3, kv.29','Sevastopol','','UKRAINE','99703','+380503930924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 10:30:15',0,NULL,3,1,2,1,'\\ ','vasvickk'),(7172,816421784012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','tanzbear69','u.beneke@benekenet.de','Becosy GmbH','Frankenweg 9','Rot am See','','GERMANY','74585','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 11:34:11',0,NULL,3,1,3,1,'RA183610331CN\r ','tanzbear69\rOTSO002'),(7173,601588290013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','pkortum','p.kortum@hotmail.com','Patrick Kortum','122 tallebudgera drive','Palm beach','Queensland','AUSTRALIA','4221','0478192852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 11:53:05',0,NULL,3,1,2,1,'\\ ','pkortum'),(7174,735449631011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',2,'CASS001',17.4,'eastar4','rajagidh','imran.shehzad@gmail.com','Imran Bhatti','4/3 Yeo Street','Neutral Bay','New South Wales','AUSTRALIA','2089','61415617133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 12:37:08',0,NULL,3,1,2,1,'\\ ','rajagidh'),(7175,735463522011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',20.64,'eastar4','cezexx','cpiekacz@gmail.com','Cezary Piekacz','Wawozowa 6/65','Warszawa','mazowieckie','POLAND','02-796','691 710090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:25:25',0,NULL,3,1,2,1,'\\ ','cezexx'),(7176,735466292011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','woropek','woropek@o2.pl','Pawel Woropinski','Fiolkowa 9','Ostroleka','mazowieckie','POLAND','07-410','29 7668194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:31:29',0,NULL,3,1,2,1,'\\ ','woropek'),(7177,697466867001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','yarns2dye4','ilovefibers@yahoo.com','Karen Jordan','2961 Sleepy Hollow Dr','Stockton','CA','UNITED STATES','95209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 13:45:21',0,NULL,3,1,1,1,'\\ ','yarns2dye4'),(7178,547748782003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',13.58,'cnfaner','vvfukuta','fukuta@sf.commufa.jp','fukuta masaru','Gifu Prefecture','Gifu City  west uzura 1-20-1','Gifu','JAPAN','500-8286','058-274-7516','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:48:00',0,NULL,3,1,3,1,'RA183610328CN\r ','vvfukuta\rHSPL005'),(7179,553352446004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','brackishsa','roann.dunn@gmail.com','Roann Dunn','865 Tainton Street<br>Wingate Park','Pretoria','Gauteng','SOUTH AFRICA','0158','082 795 0979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:51:46',0,NULL,3,1,3,1,'RA183610314CN\r ','brackishsa\rHSNO022'),(7180,735474171011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','isaichev_uv','smith52@narod.ru','Юрий Исаичев','ул. Невская, д23','Нижний Новгород','Нижний Новгород','RUSSIAN FEDERATION','603009','+79308108294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:58:28',0,NULL,3,1,2,1,'\\ ','isaichev_uv\r盒装的\r欧标'),(7181,735487968011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.4,'eastar4','imp0','219101019@mail.ru','Алексей Жуков','Stepana Razina st. 6-29','Chelyabinsk','','RUSSIAN FEDERATION','454111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 14:48:38',0,NULL,3,1,2,1,'\\ ','imp0\rHP 8pin 1.0 23cm '),(7182,816510294012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',29.99,'eastar4uk','dirtywashing','emmott.martin@googlemail.com','Martin Emmott','The Torbay Hotel<br>Torbay Road','Torquay','Devon','UNITED KINGDOM','TQ2 5EY','01803295218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 15:51:28',0,NULL,3,1,3,1,'RA183610402CN\r ','dirtywashing\rRCLO006\r新的'),(7183,816517477012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',2,'SCLO002',11,'eastar4','theshack74','dnelson74@bellsouth.net','Dave Nelson','2340 Rackley Rd','BROOKSVILLE','FL','UNITED STATES','34604-7040','(352) 796-5562','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 16:09:14',0,NULL,3,1,1,1,'\\ ','theshack74'),(7184,601648374013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',37.8,'eastar4','ztreuma','myashin@mail.ru','Michail Yashin','Znamenskaya st. 38-1-14','Moscow','Moscow','RUSSIAN FEDERATION','107392','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 16:10:09',0,NULL,3,1,3,1,'RA183610359CN\r ','ztreuma\rANCN001\r再发一个UNLOCKED Option GTM382    需要召回撤单'),(7185,601647437013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',83.6,'eastar4','micpang197310','pangmichael.hk@gmail.com','Pang Michael','Flat2 3/F, Tower A, San Francisco Towers<br>35 Ventris Road, Happy Valley Hong Kong','default','','HONG KONG','default','92119853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 16:10:58',0,NULL,3,1,14,1,'301117257657','micpang197310\rBAZA001'),(7186,735530352011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','hitchntrailer','lfweyers@gmail.com','Lorne Weyers','37 Minford Avenue','Scarborough','ON','CANADA','M1R2B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 16:34:22',0,NULL,3,1,2,1,'\\ ','hitchntrailer'),(7187,735534643011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','seama.koohi','seamakoohi@yahoo.com','Seama Koohi','2136 Kedron Street','Oshawa','ON','CANADA','L1L 1B8','(905) 903-9189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 16:46:34',0,NULL,3,1,2,1,' \\','seama.koohi'),(7188,735050296011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','geert2891','geertvlumig@hotmail.com','Geert van Lumig','Boschdijk 232A','Eindhoven','','NETHERLANDS','5612HH','06 48183153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 16:46:50',0,NULL,3,1,2,1,'\\ ','geert2891'),(7189,735552305011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','sonofjesse','douglaskster@gmail.com','Douglas King','170 Teal Cres','Orleans','ON','CANADA','K1E 2C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 17:29:58',0,NULL,3,1,2,1,'\\ ','sonofjesse'),(7190,735566492011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','cpi60','p.sawatzky@comcast.net','Patricia Sawatzky','10S730 S Jackson St','Burr Ridge','IL','UNITED STATES','60527-6813','(630) 325-8828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 18:01:46',0,NULL,3,1,1,1,'\\ ','cpi60\r兼容型3D眼镜  samsung 专用'),(7191,601694145013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',52.2,'eastar4','ucdb2011','compras@ucdb.br','Maria Chiste Machado','Av. Tamandaré<br>6000','Campo Grande','Mato Grosso do Sul','BRAZIL','79117900','55+67 3312-3375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 18:36:35',0,NULL,3,1,3,1,'RA183610305CN\r ','ucdb2011\rCASS003\rCAB-6060'),(7192,601714910013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',11.99,'eastar4','icelord_rus','dteplitsky@yandex.ru','Dmitry Teplitsky','3-1-43 Grimau str','Moscow','RU','RUSSIAN FEDERATION','117449','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 19:29:02',0,NULL,3,1,2,1,'\\ ','icelord_rus\r新的'),(7193,735274931011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','justneedaconnector','bluec@shaw.ca','Stanley Chan','9880 Garden City Rd.','Richmond','BC','CANADA','v7a2s3','(778) 320-3285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 19:38:49',0,NULL,3,1,2,1,'\\ ','justneedaconnector'),(7194,816619179012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',26.9,'eastar4uk','alondahary','alon.dahary@gmail.com','Alon Dahary','Shderot Ha\'haskala 17a','Tel-Aviv-Yafo','Israel','ISRAEL','67890','+972-545677529','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 20:03:37',0,NULL,3,1,3,1,'RA183610274CN\r ','alondahary\rOTGR001+OTGR002'),(7195,816636357012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',26.9,'eastar4uk','pug1fm','pug1fm@aol.com','Roy Lee Evans','10 Castleford Close<br>Beddau','Pontypridd','Mid Glamorgan','UNITED KINGDOM','CF38 2RW','01443209419','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 20:04:07',0,NULL,3,1,3,1,'RA183610265CN\r ','pug1fm\rOTGR001+OTGR002'),(7196,816659367012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','stu686868','stu68@hotmail.com','Stuart Leith','525 Manchester St<br>St Albans','Christchurch','Canterbury','NEW ZEALAND','8014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 20:54:54',0,NULL,3,1,3,1,'RA183610288CN\r ','stu686868\rOTRA001'),(7197,735666407011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',5,'CCGR001',34.4,'eastar4','snoddy421','asnodgra@gmail.com','Ashley Snodgrass','11333 Iowa Ave','Los Angeles','CA','UNITED STATES','90025-4214','(310) 980-2543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 21:32:07',0,NULL,3,1,1,1,'\\  ','snoddy421'),(7198,735666653011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','damnson1','troycapp@optonline.net','troy capp','po box 6','staatsburg','NY','UNITED STATES','12580','(845) 773-9158','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 21:32:41',0,NULL,3,1,1,1,'\\ ','damnson1'),(7199,735667428011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','cdnpicker1997','stavsky@rogers.com','Michael Stavsky','6 Michael Court','Thornhill','ON','CANADA','L4J3A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 21:35:17',0,NULL,3,1,2,1,'\\ ','cdnpicker1997'),(7200,816671234012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','paullankes','plankes1@yahoo.com','Paul E. Lankes','1583 Monarch Dr','Venice','FL','UNITED STATES','34293-0302','(941) 882-6266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 21:36:11',0,NULL,3,1,1,1,'\\ ','paullankes\r旧的'),(7201,735673407011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','aholata','aholatatu@yahoo.com','Tatu Ahola','Valtakatu 5-7 a3','Valkeakoski','','FINLAND','37600','0456383574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 21:52:35',0,NULL,3,1,2,1,'\\ ','aholata\r无线蓝牙二合一'),(7202,816696257012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','trad23','mike.welham666@zen.co.uk','Mike Welham','8 Brook Lodge','Portadown, Craigavon','Co Armagh','UNITED KINGDOM','BT62 3LU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 22:31:39',0,NULL,3,1,2,1,'\\ ','trad23'),(7203,553497569004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','1980vinvin','abelvincent@hotmail.fr','Vincent Abel','7385, Hector Heroux','Trois-Rivieres','QC','CANADA','G8Y 7A9','(819) 697-2725','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'1980vinvin'),(7204,553507194004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'cnfaner','mr1173','1173@mail.ru','Anton Petukhov','Khersonskaya st., 9-2-177','Moscow','','RUSSIAN FEDERATION','117461','+7-916-700-9445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 00:00:27',0,NULL,3,1,3,1,'RA183610345CN\r ','mr1173\rOTSO002'),(7205,601808167013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','pawel.17','pawel.17@hotmail.com','pawel nowak','4020 Huntington Blvd','Hoffman Estates','IL','UNITED STATES','60192-1650','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 02:01:52',0,NULL,3,1,1,1,'\\ ','pawel.17'),(7206,735738478011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','tazik85','tamaztvauri@yahoo.com','tamaz tvauri','29 Fletcher Rd<br>APT C','Monsey','NY','UNITED STATES','10952-3231','(845) 598-4855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 02:12:05',0,NULL,3,1,1,1,'\\ ','tazik85'),(7207,816769371012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','award200','beliveaujason@videotron.ca','Jason Béliveau','80 rue Patry App 5','Trois-rivieres','QC','CANADA','G8T8J4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 03:09:07',0,NULL,3,1,2,1,'\\ ','award200'),(7208,601825436013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',12.5,'eastar4','valtertolentino','valter.tolentino@uol.com.br','Valter Tolentino','Rua Itaucama 35<br>Bosque da saúde','São paulo','São paulo','BRAZIL','04135040','55 11 55890656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 03:42:10',0,NULL,3,1,2,1,'\\ ','valtertolentino\racer 5pin1.25 20cm '),(7209,735761070011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','johnnie_hat','hatfij@optonline.net','John L Hatfield','2 Hellman Ct','Wappingers Falls','NY','UNITED STATES','12590-6426','(845) 227-5867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 03:56:55',0,NULL,3,1,1,1,'\\ ','johnnie_hat'),(7210,601828946013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',29.99,'eastar4','mangos47','ak47wow@gmail.com','Zhang Songhua','Data Storage Institute<br>5, Engineering Drive 1','Singapore','','SINGAPORE','117608','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 04:05:35',0,NULL,3,1,11,1,NULL,'mangos47\rWWSI005'),(7211,735766095011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','expatjen','patrickdaly64@yahoo.com','patrick daly','688 S Van Ness Ave','san francisco','CA','UNITED STATES','94110-1306','(408) 410-7653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 04:25:15',0,NULL,3,1,1,1,'\\ ','expatjen'),(7212,697745615001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','cactii29','cactus292929@yahoo.com','Kevin Scarlett','7979 NW 21st St<br>KIN 6076','Doral','FL','UNITED STATES','33122-1630','(876) 298-5398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 05:32:28',0,NULL,3,1,1,1,'\\ ','cactii29'),(7213,816808440012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','exoticutopia','origin.of.justice@gmail.com','Eui-Weon Jeong','377-9 hartvilla 17-302<br>samsandong','bupyuong gu','incheon','KOREA,REPUBLIC OF','403090','82-10-5271-3946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 06:27:18',0,NULL,3,1,2,1,'\\ ','exoticutopia'),(7214,816812600012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','dominicmichael83','dominicmichaels@hotmail.com','Dominic Huang','798 Woodlands Drive 72<br>#03-67','default','','SINGAPORE','730798','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 06:51:16',0,NULL,3,1,3,1,'RA183619582CN\r ','dominicmichael83\rGLSG001*3'),(7215,816818912012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','barry.solomon','barry@bsolomon.net','Barry Solomon','6789 Quail Hill Pkwy<br># 405','Irvine','CA','UNITED STATES','92603-4233','(714) 395-3381','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 07:16:49',0,NULL,3,1,1,1,'\\ ','barry.solomon'),(7216,601860552013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','zauib8','dzativ@yahoo.com','Daniel Natividad','5747 Chandler Ct','Rancho Cucamonga','CA','UNITED STATES','91739-2446','(909) 418-7430','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 08:09:42',0,NULL,3,1,1,1,'\\ ','zauib8'),(7217,601860958013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','hammerchewer','pl@vk6ad.net','Philip Maley','PO Box 1526','Applecross','Western Australia','AUSTRALIA','6953','0417954187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 08:11:27',0,NULL,3,1,3,1,'RA183610552CN\r ','hammerchewer\rMOSA003'),(7218,816833298012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 08:24:07',0,NULL,3,1,3,1,'RA183610504CN\r ','avextra-co-uk\rOTCN004*10'),(7219,816852258012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','mallawa2011','contact@disneyland-parisshuttle.com','Damian Sepion','14 Rue des petits champs','STE Colombes','Ile-de-France','FRANCE','77650','0627267773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 09:44:05',0,NULL,3,1,2,1,'\\  ','mallawa2011'),(7220,547997974003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','ypeled101','ypeled@gmail.com','Yoram Peled','Ben-Shemen<br>11','BEN-SHEMEN Moshav','','ISRAEL','73115','972-8-9247547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 10:39:33',0,NULL,3,1,3,1,'RA183610481CN\r ','ypeled101\rBALO007'),(7221,735843536011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',20.64,'eastar4','penkerton','penkerton@gmail.com','Yury Peikrishvili','Kievskaya, 24, 150','Moscow','','RUSSIAN FEDERATION','121165','+79150347592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 10:57:54',0,NULL,3,1,2,1,'\\ ','penkerton'),(7222,553601474004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','korwazbigniew','karolpietr@gmail.com','ZBIGNIEW PIETRZAK','3  /  9  LINCOLN  ST','SYDNEY  ','New South Wales','AUSTRALIA','2168','0488904097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 11:14:29',0,NULL,3,1,3,1,'RA183610420CN\r ','korwazbigniew\rOTGR001+OTGR002'),(7223,601895804013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','kevbo999','big_kev_91@hotmail.com','Kevin Quan','72 McCallum Street<br>Carseldine','Brisbane','Queensland','AUSTRALIA','4034','0732638526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 11:47:33',0,NULL,3,1,3,1,'RA183614421CN ','kevbo999\rGLOT001*3\r兼容型3D眼镜 通用型'),(7224,601898784013,230641231655,'New lady lotus leaves  sun/rain stick Umbrella blue',1,'UM00002',24.99,'eastar4','lamashty','nbadenko@gsg.spb.ru','Natalya Badenko','Dynaisky pr. 24-243','Saint-Petersburg','','RUSSIAN FEDERATION','192168','89217913379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:10:18',0,NULL,3,1,3,1,'RA183610597CN\r ','lamashty\rUM00014+UM00002\r荷叶边伞 \r再发一个美女涂鸦伞 '),(7225,816891429012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','roypeles','roypeles@bezeqint.net','roy peles','10 hanotrim st.','holon','israel','ISRAEL','58280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:10:21',0,NULL,3,1,2,1,'\\  ','roypeles'),(7226,816888433012,220807272254,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',19.99,'eastar4','lamashty','nbadenko@gsg.spb.ru','Natalya Badenko','Dynaisky pr. 24-243','Saint-Petersburg','','RUSSIAN FEDERATION','192168','89217913379','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 12:11:44',0,NULL,3,1,17,0,NULL,'lamashty'),(7227,735860771011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','florinfilipescu','philipone69@yahoo.com','Filipescu Florin','Baraj Bicaz no7 Bloc G1 et2 ap9<br>Sector3','Bucharest','Romania','ROMANIA','032791','+40723218498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:22:02',0,NULL,5,0,18,1,NULL,'florinfilipescu\r旧的\r'),(7228,697827764001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','louisaint','louisaint_99@yahoo.com','Alexis Dy','Kisogawa Cho Oaza Kadoma Aza Shin Yasiki 36-2 Banchi Maruhachi Sou 7 Gou','Ichinomiya Shi','Aichi','JAPAN','4930002','81-9099129165','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:22:48',0,NULL,3,1,3,1,'RA183610464CN\r ','louisaint\rBR3D005'),(7229,816930907012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','leezorgirl','leezorgirl@yahoo.com','Brian Bowman','4714 W Northfox Ln<br>Apt 6','McHenry','IL','UNITED STATES','60050-4907','(630) 723-7395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 14:19:18',0,NULL,3,1,1,1,'\\ ','leezorgirl'),(7230,553636970004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',129.99,'cnfaner','lgoworld','3q.worldwide@gmail.com','Craig Reilly','38 Linton Avenue','West Ryde','New South Wales','AUSTRALIA','2114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 14:19:59',0,NULL,3,1,3,1,'RA183610606CN\r ','lgoworld\rEXLO001'),(7231,816932275012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','lm32692','lmehefko@gmail.com','Larry Mehefko','3505 Almond Ln','Mckinney','TX','UNITED STATES','75070-7612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 14:22:43',0,NULL,3,0,1,1,'\\  ','lm32692'),(7232,735895104011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','ppyy','hjmwang@yahoo.com','Mickey Wang','388 Richmond St. West<br>Unit# 411','Toronto','ON','CANADA','M5V 3P1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 14:45:48',0,NULL,3,1,2,1,'\\  ','ppyy\r\r\r'),(7233,816948492012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','mama$unflower','roselle.la@gmail.com','Rosemary Lehan','34 Springside View<br>Brandlesholme','Bury','Lancashire','UNITED KINGDOM','BL8 4LU','01617631111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 15:05:34',0,NULL,3,1,2,1,'\\ ','mama$unflower'),(7234,735917262011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','tele-rollei','calciu1@hotmail.com','Andrei Calciu','6371 Birch Leaf Ct','Burke','VA','UNITED STATES','22015-3528','(703) 995-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 15:13:23',0,NULL,3,1,1,1,'\\ ','tele-rollei'),(7235,735918607011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','bonesdc','pdengler@mac.com','Patricia Dengler','4916 Coolidge Ave','Culver City','CA','UNITED STATES','90230-5121','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 15:18:25',0,NULL,3,1,1,1,'\\  ','bonesdc'),(7236,735918734011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',4,'TRTS001*10',332,'eastar4','gigadata','gigadataus@gmail.com','Beyin IT','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(862) 234-5966','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 15:19:14',0,NULL,3,1,4,1,'YW866475831CN ','gigadata'),(7237,601794324013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','manovsanjin','sanjinmanov@hotmail.com','Sanjin Manov','Dzemala Bijedica 76','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0038761272228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 15:31:57',0,NULL,3,1,2,1,'\\ ','manovsanjin'),(7238,601949306013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','k750zs','k750reg@gmail.com','Puskásné Kotulics Anikó','Diak u. 21/b','Nyiregyhaza','','HUNGARY','4551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 15:42:57',0,NULL,3,1,2,1,'\\ ','k750zs'),(7239,735927410011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','paypalsucksjoseph','geremia@cox.net','Joe Geremia','9309 N 12th St','Phoenix','AZ','UNITED STATES','85020-2637','(602) 214-1238','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 15:48:08',0,NULL,3,1,1,1,'\\ ','paypalsucksjoseph'),(7240,601947418013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','liat_store','soleron@bezeqint.net','Yaniv Anaf','19 Kadish Loz Street<br>Apartment # 2','Haifa','','ISRAEL','32159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 16:11:35',0,NULL,3,1,2,1,'\\ ','liat_store'),(7241,601959578013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','dgoodman79bf','drdgoodman1@verizon.net','Don Goodman','156 Donnick Ave','Thousand OAks','CA','UNITED STATES','91360-3311','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 16:20:35',0,NULL,3,1,1,1,'\\ ','dgoodman79bf\r兼容型3D眼镜 通用型'),(7242,816970016012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','rikardcore','rs148@hotmail.com','Rikard Strömmer','Himlabacken 9A','Stockholm','Stockholm','SWEDEN','17078','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 16:25:38',0,NULL,3,1,3,1,'RA183610495CN\r ','rikardcore\rWWOT003\r\r\r'),(7243,816980298012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','angelykeyla2610','computerrepairsunlimited@ymail.com','L Electronics','PO Box 2688','brandon','FL','UNITED STATES','33509-2688','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 16:28:21',0,NULL,3,1,1,1,'\\ ','angelykeyla2610'),(7244,553668395004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','kuxx26','garnet166@msn.com','Sergiu Girnet','St.Emilion ,319','Gatineau','QC','CANADA','J8R2R4','(819) 663-6368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 16:47:10',0,NULL,3,1,3,1,'RA183610478CN\r ','kuxx26\rOTGR002'),(7245,0,110712830772,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',63.02,'buysia','4839bwm','bwm1943@hotmail.com','Barney McConkey','7907 Bailey Bridge Way','Knoxville','TN','UNITED STATES','37938-3298','(865) 922-8962','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 17:05:02',0,NULL,3,1,1,1,'\\ ','4839bwm'),(7246,735963699011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','dad929','ddaines929@aol.com','David Daines','17350 Temple Ave<br>Spc 337','La Puente','CA','UNITED STATES','91744-4637','(626) 964-2403','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 17:21:07',0,NULL,3,1,1,1,'\\ ','dad929'),(7247,817022210012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','esergen_01','esergen@gizerler.com.tr','Eser GEN','ADANA IL EMNIYET MUDURLUGU - ASAYIS SUBE MUDURLUGU - OTO HIRSIZLIK BURO AMIRLIGI','Seyhan/ADANA','','TURKEY','01100','05053710206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 18:07:39',0,NULL,3,1,2,1,'\\  ','esergen_01\r白色的'),(7248,601996150013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','mago_1979','mag19_79@yahoo.com','margarita alcantara','395 E Okeefe St<br>Apt A','east palo alto','CA','UNITED STATES','94303-5105','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 18:20:03',0,NULL,3,1,1,1,'\\ ','mago_1979\r兼容型3D眼镜 通用型'),(7249,601999735013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ideax13','sashestakov@gmail.com','Sergiy Shestakov','App. 65, Miloslavskaya str. 41/15','Kiev','','UKRAINE','02167','+380 (50) 375-55-78','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 18:27:10',0,NULL,3,1,2,1,'\\ ','ideax13'),(7250,817054784012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','bzenobiad1970','bzenobiad@yahoo.com','Beatrice Davies','Escamplaan<br>526','DEN HAAG','','NETHERLANDS','2547EP','0652192505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 19:07:30',0,NULL,3,1,2,1,'\\  ','bzenobiad1970\rCAB-6060'),(7251,817051663012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','atwazin','tigerwolf10@hotmail.com','Guilherme Nascimento','R: André Vidal de Negreiros, 25, apt. 24','Santos','São Paulo','BRAZIL','11035081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 19:08:30',0,NULL,3,1,3,1,'RA183610416CN\r ','atwazin\rOTRA001'),(7252,816711291012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','wavemg-wa','info@wavemg.com','KIHOON LIM','4208 198th ST SW<br>Ste 109','Lynnwood','WA','UNITED STATES','98036-6736','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 19:12:24',0,NULL,3,1,1,1,'\\ ','wavemg-wa\r白色的'),(7253,817072022012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','storeyl66','lynne.storey@trin.net','Lynne Storey','2739 Manorwood TRL','Fort Worth','TX','UNITED STATES','76109-5589','(214) 870-9828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 19:38:36',0,NULL,3,1,1,1,'\\ ','storeyl66'),(7254,697977743001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',32.99,'buysia','jaimesonia1608','jaimevguadalajara@yahoo.com','jaime vazquez','1845sperry rd','carrollton','TX','UNITED STATES','75006','(469) 789-6586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 19:44:37',0,NULL,3,1,1,1,'\\ ','jaimesonia1608'),(7255,736068703011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','lior3103','lior1984@yahoo.com','Lior Markushevich','Mishol Gil 9 apartment 4','Kfar Saba','Ha Sharon','ISRAEL','44281','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 21:10:12',0,NULL,3,1,2,1,'\\ ','lior3103'),(7256,817125890012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','steven116116','steven_mc_lean@hotmail.com','Steven Mc Lean','4 Rue Benoit','Mont-Saint-Grégoire','QC','CANADA','J0J 1K0','(450) 358-8037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 21:33:10',0,NULL,3,1,2,1,'\\ ','steven116116\rmicorsoft 极动鲨 mouse'),(7257,736078949011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',3,'HSJA010',89.97,'eastar4','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 21:43:40',0,NULL,3,1,3,1,'RA183610521CN\r ','vjendrisvelimir\r欧标\rHSJA010'),(7258,736080980011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'eastar4','coloradokennett','rfkocoa@hotmail.com','Rachel Kennett','10145 W 25th Ave<br>Apt 74','Lakewood','CO','UNITED STATES','80215-1456','(720) 206-4785','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 21:46:29',0,NULL,3,1,1,1,'\\ ','coloradokennett\r地图伞 '),(7259,698027196001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',17.99,'buysia','ahen7714','allenhenry4@aol.com','allen henry','1304 hampton xing','norcross','GA','UNITED STATES','30093-4078','(770) 717-1155','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 21:56:03',0,NULL,3,1,1,1,'\\ ','ahen7714'),(7260,736092528011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','xkoukos123','x@koukos.gr','Koukos Xenophon','Kileler 3','Tirnavos','Thessalia','GREECE','40100','00302492024595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 22:18:34',0,NULL,3,1,3,1,'RA183610433CN ','xkoukos123\rUDAP001'),(7261,736092455011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.4,'eastar4','ziggystarman','ziggy@iastate.edu','Marty Ellenberger','1019 Grand Ave','Ames','IA','UNITED STATES','50010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-14 22:23:22',0,NULL,3,1,1,1,'\\  ','ziggystarman\rHP 8pin 0.8 3cm'),(7262,553772350004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','petr-2010','peterbalaz@freenet.de','computershop24 flemer','hein hoyer str 24','hamburg','','GERMANY','20359','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 22:54:15',0,NULL,3,1,3,1,'RA183610518CN\r ','petr-2010\rMOOE001\r发OEM的'),(7263,548183132003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',49.99,'cnfaner','mox1980','moxiebay@gmail.com','Nicolas Brown','Unit 42, 3482 Main Beach Pde.<br>Main Beach','Gold Coast','Queensland','AUSTRALIA','4217','04131863893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 23:38:27',0,NULL,3,1,3,1,'RA183610447CN\r ','mox1980\rWWOT003'),(7264,736118958011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','krew4life512','bakonheyusuck@yahoo.com','Abacu perez','6420 orange blossom way','austin','TX','UNITED STATES','78744','(512) 921-6218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 00:00:14',0,NULL,3,1,1,1,'\\  ','krew4life512'),(7265,736122686011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','beecool666','roger.gaudreault@cgocable.ca','Roger Gaudreault','140 Delage E','Alma','QC','CANADA','G8B6A4','(418) 480-2775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 00:17:54',0,NULL,3,1,2,1,'\\ ','beecool666'),(7266,736132974011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','nassco5','gemini58@cox.net','Oscar  Contreras','2970 Coronado Ave<br>Space 5 Spc 5','San Diego','CA','UNITED STATES','92154-2152','(619) 271-9007','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 01:01:37',0,NULL,3,1,1,1,'\\ ','nassco5'),(7267,817206435012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','jer20084','jer20084@yahoo.com','Jeremy Venerella','5626 Flack Dr','Houston','TX','UNITED STATES','77081','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 02:16:34',0,NULL,3,1,1,1,'\\  ','jer20084'),(7268,817209642012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','cookiewanko','kobayashim@nkcusa.com','Mark kobayashi','1584 E Brooks Rd<br>NKC Engineering','Memphis','TN','UNITED STATES','38116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 02:28:26',0,NULL,3,1,1,1,'\\ ','cookiewanko'),(7269,698112594001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',17.99,'buysia','cristobalm2006','cristomg2000@q.com','cristobal montes','3323 89th Ln NE','blaine','MN','UNITED STATES','55449-6808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 04:41:47',0,NULL,3,1,1,1,'\\ ','cristobalm2006'),(7270,735796347011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','sietse-koonstra','sietse.koonstra@gmail.com','Sietse Koonstra','De Gentiaan 10','De Westereen','','NETHERLANDS','9271LD','+31511701452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 04:45:06',0,NULL,3,1,2,1,'\\ ','sietse-koonstra'),(7274,736205464011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',70.95,'eastar4','scooby4491','bdav4491@gmail.com','Byron Davies','27 Ellery Street','Bundoora','Victoria','AUSTRALIA','3083','0394677232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 07:13:28',0,NULL,3,1,3,1,'RA183611045CN ','scooby4491\rMOSA001'),(7271,0,180692062164,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',18.5,'au-buy','1555377','terryf320@hotmail.com','Terry Fortney','116 Sherwood Common NW','Calgary','AB','CANADA','T3R1R2','(403) 923-2304','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 05:41:19',0,NULL,3,1,3,1,'RA183610610CN\r ','1555377\rSCLO001'),(7272,817251111012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','roberto.m.diez','roberto.m.diez@gmail.com','Roberto Martinez Diez','Avenida de Roma 14, 5ºD<br>Escalera Derecha','Coslada','Madrid','SPAIN','28820','645846137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 05:48:13',0,NULL,3,1,2,1,'\\ ','roberto.m.diez\racer 8pin1.00 15cm'),(7273,817255213012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.97,'eastar4','vladimirvalkov','valkov@podolsk.ru','Vladimir Valkov','Mashtakova 4B-11','Moscow, Podolsk','RU','RUSSIAN FEDERATION','142110','+7-910-442-22-23','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 06:06:51',0,NULL,3,1,2,1,'\\ ','vladimirvalkov'),(7275,736207021011,320411515152,'UNLOCKED Option GTM382 PCI-E 7.2Mbps Modem WWAN GTM 382',1,'WWOP003',28,'eastar4','ribiyhvost','ribiyglaz@mail.ru','Maxim Mokhov','Krasnogo Znameny 121-125<br>Красного Знамени 121-125','Vladivostok','','RUSSIAN FEDERATION','690014','89147906542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 07:18:39',0,NULL,3,1,2,1,'\\ ','ribiyhvost'),(7276,817272621012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','arjenschreur1989','arjenmoh@gmail.com','Arjen Schreur','Waagplein 59','Joure','','NETHERLANDS','8501BH','0619689931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 07:29:14',0,NULL,3,0,2,1,'\\ ','arjenschreur1989'),(7277,817277390012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','eduspe','freeshopman@uol.com.br','Eduardo S Pereira','Av.Casper Libero, 134, apto.612, Centro','Sao Paulo','SP','BRAZIL','01033901','(+5511)9485-5522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 08:28:02',0,NULL,3,1,2,1,NULL,'eduspe\r白色的'),(7278,817291265012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','manudood','turkeyman@gmail.com','Manu Evans C/O Remedy Entertainment','Päivantäite 8','Espoo','','FINLAND','02210','+358458847644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 08:51:52',0,NULL,3,1,3,1,'RA183611283CN ','manudood\rOTHP003'),(7279,735401090011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','crsanita','crsanita@msn.com','Anita Bryant','Global Linguist Solutions<br>Unit 42150','APO','AE','AA','09342','(703) 840-1361 ext.: 42609','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 09:11:18',0,NULL,3,1,1,1,'\\ ','crsanita'),(7280,602188705013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',87,'eastar4','spurlywurly','claire.wilks@yahoo.co.uk','Claire Wilks','6 Dampier Road','Coggeshall','Essex','UNITED KINGDOM','CO6 1QZ','01376561965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:18:08',0,NULL,3,1,3,1,'RA183611155CN ','spurlywurly\rCASS003\r一共买了10个CAB-6060'),(7281,817317149012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',29.98,'eastar4','prepress_fixing','scitex@ukr.net','Vasyl Postaychuk','Pushinoy Feodory 50-a/2','Kiev','','UKRAINE','03179','+380674663858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:33:50',0,NULL,3,1,2,1,'\\ ','prepress_fixing\rIBM版'),(7282,817318505012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',3,'WLAT009',29.94,'eastar4','wellesximenes','suportewelles@gmail.com','Welles Freire','Padre Valdevino 1386 102/a','Fortaleza','Ceara','BRAZIL','60135040','8532683678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:39:50',0,NULL,3,1,2,1,'\\ ','wellesximenes'),(7283,602194181013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',89.97,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:46:51',0,NULL,3,1,3,1,'RA183611116CN\r ','update_marcelo\rWWSI005'),(7284,736254757011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','warathorn','komtz@yahoo.com','warathorn khumsap','384 Charunsanitwong3 Rd.','Bangkokyai','Bangkok','THAILAND','10600','660870915806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:53:57',0,NULL,3,1,2,1,'\\ ','warathorn'),(7285,602195533013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','intrancer2011','shish@shish.ru','Shishov Nikolai Aleksandrovich','Kytyzova street, d. 2, kv. 432','Moscow','','RUSSIAN FEDERATION','121354','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 10:55:48',0,NULL,3,1,3,1,'RA183611204CN ','intrancer2011\rWLIN014\r通用版'),(7286,736277724011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','vpblau','karsten-ist@abwesend.de','KARSTEN HENNEBERG','Ententeich 32','CELLE','','GERMANY','29225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 12:19:04',0,NULL,3,1,2,1,'\\ ','vpblau'),(7287,736286573011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','dannich84','puwistii@gmail.com','Dmitry Bravshtein','Pinsker 10/2','Petah Tiqwa','merkaz','ISRAEL','49560','+972547641106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 12:50:35',0,NULL,3,1,2,1,'\\ ','dannich84'),(7288,736286237011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','adrideb72','cutsiepie32@aol.com','Adriana Mitchell','10825 E Keswick Rd<br>Apt 228','Philadelphia','PA','UNITED STATES','19154-4133','(215) 280-6362','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 12:53:45',0,NULL,3,1,1,1,'\\ ','adrideb72'),(7289,548222247003,130490602057,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'',38.9,'cnfaner','funny_intruder','sgorlov@gmail.com','Sergey Gorlov','27-75 Vl. Nevskiy str.','Voronezh','','RUSSIAN FEDERATION','394005','+7(473)2384523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 13:19:31',0,NULL,3,0,3,1,'RA183611235CN\r','funny_intruder'),(7290,602225839013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','rodaos','dstazic@vip.hr','Danijel Stazic','Dunavska 112','Osijek , 31000','Croatia','CROATIA','385','+385913337032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 13:22:34',0,NULL,3,1,2,1,'\\ ','rodaos\rCAB-6060'),(7291,553902476004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',15,'WWSI005',464.85,'cnfaner','itecsrl2011','f.cau@i-tec.it','I-TEC srl','via lorenteggio 280','Milano','MI','ITALY','20152','+39024839151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 13:30:53',0,NULL,3,1,4,1,'YW866475691CN ','itecsrl2011'),(7292,736302505011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','j.nelson7','justin.l.nelson@gmail.com','Nonaka Maki','305-2 South Island Mansion 201<br>Sunabe, Chatan Chou','Nakagami Gun','Okinawa','JAPAN','904-0111','+818017661337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 13:46:09',0,NULL,3,1,2,1,'\\ ','j.nelson7'),(7293,0,110712388450,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',121.99,'buysia','4839bwm','bwm1943@hotmail.com','Barney McConkey','7907 Bailey Bridge Way','Knoxville','TN','UNITED STATES','37938-3298','(865) 922-8962','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 13:49:34',0,NULL,3,1,1,1,'、 ','4839bwm\r一共买了两个'),(7294,736302752011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','suellen_alencar','suellenamelo@hotmail.com','Suellen Allencar Melo','Rua Antonio Carneiro, 210 - Centro','Araruna','PARAIBA','BRAZIL','58233-000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 13:54:37',0,NULL,3,1,2,1,'\\ ','suellen_alencar'),(7295,817378511012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',16.95,'eastar4uk','mr-chips','abbiejones143@msn.com','Abbie Jones','73 Lisfannon Park','Derry City','NIreland','UNITED KINGDOM','BT48 9DU','02871264949','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 13:55:27',0,NULL,3,1,3,1,'RA183611080CN\r ','mr-chips\rHSMO014\r英标\r黑色的旧的'),(7296,734950052011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','ekvilla','ekvilla85@hotmail.com','Eric Villaruz','31311 10th Ave S','Federal Way','WA','UNITED STATES','98003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 13:57:20',0,NULL,3,1,1,1,'\\ ','ekvilla'),(7297,817387480012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',65.99,'eastar4','victoriabears','victoriabearsebay@yahoo.ca','TERRY BARKER','1028 Colville Road','Victoria','BC','CANADA','v9a4p7','(250) 478-3154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 14:22:20',0,NULL,3,1,3,1,'RA183611399CN\r ','victoriabears\rHBPH001'),(7298,736327459011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','h3h3548','hani3li@gmail.com','Hani Ali Hassan','House:1291 Road:1538 Block::815','Isa Town','','BAHRAIN','1291','97339084472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 15:03:06',0,NULL,3,1,2,1,'\\ ','h3h3548'),(7299,736328491011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','hottroxx','cwhite@theatomicmoose.ca','Carlos White','63 Bethune Blvd','Scarborough','ON','CANADA','M1M 3C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 15:05:39',0,NULL,3,1,2,1,'\\ ','hottroxx'),(7300,736334982011,320419051307,'IBM 2nd HDD Caddy SATA2 + HDD CD-ROM to 2.0 USB caddy',1,'CACN001+CACN003',29.99,'eastar4','darindf','darin@omegasoft.org','Darin DeForest','1418 E Briarwood Ter','Phoenix','AZ','UNITED STATES','85048','(480) 460-0510','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 15:26:33',0,NULL,3,1,1,1,'\\ ','darindf'),(7301,736343472011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','minorca69','filipesilva.pt@gmail.com','FILIPE SILVA','BES SA - AG OLIVEIRA DO BAIRRO<br>AV DR ABILIO PEREIRA PINTO 27/26','OLIVEIRA DO BAIRRO','OLIVEIRA DO BAIRRO','PORTUGAL','3770-201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 15:52:11',0,NULL,3,1,3,1,'RA183611371CN\r ','退货回来  已经退款minorca69\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(7302,817420322012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 15:52:17',0,NULL,3,1,3,1,'RA183611102CN ','grandizom\rOTCN004*10'),(7303,817418392012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.4,'eastar4','vagnerclima','vagner36@msn.com','Vagner Lima','Rua Soldado José Costa, 107 apartmento 101 - Curicica - Jacarepaguá','RIO DE JANEIRO','Rio de Janeiro','BRAZIL','22780650','021 76004849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 15:53:37',0,NULL,3,1,2,1,'\\ ','vagnerclima\racer 5pin1.25 15cm'),(7304,817366779012,220763418811,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',5.8,'eastar4uk','p_cairney','ebay2@cairney.me.uk','Paul Cairney','55 Rose Street','Wokingham','Berkshire','UNITED KINGDOM','RG40 1XS','07973249291','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 15:54:36',0,NULL,3,1,3,1,'RA183611093CN ','p_cairney\rPOLO001'),(7305,602267270013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','974wizard','emmanuel974@gmail.com','Emmanuel HOARAU','22 chemin zaïre<br>logement 2','Petite Ile','','REUNION','97429','06292202863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 16:12:39',0,NULL,3,1,2,1,'\\ ','974wizard'),(7306,816999213012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','ronaldo_rrc','ronaldo.rrc@gmail.com','Ronaldo Carvalho','Av. Unisinos, 950 – Sala 401 - Edifício Pe. Rick','São Leopoldo','RS','BRAZIL','93022000','+555191749714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 16:23:47',0,NULL,3,1,3,1,'RA183611195CN ','ronaldo_rrc\rWWOT003'),(7307,736362774011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','alcs2000au','adrian.lehner@alcs.ch','Adrian Lehner','17 Georgina Street','Newtown','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 16:46:24',0,NULL,3,1,2,1,'\\ ','alcs2000au\r红边优联'),(7308,736365811011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','ringolt8797','ringo8797@hotmail.com','Ringo Wu','Flat D, 3/F, Tower 3<br>La Grove, Yuen Long','default','','HONG KONG','default','852-98645369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 16:51:40',0,NULL,3,1,2,1,'\\ ','ringolt8797'),(7309,553948204004,140516173934,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',25.49,'cnfaner','discmanx1','discman@delfi.lt','Giedrius Stasiulis','Geliu g. 24','Kaunas','Garliava','LITHUANIA','LT53260','+37067622720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 16:55:26',0,NULL,3,1,3,1,'RA183611297CN ','discmanx1\r旧的\rWLAP002'),(7310,817448790012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','phoenix0022','e_ulhaq22@hotmail.com','E Ul-haq','8 Whetley Close','Bradford','West Yorkshire','UNITED KINGDOM','BD8 8HL','01274221725','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 17:10:55',0,NULL,3,1,3,1,'RA183611120CN ','phoenix0022\rOTCN002'),(7311,602284048013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','miamiboxchile','gustavoallegrini@gmail.com','Gustavo Enrique Allegrini','8343 NW 64TH ST','Miami','FL','UNITED STATES','33166-2647','(305) 718-8787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 17:12:20',0,NULL,3,1,1,1,'\\ ','miamiboxchile'),(7312,736378535011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',3,'WLAT001+ANTY002',47.97,'eastar4','allagerev79','allagerev@mail.ru','aleksander lagerev','bulvar matrosa zheleznyaka 27 flat 45','moscow','','RUSSIAN FEDERATION','125239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 17:23:05',0,NULL,3,1,3,1,'RA183611796CN ','allagerev79\rWLAT001+ANTY002'),(7313,817458579012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',3,'MOMI002',46.5,'eastar4','gmussar','gary@mussar.com','Gary Mussar','53 Aero Dr.','Nepean','ON','CANADA','K2H 5E3','(613) 829-7035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 17:26:17',0,NULL,3,1,3,1,'RA183612010CN ','gmussar\rMOMI002'),(7314,602295981013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','nicereurope','gerencia@i95ds.com.ar','Claudio S Pizetti','Alte. Brown 54','Salta','Salta','ARGENTINA','4400','543874800108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 17:56:25',0,NULL,3,1,3,1,'RA183611408CN','nicereurope\r盒装的\rOTSO004*4\r新地址\rCarlos Nallar\rBalcarce 364 2B\rSalta Salta 4400\rARGENTINA\r\r\r\r\r\r'),(7315,736418295011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16.9,'eastar4uk','bluetch0','bluetch@hotmail.co.uk','Bob Luetchford','12 Wheatcroft Gdns.<br>Rushden','Northampton','Northamptonshire','UNITED KINGDOM','NN10 0EX','07752898686','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 18:58:06',0,NULL,3,1,3,1,'RA183611218CN\r ','bluetch0\rWLAP002\r旧的'),(7316,817501078012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','vranki42','ville.ranki@iki.fi','Ville Ranki','Näsilinnankatu 16 B 29','Tampere','','FINLAND','33210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 18:59:41',0,NULL,3,1,2,1,'\\ ','vranki42\r旧的'),(7317,736414400011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','bevblake61','bevblake@sbcglobal.net','Beverly Blake','439 Bradshaw St','Cedar Hill','TX','UNITED STATES','75104-1982','(972) 291-3032','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 18:59:53',0,NULL,3,1,1,1,'\\ ','bevblake61'),(7318,736062319011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','jesusponga','jesusponga@hotmail.com','Jesus Ponga Garcia','C/El Foro 6,   1ºC','Navatejera','Castilla y León','SPAIN','24193','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 19:36:29',0,NULL,3,1,3,1,'RA183611456CN\r ','jesusponga\rGLSG001*2'),(7319,731766855011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.99,'eastar4','epromrus','eprom@yandex.ru','Pavel Zakharov','Bashilovskaya Str.<br>build: 23, korp: 1, apt: 36','Moscow','','RUSSIAN FEDERATION','127287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 20:00:04',0,NULL,3,1,2,1,'\\ ','epromrus'),(7320,698362936001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','ukrfly','pavdima@yahoo.com','Dima Pavlenko','106 Harbor Coast St','Las Vegas','NV','UNITED STATES','89148-2820','(702) 419-3088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 20:16:52',0,NULL,3,1,1,1,'\\ ','ukrfly'),(7321,736452608011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','badboyke','vercauterenkevin@hotmail.com','kevin vercauteren','kruisbeeldstraat 31','hamme ','','BELGIUM','9220','3252413200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 20:26:55',0,NULL,3,1,2,1,'\\ ','badboyke\r红边优联'),(7322,736466543011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','htngmn2004','alant@servicemachine.net','Alan Thompson','800 Shorewood Dr','Dothan','AL','UNITED STATES','36303','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 20:53:54',0,NULL,3,1,1,1,'\\ ','htngmn2004\r红边优联'),(7323,817565177012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','arnaldohe63','arnaldohe@hotmail.com','Arnaldo Herrera','2011 NW 79th Ave<br>JBC GU742','Doral','FL','UNITED STATES','33122-1612','(305) 396-3775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 21:23:49',0,NULL,3,1,1,1,'\\ ','arnaldohe63'),(7324,817583314012,220807272265,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',19.99,'eastar4','vintfresh','vint_fresh@mail.ru','Evgeniy Ilukhin','Moskovskaya 42, korpus 6, kv. 33','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350072','+79180287155','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 22:18:08',0,NULL,3,1,2,1,'\\ ','vintfresh\r钢琴美女伞 要 Ivory'),(7325,602382355013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','tui_ru','tuirung@gmail.com','Rungroj Siripornmongkol','1<br>20 Floor, CP2 Tower, Ratchadapisek Road','Dindaeng','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 23:09:40',0,NULL,3,1,3,1,'RA183611076CN ','tui_ru\rBAZA001'),(7326,736517891011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','aleksey_b_rozhkov','rozhkoff.aleksey@mail.ru','Rozhkov Aleksey B.','Govorova 15-224','Moscow','Moscow','RUSSIAN FEDERATION','121596','+79262646300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 23:50:02',0,NULL,3,1,2,1,'\\ ','aleksey_b_rozhkov\r客户要求放在坚固的包装箱里'),(7327,602390739013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','samuel.rizzo','samuel365@ig.com.br','Samuel Rizzo','Rua Paissandu 59<br>1003','Rio de Janeiro','Rio de Janeiro','BRAZIL','22210-080','21-8262-6113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 23:59:06',0,NULL,3,1,2,1,'\\ ','samuel.rizzo'),(7328,736528464011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','tal223','tal@scinternet.net','Tal Ehlers','765 N 200 E','Loa','UT','UNITED STATES','84747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 00:41:27',0,NULL,3,1,1,1,'、 ','tal223'),(7329,817636297012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','valadarescam','leonardovaladares@hotmail.com','Leonardo Valadares Campos','SHCGN QD 708 BL D APTO 101<br>SHCGN QD 708 BL D APTO 101','BRASILIA','DISTRITO FEDERAL','BRAZIL','70740-764','+55 61 81239770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 01:52:01',0,NULL,3,1,2,1,'\\ ','valadarescam'),(7330,817639962012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',104.95,'eastar4','amysusannahpen','afpenisson@cityofno.com','Amy Penisson','807 Estalote Ave','Harvey','LA','UNITED STATES','70058-4039','(504) 908-2841','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 02:20:43',0,NULL,3,1,1,1,'\\ ','amysusannahpen\r兼容型3D眼镜 通用型'),(7331,548479050003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',21.9,'cnfaner','imacos','ivan.imacos@gmail.com','Ivan Cortes','Calle 18s # 13 16','Bogota','','COLOMBIA','111511','57 1 2784520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 02:39:02',0,NULL,3,1,3,1,'RA183611270CN\r ','imacos\rHSSE003'),(7332,736610115011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','zivtikh','zivviz@gmail.com','Ziv Tikhonov','HaAlon 372 a','Shtulim','','ISRAEL','79280','054-4965567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 08:06:01',0,NULL,3,1,2,1,'\\ ','zivtikh'),(7333,736617177011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','malan_anushka','max.malan@gmail.com','Malan Dharmathilake','119/20, Prestige Park, Hiribura','Galle','Southern','SRI LANKA','80000','0094777775177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 08:37:46',0,NULL,3,1,2,1,'\\ ','malan_anushka'),(7334,736619374011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','samcraig107','justcuts107@bigpond.com','samantha hill','po box 2290<br>Wandal','ROCKHAMPTON','Queensland','AUSTRALIA','4702','0749333045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 08:47:20',0,NULL,3,1,2,1,'\\ ','samcraig107\r黄色的'),(7335,736641375011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','ot9191','oliviatunstall@hotmail.com','Olivia Tunstall','6 Chings Road<br>Enner Glynn','Nelson','','NEW ZEALAND','7011','035475067','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 10:13:10',0,NULL,3,1,2,1,'\\ ','ot9191\r黑色的'),(7336,817760810012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','nethobby4fun','anc.cruz@sapo.pt','Antonio Cruz','R. das Almas, Lote 7<br>Póvoa do Paço','Cacia','Aveiro','PORTUGAL','3800-552','(351) 234315358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 11:12:37',0,NULL,3,0,2,1,'\\ ','nethobby4fun'),(7337,0,110712830874,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',61,'buysia','sunny707','bb007bb@yahoo.com','BOB BOONE','14811 Blackbird Lane','Fort Myers','FL','UNITED STATES','33919','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 11:22:07',0,NULL,3,1,1,1,'\\ ','sunny707'),(7338,736645042011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','huppi1','thomas@huppertz.info','Thomas Huppertz','Schmuckstr. 6','Bad Münstereifel','','GERMANY','53902','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 11:32:44',0,NULL,3,1,2,1,'\\ ','huppi1'),(7339,736664806011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','siddys','andrew.fairburn@sky.com','Andrew Fairburn','5 John Charles Way','Leeds','WYorkshire','UNITED KINGDOM','LS12 6QD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 11:37:13',0,NULL,3,1,2,1,'\\ ','siddys'),(7340,602506391013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.4,'eastar4','k3nz082','arieliha@gmail.com','Ariel Alejandro Iha','Helguera 2194 6to. B','Villa del Parque','Capital Federal, Buenos Aires, Argentina','ARGENTINA','1416','541161037460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 12:14:34',0,NULL,3,1,2,1,'\\ ','k3nz082\rHP 8pin 1.0 23cm \r'),(7341,602522590013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','shubina_olga','shubinales@mail.ru','Dmitriy Shubin','Karagandinskaya street, home 84, flat 89','Orenburg','Orenburgskiy region','RUSSIAN FEDERATION','460000','89058881444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 13:24:28',0,NULL,3,1,2,1,'\\ ','shubina_olga\r欧标'),(7342,817804409012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','2011paddlingman','mth.hne@pp.inet.fi','Mika Honkanen','Wilhelm Schildtin katu 11 A 18','Jyväskylä','','FINLAND','40740','040-067-9461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 13:25:55',0,NULL,3,1,2,1,'\\ ','2011paddlingman'),(7343,736716923011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','erik2929','erikkerimov@gmail.com','Erkin Kerim','Trakya Üniversitesi Lojmanları Gülapoğlu<br>Yerleşkesi A Blok Daire 8','Edirne','Merkez','TURKEY','22030','+905558352780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 14:19:39',0,NULL,3,1,3,1,'RA183611252CN ','erik2929\rWLIN015\r\r客户达4 美金挂号'),(7344,736721088011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','terracoin','snterranova@yahoo.com','Steven Terranova','111 Lake Boone Trl','Raleigh','NC','UNITED STATES','27608-1019','(919) 326-2181','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 14:32:23',0,NULL,3,1,1,1,'\\ ','terracoin'),(7345,602539584013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','bahman7891','bahman@ou.edu','Bahman Roostaei','Neuenahrerstr.<br>13','Koeln','','GERMANY','50968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 14:35:56',0,NULL,3,1,2,1,'\\ ','bahman7891\r红边优联'),(7346,602536519013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','frank31crx','frankvanleeuwen@upcmail.nl','F.van Leeuwen','Steenakker 177','Druten','Gelderland','NETHERLANDS','6651 JD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 15:09:47',0,NULL,3,1,2,1,'\\ ','frank31crx'),(7347,602544803013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',2,'HSNO023',29.96,'eastar4','assaf636','assafi_m@walla.co.il','assaf meltz','har sne,636','maccabim-reut','','ISRAEL','71908','+972528667527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 15:16:46',0,NULL,3,1,2,1,'\\ ','assaf636'),(7348,736742207011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','mmtil5','tilsonvic@aol.com','Matthew Tilson','14945 Cerezo Rd','Victorville','CA','UNITED STATES','92392-9310','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 15:29:41',0,NULL,3,1,1,1,'\\ ','mmtil5'),(7349,817858850012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',10,'WLAP004',49.9,'eastar4','rentner42','f.fischer@me.com','Frank Fischer','Lychener Str. 78','Berlin','','GERMANY','10437','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 15:47:30',0,NULL,3,1,3,1,'RA183611337CN ','rentner42\rWLAP004'),(7350,698644528001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK001',96,'buysia','cwolverine123','fborsato@shaw.ca','frank Borsato','17 Promontory Point','Edmonton','AB','CANADA','t6r 1j1','(780) 427-0138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 16:12:43',0,NULL,3,1,3,1,'RA183611385CN\r ','cwolverine123\rHSAK001'),(7351,736756619011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','hendriksutjiatmadja','hendrik_tjia@yahoo.com','Hendrik Sutjiatmadja','PT. Bersama Bangun Persada<br>Perkantoran Mega Sunter Blok D 10','Jakarta','Jakarta','INDONESIA','14350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 16:22:38',0,NULL,3,1,2,1,'\\ ','hendriksutjiatmadja'),(7352,817874932012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',104.95,'eastar4','mikebraiman','mikebraiman@yahoo.com','mike braiman','herzl,115/D/4<br>block 4','nahariya','isreal,herzl115/D/4','ISRAEL','22447','972049926382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 16:27:48',0,NULL,3,1,3,1,'RA183614506CN ','mikebraiman\rGLOT001*2\r兼容型3D眼镜 通用型'),(7353,736772579011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','zorantus1rtr','manuelnina@msn.com','Manuel Nina','Rua Mário Cesariny, 8, 5C','Lisboa','Portugal','PORTUGAL','1600-313','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-16 16:46:01',0,NULL,3,1,2,1,'\\ ','zorantus1rtr\r红边优联'),(7354,817897252012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','juicder2011','juicder@gmail.com','babintsev anatoly','prospect pobedy str,71-185','lipetsk','','RUSSIAN FEDERATION','398024','455010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 17:17:07',0,NULL,3,1,2,1,'\\ ','juicder2011'),(7355,602601732013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',53.64,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 18:09:17',0,NULL,3,1,3,1,'RA183611164CN ','small.mac\rWLAP008'),(7356,817929276012,220682005018,'2.1 HP DV9500t DV9500z DV9700  Bluetooth Module+cable',1,'BTHP2111',12.4,'eastar4','tkdldd51','tkdldd@charter.net','Larry Devereaux','440 N State St','Ionia','MI','UNITED STATES','48846-1427','(517) 930-1051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 18:22:58',0,NULL,3,1,1,1,'\\ ','tkdldd51\rHP 8pin 1.25 25cm '),(7357,736861259011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','tony2608','tony.lopes2@gmail.com','Tony Lopes','2608 Gates Ave<br># B','Redondo Beach','CA','UNITED STATES','90278-2218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 20:09:08',0,NULL,3,1,1,1,'\\ ','tony2608'),(7358,602640553013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',70.96,'eastar4','mthomesales','mtsudik@gmail.com','Maxim Tsudik','48 Aba Hilel st','Ramat Gan','Israel','ISRAEL','52532','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 20:12:04',0,NULL,3,1,3,1,'RA183611014CN ','mthomesales\rMOSA002'),(7359,736864154011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','maheo67','john@bestwindows.net','john wrzesinski','1112 cleveland ave','la grange park','IL','UNITED STATES','60526-1302','(708) 204-2446','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 20:17:40',0,NULL,3,1,1,1,'、 ','maheo67\r兼容型3D眼镜  samsung 专用'),(7360,736873070011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',8.99,'eastar4','din4ik2011','din4ik@live.com','Dina Podlubny','Haim 18/9','Quiriat Bialik','','ISRAEL','123456','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 20:38:00',0,NULL,3,1,2,1,'\\ ','din4ik2011'),(7361,818002697012,220759953524,'New APPLE iMac G6  Bluetooth Wireless Keyboard',1,'KBAP003',79.99,'eastar4','wil_963','captain_black_sweets@hotmail.com','William Logue','PO BOX 2439<br>4225 52nd Ave','Chetwynd','BC','CANADA','v0c1j0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 21:06:47',0,NULL,3,1,3,1,'RA183611310CN\r ','wil_963\rKBAP003'),(7362,736896196011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','magicred23','redmagic46@yahoo.com','Nayyirah Abdullah','20926 110th Ave','Queens Village','NY','UNITED STATES','11429-1825','(646) 299-2288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 21:40:56',0,NULL,3,1,1,1,'、 ','magicred23\r兼容型3D眼镜  samsung 专用'),(7363,601948161013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','samucalimb','slimberg@terra.com.br','Samuel F. Limberger','Rua Riachuelo, 1098 - Sala 1204<br>Centro','Porto Alegre','Rio Grande do Sul','BRAZIL','90010270','+55-51-81623337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 22:20:20',0,NULL,3,1,2,1,'\\ ','samucalimb'),(7364,818038706012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','meboobo','dolgovs@gmail.com','Sergei Dolgov','2004 route des Lucioles - BP 93','Sophia Antipolis Cedex','Provence-Alpes-Côte d\'Azur','FRANCE','06902','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 22:50:40',0,NULL,3,1,2,1,'\\ ','meboobo'),(7365,602684275013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','templeislandsound','bzurek@cox.net','Bob Zurek Jr.','1702 Jefferson St','Omaha','NE','UNITED STATES','68107','(402) 733-1706','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 23:09:25',0,NULL,3,1,1,1,'、 ','templeislandsound\r'),(7366,736933686011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','ehudh','ehudh@bezeqint.net','Ehud Hamami','84/28 Itzhak Rabin Road','Givatayim','','ISRAEL','53483','+972 (54) 4816523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 23:52:03',0,NULL,3,1,2,1,'\\ ','ehudh'),(7367,736935956011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','49marvin','dsteele@eea.epson.com','David Steele','5766 Barnswell Way','San Jose','CA','UNITED STATES','95138-1604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 00:01:36',0,NULL,3,1,1,1,'\\ ','49marvin'),(7368,736946360011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','boobahshazam','viper405@hotmail.com','JAMES WEBSTER','14817 METRO PLAZA BLVD.','EDMOND','OK','UNITED STATES','73013','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 00:49:00',0,NULL,3,1,1,1,'\\ ','boobahshazam'),(7369,698735892001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',2,'HSJB001',21.98,'buysia','thenov2242','thenov@comcast.net','James Novak','1663 Piazza DR','Salinas','CA','UNITED STATES','93905-2259','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 01:06:23',0,NULL,3,1,1,1,'、 ','thenov2242'),(7370,818085394012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','luvmy5girlz','amys@magiclink.com','amy widener','2014 Hillcrest Dr','twin falls','ID','UNITED STATES','83301-5349','(208) 751-2175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 01:52:28',0,NULL,3,1,6,1,'EE506555642CN','luvmy5girlz'),(7490,738065519011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','oskarecek','pavelneumann@web.de','Pavel Neumann','Mühlenring 2','Mühlenbeck','','GERMANY','16567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 05:40:42',0,NULL,3,1,2,1,'、 ','oskarecek'),(7371,818100010012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.65,'eastar4','exinocom','adam@exino.com','Adam Moore','36 Brookshire Court<br>Suite 5','Bedford','NS','CANADA','B4A 4E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 02:57:45',0,NULL,3,0,2,1,'\\ ','exinocom\r发210TS3个'),(7372,818101931012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','eon90210','ianmarigomen@gmail.com','Ian Marigomen','102-745 West 7th Avenue','Vancouver','BC','CANADA','V5Z1B9','(604) 614-9058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 03:08:59',0,NULL,3,1,2,1,'\\ ','eon90210'),(7373,818120473012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','carlosforest','carlosmorad@gmail.com','Carlos Mora Delgado','Jose Maria Vigil 2896<br>Colonia Providencia','Guadalajara','Jalisco','MEXICO','44630','38131235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 04:36:08',0,NULL,3,1,2,1,'\\ ','carlosforest\r七色彩虹伞'),(7374,736995336011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',5,'ANTY002',17.9,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 04:52:45',0,NULL,3,1,2,1,'\\ ','saiajin77'),(7375,554364418004,140535373671,'New Atheros AR9287 Wireless Half PCI-E Card+antenna',5,'WLAT007+ANTY001',84.5,'cnfaner','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 04:55:53',0,NULL,3,1,3,1,'RA183611133CN ','saiajin77\rWLAT007+ANTY001'),(7376,736999332011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','razer2808','blkybrny@gmail.com','Bert Ishikawa','94-509 Awamoi St','Waipahu','HI','UNITED STATES','96797-1612','(808) 927-3957','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 05:17:37',0,NULL,3,1,1,1,'\\ ','razer2808'),(7377,737002290011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','the_vulcan2000','pgrayward@iprimus.com.au','PHILIP G. RAYWARD','UNIT 8 / 8 LATROBE STREET<br>MENTONE','MELBOURNE','VICTORIA','AUSTRALIA','3194','0400288101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 05:35:59',0,NULL,3,1,2,1,'\\ ','the_vulcan2000'),(7378,737002472011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','tinycopper','xtfaith@singnet.com.sg','Faith Yeo','468B Admiralty Drive #10-25','Singapore','SINGAPORE','SINGAPORE','752468','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 05:53:23',0,NULL,3,1,3,1,' RA183611181CN\r','tinycopper\rCCGR001'),(7379,737009040011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','ozebarjadi','omid.zebarjadi@gmail.com','omid zebarjadi','37 Modoc Place','Novato','CA','UNITED STATES','94947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 06:15:45',0,NULL,3,1,1,1,'\\ ','ozebarjadi'),(7380,737010764011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',104.95,'eastar4','derekgharris','derek.g.harris@gmail.com','derek harris','4631 opal st','riverside','CA','UNITED STATES','92509','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 06:27:00',0,NULL,3,1,1,1,'\\','derekgharris\r兼容型3D眼镜 通用型'),(7381,737015199011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','terf49','tdf125@optonline.net','Teresa Franco','136 MILL ROAD','MANORVILLE','NY','UNITED STATES','11949','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 06:47:54',0,NULL,3,1,1,1,'\\ ','terf49'),(7382,818150015012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','yukyan2k','style2k.dc2@gmail.com','YUUKI ARATA','18-41-5<br>toda','kunohe-mura,kunohe-gun','Iwate','JAPAN','028-6612','0195432057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 07:10:13',0,NULL,3,1,2,1,'\\ ','yukyan2k'),(7383,737026885011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','bronze44','bronze44@gmail.com','israel b gutierrez','2824 W Pintail Way','elk grove','CA','UNITED STATES','95757-8201','(916) 897-8764','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 07:39:49',0,NULL,3,1,1,1,'\\ ','bronze44'),(7384,602782990013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',1,'BAZA001',75.6,'eastar4','charmedsuperman','marksantos702@gmail.com','Mark Santos','PO Box 30851','Las Vegas','NV','UNITED STATES','89173-0851','(702) 767-3009','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 09:22:44',0,NULL,3,1,1,1,'\\ ','charmedsuperman'),(7385,602783938013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','sleeper7135','jykke@nic.fi','Jyrki Takalo-Kastari','Kokkareentie 10','Kello','','FINLAND','90820','050 4820683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 09:24:09',0,NULL,3,1,2,1,'\\ ','sleeper7135\r旧的'),(7386,737063231011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','bigergeor','bigergeo@yahoo.gr','GEORGE BIGERIS','P.O. BOX 8107','ATHENS','ASPROPYRGOS','GREECE','19300','+306983521782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 09:35:12',0,NULL,3,1,2,1,'\\ ','bigergeor\r欧标'),(7387,818200952012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','xbox-chris','wwefan001@hotmail.com','Christopher Constantinou','8/10 airlie','melbourne','Victoria','AUSTRALIA','3186','0390770044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 09:47:20',0,NULL,3,1,2,1,'\\ ','xbox-chris'),(7388,818207399012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','liighseva','tomy333@gmx.ch','Thomas Gilg','Seestrasse 29','Kastanienbaum','','SWITZERLAND','6047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 10:07:22',0,NULL,3,1,2,1,'\\ ','liighseva'),(7389,737082610011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','mungmonger','feloosa@hotmail.com','David Rothwell','1G/75 Lorne St.','Auckland City','Auckland','NEW ZEALAND','1010','(640) 211-3739 ext.: 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 10:27:12',0,NULL,3,1,2,1,'\\ ','mungmonger'),(7390,548857648003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','drvandi2005','halphonse@hotmail.com','HANY DEMIAN','202 UNIT 202 Wlater Havill dr.','Halifax','NS','CANADA','B3N3M4','(902) 292-9696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 11:37:30',0,NULL,3,1,3,1,'RA183611147CN\r ','drvandi2005\rHSMO011'),(7391,602824321013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','neromester','banfai.gabor@freemail.hu','Gabor Banfai','30 Great Lynch<br>Middleton','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK10 9BF','07877161563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 11:50:26',0,NULL,3,1,2,1,'\\ ','neromester\rCAB-6060'),(7392,817838619012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','bacujiu4','kvsergeevinbox@gmail.com','Кирилл Сергеев','Спортивная, 6, 46','Лыткарино','Московская область','RUSSIAN FEDERATION','140083','+79262353118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 12:31:12',0,NULL,3,1,3,1,'RA183611323CN ','bacujiu4'),(7393,602838162013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','sntu2921','cph1215@chol.com','Pilhyun Chung','Hyundai APT 204-604<br>3029 Bokdae 1-dong, Heungdeok-gu','CheongJu','Chungbuk','KOREA,REPUBLIC OF','361-815','82-10-9278-9232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 12:34:36',0,NULL,3,1,3,1,'RA183611249CN\r ','sntu2921\rWLIN014'),(7394,818276765012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',37.99,'eastar4uk','opalosan','ovi.itw@gmail.com','Ovidiu Palosanu','Express Data<br>Level 2, 99 Coventry Street','South Melbourne','Victoria','AUSTRALIA','3205','0392787221','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-17 12:41:42',0,NULL,3,1,3,1,'RA183611062CN ','opalosan\rBAZA001'),(7395,737144438011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','068592377','cyril.snegurov@gmail.com','Cyril Snigurov','14 Daintree Way, Menai','Sydney','New South Wales','AUSTRALIA','2234','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 12:55:51',0,NULL,3,1,2,1,'\\ ','068592377\r澳标'),(7396,737155451011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','extorr1','lavety@hotmail.com','Jack Lavety','16 Deeside Park','ABERDEEN','Aberdeenshire','UNITED KINGDOM','AB15 7PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 13:23:10',0,NULL,3,1,3,1,'RA183611178CN\r ','extorr1\rRELO003\r红边优联'),(7397,737169760011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','aridzuan','ahmridz@tm.net.my','Ahmad Ridzuan','TM Global, Level 54, Menara TM<br>Jalan Pantai Baharu','Kuala Lumpur','Malaysia','MALAYSIA','50672','0133882410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 13:52:01',0,NULL,3,1,2,1,'\\ ','aridzuan'),(7398,602903832013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','strizzetta','abatec@gmx.net','Cristian Abate','Windeggstrasse 3','Niederurnen','','SWITZERLAND','8867','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 15:39:26',0,NULL,3,1,2,1,'\\ ','strizzetta'),(7399,818372884012,220814220259,'NIB Sony TDG-BR50/L Youth Size 3D Active Glasses  Blue',1,'OTSO006',69.99,'eastar4','elpibee','elpibee@gmail.com','Mariano Gaston Vera','santa cruz 440','Ezpeleta  (quilmes)','Buenos Aires','ARGENTINA','1882','+541142541014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 15:40:01',0,NULL,3,1,3,1,'RA183611354CN ','elpibee\rOTSO006'),(7400,737237855011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','1004170850','paul.gadsby4@btinternet.com','Paul Gadsby','31 Mapleton Road','DRAYCOTT','Derbyshire','UNITED KINGDOM','DE72 3QQ','01332872939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 15:57:08',0,NULL,3,1,2,1,'\\ ','1004170850\racer 8pin1.00 15cm'),(7401,602918704013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',155,'eastar4','mi062006','pcmike1@yahoo.com','Michael Miller','923 Clark St','Muskegon','MI','UNITED STATES','49442-3811','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mi062006'),(7402,602922791013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','beschter','minks2@gmx.de','Daniel Minks','Westbahnhofstr. 14','Tübingen','','GERMANY','72070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 16:21:16',0,NULL,3,1,2,1,'\\ ','beschter'),(7403,737262837011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','npk_epay','nattapon999@hotmail.com','Nattapon Kaensiri','14/11 Thanintorn Village Moo 9<br>Vibhawadee Rangsit Road.','Donmuang','Bangkok','THAILAND','10210','66877039990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 16:37:35',0,NULL,3,1,2,1,'\\ ','npk_epay'),(7404,737268236011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','mattlessins','mlessins@gmail.com','Matthew Lessins','4565 Middleton Dr','West Bloomfield','MI','UNITED STATES','48323-3640','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 16:42:18',0,NULL,3,1,1,1,'\\ ','mattlessins'),(7405,737274629011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','er_maqui','er_maqui@darkbolt.net','Nany Rivero','CL Elias Espinosa 11, P1, 4B','Santa Cruz de Tenerife','Canarias','SPAIN','38107','673537921','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-17 16:57:27',0,NULL,3,1,2,1,'\\ ','er_maqui\r红边优联'),(7406,602959422013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',2,'CRLO002',19.8,'eastar4','bsnow101','bsnowee@aol.com','Blake Dunnahoo','115 Riverside Park','Abilene','TX','UNITED STATES','79605','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 17:29:24',0,NULL,3,1,1,1,'\\ ','bsnow101\r旧的'),(7407,602982838013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','repairtmail','postal2620@sbcglobal.net','Rex L Weaver','542 Walnut Hill Dr','Hot Springs National Park','AR','UNITED STATES','71913-8831','(501) 767-2620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 18:04:56',0,NULL,3,1,1,1,'\\ ','repairtmail\r兼容型3D眼镜 通用型'),(7408,737366384011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',2,'HSSE009',131.98,'eastar4','dall4643','sotndr@yahoo.com','Donna Allen','1610 Robert E Lee<br>#611','New Orleans','LA','UNITED STATES','70122','(504) 231-9315','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 18:35:51',0,NULL,3,1,1,1,'、 ','dall4643\r美标'),(7409,737406365011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','iammastersensei','jvdw007@gmail.com','Jaco van der Walt','52 Lambourne Way<br>Tongham','Farnham','Surrey','UNITED KINGDOM','gu10 1ab','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 19:23:02',0,NULL,3,1,2,1,'\\ ','iammastersensei'),(7410,818584939012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','torsales','wingodigital@gmail.com','Wenge Du','1503-155 LEGION RD N','ETOBICOKE','ON','CANADA','M8Y 0A7','(647) 868-3686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 19:45:13',0,NULL,3,0,2,1,'\\ ','torsales\r\r'),(7411,818600224012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','tourer22','webmaster10@frontiernet.net','Sampson Sport Touring','PO Box 272<br>4922 Bullion','Chloride','AZ','UNITED STATES','86431-0272','(928) 565-2274','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 20:12:30',0,NULL,3,1,1,1,'\\ ','tourer22'),(7412,554677562004,140516874483,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',17.99,'cnfaner','benkejan','benkej@t-online.hu','Benke Janos','Bercsenyi Miklos utca 92/a','Budapest','','HUNGARY','1188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 20:55:12',0,NULL,3,1,3,1,'RA183611306CN ','benkejan\rWLAT001+ANTY002\r'),(7413,737475653011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','chameo74','chameo74-encheres@yahoo.fr','Christophe Roy','56C Riverside Drive','Aberdeen','Aberdeen City','UNITED KINGDOM','AB10 7LE','06 21 25 06 39','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 21:09:48',0,NULL,3,1,3,1,'RA183611028CN\r ','chameo74\r红边优联\rRELO003'),(7414,603082218013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','b-l-c-h','christoffer.blindheim@gmail.com','Christoffer Blindheim','Sommerlystvegen 15','Trondheim','','NORWAY','7019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 21:09:57',0,NULL,3,1,2,1,'、 ','b-l-c-h\r新的'),(7415,818649913012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','adanblinblindj','adanblinblin@yahoo.com','AdanDJ BlinBlin','RR 1 Box 3125','Anasco','PR','UNITED STATES','00610','(787) 362-0422','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'adanblinblindj'),(7416,549119343003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','shannon-william','driskellwilliam@yahoo.com','william driskell','1905 Elmore St<br>Apt 306','CINCINNATI','OH','UNITED STATES','45223-2399','(513) 328-9588','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-17 22:09:08',0,NULL,3,1,1,1,'\\ ','shannon-william'),(7417,603109870013,230515667820,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD',2,'BAZA001',167.2,'eastar4','andre.rangel','andrelrangel@gmail.com','Andre Rangel','Rua Vilela Tavares, 148/101<br>Meier','Rio de Janeiro','RJ','BRAZIL','20725220','+552182790746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 22:47:11',0,NULL,3,1,3,1,'RA183611221CN ','BAZA001'),(7418,737514459011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',22.59,'eastar4uk','shafiq786110','shafiq786110@gmail.com','Shafiq Pradhan','1 Wedgewood Close','Epping','Essex','UNITED KINGDOM','CM16 4QD','01992575064','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 22:51:42',0,NULL,3,1,3,1,'RA183611031CN\r ','shafiq786110\rUDAP001'),(7419,818689134012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','indianajonesjl9981','tuffyanimeblue@yahoo.com','Justin Lewis','8330 Domer Dr','Spring','TX','UNITED STATES','77379-6712','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 23:01:34',0,NULL,3,1,1,1,'\\ ','indianajonesjl9981\r发210TS'),(7420,699335234001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','dallas1504','dallas@ocgolfclub.com','Dallas Daul','20124 Beavercreek Rd','Oregon City','OR','UNITED STATES','97045','(503) 518-2846','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 23:08:34',0,NULL,3,1,1,1,'\\ ','dallas1504'),(7421,737521869011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','takhisis28','nessbevan@internode.on.net','Vanessa Bevan','21 Walter St','Rutherford','New South Wales','AUSTRALIA','2320','0249324976','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-17 23:12:36',0,NULL,3,1,3,1,'RA183611266CN ','takhisis28\rOTSO004*2'),(7422,603121258013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','jishywa','jsutinen@gmail.com','Josh Sutinen','52175 Heatherstone Ave','Macomb','MI','UNITED STATES','48042-3553','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 23:33:13',0,NULL,3,1,1,1,'\\ ','jishywa'),(7423,603121712013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','skinned77','skinned@rogers.com','Emanuel Melo','59 Sutcliffe Terrace','Nepean','ON','CANADA','K2J 4N8','(613) 440-2243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 23:34:55',0,NULL,3,1,2,1,'\\ ','skinned77\r全高卡 正式 新'),(7424,549158340003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.99,'cnfaner','smart.world','solano.shop@gmail.com','Juliana Calvelo e Silva','Avenida 7 de Setembro 175<br>Apartamento 1001 Icarai','Niteroi','Rio de Janeiro','BRAZIL','24230-251','55 21 27106878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 01:03:50',0,NULL,3,1,3,1,'RA183611345CN ','smart.world\rMOOE002\r发OEM的'),(7425,699370680001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','ueynnhi','ueynnhi@yahoo.com','sang vu','13006 Ansell Ct','garden grove','CA','UNITED STATES','92844-3414','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 01:15:08',0,NULL,3,1,1,1,'\\ ','ueynnhi'),(7426,603149347013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','lawdoc819','jimbo2468@aol.com','James Bopp','41 N Suffolk Dr','Rocky Point','NY','UNITED STATES','11778-9225','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 01:30:08',0,NULL,3,1,1,1,'\\ ','lawdoc819\r兼容型3D眼镜 通用型'),(7427,737563317011,320721867028,'Transparent Dome Rain Sun Umbrella with black trim',1,'UMTR001',15.95,'eastar4','vasanthttca','vasanth.tt@live.com','Jenifer V','No. 19/1 New No 4<br>3rd street, Sowrasthra nagar,Choolaimedu','Chennai','TN','INDIA','600094','(979) 108-7586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 01:38:02',0,NULL,3,1,2,1,'\\ ','vasanthttca'),(7428,818750602012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','rusty_1256','rustyaccounts@gmail.com','Allan Mackwell','11 Palmer Parade','Cremorne','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 01:59:56',0,NULL,3,1,2,1,'\\ ','rusty_1256'),(7429,603171668013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','onencguard','mjchauhan@gmail.com','Marc Chauhan','3906 Edgewood Terrace Dr','Greensboro','NC','UNITED STATES','27406-8695','(704) 491-9786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 03:09:07',0,NULL,3,1,1,1,'\\ ','onencguard'),(7430,603171590013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','carolinecodsi2010','carolinecodsi@yahoo.ca','Caroline Codsi','600 de maisonneuve W. #2510','Montreal','QC','CANADA','H3A3J2','(514) 954-4124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 03:09:22',0,NULL,3,1,3,1,'RA183614435CN ','carolinecodsi2010\rGLOT001*3\r兼容型3D眼镜 通用型'),(7431,603111284013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',5,'MOSA005',459.8,'eastar4','mortn2010','mortn@list.ru','9016ALEXEY POKHABOV','28,PARTIZANSKY PROSPEKT<br>DIGITAL HALL','VLADIVOSTOK','','RUSSIAN FEDERATION','690106','89084423989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 04:20:19',0,NULL,3,1,5,1,'CP227165692CN ','mortn2010'),(7432,818153633012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','agimatoys','agimatoys@gmail.com','Edmond Yanga','69- 05 Roosevelt Ave','Woodside','NY','UNITED STATES','11377-2933','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 04:32:56',0,NULL,3,1,1,1,'\\ ','agimatoys\r'),(7433,737321716011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','jagsell','warriorjoe00007@hotmail.com','Joseph Gennaro','107 Hawthorne St<br>Apt 2','Syracuse','NY','UNITED STATES','13210-2125','(315) 849-0770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 04:41:04',0,NULL,3,1,1,1,'\\ ','jagsell'),(7434,603187403013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',82.9,'eastar4','redhotstudio','tolyn@yahoo.com','Azlin Abd Rahman','2, Jalan Putra Perdana 3/13,<br>Taman Putra Perdana','Puchong','Selangor','MALAYSIA','47130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 04:48:13',0,NULL,3,1,3,1,'RA183611535CN\r ','redhotstudio\rOTES001'),(7435,603200543013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',6,'CCGR001',41.28,'eastar4','almohnds','eng.emad99@gmail.com','EMAD MOHD ALASKAR','P.O.BOX 674','HAIL','HAIL','SAUDI ARABIA','81421','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 06:33:57',0,NULL,3,1,3,1,'RA183611558CN\r ','almohnds\rCCGR001'),(7436,818827867012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','dom_ari','dominic_arias2003@yahoo.com.au','Dominic Arias','1/5<br>Parrs road','Croydon','Victoria','AUSTRALIA','3136','0390187134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 07:39:51',0,NULL,3,1,2,1,'\\ ','dom_ari'),(7437,736595720011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','kkhloe','shpxxx@gmail.com','Leong Wen-Ting','Blk 984D Buangkok Link #05-29','-','','SINGAPORE','537984','91859049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 07:53:26',0,NULL,3,1,11,1,NULL,'kkhloe\rCCGR001'),(7438,603201962013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','jethroheller','donutpond@gmail.com','Eric Leong','51 Changi Business Park Central 2,<br>The Signature, #05-01.','default','','SINGAPORE','486066','065 9740-1522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 07:55:42',0,NULL,3,1,3,1,'RA183611544CN\r ','jethroheller\rWWOT001+ANCN001'),(7439,601927919013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',91.96,'eastar4','camilacg','camilamoret@yahoo.com.br','Camila Moret','Rua das Figueiras, 1800 <br>apto 203 - Bloco C','Santo Andre','Sao Paulo','BRAZIL','09080301','+551180273870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 09:30:42',0,NULL,3,1,3,1,'RA183611907CN\r ','camilacg\rMOSA004'),(7440,603230946013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','kiwanoo','did@kiwano.be','Didier Boulvin','ARC Europe<br>Av des Olympiades 2','Brussels','','BELGIUM','1140','0485114596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 09:48:45',0,NULL,3,1,2,1,'\\ ','kiwanoo'),(7441,818865476012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','mayksabi','pableras38@hotmail.com','JESUS MAINER','CALLE LEPANTO N 13','SABIÑANIGO  (HUESCA )','Aragón','SPAIN','22600','697477489','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 10:06:20',0,NULL,3,1,2,1,'\\ ','mayksabi'),(7442,818872098012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 10:29:07',0,NULL,3,1,3,1,'RA183611822CN\r ','avextra-co-uk\rOTCN004*10'),(7443,818876364012,220704730766,'New Plantronics Voyager 855 Bluetooth Headset+carcharge',1,'HSPL009+CCPL001',42,'eastar4uk','sydney88808','sydney880@gmail.com','LEO (SO25092)','Techoni.Mobile.Phones<br>Suite 214, 160 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 10:47:47',0,NULL,3,1,3,1,'RA183611779CN\r ','sydney88808\rHSPL009+CCPL001'),(7444,737696370011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',50.97,'eastar4uk','jaymacspurs','jamie@f1colour.co.uk','James Robinson','91 Barnehurst Avenue','Bexleyheath','Kent','UNITED KINGDOM','DA76QD','01322330406','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 11:25:36',0,NULL,3,1,3,1,'RA183611938CN\r ','jaymacspurs\rMOAP001\r发之前测试一下'),(7445,737702146011,320596607503,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',7.7,'eastar4','aussietea1','jm@solarchoice.net','J. Almustafa','61 Arundel Ave','Reservoir','Victoria','AUSTRALIA','3073','0413217442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 11:44:51',0,NULL,3,1,2,1,'\\ ','aussietea1'),(7446,736163898011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',104.95,'eastar4','ravimis1','ravimis1@charter.net','pradip mishra','280 Deerwood Rd<br>clarksville','clarksville','TN','UNITED STATES','37043-7401','(931) 358-4960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 11:46:48',0,NULL,3,1,1,1,'\\','ravimis1\r兼容型3D眼镜 通用型'),(7447,737708444011,320721819844,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',17.99,'eastar4','crimsonpebble1','crimsonpebble@hotmail.com','Grace Chin','30 Kinnoull Grove','Glen Waverley','Victoria','AUSTRALIA','3150','0388028608','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 12:06:05',0,NULL,3,1,2,1,'\\ ','crimsonpebble1\r草莓伞 '),(7448,737720462011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','8jpc','pakko091@gmail.com','Justin Chan','Apt.4<br>120 Colborne Street','Kingston','ON','CANADA','K7K 1C9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 12:59:55',0,NULL,3,1,2,1,'\\ ','8jpc'),(7449,603269514013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','cathaz','cathaszard@gmail.com','Cat Haszard','C/O CyberdesignWorks<br>Level 1, 49 Herbert Street','Artarmon','New South Wales','AUSTRALIA','2064','0298949696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 13:01:02',0,NULL,3,1,2,1,'\\ ','cathaz'),(7450,603270212013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',4,'CCGR001',27.52,'eastar4','racerx311','racerx@htc.net','Kevin Caby','236 Charles St','Red Bud','IL','UNITED STATES','62278-1305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 13:02:56',0,NULL,3,1,1,1,'\\ ','racerx311'),(7451,818925456012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','jimnorth2003','jimnorth1958@o2.co.uk','Jim North','7 Jervis Avenue','Enfield','Middlesex','UNITED KINGDOM','EN3 6LJ','01992787936','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 13:12:28',0,NULL,3,1,3,1,'RA183611867CN\r ','jimnorth2003\rOTHP004'),(7452,737734406011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','ezwakeboarder','erichune@hotmail.com','Eric Hune','7141 Peninsula Dr NE','Rockford','MI','UNITED STATES','49341-9506','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 13:27:19',0,NULL,3,1,1,1,'\\ ','ezwakeboarder'),(7453,737739565011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','fur86','jen_schilbach@hotmail.com','Jennifer Schilbach','20 Fitzgibbon Crescent<br>Caulfield North','Melbourne','Victoria','AUSTRALIA','3161','0395329979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 13:43:02',0,NULL,3,1,2,1,'\\ ','fur86'),(7454,737739601011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','bonassifer','bonassi_fer@hotmail.com','Fernando Cordeiro','Flora Avenue, 1170 - Block 04 - ap.32<br>neighborhood jaguaribe','Osasco','São Paulo','BRAZIL','06053-130','55-11-80910602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 13:44:59',0,NULL,3,1,2,1,'\\ ','bonassifer'),(7455,737759690011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','kepesak','martin.zgos@tiscali.cz','Ladislav Pospisil','Na Valticke 44','Breclav 4','Breclav','CZECH REPUBLIC','69141','00420519334260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 14:45:36',0,NULL,3,1,2,1,'\\ ','kepesak'),(7456,818961016012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',9.9,'eastar4','wright-11','wright1@aol.com','Mark L Wright','1707 S Sherbourne Dr','Los Angeles','CA','UNITED STATES','90035','(310) 559-5250','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 14:52:03',0,NULL,3,1,1,1,'\\ ','wright-11\r旧的'),(7457,603296602013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','joseph1073','josber1073@hotmail.com','JOSE ANDRES BERNAD BUISÁN','C/RAMÓN MARIA DEL VALLE INCLÁN 84','ALCALÁ DE HENARES','Madrid','SPAIN','28806','678990044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 14:54:37',0,NULL,3,1,3,1,'RA183614418CN ','joseph1073\rGLOT001*3\r兼容型3D眼镜 通用型'),(7458,0,110715649616,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',54,'buysia','hopsalots_toybox','s_kohlrusch@earthlink.net','Sheri Kohlrusch','11167 5th St NE','Blaine','MN','UNITED STATES','55434-1733','(763) 757-4881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 15:11:26',0,NULL,3,1,1,1,'\\ ','hopsalots_toybox'),(7459,603327605013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','igrega1','pozek.g@me.com','grega pozek','Vrtnarija 2D','Vrhnika','','SLOVENIA','1360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 16:39:34',0,NULL,3,1,2,1,'\\ ','igrega1'),(7460,554902940004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',53.99,'cnfaner','olegnik12','lkakunin@gmail.com','Aliaksei Kakunin','Minsk region','Lesnoy 9 - 70','Minsk region','BELARUS','223040','+375293500839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 16:43:54',0,NULL,3,1,3,1,'RA183611875CN\r ','olegnik12\rWWOT003+ANCN001'),(7461,602311396013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','marcinju','marcin@semco.pl','Marcin Just','Śmołowo 16','Szamotuły','wielkopolskie','POLAND','64500','501 556466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 16:53:25',0,NULL,3,1,3,1,'RA183611924CN\r ','marcinju\rHSNO019'),(7462,554905753004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',2,'HSPL002',25.98,'cnfaner','dmarviin','dmarviin@yahoo.com','Dereck Jones','1296 Pacific St. Apt. 607','Brooklyn','NY','UNITED STATES','11216','(347) 565-7780','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-18 16:55:32',0,NULL,3,1,1,1,'\\ ','dmarviin'),(7463,737812987011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','charnyuts','charnyut@yahoo.com','Charnyut Srimakutphan','35/69 Moo 12, Praditmanuthuam Rd.<br>Klong-Kuam, Buang-Kuam','Bangkok','BA','THAILAND','10230','66816557559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 17:01:09',0,NULL,3,1,2,1,'\\ ','charnyuts'),(7464,737824277011,320721819796,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',19.99,'eastar4','ricknjme','jamielynn_34@live.com','jamie Anderson','2050 Hansen Ave','burley','ID','UNITED STATES','83318-2537','(208) 220-3673','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-18 17:26:20',0,NULL,3,1,1,1,'\\ ','ricknjme\r蕾丝蝴蝶结伞 '),(7465,549343674003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','pimpdaloose336','pimpdaloose@yahoo.com','Keith R. Collins','3236 Butner Mill Rd','East Bend','NC','UNITED STATES','27018-7132','(336) 699-6037','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-18 17:32:58',0,NULL,3,1,1,1,'\\ ','pimpdaloose336'),(7466,554927788004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','chandulk','chandu@sarasavi.lk','chandu haputhanthri','1/3, St. Johns Road<br>Standley Thilakarathne Mw','Nugegoda','Western','SRI LANKA','10250','+94713848484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 18:04:58',0,NULL,3,1,3,1,'RA183611972CN\r ','chandulk\rOTHP004'),(7467,819074308012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.58,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 18:44:14',0,NULL,3,1,3,1,'RA183611836CN\r ','grandizom\rOTCN004*10\r黑色的'),(7468,737872136011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',32.94,'eastar4','vkomissarov','vladislav@komissarov.net','Vladislav Komissarov','Truda, 26, 83','Kaluga','','RUSSIAN FEDERATION','248030','+79165895803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 18:58:26',0,NULL,3,1,3,1,'RA183611986CN\r ','vkomissarov\r欧标\rHSNO003'),(7469,737904246011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','maplesyrupdeals','maple.syrup.deals@gmail.com','Rob Martin','1888 East 61 Avenue<br>Basement Suite','Vancouver','BC','CANADA','V5P2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 19:57:38',0,NULL,5,0,18,0,' ','maplesyrupdeals\r客户撤单了'),(7470,603397895013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','mbilalbhatti','bilalbhatti@bilalbhatti.com','Muhammad Bilal Bhatti','House No A-6, Ghazi Colony<br>Tipu Road, Chaklala','Rawalpindi','Punjab','PAKISTAN','46000','923455929499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 19:48:47',0,NULL,3,1,3,1,'RA183611969CN\r ','mbilalbhatti\rCAB-6060\rCASS003'),(7471,737912304011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mmb1316','mattbai@gmail.com','Matthew Bailey','1020 Majors Dr','Mesquite','TX','UNITED STATES','75149','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 20:16:57',0,NULL,3,1,1,1,'\\ ','mmb1316'),(7472,737913224011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','maplesyrupdeals','maple.syrup.deals@gmail.com','Rob Martin','1888 East 61 Avenue<br>Basement Suite','Vancouver','BC','CANADA','V5P2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 20:18:35',0,NULL,5,0,18,0,NULL,'maplesyrupdeals\racer 4pin1.25 6cm'),(7473,603412501013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',18.5,'eastar4','yonatana','yonatan.amir@gmail.com','Yonatan Amir','55/4 Einstein Street','Tel Aviv','','ISRAEL','69102','0502056969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 20:26:09',0,NULL,3,1,2,1,'\\ ','yonatana'),(7474,549417132003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','halrockwell','elibelous@gmail.com','Eli Belous','Yoseftal st. 22/22','Kiryat Yam','','ISRAEL','29045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 20:59:29',0,NULL,3,1,3,1,'RA183611990CN\r ','halrockwell\rWLAT007'),(7475,819168046012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','gnomenatty','natalie.holt@orange.net','Natalie Holt','61 Bowcombe<br>Netley Abbey','Southampton','Hampshire','UNITED KINGDOM','SO31 5GP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 21:33:05',0,NULL,3,1,3,1,'RA183612006CN\r','gnomenatty\rOTHP003'),(7476,737949340011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','tstduke77','tstduke@gmail.com','Tyson  St Duke','23 Dawson St Beldon','Perth','Western Australia','AUSTRALIA','6027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 21:33:06',0,NULL,3,1,2,1,'\\ ','tstduke77'),(7477,819197086012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','lips0628','templesgold@gmail.com','Lisa Pham','4725 Fielder St','Midland','TX','UNITED STATES','79707-2817','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 22:55:55',0,NULL,3,1,1,1,'\\ ','lips0628\r七色彩虹伞 '),(7478,549446389003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.9,'cnfaner','pocobueno09','pete@sunrise.ch','NC Tec GmbH','Neubrunn 6','Unterstammheim','','SWITZERLAND','CH-8476','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 23:04:48',0,NULL,3,1,3,1,'RA183611915CN\r ','pocobueno09\rHSNO019+CCNO001'),(7479,737974628011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','marciohubr','marciohu@gmail.com','Marcio Haruo Uessugue','Av. Paraná, 05','Goioerê','PR','BRAZIL','87360000','44-8827-4611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 23:15:06',0,NULL,3,1,3,1,'RA183611853CN\r ','marciohubr\rGLSG001'),(7480,549450692003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',13.99,'cnfaner','puaten','puaten@hotmail.com','BeomJik Kim','815 N 52nd street #1268','PHOENIX','AZ','UNITED STATES','85008','(512) 653-4813','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-18 23:28:41',0,NULL,3,1,1,1,'\\ ','puaten'),(7481,737986547011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','supermuch','zachhobson@gmail.com','Zach Hobson','6413 Glenwood Road','Louisville','KY','UNITED STATES','40222','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 23:36:25',0,NULL,3,1,1,1,'\\ ','supermuch'),(7482,737994230011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',35.99,'eastar4','langui1111','impasse2@hotmail.com','Matías Caro','Alférez Pareja 256','Capital Federal','Buenos Aires','ARGENTINA','C1107BJD','5170-6764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 00:12:30',0,NULL,3,1,3,1,'RA183611840CN\r ','langui1111\rWWSI005+ANCN001'),(7483,737693671011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',130.99,'eastar4','peterivs','pstothers@gmail.com','Asset Security Distribution Ltd','13E Paul Mathews Rd<br>Albany','Auckland','North Shore City','NEW ZEALAND','0632','+649.970.5332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 00:25:06',0,NULL,3,1,3,1,'RA183611765CN\r ','peterivs\rEXLO001'),(7484,819234400012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','donr54','donr54@yahoo.com','donald ranous','54 Sagamore Dr','rochester','NY','UNITED STATES','14617-2402','(585) 342-6828','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'donr54'),(7485,603343341013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','war2ta','war2ta@mindspring.com','Peter Drawdy','3 Lamar Cir','Greenville','SC','UNITED STATES','29605-1631','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 01:15:51',0,NULL,3,1,1,1,'\\ ','war2ta\racer 5pin1.25 6cm'),(7486,819248668012,220785819830,'NIB 3D Active Shutter TV Glasses 4 Mitsubishi Japan TV',2,'GLOT001',107.98,'eastar4','3dtvcorp','seeall3d@yahoo.com','yan jin','290 Moreton Bay Lane Unit 1','Goleta','CA','UNITED STATES','93117-6221','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 02:05:12',0,NULL,3,1,1,1,'\\ ','3dtvcorp\r兼容型3D眼镜 通用型'),(7487,819253338012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','cubanaketty','d.andan@hotmail.com','Ketty Vazquez','1820 SW 85th ave','Miami','FL','UNITED STATES','33155-1015','(786) 367-5575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 02:17:32',0,NULL,3,1,1,1,'\\ ','cubanaketty'),(7488,819260941012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','nworldt','nworld.t@gmail.com','Miyuki Kiyohara','3-510-2<br>Otemachi','Natori-shi','Miyagi','JAPAN','981-1232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 02:42:48',0,NULL,3,1,2,1,'\\ ','nworldt'),(7489,549492606003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',2,'HSMO017',25.98,'cnfaner','haim2210','haimoked@bezeqint.net','Haim Oked','Hanakar 1','Beer Yaaqov','Israel','ISRAEL','70300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 03:45:53',0,NULL,3,1,3,1,'RA183611782CN ','haim2210\rHSMO017'),(7491,738079718011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',13.99,'eastar4','dsnehul','dusan@pohladnica.sk','Dusan Lenko','Starkova','Zilina','SD','SLOVAK REPUBLIC','01001','00421907576456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 07:04:39',0,NULL,3,1,2,1,'、 ','dsnehul'),(7492,819320780012,220807319942,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4','chriissy_biiscuiit','christinesamuels@live.co.uk','Christine Samuels','208 Malyons Road<br>Ladywell','Ladywell','London','UNITED KINGDOM','SE13 7XF','0206905967','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-19 07:32:01',0,NULL,3,1,2,1,'、 ','chriissy_biiscuiit\r钢琴美女伞 \r粉色的PINK'),(7493,603542583013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','nontouchs','non.touch@hotmail.com','Nontouch Srisuksa','70/29  Room 619 Soi Petchburi 7<br>Petchburi Road','Phyathai','Bangkok','THAILAND','10400','66891361048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 07:58:44',0,NULL,3,1,3,1,'RA183611734CN ','nontouchs\rBAZA001'),(7494,738091806011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.99,'eastar4','caton80','clementhhlow@yahoo.com.au','Clement Low','Block 286 Tampines Street 22<br>#07-181','default','','SINGAPORE','520286','(659)125-0502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 08:01:20',0,NULL,3,1,11,1,'、 ','caton80\rHSUE003\r带麦的'),(7495,555112164004,140535373671,'New Atheros AR9287 Wireless Half PCI-E Card+antenna',7,'WLAT007+ANTY001',118.3,'cnfaner','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 09:44:50',0,NULL,3,1,3,1,'RA183611694CN\r ','saiajin77\rWLAT007+ANTY001'),(7496,603568384013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',15.5,'eastar4','askonage','kazakov@inbox.lv','Artjoms Kazakovs','Aleksandra Chaka 24-3','Riga','','LATVIA','LV-1011','0037129935349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 10:34:44',0,NULL,3,1,2,1,'\\ ','askonage\r欧标'),(7497,819368115012,220814220259,'NIB Sony TDG-BR50/L Youth Size 3D Active Glasses  Blue',1,'OTSO006',69.99,'eastar4','dkb_online','dkbruback@hotmail.com','David Bruback','43 Leichhardt Circuit<br>Forest Lake','Brisbane','Queensland','AUSTRALIA','4078','0732789313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 10:43:42',0,NULL,3,1,3,1,'RA183612023CN ','dkb_online\rOTSO006'),(7498,549547381003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',2,'HSSE004',43.8,'cnfaner','hithisismeabdullah','hithisisme@hotmail.com','abdullah alghannam','P.O. 5248','Dhahran','Dhahran','SAUDI ARABIA','31311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 10:44:19',0,NULL,3,1,3,1,'RA183611703CN\r ','hithisismeabdullah\rHSSE004'),(7499,738129812011,320590826661,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',129,'eastar4','michael_yeahman','michaelrohanek@me.com','Michael Rohanek','38 Foster St','Leichhardt','New South Wales','AUSTRALIA','2040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 10:48:47',0,NULL,3,1,3,1,'RA183616263CN\r ','michael_yeahman\rRCMA001\r澳标'),(7500,819380761012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',13.99,'eastar4uk','acme-bargains','ebay@dave-winwood.co.uk','Louise Gladstone','16 Hazel Drive<br>Hesleden','Hartlepool','Cleveland','UNITED KINGDOM','TS27 4PW','01429835877','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-19 11:28:37',0,NULL,3,1,3,1,'RA183611615CN\r ','acme-bargains\rHSMO019\r英标'),(7501,738146247011,320408987494,'Sata2 2nd HDD Hard Caddy Adapter For IBM UltraBay Slim',1,'CACN001',19.9,'eastar4','knuddeleckenstammtisch','mathias.brockmann@arcor.de','Mathias Brockmann','Arnswaldtstr. 39','Hannover','','GERMANY','30159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 11:49:54',0,NULL,3,1,2,1,'\\ ','knuddeleckenstammtisch'),(7502,819394666012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',28,'eastar4','astro2064','nkhall@btinternet.com','Nigel Hall','Rose Cottage<br>4 swardeston Lane, Lower East Carleton','Norwich','Norfolk','UNITED KINGDOM','NR14 8LF','01508571103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 12:11:01',0,NULL,3,1,2,1,'、 ','astro2064'),(7503,555140664004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','asuquo01','simon_victor06@yahoo.com','asuquo simon','263 long dr','mcdonough','GA','UNITED STATES','30253-6698','(404) 409-6887','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-19 12:29:18',0,NULL,3,1,1,1,'\\ ','asuquo01'),(7504,738163184011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','cyprusgo333','ebay@cyprusgo.ru','Vyacheslav Golovanov','Klementos 33, office 402','Nicosia','Nicosia','CYPRUS','1061','+(357)97773666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 12:48:24',0,NULL,3,1,2,1,'\\ ','cyprusgo333'),(7505,819419364012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',13.99,'eastar4uk','kalvinhuey','scoleman21708@yahoo.com','kevin hewitt','1112 Corinth Ave','savannah','GA','UNITED STATES','31406-4988','(912) 658-5511','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 13:27:06',0,NULL,3,1,1,1,'\\ ','kalvinhuey'),(7506,819427908012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','rksantia15','rksantia15@sbcglobal.net','Roxane Santiago','876 Scarlet Ave','Henderson','NV','UNITED STATES','89002-8432','(702) 568-6044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 13:57:17',0,NULL,3,1,1,1,'\\ ','rksantia15\r兼容型3D眼镜 通用型'),(7507,738185796011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','cisco_bridger','ebay@systemsteam.com','Viviane Schols','Leverenweg 47','Neeroeteren','','BELGIUM','3680','+3289860604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 14:18:01',0,NULL,3,1,2,1,'\\ ','cisco_bridger'),(7508,819442444012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','onomastidroid','orlando.bustos@bancopenta.cl','Orlando Bustos','El Bosque Norte 0440<br>Piso 1','Santiago','Region Metropolitana','CHILE','755 0092','(562)8733462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 14:34:03',0,NULL,3,1,3,1,'RA183611629CN\r ','onomastidroid\rOTRA001'),(7509,603615369013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',9.99,'eastar4','atti_the_hun','kazmer@inabo.com','Mr. Kazmer Beretzky - PizzazZ Pizza Restaurant','447 Sukhumvit Soi 22','Bangkok','','THAILAND','10110','(668) 867-2166 ext.: 6','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 14:35:29',0,NULL,3,1,2,1,'、 ','atti_the_hun'),(7510,738211729011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','jefim2007','kea@hot.ee','Jefim Ionov','Pallase pst 129-9','Tartu','Tartumaa','ESTONIA','51011','5526666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 15:21:37',0,NULL,3,1,3,1,'RA183612037CN ','jefim2007\rGLOT004\r兼容型3D眼镜  samsung 专用'),(7511,737839482011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','vikastyleusa','vicarman@prodigy.net.mx','Armando Oliva Arizabalo','Norte 17 A 5196<br>Nueva Vallejo','Gustavo A. Madero','Distrito Federal','MEXICO','07750','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 15:12:26',0,NULL,3,1,2,1,'\\ ','vikastyleusa\rHP 8pin 1.25 25cm '),(7512,549611426003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.69,'cnfaner','rmimail','rmimail2002@yahoo.com','Rosca Marius Ioan','Al. Macilor Nr. 6, Sc. 2, Et. 3, Ap. 8','Resita','Romania','ROMANIA','320199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 15:57:50',0,NULL,3,1,3,1,'RA183611632CN\r ','rmimail\rBALO007'),(7513,736192584011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.4,'eastar4','bajenov','bajenov@gmail.com','Roman Bajenov','Osipova<br>20 - 20','Saratov','Saratovskaja oblast','RUSSIAN FEDERATION','410010','+7.9033299998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 16:21:20',0,NULL,3,1,2,1,'\\ ','bajenov\rHP 8pin 1.0 23cm '),(7514,819488646012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','ruffuzz','guilhoff@hotmail.com','Guilherme Hoffmann','Rua Diogo Dias Velho, 33','Joinville','Santa Catarina/Joinville','BRAZIL','89217-330','554796318188\r\n','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 16:29:44',0,NULL,3,1,3,1,'RA183614568CN ','ruffuzz\rGLOT001*2\r兼容型3D眼镜 通用型'),(7515,738240215011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.99,'eastar4','**xandro**111','odw-d-m-x-odw@hotmail.com','alexander schmitt','liebersbacherstr.66','birkenau','','GERMANY','69488','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'**xandro**111'),(7516,738242134011,320730084621,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'OTLK001',5.98,'eastar4uk','niklas_dk','ng@imperator.dk','Niklas Greve','Nordre Fasanvej 80, 3. tv','Frederiksberg','','DENMARK','DK-2000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 16:43:46',0,NULL,3,0,2,1,'\\ ','niklas_dk'),(7517,738247343011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',2,'HSJA005',35.94,'eastar4','rafimuli','rafimuli@gmail.com','yossi goldsthein','gordon 4','reshon la zion','','ISRAEL','75223','0506588753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 16:59:40',0,NULL,3,1,3,1,'RA183612615CN ','rafimuli\rHSJA005'),(7518,603660974013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','behc777','rey@spmi.ru','Evgeny Chorpita','55-18 Vosstaniya str<br>+7 911 712 9060','Saint-Peterburg','RU','RUSSIAN FEDERATION','191123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 17:18:08',0,NULL,3,1,3,1,'RA183611677CN\r ','behc777\rWLIN014'),(7519,819512750012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','mikedesor123','mikedesor@hotmail.com','Michael Desormeaux','12368 Deeks Rd','Morrisburg','ON','CANADA','k0c 1x0','(613) 571-5557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 17:22:15',0,NULL,3,0,2,1,'\\ ','mikedesor123\r发210TS'),(7520,737756356011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','alexgl18','alexguerrerolozano@gmail.com','Alejandro Guerrero Lozano','Calle Jaen Nº8','Rivas-Vaciamadrid','Madrid','SPAIN','28522','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 17:38:48',0,NULL,3,1,2,1,'\\ ','alexgl18'),(7521,819521573012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','klaxon5961','dave.fluri@onlink.net','Dave Fluri','778 Drive In Road','Sturgeon Falls','ON','CANADA','P2B 2R6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 17:40:20',0,NULL,3,1,3,1,'RA183611663CN\r ','klaxon5961\rOTRA001'),(7522,738271046011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','musclnsd','musclnsd@yahoo.com','chris homeier','1001 Chatham Rd','Springfield','IL','UNITED STATES','62704-2214','(217) 547-1234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 17:51:56',0,NULL,3,1,1,1,'、 ','musclnsd'),(7523,603653601013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','copernick1233','copernick@i.ua','Andrew Bondar','Frunze street, 27','Krasnoarmeysk','Donetskaya oblast','UKRAINE','85307','(066)538-2868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 18:05:55',0,NULL,3,1,2,1,'\\ ','copernick1233'),(7524,819546046012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','artpapyan','art-pn@rambler.ru','Artashes Papyan','M.Heratsu str.,2a,ap.39','YEREVAN','Yerevan','ARMENIA','025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 18:30:19',0,NULL,3,1,2,1,'\\ ','artpapyan'),(7525,738307730011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','sa-ji-2000','sdvinin@hotmail.com','Sergey Dvinin','5282 Newport Bay Psge','Alpharetta','GA','UNITED STATES','30005-7522','(678) 661-1165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 19:06:39',0,NULL,3,1,1,1,'\\ ','sa-ji-2000'),(7526,819571559012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.4,'eastar4uk','jacjovil','jacjovil@hotmail.com','Dr. Jacques Viljoen','Resident Medical Officer, BMI Woodlands Hospital<br>Morton Park','Darlington','Durham','UNITED KINGDOM','DL1 4PL','01325341700','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-19 19:10:15',0,NULL,3,1,3,1,'RA183611751CN\r ','jacjovil\rSCLO002'),(7527,819581224012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','37point2','raymond87.lilly@gmail.com','Raymond Lilly','100 S RAAB RD','SWANTON','OH','UNITED STATES','43558-9332','(419) 826-9167','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 19:28:40',0,NULL,3,0,1,1,'\\ ','37point2\r发210TS'),(7528,603711786013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',95.97,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 19:42:12',0,NULL,3,1,3,1,'RA183611748CN\r ','update_marcelo\rWWSI005'),(7529,603721464013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ppvvld791','ppvvld@mail.ru','Vladimir Popov','ul. Lelushenko 1A kv 28','Rostov-on-Don','','RUSSIAN FEDERATION','344045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 20:08:15',0,NULL,3,1,2,1,'\\ ','ppvvld791'),(7530,738346150011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.4,'eastar4','g3762','sr-73@t-online.de','Stefan Roßkopf','Neuteichweg 4','Waldsassen','','GERMANY','95652','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 20:22:41',0,NULL,3,1,2,1,'\\ ','g3762\racer 5pin1.25 4cm'),(7531,738357240011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','arima77_9','jquintanilla1@rgv.rr.com','Juan Quintanilla','510 W Kelly Ave','Pharr','TX','UNITED STATES','78577-4648','(956) 783-6121','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'arima77_9'),(7532,819623901012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','deeteekay51','tonykelly2007@hotmail.com','Tony Kelly','31 Gorse Hall Road','Dukinfield','Cheshire','UNITED KINGDOM','SK165HE','07824468827','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-19 20:48:40',0,NULL,3,1,3,1,'RA183611685CN\r ','deeteekay51\rHSMO017\r英标'),(7533,738376906011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','familyborderlover','tkreeves@cox.net','Kimbell Reeves','3846 Peachtree Ct','New Orleans','LA','UNITED STATES','70131-8314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 21:34:00',0,NULL,3,1,1,1,'\\ ','familyborderlover'),(7534,738388636011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','csch1609','shoe@lofty.com','Chris Schomaker','485 7th Ave','New York','NY','UNITED STATES','10018','(816) 213-0084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 22:05:21',0,NULL,3,1,1,1,'\\ ','csch1609'),(7535,738395961011,320698314620,'Original Jabra BT800 BT 800 wireless Bluetooth Headset',1,'HSJA008',28.7,'eastar4','al-verchi','elshan.khalilov@gmail.com','ELSHAN  KHALILOV','65 Primrose Street.<br>Apt. 126','Dartmouth','NS','CANADA','B3A4E1','(902) 431-5590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 22:29:38',0,NULL,3,1,2,1,'、 ','al-verchi'),(7536,819670556012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','dumbo34','jacob.fock@gmx.de','Jacob Fock','Griesstr. 6','Hamburg','Hamburg','GERMANY','20535','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 22:44:45',0,NULL,3,0,2,1,'\\ ','dumbo34'),(7537,819692974012,220807272254,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',19.99,'eastar4','aan2006812','aan812@gmail.com','Angela Lee','Suite803, 14 Martin Place','Sydney','New South Wales','AUSTRALIA','2000','61404088264','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 00:02:07',0,NULL,3,1,2,1,'、 ','aan2006812\r美女涂鸦伞 '),(7538,555317247004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','robertl2011','robertlromero@hotmail.com','robert romero','2203 Greenbriar Cir<br>Apt 5','johnson city','TN','UNITED STATES','37601-2190','(423) 258-0033','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-20 00:05:54',0,NULL,3,1,1,1,'\\ ','robertl2011'),(7539,737245893011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','phinupihe','phinupihe934@gmail.com','Andre M. Robinson','31 Drake Rd','Somerset','NJ','UNITED STATES','08873-2323','(973) 271-6775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 01:10:38',0,NULL,3,1,1,1,'\\ ','phinupihe'),(7540,819715888012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','8551denis','denissalamicha@hotmail.com','denis gauthier','62 principal nord ','sutton','QC','CANADA','j0e2k0','(450) 538-3400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 01:35:57',0,NULL,3,1,2,1,'\\ ','8551denis'),(7541,738443815011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','nale-chile','goran.nakic@gmail.com','GORAN NAKIK','ZURICH 221, DP. 104','SANTIAGO','RM','CHILE','000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 01:42:16',0,NULL,3,1,2,1,'、 ','nale-chile'),(7542,700191281001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','s1llyvi3tb0i','nghivinhton@yahoo.com','Nghi Ton','12303 Plano Rd<br>Apt 244','Dallas','TX','UNITED STATES','75243','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 01:51:17',0,NULL,3,1,1,1,'\\ ','s1llyvi3tb0i'),(7543,603808719013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','188mike','mimkeith118@bigpond.com','Mim Brown','PO box 14','Staghorn Flat','Victoria','AUSTRALIA','3691','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 02:26:22',0,NULL,3,1,2,1,'\\ ','188mike'),(7544,738449855011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','danielf907','dannyboyyo@hotmail.com','Daniel Finley','1150 Lower Sunny Circle','Eagle River','AK','UNITED STATES','99577','(907) 696-0447','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 02:48:19',0,NULL,3,1,1,1,'\\ ','danielf907\r'),(7545,603589996013,230395559651,'2.1 Acer AS aspire D250 Bluetooth Module EDR+cable',1,'BTAC2107',12.4,'eastar4','9065159990','s.o.v.4@mail.ru','Князев Павел','Ивановская область, Комсомольский район, д. Бутово  д. 49-а  кв1','Иваново','','RUSSIAN FEDERATION','155134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 03:09:53',0,NULL,3,1,2,1,'\\ ','9065159990\rAcer 4pin 1.25 15cm'),(7546,555349628004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','sam11010','110sam@mail.ru','Mikhail Sukach','Tupoleva, dom 3, korpus 1, kv. 24','Omsk','RU','RUSSIAN FEDERATION','644112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 03:27:02',0,NULL,3,1,3,1,'RA183612054CN\r ','sam11010\r欧标  银色的\rHSNO022'),(7547,819755806012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','tomj59','tom.r.james@gmail.com','Tom James','24 Church St','Mountain View','CA','UNITED STATES','94041-2356','(650) 400-1641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 04:01:17',0,NULL,3,0,1,1,'\\ ','tomj59'),(7548,738476037011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',53.99,'eastar4','donovanangel','omar.perez@cox.net','Victor Perez','423 Alderwood St N','Oceanside','CA','UNITED STATES','92058-6608','(760) 402-5618','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 04:08:57',0,NULL,3,1,1,1,'\\ ','donovanangel\r兼容型3D眼镜 通用型'),(7549,603826975013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',89.4,'eastar4','lametal410','bukhakin13@gmail.com','Hyeon-sik Yoon','No.311, Daemyeong gositel, 27-11, Noryangjin 2-dong, Dongjak-gu','Seoul','','KOREA,REPUBLIC OF','156-052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 04:19:25',0,NULL,3,1,3,1,'RA183611650CN\r ','lametal410\rWLAP008'),(7550,603836000013,230649288384,'New Replaceable Shell 4 logitech Anywhere MX Mouse M905',1,'SHLO005',16.99,'eastar4','worlddigital2011','bluesky3056@hotmail.com','Park Kyung In','SeoMyeon Norwei-Achim 1009HO,892-21<br>Jeonpo-Dong Jin-gu','BUSAN','South KOREA','KOREA,REPUBLIC OF','614-040','+82-010-4005-3056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 05:31:13',0,NULL,3,1,2,1,'、 ','worlddigital2011'),(7551,603841751013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','2010rudenko','rudenkovitaly@mail.ru','Rudenko Vitaliy','Sportivnaya 12 kv.9','Kramatorsk','Donetskaya','UKRAINE','84303','+380957053533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 06:12:06',0,NULL,3,1,2,1,'、 ','2010rudenko'),(7552,603842322013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','sn00ze_24','danmee21@gmail.com','Danie Maree','BoE Clocktower Building<br>V&A Waterfront','Cape Town','Western Cape','SOUTH AFRICA','8001','0722269236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 06:16:32',0,NULL,3,1,2,1,'、 ','sn00ze_24'),(7553,549795470003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',25.98,'cnfaner','imperial1_7','imperial1_7@hotmail.com','Rory Wint','1735 Main St<br>Apt C5','West Warwick','RI','UNITED STATES','02893-7407','(401) 228-4782','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-20 06:34:31',0,NULL,3,1,1,1,'\\ ','imperial1_7'),(7554,603853892013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','zavarakatranemia1900','ieronymo@hotmail.com','Θανασης  Ιερωνυμακης','Αγιας Μαρινας 5 Οικ. Αμμούδι Λυγαριάς<br>Αριθμος Αγροτικης Θυριδας 3','Hrakleio-Creta (Ηράκλειο-Κρήτη)','','GREECE','71500','6972852624','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 07:41:30',0,NULL,3,1,2,1,'、 ','zavarakatranemia1900'),(7555,738520256011,320441946476,'2.1 HP DV9500  Bluetooth Module  EDR+cable',1,'BTHP2111',12.4,'eastar4','ibazarmatlo','mat.lau@laposte.net','Laurendeau Mathieu','125 Bd de Lattre de Tassigny','Rennes','Bretagne','FRANCE','35000','0663976896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 08:14:30',0,NULL,3,1,2,1,'、 ','ibazarmatlo\rHP 8pin 1.25 25cm '),(7556,738531175011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','0797katieone','tjw@cotswoldwireless.co.uk','Kate Whittaker','lords meade<br>longney','glos','Gloucestershire','UNITED KINGDOM','gl2 3sw','07970992958','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 09:01:07',0,NULL,3,1,3,1,'RA183612108CN\r ','0797katieone\rHSJA011\r英标'),(7557,819835541012,220713846430,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.9,'eastar4uk','hamxa_sin','syedhamzatauheed@gmail.com','hamza bin tauheed','175 ley street','ilford','Essex','UNITED KINGDOM','ig1 4bl','07879157806','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 10:03:44',0,NULL,3,1,3,1,'RA183612111CN\r ','hamxa_sin\rHSNO023\r英标'),(7558,738550613011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','ams13myye','ams_myye@yahoo.com','Adli Mohd Saad','C-201 Blok C, Kondo De\' Rozelle,<br>Jalan Merbah 10/1, Seksyen 10, Kota Damansara','Petaling Jaya','Selangor','MALAYSIA','47810','013-3997568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 10:22:41',0,NULL,3,1,2,1,'\\ ','ams13myye'),(7559,819843729012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',164.99,'eastar4uk','urasek','uras@buziaczek.pl','marcin grubiak','11 cnocan rua','moycullen','Galway','IRELAND','default','091850736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 10:36:22',0,NULL,3,1,3,1,'RA183612235CN\r ','urasek\rOTSO004*4'),(7560,0,110715649250,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',51.99,'buysia','sudip_calcutta','sudip_calcutta@yahoo.co.in','Sudip Mukherjee','C/o.Genius Consultants Ltd., 31, Dr.Ambedkar Sarani<br>2nd Floor, Topsia More','Kolkata','West Bengal','INDIA','700046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 11:41:28',0,NULL,3,1,3,1,'RA183612125CN\r ','sudip_calcutta'),(7561,819867802012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','iceberg457','ian_jones30@hotmail.com','Ian Jones','58 Runswick Rd<br>Brislington','Bristol','Bristol','UNITED KINGDOM','BS4 3HY','01179774015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 11:57:06',0,NULL,3,0,2,1,'\\ ','iceberg457'),(7562,603903337013,230432994061,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',33.99,'eastar4','mrs-torana','mrs-torana@hotmail.com','naomi dewhurst','121 wyee rd, wyee<br>wyee','wyee','New South Wales','AUSTRALIA','2259','0438572404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 12:22:11',0,NULL,3,1,3,1,'RA183612139CN\r ','mrs-torana\rWWSI004+ANCN001'),(7563,0,110715659388,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',28.1,'buysia','amberger1','leslieamberger@hotmail.com','leslie amberger','40 oakland st','wilbraham','MA','UNITED STATES','01095-2751','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 12:25:54',0,NULL,3,1,1,1,'\\ ','amberger1'),(7564,819882932012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','damusicjunkie','dominicbest@googlemail.com','Dominic Best','7 Fallsbrook Road','Streatham','London','UNITED KINGDOM','SW16 6DU','02087691513','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 12:43:05',0,NULL,3,1,3,1,'RA183612142CN\r ','damusicjunkie\rOTHP004'),(7565,819887371012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','blastarrrr','djdk@mail.ru','Oleg Larin','Komarova 2/1, 82','Mytischi','','RUSSIAN FEDERATION','141002','+7(916)4444744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 12:56:57',0,NULL,3,1,3,1,'RA183612068CN\r ','blastarrrr\rOTRA001'),(7566,603918768013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',4,'WLIN002',155.96,'eastar4','destrhythmer','kawasaki@stocmarketing.jp','Yusuke Kawasaki','Ishihara 1-4-10-603','Sumida-ku','Tokyo','JAPAN','130-0011','090-8089-0090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 13:30:03',0,NULL,3,1,3,1,'RA183612156CN\r ','destrhythmer\rWLIN002\r送两个螺丝'),(7567,738620526011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','neoss156','fabrizio156@gmail.com','fabrizio rizzo','rue de bois du luc 90','houdeng aimeries','','BELGIUM','7110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 14:12:28',0,NULL,3,1,2,1,'\\ ','neoss156\r不带壳的'),(7568,819584003012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',58.99,'eastar4','marcel_alves','marcelr90@gmail.com','marcel alves dias paes','estr. M. Miguel Salazar M. de Morais<br>n:291 venus 805','rio de janeiro','rio de janeiro','BRAZIL','22770-330','0021552133420994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 14:37:31',0,NULL,3,1,3,1,'RA183612227CN\r ','marcel_alves\rREPL001\r\r再发一个 PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906 \r\r '),(7569,738643417011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','jclenden','jake@acrophile.net','Jacob Clendenon','13371 W Fountain Dr<br>Apt 7','New Berlin','WI','UNITED STATES','53151-8903','(904) 238-4386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 15:20:47',0,NULL,3,1,1,1,'\\ ','jclenden'),(7570,819955022012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','4damoe','t.moelmann@yahoo.de','Thomas Mölmann','Alban-Stolz-Str. 18','Freiburg','','GERMANY','79108','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 15:57:52',0,NULL,3,1,3,1,'RA183612071CN\r ','4damoe\rWWOT002\rIBM版 二手'),(7571,603969026013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','sgoetz8pqp','sgoetz@hotmail.com','Slawek Goetz','26415 Tweed','Lake Forest','CA','UNITED STATES','92630-7229','(714) 924-0288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 16:39:59',0,NULL,3,1,1,1,'\\ ','sgoetz8pqp'),(7572,603550405013,230649292141,'New Westwood Red w/lace Boetie Sun Rain Stick unbrella',2,'UM00027',29.9,'eastar4','redjulia3873','simplystamps@googlemail.com','julia guainiere','shop 3, strand court<br>strand quay','rye','East Sussex','UNITED KINGDOM','tn317ay','01797229060','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-20 17:01:19',0,NULL,3,1,2,1,'、 ','redjulia3873\r蕾丝蝴蝶结长柄伞   '),(7573,818649913012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','adanblinblindj','adanblinblin@yahoo.com','AdanDJ BlinBlin','RR 1 Box 3125','Anasco','PR','UNITED STATES','00610','(787) 362-0422','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 17:12:11',0,NULL,3,1,1,1,'\\ ','adanblinblindj'),(7574,738691641011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','jeanraymobd280156','jean-raymond.lagneaux@wanadoo.fr','JEAN RAYMOND LAGNEAUX','10 LES AUDRIES','CREUZIER LE NEUF','ALLIER','FRANCE','03300','04 70 59 63 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 17:16:55',0,NULL,3,1,3,1,'RA183612173CN\r ','jeanraymobd280156\rGLOT004\r兼容型3D眼镜  samsung 专用'),(7575,819996757012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.96,'eastar4','pbrad1400_1','pbrad1400_1@juno.com','Paul Bradley','PO Box 1511','Burleson','TX','UNITED STATES','76097','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 17:26:20',0,NULL,3,1,1,1,'\\ ','pbrad1400_1'),(7576,820008353012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','muhun12345','muhun1@hotmail.com','Moe Ananthasothy','38 Elm St, Unit 608','Toronto','ON','CANADA','M5G 2K5','(416) 720-4045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 17:49:16',0,NULL,3,1,2,1,'\\ ','muhun12345'),(7577,738717013011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','genor004','genor@zahav.net.il','Evgeni Nepomniachtchi','Shik str. 4/15','Tel-Aviv','Israel','ISRAEL','68191','972-3-6824790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 18:10:37',0,NULL,3,1,2,1,'\\ ','genor004'),(7578,820032845012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','duncan180','duncan.garrett@virgin.net','Duncan Garrett','17 Broomhill Road','Orpington','Kent','UNITED KINGDOM','BR6 0EN','07880541438','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 18:33:18',0,NULL,3,1,3,1,'RA183612085CN\r ','duncan180\rRELO002'),(7579,820047842012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.79,'eastar4','zedgama3','zedgama3@gmail.com','Jared Fowkes','PO Box 11665','Jacksonville','FL','UNITED STATES','32239-1665','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 19:01:52',0,NULL,3,1,1,1,'\\ ','zedgama3'),(7580,602918704013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',155,'eastar4','mi062006','pcmike1@yahoo.com','Michael Miller','923 Clark St','Muskegon','MI','UNITED STATES','49442-3811','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 19:13:27',0,NULL,3,1,1,1,'\\ ','mi062006\r兼容型3D眼镜 通用型'),(7581,820062980012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','sedbh','sedutor.dotado@gmail.com','Alisson Souza','rua joão ramalho,192<br>Glória','Belo Horizonte','minas gerais','BRAZIL','30880310','31-87747179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 19:28:00',0,NULL,3,1,3,1,'RA183612099CN\r ','sedbh\rOTRA001'),(7582,738772051011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','kesslersantoss','kesslersantos@gmail.com','Kessler Nemuel Souza Santos','Avenida Primavera de Caiena,664','São Paulo','São Paulo','BRAZIL','03981010','551199588710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 19:57:08',0,NULL,3,1,3,1,'RA183612200CN\r ','kesslersantoss\rGLSG001\r一共买了两个'),(7583,735997454011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','tbone20106969','jt805@live.com','JASON HUNTER','PO BOX 766','GROVER BEACH','CA','UNITED STATES','93483-0766','(805) 904-3855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 19:58:31',0,NULL,3,1,1,1,'\\ ','tbone20106969'),(7584,820081445012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','famogo01','fmg@interponta.com.br','Fabiano Gomes','Av. Anita Garibaldi, 1979 Casa 10','Ponta Grossa','PR','BRAZIL','84015-050','4299159910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:00:58',0,NULL,3,1,3,1,'RA183612160CN\r ','famogo01\rGLSG001*4'),(7585,738779135011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','nuklin73','nuklin@mail.ru','Pavel Utkin','st.Korneychuka 59-110','Moscow','RU','RUSSIAN FEDERATION','127543','+79255173047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:10:54',0,NULL,3,1,2,1,'\\ ','nuklin73'),(7586,738784281011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','kesslersantoss','kesslersantos@gmail.com','Keilla Vivian Souza Santos','Avenida Primavera de Caiena,664','São Paulo','São Paulo','BRAZIL','03981-010','551127026507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:22:25',0,NULL,3,1,3,1,'RA183612301CN\r ','kesslersantoss\rGLSG001'),(7587,738785525011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','kesslersantoss','kesslersantos@gmail.com','Kessler Nemuel Souza Santos','Avenida Primavera de Caiena,664','São Paulo','São Paulo','BRAZIL','03981010','551199588710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:23:54',0,NULL,3,1,17,0,NULL,'kesslersantoss'),(7588,820105564012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','vmonheros','frederic.fenoglietto@gmail.com','FENOGLIETTO','Frédéric<br>17 rue Pierre d\'Aragon','TOULOUSE','Midi-Pyrénées','FRANCE','31200','+33 617734405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 20:46:29',0,NULL,3,1,2,1,'\\ ','vmonheros'),(7589,604056080013,230620799040,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',1,'HSSA004',13.99,'eastar4','stepanzo1','stepanzo@yahoo.com.br','Stepan Oglouyan','Marechal Hermes da Fonseca , 314 ap 93 b','São Paulo','São Paulo','BRAZIL','02020-900','011 9974 3696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:51:49',0,NULL,3,1,2,1,'\\ ','stepanzo1'),(7590,820110974012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','andiroconst10','andiroconst@gmail.com','Andrei Vicentiu Hincu','Alexandru Lapusneanu, nr. 105, bl. LV 42, sc. B, ap. 23, et. 1','Constanta','Constanta','ROMANIA','900396','0762159372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:56:09',0,NULL,3,1,2,1,'\\ ','andiroconst10'),(7591,819377081012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',25.34,'eastar4','vladww','vladw@earthlink.net','Walter Weinstein','5000 palomar dr','tarzana','CA','UNITED STATES','91356-4434','(818) 343-0460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 21:14:04',0,NULL,3,0,1,1,'\\ ','vladww\r再发10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable黑色的\r'),(7592,819386172012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','azalina','ru_2_ru@yahoo.com','Tatiana Toldova','Asafieva ulitsa<br>dom 10 kv. 124','Sankt-Peterburg','','RUSSIAN FEDERATION','194356','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 21:48:30',0,NULL,3,1,2,1,'\\ ','azalina\r多色伞 '),(7593,604084788013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',13,'CASS003',113.1,'eastar4','s0601444','c_e@gmx.de','Carsten Ellermann','Am großen Weserbogen 66','Bad Oeynhausen','','GERMANY','32549','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 22:43:58',0,NULL,3,1,3,1,'RA183612213CN\r ','s0601444\rCASS003\rCAB-6060  发两个小包\rRA183612195CN\r'),(7594,700547290001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','bnkjar6','bnkjar6@aol.com','Kimberly Jarrett','5735 Arnhem Rd','Baltimore','MD','UNITED STATES','21206','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 22:48:39',0,NULL,3,1,1,1,'\\ ','bnkjar6'),(7595,602346763013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',91.96,'eastar4','418ethananthony','sintenial@hotmail.com','anthony hernandez','6309 taylor canyon pl','rancho cucamonga','CA','UNITED STATES','91739-5901','(909) 202-3255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 22:57:21',0,NULL,3,1,1,1,'\\ ','418ethananthony'),(7596,604102726013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',95.97,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 00:17:21',0,NULL,3,1,3,1,'RA183612258CN\r ','update_marcelo\rWWSI005'),(7597,738863197011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT004',107.98,'eastar4','alec2421','alec47@tpg.com.au','AlecRowe','4 Lavender drive','Parafield Gardens','South Australia','AUSTRALIA','5107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 00:21:50',0,NULL,3,1,3,1,'RA183612292CN\r ','alec2421\rGLOT004\r兼容型3D眼镜  samsung 专用'),(7598,738874386011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.94,'eastar4','chucky_ath','chucky_ath@yahoo.com.br','Felipe Matos Moreira','Rua Marie Nader Calfat, 351 Apto 62E<br>Jardim Ampliação','São Paulo','São Paulo','BRAZIL','05713-520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 01:09:21',0,NULL,3,1,2,1,'\\ ','chucky_ath'),(7599,820213441012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','getstuff69','mhebert68@verizon.net','MIKE HEBERT','28 Elmwood Ave','CHERRY VALLEY','MA','UNITED STATES','01611-3317','(508) 797-1701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 02:27:53',0,NULL,3,0,1,1,'\\ ','getstuff69'),(7600,738895104011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','dpms30809','t_p_leonard@comcast.net','Terrence P. Leonard','3067 Kregel Dr','Rockford','IL','UNITED STATES','61109','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 02:42:16',0,NULL,3,1,1,1,'、 ','dpms30809'),(7601,820231795012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','steveg5014','galeace90@hotmail.com','Steve & Cynthia Gale','1630 E Shaw Ave<br>Ste 176','Fresno','CA','UNITED STATES','93710-8112','(559) 446-0663','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 03:46:36',0,NULL,3,1,1,1,'\\ ','steveg5014'),(7602,820251776012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',19.99,'eastar4uk','bariasd','ariasdonoso@gmail.com','bernardo arias','199 East Flagler Street  #191','miami','FL','UNITED STATES','33131','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 05:29:03',0,NULL,3,1,1,1,'、 ','bariasd'),(7603,738931403011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',52.3,'eastar4','cushty202','boussh@arach.net.au','Corey Allen','3/140 Onslow Road<br>Shenton Park','Perth','Western Australia','AUSTRALIA','6008','0893888223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 05:51:49',0,NULL,3,1,3,1,'RA183612350CN ','cushty202\r旧的\rWLAP001+UDAP002+UDAP001\r再发一个\rNew Apple Macbook Reinstall Driver 8GB USB pen key\r一个New Apple 8GB USB PEN KEY FLASH DRIVE U disk\r'),(7604,738935756011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','cushty202','boussh@arach.net.au','Corey Allen','3/140 Onslow Road<br>Shenton Park','Perth','Western Australia','AUSTRALIA','6008','0893888223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 06:22:17',0,NULL,3,1,17,0,NULL,'cushty202\rUDAP001'),(7605,820263243012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','bodguard444','kim.nickolay@gmail.com','Nickolay Kim','23 Natashi Kovshovoy Street<br>Apartment 122','Moscow','Russia','RUSSIAN FEDERATION','119361','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 06:29:11',0,NULL,3,1,3,1,'RA183612261CN ','bodguard444\rOTRA001'),(7606,738940847011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',68.98,'eastar4','cisoftware','bart@cisoftware.eu','Bart Podkowka','Carrer Germans Pastor 1<br>Piso 2','Santa Maria del Cami','Baleares','SPAIN','07320','871962334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 06:42:57',0,NULL,3,1,3,1,'RA183612275CN ','cisoftware\rUDAP001'),(7607,8881311230641579,111,'Item Title:New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'',24.99,'eastar4','luvdance2','nikki.aspiras@hotmail.com','Nicole Aspiras','8130 Crystal Walk Cir','Elk Grove','CA ','UNITED STATES','95758','',NULL,NULL,NULL,NULL,0,NULL,3,0,1,1,'\\ ','UM00007\rLK032691231CN\r地图伞 \r补发'),(7608,8881311230667542,111,'Item Title:New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'',24.99,'eastar4','luvdance2','nikki.aspiras@hotmail.com','Nicole Aspiras','8130 Crystal Walk Cir','Elk Grove','CA ','UNITED STATES','95758','',NULL,NULL,NULL,NULL,0,NULL,5,0,18,0,' ','这个是我弄重复了 '),(7609,604165265013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','tinimidget11','tini_midget@hotmail.com','tony tran','162 biggs street','melbourne','Victoria','AUSTRALIA','3021','0393560487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 07:04:12',0,NULL,3,1,2,1,'、 ','tinimidget11\r红边优联'),(7610,738944247011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',4,'CASS002',34.8,'eastar4','morneb2008','morneb@live.com','Tean Jacobs','3A Summit Road<br>Dunkeld West','JHB','Gauteng','SOUTH AFRICA','2196','0027794287424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 07:18:11',0,NULL,3,1,3,1,'RA183612289CN ','morneb2008\rCASS002+CASS003\r再发四条CAB-6060  货已经退回'),(7611,738948092011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','pasare007','pasareebay@yahoo.com','Pasarica Titus Constantin','Ipsilanti, nr. 14','Iasi','','ROMANIA','700029','0040724289255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 07:29:17',0,NULL,3,1,2,1,'、 ','pasare007'),(7612,604169626013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','morneb2008','morneb@live.com','Tean Jacobs','3A Summit Road<br>Dunkeld West','JHB','Gauteng','SOUTH AFRICA','2196','0027794287424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 07:29:53',0,NULL,3,1,17,0,NULL,'morneb2008'),(7613,738950018011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','pendekarhitam','caesara.anindya@gmail.com','IBU LUKMAN','PERUMAHAN DUREN JAYA PERMAI JALAN BOROBUDUR RAYA BLOK E2 NO.20','bekasi','jawa barat','INDONESIA','17111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 07:37:48',0,NULL,3,1,2,1,'、 ','pendekarhitam'),(7614,8881311235684826,111,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',19.99,'eastar4','boojalavelle','jaynelavelle@hotmail.com','Jayne Lavelle','Bee Cottage, , Elwick','Hartlepool','Cleveland','UNITED KINGDOM','TS27 3ED ','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183612690CN\r ','补发\r向日葵三折叠伞  '),(7615,820306008012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',2,'RELO002',17,'eastar4uk','gary_jameson','gary@hamptonraid.com','Gary Jameson','Sardinella Court 3<br>Triq il-Kannizzata','Balzan','','MALTA','BZN 1702','35677257495','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 09:37:13',0,NULL,3,1,2,1,'\\ ','gary_jameson'),(7616,820305891012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','hakanetmarket07','hakanetmarket@gmail.com','M.Hakan BÄLDIROGLU','Hukumet Caddesi Orman Isletme Karsısı<br>Hakan Et Market No 110','ELMALI','ELMALI / ANTALYA','TURKEY','07700','+90242 618-5080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 09:39:27',0,NULL,3,1,2,1,'、 ','hakanetmarket07'),(7617,820312542012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','qeesha','nila_pratiwi01@yahoo.com','Nila Pratiwi','Jl. H. Muhtar No. 9 Rt 07 Rw 02<br>PU Pengairan, Bintaro Jaya Sektor 2','Jakarta','Selatan','INDONESIA','15412','+6283898272727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 10:02:53',0,NULL,3,1,2,1,'、 ','qeesha\r美女涂鸦伞 '),(7618,8881311242867361,111,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',25.85,'eastar4','carlosmoranoherrero','moranocarlos@gmail.com','Carlos Morano Herrero','Punta Umbria, 29','Arroyomolinos','Madrid ','SPAIN','28939 ','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183612329CN\r ','OTCR001\r补发的 '),(7619,738984867011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',38.99,'eastar4uk','volvoman-1','robinsonkelly3@aol.com','KELVIN JAMES ROBINSON','6 MALVERN ROAD<br>BLACON','CHESTER','Cheshire','UNITED KINGDOM','CH1 5BG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-21 10:08:10',0,NULL,3,1,3,1,'RA183612641CN\r ','volvoman-1\rGLSG001'),(7620,604198286013,230641642037,'New lady Painting Rain Sun Parasol Stick Umbrella',1,'UM00014',15.95,'eastar4','teghan666','noonoo7@tiscali.co.uk','nicola davies','21 tristan road','truro','Cornwall','UNITED KINGDOM','tr1 1au','01872263904','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-21 10:32:51',0,NULL,3,1,2,1,'、 ','teghan666\r美女涂鸦伞 '),(7621,555696742004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','mevingooraya','kgooraya@yahoo.com','Gooraya Kaissy Reddy','Royal Road','Bel Air','','MAURITIUS','0000','230 4192402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 10:48:20',0,NULL,3,1,3,1,'RA183612363CN\r ','mevingooraya\rHSNO022'),(7622,682884195008,180699060860,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',26.8,'au-buy','marshal8820','nickrae2000@yahoo.ca','Nicholas Rae','18 mcrae drive','toronto','ON','CANADA','m4g 1r9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-21 10:56:53',0,NULL,3,1,3,1,'RA183612394CN\r','marshal8820\rHSNO019'),(7623,738999734011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',15.9,'eastar4uk','django.russ','miguel.dasilva@wanadoo.fr','MIGUEL DA SILVA','25 BIS RUE DU MOULIN DES CHAUMES','SAINT AGNANT','Poitou-Charentes','FRANCE','17620','0516849275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 11:06:57',0,NULL,3,1,2,1,'\\ ','django.russ\r旧的'),(7624,820343516012,220501826426,'2.1 New Acer Aspire 3810 3810T  Bluetooth Module+cable',1,'BTAC2118',12.4,'eastar4','lcv_electronic','luis_cubero@hotmail.es','Luis Cubero Valladolid','Mare de Deu dels Angels-74-SobA 2ª','Barcelona','Cataluña','SPAIN','08035','661722974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 11:52:46',0,NULL,3,1,2,1,'\\ ','lcv_electronic\racer 8pin1.0 3cm'),(7625,604214785013,230501433842,'2.1 Acer Aspire One 751 AO751h Bluetooth Module EDR',1,'BTAC2115',12.4,'eastar4','fabio_bra','fabio_bnu@pop.com.br','Fabio Cristofolini','RUA XV DE NOVEMBRO - ED. HERING, 12º ANDAR','Blumenau','Santa Catarina','BRAZIL','89010-001','55473326-5481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 12:00:23',0,NULL,3,1,2,1,'\\ ','fabio_bra\racer 5pin1.25 20cm'),(7626,550139317003,130466041446,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',29.9,'cnfaner','ahurme','zimeon.null@gmail.com','Antti Hurme','Palokärjentie 19','Kyrö','','FINLAND','21800','+358403532720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 12:25:38',0,NULL,3,1,3,1,'RA183612385CN\r ','ahurme\rWWSI004'),(7627,604220993013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','jaew_2008','jaw15@hotmail.com','Suchada Sangkhasudprasert','Daiichi Sankyo (Thailand) Ltd.<br>138 Boonmitr Bldg.10th F. Silom road, Bangrak','BKK','','THAILAND','10500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 12:38:53',0,NULL,3,1,3,1,'RA183612434CN\r ','jaew_2008\rBAZA001'),(7628,820364092012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',19.99,'eastar4uk','danto007','danielcimatti@hotmail.com','Daniel CIMATTI','Rue du Ruisseau, 20','Flémalle','','BELGIUM','4400','042344742','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 12:56:10',0,NULL,3,1,3,1,'RA183612505CN\r ','danto007\rOTRA001'),(7629,604229715013,230620799040,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',1,'HSSA004',13.99,'eastar4','djjhunboy','jhunboy@hotmail.com','Jhunboy Billedo','c/o KENNARDS SELF STORAGE<br>565 Woodville Road','Guildford','New South Wales','AUSTRALIA','2161','0296322922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:12:29',0,NULL,5,0,18,1,NULL,'djjhunboy\r澳标\r客户要求退款'),(7630,820370109012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',65.99,'eastar4','gman165','greg@crispyclean.ca','GREG SHULKIN','165 SCHUBERT<br>D.D.O.','MONTREAL','QC','CANADA','H9B2E5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:14:59',0,NULL,3,1,3,1,'RA183612686CN\r ','gman165\rHBPH001'),(7631,553497569004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','1980vinvin','abelvincent@hotmail.fr','Vincent Abel','7385, Hector Heroux','Trois-Rivieres','QC','CANADA','G8Y 7A9','(819) 697-2725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:36:15',0,NULL,3,1,3,1,'RA183612482CN\r ','1980vinvin\rRCLO006\r新的'),(7632,738173067011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','kish12345','ekill-kish@stalux.org','Evonne Kill-Kish','18 Wallace Drive','Dover','NH','UNITED STATES','03820','(603) 740-4987','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 14:12:59',0,NULL,3,1,1,1,'、 ','kish12345'),(7633,604243502013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.76,'eastar4','fanyang0530','yangfan0530@gmail.com','Fan Yang','Unit 12/84-86 Albert Road','Strathfield','New South Wales','AUSTRALIA','2135','0280348414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 14:16:55',0,NULL,3,1,3,1,'RA183612540CN\r ','fanyang0530\rWLAP008'),(7634,555737912004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','humaidka','humaidka@gmail.com','Ali AlHumaid','P.O. Box 2128','Unaizah','','SAUDI ARABIA','51911','+966505205640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 14:22:24',0,NULL,3,1,3,1,'RA183612536CN\r ','humaidka\rBALO007'),(7635,604247455013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','osa0502','ostapvf@yandex.ru','aleksandr ostapchuk','Rekinco h.14','Solnechnogorsk','Moscow Region','RUSSIAN FEDERATION','141508','(+7903)0030680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 14:30:11',0,NULL,3,1,2,1,'\\ ','osa0502'),(7636,739066872011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','philip_petev','philip.petev@gmail.com','Philip Petev','bul. Rakovski 30 vh. D ap. 8','Haskovo','','BULGARIA','6300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 14:51:45',0,NULL,3,1,2,1,'\\ ','philip_petev'),(7637,819234400012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','donr54','donr54@yahoo.com','donald ranous','54 Sagamore Dr','rochester','NY','UNITED STATES','14617-2402','(585) 342-6828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 15:12:42',0,NULL,3,1,6,1,'EE506555660CN ','donr54'),(7638,739068532011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',119.99,'eastar4uk','karambolik','dovzhanskaja@mail.ru','Galkin Dmitriy','Fontanskaya doroga 8/7 app. 23','Odessa','Odessa','UKRAINE','65009','380957309131','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 15:48:14',0,NULL,3,1,3,1,'RA183612584CN\r ','karambolik\rMOLO010'),(7639,817394602012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',96.9,'eastar4uk','beerjammy','kris_farren@hotmail.com','Kris Farren','21<br>Ewloe Place','Buckley','Flintshire','UNITED KINGDOM','CH73NJ','01244540980','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-21 16:31:25',0,NULL,3,1,3,1,'RA183612567CN\r ','beerjammy\rOTSO004*2'),(7640,820452396012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',4,'HSMO017',35.96,'eastar4uk','silkehi','silke.mansuras@gmx.de','Silke Mansuras','Monschauer Weg 14','Berlin','','GERMANY','12105','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 16:52:37',0,NULL,3,1,3,1,'RA183612519CN\r ','silkehi\rHSMO017\r欧标'),(7641,739111432011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','nonye.atueyi','atueyi_emma@yahoo.com','Emmanuel Atueyi','73 Hinchley Wood Grove','BRAMPTON','ON','CANADA','L6V4B1','(905) 452-9184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 16:55:22',0,NULL,3,1,3,1,'RA183612315CN\r ','nonye.atueyi\rWWSI002+ANCN001'),(7642,739116262011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','citrine828','billgate23@live.com','citrine yap','32 jalan 1/5 A,<br>taman sri kluang','kluang','johor','MALAYSIA','86000','012-7555000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 17:06:04',0,NULL,3,1,3,1,'RA183612332CN\r ','citrine828\rUDAP002'),(7643,555786061004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','milledi666irina','milledi666@yandex.ru','Irina Kleyman','Hagalil<br>25','Haifa','Israel','ISRAEL','32241','972525778654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 17:39:43',0,NULL,3,1,3,1,'RA183612346CN\r ','milledi666irina\rHSNO022'),(7644,739137630011,320667818608,'New Logitech battery 4  DJ remote diNovo keyboard 930mA',2,'BALO004',21.98,'eastar4','koko6mo','dklausmeyer@comcast.net','David M. Klausmeyer','10811 Brenner Creek Ct','Houston','TX','UNITED STATES','77079-7300','(713) 461-2047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 17:54:24',0,NULL,3,1,1,1,'\\ ','koko6mo\r黑色的\r新的'),(7645,739140166011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','dave124c41','davide+ebay@cs.cmu.edu','David Eckhardt','330 Jefferson Dr','Mt Lebanon','PA','UNITED STATES','15228-2161','(412) 344-9540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 18:01:01',0,NULL,3,1,1,1,'\\ ','dave124c41'),(7646,739140091011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',19.88,'eastar4','neil042','neilhart@comcast.net','Neil Everhart','43775 Nansa Ct','Fremont','CA','UNITED STATES','94539','(510) 579-1593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 18:05:36',0,NULL,3,0,1,1,'\\ ','neil042'),(7647,820506904012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',34.98,'eastar4','verleihnix','omarx@uos.de','Olaf Marx','Borsigstr. 9','Osnabrueck','','GERMANY','49084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 18:45:32',0,NULL,3,0,3,1,'RA183612638CN ','verleihnix\r\rBTHP3002\r再发一个New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311\r\rHP 6pin1.0 3cm'),(7648,820512061012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'eastar4','zig960','dmb_nk@mail.ru','Dmitriy Kobelev','Suumbike 79 - 71','Nizhnekamsk','Tatarstan','RUSSIAN FEDERATION','423570','960-068-2265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 18:45:43',0,NULL,3,1,3,1,'RA183612598CN\r ','zig960\rGLOT001\r兼容型3D眼镜 通用型'),(7649,820522096012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',19.99,'eastar4uk','abalone59255','manie383@hotmail.com','alexis stepnowski','49 bis rue Edouard Vaillant','Haveluy','Nord-Pas-de-Calais','FRANCE','59255','06.13.17.31.31','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 19:06:18',0,NULL,3,1,3,1,'RA183612425CN\r ','abalone59255\rOTRA001'),(7650,604335010013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','polizeiaudi','koflerch@gmx.at','Christian Kofler','Fresnach 3','Maria Elend/ Ros.','','AUSTRIA','9182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 19:21:42',0,NULL,3,1,2,1,'\\ ','polizeiaudi'),(7651,820533665012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',65.99,'eastar4','zebp','zeberian@gmail.com','Zeberian Merlin','6827 Autumn Ridge Dr<br>Unit G4','Fort Collins','CO','UNITED STATES','80525-7819','(970) 581-2602','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 19:24:42',0,NULL,3,1,1,1,'\\ ','zebp'),(7652,739184148011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','adlanda7','alanda7@yahoo.com','Adam Landa','1050 Island Ave<br>Unit 322','San Diego','CA','UNITED STATES','92101-7261','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 19:30:24',0,NULL,3,1,1,1,'\\ ','adlanda7'),(7653,604338230013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','jcrhea','john_rhea@cox.net','John C Rhea','1701 W Briddle Dr','Rogers','AR','UNITED STATES','72758-8406','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 19:30:27',0,NULL,3,1,1,1,'\\ ','jcrhea'),(7654,604339483013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','samjohle','wo.kuehn@web.de','wolfgang kühn','am höller 6','rögling','','GERMANY','86703','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 19:35:16',0,NULL,3,1,2,1,'\\ ','samjohle'),(7655,604342360013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','hsalonen','hsalonen+ebay@gmail.com','Harri Salonen','Siltavoudintie 10 C 37','Helsinki','Finland','FINLAND','00640','+358415195078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 19:50:48',0,NULL,3,1,2,1,'\\ ','hsalonen'),(7656,820552986012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',65.99,'eastar4','ganes-nc','brian.gurganus@yahoo.com','Mary Gurganus','102 Windswept Ln','Cary','NC','UNITED STATES','27518-8936','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 20:01:25',0,NULL,3,1,1,1,'\\ ','ganes-nc'),(7657,739202067011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','adydkin','nink34@mail.ru','Andrii Dudkin','N. Raevskogo str, 13','Kiev','Ukraine','UKRAINE','01042','380688043535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 20:05:28',0,NULL,3,1,2,1,'\\ ','adydkin'),(7658,819709319012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','sassyat50','biffyjustin@hotmail.com','Jan Rifino','361 Linares Ave','Long Beach','CA','UNITED STATES','90803','(949) 632-1935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 20:10:26',0,NULL,3,1,1,1,'\\ ','sassyat50'),(7659,555567304004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56,'cnfaner','giulioecf','giulio@ham.homelinux.org','Giulio Di Pego','Via Stradone Di Camigliano n 56<br>Camigliano Santa Gemma - Capannori ','(Lucca)','LU','ITALY','55010','328-6962305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 20:13:28',0,NULL,3,1,3,1,'RA183612417CN\r ','giulioecf\rWWSI006'),(7660,820567932012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','sarahashley232','sarybeary232@yahoo.com','Sarah Bostick','1782 E Maple Rd<br>John R Spring','Troy','MI','UNITED STATES','48083','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 20:29:02',0,NULL,3,1,1,1,'\\ ','sarahashley232'),(7661,739220741011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','martin12t','mtwelftree@hotmail.com','Martin Twelftree','20, Wallace St<br>New Bradwell','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk13 0ar','07815040396','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-21 20:44:39',0,NULL,3,1,3,1,'RA183612496CN\r ','martin12t\rHSJA011\r英标'),(7662,739225068011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','tymono1','tymur@wp.pl','Tymoteusz Wiśniowski','Rolnicza 12/85','Tarnów','małopolskie','POLAND','33100','696 437996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 20:59:49',0,NULL,3,1,3,1,'RA183612655CN ','tymono1\rOTES001'),(7663,604368551013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mbilalbhatti','bilalbhatti@bilalbhatti.com','Muhammad Bilal Bhatti','House No A-6, Ghazi Colony<br>Tipu Road, Chaklala','Rawalpindi','Punjab','PAKISTAN','46000','923455929499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 21:00:20',0,NULL,3,1,2,1,'\\ ','mbilalbhatti\rCAB-6060'),(7664,738963602011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','hardcorepansen','hoemma@luftfilteroffen.de','Jochen Hansch','Im Bruchkamp 12','Reichshof','other','GERMANY','51580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 22:13:54',0,NULL,3,1,2,1,'\\ ','hardcorepansen\r'),(7665,820616357012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','mert1234porsche','cillop31@yahoo.com','MERT YILDIZHAN','METIS VILLARI 117.CADDE NO:7<br>CAYYOLU','ANKARA','','TURKEY','06810','(031) 224-2161 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 22:24:15',0,NULL,3,1,2,1,'、 ','mert1234porsche'),(7666,820616962012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','contento1978','ester.contento@gmail.com','Ester Contento SAcristan','avenida Pablo Iglesias 87 portal C 5ºC','Rivas Vaciamadrid','Madrid','SPAIN','28521','627463204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 22:26:30',0,NULL,3,1,3,1,'RA183612465CN\r ','contento1978\rOTSO002'),(7667,820631242012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',19.99,'eastar4uk','tyr-rex','tyr.rex@gmail.com','Fco.Javier Hernández López','Av.Nuestra Señora de Valvanera, 90 -<br>Banco Santander','Madrid','Madrid','SPAIN','28025','616867098','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 23:11:04',0,NULL,3,1,3,1,'RA183612479CN\r ','tyr-rex\rOTRA001'),(7668,820638760012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','rob2222_de','rob2222@gmx.net','Robert Mahs','Bernardstrasse 19','Hausen / Obertshausen','','GERMANY','63179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 23:36:34',0,NULL,3,1,2,1,'\\ ','rob2222_de\racer 5pin1.25 6cm'),(7669,820640968012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','harper57bl','brucicle@optusnet.com.au','Bruce Lemin','19 Boas Place','Florey','Australian Capital Territory','AUSTRALIA','2615','0261562080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 23:45:43',0,NULL,3,1,2,1,'\\ ','harper57bl\r澳标'),(7670,739288098011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','fairdeal24.7','online2kashif@gmail.com','kashif','56pendrill street','hull','East Riding of Yorkshire','UNITED KINGDOM','hu3 1uu','01482216839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 00:23:10',0,NULL,3,1,3,1,'RA183612553CN\r ','fairdeal24.7\rHSJA011\r英标'),(7671,739286374011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','meankty','kty@rccns.net','Staci Emanuel','125 Berry Dr','West Columbia','SC','UNITED STATES','29170','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 00:24:25',0,NULL,3,1,1,1,'\\ ','meankty'),(7672,739290527011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','helenaca.416','hpuchlova@hotmail.com','Helena Puchlova','116-221 Balliol street','Toronto','ON','CANADA','m4s 1c8','(416) 551-9686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 00:30:34',0,NULL,3,1,3,1,'RA183616643CN\r\r ','helenaca.416\rHBPH002'),(7673,739315013011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','massie101','gqmansour@hotmail.com','Whana hashimi','20228 Pienza Ln','PORTER RANCH','CA','UNITED STATES','91326-4242','(949) 439-6053','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 02:14:32',0,NULL,3,1,1,1,'\\ ','massie101\r红边优联'),(7674,739317455011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','nerf37','nealfost@umich.edu','Neal R. Foster','2115 Georgetown Blvd','Ann Arbor','MI','UNITED STATES','48105-1534','(734) 663-0756','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 02:25:40',0,NULL,3,1,1,1,'\\ ','nerf37'),(7675,739318741011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','leandrocicci','leandrociccirello@gmail.com','Leandro Ciccirello','Sarmiento 779 1A','Quilmes','Buenos Aires','ARGENTINA','1878','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 02:32:35',0,NULL,3,1,3,1,'RA183612575CN\r ','leandrocicci\rOTSO004'),(7676,604442829013,230641258112,'New lady lace trim sun/rain stick Umbrella pink',1,'UM00011',24.99,'eastar4','rikku_01','anime_la_323@yahoo.com','zulma castro','948 Cedar St<br>Apt B','el segundo','CA','UNITED STATES','90245','(310) 322-0718','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 03:02:19',0,NULL,3,1,1,1,'、 ','rikku_01\r蕾丝花边伞 \r粉色的'),(7677,739328742011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','eigenstate0','lachlan.tailby@internode.on.net','Lachlan Tailby','29 Yeo Ave','Highgate','South Australia','AUSTRALIA','5063','0883036746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 03:15:04',0,NULL,3,1,2,1,'\\ ','eigenstate0'),(7678,739328822011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mcandan','mcandan@mindspring.com','Michael Candan','8830 51st Ave, c/o ARMCO Management<br>STE MGMT','Elmhurst','NY','UNITED STATES','11373-3919','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 03:18:27',0,NULL,3,1,1,1,'\\ ','mcandan'),(7679,820708123012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','philwithrats','philipclemmer@comcast.net','Philip Clemmer','2304 NW 99th St','Vancouver','WA','UNITED STATES','98665-6242','(360) 546-1972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 04:08:04',0,NULL,3,1,1,1,'、 ','philwithrats'),(7680,820721873012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','vsudath1111','vsudath@gmail.com','sudath fernando','34A ,jayasooriya road<br>wewala','jaela','western province','SRI LANKA','GQ P 11350','0775353008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 05:19:33',0,NULL,3,1,2,1,'、 ','vsudath1111'),(7681,739356349011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','balderarendt','balderarendt@gmail.com','Balder Christian Arendt','Soender Boulevard 130 4.tv','Copenhagen V','','DENMARK','1720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 05:44:19',0,NULL,3,1,2,1,'、 ','balderarendt'),(7682,555937452004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.8,'cnfaner','rfett','jspringer1@aol.com','Robert Fetterman','6101 Stardust Ln','Bethesda','MD','UNITED STATES','20817-5925','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-22 06:05:22',0,NULL,3,1,1,1,'、 ','rfett\r美标'),(7683,820736002012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','attu09','chaminda.senanayake@gmail.com','Pradeep Wijesinghe','531/5 Wijesinghe gardens<br>Kotte Road','Pitakotte','','SRI LANKA','10100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 06:29:56',0,NULL,3,1,2,1,'、 ','attu09'),(7684,739368629011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ragunathd','ragunathd@yahoo.com','Ragunath Devarasu','4863 Montague Ave','Fremont','CA','UNITED STATES','94555-3402','(408) 375-3463','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 06:51:23',0,NULL,3,1,1,1,'、 ','ragunathd'),(7685,550370525003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',39.9,'cnfaner','qarawol','qarawol2@yahoo.com','Rick Diaz - qarawol','4203 Floyd Dr','CORONA','CA','UNITED STATES','92883-0650','(951) 768-2275','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-22 06:52:39',0,NULL,3,1,1,1,'、 ','qarawol'),(7686,683240808008,180699060966,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','alondavi','alon4d@gmail.com','Alon Davidzon','gissin 3/2','Rishon Le Zion','','ISRAEL','75281','972-54-2428285','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 07:52:21',0,NULL,3,1,3,1,'RA183612669CN ','alondavi\rHSPL002'),(7687,8881311321165772,111,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','fichi85','fichi85@aliceposta.it','Luca ficagna','Via alfieri n 17','Vicenza.','Longare ','ITALY','36023','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183612757CN ','OTRA001\r补发的 '),(7688,820761218012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','rib8732','dscanlan@live.com','David Scanlan','390 Palatine Road<br>Northenden','Manchester','Lancashire','UNITED KINGDOM','M22 4fz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 08:21:14',0,NULL,3,1,3,1,'RA183612743CN ','rib8732\rHSJA010\r英标'),(7689,739389851011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','blulic','foxxbl@gmail.com','Boris Lulic','Vijenac Dinare 15','Osijek','','CROATIA','31000','+385992714900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 08:29:21',0,NULL,3,1,2,1,'\\ ','blulic'),(7690,739397514011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',65.98,'eastar4','gaansan1','gaansan@gmail.com','Antonio Bernhard','Strecia di Massari 1','Morcote','','SWITZERLAND','6922','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 09:03:58',0,NULL,3,1,3,1,'RA183616674CN ','gaansan1\rWWSI004'),(7691,604504041013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','hamyachi','mail@alexsin.com','Oleksiy Synyaschok','ul. Schuseva, 36, kv 80','Kiev','Kievskaya oblast','UKRAINE','04060','380934736965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 10:05:05',0,NULL,3,1,2,1,'、 ','hamyachi'),(7692,604510793013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','daryl3412','dgray@powercor.com.au','Daryl Gray','PO Box 6118','White Hills','Victoria','AUSTRALIA','3550','0354405828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 10:43:06',0,NULL,3,1,3,1,'RA183616215CN ','daryl3412\rGLOT001*3\r兼容型3D眼镜 通用型\r'),(7693,820797510012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',35,'eastar4uk','nimitmo','nimit_mit@yahoo.com','Nimit Monarumit','9/147 Mooban PanyaRamindra,<br>Panya Intra Road, Kannayao','Bangkok','','THAILAND','10230','+66818496533','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 10:57:14',0,NULL,3,1,3,1,'RA183612955CN ','nimitmo\rBAZA001'),(7694,739429827011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',39.99,'eastar4','cfm2447','mail@oleg.bz','Oleg Khotyanovich','Oktyabrsky prospekt, 111/119-52','Lubertsy','Moskovskaya oblast','RUSSIAN FEDERATION','140002','+7 495 9723130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 11:13:22',0,NULL,3,1,3,1,'RA183616100CN\r ','cfm2447 欧标\rHSNO019'),(7695,739440641011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','meankty','kty@rccns.net','Staci Emanuel','125 Berry Dr','West Columbia','SC','UNITED STATES','29170','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 11:52:38',0,NULL,3,1,1,1,'\\ ','meankty'),(7696,683300965008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','jmalhtora','jatin.malhotra@gmail.com','Jatin Malhotra','181 D16 Sec3<br>Rohini','Delhi','DL','INDIA','110085','9810520185','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 12:13:10',0,NULL,3,1,3,1,'RA183616127CN\r ','jmalhtora\rHSPL005'),(7697,739447750011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',1,'HSSE009',65.99,'eastar4','msoutlaw223','tastyone_223@yahoo.com','emelda morris','3511 livingston st','new orleans','LA','UNITED STATES','70118-1822','(504) 292-3613','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 12:24:01',0,NULL,3,1,1,1,'\\ ','msoutlaw223\r美标'),(7698,820831021012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','bolly_2','frankiegarcia2009@hotmail.com','frankie','bda santa ana calle c #135-13<br>puente de jobos','guayama','PR','UNITED STATES','00784','(787) 864-2746','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 12:33:00',0,NULL,3,1,1,1,' \\','bolly_2'),(7699,604538713013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','meanworks','tamas.torjek@t-online.hu','Tamás Törjék','Egyetem tér 2, Egyetemi templom<br>Oldalsó bejárat, hátul 19/1-es szoba','Debrecen','','HUNGARY','4032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 13:06:55',0,NULL,3,1,2,1,'、 ','meanworks'),(7700,739463700011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','maggieblue_0','m.agee@comcast.net','Margaret Agee','4551 Lascassas Pike','Murfreesboro','TN','UNITED STATES','37130-6877','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 13:11:49',0,NULL,3,1,1,1,'\\ ','maggieblue_0'),(7701,820853846012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','fdzgeos','fdzgeos@wanadoo.es','Jose Maria Fernandez Andujar','hernando de esturmio 46','osuna Sevilla','Andalucía Ceuta y Melilla','SPAIN','41640','954810319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 13:42:28',0,NULL,3,1,2,1,'、 ','fdzgeos'),(7702,550451364003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','nikolous01','nikolous@gmail.com','Nicholas Hung','PO Box 462<br>Artarmon','Sydney','New South Wales','AUSTRALIA','1570','61405668464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 14:36:58',0,NULL,3,1,3,1,'RA183616087CN\r ','nikolous01\rUDAP001'),(7703,739494432011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','woody773305','paul.woodsford@virgin.net','Dr P V Woodsford c/o Anaes:Dept:','Royal Glamorgan Hospital<br>Ynysmaerdy','Llantrisant','Mid Glamorgan','UNITED KINGDOM','CF72 8XR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 14:42:43',0,NULL,3,1,3,1,'RA183612880CN\r ','woody773305\rMOAP001'),(7704,739494281011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','castolfo','chrisastolfo@gmail.com','Christopher A. Astolfo','42 Furnival Road','Toronto','ON','CANADA','M4B 1W3','(416) 752-9815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 14:45:32',0,NULL,3,1,3,1,'RA183612788CN\r ','castolfo\rUDAP001'),(7705,739497532011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.9,'eastar4','fordgirl51diana','fordgirl198348@yahoo.com','Diana Murray','7132 Beverly St','Overland Park','KS','UNITED STATES','66204-2131','(913) 963-5512','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 14:52:27',0,NULL,3,1,1,1,'\\ ','fordgirl51diana'),(7706,0,110715659383,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',31,'buysia','smolson899','jaybird899.ebay@gmail.com','Jason James','236 Centaurian Dr','West Berlin','NJ','UNITED STATES','08091-3821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 15:38:30',0,NULL,3,1,1,1,'、 ','smolson899'),(7707,0,110715649258,'AVATAR New sealed Panasonic exclusive 3D Blu-ray',1,'BR3D003',66.01,'buysia','entomologist','david_wyatt@email.msn.com','David Wyatt','1314 Vanna Ct','San Jose','CA','UNITED STATES','95131-2468','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 15:39:31',0,NULL,3,1,1,1,'、 ','entomologist'),(7708,738357240011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','arima77_9','jquintanilla1@rgv.rr.com','Juan Quintanilla','510 W Kelly Ave','Pharr','TX','UNITED STATES','78577-4648','(956) 783-6121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 15:49:29',0,NULL,3,1,1,1,'\\ ','arima77_9\racer 6pin1.25 23cm'),(7709,604580893013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','mooltik','vitaly.korenkov@gmail.com','Vitaly Korenkov','21 2nd St','Jersey City','NJ','UNITED STATES','07302-3099','(201) 659-2900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 15:53:09',0,NULL,3,1,1,1,'\\ ','mooltik'),(7710,739522508011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','northernlad17','shayneb@sympatico.ca','shayne beattie','63 virginia street','welland','ON','CANADA','l3c7a4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 16:02:31',0,NULL,3,1,2,1,'\\ ','northernlad17'),(7711,739527037011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','guysegev11','segev.guy@gmail.com','Guy Segev','Shimoni<br>19/14','Tel-Aviv','Israel','ISRAEL','69026','+972547440400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 16:14:37',0,NULL,3,1,2,1,'\\ ','guysegev11'),(7712,820921568012,220815928110,'Genuine Jabra BT800 wireless Bluetooth headset BT 800',1,'HSJA008',17.49,'eastar4uk','caiwingfield','mail@caiwingfield.com','Cai Wingfield','21 Bedford Court<br>Bedford Street','Bath','Avon','UNITED KINGDOM','BA1 6PH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 16:37:01',0,NULL,3,1,3,1,'RA183612765CN\r ','caiwingfield \rHSJA008\r英标'),(7713,739539627011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','boilerquack','snowdon.ashley@gmail.com','Ashley Snowdon','3 Ripon Close','Gillingham','Kent','UNITED KINGDOM','ME8 7BS','01634316595','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 16:45:14',0,NULL,3,1,3,1,'RA183612831CN\r ','boilerquack\rUDAP001'),(7714,739541863011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','matteougolini','matteo.ugolini@gmail.com','Matteo Ugolini','1 Place du Commerce, Suite 220','Montreal','QC','CANADA','H3E 1A2','(514) 574-3750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 16:50:17',0,NULL,3,1,3,1,'RA183616073CN ','matteougolini\rUDAP001'),(7715,604599438013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','alexrockboy','rock13@mail.ru','Alexey Kulinich','Zaozernaya 25, kv.38','Omsk','RU','RUSSIAN FEDERATION','644090','9083158739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 16:58:33',0,NULL,3,1,2,1,'、 ','alexrockboy'),(7716,739548157011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','pres7759','sales@online-tech.com','Marc Laffer/Online Technologies','7759 La Corniche Cir','Boca Raton','FL','UNITED STATES','33433-6009','(561) 226-2530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 17:05:40',0,NULL,3,1,1,1,'\\ ','pres7759'),(7717,739557044011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','highlaender12','highlaender12@web.de','udo schwarz','Marienfelder Allee 47','berlin','na','GERMANY','12277','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:29:56',0,NULL,3,1,2,1,'\\ ','highlaender12  欧标'),(7718,820954869012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',53.99,'eastar4','laurie6425','dspeckma@yahoo.com','Laurie Speckmann','252 Fox Chase St','Warrenton','VA','UNITED STATES','20186-2366','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 17:49:26',0,NULL,3,1,1,1,'\\ ','laurie6425 兼容型眼镜  通用的'),(7719,739579816011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',4,'CASS003',34.8,'eastar4','jeremyrock','jeremy.paris@free.fr','Jérémy Paris','1999 impasse pablo picasso<br>La Mistouflette','BOUC BEL AIR','Provence-Alpes-Côte d\'Azur','FRANCE','13320','0617576873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 18:21:32',0,NULL,3,1,4,1,'YW866127172CN ','jeremyrock  客户要express  补25美金'),(7720,604628172013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','crsri','crsri@yahoo.com','srinivasan ramaswamy','6 WARBLERS CV','LITTLE ROCK','AR','UNITED STATES','72211-4480','(501) 227-8035','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 18:30:57',0,NULL,3,1,1,1,'\\ ','crsri 兼容型眼镜  通用的'),(7721,819045520012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','keysersozecl','eparraguez@gmail.com','Eduardo Parraguez','Pedro Aguirre Cerda 0477 D 202-2','Sanitago','La Cisterna','CHILE','7970637','+56-2-8853118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 18:42:53',0,NULL,3,1,3,1,'RA183616095CN\r ','keysersozecl\rOTRA001'),(7722,739594151011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','keithkleonard','keithmleonard4@hotmail.co.uk','Keith Leonard','4 Mead Way<br>Balderton','Newark','Nottinghamshire','UNITED KINGDOM','NG24 3GA','01636684093','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 18:51:58',0,NULL,3,1,3,1,'RA183612876CN ','keithkleonard \r英标\rHSJA011'),(7723,550520977003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.9,'cnfaner','szmyrek','szmyrek@wp.pl','wojciech szmyra','lesniczowka stawiany','skoki','wielkopolskie','POLAND','62-085','61 4276004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 19:00:47',0,NULL,3,1,3,1,'RA183615594CN ','szmyrek\rWWOT003'),(7724,820989014012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','gmoney2470','gmoney0204@msn.com','Greg Crompton','100 Brunswick Pl','Lansdale','PA','UNITED STATES','19446-6458','(215) 350-8061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 19:01:54',0,NULL,3,1,1,1,'、 ','gmoney2470'),(7725,550524663003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','greygreg','g.steele@steeleweb.com','William Steele','743 Prescott Ct','Naperville','IL','UNITED STATES','60563-2484','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-22 19:12:39',0,NULL,3,1,1,1,'、 ','greygreg'),(7726,739615103011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',2,'ANTY002',7.16,'eastar4','binarylv','delphists@apollo.lv','Andrejs Šitals','Gobu iela 1-5','Baloži','','LATVIA','LV-2128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 19:37:29',0,NULL,3,1,2,1,'\\ ','binarylv'),(7727,739624495011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','spdrmn530','spdrmn530@gmail.com','Nick Fife','13960 SE 215th Ct.','Damascus','OR','UNITED STATES','97089','(503) 473-5190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 19:58:57',0,NULL,3,1,1,1,'\\ ','spdrmn530'),(7728,604674353013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',55,'eastar4','sebkochrossbach','sebkoch@t-online.de','Sebastian Koch','Weserstraße 6','Hünfeld','','GERMANY','36088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 21:01:30',0,NULL,3,1,3,1,'RA183616232CN ','sebkochrossbach\rOTIN003'),(7729,738240215011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.99,'eastar4','**xandro**111','odw-d-m-x-odw@hotmail.com','alexander schmitt','liebersbacherstr.66','birkenau','','GERMANY','69488','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 21:14:55',0,NULL,3,1,2,1,'\\ ','**xandro**111'),(7730,821069159012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','theceonlacd','craig.cd.davenport@gmail.com','BadAzz Shoes  Attn: Craig Davenport','1425 W Manchester Ave<br>Ste C','Los Angeles','CA','UNITED STATES','90047-5436','(310) 930-0262','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 22:23:53',0,NULL,3,1,1,1,'、 ','theceonlacd'),(7731,739696735011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bv57','bvoss57@cox.net','William R. Voss','6505 Blue Wing Dr','Alexandria','VA','UNITED STATES','22307-1338','(703) 678-1068','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 23:29:36',0,NULL,3,1,1,1,'\\ ','bv57'),(7732,821102051012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','rogerdennis','rdbean@verizon.net','Roger Bean','808 Mill Rd','East Aurora','NY','UNITED STATES','14052-2838','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 23:49:54',0,NULL,3,1,1,1,'、 ','rogerdennis'),(7733,604716450013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',5,'CCGR001',34.4,'eastar4','jdeoleo','jsdeoleo@gmail.com','jonathan deoleo JP-14644','8374 NW 64th St<br>Miami, FL 33166','Miami','FL','UNITED STATES','33166-2624','809 236 9791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 00:21:09',0,NULL,3,1,1,1,'\\ ','jdeoleo'),(7734,604719880013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','newyorkturtle','chicagoturtle@earthlink.net','Donald Pepper','9845 Ash Dr','Overland Park','KS','UNITED STATES','66207-3226','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 01:10:19',0,NULL,3,1,1,1,'\\ ','newyorkturtle'),(7735,604748455013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mitchell.darge','mitchell.drage@hotmail.com','Mitchell Drage','3 Willaura Pl','Yallambie','Victoria','AUSTRALIA','3085','0414069368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 03:42:00',0,NULL,3,1,2,1,'、 ','mitchell.darge'),(7736,604748820013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','morkainin','toxsin2000@yahoo.com','Steven Low','412 Christopher Ave<br>APT E','Gaithersburg','MD','UNITED STATES','20879-3628','(240) 423-3990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 03:45:49',0,NULL,3,1,1,1,'、 ','morkainin\rCAB-6060'),(7737,604749125013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',2,'CRLO002',19.8,'eastar4','claudeh2004','claudeh@cvm.qc.ca','claude hetu','32 carré-dubois','boisbriand','QC','CANADA','J7G1S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 03:46:42',0,NULL,3,1,2,1,'\\ ','claudeh2004'),(7738,604751659013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','zunbah','rusyaa@mail.ru','Ruslan Bakhvala','4641 Oakwood Dr<br>Apt 59','Odessa','TX','UNITED STATES','79761-2048','(650) 335-5564','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 04:08:47',0,NULL,3,1,1,1,'\\ ','zunbah'),(7739,604753009013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',15.5,'eastar4','wdhop66','wdhop66@aol.com','Dwight Hopkins','317 Cambridge Rd','Pasadena','Md','UNITED STATES','21122','(443) 817-2166','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-23 04:20:38',0,NULL,3,1,1,1,'\\ ','wdhop66'),(7740,739762779011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','pet6536','peter.dunn@kornferry.com','peter l. dunn','5227 Shirley Ave','tarzana','CA','UNITED STATES','91356-3808','(310) 843-4121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 05:08:31',0,NULL,3,1,1,1,'\\ ','pet6536'),(7741,739774718011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',38.99,'eastar4uk','niiash','bryan_adjetey@yahoo.co.uk','Bryan Adjetey','92 Avon Road','Upminster','Essex','UNITED KINGDOM','RM14 1RF','07515425163','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 06:22:42',0,NULL,3,1,3,1,'RA183616246CN\r ','niiash\rGLSG001'),(7742,821186082012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.4,'eastar4','saosborne9','saosborne9@hotmail.com','Shaun Osborne','123 Styles Dr','Gurley','AL','UNITED STATES','35748-8324','(256) 776-4518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 06:32:05',0,NULL,3,1,1,1,'、 ','saosborne9\racer 8pin1.00 18cm '),(7743,739781679011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','masahiroise','m-ise@kxa.biglobe.ne.jp','Masahiro Ise','3-1-2-306<br>Izumi-cho','Kokubunji-shi','Tokyo','JAPAN','185-0024','+81-42-321-8237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 07:00:07',0,NULL,3,1,17,0,NULL,'masahiroise'),(7744,604644538013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','sunil_kanzig','sunilsunil@naver.com','sun-il kwon','506dong 105ho, Gayang5-danji Apt.,<br>Yangcheonro-57gil 36 (Gayang2-dong, 1481),','Gangseo-gu, Seoul','Seoul','KOREA,REPUBLIC OF','157-745','+82 10-4437-0713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 07:08:54',0,NULL,3,1,3,1,'RA183612859CN\r ','sunil_kanzig\rWLIN014'),(7745,739784606011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',22.97,'eastar4','ppplo','ppploebay@gmail.com','Loisseau Philippe','Rue des Chanterelles, 149','Seraing','','BELGIUM','4100','0495635298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 07:15:17',0,NULL,3,1,2,1,'\\ ','ppplo    再加一个New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card\r'),(7746,604780903013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','masahiroise','m-ise@kxa.biglobe.ne.jp','Masahiro Ise','3-1-2-306<br>Izumi-cho','Kokubunji-shi','Tokyo','JAPAN','185-0024','+81-42-321-8237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 07:50:24',0,NULL,3,1,3,1,'RA183616025CN\r ','masahiroise  \rWLIN014+MOCN001\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e'),(7747,701409786001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','btz1','bht0504@gmail.com','Bryan Tribble','11800 Prince Regent Pl','Richmond','VA','UNITED STATES','23238-3947','(540) 522-0943','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 07:51:23',0,NULL,3,1,1,1,'、 ','btz1'),(7748,821215305012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',23.99,'eastar4uk','dev237','johnflo@sky.com','John Devey','5 caveners Court<br>Upper Bristol Road','Weston-super-Mare','Somerset','UNITED KINGDOM','BS22 8DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 08:39:24',0,NULL,3,1,3,1,'RA183612862CN\r ','dev237\rOTRA001'),(7749,821219330012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',75.99,'eastar4','pmaytona','pmaytona@mac.com','Paul Michael Aytona','3 Citrus Ave.','Hornsby','New South Wales','AUSTRALIA','2077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 08:53:44',0,NULL,3,1,3,1,'RA183612774CN\r ','pmaytona\rHBPH001'),(7750,821219939012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',21.99,'eastar4uk','gfpenman','gfpenman@ntlworld.com','Gordon Penman','19 Lindsay Drive<br>Kelvindale','Glasgow','Glasgow (City of)','UNITED KINGDOM','G12 0HB','01415816296','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 08:55:48',0,NULL,3,1,3,1,'RA183612828CN\r ','gfpenman\rUDAP002'),(7751,739811116011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','chatpet','cxy1343@njit.edu','Chatpet Yossapol','Institute of Engineering<br>Suranaree University of Technology','Amphur Muang','Nakornratchasima','THAILAND','30000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 09:06:35',0,NULL,3,1,2,1,'\\ ','chatpet'),(7752,604796824013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','jamicaela','josemicaela@hotmail.com','jose Micaela','45 fitzwarren Court,<br>Rosehill Close,Rosehill Close','Manchester, Salford','Lancashire','UNITED KINGDOM','M6 5LN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 09:20:07',0,NULL,3,1,2,1,'\\ ','jamicaela'),(7753,821229524012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','melhiore','melhiore@yahoo.co.uk','Dominika&Marcin Wojcik','75 Coniston Avenue','Bolton, Farnworth','Lancashire','UNITED KINGDOM','BL4 0PZ','07701025336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 09:29:48',0,NULL,3,1,2,1,'\\ ','melhiore'),(7754,821252633012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',25.9,'eastar4uk','abre5221','a.brennan@latrobe.edu.au','Andrew Brennan','49/400 Victoria Parade','East Melbourne','Victoria','AUSTRALIA','3002','0394191916','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-23 10:46:59',0,NULL,3,1,2,1,'、 ','abre5221'),(7755,604816702013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','hoejer85','ebay@fixcom.dk','Rasmus Hoejer Larsen','Bredgade 107','Taars','','DENMARK','9830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 11:02:01',0,NULL,3,1,2,1,'\\ ','hoejer85'),(7756,821287216012,220807272247,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',25.99,'eastar4','lanek55','gargielane@gmail.com','Kerry Lane','27 Budgewoi Road','Noraville','New South Wales','AUSTRALIA','2263','0413597707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 12:35:07',0,NULL,3,1,2,1,'、 ','lanek55'),(7757,604806276013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','vintage_destination','cc_hakim@rediffmail.com','Aftab Hakim','Room no 503 Al Nahada<br>Al Nahada 2 Near NMC Hospital','Dubai','','UNITED ARAB EMIRATES','94392','971553019930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 12:55:27',0,NULL,3,1,2,1,'\\ ','vintage_destination'),(7758,739879686011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','preecha7312','preecha_scorpion@yahoo.com','Mr.Preecha Padermsakpittaya','ZTE (Thailand) Co.,Ltd. 20th Floor, Unit 2005-7 Empire Tower ,<br>195 South Sathorn Road, Yannawa, Sathorn,','Bangkok','Thailand','THAILAND','10120','669-119-9126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 13:04:15',0,NULL,3,1,2,1,'\\ ','preecha7312'),(7759,604848703013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','vintage_destination','cc_hakim@rediffmail.com','aftab hakim','392/393 hakim bunglow s.m road <br>antophill','Mumbai','MH','INDIA','400037','9833529567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 13:26:12',0,NULL,3,1,2,1,'\\ ','vintage_destination'),(7760,701496106001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','louisaint','louisaint_99@yahoo.com','Alexis Dy','Kisogawa Cho Oaza Kadoma Aza Shin Yasiki 36-2 Banchi Maruhachi Sou 7 Gou','Ichinomiya Shi','Aichi','JAPAN','4930002','81-9099129165','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 13:26:18',0,NULL,3,1,3,1,'RA183612978CN\r ','louisaint\rBR3D004'),(7761,556287049004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',15.5,'cnfaner','ling2long','pmerwarth@adam.com.au','Philip Merwarth','c/o Elcon Cables<br>U1/35 Aldenhoven Rd','Lonsdale','South Australia','AUSTRALIA','5160','0411138542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 13:26:40',0,NULL,3,1,3,1,'RA183616144CN ','ling2long\rWLAT008'),(7762,739889236011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','anosh57','anoshmohamed57@gmail.com','Anosh Mohamed','11B Eagle Street','Ipswich','Suffolk','UNITED KINGDOM','Ip4 1ja','07403315263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 13:32:45',0,NULL,3,1,3,1,'RA183616056CN ','anosh57\rUDAP001'),(7763,739904927011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','famtrans','jeff@familytransitions.com.au','Family Transitions','P.O. Box 5130','Alphington','Victoria','AUSTRALIA','3078','0403772883','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-23 14:17:19',0,NULL,3,1,2,1,'\\ ','famtrans'),(7764,821322889012,220565577390,'Dell 1510 mini PCI-E half size card +2 tyco antenna',2,'WLDE002+ANTY001',53.86,'eastar4','bayani69','bayani69@hotmail.com','BAYANI DE GUZMAN','11043 Wescott Ave','Sunland','CA','UNITED STATES','91040','(323) 543-6263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 14:20:49',0,NULL,3,1,1,1,'\\ ','bayani69    再发一个New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna\r'),(7765,556303556004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'',29.8,'cnfaner','pnelson858','phillip_nelson@verizon.net','Phillip Nelson','12022 Starboard Dr<br>Apt 305','Reston','VA','UNITED STATES','20194-4370','(858) 220-4307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-23 14:37:10',0,NULL,3,1,1,1,'\\ ','pnelson858'),(7766,739921813011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',42.9,'eastar4uk','felber7310','felber73@gmail.com','George Felber','67b<br>Cricklewood Broadway','London','London','UNITED KINGDOM','nw2 3jr','07577852401','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 15:03:15',0,NULL,3,1,3,1,'RA183616303CN ','felber7310  英标\rHDGE001'),(7767,550740591003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','maximehome','maximehome@free.fr','Maxime Car','8 place leon bourgeois','Sermaize les bains','Champagne-Ardenne','FRANCE','51250','0677134435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 15:25:04',0,NULL,3,1,3,1,'RA183616039CN ','maximehome\rBALO007'),(7768,739206743011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',8.55,'eastar4','b00merfsu','marionfsu@gmail.com','Marion Bogdanov','2529 Carthage','Tallahassee','FL','UNITED STATES','32312-4860','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 15:32:16',0,NULL,3,1,1,1,'\\ ','b00merfsu'),(7769,604901888013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','berolina_baer','twiegleb@gmx.de','Thomas Wiegleb','Platanenweg 2a','Berlin','','GERMANY','12437','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 16:32:49',0,NULL,3,1,2,1,'\\ ','berolina_baer'),(7770,821396009012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','ilovetobuynow','paulkang@aol.com','Paul Kang','20553 Five Oaks Ct','Sterling','VA','UNITED STATES','20165-3171','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 17:05:27',0,NULL,3,1,1,1,'、 ','ilovetobuynow'),(7771,821424032012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',35,'eastar4uk','60p','highlorddave@hotmail.com','david smith','135 runfold ave','luton','Bedfordshire','UNITED KINGDOM','lu3 2el','07966962630','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 18:02:11',0,NULL,3,1,3,1,'RA183612726CN ','60p  \r英标\rBAZA001'),(7772,821434335012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','digo_pe','pedrosa.rodrigo@gmail.com','RODRIGO PEDROSA','RUA OUREM N.227 BL.C AP.604','RECIFE','PERNAMBUCO','BRAZIL','50761340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 18:27:48',0,NULL,3,1,2,1,'\\ ','digo_pe'),(7773,740012971011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','sherryok22','sherry.lyall@cox.net','Sherry Lyall','3315 S Lewis Ave','Tulsa','OK','UNITED STATES','74105-2802','(918) 743-9236','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 18:39:16',0,NULL,3,1,1,1,'\\ ','sherryok22'),(7774,821463632012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','toroianuk','toroian@hotmail.co.uk','Miss C E Toogood','14 Belvedere Road','Hessle','East Riding of Yorkshire','UNITED KINGDOM','HU13 9JJ','01482641601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 19:18:20',0,NULL,3,1,2,1,'\\ ','toroianuk'),(7775,740038026011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',4,'GLOT004',215.96,'eastar4','1964mikemorreale','morrealemike@yahoo.com','Mike Morreale','305 Buttonwood St','Hamilton','NJ','UNITED STATES','08619-3508','(609) 954-2075','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 19:30:28',0,NULL,3,1,6,1,'EE495341198CN ','1964mikemorreale  兼容型眼镜  sansung 专用的'),(7776,556401118004,140535373671,'New Atheros AR9287 Wireless Half PCI-E Card+antenna',1,'WLAT007+ANTY001',16.9,'cnfaner','pavel.hanc','tashi@email.cz','Pavel Hanč','Dobřanská 389','Chlumčany u Přeštic','','CZECH REPUBLIC','33442','+420-775597766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 20:14:52',0,NULL,3,1,3,1,'RA183616158CN ','pavel.hanc\rWLAT007+ANTY001'),(7777,740059741011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','kpoloman','kpoloman@aol.com','Kevin Gibbs','24 Bee St<br>Apt K','Charleston','SC','UNITED STATES','29403-6820','(864) 242-1655','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 20:21:34',0,NULL,3,1,1,1,'\\ ','kpoloman'),(7778,604982541013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','topidavid','topi6@walla.co.il','Eitan Shaked','israel yeshaayahu 3 st.','qiriat yam','','ISRAEL','29082','972525222276','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 20:46:52',0,NULL,3,1,2,1,'\\ ','topidavid'),(7779,604982362013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','opjiahryp','opjiahryp@gmail.com','Aleksandr Kurnosov','mkr. Skhodnya Michurina str. 29-8','Khimki','','RUSSIAN FEDERATION','141420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 20:46:56',0,NULL,3,1,2,1,'\\ ','opjiahryp'),(7780,701675348001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','patpenny','leslie_miller@hotmail.com','Leslie S. Miller','2808 E Kenwood Blvd','Milwaukee','WI','UNITED STATES','53211-3453','(414) 298-8321','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 21:17:36',0,NULL,3,1,1,1,'\\ ','patpenny'),(7781,604991622013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.4,'eastar4','shakeebh67','shakeebh@gmail.com','Shakeeb Hussain','345 Central Park Ave<br>Apt E','Scarsdale','NY','UNITED STATES','10583-1361','(914) 831-0575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 21:19:23',0,NULL,3,1,1,1,'、 ','shakeebh67'),(7782,821535074012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','valemarcos','valemarcos@hotmail.com','Marcos Vale','Santa Luiza street, 259/apt 203','Rio de Janeiro','Rio de Janeiro / Maracanã','BRAZIL','20511030','+55 21 86685221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 22:01:07',0,NULL,3,1,3,1,'RA183612933CN ','valemarcos\rOTRA001'),(7783,604869893013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',5,'OTCN001',19.95,'eastar4','mwlblues','mattlongfield@gmail.com','Matthew Longfield','50 Signal Ct','Saint Louis','MO','UNITED STATES','63146-5462','(314) 989-9065','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 22:10:51',0,NULL,3,1,1,1,'、 ','mwlblues'),(7784,740116896011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','indianpass','kenmckneely@hotmail.com','Kenneth W. McKneely','971 NORTH AVE NE','ATLANTA','GA','UNITED STATES','30306-4412','(404) 872-5506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-23 23:02:28',0,NULL,3,1,1,1,'\\ ','indianpass 兼容型眼镜  samsung专用的'),(7785,605012371013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',95.97,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 23:03:25',0,NULL,3,1,3,1,'RA183612995CN ','update_marcelo\rWWSI005'),(7786,740125475011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','gluchy3','gluszek.tomasz@gmail.com','Tomasz Gluszek','48 Cadogan Road<br>Fairview','Dublin','Dublin','IRELAND','3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 23:35:53',0,NULL,3,1,2,1,'\\ ','gluchy3'),(7787,740128355011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','juliovizma','julio_vizcaino@hotmail.com','Julio Vizcaino Martinez','c/ General Millan Astray nº19 piso 6º 2','Madrid','Madrid','SPAIN','28044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 23:48:26',0,NULL,3,1,2,1,'\\ ','juliovizma'),(7788,740139931011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',53.99,'eastar4','dijandira','dsvianajr@hotmail.com','Dorgival S Viana Jr','Alameda São Francisco, 950<br>Pinheiro','Maceió','Alagoas','BRAZIL','57055770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 00:37:28',0,NULL,3,1,3,1,'RA183612964CN\r ','dijandira  兼容型眼镜  通用的\rGLOT001'),(7789,740142975011,320585224260,'Intel 5300 AGN MIMO half size Mini PCI-E Card+tyco ante',1,'WLIN009+ANTY002',17.99,'eastar4','zardojunior','zardojunior@gmail.com','Moacir Zardo Junior','Barão de Ubá, 469 ap 902','Porto Alegre','RS','BRAZIL','90450-090','55 51 3333-1615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 00:53:47',0,NULL,3,1,2,1,'\\ ','zardojunior'),(7790,683956465008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','williamttt','billteis@hotmail.com','william teis','525 crabbes creek road','crabbes creek','New South Wales','AUSTRALIA','2483','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 01:31:39',0,NULL,3,1,3,1,'RA183616201CN\r ','williamttt\r澳标\rHSPL005'),(7791,821593047012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','pwh24','pwh24@hotmail.com','paul hinterberger','1088 North Dr','waterford','PA','UNITED STATES','16441','(814) 434-1427','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 01:42:59',0,NULL,3,1,1,1,'、 ','pwh24'),(7792,738561584011,320730530130,'New Lady Wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','tony_rj45','rsio@optusnet.com.au','Rebecca Sio','5 Beresford Pde','Kingsgrove','New South Wales','AUSTRALIA','2208','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 01:55:01',0,NULL,3,1,2,1,'、 ','tony_rj45\r正红色长柄婚庆伞'),(7793,821612189012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','fellowgamer','thegamefish@gmail.com','Eddie Turner','7030 Hunter Glen Dr','Ooltewah','TN','UNITED STATES','37363','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 02:51:00',0,NULL,3,1,1,1,'\\ ','fellowgamer'),(7794,605063770013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','h2oat0c32f','zhangjacob@msn.com','Jacob Zhang','2 Mossgrove Trail','Toronto','ON','CANADA','M2L2W3','(416) 508-2602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 03:49:06',0,NULL,3,1,3,1,'RA183612947CN\r ','h2oat0c32f\rBAZA001'),(7795,605063001013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','jatinder042','jetu48@yahoo.com','jatinder singh','246yarramalong road','wyong creek','New South Wales','AUSTRALIA','2259','0422787289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 03:58:22',0,NULL,3,1,2,1,'、 ','jatinder042\r澳标'),(7796,740197657011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jkellington','jasonkellington@gmail.com','Jason Kellington','506 Macleod Ave W<br>P.O. Box 537','Melfort','SK','CANADA','S0E 1A0','(306) 921-5254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 05:24:54',0,NULL,3,1,2,1,'\\ ','jkellington'),(7797,821646926012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',4,'OTAP001',37.96,'eastar4','irahola.marcelo','mirahola@gmail.com','Marcelo Irahola','593 Gregorio Reynolds Esq. Presbitero Medina','La Paz','La Paz / Murillo','BOLIVIA','0000','(591)795-75492.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 05:52:21',0,NULL,3,1,3,1,'RA183612916CN\r ','irahola.marcelo\rOTAP001'),(7798,821479000012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','victoriavev','vika-veverica@mail.ru','Victoria Veveritsa','Budennogo boulevard, 5-186','Togliatti','Samarskaya oblast','RUSSIAN FEDERATION','445027','89277792264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 06:25:29',0,NULL,3,1,2,1,'、 ','victoriavev\r24K 多色伞'),(7799,821659058012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','xpmaster_antofagasta','acortes@nortraining.com','Alvaro Cortes','Cerro Colorado 3746 Edificio Radiatta Dept. 503<br>Condominio Jardines del Sur','Iquique','Tarapacá','CHILE','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 06:52:28',0,NULL,3,1,3,1,'RA183612920CN ','xpmaster_antofagasta\rOTRA001'),(7800,740219517011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.9,'eastar4','vn94264','shaitz@gmail.com','shai tzfadia','Ben-hur 15 st','Petach tikva','ISRAEL','ISRAEL','49063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 07:19:53',0,NULL,3,1,2,1,'\\ ','vn94264'),(7801,740213926011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','marlonazada','marlonazada@att.net','Marlon Azada','918 W 18th St','Houston','TX','UNITED STATES','77008-3337','(303) 912-1224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 07:32:42',0,NULL,3,1,1,1,'\\ ','marlonazada'),(7802,605093021013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','puneetaki','arjun_sneha007@yahoo.co.in','puneet kumar sharma','24 curtin street <br>saint albans','melbourne','Victoria','AUSTRALIA','3021','0413037672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 07:39:51',0,NULL,3,1,2,1,'\\ ','puneetaki\r澳标'),(7803,556515359004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.8,'cnfaner','chammahl','chammah_leon@hotmail.com','Manale Azar','Liban Post Head office - OPS section<br>Rafic Hariri Int Airport, 1000 Baabda','Beirut','Beirut','LEBANON','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 08:01:59',0,NULL,3,1,3,1,'RA183616229CN ','chammahl\r美标\rMOMI001'),(7804,740246345011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','joosttsooj','joostk-eb@scintilla.utwente.nl','Joost Kauffman','De Groene Boog 38','Enschede','','NETHERLANDS','7513 KB','0538502309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 08:53:28',0,NULL,3,1,2,1,'\\ ','joosttsooj'),(7805,605107692013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.2,'eastar4','rodyap','radiator28@gmail.com','Alvin Nunez','Edogawa-Ku Minami Kasai 6-20-14<br>Maison Onda 201','Tokyo','Tokyo','JAPAN','134-0085','090-9837-2003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 08:59:14',0,NULL,3,1,3,1,'RA183612814CN\r ','rodyap\rCAB-SS-2626\rCASS001'),(7806,740261961011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','bdk9001','dhr.de.kort@gmail.com','Bart de Kort','Ina Boudier-Bakkerlaan 143-1','UTRECHT','','NETHERLANDS','3582XW','06-23437971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 09:37:38',0,NULL,3,1,2,1,'\\ ','bdk9001\racer 4pin1.25 6cm'),(7807,740267110011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','denlee_moscow','denlee@mail.ru','Denis Lichak','25 Krasnaya St, Apt. 91','Solnechnogorsk','Moscow Region','RUSSIAN FEDERATION','141503','+7-919-760-29-27','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 09:50:45',0,NULL,3,1,2,1,'\\ ','denlee_moscow\r'),(7808,821722028012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',164.99,'eastar4uk','holliebikes','robjenm@tpg.com.au','Rob Moran','15 Javelin Street','Gladstone','Queensland','AUSTRALIA','4680','0409582868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 10:03:16',0,NULL,3,1,6,1,'EE495341017CN ','holliebikes\rOTSO004*4'),(7809,740277969011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','akandrew2007','drayekyaw@yahoo.com','Andrew Aye Kyaw','#02-1917, BLK 333<br>Ang Mo kio Ave 1','Singapore','','SINGAPORE','560333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 10:17:39',0,NULL,3,1,11,1,'、 ','akandrew2007\rHSJA002'),(7810,740295564011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',24.99,'eastar4','luvbead_perth','icecjan@gmail.com','Janice T Chan','PO Box 283<br>Osborne Park','Perth','Western Australia','AUSTRALIA','6017','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 11:01:57',0,NULL,3,1,2,1,'、 ','luvbead_perth\rProLee24K超轻碳纤骨长柄伞 \r深蓝色的'),(7811,684089589008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','axalotl1','gary.deegan@gmail.com','Gary Deegan','Level 8, 255 george street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 11:03:38',0,NULL,3,1,3,1,'RA183612845CN\r ','axalotl1\rRELO002'),(7812,605154727013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.97,'eastar4','leixing063lvm','leixing007@hotmail.com','dong zhao','Unit 41/16 Lakefield Place','Runcorn','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 11:32:13',0,NULL,3,1,2,1,'\\ ','leixing063lvm'),(7813,740320071011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','trutano','jezzel.martinez@gmail.com','Jezzel Martinez','Palmar Dorado Norte<br>32005 Calle Real','Dorado','PR','UNITED STATES','00646','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 11:58:58',0,NULL,3,1,1,1,'\\ ','trutano'),(7814,740322227011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.94,'eastar4','philleflisan','pepo72@gmail.com','Peter Polvi','Bangatan 28','Sodertalje','Sodertalje','SWEDEN','15132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 12:05:01',0,NULL,3,1,2,1,'\\ ','philleflisan'),(7815,605185849013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',2,'WLDE001',29.96,'eastar4','leon.bollerup','mail@r2x2.com','Leon Bollerup','Ankarskatavägen 28','Piteå','Piteå','SWEDEN','94164','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 13:13:53',0,NULL,3,1,2,1,'\\ ','leon.bollerup'),(7816,740366361011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',3,'RELO002',38.91,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 13:44:55',0,NULL,3,1,3,1,'RA183616135CN ','masteroll2010\rRELO002'),(7817,740368567011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','laszlo.toth','laca.toth@gmail.com','László Tóth','Zoltai Lajos 3','Hortobagy','','HUNGARY','4071','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 13:53:51',0,NULL,3,1,2,1,'\\ ','laszlo.toth\r红边优联'),(7818,740380175011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','i_shep','ionashepherd@hotmail.com','Iona Shepherd','11 Church Road<br>Whitchurch','Cardiff','Cardiff','UNITED KINGDOM','CF14 2DX','02920625192','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-24 14:20:10',0,NULL,3,1,3,1,'RA183612893CN\r ','i_shep\r红边优联\rRELO003'),(7819,740398473011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','baumhaus13505','thliese@gmx.de','Thomas Liese','Rohrweihstr. 39','Berlin','','GERMANY','13505','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 14:50:04',0,NULL,3,1,2,1,'\\ ','baumhaus13505'),(7820,740421710011,320575299743,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT011',29.99,'eastar4','exogen_de','richard.w.schaetzl@gmx.de','Richard Schätzl','Sutelstr.54D','Hannover','','GERMANY','30659','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 15:33:15',0,NULL,3,1,2,1,'\\ ','exogen_de\r盒装的'),(7821,605235933013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*3',310,'eastar4','dahveed2','david.blake@capmark.com','Shelly Blake','12330 Hampton Valley Pl','Chesterfield','VA','UNITED STATES','23832-2035','(804) 276-5380','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 15:38:11',0,NULL,3,1,6,1,'EE495341025CN ','dahveed2\r兼容型3D眼镜 通用型'),(7822,740421058011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',127.98,'eastar4','chupe0228','seehupe@gmail.com','Christine Hupe','401 7th ave n','Sartell','MN','UNITED STATES','56377-1630','(320) 249-4928','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 15:41:44',0,NULL,3,1,1,1,'\\ ','chupe0228'),(7823,605241049013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','joel_95','joelchan95@gmail.com','Joel Chan','Flat A, G/Floor, Block 15, Beacon Heights, Lung Ping Rd.<br>Kowloon Tong, Hong Kong','default','','HONG KONG','default','(852) 61500492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 15:44:49',0,NULL,3,1,2,1,'\\ ','joel_95'),(7824,740432323011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','taz999baby','tarrantjai@hotmail.com','James Tarrant','44 Sampson Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892930951','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-24 15:49:38',0,NULL,3,1,3,1,'RA183616011CN ','taz999baby\rOTSO004*2'),(7825,821891731012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','tiger.700970','tiger.70@op.pl','Jaroslaw Toczylowski','6 Stephen Road','Newark','Nottinghamshire','UNITED KINGDOM','NG24 2BG','07542997055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 15:51:18',0,NULL,3,1,2,1,'\\ ','tiger.700970\r英标'),(7826,740511046011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','drautaler','hardiauge@arcor.de','Rolf Kaul','Bleibtreustr.19','Duisburg','','GERMANY','47137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 17:41:26',0,NULL,3,1,2,1,'\\ ','drautaler'),(7827,739071838011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',2,'SCLO001',39,'eastar4','grammastoolshed','grammastoolshed@rogers.com','Jeff Holley','c/o Mazda of Toronto<br>6167 Yonge Street','Toronto','ON','CANADA','M2M 3X2','(647) 404-2874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 17:49:17',0,NULL,3,1,3,1,'RA183612902CN ','grammastoolshed\rSCLO001+BALO001\r再发两块蓝电池 \r 新的'),(7828,739070891011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','grammastoolshed','grammastoolshed@rogers.com','Jeff Holley','c/o Mazda of Toronto<br>6167 Yonge Street','Toronto','ON','CANADA','M2M 3X2','(647) 404-2874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 17:48:04',0,NULL,3,1,17,0,NULL,'grammastoolshed'),(7829,822030917012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',56.98,'eastar4uk','mohmmadtahirali','tahirali786@live.com','Syed Ali','104 WinterFold Drive','Brampton','ON','CANADA','L6V3T3','(647) 864-6414','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 18:33:16',0,NULL,3,1,3,1,'RA183613001CN\r ','mohmmadtahirali\rHSNO019'),(7830,740566886011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','rayfidelity','rayfidelity@gmail.com','Ana Avgustin','Locka cesta 14d','Crnomelj','','SLOVENIA','SI8340','+38640753246','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 18:42:10',0,NULL,3,1,2,1,'\\ ','rayfidelity'),(7831,605348910013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.97,'eastar4','darvikon','xemich@gmail.com','Stepan Polovnikov','Tropinina 61-35','Nizhniy Novgorod','Nizhniy Novgorod','RUSSIAN FEDERATION','603137','+79101033427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 18:58:44',0,NULL,3,1,3,1,'RA183616042CN\r ','darvikon\rWLIN014+MOCN001\r通用版\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e\r'),(7832,740587498011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','pymat','pymatagne@gmail.com','Andrea Maria Matagne Ñiquen','Julien Colson, 49/9','Namur','','BELGIUM','5000','0478309261','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:07:08',0,NULL,3,1,2,1,'\\ ','pymat'),(7833,740603705011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','ahurme','zimeon.null@gmail.com','Antti Hurme','Palokärjentie 19','Kyrö','','FINLAND','21800','+358403532720','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 19:27:28',0,NULL,3,1,2,1,'\\ ','ahurme'),(7834,605369587013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','fun2hunt4ducks','bkachmer@aol.com','Bryan Kachmer','5550 Duck Creek Rd','Berlin center','OH','UNITED STATES','44401','(330) 550-0139','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 19:30:18',0,NULL,3,1,1,1,'\\ ','fun2hunt4ducks'),(7835,822102740012,220501842449,'2.1 Acer Extensa 5420 5420G  Bluetooth Module +cable',1,'BTAC2106',12.4,'eastar4','stephenghowe','stephenghowe@yahoo.com','Stephen Howe','2241 W Greenleaf Dr','Frederick','MD','UNITED STATES','21702-2625','(240) 575-4739','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 19:56:05',0,NULL,3,1,1,1,'、 ','stephenghowe\racer 4pin1.25 15cm '),(7836,740626310011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','sygmund666','vladoadam@gmail.com','Vladimir Adam','Frankovo naselje 43','Škofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:58:31',0,NULL,3,1,3,1,'RA183616630CN\r ','sygmund666\rHBPH002'),(7837,740671181011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','brunoeudes007','brunoeudes@hotmail.com','Bruno Eudes da Silva','Rua das Rosas nº 107, Feu Rosa','Serra','Espirito Santo','BRAZIL','29172360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 21:14:41',0,NULL,3,1,3,1,'RA183616294CN ','brunoeudes007\rGLSG001*2'),(7838,605433577013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',70.96,'eastar4','tony24554','tony245541@aol.com','tony smith','134 antwerp ave','brookville','OH','UNITED STATES','45309','(937) 409-9251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 22:21:07',0,NULL,3,1,1,1,'、 ','tony24554'),(7839,551255536003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','shalevlazarof','lazarof.shalev@gmail.com','SHaLeV Lazarof','Hasahlav 12','Neve Ziv','IL','ISRAEL','25123','0526206091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 22:23:24',0,NULL,3,1,3,1,'RA183616060CN ','shalevlazarof\rUDAP001'),(7840,605438390013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','seeker_spartanovka','fomichev.ru@gmail.com','Aleksandr Fomichev','ul. 15 Parkovaya, 47k3, kv.83','Moscow','','RUSSIAN FEDERATION','105523','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 22:32:23',0,NULL,3,1,2,1,'\\ ','seeker_spartanovka\r新的'),(7841,739978048011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','horizontal2009','richardmcareavey@gmail.com','Richard McAreavey','11 Cill Ard','Newmarket','Cork','IRELAND','IE','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-24 22:37:38',0,NULL,3,1,3,1,'RA183616250CN\r ','horizontal2009\rRELO003\r红边优联'),(7842,822196930012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','jackiedashley','jackieashley@yahoo.com','Jackie Ashley','28034 Curtis Rd','Livonia','MI','UNITED STATES','48152-3749','(313) 318-4261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 23:14:57',0,NULL,3,1,1,1,'、 ','jackiedashley'),(7843,684472537008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','bri597','thebeck5@aol.com','Brian Beck','597 Sunrise DR','Clarkston','MI','UNITED STATES','48348-1492','(248) 627-3332','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-24 23:25:42',0,NULL,3,1,1,1,'、 ','bri597\r\r\r'),(7844,739659828011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','cheezxe10','b.brady@tx.rr.com','Bill Brady','296 Freeport PKWY','Coppell','TX','UNITED STATES','75019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 23:36:24',0,NULL,3,1,1,1,'\\ ','cheezxe10'),(7845,740724127011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','vtcommodore09','jessiehonda97@gmail.com','robert derr','51 Demetrius Road','Rosemeadow','New South Wales','AUSTRALIA','2560','04169579970416957997','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 23:42:22',0,NULL,3,1,2,1,'\\ ','vtcommodore09\racer 4pin1.25 8cm '),(7846,740739905011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','olent2','olent2@aol.com','Michael S. Oholendt','2703 Nicholson St','Houston','TX','UNITED STATES','77008-2026','(713) 880-0793','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 00:32:10',0,NULL,3,1,1,1,'\\ ','olent2'),(7847,551288449003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',16.99,'cnfaner','arthur_tc','arthur_liberman@hotmail.com','Arthur Liberman','Snapir st. 1/12','Tel Aviv','','ISRAEL','67298','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 01:00:27',0,NULL,3,0,3,1,'RA183616113CN\r ','arthur_tc\rHSPL005\r欧标'),(7848,605475084013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.98,'eastar4','micheal2235','mhightower@charter.net','Micheal Hightower','735 Old State Route 22','Mc Kenzie','TN','UNITED STATES','38201-3707','(731) 352-9637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 01:02:20',0,NULL,3,1,1,1,'、 ','micheal2235'),(7849,740767320011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.9,'eastar4uk','tiliax41','specularium@bredalsparken.dk','Alex Lind','Gurrevej 10, 2.tv.','Hvidovre','','DENMARK','2650','004542451215','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 01:59:41',0,NULL,3,1,3,1,'RA183612712CN\r ','tiliax41\rOTSO002'),(7850,740154371011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',2,'WLAP008+ANAP001',39.76,'eastar4','galtamir','gerardo.gonzalez@cox.net','gerardo gonzalez','5973 W Morelos St','Chandler','AZ','UNITED STATES','85226-4483','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 02:16:07',0,NULL,3,0,1,1,'\\ ','galtamir\r已入库'),(7851,740773211011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','timebomb0602','daham06@yahoo.com','Dadron A. Ham','1156 Westridge Cir','Birmingham','AL','UNITED STATES','35235-1857','(205) 335-1460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 02:17:18',0,NULL,3,1,1,1,'\\ ','timebomb0602'),(7852,740773531011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','cgal2449','cgallegosbn@live.com','chris gallegos','11201 suffolk ave sw','albuquerque','NM','UNITED STATES','87121-9537','(505) 730-7125','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 02:18:21',0,NULL,3,1,1,1,'\\ ','cgal2449'),(7853,740753165011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','maplesyrupdeals','maple.syrup.deals@gmail.com','Rob Martin','1888 East 61 Avenue<br>Basement Suite','Vancouver','BC','CANADA','V5P2K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 02:36:07',0,NULL,3,1,2,1,'\\ ','maplesyrupdeals\racer 4pin1.25 6cm'),(7854,0,230650488078,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.01,'eastar4','jerryrig1947','jerntam@bridgemail.com','Jerry Switzer','232 Caliente Avenue','Twin Falls','ID','UNITED STATES','83301-9282','(208) 734-3851','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 02:42:04',0,NULL,3,1,1,1,'\\ ','jerryrig1947'),(7855,551310255003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',13.45,'cnfaner','sdiodato','sdiodato@juno.com','Scott Diodato','816 Windridge Ln','Downingtown','PA','UNITED STATES','19335','(610) 269-0404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-25 02:44:30',0,NULL,3,1,1,1,'、 ','sdiodato'),(7856,8881311563966101,111,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',0,'eastar4','ezjeff1100','gogetjeff2003@yahoo.com','Gerardo Rodriguez Jr.','5155 Havering Way<br>  ','Woodbridge','VA','UNITED STATES','22193-4932','(703) 869-3872',NULL,NULL,NULL,NULL,0,NULL,5,0,18,0,NULL,''),(7857,0,220817721843,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.02,'eastar4','jcgobanza','justin.clarke@gmail.com','Justin Clarke','425 1st St<br>Unit 2505','San Francisco','CA','UNITED STATES','94105-4628','(415) 683-6722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 03:25:12',0,NULL,3,1,1,1,'、 ','jcgobanza\r一共买了两个'),(7858,740791672011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','budweiser92025','bud_white@sbcglobal.net','Loring White','3320 Jasmine Pl','Escondido','CA','UNITED STATES','92025-7604','(760) 741-0922','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 03:27:14',0,NULL,3,1,1,1,'\\ ','budweiser92025'),(7859,740083109011,320394934550,'Acer Aspire 6920 6920G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',12.5,'eastar4','convsx','enunez@pixelgate.net','Edward Nunez','1655 Fremont Dr.','Thousand Oaks','CA','UNITED STATES','91362','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 03:29:32',0,NULL,3,1,1,1,'\\ ','convsx\racer 8pin0.8 16cm '),(7860,822290513012,220501826030,'2.1 Acer Aspire 4730Z 4930Z Bluetooth Module EDR+cable',1,'BTAC2120',12.4,'eastar4','hamrules','johnschwinn@hotmail.com','John Schwinn','7813 W Bottsford Avenue','Greenfield','WI','UNITED STATES','53220','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 03:32:22',0,NULL,3,1,1,1,'、 ','hamrules\racer 8pin1.0 6cm'),(7861,605509148013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','buynow2k','tri_trinh@yahoo.com','Tri Trinh','7536 Axton St','Springfield','VA','UNITED STATES','22151-2603','(703) 606-8454','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-25 03:35:29',0,NULL,3,1,1,1,'\\ ','buynow2k'),(7862,0,320731881748,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.04,'eastar4','best_online_gear','phoneguy4repair2@yahoo.com','Seth Shapiro','1307 157th St','Whitestone','NY','UNITED STATES','11357-1968','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 04:09:14',0,NULL,3,1,1,1,'\\ ','best_online_gear\r一共买了四个'),(7863,0,230650488127,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.03,'eastar4','mngo2166','m.ngo@hilevel.com','Hilevel Tech att. Minh Ngo','17805 Sky Park Cir<br>Ste E','Irvine','CA','UNITED STATES','92614-6108','(949) 263-8577 ext.: 23','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 04:29:00',0,NULL,3,1,1,1,' \\','mngo2166\r一共买了三个\r\r新地址\rMinh Ngo\r2026 W Hemlock Way\rSanta Ana CA 92704-6124\rUnited States\r'),(7864,0,230650488051,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.01,'eastar4','ibmphanphan','phanphanibm@gmail.com','Phan Phan','5826 N Cicero Ave','Chicago','IL','UNITED STATES','60646-6656','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 04:32:10',0,NULL,3,1,1,1,'\\ ','ibmphanphan'),(7865,740798187011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','klimaxsaga','klimax@live.jp','MASAKI TAKIGAWA','Kanzaki-chou Kanzaki<br>496','Kanzaki','Saga','JAPAN','842-0001','090-2197-1576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 04:35:10',0,NULL,3,1,2,1,'\\ ','klimaxsaga'),(7866,0,230650488339,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.2,'eastar4','unix_core','themadlion2002@yahoo.com','Christopher Witthaus -  HCRC','2625 Michigan Ave','Saint Louis','MO','UNITED STATES','63118-1213','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 04:35:55',0,NULL,3,1,1,1,'、 ','unix_core\r一共买了两个'),(7867,0,220817721749,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','digibaublesla','p1a5244@gmail.com','Richard Westmoreland','240 S Reeves Dr<br>Apt 1','Beverly Hills','CA','UNITED STATES','90212-4036','(310) 858-3855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 05:01:06',0,NULL,3,1,1,1,'\\ ','digibaublesla'),(7868,821673981012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','szrorkn','szrorkn@hotmail.com','ORKUN SEZER','24 Hopkins way<br>Meadow heights','MELBOURNE','Victoria','AUSTRALIA','3048','61413827472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 05:16:40',0,NULL,3,0,2,1,'\\ ','szrorkn\r发210TS 一个'),(7869,740832742011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','webtata','ebay@mw.ro','Niculae Cristian Alexandru','Str. Carpenului nr. 7,<br>Bl. A17, Sc. A, Ap. 27','Brasov','','ROMANIA','500256','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 07:10:55',0,NULL,3,1,2,1,'、 ','webtata'),(7870,822339278012,220747230769,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',11.99,'eastar4uk','noni_62','jl5346@dodo.com.au','Brian Schnabel','C-/- Kempe Supply Group<br>Unit 2, 100 Pipe Rd,','Laverton Nth','Victoria','AUSTRALIA','3026','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 07:35:49',0,NULL,3,1,2,1,'、','noni_62\r只发耳机\r不带电源'),(7871,822341212012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','leo_alqd','team_al-qaeda@hotmail.com','leonardo hernan burgos','humahuaca 62','san salvador de jujuy','jujuy','ARGENTINA','4600','54-0388-4221186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 07:38:44',0,NULL,3,1,3,1,'RA183616277CN ','leo_alqd\rOTSO004*2\r申报35 美金'),(7872,740835571011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','atias007','tsahiatias@gmail.com','Tsahi Atias','Zabutinski 50/1103','Givaat Shmuel','','ISRAEL','54010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 07:39:37',0,NULL,3,1,2,1,'、 ','atias007'),(7873,740839602011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','davidaquilina','david.aquilina@live.com.au','david aquilina','12 graham st greystanes','sydeny','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-25 07:43:44',0,NULL,3,1,3,1,'RA183616189CN\r ','davidaquilina\rOTSO004*2'),(7874,822348412012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','prozzerg','arnell.fredrik@home.se','Arnell Fredrik','Ranterigrand 1<br>C','Jonkoping','','SWEDEN','55320','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 08:07:15',0,NULL,3,1,2,1,'、 ','prozzerg'),(7875,605548311013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','fernandoauk','fernandoauk@gmail.com','Fernando Kursancew','Rua Dhalia, 353. Apto 1101.<br>Boa Viagem','Recife','Pernambuco','BRAZIL','51020290','8187572212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 08:11:27',0,NULL,3,1,2,1,'、 ','fernandoauk'),(7876,556089120004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','vandapa1','vandapa@freemail.hu','Gyula Foldy','Keglevich út 18.','Pétervására','','HUNGARY','3250','0036703643792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 08:15:01',0,NULL,3,1,3,1,'RA183616192CN\r ','vandapa1\rHSNO022\r欧标'),(7877,822354545012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',10.99,'eastar4uk','ianhomes','ian_112-toby@tiscali.co.uk','Ian Dowsett','112 Tobyfield Road<br>Bishops Cleeve','Cheltenham','Gloucestershire','UNITED KINGDOM','GL52 8PG','01242679968','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 08:31:13',0,NULL,3,1,3,1,'RA183616285CN\r ','ianhomes\rMOMI002\r极动鲨 鼠标\r'),(7878,822370756012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','adriang76','adriang76@o2.pl','Adrian Gorski','Flat 8 Floris Court<br>15 Knole Road','Bournemouth','Dorset','UNITED KINGDOM','bh1 4DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 09:34:49',0,NULL,3,1,3,1,'RA183616396CN\r ','adriang76\rHSPL011\r英标'),(7879,822370742012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','arabadmiral','q8wait@hotmail.com','Naser Al Otaibi  KWI 515','1618 Yishan Rd Building C 1/F Minhang District','Shanghai , 201103','上海','CHINA','201103','+862 6163 5511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 09:36:22',0,NULL,3,1,15,1,'368849476183 ','arabadmiral\rOTRA001\r客户的中文地址\rNaser Al Otaibi  KWI 515\r宜山路1618号\rC栋1楼\r闵行区  201103\r上海 \r电话：02161635511\r申通\r\r'),(7880,821705678012,220663959909,'New Intel 512ANX 5150 HMW Half Mini PCI-E WIFI Card',1,'WLIN004',19.6,'eastar4','linden178','linden198@gmail.com','Denis Nyanchenko','Kresnoarmeyskaya st., 65','Artemovsk','Donetsk','UKRAINE','84503','38-050-6441320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 09:44:30',0,NULL,3,1,2,1,'\\ ','linden178\r半高卡 新的'),(7881,822375959012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','mmoli_es','molines.publi@ono.com','Manuel Molines Muñiz','Avda. Santander, 3 - 2C','SOLARES','Cantabria','SPAIN','39710','652941827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 09:54:39',0,NULL,3,1,3,1,'RA183616422CN\r ','mmoli_es\rOTRA001'),(7882,822378733012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','mikejvf','hotmikej@hotmail.com','Mihhail Fjodorov','Anne 87-41','Tartu','','ESTONIA','50705','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 10:06:35',0,NULL,3,1,2,1,'\\ ','mikejvf\r欧标'),(7883,822385505012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','nylundp','patrik@bones-junior.com','Patrik Nylund','Svanekegränd 1','KISTA','KISTA','SWEDEN','16446','(070) 7740498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 10:28:11',0,NULL,3,1,2,1,'\\ ','nylundp'),(7884,822398176012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','poplar_mark','mark@poplarhouse.net','Mark Scott','Poplar House, Poplar Close, Sherfield on Loddon','Hook','Hampshire','UNITED KINGDOM','RG27 0DX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 11:09:25',0,NULL,3,1,2,1,'\\ ','poplar_mark\racer 8pin1.00 8cm'),(7885,822378628012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','zr850329','alligator2008@hotmail.co.uk','Rui Zhang','27<br>Litcham Close','Manchester','Lancashire','UNITED KINGDOM','M1 7JW','01612732927','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 11:22:29',0,NULL,3,1,3,1,'RA183616440CN\r ','zr850329\rHSPL011\r英标'),(7886,822408681012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','stannislavz','stanislav_26@yahoo.com','Stanislav Zhelyazkov','860 Cross Creek Dr N<br>Apt BB1','Roselle','IL','UNITED STATES','60172-3662','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 11:43:39',0,NULL,3,1,1,1,'\\ ','stannislavz'),(7887,740897190011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','bankids62','bankids@hotmail.com','Min Kang','18 Leach ave','riverton','Western Australia','AUSTRALIA','6148','0402736958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 11:51:59',0,NULL,3,1,2,1,'\\ ','bankids62'),(7888,822421470012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',77.9,'eastar4uk','peteyg272','petegg@rocketmail.com','Peter Greenhalgh','Treasure Transport Services Limited<br>Triangle Park, Gonerby Moor,','Grantham','Lincs','UNITED KINGDOM','NG32 2BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 12:23:23',0,NULL,3,1,3,1,'RA183616609CN\r ','peteyg272\rRCMA001'),(7889,0,320731885255,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.01,'eastar4uk','w-i-z-a-r-d-s-m-a-g-i-c','orientalmwt@gmail.com','Matthew Tanner','37 Borough Road','Mitcham','Surrey','UNITED KINGDOM','CR43DX','07772122456','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-25 13:12:53',0,NULL,3,1,3,1,'RA183616325CN\r ','w-i-z-a-r-d-s-m-a-g-i-c\rANCN001'),(7890,605615530013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','shavlik733','gmbu0212@yahoo.com','Greg Butler','10501 Deepbrook Dr','Riverview','FL','UNITED STATES','33569-5782','(813) 728-8418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 13:49:00',0,NULL,3,1,1,1,'\\ ','shavlik733\rCAB-6060'),(7891,821189328012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','icplg2','leogerritsen@gmail.com','Roungtawan Rakkratok','14/ 1 moo 5 Phetlakorn<br>Nong Phai','Phetchabun','','THAILAND','67140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 14:19:14',0,NULL,3,1,2,1,'\\ ','icplg2\rNEW Apple Atheros AR9280 AR5BXB92+ANTENNA*2\r '),(7892,822469948012,220565577390,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',16.99,'eastar4','clever-sellers','info@clever-mediagroup.de','CLEVER MEDIAGROUP','Christian Clever<br>Heerdter Landstrasse 245','Düsseldorf','','GERMANY','40549','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 14:45:08',0,NULL,3,1,2,1,'\\ ','clever-sellers'),(7893,740958489011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','diego2v2011','diego_2v@hotmail.com','Diego Valdivia Valdez','Urb Valencia C9 Umacollo Yanahuara','Arequipa','Arequipa','PERU','054','05154251882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 14:53:23',0,NULL,3,1,3,1,'RA183616524CN\r ','diego2v2011\rGLSG001*2'),(7894,740958434011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','bag1069barbara','bgraham1069@windstream.net','Barbara Graham','2530 Bathgate Ln','Matthews','NC','UNITED STATES','28105-2343','(704) 507-5937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 14:56:52',0,NULL,3,1,1,1,'\\ ','bag1069barbara'),(7895,822479589012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','wannaberedneck','omgitshim@zoho.com','Donald Everson','1781 County Road 205','Jack','AL','UNITED STATES','36346-5129','(334) 282-3561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 15:12:57',0,NULL,3,1,1,1,'\\ ','wannaberedneck'),(7896,740967389011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','eyal_oren','indiferent@013.net.il','eyal oren','11 Vital st. App 29','tel aviv','','ISRAEL','66088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 15:19:14',0,NULL,3,1,2,1,'\\ ','eyal_oren'),(7897,740967410011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','grimes-atl','mngrimes@bellsouth.net','Michelle Grimes','3429 Elm Creek Dr NW','Marietta','GA','UNITED STATES','30064-1131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 15:19:15',0,NULL,3,1,1,1,'\\ ','grimes-atl'),(7898,822483527012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',25.65,'eastar4','mrsportman','watanachai_w@yahoo.com','Watanachai Wanichakornkul','13B  Garnett  Pl','Balga','Western Australia','AUSTRALIA','6061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 15:19:59',0,NULL,3,0,2,1,'\\ ','mrsportman\r发210TS三个'),(7899,556135739004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',3,'HSNO003',197.4,'cnfaner','gihad1995','preetyprincess62@yahoo.com','gihad hussein','14314 w e st','kerman','CA','UNITED STATES','93630-1961','(559) 842-5551','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-25 16:01:34',0,NULL,3,1,1,1,'\\ ','gihad1995\r一共买了六个'),(7900,740992099011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','akkaniclas','niclas.granstrom@gmail.com','Niclas Granström','Arlavägen 14','Jönköping','Jönköping','SWEDEN','55466','0768773248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 16:26:04',0,NULL,3,1,2,1,'\\ ','akkaniclas'),(7901,740995970011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','mbimad1011','info@choice-apex.com','s.c.jones','5 the cleevelands<br>Cleevelands drive','Cheltenham','Gloucestershire','UNITED KINGDOM','GL50 4QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 16:38:09',0,NULL,3,1,3,1,'RA183616334CN\r ','mbimad1011\rRELO003\r红边优联'),(7902,822519338012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',7.9,'eastar4','dpelectronicsinc','dp2kelectronics@yahoo.com','DP\'S ELECTRONICS, INC.','4891 Buford Hwy','NORCROSS','GA','UNITED STATES','30071-2703','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 16:42:28',0,NULL,3,1,1,1,'\\ ','dpelectronicsinc\r旧的'),(7903,740999300011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','raekone','mr_keshani@hotmail.com','Amar Keshani','101 Summer St<br>Unit 305','Stamford','CT','UNITED STATES','06901-2326','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 16:42:45',0,NULL,3,1,1,1,'\\ ','raekone'),(7904,822521731012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',10.99,'eastar4uk','oliw680','winter.oli@gmail.com','Oliver Winter','Mitterweg 10','ALTENBERG','','AUSTRIA','4203','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 16:51:01',0,NULL,3,1,2,1,'\\ ','oliw680\r极动鲨 mouse'),(7905,605664059013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','djfatu','djfatu@terra.com.br','Flavio Ricardo Bortolin Romão','Av. Pompéia, 1380 - Apt 73<br>Perdizes','Sao Paulo','São Paulo','BRAZIL','05022-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 16:52:03',0,NULL,3,1,2,1,'\\ ','djfatu'),(7906,702519305001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',32.99,'buysia','tommtomm82','friedlthomas@yahoo.de','Thomas Friedl','Von-Sauer-Str. 31 e','Hamburg','','GERMANY','22761','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 16:54:24',0,NULL,3,1,3,1,'RA183616351CN\r ','tommtomm82\rBR3D006'),(7907,741000069011,320511210812,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',42.99,'eastar4','nikusrr','jimi-nikus@mail.ru','Nikita Repin','Tuhachevskogo<br>28-40','Samara','Samarskaya oblast\'','RUSSIAN FEDERATION','443082','(917) 147 - 8688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 16:57:40',0,NULL,3,1,3,1,'RA183616379CN\r ','nikusrr\rWWSI004'),(7908,822528494012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','romanromanov','art-roman@mail.ru','Roman Romanov','Aviahima, 53/3, 4','Kazan','Tatarstan','RUSSIAN FEDERATION','420073','+7 (905) 377-9070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 17:02:42',0,NULL,3,1,2,1,'\\ ','romanromanov'),(7909,741028794011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','bartsijtsma','bart.sijtsma@gmail.com','Bart  Sijtsma','Zeilenmakersgilde 31','Dronten','Flevoland','NETHERLANDS','8253 GH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 17:48:45',0,NULL,3,1,2,1,'\\ ','bartsijtsma'),(7910,741063033011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','lines.randall','lines_randall@yahoo.com','Bruce St John','610 Briar Creek Dr','La Porte','TX','UNITED STATES','77571-2704','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 18:51:39',0,NULL,3,1,1,1,'\\ ','lines.randall'),(7911,551509214003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.9,'cnfaner','ivo12*s','ivo.scuka@akvanet.cz','Ivo ŠČUKA','Paťanka 2616/15','PRAHA','','CZECH REPUBLIC','16000','+420602610558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:18:03',0,NULL,3,1,3,1,'RA183616317CN\r ','ivo12*s\rWWOT003\r通用版'),(7912,741087912011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','chaiyo_1982','dd_a72@yahoo.com','Somphop  Achawakijkoson','550/6  Soi Pho-Pun<br>Asok-Dindang Rd,','Dindang','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:37:51',0,NULL,3,1,2,1,'\\ ','chaiyo_1982'),(7913,605725823013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','pink123shawn','sandraroberts41@hotmail.com','sanda roberts','150 willow st','truro','NS','CANADA','b2n 4z6','(902) 843-6127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:38:25',0,NULL,3,1,3,1,'RA183616515CN ','pink123shawn\rGLOT001*3\r兼容型3D眼镜 通用型\r'),(7914,741090146011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.4,'eastar4','dleeecl','dleeecl@hotmail.com','LEE SUI HONG','Rm 601, 108 Java Road, North Point','default','','HONG KONG','default','(852) 275-7100 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:42:50',0,NULL,3,1,2,1,'\\ ','dleeecl\rHP 8pin 1.0 23cm '),(7915,702606918001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','carin_09','oscarlopez_00@yahoo.com','Oscar Lopez','5773 Paso Real Dr','Brownsville','TX','UNITED STATES','78521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 20:02:00',0,NULL,3,1,1,1,'\\ ','carin_09'),(7916,741104333011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','golden-calf','max0583@o2online.de','Irene Huck','Greifswalder Straße 57','Bielefeld','','GERMANY','33605','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 20:10:56',0,NULL,3,1,2,1,'\\ ','golden-calf'),(7917,741109539011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','martin-vestergaard','martin@vestergaard-kristiansen.dk','Martin Vestergaard Kristiansen','Teglgårdsvej 31','Århus','Højbjerg','DENMARK','8270','86113675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 20:20:15',0,NULL,3,1,2,1,'\\ ','martin-vestergaard'),(7918,741121062011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',38.99,'eastar4uk','marlon1503','m.m.gomes@qmul.ac.uk','Marlon Gomes','82 Hillside Avenue','Woodford Green','Essex','UNITED KINGDOM','IG8 7RN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 20:44:00',0,NULL,3,1,3,1,'RA183616590CN\r ','marlon1503\rGLSG001'),(7919,822656516012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','proszper','proszper@freemail.hu','László Kiss','Középszer u. 62. 8/2','Miskolc','','HUNGARY','3529','+36209154854','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 20:55:17',0,NULL,3,1,2,1,'\\ ','proszper\r欧标'),(7920,741139832011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',107.99,'eastar4uk','delirium_of_disorder','ben_633@hotmail.com','Ben Ratcliffe','Apartment 22, Junction House<br>Dale Way','Crewe','Cheshire','UNITED KINGDOM','CW1 3GU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 21:26:42',0,NULL,3,1,3,1,'RA183616586CN\r ','delirium_of_disorder\rGLSG001*3'),(7921,605771299013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',95,'eastar4','speratics','raulhinojosajr@gmail.com','Raul Hinojosa Jr','10003 Forum West Dr<br>Apt 332','Houston','TX','UNITED STATES','77036-8352','(708) 220-6449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 21:53:23',0,NULL,3,1,1,1,'\\ ','speratics'),(7922,551559380003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','pariquera','felipe_capetown@yahoo.com','Felipe Allegretti','Rua Romualdo Lopes Cançado, 834<br>Bloco 3 - Apto 101','Belo Horizonte','Minas Gerais','BRAZIL','30840-460','(19) 34348407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 21:56:14',0,NULL,3,1,3,1,'RA183616382CN\r ','pariquera\rBALO007'),(7923,551560086003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',17.99,'cnfaner','reelchlg','reelchlg@optonline.net','steve galimi','4218 throgsneck expwy','bronx','NY','UNITED STATES','10465','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-25 21:59:41',0,NULL,3,1,1,1,'\\ ','reelchlg'),(7924,551341740003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',66.9,'cnfaner','actionjacksonwould','ben.emery@mail.com','ben emery','7/938 south rd','edwardstown','South Australia','AUSTRALIA','5038','0882971255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 22:07:56',0,NULL,3,1,3,1,'RA183616348CN\r ','actionjacksonwould\rMOSA003'),(7925,822689008012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','tox87','nettrek@adam.com.au','Leonid Turczynowicz','9 Beaconsfield Street<br>Hyde Park','Adelaide','South Australia','AUSTRALIA','5061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 22:09:26',0,NULL,3,1,2,1,'\\ ','tox87'),(7926,741157613011,320730084018,'Cisco PVDM2-16 16 Channel Packet Voice DSP Module',3,'OTIN005',149.97,'eastar4uk','jpatje','jpatje@hotmail.co.uk','Juliet Patje','78 Emma Road<br>Plaistow','London','London','UNITED KINGDOM','E13 0DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 22:18:03',0,NULL,3,1,3,1,'RA183615965CN\r ','jpatje\rOTIN005'),(7927,822701871012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','buff85','buffruss85@yahoo.com','Russell Buffington','26722 Wedgewood Park','Cypress','TX','UNITED STATES','77433-1292','(281) 256-0617','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 22:46:56',0,NULL,3,1,1,1,'\\ ','buff85\r兼容型3D眼镜 通用型'),(7928,557139864004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56,'cnfaner','cbesseli','chris.besseling@home.nl','Chris Besseling','Schoolstraat 108','Belfeld','','NETHERLANDS','5951 CR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 22:48:07',0,NULL,3,1,3,1,'RA183616453CN\r ','cbesseli\rWWSI006  新的\r'),(7929,741179923011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','briann773','cmammo13@aol.com','Brian Nix','357 E Shady Pines Ct','Palatine','IL','UNITED STATES','60067-8800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 23:36:11',0,NULL,3,1,1,1,'、 ','briann773'),(7930,557149339004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',32.9,'cnfaner','nycprincezzz26','nasreennazia@gmail.com','Nazia Nasreen','2338 Newbold Ave','bronx','NY','UNITED STATES','10462-5320','(914) 689-5069','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-25 23:40:29',0,NULL,3,1,1,1,'\\ ','nycprincezzz26'),(7931,0,320731885235,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.01,'eastar4uk','netbook-spares','netbookspares@euro-switch.co.uk','DAVID TURNER','16 TALLY CLOSE','STOKE ON TRENT','Staffordshire','UNITED KINGDOM','ST20SR','01782595477','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-26 00:09:51',0,NULL,3,1,3,1,'RA183616365CN\r ','netbook-spares\rANCN001'),(7932,822731101012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','dumbarton11','ldeangelo@hotmail.com','Lawrence J. DeAngelo','3811 Dumbarton Rd NW','Atlanta','GA','UNITED STATES','30327-2619','(404) 841-5573','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 00:28:33',0,NULL,3,1,1,1,'\\ ','dumbarton11'),(7933,741197485011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.94,'eastar4','jmd608','jdumlao3@gmail.com','Jessie Dumlao','12834 24th Ave So','Seatac','WA','UNITED STATES','98168','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 00:45:27',0,NULL,3,1,1,1,'\\ ','jmd608'),(7934,741192382011,320730085617,'New Atheros AR5008 802.11N Wireles WiFi Mini PCI-E Card',5,'WLAT001',55,'eastar4uk','musfiar2011','musfiar@denka.co.id','harry musfiar','gd. MGG lantai 3. suite 8. Jl. Margaguna Raya No. 9.','default','JK','INDONESIA','12420','62817891167','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 00:52:27',0,NULL,3,1,3,1,'RA183616436CN\r ','musfiar2011\rWLAT001\r新的'),(7935,684932529008,180699061462,'New Jabra BT250 FreeSpeak Bluetooth Headset',5,'HSJA002',109.95,'au-buy','aulakh1982','b4u_payal@hotmail.com','Mandeep AUlakh','#102 -30505 Blueridge Drive','Abbotsford','BC','CANADA','V2T0B1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-26 01:02:14',0,NULL,3,1,3,1,'RA183616405CN\r ','aulakh1982\rHSJA002'),(7936,605814705013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','emmeryc','emmerycheung@gmail.com','Emmery Cheung','7 cortleigh crt','Richmond Hill','ON','CANADA','l4b3g9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 01:19:35',0,NULL,3,1,2,1,'\\ ','emmeryc\r新的'),(7937,0,320731881647,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.01,'eastar4','1r1','shoprg@rocketmail.com','Ronald Reed','4432 Telegraph Ave<br># D','Oakland','CA','UNITED STATES','94609-2018','(510) 715-5833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 01:28:35',0,NULL,3,1,1,1,'\\ ','1r1'),(7938,741210259011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','melo_arte','melo_arte@hotmail.com','Carmelo Ocasio','131 Calle Rosa Vega<br>Bo Barahona','Morovis','PR','UNITED STATES','00687-2114','(787) 515-7824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 01:37:15',0,NULL,3,1,1,1,'\\ ','melo_arte\racer 8pin1.00 15cm '),(7939,822784451012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','air-ocean','air-ocean-so@ya.ru','Viacheslav Dorogaykin','Astrahanskaya 11-49','Krasnoyarsk','','RUSSIAN FEDERATION','660037','902-9235388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 03:46:14',0,NULL,3,0,2,1,'\\ ','air-ocean\r再发一个New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card\r'),(7940,822785049012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','air-ocean','air-ocean-so@ya.ru','Viacheslav Dorogaykin','Astrahanskaya 11-49','Krasnoyarsk','','RUSSIAN FEDERATION','660037','902-9235388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 03:48:56',0,NULL,3,1,17,0,NULL,'air-ocean'),(7941,741242637011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','rkyokota','rkyokota@gmail.com','Roberto Yokota','Rua Oscar Freire, 1735<br>ap. 121','São Paulo','SP','BRAZIL','05409-011','5511 30688320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 03:57:51',0,NULL,3,1,2,1,'\\ ','rkyokota'),(7942,605845602013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','steelhead1986','atheist@hotbox.ru','Vadzim A Zhuk','Zaslonova st. 11/20','Gantsevichi','Brest region','BELARUS','225432','298347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 04:09:55',0,NULL,3,1,2,1,'\\ ','steelhead1986'),(7943,548680636003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',31.95,'cnfaner','nadamsmd','nadamsmd@pacbell.net','Neal Adams','3055 Dana St<br>Apt 2','Berkeley','CA','UNITED STATES','94705-2062','(408) 591-2110','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 04:30:27',0,NULL,3,1,1,1,'\\ ','nadamsmd\r旧的 '),(7944,605848999013,230520213346,'New Intel 5300 AGN half size wireless Mini PCI-E Card',5,'WLIN009',79.95,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 04:33:01',0,NULL,3,1,3,1,'RA183616475CN\r ','saiajin77\rWLIN009\r全高卡新的\r\r\r'),(7945,741250011011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',35.98,'eastar4','ziadhosany','ziad.hosany@yahoo.com','MR MOHAMMAD ZIAD HOSANY','88, Western Boundary,<br>La Rue Vel Murugen','Quatre-Bornes','Plaines Wilhems','MAURITIUS','230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 04:53:30',0,NULL,3,1,3,1,'RA183616538CN\r ','ziadhosany\rSHLO002\r一共买了两个'),(7946,741253919011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',8.99,'eastar4','galewaves506','glick.eliot@gmail.com','Gudiya Ale','Mantri Elegance, Suite B-506<br>(Next to Shoppers Stop)','Bangalore','KA','INDIA','560076','9945575575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 05:01:42',0,NULL,3,1,2,1,'\\ ','galewaves506'),(7947,741255453011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','techspringclean','onlinesalesemails@googlemail.com','Mehmood Khan','3 Swanley House<br>Grant Road,','Wealdstone, Harrow','Middlesex','UNITED KINGDOM','HA37SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-26 05:11:24',0,NULL,3,1,3,1,'RA183616467CN\r ','techspringclean\rUDAP001'),(7948,741274620011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','areamihc','chiachong@gmail.com','Jason Tay','Suite 1, Level 5<br>No. 1 Oxford Street','Darlinghurst','New South Wales','AUSTRALIA','2010','020423008889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 07:02:20',0,NULL,3,1,2,1,'\\ ','areamihc'),(7949,822825818012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',39,'eastar4uk','raytansg','tanfreeman@yahoo.com.sg','Tan Jian Zhang','190 Joo Chiat Terrace<br>#05-02','Singapore','','SINGAPORE','427336','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 07:21:36',0,NULL,3,1,3,1,'RA183616657CN\r ','raytansg\rHSPL009'),(7950,741278805011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',17.4,'eastar4','the_pastafarian','boekenkast@gmail.com','leo van der Schans','Wijckermolen 86','beverwijk','','NETHERLANDS','1941JA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 07:27:26',0,NULL,3,1,2,1,'\\ ','the_pastafarian'),(7951,822833271012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','shpunt1','well.israel@gmail.com','Gil Shpunt','st. Tlamim 5 / 10','Lod','Ganey-Aviv','ISRAEL','71452','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 07:50:30',0,NULL,3,1,2,1,'\\ ','shpunt1'),(7952,822841876012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','philcharles','phil.charles@uk.renaultf1.com','Phil Charles','Formula Fast Ltd, Unit 1<br>19 Wildmere Road Industrial Estate','Banbury','Oxfordshire','UNITED KINGDOM','OX16 3JU','07747636267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-26 08:30:46',0,NULL,3,1,3,1,'RA183616626CN\r ','philcharles\rOTCN004*10'),(7953,605882361013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','wmhwar','wmhasbullah@gmail.com','WAN MOHD HASBULLAH WAN ABDUL RAHMAN','4950 KG. TELUK PASU<br>MANIR','KUALA TERENGGANU','TERENGGANU','MALAYSIA','21200','0137977032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 08:39:05',0,NULL,3,1,2,1,'\\ ','wmhwar'),(7954,8881311672705287,111,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'',16.99,'eastar4','bianca07*123','biancamcasey@hotmail.com','Bianca McAsey','1/17 Ballarter StreetEssendon','Melbourne','Victoria','AUSTRALIA','3040 ','',NULL,NULL,NULL,NULL,0,NULL,3,0,2,1,'\\ ','补发的\r紫色的 \rUMTR001\r已入库 '),(7955,0,220817721911,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.24,'eastar4','intellact','intellact12@gmail.com','Tad Bednarczyk','1921 W Crestview Cir','Romeoville','IL','UNITED STATES','60446-2804','(186) 676-7266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 09:56:02',0,NULL,3,1,1,1,'、 ','intellact\r一共买了二十四个'),(7956,685013045008,180699061296,'New geuine Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',94.96,'au-buy','underwood786','mobilerepairs@bigpond.com','Faisal Koya','P. O. Box 292<br>Underwood','Brisbane','Queensland','AUSTRALIA','4119','0732197444','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 11:37:59',0,NULL,3,1,3,1,'RA183616612CN ','underwood786\r澳标\rHSJA011+HSJA001+HSJA005\r再发一个New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V\r和两个\rNew in box Jabra BT-2080 Wireless Bluetooth Headset\r'),(7957,822898320012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',2,'UM00008',49.98,'eastar4','cstleo777','tileugazyrakhimbaev@gmail.com','Tileugazy Rakhimbaev','13 microdistrict, 21-61','Karaganda','Karagandinskaya','KAZAKHSTAN','100018','+77773100102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 11:53:27',0,NULL,3,1,3,1,'RA183616970CN\r ','cstleo777\r24K 多色伞\rUM00008'),(7958,822404024012,220807272254,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',19.99,'eastar4','doublelp636','liv.lpop@yahoo.com','Livia L.POP','12 Bexley way,Girrawheen','Perth','Western Australia','AUSTRALIA','6064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 12:15:24',0,NULL,3,1,2,1,'\\ ','doublelp636\r美女涂鸦伞 '),(7959,741354039011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',2,'RELO002',25.94,'eastar4','benlikesturtles','ben_terrill@yahoo.com','Ben Terrill','18a Noone Street<br>Clifton Hill','Melbourne','Victoria','AUSTRALIA','3068','0400435460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:28:53',0,NULL,3,1,2,1,'\\ ','benlikesturtles'),(7960,551701381003,130466041506,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',60,'cnfaner','themac82sa','richardsa82@gmail.com','Richard McIntyre','2 Dorchester Road<br>Charlo','Port Elizabeth','Eastern Cape','SOUTH AFRICA','6000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:48:05',0,NULL,3,1,3,1,'RA183616762CN\r ','themac82sa\rWWSI006+ANCN001'),(7961,822904591012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','donnybrasco187','ali_masoudi_187@yahoo.de','Ali Masoudi Alavi','Hohenstaufenstr. 1','Koblenz','','GERMANY','56075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 13:32:38',0,NULL,3,1,3,1,'RA183616688CN\r ','donnybrasco187\rWWOT003\r通用版新的'),(7962,557282175004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',29.9,'cnfaner','pepcio1970','pepcio_ebay@o2.pl','Andrzej Pietrzak','Wieniawskiego 8/60','Konin','wielkopolskie','POLAND','62507','48 5092384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 14:06:58',0,NULL,3,1,3,1,'RA183616731CN\r ','pepcio1970\rWWSI002\rIBM版'),(7963,822946352012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','uncut7777','brainscape@naver.com','404-763Han Jae Cho','122 Dong - 407 Ho, Jugong Apt. 2-Danji Gajwa 4-dong, Seo-gu','Incheon','','KOREA,REPUBLIC OF','404-763','82-10-3344-4529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 14:24:01',0,NULL,3,1,2,1,'\\ ','uncut7777'),(7964,741396447011,320701927743,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',65.9,'eastar4','cashudara','cash.udara@axpro.co.cc','Mochamad Agung','Kav. Paledang II no.8','Bandung','West Java','INDONESIA','40617','6285860460006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 14:43:41',0,NULL,5,1,18,0,' ','cashudara\rHDSG001 paypal 付款有问题'),(7965,820361582012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',110,'TRMX003',940.5,'eastar4','jrnotocca','jrnoto_cca@hotmail.com','Alexandre Herrero','1553 SW 137th Ct<br>Merlion Exchange Corp','Miami','FL','UNITED STATES','33184-2724','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-07-26 14:54:09',0,NULL,3,0,4,1,'YW866475245CN','jrnotocca\r我剪得是210TS\r已入库\r客户已确认发210S'),(7966,740793047011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','thagenda','gottlucky@gmail.com','Thayer Luckette','9574 Lakeview Cir','Union City','GA','UNITED STATES','30291-6018','(305) 934-0099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 15:07:29',0,NULL,3,1,1,1,'、 ','thagenda'),(7967,821650305012,220807272265,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',2,'UM00010',47.98,'eastar4','supernatural_01','iamichelle@hotmail.com','Michelle Facchini','2/4 crown St','Batemans bay','New South Wales','AUSTRALIA','2536','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 15:33:56',0,NULL,3,1,3,1,'RA183616966CN ','supernatural_01\rUM00010\r钢琴美女伞 '),(7968,605969833013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','felorojas','feliperojase@hotmail.com','Hyatt Regency Bellevue - Felipe Rojas','900 Bellevue Way NE','Bellevue','WA','UNITED STATES','98004-4206','(425) 462-1234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 15:49:28',0,NULL,3,1,1,1,'、 ','felorojas'),(7969,741275277011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','adjenkinsuk','andrew.jenkins@dsl.pipex.com','Andrew Jenkins','13 Church Street','Bargoed','Mid-Glam','UNITED KINGDOM','CF81 8RN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-26 16:09:17',0,NULL,3,1,3,1,'RA183616691CN\r ','adjenkinsuk\rOMHJ001'),(7970,741436923011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','looking2buyu','juiceboxxsnc@hotmail.com','James Barbour','621 Midvale Ave<br>Apt 3','Los Angeles','CA','UNITED STATES','90024-2316','(626) 833-2437','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 16:39:48',0,NULL,3,1,1,1,'、 ','looking2buyu'),(7971,823005106012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','cthulhu.from.omsk','flash.tl@mail.ru','Tamara Frolova','Energetikov 68, 116','Omsk','Omsk','RUSSIAN FEDERATION','644088','89059416525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 17:00:47',0,NULL,3,1,3,1,'RA183616714CN\r ','cthulhu.from.omsk\rOTSO004*2\r盒装的'),(7972,605992216013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','terrywijaya','terry_wijaya@ymail.com','Terry Wijaya','Jalan Dadali no.25 - 27','Bandung','West Java','INDONESIA','40184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 17:05:59',0,NULL,3,1,2,1,'\\ ','terrywijaya'),(7973,823016364012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','marcelogari','marcelo.gari@hotmail.com','Marcelo Augusto Pinto de Magalhães','Rua Joaquim Meier 121 apt 401 Meier','Rio de Janeiro','Rio de Janeiro','BRAZIL','20725-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 17:13:37',0,NULL,3,1,2,1,'\\ ','marcelogari'),(7974,741319354011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',12,'CCGR001',82.56,'eastar4','le_coq','m.tellawi@live.com','mohammad h altellawi','18221 150th Ave<br>JED 15001','springfield gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 17:29:52',0,NULL,3,1,1,1,'、 ','le_coq'),(7975,741495094011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','plum2plum','cindyaccardi@yahoo.ca','Vince Accardi','29 Duckworth St','Toronto','ON','CANADA','M6M 4W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 18:45:27',0,NULL,3,1,2,1,'\\ ','plum2plum'),(7976,823073228012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',3,'OTHP003',34.5,'eastar4uk','zjonesz','zjonesz@lyse.net','Bjørn Vidar Jones','Tuånå 20','Jørpeland','Rogaland','NORWAY','4100','+47 452 50 415','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 18:59:59',0,NULL,3,1,3,1,'RA183616759CN ','zjonesz\rOTHP003'),(7977,741536334011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','linehedstroem','liine-@hotmail.com','Line Hedstrøm','Laurbæråsen 10','Gressvik','','NORWAY','1621','91152280','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-26 20:07:26',0,NULL,3,0,2,1,'\\ ','linehedstroem\r黑色的\r已入库'),(7978,741539893011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','overspace1','rwneild@hotmail.com','Robert Neild','316 Prettyman Dr.<br>Apt. 6101','Rockville','MD','UNITED STATES','20850','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 20:15:19',0,NULL,3,1,1,1,'、 ','overspace1'),(7979,823129529012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','nate8282','nate8282@hotmail.com','Nathan Blevins','1227 Kraft St','Saint Louis','MO','UNITED STATES','63139','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 20:41:41',0,NULL,3,1,1,1,'、 ','nate8282'),(7980,606069166013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','mbilalbhatti','bilalbhatti@bilalbhatti.com','Muhammad Bilal Bhatti','House No A-6, Ghazi Colony<br>Tipu Road, Chaklala','Rawalpindi','Punjab','PAKISTAN','46000','923455929499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 20:49:54',0,NULL,3,1,2,1,'\\ ','mbilalbhatti  再加一个CAB-6060补货\r一共发给客户两个'),(7981,823156606012,220816785876,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',6.9,'eastar4uk','bazbo1','bryanwall@bryanwall.freeserve.co.uk','Bryan Wall','9 Butt Street<br>Brooklyn','Wellington','','NEW ZEALAND','6021','006443899241','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 21:40:43',0,NULL,3,1,2,1,'\\ ','bazbo1'),(7982,740817325011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',35.99,'eastar4','alatsat','alatsat@gmail.com','Yannis Alatsatianos','Adelfon Pouliou 4','Thessaloniki','Thessaloniki','GREECE','54655','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:08:52',0,NULL,3,1,3,1,'RA183616728CN ','alatsat\rWWSI005+ANCN001'),(7983,606092877013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',99.96,'eastar4','neurografismosed','neurografismos@hotmail.com','Eduardo Barrera Arambarri','Adolfo Prieto 138-A4<br>Col. del Valle Norte','Mexico','DF','MEXICO','03103','(521) 552-7559 ext.: 998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:13:58',0,NULL,3,1,3,1,'RA183616665CN ','neurografismosed\rMOAP001\r新的'),(7984,551535801003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','orenjordanaks','oren.j.aks@gmail.com','Oren Aks','18652 Canasta st','Tarzana','CA','UNITED STATES','91356-4115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 22:39:35',0,NULL,3,1,1,1,'、 ','orenjordanaks'),(7985,823182548012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',4,'RELO002',34,'eastar4uk','knightxchange','ebay@knightxchange.co.uk','knight Xchange','88 Green Lane','Addlestone','Surrey','UNITED KINGDOM','KT15 2TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-26 22:53:56',0,NULL,3,1,3,1,'RA183616705CN\r ','knightxchange\rRELO002'),(7986,741602914011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','jopievenom','joostenpatje@casema.nl','J den Hartog','Streefkerkstraat 50','ZOETERMEER','','NETHERLANDS','2729KN','+31(0)610926065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:57:30',0,NULL,3,1,2,1,'\\ ','jopievenom'),(7987,741612403011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',25.99,'eastar4uk','brooschi','brosch_90@hotmail.com','Anwar Rewan','Rödkullegatan 5','Hisings Backa','Västra Götaland','SWEDEN','42244','0046767147079','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 23:40:22',0,NULL,3,1,3,1,'RA183616745CN\r ','brooschi\rWWOT001\r通用版新的'),(7988,685317384008,180699062113,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',1,'GLOT001',53.99,'au-buy','allanb6344','allan@teachinfo.com','Allan Banks','74 Stanley Street','oatlands','Tasmania','AUSTRALIA','7120','0362541237','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 23:41:34',0,NULL,3,1,3,1,'RA183616802CN ','GLOT001\r盒装的\r兼容型3D眼镜 通用型'),(7989,741616566011,320497200017,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',19.88,'eastar4','mspant','espantidakis@gmail.com','EMMANOUIL SPANTIDAKIS','TH. KOLOKOTRONI 15','AGIOS DIMITRIS','ATTICA','GREECE','17343','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 23:49:26',0,NULL,3,0,2,1,'\\ ','mspant\r已入库'),(7990,741621475011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','gaetan551','gaetan.wb@videotron.ca','Gaetan blanchette','2480 boileau','Longueuil','QC','CANADA','J4m2s3','(450) 445-3829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 00:10:05',0,NULL,3,1,2,1,'\\ ','gaetan551'),(7991,823207554012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','juliloko','julilokoaero@hotmail.com','Juliano de Oliveira Neves da Fontoura','Rua Sete de Setembro, 397','Biguaçu','Santa Catarina','BRAZIL','88160-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 00:28:01',0,NULL,3,1,2,1,'、 ','juliloko'),(7992,703099942001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','scubaking503','scubaking503@hotmail.com','Marc Pelletier','68 Ste Anne<br>Appt #1','Ste-Genevieve','QC','CANADA','H9H 2Z1','(514) 784-1504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 01:15:53',0,NULL,3,1,3,1,'RA183616776CN\r ','scubaking503\rBR3D005'),(7993,823225324012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','pathogen311','wpittman@gmail.com','William Pittman','1854 Creely Dr','Birmingham','AL','UNITED STATES','35235-1951','(205) 856-5247','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 01:25:33',0,NULL,3,0,1,1,'、 ','pathogen311\r已入库'),(7994,741640753011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','raada2006','ralkareem@hotmail.com','Raad Alkareem','9 Kookaburra Tce',' Ballajura','Western Australia','AUSTRALIA','6066','0892481670','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 01:28:09',0,NULL,3,1,2,1,'\\ ','raada2006'),(7995,741644299011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',8.99,'eastar4','matthewqyc2009','matthewqyc@hotmail.com','Yanchao QIN','21/6 Omeo St<br>Macgregor','Brisbane','Queensland','AUSTRALIA','4109','0416440181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 01:48:33',0,NULL,3,1,2,1,'\\ ','matthewqyc2009'),(7996,823216950012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','malljunior','maljunior@gmail.com','Francisco Marcelo de Araújo Lima Júnior','Rua dos Marchantes, 32, Santo Antônio','Salvador','Bahia','BRAZIL','40301-430','+557191941331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 02:01:10',0,NULL,3,1,2,1,'\\ ','malljunior'),(7997,823239512012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','mr_zeddeh','darren.email@gmx.com','Darren Oxner','27 MicMac Drive','Dartmouth','NS','CANADA','B2X 2H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 02:15:23',0,NULL,3,1,2,1,'\\ ','mr_zeddeh'),(7998,741665234011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','gd_anthony','greg.anthony@me.com','Greg Anthony','15 Claire Close','Sherwood Park','AB','CANADA','T8H 0A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 03:07:11',0,NULL,3,1,2,1,'\\ ','gd_anthony'),(7999,606150906013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','anaconda711','azianguy27@aol.com','Khoa Nguyen','3024 Hillcrest Ave','Allentown','PA','UNITED STATES','18103-6433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 03:10:02',0,NULL,3,1,1,1,'\\ ','anaconda711\r红边优联'),(8000,551909324003,130553376100,'NIB GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO029',37.9,'cnfaner','laurent.bty1807','laurent.bty@gmail.com','BOUTRY Laurent','350 Lotissement REVERCE, rue Pascal BAYLON<br>Route de Yahoué','Mont Dore','','NEW CALEDONIA','98809','(687)815009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 03:33:46',0,NULL,3,1,3,1,'RA183616878CN ','laurent.bty1807\rHSNO029\r盒装的'),(8001,741690672011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','misfer44','al_kaed__44@hotmail.com','misfer alnaimi','Asharqia Chamber - P.O.Box 719<br>Mobile: 0545277774','dammam','Eastern Province','SAUDI ARABIA','31421','+966545277774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 05:23:35',0,NULL,3,1,2,1,'\\ ','misfer44'),(8002,822761119012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4uk','firyembers','firyembers@gmail.com','Mr RD Weston (GE)','4 Banbury<br>Burwarton','Bridgenorth','Shropshire','UNITED KINGDOM','WV16 6QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 05:36:16',0,NULL,3,1,3,1,' RA183616816CN\r','firyembers\rOTCN002'),(8003,823286816012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',20,'OTAP001',189.8,'eastar4','rhinobr','contato@rhinotec.com.br','M. H. ZORTEA RHINOTEC ME','Desembargador Vieira Cavalcanti 292 ap 11 subsolo','Curitiba','Paraná','BRAZIL','80510-090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 05:49:48',0,NULL,3,1,3,1,'RA183617003CN\r ','rhinobr\rOTAP001\r分两票发\rRA183616997CN\r'),(8004,741710204011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','air-ocean','air-ocean-so@ya.ru','Viacheslav Dorogaykin','Astrahanskaya 11-49','Krasnoyarsk','','RUSSIAN FEDERATION','660037','902-9235388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:09:30',0,NULL,3,1,2,1,'\\ ','air-ocean'),(8005,685409546008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','laknj001','nathan.lakes@internode.on.net','Nathan Lakes','107 Osmond Tce','Norwood','South Australia','AUSTRALIA','5067','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 07:38:43',0,NULL,3,1,3,1,NULL,'laknj001\rRELO002'),(8006,741723983011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ashplatell','ash.platell@gmail.com','Ashley Platell','23 Drysdale Avenue','Collingwood Park','Queensland','AUSTRALIA','4301','0733890454','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 08:14:52',0,NULL,3,1,2,1,'、 ','ashplatell\r红边优联'),(8007,8881311755038324,111,'Monster House New sealed 3D Blu-ray',1,'BR3D004',19.99,'buysia','keo1','krisblakely@bellsouth.net','Kris Blakely','1970 Highway 51','Winona','MS','UNITED STATES','38967-9566','',NULL,NULL,NULL,NULL,0,NULL,3,1,1,1,'\\ ','漏单子了 '),(8008,741739950011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',77.98,'eastar4uk','clairem6','m11.claire@gmail.com','Claire Murphy','41 oldcourt<br>greenfields','ballincollig','Cork','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 09:23:18',0,NULL,3,1,3,1,'RA183618220CN\r ','clairem6\rGLSG001'),(8009,8881311759088255,111,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4',' ndterpstra  ','nate.terpstra@gmail.com','Nate Terpstra','6040 Carrollton Ave','Indianapolis','IN','UNITED STATES','46220-1921 ','',NULL,NULL,NULL,NULL,0,NULL,3,1,1,1,'\\\r ','补发的 \rLK005794280CN\r'),(8010,741743870011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','retailtragic','paulbb@iinet.net.au','Paul Bresloff-Barry','C/O Synergy,<br>228 Adelaide Terrace','Perth','Western Australia','AUSTRALIA','6000','08621219882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 09:40:38',0,NULL,3,1,2,1,'\\ ','retailtragic'),(8011,741746351011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','mpawlows2','mp185067@ncr.com','Maciej Pawlowski','NCR POLSKA SP Z O. O.<br>Woloska 3, Mercury office building','WARSAW','mazowieckie','POLAND','02675','695 790024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 09:48:52',0,NULL,3,1,2,1,'\\ ','mpawlows2'),(8012,741755960011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','madmags43','madmags43@hotmail.com','Margaret Burke','43 Crispin Road<br>Bradville','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK13 7BS','01908310012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 10:27:26',0,NULL,3,1,3,1,'RA183618159CN\r ','madmags43\rHSJA011\r英标'),(8013,551974762003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','lgo_smiley','ebaysmiley@gmail.com','Robert Davis','2116 Rocky Creek Rd','Rocky Creek','New South Wales','AUSTRALIA','2371','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:12:12',0,NULL,3,1,3,1,'RA183618030CN\r ','lgo_smiley\rHSPL010\r澳标'),(8014,685460059008,180699061927,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','luda2002au','hlewicki@csc.com.au','Helen  Lewicki','4 cavendish street','pennant hills','New South Wales','AUSTRALIA','2120','0294840989','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 11:13:10',0,NULL,3,1,3,1,'RA183618088CN\r ','luda2002au\rOTRA001'),(8015,823367339012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',12.99,'eastar4','wisesimon','simonwis@googlemail.com','Simon  Wise','7 Hammond Square','Andover','Hants','UNITED KINGDOM','SP10 5BT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:13:32',0,NULL,3,0,2,1,'\\ ','wisesimon\r发210T'),(8016,823371346012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','choodalls','choodalls@aol.com','D J Chugg','Carnaby, Pecket Well,','Hebden Bridge','West Yorkshire','UNITED KINGDOM','HX7 8QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 11:26:39',0,NULL,3,1,3,1,'RA183616935CN\r ','choodalls\rWLAP008'),(8017,741775836011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','elijus.civilis','elijus@gmail.com','Elijus Civilis','VARSUVOS 11 - 27','VILNIUS','','LITHUANIA','02103','+37065231656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:38:26',0,NULL,3,1,2,1,'\\ ','elijus.civilis'),(8018,703229126001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','poreliob','ladawgs@suddenlink.net','John Heslop','204 Longacre St','Marietta','OH','UNITED STATES','45750','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 11:46:09',0,NULL,3,1,1,1,'\\ ','poreliob\r再发一个Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW'),(8019,703229914001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',49.99,'buysia','poreliob','ladawgs@suddenlink.net','John Heslop','204 Longacre St','Marietta','OH','UNITED STATES','45750','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 11:48:18',0,NULL,3,1,17,0,NULL,'poreliob'),(8020,551981860003,130466041506,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',60,'cnfaner','datinelks','krcmar@datinel.cz','Milan Krcmar','DATINEL k.s.<br>Dlouha 33','Kladno','','CZECH REPUBLIC','27201','+420-775322513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:49:18',0,NULL,3,1,3,1,'RA183618012CN\r ','datinelks\rWWSI006+ANCN001'),(8021,606231702013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','andystewart999','cart_champ@hotmail.com','Andrew Stewart','22 Cobblestone Court','Glenhaven','New South Wales','AUSTRALIA','2156','61408710657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:52:54',0,NULL,3,1,2,1,'\\ ','andystewart999\rCAB-6060'),(8022,823384848012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.4,'eastar4','duscadan','dasg@shelman.gr','Yorgos-Fotios Daskalakis','SHELMAN S.A.<br>26 Kifisias Av.','Athens','','GREECE','15125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:08:14',0,NULL,3,1,2,1,'\\ ','duscadan\rHP 8pin 1.0 18cm 4线连 '),(8023,823385547012,220816379674,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT004*3',95.99,'eastar4uk','pepo80pavlin','plastering.pavlin@googlemail.com','Pavlin Hristov','5 middle lane','London','London','UNITED KINGDOM','N8 8PJ','07912100424','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 12:12:01',0,NULL,3,1,3,1,'RA183618162CN\r ','pepo80pavlin\rGLOT004*3\r兼容型3D眼镜  samsung 专用\r'),(8024,739296784011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',207.99,'eastar4','robepare','robert_pare@sympatico.ca','Robert Pare','2431 car Cluseau','Quebec','QC','CANADA','G2B 4P6','(418) 847-4100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:21:48',0,NULL,3,1,3,1,'RA183618247CN\r ','robepare\rOTSO004*3'),(8025,823391251012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','lhumbel','leopold@humbel.com.au','Leopold Humbel','2 Effingham St','Mosman','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:29:07',0,NULL,3,1,3,1,'RA183618145CN\r ','lhumbel\rOTGR001+OTGR002'),(8026,823395224012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','boriska_il','rauchv@gmail.com','Boris Rauchverger','Hermon 17/9','Nazareth-Illit','Israel','ISRAEL','17641','(972) 522-4839 ext.: 27','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:41:37',0,NULL,3,1,3,1,'RA183618193CN ','boriska_il\rGLOT001*2\r兼容型3D眼镜 通用型'),(8027,551714862003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','molitan2010','faktorom@gmail.com','mihael faktorovich','kibutz galuyot 57/16','nahariya','israel','ISRAEL','22261','97249521478','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 13:04:18',0,NULL,3,1,3,1,'RA183618128CN ','molitan2010\rMOOE002\r发OEM的'),(8028,685146603008,180699061342,'New in box Jabra BT-2080 Wireless Bluetooth Headset',1,'HSJA005',18.99,'au-buy','dmytro_yaroshenko','mu-mu4@list.ru','dmytro yaroshenko','vul. Minina i Pozharskogo, 2','cherkassy','?herkaska oblast','UKRAINE','18009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 13:07:07',0,NULL,3,1,3,1,'RA183616864CN\r ','dmytro_yaroshenko\rHSJA005'),(8029,740834733011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','sandorv','sandorv@hotmail.com','Sandor Veltman','Roemer Visscherlaan 37','Zeist','','NETHERLANDS','3705SC','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 13:16:07',0,NULL,3,1,2,1,'\\ ','sandorv'),(8030,823134276012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',8.55,'eastar4','jason_miagi','1s0upcan@gmail.com','Jason Welton','1898  denver court west apt 1225','lakewood','CO','UNITED STATES','80401','(316) 779-5267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 13:30:54',0,NULL,3,0,1,1,'\\ ','jason_miagi\r'),(8031,741811354011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','jmcesareo','janine_cesareo@hotmail.com','Janine Micallef Cesareo','Belview Flats, Flat 1<br>Triq Martino DeRedin','San Pawl il-Bahar','','MALTA','SPB3461','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 13:45:40',0,NULL,3,1,2,1,'\\ ','jmcesareo\r欧标'),(8032,741818418011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','moparman9678','pcmender@yahoo.com','garrett compston','1036 Buena Vista Ave NE','warren','OH','UNITED STATES','44483-3904','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 13:58:47',0,NULL,3,1,1,1,'\\ ','moparman9678'),(8033,606273970013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',4,'CCGR001',27.52,'eastar4','nci720','ncibbott@hotmail.com','Nicholas Ibbott','261 Lewis Honey Drive','Aurora','ON','CANADA','L4G 0H2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:56:26',0,NULL,3,1,2,1,'\\ ','nci720'),(8034,823448768012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','donc223','donsam@bigpond.net.au','Don Cameron','29 Haven Close','Norman Gardens','Queensland','AUSTRALIA','4701','0749266916','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 15:10:37',0,NULL,3,1,2,1,'\\ ','donc223'),(8035,552028604003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','islandcapri','gallansjc@gmail.com','David Moyer','PO Box 353','Pineland','FL','UNITED STATES','33945-0353','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-27 15:26:05',0,NULL,3,1,1,1,'\\ ','islandcapri'),(8036,741849033011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',26.49,'eastar4','dianafabbro','dfabbro2000@hotmail.com','Diana  Fabbro','C/ Cap Ponent Nº 11 Edif. Garbi bajo 22B Buzon 5','Roses','Cataluña','SPAIN','17480','687958747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 15:33:10',0,NULL,3,1,2,1,'\\ ','dianafabbro\r旧的'),(8037,823458435012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','martinmax79','martinmaxlarsen@gmail.com','Martin Max Larsen','Aalekistevej 72, 4 TV','Vanloese','DK','DENMARK','2720','+4540857151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 15:40:13',0,NULL,3,1,2,1,'\\ ','martinmax79'),(8038,741853911011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',35.9,'eastar4uk','racerman202','tonyhall@woodpeckercottage.net','A. G. Hall','Gurney Environmental Ltd.,    1 Bryggen Road,<br>North Lynn Industrial Estate,','King\'s Lynn,','Norfolk','UNITED KINGDOM','PE30 2HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 15:41:05',0,NULL,3,1,3,1,'RA183618202CN\r ','racerman202\rMOLO005\r蓝牙版旧的\r'),(8039,606291837013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','alexp2181','alexandrpach@yahoo.com','Alex Pach','2425 Greenmount ave','Baltimore','MD','UNITED STATES','21218-5337','(443) 527-6527','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 16:05:23',0,NULL,3,1,1,1,'\\ ','alexp2181'),(8040,606294613013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.97,'eastar4','oldpantry','grecilda@hotmail.com','William Cook','16026 24th Dr SE','Mill Creek','WA','UNITED STATES','98012-7837','(425) 316-3605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 16:14:58',0,NULL,3,1,1,1,'\\ ','oldpantry'),(8041,741867856011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','denisnadym','denis.hvatov@mail.ru','Denis Khvatov','Prospekt Leningradsky<br>dom 10G kv.38','Nadym','Yamalo-Nenetcky avtonomny okrug','RUSSIAN FEDERATION','629730','+79220653365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 16:21:09',0,NULL,3,1,2,1,'\\ ','denisnadym'),(8042,741858695011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','cmichaelis1990','cmichaelis1990@gmail.com','Christopher Michaelis','9 Alexander St','Babylon','NY','UNITED STATES','11702-1101','(631) 395-4024','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 16:23:54',0,NULL,3,1,1,1,'\\ ','cmichaelis1990'),(8043,741770380011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56.49,'eastar4','kouglof13','patrick.lips@wanadoo.fr','patrick LIPS','155 Allée des pins<br>VAL DE SIBOURG','LANCON DE PROVENCE','Provence-Alpes-Côte d\'Azur','FRANCE','13680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 16:26:21',0,NULL,3,1,3,1,'RA183618091CN\r ','kouglof13\rWWSI006'),(8044,741873054011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','chiphfb','hbritton@yahoo.com','Herman F Britton','288 W Fryeburg Rd','Fryeburg','ME','UNITED STATES','04037-4343','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 16:32:02',0,NULL,3,1,1,1,'\\ ','chiphfb'),(8045,606304221013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','iceman300380','hskifte@gmail.com','Marit Opheim','Århuskleiva','Åmli','Åmli','NORWAY','4865','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 16:49:08',0,NULL,3,1,3,1,'RA183618026CN\r ','iceman300380\rHSNO019\r欧标'),(8046,823494333012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','p0mr0y','p0mr0y@hotmail.com','Dimitri Azulay','2 ashburnham mansions<br>ashburnham road','London','London','UNITED KINGDOM','SW100DX','07770268613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 16:58:50',0,NULL,3,1,3,1,'RA183616921CN\r ','p0mr0y\rANCN001'),(8047,823494528012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',2,'UM00008',49.98,'eastar4','vyssotskiy','vyssotskiy@of.kz','Vladimir Vysotskiy','161 Kytyzova Str, room 46','Pavlodar','Kazakhstan','KAZAKHSTAN','140000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 17:01:49',0,NULL,3,1,3,1,'RA183618304CN\r ','vyssotskiy\rUM00008\r24K 多色伞'),(8048,741877644011,320721418293,'Genuin Samsung SSG-2200AR Rechargeable Adult 3D glasses',1,'GLSG006',75.99,'eastar4','jipege44','pascal.godel@free.fr','Pascal GODEL','32 Avenue TELSTAR','NANTES','Pays de la Loire','FRANCE','44300','06.87.08.55.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 17:09:06',0,NULL,3,1,3,1,'RA183618176CN ','jipege44\rGLSG006'),(8049,741892043011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',38.99,'eastar4uk','nurrojenna','jenna.nurro@hotmail.com','Jenna  Nurro','Tähdenlento 2 b 11','kempele','Kempele','FINLAND','90450','+358414490370','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 17:18:46',0,NULL,3,1,3,1,'RA183618233CN ','nurrojenna\rGLSG001'),(8050,823508192012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','d_a_v_i_d_h','david@murderville.co.uk','David Highcock','5 Kentmere Drive<br>Lakeside','Doncaster','South Yorkshire','UNITED KINGDOM','DN4 5FL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 17:29:01',0,NULL,3,1,3,1,'RA183618074CN\r ','d_a_v_i_d_h\rOTHP003'),(8051,741913976011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','1rembertt','rembee1@sbcglobal.net','Tina Rembert','3853 W. Maypole Avenue','Chicago','IL','UNITED STATES','60624','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 18:06:14',0,NULL,3,1,1,1,'\\ ','1rembertt'),(8052,741918730011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','daniel783','ctgjhsu@gmail.com','Jesse Hsu','32 Avenue of the Americas<br>Fl 21','New York','NY','UNITED STATES','10013','(212) 925-6692','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'daniel783'),(8053,823534770012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','darwencomputersuk','dom@darwencomputers.co.uk','Dominic Holden','19 Duckworth St<br>Darwen','Darwen','Lancashire','UNITED KINGDOM','BB3 1AR','01254368121','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 18:20:41',0,NULL,3,1,3,1,'RA183618065CN\r ','darwencomputersuk\rOTCN004*10'),(8054,606336353013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','chlasic','chlee07@postech.ac.kr','ChangHwan Lee','2 Granite Ln, #2B','Hanover','NH','UNITED STATES','03755','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 18:28:55',0,NULL,3,1,1,1,'\\ ','chlasic'),(8055,703365368001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','sheshe611','shespro@yahoo.com','Sheila Sprovieri','1802 N Halsted St<br>Apt A','Chicago','IL','UNITED STATES','60614-7276','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 18:31:39',0,NULL,3,1,1,1,'\\ ','sheshe611'),(8056,606346206013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','rasuyom','rasuyom@hotmail.com','Ronald Suyom','4620 S Slauson Ave<br>Apt 101','Culver City','CA','UNITED STATES','90230-5179','(925) 550-4692','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 18:54:13',0,NULL,3,1,1,1,'\\ ','rasuyom'),(8057,685604202008,180699061927,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','giovani_pierobon','giovani_bom@yahoo.com.br','Giovani Pierobon','Rua brigadeiro jordão, 473 apto 83<br>Bairro Ipiranga','São paulo','São Paulo','BRAZIL','04210000','(011)8411-9096','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 19:02:04',0,NULL,3,1,3,1,'RA183618057CN\r ','giovani_pierobon\rOTRA001'),(8058,552088739003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.9,'cnfaner','dasuperfly','thesuperfly@live.co.za','Craig Engelbrecht','23 Linda Street<br>Bellville','Cape Town','Western Province','SOUTH AFRICA','7530','+27219454091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 19:07:52',0,NULL,3,1,3,1,'RA183618043CN\r ','dasuperfly\rWWSI002+ANCN001'),(8059,823560883012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','malee9989','maleenota@hotmail.com','Malee Nota','De Genestetlaan 2c','Zeist','','NETHERLANDS','3705 BV','(030)6991988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 19:09:05',0,NULL,3,1,3,1,'RA183618216CN ','malee9989\rGLSG001*4'),(8060,741957022011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jeremiah2008','jeremiah@tropicaltraditions.com','Jeremiah Shilhavy','13210 Shadow Wood Pl','Moorpark','CA','UNITED STATES','93021-1189','(805) 870-5385','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 19:32:48',0,NULL,3,1,1,1,'\\ ','jeremiah2008'),(8061,552130657003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','mohalrug','al_rug_moh@hotmail.com','Mohammed Alruqaibah','SAMA, P O Box: 2992','Riyadh','Riyadh','SAUDI ARABIA','11169','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 21:03:16',0,NULL,3,1,3,1,'RA183618180CN ','mohalrug\rMOOE002\r发OEM的'),(8062,742003084011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','seemers22','nhseem@yahoo.com','Gabriela Barba','24424 Albatross Ave','Wilmington','CA','UNITED STATES','90744-1015','(310) 560-8606','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 21:16:32',0,NULL,3,1,1,1,'\\ ','seemers22'),(8063,742010534011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','rainers1966','rainer_stober@web.de','Rainer Stober','Am Borsdorfer 50a','Frankfurt am Main','','GERMANY','60435','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 21:29:37',0,NULL,3,1,2,1,'\\ ','rainers1966'),(8064,823647060012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','adrze65pl','andrzej_sitarz@o2.pl','Andrzej Sitarz','Zapolskiej 42/77','Kraków','małopolskie','POLAND','30-126','605 269245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 22:07:14',0,NULL,3,1,3,1,'RA183618105CN\r ','adrze65pl\rOTSO002'),(8065,742035348011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','kristen8311','kristen.ryan1@bigpond.com','Kristen Ryan','31 South Molle Boulevard','Cannonvale','Queensland','AUSTRALIA','4802','0414440285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 22:49:07',0,NULL,3,1,3,1,'RA183618255CN\r ','kristen8311\rGLSG001*2'),(8066,823675142012,220644682557,'New Yagi 18dBi 2.4 GHz Wifi Antenna RP-SMA',1,'ANYA002',19.5,'eastar4','padeya','keijomiguel@hotmail.com','SILVIA YANES MARRERO','EMILIO SERRA RUS 22  bloque 7 1º izda','SANTA CRUZ DE TENERIFE','Canarias','SPAIN','38008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 23:35:54',0,NULL,3,1,11,1,'、 ','padeya\rANYA002'),(8067,742057288011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','jrkirby24','jlkirby32@gmail.com','Jason','110 Royal Oak Ct','Lenoir','NC','UNITED STATES','28645-8464','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 00:08:27',0,NULL,3,1,1,1,'\\ ','jrkirby24'),(8068,557732766004,140583346344,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',2,'HSPL001',29.98,'cnfaner','noirmarginal','richardcoutu@videotron.ca','richard coutu','49 des fromagers','st-basile le grand','QC','CANADA','j3n1y6','(450) 723-0532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 01:11:20',0,NULL,3,1,3,1,'RA183616952CN\r ','noirmarginal\rHSPL001'),(8069,742077832011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',2,'HSUE002',39.98,'eastar4','sirlonramos','sirlonbaixo@hotmail.com','Amando Ramos','Rua Fortaleza qd 29 lt 03<br>Jd das Esmeraldas','Aparecida de Goiânia','Goias','BRAZIL','74905060','6281275304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 01:31:36',0,NULL,3,1,3,1,'RA183616949CN\r ','sirlonramos\rHSUE002'),(8070,741996978011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','coolgdelta','coolgdelta8@live.com','charles danh','9852 palazzo dr','stockton','CA','UNITED STATES','95212-3516','(209) 981-5827','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 01:39:05',0,NULL,3,1,1,1,'\\ ','coolgdelta'),(8071,606454535013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','greenfinder64','mohammedk28@hotmail.com','Ayaz Khan','64 Brickstone Circle','Thornhill','ON','CANADA','L4J6M4','(905) 660-7974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 01:51:45',0,NULL,3,1,2,1,'\\ ','greenfinder64'),(8072,823712519012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','chanizzz1','dunen@nate.com','Yun-chan Han','Jangnim 2-dong, Saha-gu<br>Hyundai Apt 7-305','Busan','','KOREA,REPUBLIC OF','604-773','82-10-2320-0965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 01:52:19',0,NULL,3,1,2,1,'\\ ','chanizzz1'),(8077,742113466011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','rmmotos','miki.nos@hotmail.com','Miguel Becerra','Gran Avenida 11310<br>El Bosque','santiago','El Bosque','CHILE','8010000','025610418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 04:05:44',0,NULL,3,1,3,1,'RA183618131CN\r ','rmmotos\rHSJA011'),(8073,606457427013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','panudomlak','pur_hom@hotmail.com','Aniruth Pan-Udomlak','449 University Blvd E','Silver Spring','MD','UNITED STATES','20901-3654','(301) 204-9450','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 02:06:04',0,NULL,3,1,1,1,'\\ ','panudomlak'),(8074,703512032001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','djrnz','evgene.pozniak@gmail.com','Evgeniy Poznyak','1075 Sheepshead Bay Rd<br>apt 6J','Brooklyn','NY','UNITED STATES','11229-4279','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 02:09:26',0,NULL,3,1,1,1,'\\ ','djrnz'),(8075,823728423012,220806882622,'New lady Piano Rain Sun Parasol Stick Umbrella purple',1,'UM00010',24.99,'eastar4','carlos_vidal','khalox@gmail.com','Carlos Vidal','Pasaje 14 #2980, Comuna Pedro Aguirre Cerda<br>Villa Universidad de Chile','Santiago','Region Metropolitana','CHILE','8460845','3106290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 02:46:35',0,NULL,3,1,2,1,'\\ ','carlos_vidal\r钢琴美女伞 \r紫色的'),(8076,823729952012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','joshg546','gabel.josh@gmail.com','Joshua Gabel','206 Beech Branch Dr','Irmo','SC','UNITED STATES','29063-8077','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 02:53:40',0,NULL,3,1,1,1,'\\ ','joshg546'),(8078,823754865012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','beyondcomm','groland@beyondcomm.us','Geoff Roland','3560 Swan Cir S','Arnold','MO','UNITED STATES','63010-3995','(314) 486-3937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 04:47:38',0,NULL,3,1,1,1,'、 ','beyondcomm'),(8079,0,130552429471,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.69,'cnfaner','ammousa72','la.louisiana@yahoo.com','osama ammous','PO Box 80472','baton rouge','LA','UNITED STATES','70898-0472','(225) 270-3040','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 05:05:34',0,NULL,3,1,1,1,'、 ','ammousa72\r一共买了11个'),(8080,0,140582815107,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.06,'cnfaner','tzaralexrex','alex.rex@gmail.com','Alexey Tsarev','Muromskaya str. h.1, apt.6','Nizhniy Novgorod','','RUSSIAN FEDERATION','603010','+79056674504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 05:08:28',0,NULL,3,1,3,1,' RA183618335CN','tzaralexrex\rANCN001'),(8081,742127969011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',25.9,'eastar4uk','lkjhgterry','terry.spencer@gmail.com','Terry Spencer','3 Woodbine Villas','Cottingham','Easty Yorkshire','UNITED KINGDOM','HU16 4NF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 05:29:06',0,NULL,3,1,3,1,'RA183618349CN ','lkjhgterry\rWWSI004'),(8082,742128684011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','grhardy3','grhardy3@care2.com','gordon hardy','638 peacock pl','victoria','BC','CANADA','v9b6c3','(250) 474-5869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 05:47:46',0,NULL,3,1,2,1,'、 ','grhardy3'),(8083,742133474011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','t1xm1n','clive.watts@ntlworld.com','Clive Watts','19 Isaacson Road<br>Burwell','CAMBRIDGE','Cambridgeshire','UNITED KINGDOM','CB25 0AF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:05:21',0,NULL,3,1,2,1,'、 ','t1xm1n'),(8084,823770575012,220763388936,'New Apple AR9280 AR5BXB92 Mini PCI-E AGN 300M+2 antenna',1,'WLAP008+ANAP001',10.99,'eastar4uk','xlucian0','xlucian@xlucian.com','Stefan Lucian Cosofret','16 Cave Street<br>GFF','Bristol','Avon','UNITED KINGDOM','BS2 8RU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 06:11:48',0,NULL,3,0,3,1,'RA183618295CN ','xlucian0\rWLAP008+ANAP001'),(8085,606495609013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','tgaripozer_83','tgaripozer@yahoo.com','turan garipözer','Haramidere sanayi sitesi G blok no:204<br>no:204 haramidere/Beylikdüzü','istanbul','beylikdüzü','TURKEY','34524','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:15:13',0,NULL,3,1,3,1,' RA183618281CN','tgaripozer_83\rBAZA001'),(8086,606500213013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','shterenbah','voland.gr8@gmail.com','Vladislav Sternbach','Bialik 152/9','Holon','Tel-Aviv','ISRAEL','58442','+972525908874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:50:07',0,NULL,3,1,2,1,'、 ','shterenbah'),(8087,0,220819095255,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.24,'eastar4','intellact','intellact12@gmail.com','Tad Bednarczyk','1921 W Crestview Cir','Romeoville','IL','UNITED STATES','60446-2804','(186) 676-7266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 07:04:42',0,NULL,3,1,1,1,'、 ','intellact\r一共买了二十四个'),(8088,0,130552430294,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.14,'cnfaner','intellact','intellact12@gmail.com','Tad Bednarczyk','1921 W Crestview Cir','Romeoville','IL','UNITED STATES','60446-2804','(186) 676-7266','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 07:04:49',0,NULL,3,1,1,1,'、 ','intellact\r一共买了十四个'),(8089,606502450013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.97,'eastar4','gary_wellington','gsmoore@bigpond.com','Gary D Moore','PO Box 456','Wellington','New South Wales','AUSTRALIA','2820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 07:07:47',0,NULL,3,1,2,1,'、 ','gary_wellington'),(8090,606509918013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','tanay_2009','tanyatret83@yandex.ru','Viktor Tret\'yakov','per.Pilotov, d.12, kv.78','Bryansk','','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 07:58:47',0,NULL,3,1,3,1,'RA183618423CN\r ','tanay_2009\rHSNO022\r银色的\r欧标\r客户打了四美金想要挂号'),(8091,8881311842716292,111,'Item Title:New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'',28.85,'eastar4','jurijsivanovs','jur4iks90@inbox.lv','Jurijs Ivanovs','Tvaika 16/54','Riga','LV','LATVIA','1005 ','',NULL,NULL,NULL,NULL,0,NULL,3,0,3,1,' RA183618321CN','补发 只补发一个模块 '),(8092,823809948012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','bananagarage','gregn31@optusnet.com.au','greg north','20 adelaide boulevard<br>gowanbrae','melbourne','Victoria','AUSTRALIA','3043','0393382476','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 09:08:35',0,NULL,3,1,2,1,'\\ ','bananagarage'),(8093,823816242012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4uk','jeanmarief12','j_m_mainguet@hotmail.com','jean-marie Mainguet','lagelire, 14','durbuy','','BELGIUM','6941','086-211234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 09:33:47',0,NULL,3,1,2,1,'\\ ','jeanmarief12'),(8094,823819248012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','bibiblp','bibilope@hotmail.com','BIBIANO LOPEZ PASCUAL','AMAZONAS 22','GETAFE','Madrid','SPAIN','28909','677240003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 09:46:55',0,NULL,3,1,2,1,'\\ ','bibiblp\racer 5pin1.25 6cm '),(8095,742183936011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',39.99,'eastar4','zexxhook','voniurestauratoriai@gmail.com','Gintaras Marscionka','T. Masiulio g. 13 - 4','Kaunas','','LITHUANIA','LT-52356','37067188575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:03:01',0,NULL,3,1,3,1,'RA183618410CN\r ','zexxhook\rHSSE008\r欧标\r棕色的'),(8096,606530498013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','janotlapinos','jc4@bluewin.ch','Marguerite Carlier et Jean','9 rue des Boudines','Meyrin, geneve','','SWITZERLAND','1217','00410762141999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:08:09',0,NULL,3,1,2,1,'\\ ','janotlapinos'),(8097,606534953013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','jyap8512','joannies@gmail.com','Joannies Yap','7 Stuart St','Hillcrest','South Australia','AUSTRALIA','5086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:34:28',0,NULL,3,1,2,1,'\\ ','jyap8512'),(8098,557815498004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','zytorus','zyto@mail.ru','Victor Kuznetsov','st. Sofia Kovalevskoi, d. 7, kv. 173','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185002','+79114021453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:50:53',0,NULL,3,1,3,1,'RA183618525CN\r ','zytorus\r发OEM的\rMOOE001'),(8099,742199555011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','ekachaiw','ekachaiw@yahoo.com','Ekachai Wongviwat','31 Prachatipatai rd.<br>Bannpanthom','Pranakorn','Bangkok','THAILAND','10200','66-2-2828574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 11:07:10',0,NULL,3,1,2,1,'\\ ','ekachaiw'),(8100,823843728012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','repel89','watzzup89@hotmail.com','Cornelius Chang','Dover Crescent Blk 21<br>#10-334','default','','SINGAPORE','130021','98775089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 11:17:26',0,NULL,3,1,11,1,'\\ ','repel89\rANTY001'),(8101,606545681013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','mgal6543','mtile@comcast.net','mark galdo','541 Gia Cir','CLIFTON HEIGHTS','PA','UNITED STATES','19018-1029','(610) 656-3013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 11:30:50',0,NULL,3,1,1,1,'\\ ','mgal6543\r兼容型3D眼镜 通用型'),(8102,823857035012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',1,'HSJA006',9.49,'eastar4uk','crazig','crazi@blueyonder.co.uk','Gary   Martin','6 Inveresk Place','Coatbridge','North Lanarkshire','UNITED KINGDOM','ML52DA','01236621803','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 12:02:55',0,NULL,3,1,3,1,'RA183618370CN\r ','crazig\rHSJA006\r英标'),(8103,742219772011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56.49,'eastar4','mamelogr','dcapitan@gmail.com','Damian Capitan Montenegro','C/ Libertador Hidalgo y Costilla, 1; portal 10; piso 1-2<br>Edificio Los Jardines I','Cordoba','Cordoba','SPAIN','14013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 12:20:09',0,NULL,3,0,3,1,'RA183618658CN\r ','mamelogr\rWWSI005\r换成8781 \r'),(8104,823868482012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','dandanhodge','ebay@dansgraphics.co.uk','Daniel Hodge','99 Knightswood<br>Goldsworth Park','Woking','Surrey','UNITED KINGDOM','GU21 3PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 12:39:04',0,NULL,3,1,3,1,'RA183618485CN\r ','dandanhodge\rOTHP004'),(8105,823879134012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',9.99,'eastar4uk','gaby.22','gavriel@tiscali.co.uk','rosa constantinides','2 chelmsford square','london','London','UNITED KINGDOM','nw10 3ar','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 13:13:03',0,NULL,3,1,3,1,'RA183618406CN\r ','gaby.22\rWLAT009'),(8106,823880047012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','multipetros','petros.kyladitis@gmail.com','Petros Kyladitis','Margaronidon  8<br>Agios Markos','Vrontados','Chios','GREECE','82200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:14:57',0,NULL,3,1,2,1,'\\ ','multipetros'),(8107,606569314013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.76,'eastar4','junkfinder99','junk900@aol.com','Edward Beck','2060 72nd St<br>Fl 1','Brooklyn','NY','UNITED STATES','11204-5819','(347) 426-7325','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 13:30:59',0,NULL,3,1,1,1,'\\ ','junkfinder99'),(8108,823888459012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','rmmotos','miki.nos@hotmail.com','Miguel Becerra','Gran Avenida 11310<br>El Bosque','santiago','El Bosque','CHILE','8010000','025610418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:40:54',0,NULL,3,1,2,1,'\\ ','rmmotos'),(8109,606572521013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',18.5,'eastar4','nejcdacar','nejc.poljanec@gmail.com','Nejc Poljanec','Dacarjeva25','Lesce','SC','SLOVENIA','4248','00386 41521917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:41:15',0,NULL,3,1,2,1,'\\ ','nejcdacar'),(8110,606574582013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','meliborn','volanxak@gmail.com','Dzianis Batura','Odoevskogo 38 - 53','Minsk','','BELARUS','220092','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:49:00',0,NULL,3,1,2,1,'\\ ','meliborn'),(8111,823900756012,220759518349,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',12,'eastar4uk','toms1108','thomas.sutton76@gmail.com','Thomas Sutton','Barclays, Meridian House<br>Anchor Boulevard, Crossways Business Park','Dartford','Kent','UNITED KINGDOM','DA2 6QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 14:18:54',0,NULL,3,1,3,1,'RA183618508CN\r ','toms1108\rSCLO001'),(8112,742259234011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','campbelltb','ollohs@hotmail.com','Campbell Tremblay-Birchall','46 Traeger Street','Dunlop','Australian Capital Territory','AUSTRALIA','2615','0448651392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 14:33:30',0,NULL,3,1,2,1,'ゝ ','campbelltb\r微软的'),(8113,742259496011,320441946530,'2.1 HP mini 2133 2140 Bluetooth Module EDR + cable',1,'BTHP2101',12.4,'eastar4','serega2082','tomchuksu@mail.ru','Sergey Tomchuk','ul.Marshala Kozheduba, 2-1-184','Moscow','Moscow','RUSSIAN FEDERATION','109559','915-220-6365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 14:35:42',0,NULL,3,1,2,1,'\\ ','serega2082\rHP 8pin 1.0 3cm '),(8114,606573543013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','edpsychdoc','zionscamp@hotmail.com','Mark White','2930 N 840 E','Provo','UT','UNITED STATES','84604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-28 14:45:00',0,NULL,3,1,1,1,'\\ ','edpsychdoc'),(8115,557865817004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','mrpar1156','mrpar52@shaw.ca','Phil Ricard','1156 Penrith Cres S E','Calgary','AB','CANADA','T2A2H9','(403) 301-0818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 15:14:51',0,NULL,3,1,3,1,'RA183618366CN\r ','mrpar1156\rRCLO006\r新的'),(8116,552317102003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','shefiavi','shefiavi@netvision.net.il','avi shefi','6 haaliyah hashniyah street','ramat-gan','','ISRAEL','52253','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 15:31:06',0,NULL,3,1,3,1,'RA183618383CN\r ','shefiavi\rMOAP001'),(8117,0,130552429244,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.12,'cnfaner','nayacandy1','nayacandy@hotmail.com','EUNJUNG KIM','102-1302 Samsung APT, Suyu-2 Dong,<br>Gangbuk-Gu','Seoul','','KOREA,REPUBLIC OF','142-772','01073660582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 15:50:06',0,NULL,3,1,3,1,'RA183618468CN\r ','nayacandy1\rANCN001\r一共买了两个'),(8118,703696585001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','jkittrick','alioneyes@aol.com','jo ann kittrick','58 Kidder St<br>Apt 2','wilkes barre','PA','UNITED STATES','18702-5446','(570) 704-6530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 15:53:12',0,NULL,3,1,1,1,'\\ ','jkittrick'),(8119,606620213013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','jtm2b','jlserra2b@wanadoo.fr','Serra jean louis','Atelier Réfection Z.I Cantone','Calvi','Corse','FRANCE','20260','0610300105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 16:47:29',0,NULL,3,1,2,1,'\\ ','jtm2b\r红边优联'),(8120,742311153011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','2010sameeraranga','godayamu@gmail.com','Sameera Ranga','252,Yamuna Katuwana Road,<br>Homagama','Colombo','Westen Province','SRI LANKA','10200','9411718355926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:00:30',0,NULL,3,1,2,1,'\\ ','2010sameeraranga'),(8121,823968450012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','rafagricolamoraes','scrst@ig.com.br','Rafael Aldighieri Moraes','r. Votorantim, 100 - ap. 125 - Bl. 2<br>Vila Nova','Campinas','SP','BRAZIL','13073-090','+55(19) 81374115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:08:08',0,NULL,3,1,2,1,'\\ ','rafagricolamoraes'),(8122,823467596012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','lobadmitriy','dmitriy.lobachev@bakerhughes.com','Dmitriy Lobachev','microdistrict 8, building 9, apartment 34.','Aktau','Mangistau','KAZAKHSTAN','130000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:26:07',0,NULL,3,1,3,1,'RA183618600CN\r ','lobadmitriy\rOTSO004*2'),(8123,606633910013,230395559651,'2.1 Acer AS aspire D250 Bluetooth Module EDR+cable',1,'BTAC2107',12.4,'eastar4','zmnzxkenneth','kenneth18_84@yahoo.com','kenneth muñoz','avenida el belloto 611 casa 23','quilpue','5ta reguion valparaiso','CHILE','2420138','+56985340677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:38:41',0,NULL,3,1,3,1,'RA183620682CN\r ','zmnzxkenneth\rBTAC2107\rAcer 4pin 1.25 15cm \r客户打四美金'),(8124,741294996011,320441575399,'2.1 Acer Aspire 7110 7000 9300 Bluetooth Module +cable',1,'BTAC2108',12.4,'eastar4','hieronimus007','happening007@yahoo.de','Karsten Scheibert','Fiedelerstrasse  16','Hannover','','GERMANY','30519','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:42:32',0,NULL,3,1,2,1,'\\ ','hieronimus007\racer 4pin1.25 18cm'),(8125,822906154012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',49.95,'eastar4uk','don-bx11','hae_tho_don@gmx.de','Thomas Häckl','Geschwister-Scholl-str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 17:52:03',0,NULL,3,1,3,1,'RA183618445CN\r ','don-bx11\rWLAP008'),(8126,742343636011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',38.99,'eastar4uk','milliemoomarjorie','marjie.bartlett@hotmail.co.uk','Marjorie','Archibalds Barbers<br>Northfield Road','Ilfracombe','Devon','UNITED KINGDOM','EX348AL','01271865382','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 18:15:11',0,NULL,3,1,3,1,'RA183618573CN\r ','milliemoomarjorie\rGLSG001'),(8127,742348800011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','razzykal','jozef@shaw.ca','Joseph Yano','2125 STE Cecilia Ave','Saskatoon','SK','CANADA','S7M0P3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 18:26:46',0,NULL,3,1,2,1,'\\ ','razzykal'),(8128,703760322001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','blueeyedmongoose','joannawhitehead@tds.net','joanna whitehead','PO Box 347','hoskinston','KY','UNITED STATES','40844-0347','(606) 672-2605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 18:39:26',0,NULL,3,1,1,1,'\\ ','blueeyedmongoose'),(8129,742380604011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','multispeed33','expertler@web.de','S. Yilmaz','Hueserstrasse 17','Recklinghausen','','GERMANY','45661','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 19:32:19',0,NULL,3,1,2,1,'\\ ','multispeed33'),(8130,742382686011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','bibi2535','fabrice.basset@gmail.com','Basset Fabrice','Roselière 5','Yverdon-les-Bains (VD)','','SWITZERLAND','1400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 19:36:36',0,NULL,3,1,2,1,'\\ ','bibi2535'),(8131,606683635013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','robustez','robustez.ru@gmail.com','Simonian S. Simon','Kolskaya street, 2-5-56','Moscow','','RUSSIAN FEDERATION','129329','(903) 676-8463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 20:00:57',0,NULL,3,1,2,1,'\\ ','robustez'),(8132,742395824011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','anglasparven','annika.forsstrom@netikka.fi','Annika Forsström','Dalitået 16','Jungsund','','FINLAND','65730','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 20:04:34',0,NULL,3,1,2,1,'\\ ','anglasparven\r欧标'),(8133,742407355011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','adrianoss1','adriano.santanna@bol.com.br','Adriano Savastano de Sant Anna','Rua Coronel Diogo, 97<br>Aclimacao','Sao Paulo','Sao Paulo','BRAZIL','01545000','+55 (11) 2609-3053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 20:31:45',0,NULL,3,1,2,1,'\\ ','adrianoss1'),(8134,0,140582816297,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.01,'cnfaner','dgiforest','diego.mur@hotmail.it','Diego Murgia','Via Emilio Morosini 71','Monterotondo','RM','ITALY','00015','06-9064855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 20:55:33',0,NULL,3,1,3,1,'RA183618397CN\r ','dgiforest'),(8135,742424811011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','pamarakos','pamar@the.forthnet.gr','Paschalis Dadoulis','Andrea Papandreou 60','Neapoli','Thessaloniki','GREECE','56728','2310672609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 21:10:36',0,NULL,3,1,2,1,'\\ ','pamarakos'),(8136,742426838011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','davedouwes','davedouwes@winmar.ca','David Douwes','2539 Apls Rd<br>RR # 1','Ayr','ON','CANADA','N0B1E0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 21:16:25',0,NULL,3,1,3,1,'RA183618437CN\r ','davedouwes\rHSJA011'),(8137,686079355008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','mengtk369','jamaxhui5777@yahoo.com.hk','teck meng hiu','417 KG BEBATIK.JALAU MANIS LIMAU MANIS BF2320 NEGARA BRUNEI <br>DARUSSALAN','default','','BRUNEI DARUSSALAM','BF2320','+6738857448','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-28 21:37:01',0,NULL,3,1,3,1,'RA183618511CN\r ','mengtk369\rHSPL015'),(8138,824102699012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','dohc20','cam.guest@sasktel.net','Cameron Guest','220 Rae Street','Regina','SK','CANADA','S4R3L8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 21:41:24',0,NULL,3,1,2,1,'\\ ','dohc20'),(8139,742441254011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','tuffstuff31','mtgman300@aol.com','Todd Garrett','2011 Richard Jones Rd<br>Apt K13','Nashville','TN','UNITED STATES','37215-2840','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 21:53:55',0,NULL,3,1,1,1,'\\ ','tuffstuff31'),(8140,606723173013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','bestgpsgr','best.gps@gmail.com','Michail  F  Kantios','Lysandrou  28  & Kristali<br>Tel : 2104970462','ATTIKH  Nikaia','Ano Neapoli Nikaias  \"  T-526  \"','GREECE','18452','00302104970462','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-28 22:11:59',0,NULL,3,1,3,1,'RA183618542CN\r ','bestgpsgr\rHSNO019\r欧标'),(8141,551935263003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','phucnhavo','phucnha@yahoo.com','Tien P Ngo','13742 Euclid St<br>Apt 8','Garden Grove','CA','UNITED STATES','92843-3404','714 468 7746','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'phucnhavo'),(8142,742468028011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','robert_dameron','rob@neseas.net','Robert Dameron','20609 W Saddle Mountain Cir','Wittmann','AZ','UNITED STATES','85361','(623) 512-5870','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-28 23:27:09',0,NULL,3,1,1,1,'\\ ','robert_dameron'),(8143,606740732013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','kjetilhaga','kjetil.haga@gmail.com','Kjetil Haga','Engveien 30','0487','','NORWAY','OSLO','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 23:33:53',0,NULL,3,1,2,1,'\\ ','kjetilhaga'),(8144,742473393011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',10.39,'eastar4uk','yippydoodle1','connahthorpe@hotmail.com','Connah Thorpe','Station House<br>Caerhowel,','Montgomery','Powys','UNITED KINGDOM','SY15 6HF','78801686668','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 23:48:17',0,NULL,3,1,3,1,'RA183618471CN\r ','yippydoodle1\rWLAT008\r新的'),(8145,742474871011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','pitrain65','pitrain@phed.auth.gr','Panagiotis Ioakeimidis','Pittakou 26','Thessaloniki','','GREECE','TK54645','6977626245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 23:55:35',0,NULL,3,1,2,1,'\\ ','pitrain65'),(8146,0,220819095187,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.1,'eastar4','*irocz*','iroczzcori@gmail.com','Dhillon','8900 Research Park Dr<br>Apt 1823','The Woodlands','TX','UNITED STATES','77381-5255','(650) 469-3511','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 00:32:58',0,NULL,3,1,1,1,'、 ','*irocz*\r一共买了10个'),(8147,606753910013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','cpacorea','vanguard@lycos.co.kr','YUN HYUN-SAM','Hyundai Goldentel 1301<br>Secho-dong 1337-2','Secho-gu','Seoul','KOREA,REPUBLIC OF','137-860','010-6604-0959','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 00:42:10',0,NULL,3,1,3,1,'RA183618499CN\r ','cpacorea\rWLIN014'),(8148,0,130552431888,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.1,'cnfaner','*irocz*','iroczzcori@gmail.com','Dhillon','8900 Research Park Dr<br>Apt 1823','The Woodlands','TX','UNITED STATES','77381-5255','(650) 469-3511','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 00:47:30',0,NULL,3,1,1,1,'、 ','*irocz*\r一共买了10个'),(8149,742492913011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','the_law_man','la_munoz@hotmail.com','Alex Munoz','18281 NW Cambray St','Beaverton','OR','UNITED STATES','97006-3478','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 01:11:23',0,NULL,3,1,1,1,'\\ ','the_law_man'),(8150,0,220819095146,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','apocalyptic*roar','myskillzownu@gmail.com','David Fisher','11993 E S Gratiot Co Line Rd','Elsie','MI','UNITED STATES','48831-9101','(989) 372-0864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 01:18:53',0,NULL,3,1,1,1,'、 ','apocalyptic*roar\r一共买了6个'),(8151,0,130552432396,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.07,'cnfaner','apocalyptic*roar','myskillzownu@gmail.com','David Fisher','11993 E S Gratiot Co Line Rd','Elsie','MI','UNITED STATES','48831-9101','(989) 372-0864','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 01:18:57',0,NULL,3,1,1,1,'、 ','apocalyptic*roar\r一共买了7个'),(8152,742512149011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','cturner937','turner937@gmail.com','Charles Turner','5213 Blue Sky Dr','Orefield','PA','UNITED STATES','18069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 02:27:47',0,NULL,3,1,1,1,'ゝ ','cturner937'),(8153,742516181011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','forrestyakiwchuk','forrestcolin@hotmail.com','Colin Forrest','235 Reunion Court','Airdrie','AB','CANADA','T4B0G8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 02:44:43',0,NULL,3,1,3,1,'RA183618539CN\r ','forrestyakiwchuk\rGLSG001*2'),(8154,606780714013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.4,'eastar4','oilitup','husker92592@verizon.net','Grant G Schaffer','32922 Cinon Dr','Temecula','CA','UNITED STATES','92592-1481','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 02:54:39',0,NULL,3,1,1,1,'\\ ','oilitup'),(8155,8881311908388202,111,'logitech screen 890',50,'SCLO001',800,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 SnowdoniaCove','Bee Cave','TX','UNITED STATES','78738','',NULL,NULL,NULL,NULL,0,NULL,3,1,4,1,'YW866475260CN ',NULL),(8156,824202143012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','carlosandresn','carlosandresn@gmail.com','CARLOS A NEIRA','17 Doris Dr','MILTON','VT','UNITED STATES','05468-3116','(973) 519-0510','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 03:26:03',0,NULL,3,1,1,1,'\\ ','carlosandresn'),(8157,824204580012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','smgray','smgray@gmail.com','Shaun M Gray','16921 Briardale Rd','Derwood','MD','UNITED STATES','20855','(303) 547-6979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 03:35:43',0,NULL,3,1,1,1,'\\ ','smgray\r新的'),(8158,558040145004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','clebio429','clebiogoncalves@hotmail.com','Clébio Gonçalves','Rua torres camara, 1250, apt 201, aldeota','Fortaleza','Ceará','BRAZIL','60150-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 04:09:35',0,NULL,3,1,3,1,'RA183618560CN\r ','clebio429\rHSPL015'),(8159,686169002008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',107.98,'au-buy','lyrix2010','bat.hill@gmail.com','Rebecca Hill','7 Truscott Court','Boulder','Western Australia','AUSTRALIA','6432','0890911968','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 04:09:51',0,NULL,3,1,3,1,'RA183618635CN\r ','lyrix2010\rGLOT001\r兼容型3D眼镜 通用型\r盒装的'),(8160,0,320731885246,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.01,'eastar4uk','soso81-2008','sorinsabau1981@yahoo.com','Sabau Sorin','28 Howard Street','Connahs Quay','Flintshire','UNITED KINGDOM','ch5 4qh','078 49219916','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-29 04:18:32',0,NULL,5,1,3,1,'\\ ','soso81-2008\rANCN001\r已发货'),(8161,606801151013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','chuotlat','the-tu.chau@vishay.com','The-Tu Chau','3605 El Grande Dr','San Jose','CA','UNITED STATES','95132-3114','(408) 926-6813','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 05:11:22',0,NULL,3,1,1,1,'、 ','chuotlat'),(8162,606801773013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','chum-li','chadrconner@hotmail.com','Chad Conner','8005 Avenida Secreto','Carlsbad','CA','UNITED STATES','92009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 05:16:41',0,NULL,3,1,1,1,'、 ','chum-li\r旧的'),(8163,742545737011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',2,'WLIN010+ANTY002',43.76,'eastar4','chiphfb','hbritton@yahoo.com','Herman F. Britton','EOD Technology, Inc<br>FOB Hammer','APO','AE','AA','09308','(603) 617-2476','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 05:22:12',0,NULL,3,1,1,1,'、 ','chiphfb'),(8164,0,140582811870,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.1,'cnfaner','digibaublesla','p1a5244@gmail.com','Richard Westmoreland','240 S Reeves Dr<br>Apt 1','Beverly Hills','CA','UNITED STATES','90212-4036','(310) 858-3855','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 07:00:30',0,NULL,3,1,1,1,'、 ','digibaublesla'),(8165,742564077011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','schautak','schautak@t-online.hu','Ildikó Schauta-Plánder','Ferenc tér 2-3.','Budapest','','HUNGARY','1094','0036302282229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 07:10:57',0,NULL,3,1,2,1,'\\ ','schautak'),(8166,606818323013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','kovalkovmaxim','m@xim.kz','Maxim Kovalkov','4281 Express Line<br>Suite L9935','Sarasota','FL','UNITED STATES','34238','(832) 659-5412','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 07:19:55',0,NULL,3,1,1,1,'、 ','kovalkovmaxim'),(8167,0,230650485289,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.01,'eastar4','jcgobanza','justin.clarke@gmail.com','Justin Clarke','425 1st St<br>Unit 2505','San Francisco','CA','UNITED STATES','94105-4628','(415) 683-6722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 07:24:43',0,NULL,3,1,1,1,'、 ','jcgobanza'),(8168,703958259001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK001',96,'buysia','aiuto58','abecedario1965@libero.it','MANCA OTTAVIANO','VICO ANNICCHIO N°39','SQUINZANO','LECCE','ITALY','73018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 07:37:38',0,NULL,3,1,3,1,'RA183618644CN\r ','aiuto58\rHSAK001\r\r\r'),(8170,742583989011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','ykovachev','lyouman@yahoo.com','Yuliyan Kovachev','BUL LIPNIK 117<br>MITNICA RUSSE','RUSSE','BULGARIA','BULGARIA','07000','+359886291393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 08:39:54',0,NULL,3,1,2,1,'\\ ','ykovachev'),(8169,606823003013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','ploopy','pamnfam@gmail.com','Pamela Jorgensen','4082 E Palm Beach Dr','Chandler','AZ','UNITED STATES','85249','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 07:53:00',0,NULL,3,1,1,1,'、 ','ploopy\r红边优联'),(8171,824269990012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',19.99,'eastar4uk','hvidehenning','kontakt@startside.info','Martin Malm','Nysøvænget 52','Terslev','Zeeland','DENMARK','4690','+4531231969','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 08:50:40',0,NULL,3,1,2,1,'\\ ','hvidehenning\rIBM版'),(8172,606837112013,230653156192,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',47.99,'eastar4','mr.haru','killahxsin_95@hotmail.com','Garlo Li','2 Bonaparte Street<br>Riverwood','Sydney','New South Wales','AUSTRALIA','2210','0424588469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 09:17:00',0,NULL,3,1,3,1,'RA183617502CN ','mr.haru\rHSIT001\r澳标\r盒装的'),(8173,742459580011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',34.8,'eastar4','objetfetiche','silicium@orange.fr','Emmanuel Coulon','6 rue André Maurois','Le Buisson de Cadouin','Aquitaine','FRANCE','24480','06.78.85.83.57','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 09:18:57',0,NULL,3,1,3,1,'RA183617414CN ','objetfetiche\rCASS002\r再发两个CAB-6060'),(8174,742597706011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',12.99,'eastar4','tomse0008','tomse@tomse.dk','Carsten Jensen','Fagotvej 6','Tangbjerg (Oelstykke)','DK','DENMARK','3650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 09:38:16',0,NULL,3,0,2,1,'\\ ','tomse0008\r发210T\r已入库'),(8175,8881311932376266,111,'NIB SSG-2100AB  with blu-ray',5,'GLSG001*2',600,'eastar4','selectgametienda','gusmlg86@hotmail.com','AGUSTIN MANUEL ALMAGRO ROJAS','C/ ARAGONITO 7A<br>CP 29190 ',' PUERTO DE LA TORRE (MALAGA)','','SPAIN','','',NULL,NULL,NULL,NULL,0,NULL,3,1,6,1,'EE495341051CN ',' Tel: 667572708   with blue-ray  new in box \r10 pairs'),(8176,606858963013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','electro_gee','aysan@comporium.net','Nazmi Aysan','622 Springhouse Pl','Lake Wylie','SC','UNITED STATES','29710-9240','(704) 904-3105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 11:21:45',0,NULL,3,1,1,1,'、 ','electro_gee\r由于没有下来改的\rLK003664622CN'),(8177,742631602011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','jefftut123','jean.quint@neuf.fr','Jean-Francois QUINT','6 rue des Pinsons','SARCELLES','Île-de-France','FRANCE','95200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 11:48:00',0,NULL,3,1,2,1,'、 ','jefftut123'),(8178,742633887011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','w8pxyi','orosz.istvan1@chello.hu','István Orosz','Tátra u. 29. 1/2','Miskolc','','HUNGARY','H-3532','36307566533','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 11:58:48',0,NULL,3,1,2,1,'、 ','w8pxyi'),(8179,824325667012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','surickaban','surickaban@yahoo.co.uk','Alexandr Litvinov','Alba Iulia 2<br>Ap. 12','Chisinau','','MOLDOVA, REPUBLIC OF','2064','+37369050534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 12:15:11',0,NULL,3,1,2,1,'、 ','surickaban'),(8180,742647305011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','mariobiker','marioracer@aol.com','Mario Wahlbuhl','An der alten Mühle 2','Leipzig','','GERMANY','04356','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 12:45:02',0,NULL,3,1,3,1,'RA183620339CN\r ','mariobiker\rWWSI002+ANCN001'),(8181,606883151013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','torahnomics','sheldon@liberman.com','Sheldon Liberman','50 Alness St.<br>2nd Floor','Toronto','ON','CANADA','M3J 2G9','(416) 783-0505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 13:17:50',0,NULL,3,1,2,1,'、 ','torahnomics'),(8182,606895307013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mistercatnap','poc0loco@hotmail.com','Joseph Petraglia','1130 1/2 Oliver Ave','San Diego','CA','UNITED STATES','92109-5137','(858) 412-5440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 14:11:38',0,NULL,3,1,1,1,'、 ','mistercatnap\r由于没有下来改的\rLK004971584CN'),(8183,824365367012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.4,'eastar4','cassiotk','cassiolengler@hotmail.com','cassio lengler cardoso','rua da paz ,  bairro Prado<br>Number 402','taquari','rio grande do sul','BRAZIL','95860-000','555136533832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 14:13:17',0,NULL,3,1,2,1,'、 ','cassiotk');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (8184,824365108012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','gabriel_mp','gabriel.penteado@uol.com.br','Gabriel Malavazzi Penteado','Rua Alcindo Bueno de Assis 126','Sao Paulo','Sao Paulo','BRAZIL','02344080','+55(11)29917696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 14:13:48',0,NULL,3,1,3,1,'RA183620400CN\r ','gabriel_mp\rWWOT001'),(8185,558134270004,140583346344,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',2,'HSPL001',29.98,'cnfaner','lgoworld','3q.worldwide@gmail.com','Rami Hermiz','633 Polding St','Bossley Park','New South Wales','AUSTRALIA','2176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 14:18:02',0,NULL,5,1,18,1,NULL,'lgoworld\rHSPL001'),(8186,742682764011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','fotisgotsis1','fotisgotsis13@gmail.com','ΦΩΤΙΟΣ ΓΚΟΤΣΗΣ','ΜΑΡΑΘΩΝΟΣ 5','ΑΙΓΑΛΕΩ','ΕΛΛΑΔΑ/ΑΘΗΝΑ/ΑΤΤΙΚΗ','GREECE','12244','0306947376972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 14:35:32',0,NULL,3,1,2,1,'、 ','fotisgotsis1\r盒装的'),(8187,742693440011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','rarebird18','akouporov@gmail.com','Alexander Kuporov','Pokryshkina str. 11 - 365','Moscow','','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 15:11:02',0,NULL,3,1,2,1,'、 ','rarebird18'),(8188,606918455013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','andysales1970','andersonsales@uol.com.br','anderson sales','rua mariz e barros, n.370 / ap 1201','niteroi','rio de janeiro','BRAZIL','24.220-121','+55 021 88978653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 15:41:38',0,NULL,3,1,2,1,'、 ','andysales1970'),(8189,742709156011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','flagpointsandhills','ruse50@cableone.net','DAVID RUSE','8910 Lamar Ave','ODESSA','TX','UNITED STATES','79765-1421','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 15:52:01',0,NULL,3,1,1,1,'、 ','flagpointsandhills由于没有下来改的\rLK006465356CN'),(8190,606921165013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','snafu1138','m_comstock@hotmail.com','Michael Comstock','3927 Ridgecrest Cir','Taylorsville','UT','UNITED STATES','84118-4148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 15:56:22',0,NULL,3,1,1,1,'\\  ','snafu1138\r旧的\r由于没有下来改的LK029527527CN'),(8191,824429205012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',7.9,'eastar4','dcoddens','danrobbinok@yahoo.com','Dan Coddens','16347 Garrett Way','Marshall','MI','UNITED STATES','49068-8320','(269) 789-2757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 16:57:52',0,NULL,3,1,1,1,'\\  ','dcoddens\r旧的'),(8192,742738467011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','im2bradthedad','bradford.west@gmail.com','Bradford J West','5940 Everett St','Arvada','CO','UNITED STATES','80004-5454','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 17:04:21',0,NULL,3,1,1,1,'\\  ','im2bradthedad'),(8193,824434621012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','alfacuore','cuore@telkomsa.net','Roshan Raghubeer','129 Annet Drive<br>Reservoir Hills','Durban','Kwa-Zulu/Natal','SOUTH AFRICA','4091','0814282923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 17:09:21',0,NULL,3,1,3,1,'RA183620033CN ','alfacuore\rGLSG001*2\r盒装的\r'),(8194,742746473011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',107.99,'eastar4uk','watkins1983','hazejw1983@aol.com','hayley watkins','6 seymour close<br>shirley','southampton','Hampshire','UNITED KINGDOM','so16 6rf','07774127378','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 17:26:37',0,NULL,3,1,3,1,'RA183620020CN ','watkins1983\rGLSG001*3\r'),(8195,742748536011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','matko2010','matko.ruzic@gmail.com','Matko Ružić','Tome Čikovića 23','Koprivnica','Croatia','CROATIA','48 000','098 550 592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 17:30:58',0,NULL,3,1,2,1,'、 ','matko2010'),(8196,742756065011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','khwankhaew','mkhwan@yahoo.com','Somphopp  Achawakijkoson','550/6 Soi Phopun<br>Asok-Dindang Road','Dindang','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 17:48:50',0,NULL,3,1,2,1,'、 ','khwankhaew'),(8197,742764512011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','lukeps1980','lukesutton@me.com','Luke Sutton','33 Honey Close','Norwich','Norfolk','UNITED KINGDOM','NR1 4LJ','01603432263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 18:06:56',0,NULL,3,1,3,1,'RA183620121CN\r ','lukeps1980\rUDAP001\r一共买了两个'),(8198,742770592011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','lukeps1980','lukesutton@me.com','Luke Sutton','33 Honey Close','Norwich','Norfolk','UNITED KINGDOM','NR1 4LJ','01603432263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 18:20:12',0,NULL,3,1,17,0,NULL,'lukeps1980'),(8199,742792086011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','redsport00','burtonjf@ieee.org','John Burton','473 Bramans Ln','Portsmouth','RI','UNITED STATES','02871-3303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 19:13:59',0,NULL,3,1,1,1,'\\  ','redsport00\r install driver'),(8200,824506904012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',23.99,'eastar4uk','neil0wheatley','neil_wheatley@ihug.com.au','Neil Wheatley','6/48 Cambridge St<br>Stanmore','Sydney','New South Wales','AUSTRALIA','2048','020412901111','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 19:40:17',0,NULL,3,1,3,1,'RA183620311CN\r ','neil0wheatley\rOTRA001\r'),(8201,742803656011,320692106584,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',99.99,'eastar4','fotoquero','gabrielforia@gmail.com','Gabriel Fernando Foria','Arana y Goiri<br>6541','Mar del Plata','Buenos Aires','ARGENTINA','7600','054-223-4825870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 19:40:45',0,NULL,3,1,3,1,'RA183620016CN ','fotoquero\rOTSO004+OTSO003\r再发一个NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable'),(8202,824507648012,220501842033,'2.1 Acer Aspire 6920 6920G Bluetooth Module  EDR+cable',1,'BTAC2117',12.4,'eastar4','jtbalenton','balenton@lclark.edu','JEFF BALENTON','7360 SW Barbur Blvd<br>Apt 13','Portland','OR','UNITED STATES','97219-2859','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 19:40:57',0,NULL,3,1,1,1,'\\  ','jtbalenton\racer 8pin0.8 16cm'),(8203,824522083012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','tda1732','tduraes2@hotmail.com','Thiago Durães Alves','Rua Enéias Miranda, nº 22<br>Quadra 44','São João de Meriti','Rio de Janeiro','BRAZIL','25540-000','+552195429676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 20:17:32',0,NULL,3,1,2,1,'、 ','tda1732'),(8204,605608073013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',95,'eastar4','cavallorossof40','cavallorossof40@web.de','Manolito Ravalli','An der Schönen Fulda 6','Eichenzell','','GERMANY','36124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 20:32:01',0,NULL,3,1,3,1,'RA183620118CN ','cavallorossof40\rMOSA006'),(8205,607009698013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dasha_danger','bcheeta@aol.com','Ainsley McWaters','216 Quail Ridge Dr','Simpsonville','SC','UNITED STATES','29680-6607','(864) 313-6504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 20:41:15',0,NULL,3,1,1,1,'\\  ','dasha_danger'),(8206,824542559012,220815931403,'New Replaceable Shell for logitech Mouse G500',1,'SHLO006',9.99,'eastar4uk','h-bogaers','hbogaers@home.nl','harrie bogaers','moerdijkerf 1','tilburg','','NETHERLANDS','5045JR','0613132229','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 20:57:20',0,NULL,3,1,2,1,'、 ','h-bogaers'),(8207,742842661011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',75.99,'eastar4','fotoquero','gabrielforia@gmail.com','Gabriel Fernando Foria','Arana y Goiri<br>6541','Mar del Plata','Buenos Aires','ARGENTINA','7600','054-223-4825870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 21:15:08',0,NULL,3,1,17,0,NULL,'fotoquero'),(8208,824553366012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','j.adel','e.adel@arcor.de','Jad Jalloul','Rendsburger Str. 2','Wahlstedt','','GERMANY','23812','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 21:26:10',0,NULL,3,1,2,1,'、 ','j.adel\r欧标'),(8209,742850003011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','gkomardjaja','gkomardjaja2003@yahoo.com.au','gunawan komardjaja','17/2 King Street','Kogarah','New South Wales','AUSTRALIA','2217','0280333666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 21:32:32',0,NULL,3,1,2,1,'、 ','gkomardjaja'),(8210,824561228012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',1,'HSJA006',9.49,'eastar4uk','s_babybeii','serena32@hotmail.co.uk','serena josephs','85 wheatmoor road<br>sutton coldfield','birmingham','West Midlands','UNITED KINGDOM','b757js','01213785046','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 21:44:00',0,NULL,3,1,3,1,'RA183620095CN ','s_babybeii\r英标\rHSJA006'),(8211,824564621012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','baheepreet99','preeti31280@gmail.com','Preeti Prithyani','Henrik Sørensensvei 39','Oslo','','NORWAY','1065','+47 9059 6491','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 22:04:28',0,NULL,3,1,2,1,'\\  ','baheepreet99\r24K 多色伞'),(8212,742860974011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','kewlmart','martynoel@gmail.com','Martin Noel','528 rue des Ormeaux','Montreal','QC','CANADA','H1L 4W8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 22:06:24',0,NULL,3,1,2,1,'、 ','kewlmart'),(8213,607042492013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','infiniteingenuity','jason.w.wainwright@gmail.com','Jason Wainwright','95-1022 Kailewa St','Mililani','HI','UNITED STATES','96789-4286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-29 22:56:19',0,NULL,3,1,1,1,'\\  ','infiniteingenuity'),(8214,824588743012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','pedroc0_0','pedrocadiz@blueyonder.co.uk','Peter Johnstone','54 Carrick Knowe avenue','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH12 7BY','01315396483','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 23:08:10',0,NULL,3,1,3,1,'RA183620183CN\r ','pedroc0_0\rWLAP008'),(8215,552723014003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',66.9,'cnfaner','kbassi2007','kellenbassi@mmcb.com.br','KELLEN APARECIDA BASSI','JOSÉ RAMON URTIZA N:181<br>APTO 161-A','SÃO PAULO','SÃO PAULO','BRAZIL','05717-270','55-11-56942805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:35:06',0,NULL,3,1,3,1,' RA183620078CN','kbassi2007\rMOSA003'),(8216,742887254011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.4,'eastar4','jlmar0123','marche.jeanlouis@orange.fr','Jean-Louis Marche','2 rue Rochet','Breurey Les Faverney','Franche-Comté','FRANCE','70160','0384913384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:43:18',0,NULL,3,1,2,1,'、 ','jlmar0123\racer 5pin1.25 4cm'),(8217,742887456011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','diegosan007','diegosaca@gmail.com','Diego  Santos Castiñeira','c/ Lago Blanco 2, portal 16, 1ºB','PARLA','Madrid','SPAIN','28981','690070441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:54:33',0,NULL,3,1,3,1,'RA183620047CN ','diegosan007\rGLSG001*2'),(8218,742888989011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','teimhneain','rptynan@hotmail.com','Richard Tynan','Whitethorn<br>Tierhogar','Portarlington','Laois','IRELAND','ROI','0578640376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:56:37',0,NULL,3,1,2,1,'、 ','teimhneain\racer 4pin1.25 8cm'),(8219,607058324013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','3426elizabeth','es4789@aol.com','Elizabeth SMITH','215 ARROWOOD RD','TYRONE','GA','UNITED STATES','30290-2084','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 00:26:19',0,NULL,3,1,1,1,'\\  ','3426elizabeth'),(8220,742917208011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','tatakrasa','tatianakrasavina@mail.ru','Татьяна Красавина','бульвар Строителей 26/1 кв69','Кемерово','Кемеровская область','RUSSIAN FEDERATION','650060','8 (953) 060-0805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 02:09:25',0,NULL,3,1,3,1,'RA183620223CN\r ','tatakrasa\rHBPH002'),(8221,558302815004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','richang2009','rc_ccl@rediffmail.com','Richard Chang','5, South Tangra Road<br>Opp. Hyundai Service Centre, Tangra','Kolkata','West Bengal','INDIA','700046','9830880329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 03:06:45',0,NULL,3,1,3,1,'RA183620197CN\r ','richang2009\rWLAP008'),(8222,824656710012,220502333404,'2.1 HP 8710w nw9440 nx9420 Bluetooth Module EDR +cable',1,'BTHP2105',12.4,'eastar4','seugor','seugor@bigpond.net.au','Mark Rogan','P.O. Box 210','Belgrave MDC','Victoria','AUSTRALIA','3160','0407523910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 03:58:44',0,NULL,3,1,2,1,'、 ','seugor\rHP 8pin 1.0 20cm'),(8223,824671365012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','piyuchan','leen_yee@hotmail.com','Dien Chuong Phung','1150 Bélanger Est #709','Montreal','QC','CANADA','H2S1H5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 05:19:40',0,NULL,3,1,2,1,'\\  ','piyuchan\r24K 多色伞 '),(8224,704306338001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',52.98,'buysia','logic79meltdown','mike_mercier@sympatico.ca ','Mayka Mercier','5926 Bélanger est,St-Léonard','Montréal','QC','CANADA','H1T1G7','(514) 254-8741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 05:23:14',0,NULL,3,1,3,1,'RA183620245CN\r ','logic79meltdown\rBR3D004+BR3D006\r再发一个\rICE AGE 3 New Panasonic sealed 3D Blu-ray tracking#\r'),(8225,742963867011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','junglejim_sg','kimjim_007@hotmail.com','Leow Sin Lak','Centre for Instructional Technology<br>2 Engineering Drive 4','Singapore','','SINGAPORE','117584','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 06:17:56',0,NULL,3,1,11,1,'、 ','junglejim_sg\rHSJA006\r英标'),(8226,742965781011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','360546','paulstephenson@verizon.net','Paul Stephenson','312 W Giddens Ave','Tampa','FL','UNITED STATES','33603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 06:28:57',0,NULL,3,1,1,1,'\\  ','360546'),(8227,607116300013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','g_dls','g_dls@hotmail.com','Guillaume De la Sablonnière','10640 Sacré-Coeur app.5','Montréal','QC','CANADA','H2C 2S9','(450) 280-9184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 07:13:36',0,NULL,3,1,2,1,'、 ','g_dls'),(8228,8881312013785322,111,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',10,'HSSE005',223,'cnfaner','bogunovic46','zulee46@yahoo.com','Dalibor Jokic','Im Hasenacker 15','Nentershausen','','GERMANY','56412','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183620427CN ',' 欧标\rHSSE005'),(8229,824708590012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','juliejonno','jools.johnston99@btconnect.com','Julie Johnston','35 Old Earth','Elland','West Yorkshire','UNITED KINGDOM','HX59ES','07753663753','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 08:17:17',0,NULL,3,1,3,1,'RA183620081CN ','juliejonno\rHSMO017\r英标'),(8230,743005382011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','alastair1308','ali2804@btinternet.com','Alastair Mearns','11 Netherbog road','Dumbarton','Dunbartonshire','UNITED KINGDOM','G82 2HT','01389765496','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 09:25:50',0,NULL,3,1,3,1,'RA183620254CN\r ','alastair1308\r英标\rHSJA011'),(8231,558357364004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.99,'cnfaner','frasia_octavian','frasiaoctavian@gmail.com','Raluca Colojoara','Burebista nr.3, sc.B, ap.7','Timisoara','','ROMANIA','300659','0726580168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 10:01:52',0,NULL,3,1,3,1,'RA183620152CN ','frasia_octavian\rOTSO002'),(8232,686610829008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','bradley4080','bcarby@bigpond.net.au','Bradley Carby','9 Harlequin Street','Toolooa','Queensland','AUSTRALIA','4680','0418753741','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 10:19:26',0,NULL,3,1,3,1,'RA183620435CN\r ','bradley4080\rHSPL015\r澳标'),(8233,552819198003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',39.9,'cnfaner','bblokar3','bogdan_blokar@rocketmail.com','Bogdan Blokar','Zupanciceva ulica 3','Ajdovscina','','SLOVENIA','5270','+38659930441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 10:45:33',0,NULL,3,1,3,1,'RA183620373CN\r ','bblokar3\rHSNO019\r欧标'),(8234,558365215004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','trikom1979','trikom@list.ru','Vladimir Nayakshin','str.Engels,5-39','Volzhsky','Volgogradsky','RUSSIAN FEDERATION','404111','89275004999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 10:46:18',0,NULL,3,1,3,1,'RA183620285CN\r ','trikom1979\rWLAP008'),(8235,824757202012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','stapostle','mail@decross.ru','Nathanael de Cross','Brateevskaya st., 18k3, 108','Moscow','Moscow','RUSSIAN FEDERATION','115408','9166413884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 11:11:26',0,NULL,3,1,2,1,'\\  ','stapostle\r24K 多色伞 '),(8236,742992831011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.99,'eastar4','pukpha','injeo_i@yahoo.com','Sompopp  Achavakijkosol','550/6 Soi pho-pun Asok-dindang rd,','Dindang','Bangkok','THAILAND','10400','66877855535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 11:42:25',0,NULL,3,1,2,1,'、 ','pukpha\r带麦的'),(8237,743046392011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','euneuneu','francois.nokia@gmail.com','Francois BARROERO','221 Avenue des AIRES','Gardanne','Provence-Alpes-Côte d\'Azur','FRANCE','13120','0664838545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 11:54:01',0,NULL,3,1,2,1,'、 ','euneuneu'),(8238,743052997011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','superspy31','superspy31@hotmail.com','Paramjit Srai','161 Dunstall Avenue, Whitmore Reans','Wolverhampton','West Midlands','UNITED KINGDOM','wv6 0ng','01902830722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 12:15:41',0,NULL,3,1,3,1,'RA183620308CN\r ','superspy31\rRCLO006\r新的'),(8239,743071138011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','maheo67','john@bestwindows.net','john wrzesinski','1112 cleveland ave','la grange park','IL','UNITED STATES','60526-1302','(708) 204-2446','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 13:16:01',0,NULL,3,1,1,1,'\\  ','maheo67\r兼容型3D眼镜  samsung 专用'),(8240,743072746011,320721819789,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',23.99,'eastar4','cdavin_84','catherinedavin@hotmail.com','Catherine Davin','5 CHIANTI CRT<br>Pearsall','Perth','Western Australia','AUSTRALIA','6065','0402349728','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 13:20:02',0,NULL,3,1,2,1,'\\  ','cdavin_84\r黑底七色边彩虹伞 '),(8241,824809327012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',29.9,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 13:50:21',0,NULL,3,1,2,1,'、 ','small.mac'),(8242,743088171011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','thisisajob','rzaguli@sbcglobal.net','Ronald Zaguli','16811 Village Corner Ct.','Houston','TX','UNITED STATES','77059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 14:06:13',0,NULL,3,1,1,1,'\\  ','thisisajob'),(8243,824816240012,220816785876,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',6.9,'eastar4uk','nikwest7','nikw1234@aol.com','Nik West','17/10-16 Melrose Parade','Clovelly','New South Wales','AUSTRALIA','2031','0468718930','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-30 14:07:52',0,NULL,3,1,2,1,'、 ','nikwest7'),(8244,824817499012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','kjw300','krystle913@yahoo.com','KRYSTLE WHITE','16311 W 124th St','OLATHE','KS','UNITED STATES','66062-1163','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 14:11:04',0,NULL,3,1,1,1,'\\  ','kjw300'),(8245,824819641012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',12.5,'eastar4','2011*stanislav','stanislav@homemail.com','Stanislav Kolotovskiy','Mira Str. 24-35','Saint-Petersburg','','RUSSIAN FEDERATION','197101','(812)2320340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 14:18:04',0,NULL,3,1,2,1,'\\ ','2011*stanislav\racer 8pin1.00 8cm '),(8246,743096526011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',43.16,'eastar4','kdav2429','smiles1@hurleymc.com','Kenneth Davis','3174 Birch Ln Dr','Flint','MI','UNITED STATES','48504','(810) 625-1836','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 14:28:18',0,NULL,3,1,1,1,'\\  ','kdav2429'),(8247,743129160011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ectin','ecwischmann@web.de','Christine Mosemann','Promenadenstraße 14c','BERLIN','','GERMANY','12207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 16:00:21',0,NULL,3,1,2,1,'、 ','ectin'),(8248,607233219013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',99.96,'eastar4','joshua301','jslick4@yahoo.com','Joshua Chamberlain','14753 Archwood St','Van Nuys','CA','UNITED STATES','91405','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 16:18:40',0,NULL,3,1,1,1,'\\  ','joshua301'),(8249,743145003011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jacksonharper','jacksonh@gmail.com','Jackson Harper','3303 Village Rd W','Norwood','MA','UNITED STATES','02062-2544','(213) 446-9960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 16:37:30',0,NULL,3,1,1,1,'\\  ','jacksonharper'),(8250,743160314011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','afnf','erikmckee@cox.net','Erik McKee','2615 SE Virginia Avenue','Topeka','KS','UNITED STATES','66605','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 17:13:14',0,NULL,3,1,1,1,'\\  ','afnf'),(8251,743176434011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','frfaraone07hq','frfaraone@sbcglobal.net','Frank Faraone','165 Canyon Place','Napa','CA','UNITED STATES','94558','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 17:51:05',0,NULL,3,1,1,1,'\\  ','frfaraone07hq'),(8252,607262815013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',104.95,'eastar4','jcas7481','slcasanova@att.net','John Casanova','1348 Blanco Woods St','San Antonio','TX','UNITED STATES','78248-1401','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 17:56:44',0,NULL,3,1,1,1,'\\  ','jcas7481\r兼容型3D眼镜 通用型'),(8253,607268520013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','haximob','egeeky@gmail.com','Pavel Isaev','Leninskiy prosp. d.85 k.5 kv.61','Moscow','RU','RUSSIAN FEDERATION','119261','+79160569436','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 18:12:00',0,NULL,3,1,2,1,'、 ','haximob\rANTY001+WLAT001\r新的\r再发一个A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna'),(8254,824932591012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',13.99,'eastar4uk','topmuddle','ianadams1980@ntlworld.com','jeanette adams','12 bockhanger lane kennington','ashford','Kent','UNITED KINGDOM','tn249bn','01233629359','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 18:34:24',0,NULL,3,1,3,1,'RA183620237CN\r ','topmuddle\r英标\rHSMO019'),(8255,824933284012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','haximob','egeeky@gmail.com','Pavel Isaev','Leninskiy prosp. d.85 k.5 kv.61','Moscow','RU','RUSSIAN FEDERATION','119261','+79160569436','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 18:35:20',0,NULL,3,1,17,0,NULL,'haximob'),(8256,743210762011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','jansku999','jpjn1@jippii.fi','Jani Neiglick','Pihkatie 14','Heinola','Heinola','FINLAND','18120','+358447832531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 19:05:47',0,NULL,3,1,2,1,'、 ','jansku999'),(8257,607294398013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',18.5,'eastar4','yu-rolex','yurolex@gmail.com','Yuriy Oleksiychuk','7 Gagarin St. App 1','Ostroh','Rivne region','UKRAINE','35800','(067) 767 - 0144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 19:34:03',0,NULL,3,1,2,1,'\\ ','yu-rolex\r挑个划痕小点的\r银色的'),(8258,607299024013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','candabossladytexas','canda_bossladytexas@msn.com','Canda Snyder','6316 Rincon Way','Dallas','TX','UNITED STATES','75214-2039','(972) 339-0530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 20:02:55',0,NULL,3,1,1,1,'\\  ','candabossladytexas\r黑色的'),(8259,607304444013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',87,'eastar4','dcwholesale','admin@dcwholesale.co.nz','Anthony Payne','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 20:04:57',0,NULL,3,1,3,1,'RA183620104CN ','dcwholesale\rCAB-6060'),(8260,0,130552430089,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.08,'cnfaner','vodef','voidef@gmail.com','Vitaliy Osaulenko','83, Zavodska street','Svitlovodsk','Kirovohrad region','UKRAINE','27507','0667705092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 20:31:47',0,NULL,3,1,3,1,'RA183620268CN\r ','vodef\rANCN001\r一共买了三个'),(8261,824994675012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','dianettee20','dianapopa_a@yahoo.com','Diana Popa','115 Minterne Waye<br>Hayes','London','Middlesex','UNITED KINGDOM','UB4 0PF','07738229248','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 20:52:59',0,NULL,3,1,3,1,'RA183620395CN\r ','dianettee20\rRELO002\r'),(8262,743276768011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','taznutt45','ckozl759@sbcglobal.net','Carl Koziol','2657 W 87th St','Evergreen Park','IL','UNITED STATES','60805','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 21:53:26',0,NULL,3,1,1,1,'\\  ','taznutt45'),(8263,825035485012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','hitechyou2011','gedas1983@gmail.com','Gediminas Rimselis','6 Soldiers View<br>Boghall Road','Bray','Wicklow','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 22:42:41',0,NULL,3,1,3,1,'RA183620170CN\r ','hitechyou2011\rWWOT002\rIBM版 二手'),(8264,607345088013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dralcaraz','alcarazdan@gmail.com','Daniel Alcaraz','13023 Carriage Rd','Poway','CA','UNITED STATES','92064-5504','(858) 568-2360','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 22:44:08',0,NULL,3,1,1,1,'\\  ','dralcaraz'),(8265,824609250012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','shah-8960','shah_8960@yahoo.co.uk','waqas shah','21dernford aevenue<br>manchester','manchester','Greater Manchester','UNITED KINGDOM','m191du','07412681278','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 23:45:34',0,NULL,3,1,3,1,'RA183620458CN\r ','shah-8960\r英标\rHSJA010'),(8266,558551173004,140584765173,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',64.9,'cnfaner','rjrafaelsoares2010','rjrafaelsoares@hotmail.com','RAFAEL ROCHA SOARES','ESTRADA DA BASE NAVAL DE ARATU, S/N<br>RUA A CASA 08 VILA NAVAL DE INEMA - SÃO THOMÉ DE PARIPE','SALVADOR','BAHIA','BRAZIL','40800310','55(71)9179-9495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 23:45:57',0,NULL,3,1,3,1,'RA183620210CN\r ','rjrafaelsoares2010\rHDSG001'),(8267,825060037012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','fordvette72','ford88vette72@aol.com','rick terrell','4102 E 76th Ave','terre haute','IN','UNITED STATES','47805','(217) 442-6634','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 00:31:35',0,NULL,3,1,6,1,'EE495341048CN ','fordvette72'),(8268,825078780012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','heddok55','bfried@telus.net','Brad Friedrick','6811 East Sooke Road','Sooke','BC','CANADA','V9z 1A7','(250) 642-6851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 01:33:11',0,NULL,3,1,3,1,'RA183620149CN ','heddok55\rWWOT003'),(8269,607383474013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',9.99,'eastar4','paramedic222','kyledesiree@gmail.com','Kyle Bridges','1042 Bond St','Neosho','MO','UNITED STATES','64850-2044','(417) 438-5400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 02:20:54',0,NULL,3,1,1,1,'\\  ','paramedic222'),(8270,607388087013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','poonhunter','alpaca_66@hotmail.com','Alfredo P Carranza','591 E Bonita Ave<br>Apt C','San Dimas','CA','UNITED STATES','91773-3181','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 02:48:39',0,NULL,3,1,1,1,'\\  ','poonhunter'),(8271,607388414013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',85.99,'eastar4','davidwb88','davidwb88@comcast.net','David Brisker','12340 20th Ave NE','Seattle','WA','UNITED STATES','98125-5132','(206) 417-9841','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 02:51:08',0,NULL,3,1,1,1,'、 ','davidwb88'),(8272,743351781011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','highperformance3','asmgt2@gmail.com','ARMANDO SUAZO','10847 NW 7th St<br>Apt 24','MIAMI','FL','UNITED STATES','33172-3763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 03:00:30',0,NULL,3,1,1,1,'\\  ','highperformance3'),(8273,607399761013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','jfactor2004','jcafaro10@gmail.com','JP Cafaro','990 Union St','San Francisco','CA','UNITED STATES','94133-2629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 04:05:50',0,NULL,3,1,1,1,'\\ ','jfactor2004\r旧的'),(8274,607411136013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','arthurszpak','arthur.szpak@gmail.com','Arthur Szpak','1610 Ross Rd.','North Vancouver','BC','CANADA','V7J 1V4','(778) 338-4712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 05:36:51',0,NULL,3,1,2,1,'、 ','arthurszpak'),(8275,743411686011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',53.99,'eastar4','fox_racing70','jpierre.petit@skynet.be','jean-pierre petit','allee du bois de bercuit 35','Grez Doiceau','belgium','BELGIUM','1390','0475455270','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 08:09:39',0,NULL,3,1,3,1,'RA183620299CN ','fox_racing70\r兼容型3D眼镜 通用型\rGLOT001\r盒装的'),(8276,607435483013,230646635106,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',2,'',149.98,'eastar4','sashasobol','sasha-sobol@ya.ru','Александр Соболь','2-микрорайон д 7 кв 11','Богородск','Нижегородская','RUSSIAN FEDERATION','607600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 08:17:26',0,NULL,3,0,3,1,'RA183620342CN\r ','sashasobol\r已入库'),(8277,607433704013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','orotacom','filimawi@yahoo.com','efrem Embaye','Flat  07 McCabe Court<br>99 Barking Road','London','London','UNITED KINGDOM','E16 4HE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 08:20:29',0,NULL,3,1,2,1,'、 ','orotacom\rCAB-6060'),(8278,743419672011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',107.99,'eastar4uk','andy314','willettandrew@hotmail.com','Mr Andrew Willett','Ringstrasse 41','Paderborn-Sennelager','','GERMANY','33106','052546499035','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-31 08:38:05',0,NULL,3,1,3,1,'RA183620413CN ','andy314\rGLSG001*3'),(8279,825179287012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','joseantonio7carmen','esa_rubia_1986@hotmail.com','jose antonio jimenez gonzalez','jacinto benavente nº 14 bajo b','almoradi','Comunidad Valenciana','SPAIN','03160','653397299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 09:04:31',0,NULL,3,1,3,1,'RA183620492CN ','joseantonio7carmen\r\r\r'),(8280,825185217012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','speedvulture','christian_geirhos@gmx.net','Christian Geirhos','Austrasse 2','Siegertshofen','','GERMANY','86850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 09:10:26',0,NULL,3,1,2,1,'、 ','speedvulture\r新的'),(8281,607459124013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','anmg2011','a.gangan@gmail.com','Andrey Gangan','ul. Molodyozhnaya, 60<br>Britovka','Belgorod-Dnestrovsky rayon,','Odessa region','UKRAINE','67755','+380484946687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 09:55:19',0,NULL,3,1,3,1,'RA183620271CN\r ','anmg2011\rWLIN002'),(8282,825203898012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','foreigner77','beelzebub77@hotmail.co.kr','Hojin Kim','103-1305 Sinchang Vivafamily Apt.<br>Dongducheon-dong   Dongducheon-si','Gyeonggi-do','','KOREA,REPUBLIC OF','483-080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 09:59:51',0,NULL,3,1,2,1,' 、','foreigner77'),(8283,825203975012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','mrtracey','neil_tracey11@msn.com','Neil Tracey','19 Baden Terrace<br>Penyard','Merthyr Tydfil','Mid Glam','UNITED KINGDOM','CF47 0HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 10:00:05',0,NULL,3,1,3,1,'RA183620360CN\r ','mrtracey\rHSMO017\r英标'),(8284,825213239012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','suneth85','suneth85@hotmail.com','Stephanie Yeo','Wincor Nixdorf<br>2 Kallang Sector','default','','SINGAPORE','349277','+65-98308056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 10:24:10',0,NULL,3,1,11,1,'、 ','suneth85\rOTCN003'),(8285,743475310011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','jpt2591','mouricao8376@hotmail.co.uk','June Tyler','Post Office Box (APARTADO) 162','S.B. MESSINES','','PORTUGAL','8376- 909','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-31 11:12:49',0,NULL,3,1,2,1,'、 ','jpt2591'),(8286,824932528012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','adharpatel7','adharpatel@gmail.com','Adhar Patel','4/A, CHAITANYA PARK, JITODIA ROAD<br>AT:- JITODIA','ANAND','Gujarat','INDIA','388345','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 11:29:12',0,NULL,3,1,2,1,'、 ','adharpatel7'),(8287,743482376011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','granofgosie','gosiesgran@aol.com','Susan Widmann','552 Eastgate Dr','Waterloo','IA','UNITED STATES','50703','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 11:29:59',0,NULL,3,1,1,1,'\\  ','granofgosie'),(8288,732942683011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','nyguy7654321','waternyc@aol.com','V. TSOLAKIDIS','TAX. THIRIDA 8035','KAROUSADES','KERKYRA','GREECE','49081','(695) 506-4708','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'nyguy7654321'),(8289,825253041012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','mismi211','michael.schippers@gmx.de','Michael Schippers','PostNummer 34696952<br>Packetstation 104','Mainz','','GERMANY','55116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 12:02:33',0,NULL,3,1,2,1,'、 ','mismi211\r欧标'),(8290,825249785012,220815931012,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',14.99,'eastar4uk','ginger51518','graham_north@btconnect.com','Graham North','Fairholme<br>The Rushes, Gotham','Nottingham','Nottinghamshire','UNITED KINGDOM','NG110HY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 12:04:50',0,NULL,3,1,3,1,'RA183620444CN\r ','ginger51518\rHSJA004\r英标'),(8291,743519462011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','elefantino_lena','net.tyumen@mail.ru','Elena Betekhtina','ul.Druzhby d.159 kv.98','Tyumen','Tyumen','RUSSIAN FEDERATION','625031','9199513176','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-31 13:11:32',0,NULL,3,0,2,1,'\\  ','elefantino_lena\r已入库'),(8292,743526172011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','ricocarpenter','richjohnstone44@gmail.com','Rich Johnstone','Flat 2 Nevena Court<br>90 Effra Road','Brixton','London','UNITED KINGDOM','sw2 1bt','02085421982','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 13:19:07',0,NULL,3,1,3,1,'RA183620356CN\r ','ricocarpenter\rWLDE001'),(8293,825292834012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','tomtheripper','1374-210@onlinehome.de','Thomas Aufmuth','Am Schlossberg 10','Thannhausen','','GERMANY','86470','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:31:25',0,NULL,3,1,2,1,'、 ','tomtheripper'),(8294,743550708011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','grandmaatrain','joshherman@gmail.com','Josh Herman','7157 Arrowroot Ave','Colorado Springs','CO','UNITED STATES','80922-3623','(719) 482-6286','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 14:16:20',0,NULL,3,1,1,1,'\\  ','grandmaatrain'),(8295,743569463011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','roberto73cas','robertovm@mundo-r.com','Roberto Varela Martínez','Torreiro, 16 - 18, 2º Izda','La Coruña','Galicia','SPAIN','15003','637545317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 14:56:45',0,NULL,3,1,3,1,'RA183620501CN ','roberto73cas\rGLSG001*2'),(8296,825383001012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','hannah_2608','shaider04@hotmail.co.uk','shaista Haider','92 Boynton Street','Bradford','West Yorkshire','UNITED KINGDOM','BD5 7BS','01274408356','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 16:19:57',0,NULL,3,1,3,1,'RA183620206CN\r ','hannah_2608\rHSMO017\r英标'),(8297,743624921011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','denisestreeter','denisestreeter1@yahoo.com','Denise Streeter','3714 SHILOH RD','DE FOREST','WI','UNITED STATES','53532-2826','(608) 318-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 16:34:03',0,NULL,3,1,1,1,'\\  ','denisestreeter'),(8298,743651895011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','vera5596','nana_serwaa@gmx.de','Vera Asibey-Donkor','Finsrterwalderstr. 7','Berlin','','GERMANY','13435','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 17:11:23',0,NULL,3,1,2,1,'、 ','vera5596'),(8299,743652665011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','labatt13','bmalia@gmail.com','Brian Malia','1255 Wondering Way','Suwanee','GA','UNITED STATES','30024-1139','(330) 221-2262','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 17:12:14',0,NULL,3,1,1,1,'\\  ','labatt13'),(8300,825448266012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.4,'eastar4','ebsmp','stephenmpeterson@yahoo.com','Stephen Peterson','845 W 6th St<br>Apt D','Winston Salem','NC','UNITED STATES','27101-2536','(336) 965-1235','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\  ','ebsmp'),(8301,743718141011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jk15637','kle1003@yahoo.com','Jeff Klebine','15637 Ryder Cup Dr','Haymarket','VA','UNITED STATES','20169','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 18:28:18',0,NULL,3,1,1,1,'\\  ','jk15637'),(8302,825493393012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','antonmont','iceb0y@list.ru','Anton Mantula','Voroshilova, 33 - 29','Magnitogorsk','Chelyabinskaya obl','RUSSIAN FEDERATION','455021','+79049737812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 18:33:55',0,NULL,3,1,2,1,'、 ','antonmont\racer 4pin1.25 8cm'),(8303,743733047011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','hansimr','hruppel@yahoo.com','Hans M. Ruppel','7007 56th Ave NE','Seattle','WA','UNITED STATES','98115-6221','(206) 522-2589','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 18:47:59',0,NULL,3,1,1,1,'\\  ','hansimr'),(8304,607669032013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','rafaelgimenes11','falecom@rafaelgimenes.net','Leite, Maria','R. Lopes Chaves, número 123<br>Barra Funda','Votorantim','São Paulo','BRAZIL','18114-320','(55) 15 - 32437078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 18:54:12',0,NULL,3,1,3,1,'RA183620736CN\r ','rafaelgimenes11\rCACN004\r客户打了四美金'),(8305,553295015003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','donald3mail','djdonaldmoore@yahoo.com','Donald Moore','1809 Springfield st','birmingham','AL','UNITED STATES','35217-2638','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-31 18:54:25',0,NULL,3,1,1,1,'\\  ','donald3mail'),(8306,607674202013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','schneiders65','info@ferienweingut-schneiders.de','Ralf Schneiders','Robert-Schuman-Str.22','Kröv','','GERMANY','54536','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 19:03:30',0,NULL,3,1,3,1,'RA183620055CN ','schneiders65\rGLOT001*2\r兼容型3D眼镜 通用型'),(8307,825529386012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','precious_sewing','hazel.dykins@btinternet.com','hazel dykins','17 churchfield road<br>lee park','liverpool','Merseyside','UNITED KINGDOM','l25 3sd','01514879643','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-31 19:09:04',0,NULL,3,1,2,1,'\\  ','precious_sewing\r24K 多色伞'),(8308,607706473013,230617128655,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',85.99,'eastar4','afitgrad86','dshannon46@msn.com','Don Shannon','5338 La Colonia Dr NW','Albuquerque','NM','UNITED STATES','87120-2488','(505) 259-8485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 20:04:44',0,NULL,3,1,1,1,'、 ','afitgrad86'),(8309,607708705013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','silversurfer316','ocelot316@gmail.com','Diego Ching','Calle Jose Perez Soler #80<br>Urb. Kennedy','Quebradillas','PR','UNITED STATES','00678','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 20:13:38',0,NULL,3,1,1,1,'\\  ','silversurfer316'),(8310,743827591011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',4.99,'eastar4uk','james07beach','tjgibbs@hotmail.co.uk','terence gibbs','8 farm grove<br>farm grove','rugby','Warwickshire','UNITED KINGDOM','cv22 5nq','01788337655','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 21:08:11',0,NULL,3,1,3,1,'RA183620325CN\r ','james07beach\rBAIN001\r光杯版电池'),(8311,825616545012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','minicell','u.narr@freenet.de','Uwe Narr','Stauffenbergstr 8','Balingen','','GERMANY','72336','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 21:19:36',0,NULL,3,1,2,1,'、 ','minicell'),(8312,825619054012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','cpt_mal','dharm08@hotmail.com','Dharm Patel','1 Hodgkiss Close','Wednesbury','West Midlands','UNITED KINGDOM','WS10 9LP','07890376124','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 21:24:13',0,NULL,3,1,3,1,'RA183620166CN\r ','cpt_mal\rOTHP003'),(8313,607745916013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','m.sosinski','mjsosins@yahoo.com','Michael J. Sosinski','2797 Old Columbus Rd','Granville','OH','UNITED STATES','43023','(614) 939-9126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 21:56:24',0,NULL,3,1,1,1,'\\  ','m.sosinski'),(8314,743852042011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','mariajosedc','mjdc@terra.com.br','Maria José Dias Cerqueira','Rua Universo 284 ap 02','Belo Horizonte','Minas Gerais','BRAZIL','30350612','31-3344-5640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 22:06:41',0,NULL,3,1,2,1,'、 ','mariajosedc'),(8315,705129759001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','gregthevoice','studiogpresents@yahoo.com','Greg Thomas','513 Kelford Ln','Charlotte','NC','UNITED STATES','28270-2205','(704) 488-0820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 22:26:09',0,NULL,3,1,1,1,'\\  ','gregthevoice'),(8316,607769567013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','jaysingh2489','kobefanatic2289@gmail.com','Jay Singh','2189 Postmaster Dr. Unit 45','Oakville','ON','CANADA','L6M 4E6','(905) 334-4181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 23:25:11',0,NULL,3,1,2,1,'、 ','jaysingh2489'),(8317,743909694011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','rhettrodj','rhettjenkins@hotmail.com','Rhett Jenkins','40 Eastwell Rd','Australind','Western Australia','AUSTRALIA','6233','0423835333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 01:11:54',0,NULL,3,1,2,1,'、 ','rhettrodj\r澳标'),(8318,743928755011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','lonniegl1100','lonnie.gl1100asp@yahoo.com','LONNIE HUNTER','304 DEMOSS RD','EROS','LA','UNITED STATES','71238-9400','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 02:11:27',0,NULL,3,1,1,1,'\\  ','lonniegl1100'),(8319,743952660011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','moffy164','mmcool18@hotmail.com','Maranda Carole','164 du Bosquet','St-Étienne-de-Lauzon','QC','CANADA','G6J1T3','(418) 831-0598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 03:42:07',0,NULL,3,1,3,1,'RA183620387CN\r ','moffy164\rHSLO001'),(8320,825762225012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','gowill323','mrwill43@aol.com','willie brown','718 E 43rd St','los angeles','CA','UNITED STATES','90011','(323) 828-3585','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 04:24:32',0,NULL,3,1,1,1,'\\  ','gowill323'),(8321,553456010003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','firefire-454','gizzball@gmail.com','Aaron  Lew','N3115 lew RD','Ladysmith','WI','UNITED STATES','54848-9382','(715) 403-3077','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-01 05:00:41',0,NULL,3,1,1,1,'\\  ','firefire-454'),(8322,825790315012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','janfrank49','janfrank49@freenet.de','Jan Frank','Emil-Fritschi-Weg 14','Rheinfelden','','GERMANY','79618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 06:50:33',0,NULL,3,1,2,1,'、 ','janfrank49'),(8323,825605563012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',258,'eastar4','taylor1928','oliver@muehlhauser.net','Katharina Leonhard','Knöbelstrasse 6','Munich','','GERMANY','80538','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 07:07:46',0,NULL,3,1,4,1,'YW866475514CN','taylor1928'),(8324,705255255001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',18.9,'buysia','pauyak','pawlu_2@hotmail.com','Paul Buhagiar','20, \'St.Anthony\'<br>Salvu Barbara Street','Mosta','Mosta','MALTA','MST 2433','+0035621414681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 07:11:21',0,NULL,3,1,3,1,'RA183620529CN\r ','pauyak\rBR3D005'),(8325,607865364013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',119,'eastar4','elarauzo','elarauzo@hotmail.com','Jairo Arauzo Huidobro','c/ Federico Velez, 3 5ºA','Burgos','Castilla y León','SPAIN','09001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 07:49:59',0,NULL,3,1,3,1,'RA183620515CN\r ','elarauzo\rTRTT002*10'),(8326,744002172011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',15.9,'eastar4uk','tanimovayu','tanevayudj@yahoo.co.uk','TANE PAGE','104 Gardner Road','Manchester','Lancashire','UNITED KINGDOM','M25 3JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 08:04:41',0,NULL,3,1,3,1,'RA183620489CN\r ','tanimovayu\rWLAP002'),(8327,825809828012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','eurodrew555','andrew@andrewsmith.ws','Andrew Smith','29 Bethwyn Circuit<br>Madeley','Perth','Western Australia','AUSTRALIA','6065','0431766865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 08:20:40',0,NULL,3,0,2,1,'、 ','eurodrew555'),(8328,825817665012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','andypalmerusa','aerobatics@clear.net.nz','Andrew Palmer','797 Ellesmere Road<br>RD 2','Christchurch','','NEW ZEALAND','7672','64-21-976665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 08:52:46',0,NULL,3,1,3,1,'RA183620617CN\r ','andypalmerusa\rOTRA001'),(8329,559027287004,140584761903,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',34.99,'cnfaner','beanjai','mustafizar.salleh@yahoo.co.uk','MOHD MUSTAFIZAR MD SALLEH','NO.21, STKRJ, SPG. 120-48-36-23,<br>KG. MUMONG','KUALA BELAIT','BELAIT','BRUNEI DARUSSALAM','KA1731','+6738200926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 09:15:54',0,NULL,3,1,3,1,'RA183620807CN ','beanjai\rMOMI003'),(8330,8881312191025574,111,'Samsung SSG-2100AB',1,'GLSG001',0,'eastar4','dominicmichael83','dominicmichaels@hotmail.com','Dominic Huang','798 Woodlands Drive 72<br>#03-67','default','','SINGAPORE','730798','',NULL,NULL,NULL,'2011-07-14 06:51:16',0,NULL,3,1,3,1,'RA183620784CN ',' 2011.8.1补货'),(8331,8881312191361409,111,'Samsung SSG-2100AB',1,'GLSG001',0,'eastar4','donr54','donr54@yahoo.com','donald ranous','54 Sagamore Dr','rochester','NY','UNITED STATES','14617-2402','(585) 342-6828',NULL,NULL,NULL,'2011-07-21 15:12:42',0,NULL,3,1,1,1,'、 ',' 补货  2011.8.1\rLK027344217CN'),(8332,825844148012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','elninio13','alexandros20001@yahoo.gr','ALEX DAVVETAS','P.O BOX 1017','AGIOS NIKOLAOS','LASITHIOU CRETE','GREECE','72100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 10:29:26',0,NULL,3,1,3,1,'RA183620890CN ','elninio13\rHSIT001\r欧标'),(8333,687558593008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','camerondunne','cameron_dunne@hotmail.com','cameron dunne','30 sundale rd','traralgon','Victoria','AUSTRALIA','3844','0421502455','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 10:30:34',0,NULL,3,1,3,1,'RA183623131CN ','camerondunne\rHSPL015\r澳标'),(8334,607893124013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',104.95,'eastar4','linh3t','linh3t_vn@yahoo.com','Ngo Hong Linh','65 TT Hon Dat','huyen Hon Dat','tinh Kien Giang','VIET NAM','84','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 10:36:35',0,NULL,3,1,3,1,'RA183620909CN ','linh3t\rGLOT001*2\r兼容型3D眼镜 通用型'),(8335,825857092012,220783475162,'New genuine Grohe Shower head holder made in Germany',1,'OTGR003',51.98,'eastar4','kenhwang78','free_cloud33@hotmail.com','Zell','Blk 1003, Bukit Merah Central<br>#04-34','default','','SINGAPORE','159836','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 11:16:06',0,NULL,3,1,3,1,'RA183620930CN ','kenhwang78\rOTGR003\r再发一个New Grohe Copper Plating Multi function washer Germany'),(8336,744058357011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','jkyard90','aung.zeya@gmail.com','Maung Thu','4/1 Kenneth Ave<br>Baulkham Hills','Sydney','New South Wales','AUSTRALIA','2153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 11:48:33',0,NULL,3,1,2,1,'\\ ','jkyard90'),(8337,607906836013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','estevaojrr1','estevaojrr@ig.com.br','Alan Antunes Rosendo','Cond. vert paradiso, Qd-J, lote-19<br>serraria','Maceió','Alagoas','BRAZIL','57048-375','8233288120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 11:50:00',0,NULL,3,1,2,1,'\\ ','estevaojrr1'),(8338,744059025011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','jggrnaut','jggrnaut@msn.com','Geoff Ritter','605 Charles Rd','Carbondale','IL','UNITED STATES','62901-5543','(618) 351-0976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 11:50:16',0,NULL,3,1,1,1,'\\  ','jggrnaut'),(8339,607915587013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','25***25','777@mind-e.com','Toru Manabe','19-1-405,araki-cho,','shinjuku-ku','Tokyo','JAPAN','160-0007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 12:27:44',0,NULL,3,1,3,1,'RA183620585CN\r ','25***25\rBAZA001'),(8340,744071666011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','christinoleo','leomilho@gmail.com','Leonardo Chrstino','Av. José Duarte de Souza<br>Nº 975 ap.14','São Carlos','São Paulo','BRAZIL','13564-030','9184146977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 12:34:38',0,NULL,3,1,2,1,'\\ ','christinoleo'),(8341,687595184008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'au-buy','niceandquiet','nicenquiet@iprimus.com.au','Naomi Land','5 Heathwren Close','Frankston South','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 12:47:01',0,NULL,3,1,3,1,'RA183620838CN ','niceandquiet\rGLOT001\r兼容型3D眼镜 通用型'),(8342,744079156011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','beeboobop1','sschears@uwm.edu','steven Schears','11021 N Hedgewood Ln','Mequon','WI','UNITED STATES','53092-4909','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 13:01:00',0,NULL,3,1,1,1,'\\  ','beeboobop1'),(8343,559068784004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','cis3h','jfsemerie@yahoo.fr','Semerie jean François','Aromafleur<br>14 route de nice','opio','Provence-Alpes-Côte d\'Azur','FRANCE','06650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 13:07:45',0,NULL,3,1,3,1,'RA183620651CN\r ','cis3h\rOTGR001+OTGR002'),(8344,744031729011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',64.99,'eastar4','komuka09','vesko_tech@abv.bg','Veselin Bozhilov','Sveta troica bl 370, entrance G, <br>floor 7, Flat104','Sofia','Sveta troica','BULGARIA','1309','828-33-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 13:29:31',0,NULL,3,1,3,1,'RA183620798CN ','komuka09\rGLSG001'),(8345,822457201012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',7.9,'eastar4','mmocha71','mynmocha@hotmail.com','Miguel Mocha','5309 w 23rd St','cicero','IL','UNITED STATES','60804-2812','(708) 617-8952','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 13:43:01',0,NULL,3,1,1,1,'\\  ','mmocha71\r旧的'),(8346,744099663011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',49.99,'eastar4','ekhoury72','eric.khoury@hec.ca','Eric Khoury','24 Mayfair','Dollard-Des-Ormeaux','QC','CANADA','H9G 2A8','(514) 249-9213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 14:06:14',0,NULL,3,1,3,1,'RA183620705CN\r ','ekhoury72\rRCLO006\r新的'),(8347,825915579012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','chas8199','bruster@dcwis.com','Robert Armbruster','7578 Sunny Point Rd','Egg Harbor','WI','UNITED STATES','54209-8934','(920) 495-6476','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 14:10:16',0,NULL,3,1,1,1,'\\  ','chas8199'),(8348,825917329012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','mickey_beads','4evrmickey@gmail.com','Trevor or Delores Colbourne','34 Todd Street','Cambridge','ON','CANADA','N1R1G5','(519) 365-7355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 14:16:11',0,NULL,3,1,3,1,'RA183620824CN ','mickey_beads\rGLSG001*2'),(8349,607940428013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','vlaja11','vlaja@atlas.cz','Vladimír Janecek','Budejovicka 140 1407','Praha 4','','CZECH REPUBLIC','140 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 14:17:42',0,NULL,3,1,2,1,'\\ ','vlaja11'),(8350,604752368013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',15.5,'eastar4','jandhindustrialspecialties','osw7@verizon.net','Mansell H Hopkins','5625 Bridlewood Dr','Roanoke','VA','UNITED STATES','24018-4641','(540) 309-3190','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-01 14:31:39',0,NULL,3,1,1,1,'\\  ','jandhindustrialspecialties'),(8351,553553461003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','josephbaronbaron','josephbaron@yahoo.ca','Joseph Barocsi','49 Lavergne St. #3','Ottawa/Vanier','ON','CANADA','K1L 5E9','(613) 749-8887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 14:40:35',0,NULL,3,1,3,1,'RA183620740CN\r ','josephbaronbaron\rHBPH002'),(8352,553554018003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','jessmax0_2','cgs1177@gmail.com','Carlotta Grenier','15 Bailiwick Rd','Greenwich','CT','UNITED STATES','06831-3609','(203) 531-4621','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-01 14:41:26',0,NULL,3,1,1,1,'\\  ','jessmax0_2'),(8353,687641833008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','yanb760','yanboissonneault@hotmail.com','yan boissonneault','4 rue tremblay','saint jean sur richelieu','QC','CANADA','j2x 2t4','(450) 741-4978','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-01 15:22:07',0,NULL,3,1,3,1,'RA183620775CN ','yanb760\rHSPL011'),(8354,607958421013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',53.64,'eastar4','tolis_technologist','tolis313@windowslive.com','APOSTOLOS TSOUMELEKAS','PAVLOU MELA MYTIKAS (there is no street number)','PREVEZA','PREVEZA - MYTIKAS','GREECE','48100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 15:30:29',0,NULL,3,1,3,1,'RA183623030CN\r ','tolis_technologist\rWLAP008\r'),(8355,825954082012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','wneu_tv60','wneu.david@comcast.net','WNEU-TV60: Attn; David Raymond','1 Sundial Ave<br>Ste 501','Manchester','NH','UNITED STATES','03103-7259','(603) 647-6060','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 15:52:17',0,NULL,3,1,1,1,'\\  ','wneu_tv60'),(8356,821085779012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',34.5,'eastar4','diallodjeri','diallo2074@gmail.com','Abdoulaye Diallo','5401 110th PL NE','Marysville','WA','UNITED STATES','98271-8811','(206) 715-8345','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 15:53:15',0,NULL,3,0,1,1,'\\  ','diallodjeri\r再发两个CAB-6060'),(8357,825966292012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','gonzitan','gabuba@live.co.uk','Sylvana Cauchi','54,<br>St. Charles Street','Sliema','Malta','MALTA','SLM 2176','79899345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:21:37',0,NULL,3,1,3,1,'RA183620563CN\r ','gonzitan\rOTGR001+OTGR002'),(8358,825971526012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','hamasdegh','hovsepmelk@cox.net','Hovsep Melkonian','8709 Pappas Way','Annandale','VA','UNITED STATES','22003-4539','(703) 425-4257','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-01 16:31:24',0,NULL,3,1,1,1,'\\  ','hamasdegh'),(8359,825971893012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','lindows-by','joshhhab@gmail.com','Andrey Burkov','boulevard Komsomolskiy 59-2','Kamensk-Uralskiy','Sverdlovskaya oblast','RUSSIAN FEDERATION','623430','+7-915-290-14-59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:33:56',0,NULL,3,0,2,1,'\\ ','lindows-by'),(8360,744153463011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','t.diddy','tyedaddy@yahoo.com','Ty Gamble','3779 S Jebel Way','Aurora','CO','UNITED STATES','80013-6607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 16:35:15',0,NULL,3,1,1,1,'\\  ','t.diddy'),(8361,744157877011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','kakicoco','antoine.cunin@wanadoo.fr','Antoine Cunin','33,Les Mélèzes','Sainte Marie aux Mines','Alsace','FRANCE','68160','03.89.58.81.91','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:45:55',0,NULL,3,1,2,1,'\\ ','kakicoco'),(8362,559121219004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','spokkettino78-2','edilmac1.srl@tiscali.it','Petta Francesco','C/o EDILMAC srl<br>Zona Industriale','San Marco Argentano','CS','ITALY','87018','0984-518634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:56:34',0,NULL,3,1,3,1,'RA183620625CN\r ','spokkettino78-2\rOTRA001'),(8363,744013805011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','2magx','magdicg@uni-duesseldorf.de','Goran Magdic','Walther-Rathenau-Str. 11','Düsseldorf','','GERMANY','40589','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 17:05:45',0,NULL,3,1,2,1,'\\ ','2magx'),(8364,825987258012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',25.98,'eastar4','harmonic9000','ericvasquez2222@yahoo.com','Eric Vasquez','11721 W Poinsettia Dr','El Mirage','AZ','UNITED STATES','85335-5026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 17:08:13',0,NULL,3,0,1,1,'\\  ','harmonic9000'),(8365,744167298011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',16.98,'eastar4','kulebyachkav','protasovandrey@mail.ru','Андрей Протасов','ул.Советская,11,27','Архангельск','Архангельская область','RUSSIAN FEDERATION','163020','+79522551729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 17:09:49',0,NULL,3,1,2,1,'\\ ','kulebyachkav'),(8366,553594819003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','ktricio','patriciomreyes@gmail.com','Patricio Reyes Rifo','Brown Norte 40, Dpto 1505<br>Nunoa','Santiago','Santiago','CHILE','7790569','(2) 223 4825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 17:20:50',0,NULL,3,1,3,1,'RA183620841CN ','ktricio\rMOOE002\r发OEM的'),(8367,607018116013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','easymoney25','eassymoney@gmail.com','David Padilla','10927 Loch Lomond Dr','whittier','ca','UNITED STATES','90606-1533','(562) 908-1118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 17:25:26',0,NULL,3,1,1,1,'\\  ','easymoney25'),(8368,826002919012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',2,'HSMO010',17.98,'eastar4uk','jwhi7130','j8125@charter.net','jill white','470 cormier rd','danville','VT','UNITED STATES','05828','(802) 535-7368','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 17:40:51',0,NULL,3,1,1,1,'\\  ','jwhi7130'),(8369,607999544013,230393137066,'2.1 Acer Aspire 4520 4520G Bluetooth Module EDR+cable',1,'BTAC2115',12.4,'eastar4','alanefi','lanefi791@yahoo.co.uk','MAZLAN MOHAMAD','NO.20, LORONG ILMU 13, TAMAN ILMU','NIBONG TEBAL,','PENANG','MALAYSIA','14300','0124884172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 17:47:28',0,NULL,3,1,2,1,'\\ ','alanefi\racer 5pin1.25 20cm'),(8370,744194793011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.4,'eastar4','a_notice','anssko@gmail.com','Anssi Kokko','Hämeen Härkätie 310','Hämeenlinna','','FINLAND','13500','0503657142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 18:08:14',0,NULL,3,1,2,1,'\\ ','a_notice\racer 5pin1.25 4cm '),(8371,826023190012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',15.95,'eastar4uk','krob66','kevroberts66@aol.com','kevin   roberts','78 Thomson drive','Ripley','Derbyshire','UNITED KINGDOM','DE59RU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 18:16:14',0,NULL,3,1,3,1,'RA183620665CN\r ','krob66\r英标\rHSMO014'),(8372,608012044013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',2,'HBPH004',19.98,'eastar4','princep95','prahmanfard@gmail.com','Pouya Rahmanfard','1450 14th St<br>Apt 115','Santa Monica','CA','UNITED STATES','90404-2767','(310) 393-2906 ext.: 3103932906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 18:20:49',0,NULL,3,1,1,1,'\\  ','princep95'),(8373,608019192013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','slay1_3','855563@gmail.com','вячеслав васильев','410004, 9 Liniya Pervomayskogo poselka 412','Saratov','Saratov obl','RUSSIAN FEDERATION','+7','(927)117-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 18:41:08',0,NULL,3,1,2,1,'\\ ','slay1_3'),(8374,743694027011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','mzlynn107','mslynn107@yahoo.com','Lynn Smith','3145 Virginia Beach Blvd<br>Ste 202','Virginia Beach','VA','UNITED STATES','23452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 18:55:09',0,NULL,3,1,1,1,'\\  ','mzlynn107'),(8375,744219150011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',2,'HSUE003',43.98,'eastar4','sompat2011','gif.z@live.com','sompat klinhol','303/30 Kan Kheha Uea Athon (Ram In Thra Soi 117)<br>Flat 6 floor 4','default','BA','THAILAND','10510','6609831146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 18:57:03',0,NULL,3,1,3,1,'RA183620696CN\r ','sompat2011\rHSUE003\r带麦的'),(8376,744230916011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','kbow6912','kevin.bower@sodexo.com','Kevin Bower','4025 Forgotten Pond Ave','Wake Forest','NC','UNITED STATES','27587','(717) 471-5073','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 19:15:21',0,NULL,3,1,1,1,'\\  ','kbow6912'),(8377,744246903011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','captainsteve266','stevescott266@gmail.com','Stephen Scott','8730 Melting Shadows Ln','Houston','TX','UNITED STATES','77095','(713) 410-2524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 19:48:00',0,NULL,3,1,1,1,'\\  ','captainsteve266'),(8378,608045333013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ithorianpresident','aaron051470@yahoo.com','Aaron Williams','882 3rd ave','Troy','NY','UNITED STATES','12182','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 19:48:36',0,NULL,3,1,1,1,'\\  ','ithorianpresident'),(8379,826075082012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','aljizeh','o4eb@yahoo.de','Abed    Alzoobi','Dissenchener Str. 78d','Cottbus','','GERMANY','03042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 19:51:38',0,NULL,3,1,3,1,'RA183620634CN\r ','aljizeh\rWWOT003'),(8380,826078358012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',13.99,'eastar4uk','66helblue','helenhughes4@yahoo.co.uk','Helen Hughes','39a Khartoum Road','Tooting','London','UNITED KINGDOM','SW17 0JA','02073859578','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 19:53:34',0,NULL,3,1,3,1,'RA183620679CN\r ','66helblue\rHSMO019\r英标'),(8381,607179565013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','artemkab','artbogach@gmail.com','Artem Bogachev','Pyathitskoe shosse<br>d.12 k.3 kv.35','Moscow','','RUSSIAN FEDERATION','125464','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 19:57:19',0,NULL,3,1,2,1,'\\ ','artemkab'),(8382,744273561011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','johnnie_hat','hatfij@optonline.net','John L Hatfield','2 Hellman Ct','Wappingers Falls','NY','UNITED STATES','12590-6426','(845) 227-5867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 20:42:23',0,NULL,3,1,1,1,'\\  ','johnnie_hat'),(8383,608065760013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',70.96,'eastar4','firetani007','tanja.kuerzeder@gmx.net','Tanja Kürzeder','Staatsstrasse 48 b','Kolbermoor','','GERMANY','83059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 20:50:09',0,NULL,3,1,3,1,'RA183620648CN\r ','firetani007\rMOSA002'),(8384,826121286012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',23.99,'eastar4uk','turbo.corp','j.icard@laposte.net','ICARD Jean-Claude','1696 route de la Motte','le Muy','Provence-Alpes-Côte d\'Azur','FRANCE','83490','0628080917','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 21:17:24',0,NULL,3,1,3,1,'RA183620577CN\r ','turbo.corp\rOTRA001'),(8385,744322716011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','cactus282000','weldsalot@gmail.com','tony j collins','9411 Emerald Dr','Saint Helen','MI','UNITED STATES','48656-9476','(989) 389-1662','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 22:54:19',0,NULL,3,1,1,1,'\\  ','cactus282000'),(8386,744321571011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','kitsune1979','josebadelafuente@gmail.com','JOSEBA DE LA FUENTE DE LA FUENTE','LOS GLADIOLOS 58A','CAMBRILS','Cataluña','SPAIN','43850','619261500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 22:57:08',0,NULL,3,1,3,1,'RA183620815CN ','kitsune1979\rGLSG001*2'),(8387,826160093012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','mustangsv08dma','vsantos720@gmail.com','victor a santos','901 Mulberry Bush Ct','orlando','FL','UNITED STATES','32828-9208','(407) 277-8865','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 22:59:46',0,NULL,3,1,1,1,'\\  ','mustangsv08dma'),(8388,826160672012,220815930167,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',49.99,'eastar4uk','carlos-penteado','carlospenteado@yahoo.com.br','Carlos Penteado','Rua Bartolomeu Faria, 510<br>Freguesia do Ó','Sao Paulo','São Paulo','BRAZIL','02730-050','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 23:02:56',0,NULL,3,1,3,1,'RA183620886CN ','carlos-penteado\rRCDE001'),(8389,826165625012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','moosetree','sjgscott@earthlink.net','Patrick Hook','1926 Fullerton Ave<br>Apt 105','Corona','CA','UNITED STATES','92881-7024','(951) 520-8957','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 23:22:13',0,NULL,3,1,1,1,'\\  ','moosetree'),(8390,826170364012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','tonykettle','ebay@tonykettle.co.uk','Tony Kettle','Holly Cottage<br>Barnhall Road','Maldon','Essex','UNITED KINGDOM','CM9 8HF','08702600600','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 23:32:32',0,NULL,3,1,3,1,'RA183620753CN\r ','tonykettle\rOTCN004*10'),(8391,705571479001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','nanjf','nanjf47@aol.com','Nancy Frazier','928 Horse Creek Rd','Crown City','OH','UNITED STATES','45623-9041','(740) 208-3270','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 23:57:57',0,NULL,3,1,1,1,'\\  ','nanjf'),(8392,826180443012,220807244626,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AB',1,'GLOT004*2',104.95,'eastar4','islanderjp','jpanzer@bellsouth.net','JIM PANZER','4594 LOTUS WAY','BOYNTON BEACH','FL','UNITED STATES','33436','(561) 375-9870','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 00:06:26',0,NULL,3,1,1,1,'\\  ','islanderjp\r兼容型3D眼镜  samsung 专用'),(8393,608115522013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','yeti_jp','s_n_o_w_21@yahoo.co.jp','Yukio Uetani','1-14<br>Ryuugaoka 2-chome,Nishi-ku','Kobe','Hyogo','JAPAN','651-2412','+81-78-967-5124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 00:09:57',0,NULL,3,1,3,1,'RA183620719CN\r ','yeti_jp\rWLIN014'),(8394,826179411012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','shannfk','fshan5@msn.com','Fonda Shannon','9849 E Shore Dr','Willis','TX','UNITED STATES','77318-6638','(713) 252-9431','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 00:12:04',0,NULL,3,1,1,1,'\\  ','shannfk'),(8395,741918730011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','daniel783','ctgjhsu@gmail.com','Jesse Hsu','32 Avenue of the Americas<br>Fl 21','New York','NY','UNITED STATES','10013','(212) 925-6692','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 00:44:03',0,NULL,3,1,1,1,'\\  ','daniel783'),(8396,744353989011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','alfredscottb','alfredscottb@yahoo.ca','Scott Barker','76 maclean ct','fredericton','NB','CANADA','e3g 9y1','(506) 449-0989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 00:57:13',0,NULL,3,1,3,1,'RA183620722CN\r ','alfredscottb\rBR3D001'),(8397,826205666012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','64olsen','lfolsen@greennet.gl','Lars-Frederik Olsen','Kigutaarnat 50<br>P.O. Box 528','Nuuk','','GREENLAND','3900','+299 326406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 01:33:00',0,NULL,3,1,3,1,'RA183620767CN ','64olsen\rOTSO004*2'),(8398,826206765012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',12.99,'eastar4','beth2126','irishanglb1@aol.com','Elizabeth Straub','411 Conner Grant Rd','New Bern','NC','UNITED STATES','28562-9811','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 01:38:57',0,NULL,3,0,1,1,'\\ ','beth2126'),(8399,744381482011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','crabs62','gelix@internode.on.net','Mr. Glenn Elix','Unit 76. / 17 Willmett Road.<br>GOOLWA.','Adelaide','South Australia','AUSTRALIA','5214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 02:42:50',0,NULL,3,1,3,1,'RA183620943CN ','crabs62\rBR3D001'),(8400,826228549012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','microtriper','webmaster@imagei.com','Renato Garcia Francisco','Av Francisco Glicerio, 1127<br>Centro','Campinas','SP','BRAZIL','13012-000','19-88007778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 02:54:06',0,NULL,3,1,2,1,'、 ','microtriper'),(8401,559279071004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','lonnie1430','luv2livnow@aol.com','Lonnie Felker','9503 Via Salerno','Burbank','CA','UNITED STATES','91504-1227','(818) 419-1819','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-02 03:50:55',0,NULL,3,1,1,1,'\\  ','lonnie1430'),(8402,559291680004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','igorsaf','igorsafiulin@gmail.com','Igor Safiyulin','Arnolda Neibuta, 11/1, 169','Omsk','','RUSSIAN FEDERATION','644070','79136706826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 05:42:30',0,NULL,3,1,3,1,'RA183620869CN ','igorsaf\rWLAP008'),(8403,826270020012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',42.99,'eastar4uk','sscherten_uk','sscherten@freesurf.ch','Sebastien Schertenleib','3rd Floor<br>13 Great Marlborough Street','London','London','UNITED KINGDOM','W1f 7HP','07847679748','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 06:11:19',0,NULL,3,1,3,1,'RA183620926CN ','sscherten_uk\r黑色的\rGLOT005\r投影仪兼容眼镜\r盒装的'),(8404,8881312267751590,111,'strawberry  umbrella',1,'UM00013',0,'eastar4','crimsonpebble1','crimsonpebble@hotmail.com','Grace Chin','30 Kinnoull Grove','Glen Waverley','Victoria','AUSTRALIA','3150','0388028608',NULL,NULL,NULL,'2011-07-18 12:06:05',0,NULL,3,1,2,1,'\\  ',' 补货 草莓伞'),(8419,553829101003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',39.9,'cnfaner','p_marcellus','pmarcellus@dadeschools.net','petrus marcellus','1840 NW 135th St','Miami','FL','UNITED STATES','33167-1549','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-02 12:58:52',0,NULL,3,1,1,1,'\\ ','p_marcellus'),(8406,8881312269588307,111,' NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER  ',1,'',87.99,'eastar4','leocadio1209','leo_ferreria@yahoo.com','Leo Ferreria','926 Aurora Blvd., Cubao','Quezon City','Metro Manila ','PHILIPPINES ','1109 ','',NULL,NULL,NULL,'2011-08-02 07:19:48',0,NULL,3,0,6,1,'EE495341079CN ',NULL),(8413,744481335011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','tamar**','asher.fruchter@gmail.com','asher fruchter','yoni netanyauo 1016/9','kiryat-arba','israel','ISRAEL','90100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 10:45:29',0,NULL,3,1,2,1,'\\  ','tamar**'),(8407,608197494013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23,'eastar4','mangaclub12345','james.carroll.jahc@gmail.com','James Carroll','1/26 Woodward Rd<br>Mt Albert','Auckland','NEW ZEALAND','NEW ZEALAND','1025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 08:35:42',0,NULL,3,1,2,1,'\\  ','mangaclub12345'),(8408,744457965011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','silver_girl21','amanda.lwin@gmail.com','Amanda Lwin','566A Kingsland Road','Dalston','London','UNITED KINGDOM','E8 4AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 09:27:45',0,NULL,3,1,3,1,'RA183623026CN\r ','silver_girl21\rMOAP001\r'),(8409,8881312277980882,111,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET ',1,'HSNO026',15.5,'eastar4','champion5435','jsn_champion@yahoo.co.uk','Jason Champion','37 Upper Shott<br>Cheshunt','Waltham Cross','Hertfordshire','UNITED KINGDOM','EN7 6DR','07811345877',NULL,NULL,NULL,'2011-08-02 09:39:40',0,NULL,3,1,3,1,'RA183623105CN\r ','补发的\rHSNO026\r只发耳机 \r发之前测试一下'),(8410,8881312277996889,111,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET ',1,'HSNO026',15.5,'eastar4','champion5435','jsn_champion@yahoo.co.uk','Jason Champion','37 Upper Shott<br>Cheshunt','Waltham Cross','Hertfordshire','UNITED KINGDOM','EN7 6DR','07811345877',NULL,NULL,NULL,'2011-08-02 09:39:40',0,NULL,5,0,18,0,NULL,NULL),(8411,8881312279820303,111,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET',1,'HSNO003',32.94,'eastar4','tckrockz','desilva.mahesh@gmail.com','Mahesh De Silva','No 14, Dolosbage Road,<br>Back Lane,','Nawalapitiya','Central','SRI LANKA','20000','+94542222492',NULL,NULL,NULL,'2011-08-02 10:10:20',0,NULL,3,1,3,1,'RA183623091CN\r ','补发的\rHSNO003 \r全套的'),(8412,608024786013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','chuzhanova64irina','chuzhanova64@gmail.com','Irina Chuzhanova','st. Buketova 49 - 57','Petropavlovsk','SKO','KAZAKHSTAN','150010','+77013403744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 10:10:44',0,NULL,3,1,3,1,'RA183623074CN\r ','chuzhanova64irina\rGLOT002+GLOT003\r兼容型3D眼镜接收器\r兼容型3D眼镜  显示器 专用'),(8414,742450739011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','emmy4593','vincent4593@hotmail.com','emmy vincent','63<br>moorfield road','salford','Greater Manchester','UNITED KINGDOM','M6 7EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 10:57:35',0,NULL,3,1,3,1,'RA183623057CN\r ','emmy4593\rRELO003\r红边优联'),(8415,8881312282992057,111,'New Genuine Motorola H700 Bluetooth Headset',1,'HSMO011',13.99,'cnfaner','1996bailey5','roselinereed@hotmail.com','Roseline Reed','64 Andrews Ct','Lewisburg','PA','UNITED STATES','17837-6509','(570) 522-9967',NULL,NULL,NULL,'2011-08-02 11:03:12',0,NULL,3,1,3,1,'RA183620974CN\r ','补发的\rHSMO011\r补发全套 '),(8416,826335502012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',74.77,'eastar4','maxim_karban','maxim.karban@gmail.com','Maxim Karban','gen. Belova 29-2-36','Moscow','','RUSSIAN FEDERATION','115563','+79166534126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 11:04:39',0,NULL,3,1,3,1,'RA183623065CN\r ','maxim_karban\rWLIN001+WWOT001+ANCN001+MOCN001\r再发一个\rBracket of half intel 5300 半高卡架子\r和一个 NEW ERICSSON F3507G +3G antenna通用版'),(8417,8881312283656979,111,'NOKIA BH 900',1,'',0,'eastar4','darius13231','darius.z@splius.lt','Darius Zarauskas','Dariaus ir Girėno g. 44-11','Radviliskis','','LITHUANIA','LT-82139','+37061644848',NULL,NULL,NULL,'2011-08-02 11:14:16',0,NULL,3,0,3,1,'RA183620965CN\r ','补发的 \r发全套\r欧标\r已入库'),(8418,744501870011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','greathammadur','hammadurb@gmail.com','Hammadur Bhandari','18009 Cozumel Isle Dr','Tampa','FL','UNITED STATES','33647-3374','(516) 330-0336','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 11:58:59',0,NULL,3,1,1,1,'\\ ','greathammadur'),(8420,608246815013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',104.95,'eastar4','5411juankoby','jmkoby@hotmail.com','JUAN MANUEL KOBYLANSKI','Rosario Vera Peñaloza 360','Capital Federal','BUENOS AIRES','ARGENTINA','C1107CLA','57767778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 13:00:06',0,NULL,3,1,3,1,'RA183623088CN\r ','5411juankoby\rGLOT001*2\r兼容型3D眼镜 通用型'),(8421,826378352012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','d.clem23','davidclemente@hotmail.com','David Clemente','1405 Rue des Orioles<br>dclemente1@yahoo.com','Sainte-Catherine','QC','CANADA','J5C 1R7','(450) 635-7455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 13:07:10',0,NULL,3,1,2,1,'\\  ','d.clem23'),(8422,608248255013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.4,'eastar4','darmawan83_211283','darmawan83_21@yahoo.com','Darmawan Wangsadiharja','Jl. Kepatihan VI No. 8','Surabaya','East Java','INDONESIA','60175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 13:07:40',0,NULL,3,1,2,1,'\\  ','darmawan83_211283\racer 8pin1.00 10cm '),(8423,826399750012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',18.98,'eastar4','raup.silva','raupsessim@gmail.com','Raup Silva','Rua General João Telles, 542/503 Bom Fim<br>Bom Fim','Porto Alegre','Rio Grande do Sul','BRAZIL','90035-120','51-99785548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 14:13:48',0,NULL,3,1,2,1,'\\  ','raup.silva\r一共买了两个'),(8424,826412059012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','colonel-81','grafzahl81@googlemail.com','Stefan Talke','Stadtpromenade 11','Cottbus','','GERMANY','03046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 14:42:44',0,NULL,3,1,2,1,'\\  ','colonel-81'),(8425,744554451011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','hali1984','hali84@verizon.net','James Shimshock','P.O. Box 384','New Salem','PA','UNITED STATES','15468','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 14:53:49',0,NULL,3,1,1,1,'\\ ','hali1984'),(8426,744555034011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','locomurdock','actitud@gmail.com','Alexander Murdoch','Rondeau 1843<br>apto. 502t','Montevideo','Montevideo','URUGUAY','11800','+59899224227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 14:55:57',0,NULL,3,1,2,1,'\\  ','locomurdock'),(8427,744556298011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','dhoffmann6l44','dhoffmann@uwalumni.com','Dominik Hoffmann','19700 Helix Dr<br>Personal @ Janelia Farm','Ashburn','VA','UNITED STATES','20147-2408','(240) 281-1619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 15:06:21',0,NULL,3,1,1,1,'\\ ','dhoffmann6l44'),(8428,826423681012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','alecp','alec@mascot.fastmail.fm','Mr A  Pearson','6 Meadway<br>Forest Hall','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE12 9RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 15:13:41',0,NULL,3,1,3,1,'RA183620912CN\r ','alecp\rWLIN013\r通用版'),(8429,744564368011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','avalokman','kpadmana@verizon.net','Krishnan Padmanabhan','25 Stanley Rd','New Providence','NJ','UNITED STATES','07974-1855','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 15:24:30',0,NULL,3,1,1,1,'\\ ','avalokman'),(8430,826442218012,220816377486,'NIB Samsung SSG-2200KR Rechargeable Child 3D Glasses',2,'GLSG003',109.98,'eastar4uk','rikardh1979','rikardh@online.no','Rikard Heimen','Tingveien 8c','Trondheim','Sør Trøndelag','NORWAY','7046','004790520252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-02 16:03:07',0,NULL,3,1,3,1,'RA183623159CN\r ','rikardh1979\rGLSG003\r盒装的'),(8431,744593636011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',17.81,'eastar4','manjmac','hellofatman@yahoo.com.hk','MR. WONG HON YIU','FLAT 15A, VALIANT COMMERCIAL BUILDING, PRAT AVENUE,<br>TSIMSHATSUI, KOWLOON, HONG KONG','default','','HONG KONG','default','(852) 23282623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 16:44:27',0,NULL,3,1,2,1,'\\ ','manjmac\r一代卡旧的\r新地址\rMr. WONG HON YIU\rFlat A, 15/F, Valiant Commercial Building\r22-24 Prat Avenue, Tsim Sha Tsui, Kowloon\rHong Kong\r'),(8432,553881408003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jvl082450','jvanliew@gmail.com','John Van Liew','10 Alta Hill Way','Walnut Creek','CA','UNITED STATES','94595','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-02 16:50:22',0,NULL,3,1,1,1,'\\ ','jvl082450'),(8433,608309780013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','bonecollector99','absinthe_qu@yahoo.com','Kyle Quatman','2057 Lakewood Dr<br>Apt D','Kettering','OH','UNITED STATES','45420-2049','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 17:06:29',0,NULL,3,1,1,1,'\\ ','bonecollector99'),(8434,608315889013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','jesse0471','jesse0471@gmail.com','JESSE ATCHISON','P.O. BOX 1605<br>2273 Camosun Cresent','PORT MCNEILL','BC','CANADA','V0N 2R0','(250) 956-4451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 17:27:33',0,NULL,3,1,2,1,'\\  ','jesse0471'),(8435,744615214011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','coravx','putzka.manfred@gmail.com','Manfred Putzka','5520 Riverbend Rd NW, App. 208<br>Buzz 140 (by day Resident Mgm Buzz 134)','Edmonton','AB','CANADA','T6H 5G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 17:34:44',0,NULL,3,1,3,1,'RA183623043CN\r ','coravx\rHSLO001'),(8436,744623177011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','fixfoxigoofi','mickie@gmx.info','Michael Kietz','Max-Planck-Str. 8, Seite','Moers','','GERMANY','47447','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 17:54:04',0,NULL,3,1,2,1,'\\  ','fixfoxigoofi'),(8437,744632477011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','*pugmilamber*','pugmilamber@hotmail.com','shawn bosworth','26 LONG ACRE','MABLETHORPE','Lincolnshire','UNITED KINGDOM','LN121JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 18:13:25',0,NULL,3,1,3,1,'RA183622374CN\r ','*pugmilamber*\rWLDE001'),(8438,826333392012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','hostinec2010','aleuhin@mail.ru','Andrey Leukhin','b-r Chavaina, 23, 86','Yoshkar-Ola','Mari El','RUSSIAN FEDERATION','424033','79177006670','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 18:25:33',0,NULL,5,1,18,1,NULL,'hostinec2010  已经退款'),(8439,703627564001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',29.9,'buysia','tachtanlee','dim_tachtalis@yahoo.gr','Dimitrios Tachtalis','Oneiron - Aspra Chomata','Loutraki','','GREECE','20300','00306973404558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 18:28:29',0,NULL,3,1,3,1,'RA183620991CN\r ','tachtanlee\rHDGE001'),(8440,608359377013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','marina_kaloudi','marina_k82@yahoo.com','MARINA KALOUDI','DELIGIANNI 31<br>RADIOFONIA','ILION','ATHENS','GREECE','13122','6936864280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 19:35:28',0,NULL,3,1,2,1,'\\  ','marina_kaloudi\r黑色的'),(8441,608372145013,230398744685,'NIB Genuine Altec Lansing M602 iPod Speaker System nano',1,'SPAL001',117,'eastar4','mr63','mgrella63@aol.com','Michael Grella','114 Naubuc Ave','Glastonbury','CT','UNITED STATES','06033-2072','(203) 605-9798','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 20:11:52',0,NULL,3,1,4,1,'YW866127183CN ','mr63'),(8442,744689766011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','akki_azizi','ak.azizi@live.nl','Ak Azizi','Hargewaard 140','Alkmaar','','NETHERLANDS','1824 TE','+31613127123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 20:18:18',0,NULL,3,1,2,1,'\\ ','akki_azizi'),(8443,608384367013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','teelegal','renitam@comcast.net','Marc Harris','102 Ashford Ct','Hendersonville','TN','UNITED STATES','37075-6731','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'teelegal'),(8444,826586103012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','honey.diva','i3ubblegirl@gmail.com','Charmaine Hall','6 Janet Court','Wangaratta','Victoria','AUSTRALIA','3677','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-02 20:48:46',0,NULL,3,1,2,1,'\\  ','honey.diva'),(8445,826588327012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','kingdog1123','travis@teamunited.com','Travis King','Box 1123  or 116 Ave B West','Wynyard','SK','CANADA','S0A 4T0','(130) 655-4252 ext.: 9','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 20:53:23',0,NULL,3,1,2,1,'\\  ','kingdog1123'),(8446,744735927011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',2,'WLIN010+ANTY002',43.76,'eastar4','beingmoody','ebay@ainteasy.net','Mandell Moody','445 Swan Dr','Hiram','GA','UNITED STATES','30141-4446','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 22:00:44',0,NULL,3,1,1,1,'\\ ','beingmoody'),(8447,553973830003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.95,'cnfaner','2mklein2','mklein@saber.net','Michael Klein','HC 62','Alderpoint','CA','UNITED STATES','95511-9801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-02 22:07:48',0,NULL,3,1,1,1,'\\ ','2mklein2\r旧的'),(8448,559515345004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'',14.9,'cnfaner','szani426','lambbox@yahoo.com','Zsolt Levek','Füssener Str. 31<br>Zum Posthörnle','Durach','','GERMANY','87471','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 23:04:27',0,NULL,3,0,3,1,'RA183621008CN\r ','szani426'),(8449,744431180011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','datadoc-0','datadoc0@yahoo.com','Hector Longoria','110 Hibiscus Ct','Brownsville','TX','UNITED STATES','78520-8023','(956) 546-6279','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 23:36:31',0,NULL,3,1,1,1,'\\ ','datadoc-0'),(8450,744763567011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','bobgathome','geachre@yahoo.com','Robert Geach','309 Presidents Blvd','Roscommon','MI','UNITED STATES','48653-8736','(248) 835-4367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 23:38:23',0,NULL,3,1,1,1,'\\ ','bobgathome'),(8451,744776420011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','patrickmcc2009','pmcconnell22@yahoo.com','Patrick McConnell','174 Cindy Anne Dr','Gray','TN','UNITED STATES','37615-6700','(865) 414-0812','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 00:19:52',0,NULL,3,1,1,1,'\\ ','patrickmcc2009'),(8452,608438952013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','byoptions','bo@byoptions.com','Bo Youssef','17 Alba Ave.','Woodbridge','ON','CANADA','L4H2A7','(416) 457-2752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 00:30:20',0,NULL,3,1,2,1,'\\  ','byoptions'),(8453,744784634011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',3,'UDAP002',103.47,'eastar4','gornros','gordo.p@gmail.com','Gordon Prokscha','45 Kirkpatrick Crs','Noranda','Western Australia','AUSTRALIA','6062','0892759275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 00:52:10',0,NULL,3,1,3,1,'RA183623281CN ','gornros\rUDAP002'),(8454,688252912008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','pos6855','office@prosys.com.au','Michael Hirst','c/  Prosys<br>unit 4 221 macquarie street','Hobart','Tasmania','AUSTRALIA','7000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 00:52:27',0,NULL,3,1,3,1,'RA183623012CN\r ','pos6855\rHSPL005\r澳标'),(8455,608443413013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',119,'eastar4','mud_slick','mud_crab@hotmail.com','Lilik Kartikasari','Komplex DPA, No. 16<br>Srengseng','Jakarta','Java','INDONESIA','11630','02158904101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 00:54:46',0,NULL,3,1,3,1,'RA183620988CN\r ','mud_slick\rTRTT002*10'),(8456,608444816013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','old*man','old_man5@juno.com','STEVE SANDERS','po box 320<br>152 suncoast dr.','north sioux city','SD','UNITED STATES','57049','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 00:58:35',0,NULL,3,1,1,1,'\\ ','old*man\r通用版'),(8457,744785006011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','felixpomerantz','fsp@umich.edu','Felix Pomerantz','350 W 37th St<br>Apt 20C','New York','NY','UNITED STATES','10018','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 00:58:42',0,NULL,3,1,1,1,'\\','felixpomerantz'),(8458,744796611011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','guesst','jescad@ymail.com','Jesus Cadena','1267 Chicago St','Green Bay','WI','UNITED STATES','54301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 01:34:45',0,NULL,3,1,1,1,'\\ ','guesst\r 无线蓝牙二合一'),(8459,744806119011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','!sniper','david@rehler.com','David Rehler','4406 N State Highway 97','Sand Springs','OK','UNITED STATES','74063','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 02:10:20',0,NULL,3,1,1,1,'\\ ','!sniper'),(8460,826696958012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*2',209.9,'eastar4','patches9662297','zoo67@persona.ca','Richard Lauzon / c/o Jan Rajotte','9350 Cimaron Rd. S.,<br>Bldg. #7, Unit 2114','Las Vegas','NV','UNITED STATES','89178','(702) 302-4295','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 02:12:13',0,NULL,3,1,6,1,'EE495341096CN ','patches9662297\r兼容型3D眼镜 通用型'),(8461,744816493011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','beduncan1','beduncan@gmail.com','Ben Duncan','136 Ridge Trl','Chapel Hill','NC','UNITED STATES','27516-1638','(919) 749-4029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 02:50:15',0,NULL,3,1,1,1,'\\ ','beduncan1'),(8462,608482641013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','goobmcg','sterlo50@hotmail.com','M McGarry','53 Monsoon Tce','Mount Sheridan','Queensland','AUSTRALIA','4868','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 04:18:56',0,NULL,3,1,2,1,'\\ ','goobmcg'),(8463,826750551012,220586052498,'NEW APC BIOPOD USB Touch Biometric Pod Password Manager',1,'OTAP001',9.49,'eastar4','kakw11','ali.kassas@neuf.fr','kassas','22 av du general de gaulle','maisons laffitte','Ile-de-France','FRANCE','78600','0623894004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 06:00:09',0,NULL,5,1,18,1,NULL,'kakw11  其实没发货  等客户问的时候说丢了  再退款'),(8464,554054834003,130554589035,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',72.99,'cnfaner','nhfbangkok','nickforder@yahoo.co.uk','Nicholas Forder','7/102 Manorom 4 Liap Klongsong<br>Klongsamwa','Bangkok','Bkk','THAILAND','10510','6629142426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 06:03:27',0,NULL,3,1,3,1,'RA183623145CN ','nhfbangkok\rKBNO001'),(8465,826765476012,220815931012,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',14.99,'eastar4uk','alpiiie86','alpiii86@hotmail.com','MUHSIN ALP','MANGÅRDSVÄGEN 21','STOCKHOLM','HUDDINGE','SWEDEN','14151','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 07:11:49',0,NULL,3,1,2,1,'\\ ','alpiiie86\r欧标'),(8466,554063994003,130490602057,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'',38.9,'cnfaner','tsunamiru','samurai80@inbox.ru','Ruslan Palamar','Orekhoviy proezd, dom 45, stroenie 1, kvartira 69','Moscow','','RUSSIAN FEDERATION','115573','(495) 999-3361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 07:13:29',0,NULL,3,0,3,1,'RA183623202CN ','tsunamiru\r已入库\rWLIN002\rIBM的 '),(8467,8881312358807735,111,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk',' innyinskip  ','craig.inskip@yahoo.co.uk','Craig Inskip','Foundation ITFoundation CourtOld Street,','HermitageThatcham','Berkshire','UNITED KINGDOM','RG18 9SE','',NULL,NULL,NULL,'2011-08-03 08:06:47',0,NULL,3,1,3,1,'RA183623114CN\r ','微软的\r\r'),(8468,8881312359074770,111,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4','chriissy_biiscuiit','christinesamuels@live.co.uk','Christine Samuels','208 Malyons Road<br>Ladywell','Ladywell','London','UNITED KINGDOM','SE13 7XF','0206905967',NULL,NULL,NULL,'2011-08-03 08:11:14',0,NULL,3,1,3,1,'RA183623193CN ','钢琴美女伞 \r粉色的\r补发的'),(8469,554085027003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','7x7-bay','7x7@mail.ru','Vadim Tiunov','Derjavina str. 77/1, kv.36','Novosibirsk','','RUSSIAN FEDERATION','630112','+79139163330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 09:35:53',0,NULL,3,1,3,1,'RA183623295CN ','7x7-bay\rMOOE002\r发OEM 的'),(8470,559616243004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','ophtha72','ophtha@empal.com','Jonghyun Lee','Hyundae-Hometown 3rd. Apartment 302-402, Bang-Bae-Dong 2233<br>Seo-Cho-Gu','Seoul','','KOREA,REPUBLIC OF','137-060','(822) 592-4329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 10:20:23',0,NULL,3,1,3,1,'RA183623180CN ','ophtha72\rWLAP008'),(8471,608538098013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',43.9,'eastar4','kaderunfo','unfokader@gmail.com','abdel kader rehaili','1700 draia ahmed','souk ahras','souk ahras','ALGERIA','41000','+213778244278','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'kaderunfo'),(8472,826815880012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','ckmurbano','xtronko@gmail.com','Grupo Dos S.L','Apartado de correos 242','catarroja','Comunidad Valenciana','SPAIN','46470','961269202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 10:32:07',0,NULL,3,1,2,1,NULL,'ckmurbano'),(8473,826832449012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',65.07,'eastar4','northeasthosting','only1pj@gmail.com','Peter Jones','61 Woodland Terrace','Darlington','Co Durham','UNITED KINGDOM','DL3 9NT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 11:31:53',0,NULL,3,0,3,1,'RA183623247CN\r ','northeasthosting\rTRMX003\r再发三个CAB-6060'),(8474,826838339012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','tobym7629','tobym7629@hotmail.com','Toby Morrison','575 Cedar Wood Cir','Bozeman','MT','UNITED STATES','59718-8213','(406) 599-5988','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'tobym7629'),(8475,744951739011,320405615280,'Acer Extensa 4620 4620z 4220 Bluetooth Module 2.0 cable',1,'BTAC2004',12.5,'eastar4','2011rust1962','rustam_abaidulov@mail.ru','Rustam Abaidulov','Krupskoy st., h. 37, a. 3','Sankt-Peterburg','078','RUSSIAN FEDERATION','192029','812-560-3855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 12:54:29',0,NULL,3,1,2,1,' 、 ','2011rust1962\racer 4pin1.25 6cm'),(8476,826877117012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','christodan','christoph_schreiner@web.de','Ch. Schreiner','Stephanstr. 30','Remscheid','','GERMANY','42859','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 13:51:02',0,NULL,3,1,2,1,' 、 ','christodan\r欧标'),(8477,826880887012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','shifaz2010','shf141@hotmail.com','easa shifaz','h.neolight<br>majeedhi magu','male\'','kmale\'','MALDIVES','960','9603321815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 14:05:46',0,NULL,3,1,2,1,' 、 ','shifaz2010'),(8478,745009921011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',64.99,'eastar4uk','jasmine136','mickandaud.brown@virgin.net','Audrey  Brown','54 Bad Bargain Lane','York','North Yorkshire','UNITED KINGDOM','YO310QL','01904425256','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 16:00:36',0,NULL,3,1,3,1,'RA183623216CN\r ','jasmine136\rGLOT001*2\r兼容型3D眼镜 通用型'),(8479,608622977013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23,'eastar4','pengguj','pengguj2000@yahoo.com','pengguang jiang','2860 Geer Rd','turlock','CA','UNITED STATES','95382-1141','(209) 668-9988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 16:46:00',0,NULL,3,1,1,1,' 、 ','pengguj'),(8480,608623198013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','kieffer','kkieff01@yahoo.com','Kenneth Kieffer','419 E 70th Ter','Kansas City','MO','UNITED STATES','64131-1338','(913) 226-9514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 16:48:42',0,NULL,3,1,1,1,' 、 ','kieffer'),(8481,745039022011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','hawleybird','ryan.hawley@gmail.com','Ryan S. Hawely','1326 Stone Meadow Dr','West Jordan','UT','UNITED STATES','84088-4007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 17:07:20',0,NULL,3,1,1,1,'、 ','hawleybird'),(8482,742509315011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','mushroom*blue','chuis@uwindsor.ca','Samuel Chui','53 Eden Avenue','Markham','ON','CANADA','L3R 8S1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:08:18',0,NULL,3,1,2,1,' 、 ','mushroom*blue'),(8483,745058527011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','the26blues91','the26blues@yahoo.co.id','Yan Tanuwidjaja','2A / 333 Anzac Parade<br>Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0296621380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:54:29',0,NULL,3,1,2,1,' 、 ','the26blues91'),(8484,608632484013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','ironside97','ironside_97@hotmail.com','Jean-Philippe Demers','7 place Robert Demers','Victoriaville','QC','CANADA','G6T 1B9','(819) 758-7425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 18:58:45',0,NULL,3,1,3,1,'RA183623304CN\r ','ironside97\rGLOT001*3\r兼容型3D眼镜 通用型'),(8485,745089713011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.9,'eastar4','mclizbeth','ecmcbee@comcast.net','Elizaeth McBee','1015 Westmoreland Blvd','Knoxville','TN','UNITED STATES','37919-7216','(865) 531-1805','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 18:59:41',0,NULL,3,1,1,1,'、 ','mclizbeth'),(8486,825719385012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',7.9,'eastar4','debatts23','debatts23@aol.com','Derek Batts','136 Reese Run','Leesville','La','UNITED STATES','71446','(337) 537-8561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 19:10:17',0,NULL,3,1,1,1,' 、 ','debatts23\r旧的'),(8487,745098921011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','ammarah212','ammarah-laher@hotmail.co.uk','ammarah laher','39 knowles road','batley','West Yorkshire','UNITED KINGDOM','wf17 7rr','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 19:20:01',0,NULL,3,1,2,1,' 、 ','ammarah212'),(8488,825844884012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','shauly4u','shauly@itis.co.il','Shaul Ghivoly','19b, Golomb St.','Givatayim','','ISRAEL','53466','+972-54-5958045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 19:46:17',0,NULL,3,1,3,1,'RA183623176CN ','shauly4u\rWWOT003'),(8489,608693144013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','davort1000','dac1000@gmail.com','Davor Tudjen','Krušljevo Selo 33','Oroslavje','Oroslavje','CROATIA','49243','098/1848961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 20:23:22',0,NULL,3,1,2,1,' 、 ','davort1000'),(8490,823799910012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',2,'WLIN001',51.98,'eastar4','ismailnwar','alamalyemen@yahoo.com','ISMAIL AL-NAWAR','4281 Express Ln<br>Ste L7723','Sarasota','FL','UNITED STATES','34238-2602','(941) 538-6941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 20:28:53',0,NULL,3,1,1,1,' 、','ismailnwar'),(8491,608696423013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',46.99,'eastar4','neo_fito','fitos@telefonica.net','Adolfo Rael Ginovart','C/ Londres, 5  Interior','Barcelona','España','SPAIN','08029','619303735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 20:31:03',0,NULL,3,1,3,1,'RA183623162CN\r ','neo_fito\rWWSI004+ANCN001'),(8492,706308109001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','drlevbk','drlevbk@gmail.com','Lev Klempner','135 San Joaquin Rd','Mountain Village','CO','UNITED STATES','81435-8937','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 20:54:42',0,NULL,3,1,1,1,'、 ','drlevbk\r黑色的'),(8493,827076404012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','jordeca','jordeca@alumni.uv.es','Jorge de Calatrava Rodriguez','Enric Valor 18 pta8','Betera (Valencia)','Comunidad Valenciana','SPAIN','46117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 21:13:01',0,NULL,3,0,2,1,' 、 ','jordeca'),(8494,745151080011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','reachmikebernstein','reachmikebernstein@gmail.com','Michael Bernstein','4455 Los Feliz Blvd<br>Apt 103','Los Angeles','CA','UNITED STATES','90027-2137','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 21:15:04',0,NULL,3,1,1,1,'、 ','reachmikebernstein'),(8495,827081401012,220820867548,'New Grohe handheld Shower Head big water output + hose',1,'OTGR005+OTGR002',39.99,'eastar4','berenike_vi','berenikevs@yahoo.com','BERENIKE VON SCHILLING','72 Est Riv','KINGSHILL','VI','UNITED STATES','00850-9833','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 21:24:39',0,NULL,3,1,1,1,' 、 ','berenike_vi\r大水量花洒和水管'),(8496,827096128012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',21.99,'eastar4','jdlawson','jefflawson00@gmail.com','Jeff Lawson','156 Chandeleur Drive','Mooresville','NC','UNITED STATES','28117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 22:01:45',0,NULL,3,1,1,1,' 、 ','jdlawson'),(8497,827111622012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','ricky_70','erickparra99@hotmail.com','erick parra','10423 plaza','montreal','QC','CANADA','h1h4m1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 22:51:32',0,NULL,3,1,2,1,' 、 ','ricky_70'),(8498,827121215012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','claudwsex','claud0016920@msn.com','Liam Walis','Biscathorpe House<br>Biscathorpe','Louth','Lincolnshire','UNITED KINGDOM','LN11 9RA','07769606008','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 23:23:41',0,NULL,3,1,3,1,'RA183623233CN ','claudwsex\rHSJA010\r英标'),(8499,827127379012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',3,'SCLO003',11.7,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 23:44:51',0,NULL,3,1,2,1,' 、 ','germanskynet'),(8500,745199834011,320721404167,'Transparent Dome Rain Sun Umbrella with black trim',1,'UMTR001',19.99,'eastar4','jenniferwadas','jwadas@rogers.com','Jennifer Wadas','3055 Elmcreek Road<br>Suite 24','Mississauga','ON','CANADA','L5B 4J9','(416) 992-6453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 23:55:24',0,NULL,3,0,2,1,' 、 ','jenniferwadas\r黑色的\r已入库'),(8501,559814167004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','siguana09','gubik@elte.hu','Viktor Gubik','Koranyi Sandor st. 12. IV/20','Budapest','Pest','HUNGARY','1089','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 00:34:36',0,NULL,3,1,3,1,'RA183623255CN ','siguana09\rOTRA001'),(8502,827150305012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',12.5,'eastar4','sailcat7','springfield98@gmail.com','Ken Porter','3965 Buglers Rest Pl','Casselberry','FL','UNITED STATES','32707-4709','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 01:11:20',0,NULL,3,1,1,1,' 、 ','sailcat7'),(8503,745221600011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','namaladj','jim.dalamangas@gmail.com','Jim Dalamangas','35 Wazir St','Bardwell Valley','New South Wales','AUSTRALIA','2207','0400685745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 01:27:02',0,NULL,3,1,2,1,' 、 ','namaladj'),(8504,745221329011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',23.8,'eastar4','happyhudson.123','glynr@optusnet.com.au','Kerry Ramsay','6/31 York Street','Richmond','Victoria','AUSTRALIA','3121','61394211610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 01:27:04',0,NULL,3,1,2,1,' 、 ','happyhudson.123\r二代卡新的'),(8505,8881312427676997,111,'New lady Painting Rain Sun Parasol Stick Umbrella',1,'UM00014',0,'eastar4','teghan666','noonoo7@tiscali.co.uk','nicola davies','21 tristan road','truro','Cornwall','UNITED KINGDOM','tr1 1au','01872263904',NULL,NULL,NULL,'2011-08-04 03:14:36',0,NULL,3,1,3,1,'RA183623352CN ','补发的 \r美女涂鸦伞'),(8506,608790727013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','tangoflowers2009','deadmoroz131274@yandex.ru','Mazhirin Oleg','Krasnogorskay 19<br>kv. 26','Lubercy','','RUSSIAN FEDERATION','140009','+79265873793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 04:01:34',0,NULL,3,1,2,1,'、 ','tangoflowers2009'),(8507,745263255011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','unsungmartyr','philip.wang.89@gmail.com','Philip Wang','51 Burnhill Road','Toronto','ON','CANADA','M1L 4S5','(519) 588-7455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 04:43:24',0,NULL,3,1,2,1,'、 ','unsungmartyr'),(8508,688698420008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','gosiaqasim11','vicky1982usa@gmail.com','Muhammed A Qasim','2801 W Lunt Ave<br>Apt K3','Chicago','IL','UNITED STATES','60645-2945','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-04 05:10:20',0,NULL,3,1,1,1,'、 ','gosiaqasim11'),(8509,745268374011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','tiamomuchomaus','rufus@gmx.com','Roland Schnetzler','Winterthurerstrasse 159','Zürich','','SWITZERLAND','8057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 05:11:54',0,NULL,3,1,2,1,'、 ','tiamomuchomaus'),(8510,608800945013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','jjamieso','john@movetoperth.net','John Jamieson','18 Harling Way','Bullsbrook','Western Australia','AUSTRALIA','6084','0895712554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 05:20:05',0,NULL,3,1,3,1,'RA183623278CN ','jjamieso\rWWOT001+ANCN001'),(8511,559860685004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',32.9,'cnfaner','ayg70','ag70@yandex.ru','Alexey Golembiovsky','Solomenskaya str. 30 ap.39','Kiev','','UKRAINE','03141','380442756907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 06:05:23',0,NULL,3,1,3,1,'RA183623264CN ','ayg70\rHSJA011'),(8512,559869568004,140583359050,'New in box Jabra BT-2080 Wireless Bluetooth Headset',1,'HSJA005',17.9,'cnfaner','alex_cz','akawork@gmail.com','Alexey Astafyev','Klenoviy bulvar, 17, 18','Moscow','','RUSSIAN FEDERATION','115142','+7(926)2565069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 07:16:00',0,NULL,3,1,3,1,'RA183623349CN ','alex_cz\r欧标\rHSJA005'),(8513,554341756003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','j4d0976jesse','j4d0976@yahoo.com','Jesse Thompson','8458 Greylock Ct','Fort Worth','TX','UNITED STATES','76137-5902','(817) 600-4881','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 07:24:55',0,NULL,3,1,1,1,'、','j4d0976jesse'),(8514,554351116003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','bagaevstanislav','dieselnbk@ya.ru','Stanislav Bagaev','ul. Gazoprovod, dom 7, korpus 1, kv. 29','Moscow','','RUSSIAN FEDERATION','117405','7-965-1100004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 07:27:19',0,NULL,3,1,3,1,'RA183623321CN ','bagaevstanislav\rWLIN016'),(8515,745296116011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','vpblau','karsten-ist@abwesend.de','KARSTEN HENNEBERG','Ententeich 32','CELLE','','GERMANY','29225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 07:45:21',0,NULL,3,1,2,1,'\\  ','vpblau'),(8516,8881312445043557,111,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',0,'eastar4uk','mr-chips','abbiejones143@msn.com','Abbie Jones','73 Lisfannon Park','Derry City','NIreland','UNITED KINGDOM','BT48 9DU','02871264949',NULL,NULL,NULL,'2011-08-04 08:04:03',0,NULL,3,1,3,1,'RA183623397CN ','补发的 \rHSMO014\r黑色的旧的'),(8517,745299751011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','dologm','martindolog@gmail.com','Martin Dolog','Kvetoslavov 476','Kvetoslavov','','SLOVAK REPUBLIC','93041','(0911) 369 994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 08:04:27',0,NULL,3,1,2,1,'\\  ','dologm\rRELO002'),(8518,551553684003,130490602057,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'',38.9,'cnfaner','ems7490','josuetorres@optonline.net','Josue C. Torres','2115 Ryer Ave<br>Apt A42','Bronx','NY','UNITED STATES','10457-2915','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 08:14:02',0,NULL,3,0,1,1,'\\ ','ems7490\r已入库\rIBM 的'),(8519,827244308012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','yesihazbacon','alex.bacon@gmail.com','Alex Bacon','17311 Gresham St','Northridge','CA','UNITED STATES','91325-3230','(818) 642-9270','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 08:18:12',0,NULL,3,1,1,1,'\\  ','yesihazbacon'),(8520,745304058011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',3,'HBPH002',191.97,'eastar4','louis_vuitton_gurl','varo@comcast.net','Varo Koga','18655 sw hideo ct','beaverton','or','UNITED STATES','97006-2998','(503) 432-6655','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 08:23:38',0,NULL,3,1,1,1,'\\  ','louis_vuitton_gurl'),(8521,745305770011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','rhak9080','liton2k@gmail.com','Md. Rezaul Hossain','House 146/1, Road - 2, Block - A,<br>Section - 12,','Dhaka','Pallabi','BANGLADESH','1216','8801822829015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 08:32:35',0,NULL,3,1,2,1,'、 ','rhak9080'),(8522,608829209013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','bulinin','mbulinin@mail.ru','Julia Bulinina','Leninskiy Prospekt 116.1.7','Moscow','RU','RUSSIAN FEDERATION','119415','(916)654-1619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 08:44:08',0,NULL,3,1,2,1,'、 ','bulinin'),(8523,608832261013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',278.99,'eastar4','skrudj','skrudjandry@gmail.com','Andrey Deryabin','m-n.50a,Altay-2, App.22','Almaty','Kasakhstan','KAZAKHSTAN','050039','+7(727)2527335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 09:03:12',0,NULL,3,1,3,1,'RA183623370CN ','skrudj\rOTSO004*4'),(8524,686216112008,180699060712,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',26.8,'au-buy','sidcarlton','sidcarlton@optusnet.com.au','sid cito','6 Valda Ave','Arncliffe','New South Wales','AUSTRALIA','2205','0295924044','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 09:27:53',0,NULL,3,1,3,1,'RA183623383CN ','sidcarlton\r澳标\rHSMO019'),(8525,745321039011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','australiasteve','stevejackson@stevejackson.com.au','Steve Jackson','532 Brighton Road','Brighton','South Australia','AUSTRALIA','5048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 09:40:47',0,NULL,3,1,2,1,'\\ ','australiasteve\rRELO002'),(8526,745327989011,320701412794,'2 pairs of SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',139.9,'eastar4','laney711','kosmo18@bigpond.net.au','Kate A Weir','4 Holly Place','Golden Grove','South Australia','AUSTRALIA','5125','0882895558','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-04 10:08:19',0,NULL,3,1,3,1,'RA183624256CN\r ','laney711\rOTSO004*2'),(8527,745329090011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','toomuchstuff!!','potentiality_@hotmail.com','Accretive Technologies (ATTN: DREW)','2019 3rd Ave','Seattle','WA','UNITED STATES','98121','(206) 326-1158','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 10:13:33',0,NULL,3,1,1,1,' \\','toomuchstuff!!'),(8528,827300406012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',139.99,'eastar4','edsoneff','edson.eff@bol.com.br','edson fonseca','Rua T-36 nr 3673 apto 1502<br>Setor Bueno','Goiânia','Goiás','BRAZIL','74.223-050','062-9688-1432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 11:48:29',0,NULL,3,1,3,1,'RA183624242CN\r ','edsoneff\rOTSO004*2'),(8529,827309572012,220807319942,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4','iheartwinter','pinkanimegirl06@hotmail.co.uk','Elaine Lieu','29 Falstaff Court<br>Opal Street','London','London','UNITED KINGDOM','SE11 4RP','07845633656','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-04 12:20:48',0,NULL,3,1,2,1,'\\ ','iheartwinter\r钢琴美女伞 \r白色的'),(8530,608879395013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','lachlan_mc','lachlan.mcginty@gmail.com','Lachlan McGinty','6/1 Kenneth Ave','Baulkham Hills','New South Wales','AUSTRALIA','2153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:13:11',0,NULL,3,1,2,1,'\\ ','lachlan_mc\r红边优联'),(8531,745386386011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','dbeeonator','apexcreative@optusnet.com.au','damien brandon','90a liberty parade','bellfield','Victoria','AUSTRALIA','3981','0433151573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:47:31',0,NULL,3,1,3,1,'RA183623454CN\r ','dbeeonator\rBR3D001'),(8532,745393540011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','fabio_lay','fabio_lay@hotmail.com','Fabien Ateba Landry','Trondheimsveien 143','OSLO','OSLO','NORWAY','0570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 14:02:42',0,NULL,3,1,2,1,'\\ ','fabio_lay'),(8533,827346766012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','c10sdc','stephen@digiterati.co.uk','Stephen Cawley','Inglewood, The Courtyard, Moorhouse','Carlisle','Cumbria','UNITED KINGDOM','CA56EX','07710151159','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 14:07:58',0,NULL,3,1,3,1,'RA183623366CN\r ','c10sdc\rOTGR001'),(8534,827344832012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','xtrimal','xtrimal@gmail.com','Aleksey Demyanov','Mashtakova st. 5 A -  23','Podolsk','Moskovskaya oblast','RUSSIAN FEDERATION','142110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 14:15:25',0,NULL,3,1,2,1,'\\ ','xtrimal'),(8535,745401742011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','vasyashchekotov','lubimez@gmail.com','Vasya Shchekotov','St. Lebedeva 41-31','Tomsk','Tomsk','RUSSIAN FEDERATION','634061','(923)4016910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 14:28:16',0,NULL,3,1,2,1,'\\ ','vasyashchekotov\r欧标'),(8536,745406280011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','thelimeguy','corkdork@cfl.rr.com','Daniel Hindsley','3913 Upmann Dr','Rockledge','FL','UNITED STATES','32955-5351','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 14:41:30',0,NULL,3,1,1,1,'\\ ','thelimeguy'),(8537,745409929011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','devildoll_texas','jace.barbin@att.com','L Jace Barbin','9121 E Lost Hill Dr','Lone Tree','Co','UNITED STATES','80124-6747','(214) 704-4000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 14:52:46',0,NULL,3,1,1,1,'\\ ','devildoll_texas'),(8538,608934583013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',52.2,'eastar4','gr4ve','michalbinczyk@wp.pl','Michał Bińczyk','Małopolska 87/7','Jastrzębie Zdrój','','POLAND','44-335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 16:53:48',0,NULL,3,1,3,1,'RA183623445CN\r ','gr4ve\rCASS003\rCAB-6060'),(8539,608935544013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','phillip.cansler','pc83@duke.edu','Phillip Cansler','308 Research Dr<br>B342C LSRC Bldg, Box 91009','Durham','NC','UNITED STATES','27708-9975','(919) 435-4418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 16:56:49',0,NULL,3,1,1,1,'\\ ','phillip.cansler\r红边优联'),(8540,827426548012,220816847816,'New Ralink RT2870F Wirelessz-N USB Adapter 300M',1,'OTRA001',23.99,'eastar4uk','czarlson111','cdybalaa@gmail.com','Cezary Dybala','81 Brouncker Road','London','London','UNITED KINGDOM','w38af','004407580426','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 17:31:21',0,NULL,3,1,3,1,'RA183623437CN\r ','czarlson111\rOTRA001'),(8541,743115890011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','opporchancity','galaxians@gmail.com','Gavin Miller','The Edinburgh Letting Co<br>35 William Street','Edinburgh','Midlothian','UNITED KINGDOM','EH37LW','07545378476','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 17:47:59',0,NULL,3,1,3,1,'RA183623539CN\r ','opporchancity\rUDAP001'),(8542,823490530012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',2,'UM00008',99.96,'eastar4','vyssotskiy','vyssotskiy@of.kz','Vladimir Vysotskiy','161 Kytyzova Str, room 46','Pavlodar','Kazakhstan','KAZAKHSTAN','140000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 17:50:36',0,NULL,3,1,3,1,'RA183623595CN ','vyssotskiy\rUM00008\r24K 多色伞\r一共买了4把伞\r分两票发 \rRA183623658CN'),(8543,745482872011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','lpheiner','heinerlp@comcast.net','Jenny Heiner','850 Grove Dr','Alpine','UT','UNITED STATES','84004-1106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 18:04:10',0,NULL,3,1,1,1,'\\\r ','lpheiner\r二代卡 旧'),(8544,608958392013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','virtustex','yurik_nnov@mail.ru','Yuriy Zapatockiy','Permyakova st., 28-93','Nijniy Novgorod','Nijegorodskaya oblast\'','RUSSIAN FEDERATION','603095','+79040600569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 18:11:25',0,NULL,3,1,3,1,'RA183623423CN\r ','virtustex\rWLIN014\r通用版'),(8545,608961997013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','tahirpasha','tahirpasha@hotmail.com','Tahir Pasha','1635 Waldie Ave.','Milton','ON','CANADA','L9T 5N3','(905) 542-9990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 18:21:30',0,NULL,3,1,2,1,'\\ ','tahirpasha'),(8546,554484599003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','mooney75mooney','avenger19962002@yahoo.com','Barry Youmans','496 E Quail St','Sparks','NV','UNITED STATES','89431-3354','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 18:26:07',0,NULL,3,1,1,1,'、 ','mooney75mooney'),(8547,554487772003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','mooney75mooney','avenger19962002@yahoo.com','Butch Youmans','15310 Macadam Road South, A304','Tukwila','WA','UNITED STATES','98188','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 18:36:50',0,NULL,3,1,1,1,'、 ','mooney75mooney'),(8548,827472364012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','juliols','julosu@gmail.com','Julio Lopez Suarez','Monsanto<br>Paraje Romeral y Atochares, S/N','La Mojonera. Almeria','Andalucía Ceuta y Melilla','SPAIN','04745','650468175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 19:07:55',0,NULL,3,1,3,1,'RA183623587CN ','juliols\rGLSG001*2'),(8549,827478388012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','norkorn2','norkorn@gmail.com','Artem Popov','Bolshoi Matrosskiy pereulok<br>house 1, ap. 145','Moscow','','RUSSIAN FEDERATION','107076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 19:13:14',0,NULL,3,1,3,1,'RA183623542CN\r ','norkorn2\rWLIN001+ANCN002\r再发一个New genuine Intel WiMAX 6250 622AGXHRU wifi'),(8550,827496469012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','norkorn2','norkorn@gmail.com','Artem Popov','Bolshoi Matrosskiy pereulok<br>house 1, ap. 145','Moscow','','RUSSIAN FEDERATION','107076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 19:48:25',0,NULL,3,1,17,0,NULL,'norkorn2\r\r'),(8551,745534296011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','128olives','michelleannemee@gmail.com','Michelle Morgan','4 Chester Road<br>Whitehall','Bristol','Bristol','UNITED KINGDOM','BS57AX','01179738360','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'128olives'),(8552,745536495011,320687842759,'New 2.8\" 4G LCD Touch Screen MP4+MP3+FM MEDIA PLAYER',1,'OTMP001',29.99,'eastar4','mariasofokleousael','maria_sofokleous@hotmail.com','Maria Sofokleous','Dionisiou Solomou 5','Limassol','Katholiki','CYPRUS','3022','96452901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 19:59:56',0,NULL,3,1,2,1,'\\ ','mariasofokleousael\r黑色的'),(8553,745539992011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','09akris72','akris@hot.ee','Sergey Sarapov','Kari 6-14','Tallinn','','ESTONIA','10313','(372)55644056','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 20:05:25',0,NULL,3,1,3,1,'RA183623508CN\r ','09akris72\rHSJA011'),(8554,706680522001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','martita6592011','martita659@gmail.com','Martha Roldán','571 Valencia St<br>Apt 3','San Francisco','CA','UNITED STATES','94110-1160','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 20:23:17',0,NULL,5,0,18,0,NULL,'martita6592011\r客户要撤单'),(8555,608729358013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','ihsaan7','iamotara@gmail.com','Ihsaan Motara','Suite 302, Al Durrah Office Towers<br>Buhairah Corniche, Al Intifidah Road,','Sharjah','SHARJAH','UNITED ARAB EMIRATES','AL KHAN','+971 55 335 3781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 20:48:01',0,NULL,3,1,2,1,'\\ ','ihsaan7'),(8556,745560687011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','prgpas','prg.pas@gmail.com','Rodion Polisadov','Karla Marksa prosp. 122/89','Samara','RU','RUSSIAN FEDERATION','443013','79179460789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 20:52:02',0,NULL,3,1,2,1,'\\ ','prgpas'),(8557,745556449011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.99,'eastar4','str1d','delta@person.dk','Bo Kanstrup Hansen','Oester Farimagsgade 18a 2.th','Oesterbro','kbh','DENMARK','2100','+45 60858530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 20:53:25',0,NULL,3,1,2,1,'\\ ','str1d\r带麦的'),(8558,745568648011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','minooiran','behnamo.o@hotmail.se','Minoo Raghibi','Mörbyleden 14','Stockholm','SD','SWEDEN','182 32','+46733180638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 21:16:52',0,NULL,3,1,2,1,'\\ ','minooiran\r二代卡 旧'),(8559,745575063011,320738499440,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',12.85,'eastar4','sharkboy_69','simon.williams@vertex.co.uk','Simon Williams','6 Night Owls<br>Greenham','Newbury','Berkshire','UNITED KINGDOM','RG19 8SB','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-04 21:27:31',0,NULL,3,1,2,1,'\\ ','sharkboy_69\r韩版透明伞\r带圆点的'),(8560,554542809003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','lsartori1977','lsartori1@hotmail.com','Luigi Sartori','Bilbao 1546 Depto 31<br>Block 4A','Quilpue','Valparaiso','CHILE','2430000','56-94410345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 21:36:36',0,NULL,3,1,3,1,'RA183623600CN ','lsartori1977\rMOOE002\r发OEM的'),(8561,745580612011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','tranzfusion83','tranzfusion63@hotmail.com','Rebecca Davis','7297 Division St','Willards','MD','UNITED STATES','21874-1164','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 21:44:09',0,NULL,3,1,1,1,'\\ ','tranzfusion83'),(8562,609029608013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','gabryel_87','gabryel.87@gmail.com','Gabriel Palacios','Mexico 444','Capital Federal','Ciudad de Buenos Aires','ARGENTINA','1097','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 21:54:38',0,NULL,3,1,2,1,'\\ ','gabryel_87'),(8563,560068719004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','gabryel_87','gabryel.87@gmail.com','Gabriel Palacios','Mexico 444','Capital Federal','Ciudad de Buenos Aires','ARGENTINA','1097','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 21:55:45',0,NULL,3,1,3,1,'RA183623485CN\r ','gabryel_87\rHSNO022'),(8564,745600792011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',2,'UDAP002',68.98,'eastar4','ctsimonson','charlest@isomedia.com','Charles Simonson','PO Box 815','Tracyton','WA','UNITED STATES','98393-0815','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 22:47:05',0,NULL,3,1,1,1,'\\ ','ctsimonson'),(8565,554566188003,130553375752,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'cnfaner','yvesetfrance','yves29@hotmail.com','Yves Aubé','625 Georges VI','Terrebonne','QC','CANADA','J6Y 1n4','(450) 965-7285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 23:35:13',0,NULL,3,1,3,1,'RA183623525CN\r ','yvesetfrance\rHSNO026'),(8566,827283803012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.4,'eastar4uk','lordttt','lordttt.ebay@googlemail.com','Richard Turner-Trotter','23 Nodes Drive<br>Broadwater','Stevenage','Herts','UNITED KINGDOM','SG2 8AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 23:50:22',0,NULL,3,1,3,1,'RA183623410CN\r ','lordttt\rSCLO002'),(8567,745619861011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','voippur','richard@richardijzermans.nl','Richard IJzermans','Ranselberg 29','Veldhoven','','NETHERLANDS','5508EK','0408487278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 00:00:44',0,NULL,3,1,3,1,'RA183623511CN\r ','voippur\rUDAP002'),(8568,745620957011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',10.39,'eastar4uk','ra17lm1nas','ebayjunk@ntlworld.com','nigel swann','11 erdyngton road','leicester','leicestershire','UNITED KINGDOM','le3 1jf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 00:05:44',0,NULL,3,1,3,1,'RA183623499CN\r ','ra17lm1nas\rWLAT008'),(8569,827595852012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','pcgear0','mediopc@optusnet.com.au','Luke Coppens','22 Bladen Ave','Brunswick East','Victoria','AUSTRALIA','3057','0383766533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 00:06:38',0,NULL,3,1,3,1,'RA183623471CN\r ','pcgear0\rOTGR001+OTGR002'),(8570,745624675011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',32,'eastar4','tom5414','t.truax@comcast.net','Thomas Truax','716 Dennis St SE<br>Spc 49','Tumwater','WA','UNITED STATES','98501-6407','(360) 970-6261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 00:22:19',0,NULL,3,1,1,1,'\\ ','tom5414\r二代卡 旧'),(8571,745633989011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','ariels2002','seravalleariel@hotmail.com','Ariel Seravalle','Constancio Vigil 1785','Villa Maria','Cordoba','ARGENTINA','5900','54-353-4066268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 01:04:53',0,NULL,3,1,3,1,'RA183623556CN\r ','ariels2002\rBR3D001\r申报18美金'),(8572,554580572003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.8,'cnfaner','abaker4047','abaker4047@yahoo.com','Andy Baker','2660 Kay Ellen Dr','Indianapolis','IN','UNITED STATES','46229-1237','(812) 219-4101','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 01:07:00',0,NULL,3,1,1,1,'\\ ','abaker4047'),(8573,609075851013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','vsm_sir','dplewes@hotmail.com','Daniel Plewes','100 Buxton Rd','Winnipeg','MB','CANADA','R3T 0G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 01:46:27',0,NULL,3,1,2,1,'\\ ','vsm_sir\r红边优联'),(8574,745643079011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','khark1987','kdharkness@mail.widener.edu','Kevin Harkness','325 Dartmouth Ave<br>Apt D3','Swarthmore','PA','UNITED STATES','19081-1523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 01:48:00',0,NULL,3,1,1,1,'\\ ','khark1987'),(8575,554589478003,130554588551,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.85,'cnfaner','nicjonic4001','nicjonic@hotmail.com','Nicolas Leclair','759 chemin des malards','St-Nicolas','QC','CANADA','g7a 3s1','(418) 831-4938','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 01:58:38',0,NULL,3,1,3,1,'RA183623468CN\r ','nicjonic4001\rMOLO002'),(8576,827635970012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',18.9,'eastar4','apaz2250','jonpaz305@gmail.com','Jonathan Paz','14951 Royal Oaks Ln<br>Apt 706','North Miami','FL','UNITED STATES','33181-2476','(305) 321-5463','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 02:40:22',0,NULL,3,1,1,1,'\\ ','apaz2250'),(8577,706786451001,110701383504,'NIB CBS High Pressure Portable Car Washer wash',1,'CAWA001',69.9,'buysia','miskoandriy845','miskoandriy@yahoo.com','ANDRIY MISKO','11 ESSEX LANE APT. 6A','SUFFERN','NY','UNITED STATES','10901','(845) 504-0058','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 03:09:56',0,NULL,3,1,4,1,'YW866127835CN ','miskoandriy845\r8L的'),(8578,745671169011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',24.99,'eastar4','cinemalink','gregory@clink.com.au','Cinema Link','216 Victoria St','Beaconsfield','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 03:44:24',0,NULL,3,1,2,1,'、 ','cinemalink\r24K超轻碳纤骨长柄伞 \r蓝色的\r\r'),(8579,609099812013,230655991728,'New Portable Funny Wine Bottle Folding Sun Umbrella',1,'UM00030',10.99,'eastar4','qqhisoka','piggytailgirl@yahoo.com','Lin Zhan','8933 Carroll Manor Dr','atlanta','GA','UNITED STATES','30350','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 04:01:37',0,NULL,3,1,1,1,'\\','qqhisoka\r红酒瓶草莓伞'),(8580,745679678011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','ytrlwls','jgaribaldi7@gmail.com','James Garibaldi','678 Tranquility Dr','Denham Springs','LA','UNITED STATES','70706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 04:31:45',0,NULL,3,1,1,1,'\\','ytrlwls\r二代卡旧的'),(8581,609115124013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','bandatheflavours','comercial@gruporgf.com.br','Rodrigo Gomes Falcão','Rua Schilling, 413','São Paulo','São Paulo','BRAZIL','05302-001','+551136446843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 06:06:22',0,NULL,3,1,2,1,'、 ','bandatheflavours'),(8582,745717620011,320730088105,'New Replaceable Shell for logitech Mouse MX518',1,'SHLO004',9.99,'eastar4uk','ralovni','involar@gmail.com','Ivan Chiriac','kv. Ovcha Kupel .no 2, bl. 39A, fl. 13, ap. 59','Sofia','Sofia','BULGARIA','1632','+359894346005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 08:02:27',0,NULL,3,1,2,1,'、 ','ralovni'),(8583,554638143003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','robertn2855','rstnyhuis@hotmail.com','amcar freight/mercy marimon','12600 NW 25th St<br>Ste 107','miami','FL','UNITED STATES','33182-1508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 08:23:52',0,NULL,3,1,1,1,'、 ','robertn2855\r发OEM的'),(8584,745722044011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','rayon*','lapypool@free.fr','Dupeyron Julien','36 Bd des crêtes','Pyla sur Mer','FRANCE MÉTROPOLITAINE','FRANCE','33115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 08:24:13',0,NULL,3,1,3,1,'RA183622961CN ','rayon*\rUDAP001'),(8585,706839365001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',16,'buysia','jtok4j','jtok4jesus@yahoo.com','Justin Kiffiak','4283 Express Ln<br>Ste R9753','Sarasota','FL','UNITED STATES','34238-2602','(403) 569-8845','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 08:31:33',0,NULL,3,1,1,1,'、 ','jtok4j'),(8586,745731122011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','megagolgoth','jlienard@altern.org','Liénard Jérémie','La grelonnerie','Vica sur nahon','Centre','FRANCE','36600','+33(0)607936373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 09:05:56',0,NULL,3,1,2,1,'、 ','megagolgoth'),(8587,609140534013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','jbasile2010','bulldog656@live.com','Joseph Basile','5415 S Shartel Ave<br>Apt 525','Oklahoma City','OK','UNITED STATES','73109-4842','(405) 225-7655','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 09:07:24',0,NULL,3,1,1,1,'\\  ','jbasile2010'),(8588,745738616011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','philippe_34','ornvin@yahoo.fr','philippe vaugrente','69 rue georges clemenceau','montblanc','Languedoc-Rousillon','FRANCE','34290','04.67.00.29.59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 09:37:09',0,NULL,3,1,2,1,'、 ','philippe_34'),(8589,827727511012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','exopc','info@exopc.com','EXOPC','94 Avenue Rouleau','Rimouski','QC','CANADA','G5L 5S5','(418) 727-6914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 09:46:10',0,NULL,3,1,3,1,'RA183623785CN\r ','exopc\rOTSO002'),(8590,745746560011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','trenton007','firemed@neo.rr.com','Steve  Anderson','2264 Englewood Ave','Akron','OH','UNITED STATES','44312-1256','(330) 734-0706','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 10:10:10',0,NULL,3,1,1,1,'\\  ','trenton007'),(8591,560183768004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'cnfaner','danielmetalbones','danielrom23@gmail.com','Daniel Rom','Haim shiba 36','Beer Sheva','','ISRAEL','84492','+972-54-4648952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 10:54:03',0,NULL,3,1,3,1,'RA183624123CN\r ','danielmetalbones\rOTTP001'),(8592,745757810011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','krzys_io','krzysiek3m@gmail.com','Krzysztof Noga','Drzewieckiego 8E / 20','Gdansk','pomorskie','POLAND','80-464','660 480777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 10:55:06',0,NULL,3,1,2,1,'\\  ','krzys_io'),(8593,745768971011,320441946530,'2.1 HP mini 2133 2140 Bluetooth Module EDR + cable',1,'BTHP2101',12.4,'eastar4','vaniliopoulos','van.iliopoulos@ncr.com','Van ILIOPOULOS','6 Gretna Court','Greenvale','Victoria','AUSTRALIA','3059','0393332218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 11:39:55',0,NULL,3,1,2,1,'\\  ','vaniliopoulos\rHP 8pin 1.0 3cm  '),(8594,554675027003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',66.9,'cnfaner','loui$cyphre','andre.krueger.db@googlemail.com','André Krüger','Industriestr. 8<br>Comfort Systems Ronad Schmidt /André Krüger','Rostock','','GERMANY','18069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 12:01:50',0,NULL,3,1,3,1,'RA183623635CN\r ','loui$cyphre\rMOSA003'),(8595,745784116011,320730084692,'HP BCM94322 WLAN Half Mini PCI-E Card + tyco antenna',1,'WLHP002+ANTY001',13,'eastar4uk','logicman1628','tfox@logiccomputers.com','john anthony Fox','unit 11 & 12 CIDO Business Complex<br>Charles Street','Lurgan','Armagh','UNITED KINGDOM','BT66 6HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 12:36:23',0,NULL,3,1,3,1,'RA183623936CN\r ','logicman1628\rWLHP002+ANTY001'),(8596,609180303013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','esmesmoselo','migueljdpeixoto@gmail.com','Miguel Peixoto','Rua da Mouta Lote G 5 - Lomar','Braga','Braga','PORTUGAL','4705-180','927046956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 12:47:19',0,NULL,3,0,3,1,'RA183623627CN\r ','esmesmoselo\r已入库\rCASS003\rCAB-6060'),(8597,827789002012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',81.99,'eastar4uk','leoburton','leo@solutionstudios.net','Leo Burton','37 Teversham Lane','Stockwell','London','UNITED KINGDOM','sw8 2dj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 13:14:21',0,NULL,3,1,3,1,'RA183624199CN\r\r ','leoburton\rGLOT005*2\r投影仪兼容眼镜'),(8598,745798220011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','hdg8006','hans.degeytere@googlemail.com','Hans de Geytere','Lange Hoevestraat 7','Baal','','BELGIUM','3128','0494263661','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 13:19:03',0,NULL,3,1,3,1,'RA183623851CN\r ','hdg8006\rUDAP001'),(8599,827790858012,220812859649,'3DConnexion SpacePilot USB 3D Motion Controller mouse',1,'MOLO004',226,'eastar4','saeedgh','saeedgharleghi@gmail.com','Saeed Gharleghi','Jumeira st.','Dubai','Duabi','UNITED ARAB EMIRATES','2330','0504221847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 13:20:38',0,NULL,3,0,3,1,'RA183621780CN ','saeedgh\rMOLO010\r已入库\r'),(8600,560220577004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','freddemagic','pfostersund@gmail.com','Fredrik Engberg','Brunkullavägen 4','Brunflo','','SWEDEN','83431','466323032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 14:07:25',0,NULL,3,1,3,1,'RA183623729CN\r ','freddemagic\rOTRA001'),(8601,745812980011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',25.99,'eastar4','leftyluk','sailaway_01@sbcglobal.net','WILLIAM WENTZ','1246 N Livingston Ave','INDIANAPOLIS','IN','UNITED STATES','46222-2927','(317) 636-7955','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 14:08:16',0,NULL,3,1,1,1,'\\  ','leftyluk'),(8602,745796598011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','graydf38','graemefuller@iinet.net.au','Graeme Fuller','P.O. Box 444','Scarborough','Western Australia','AUSTRALIA','6922','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 14:29:00',0,NULL,3,1,3,1,'RA183623940CN\r ','graydf38\rBR3D001'),(8603,745821103011,320700100689,'NIB cisco Linksys DMP100 Wireless-N Music Extender',1,'OTLK001',119,'eastar4','bfmstanford','2024681565@tmomail.net','Bryan Moore','3 Rosecrest Ave','Alexandria','VA','UNITED STATES','22301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 14:32:12',0,NULL,3,1,4,1,'YW866127231CN ','bfmstanford'),(8604,745826752011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','ts-art','peter@whywouldwe.com','Peter Flood','9/17 Moo 6<br>Thepkasattri Road','A. Muang','Phuket','THAILAND','83000','66899705300','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 14:58:57',0,NULL,3,1,2,1,'\\','ts-art\r微软的\r新地址\rPeter Flood\rAsia Web Direct\r9/17 Moo 6 \rThepkasattri Road\rA. Muang\rPhuket \r83000\rThailand\r'),(8605,827826386012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','toddbooster','toddbooster@rogers.com','Todd N Tolls','1057 Davenport Rd.<br>Apt. 2','Toronto','ON','CANADA','M6G 2C2','(416) 890-9158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 15:04:07',0,NULL,3,1,3,1,'RA183624110CN\r ','toddbooster\rRCLO002\r旧的'),(8606,609216538013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','sisithad','chamilabj@hotmail.com','Dinuka Jayanath','No:852/37A , Robert Gunawardena Mawatha ,<br>Susithapura','Malabe','Western','SRI LANKA','0094','0094777370395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 15:21:00',0,NULL,3,1,2,1,'\\  ','sisithad'),(8607,609226569013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','007radim6036','radim@dolezal-cz.com','Radim Dolezal','Novy Malin 606<br>Novy Malin','Novy Malin','Olomoucky kraj','CZECH REPUBLIC','78803','+420 581111093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 15:56:40',0,NULL,3,1,2,1,' \\','007radim6036\r'),(8608,827862000012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',190.98,'eastar4','rob-pf','technocom@mail.pf','MAES Robert','BP 679 PAPEETE TAHITI  FRENCH POLYNESIA','PAPEETE','TAHITI','FRENCH POLYNESIA','98713','689 480026 /689 770126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 16:47:36',0,NULL,3,1,3,1,'RA183624145CN\r ','rob-pf\rGLSG001*2\r再发一个New genuine Samsung 3D Active Glasses SSG-2100AB'),(8609,827866989012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',235.99,'eastar4','suanycarlos','sdavilaocasio@yahoo.com','Suan  Davila','48 Ave Jupiter<br>Barriada Sandin','Vega Baja','PR','UNITED STATES','00693-3370','(787) 354-6501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 16:48:05',0,NULL,3,1,6,1,'EE495341082CN ','suanycarlos'),(8610,827855988012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','zipper480xm','clive.adamson@virgin.net','Clive Adamson','28 Shore Drive, Port Sunlight,<br>Bebington','Wirral','Cheshire','UNITED KINGDOM','CH62 4RW','01516457713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 17:00:44',0,NULL,3,1,3,1,'RA183623750CN\r ','zipper480xm\rWLAP001+WLAP004'),(8611,745873033011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','eric_gignac','eric.gignac@gmail.com','Eric Gignac','1009 Bleury #1802','Montreal','QC','CANADA','H2Z 0A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 17:00:45',0,NULL,3,1,2,1,'\\  ','eric_gignac'),(8612,608993058013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',2,'BTHP2107',24.8,'eastar4','g1967','greg@diamondpaws.com','Greg Hindle','2711 Bayonne Ave','Baltimore','MD','UNITED STATES','21214-1722','(443) 928-0658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 17:02:42',0,NULL,3,1,1,1,'\\  ','g1967\rHP 8pin 1.0 23cm '),(8613,554746934003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','dude_brazil','al3xpoa@gmail.com','Alexandre Oss','Rua Pedro Grendene, 629 casa 402<br>Bairro Volta Grande','Farroupilha','Rio Grande do Sul','BRAZIL','95180000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 17:25:58',0,NULL,3,1,3,1,'RA183623896CN\r ','dude_brazil\rOTCR001'),(8614,689279509008,180699060966,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','rickgourdier','catsdughi@mchsi.com','Laurie Dughi','1055 Iron Bridge Rd<br>PUT IN BLACK BOX AT GATE','Havana','FL','UNITED STATES','32333-5779','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-05 17:37:22',0,NULL,3,1,1,1,'\\  ','rickgourdier'),(8615,743371975011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','machocloud','jcloud123@sbcglobal.net','jeffery cloud','19411 Diversion Dr','tomball','TX','UNITED STATES','77375-7684','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 18:16:17',0,NULL,3,1,1,1,'\\  ','machocloud'),(8616,558593717004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','machocloud','jcloud123@sbcglobal.net','jeffery cloud','19411 Diversion Dr','tomball','TX','UNITED STATES','77375-7684','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 18:16:18',0,NULL,3,1,1,1,'\\  ','machocloud'),(8617,827908332012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',19.98,'eastar4uk','crussia','zratsch63@gmail.com','Zenon Ratschkewycz','6 Alcester Drive','Sutton Coldfield','West Midlands','UNITED KINGDOM','B73 6PY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 18:21:18',0,NULL,3,1,3,1,'RA183623777CN\r ','crussia\rWLAP008'),(8618,560286148004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','sycocflj','ljohnsontd@aol.com','Leland Johnson','131 Chambwood Lane','Shelby','NC','UNITED STATES','28152','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 18:38:16',0,NULL,3,1,1,1,'\\  ','sycocflj'),(8619,745916925011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','futureframe2010','futureframeltd@yahoo.com','Oludimu Olusoji','89 Withern Road','Nottingham','Nottinghamshire','UNITED KINGDOM','NG8 6FH','1159608064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 18:47:36',0,NULL,3,1,2,1,'\\  ','futureframe2010'),(8620,608384367013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','teelegal','renitam@comcast.net','Marc Harris','102 Ashford Ct','Hendersonville','TN','UNITED STATES','37075-6731','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 18:58:05',0,NULL,3,1,1,1,'\\  ','teelegal\r黑色的'),(8621,745932622011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','compused_ca','ebay@compused.ca','Justin McDermid','5011 Silver Star Road','Vernon','BC','CANADA','V1B3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 19:24:36',0,NULL,3,1,2,1,'\\  ','compused_ca\r 二代卡 旧'),(8622,609297229013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','hockiedoc','jlittman@rochester.rr.com','jon e littman','205 Plains Rd','honeoye falls','NY','UNITED STATES','14472-9343','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 20:13:16',0,NULL,3,1,1,1,'\\  ','hockiedoc\r旧的'),(8623,745971964011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','modeus451','modeus451@btconnect.com','Christopher Brine','4 Newton Green<br>Dunmow','Essex','Essex','UNITED KINGDOM','CM6 1DU','07970389175','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 20:59:13',0,NULL,3,1,3,1,'RA183623763CN\r ','modeus451\rWLAP002\r二代卡 旧'),(8624,827979100012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',4,'CASS001',23.96,'eastar4uk','peterz3494','peter.zilik@gmail.com','Peter Zilik','Palkovicova 2/C','Bratislava','','SLOVAK REPUBLIC','82108','+421903553826','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 21:04:45',0,NULL,3,1,3,1,'RA183624049CN\r ','peterz3494\rCASS001'),(8625,745992027011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','alpha0316elton','alphaprez06@gmail.com','elton kIRKWOOD','9905 Oak Knoll Ter','colorado springs','CO','UNITED STATES','80920-2429','(719) 271-7147','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 21:59:06',0,NULL,3,1,1,1,'\\  ','alpha0316elton'),(8626,554826533003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.8,'cnfaner','jcharles2011','jdc@usa.com','Jeremy Charles','2412 Dupont Ave S<br>Apt 2','Minneapolis','MN','UNITED STATES','55405-3081','(715) 505-1848','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 22:27:16',0,NULL,3,1,1,1,'\\  ','jcharles2011'),(8627,828017207012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','milanmajkut','majkutmilan@gmail.com','Milan Majkut','Bottyanhegy str. 13. 3/13.','Szekszard','Tolna','HUNGARY','H7100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 22:44:23',0,NULL,3,1,2,1,'\\  ','milanmajkut\r欧标'),(8628,609340377013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','yuriydreamdim','apxitektop@gmail.com','Yuriy Brykaylo','16 Lesi Ukrainki bulv., app. 63','Kiev','','UKRAINE','01133','+380689220000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 22:48:10',0,NULL,3,1,2,1,'\\  ','yuriydreamdim'),(8629,707103898001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','cra5hoverride1','cra5hoverride@hotmail.com','Justin Boldthen','110536 Windmill Ct','Chaska','MN','UNITED STATES','55318-1347','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 23:03:58',0,NULL,3,1,1,1,'\\  ','cra5hoverride1'),(8630,828027917012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','maniast123','staniewscy@onet.eu','Magdalena Staniewska','19 Riveroaks<br>Riverstown','Birr','Offaly','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 23:19:55',0,NULL,3,1,3,1,'RA183624137CN\r ','maniast123\rSHLO005'),(8631,707107548001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','caligulateratoma','willowbayorelse@gmail.com','Laura Robertson','3251 W Covenant Ln','Benson','AZ','UNITED STATES','85602-7777','(520) 221-0774','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 23:20:53',0,NULL,3,1,1,1,'\\  ','caligulateratoma'),(8632,746024207011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','killyang','killyang@gmail.com','ilkyung karam','2452 S Centinela Ave<br>Apt 6','Los Angeles','CA','UNITED STATES','90064-2700','(818) 640-8811','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 23:56:02',0,NULL,5,0,18,0,NULL,'killyang\r客户要撤单\r已退款'),(8633,746024480011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','galazkaw','wgalazka@bellsouth.net','Waldemar Galazka','11956 Elizabeth Ann Ct','Jacksonville','FL','UNITED STATES','32223-0763','(904) 262-2107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-05 23:58:04',0,NULL,3,1,1,1,'\\  ','galazkaw'),(8634,746024255011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',33.99,'eastar4uk','omsoares','ophelia@thames-gateway.org.uk','Ophelia Soares','98<br>Norfolk Road','Seven Kings, Ilford','Essex','UNITED KINGDOM','IG3 8LJ','02085902198','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 00:06:02',0,NULL,3,1,3,1,'RA183624066CN\r ','omsoares\rGLOT001\r兼容型3D眼镜 通用型'),(8635,606862026013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','makariossss91','hliasmak91@hotmail.com','ilias','manoliasis 30','ioannina','','GREECE','45221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 00:16:05',0,NULL,3,1,2,1,'\\  ','makariossss91'),(8636,828071536012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','maxx5224','maxx_909@live.ca','maxime murray','50 rue Saint-Joseph','La Malbaie','QC','CANADA','g5a 1g7','(418) 665-5224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 02:26:58',0,NULL,3,1,2,1,'\\  ','maxx5224'),(8637,609382303013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','nvstg8u','edbrooks62@gmail.com','Edward Brooks','3721 Shimmering Creek Ave','North Las Vegas','NV','UNITED STATES','89031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 02:52:13',0,NULL,3,1,1,1,'\\  ','nvstg8u'),(8638,745719344011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','micheleshelleyshortcake','michele.mulholl@optusnet.com','Michele Mulholland','597 Princes Highway<br>Russell Vale','Wollongong','New South Wales','AUSTRALIA','2517','0242855081','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 03:59:49',0,NULL,3,0,2,1,'\\','micheleshelleyshortcake\r粉红色的\r已入库'),(8639,746083783011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',19.5,'eastar4','wilgand10','wilsongandolfo@bol.com.br','Wilson Gandolfo','R Caraibas,544 apto 142 b','São Paulo','Perdizes/ São Paulo','BRAZIL','05020000','011-36755105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 04:58:59',0,NULL,3,1,2,1,'\\  ','wilgand10'),(8640,554878870003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','614aaron1234','aaronsunderland@phs-kids.com','aaron sunderland','1233 w oakbrook dr','reynoldsburg','OH','UNITED STATES','43068-7238','(614) 743-7801','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-06 04:42:29',0,NULL,3,1,1,1,'\\  ','614aaron1234'),(8641,746032181011,320721819844,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','mitzy5','mitzi5@bigpond.com','catherine franks','16 wattle road','mccrae','Victoria','AUSTRALIA','3938','0359821713','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 04:42:33',0,NULL,3,1,2,1,'\\','mitzy5\r草莓伞 '),(8642,828113130012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','msw1478','msw1478@gmail.com','Mattias  Greenbaum','Seedri 43<br>Karla kula','Harjumaa,','Rae vald,','ESTONIA','75326','5182061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 06:02:57',0,NULL,3,1,3,1,'RA183623715CN\r ','msw1478\rWWOT002\rIBM版 二手'),(8643,746095552011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','rhyskoedijk','rhys@koedijk.co.nz','Rhys Koedijk','247a Jackson Street<br>Petone','Lower Hutt','Wellington','NEW ZEALAND','5012','+64223227497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 06:12:00',0,NULL,3,1,2,1,'\\  ','rhyskoedijk\r 二代卡 旧'),(8644,746102801011,320441575818,'2.1 Acer Travelmate 5520 5530 Bluetooth Module+cable',1,'BTAC2109',12.4,'eastar4','lessanvaezi','lessan@gmail.com','Lessan Vaezi','PO Box 155','Haifa','--','ISRAEL','31001','972542414302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 06:55:34',0,NULL,3,1,2,1,'\\  ','lessanvaezi\racer 4pin1.25 20cm'),(8645,609414147013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','bumerm6','yamahamt-01@mail.ru','Roman Kolodyazhnyy','Stavropolskaya str. 169/74','Krasnodar','','RUSSIAN FEDERATION','350058','(918)135-5663','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-08-06 07:01:57',0,NULL,3,1,3,1,'RA183624021CN\r ','bumerm6\rHSNO019\r欧标'),(8646,746125829011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','k0ji471i','epquimbo@aol.com','Edwin Quimbo','2305 Pecan Grove Way','Rancho Cordova','CA','UNITED STATES','95670-2341','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 08:40:27',0,NULL,3,1,1,1,'\\  ','k0ji471i'),(8647,746130238011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','acrnrsk','slavakharin@gmail.com','Viatcheslav Kharine','21-1742 Newton Street','Victoria','BC','CANADA','V8R 2R2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 08:58:20',0,NULL,3,1,3,1,'RA183623689CN\r ','acrnrsk\rHBPH002'),(8648,746133391011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','psaltevogt','s.altevogt@gmx.de','Sebastian Altevogt','Breitenweg 1a','Bremen','','GERMANY','28195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 09:11:30',0,NULL,3,1,2,1,'\\  ','psaltevogt'),(8649,560432031004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','liormaron2010','liormaron@hotmail.com','Lior Maron','11/3 Haimahot st','Ness Tsiyunna','','ISRAEL','74025','972-52-2341686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 09:17:27',0,NULL,3,1,3,1,'RA183623746CN\r ','liormaron2010\rOTHP004'),(8650,746137490011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','quintinmiddle','anthonyfirst@verizon.net','Anthony Kennedy','5772 Garden Grove Blvd<br>Spc 444','Westminster','CA','UNITED STATES','92683-1855','(562) 572-3769','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 09:29:08',0,NULL,3,1,1,1,'\\  ','quintinmiddle'),(8651,744984322011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',4,'CASS003',34.8,'eastar4','lodrick2010','lodrickn@gmail.com','Lodrick Ndhlovu','PO Box 9287<br>No 70,Tonga Block A5, Kazibokwana','KwaLugedlane','Mpumalanga','SOUTH AFRICA','1341','+27722283222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 09:47:37',0,NULL,3,1,3,1,'RA183624052CN\r ','lodrick2010\rCASS003\r'),(8652,828168249012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',2,'HSMO014',31.9,'eastar4uk','bob6104red','varaltd@aol.com','Robert Collins','58 Pheasant Way<br>Beeches Park','Cirencester','Glos','UNITED KINGDOM','GL7 1BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 09:55:40',0,NULL,3,1,3,1,'RA183623692CN\r ','bob6104red\rHSMO014\r英标'),(8653,554934684003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','manuelxnuno310','manuelxnuno@gmail.com','Manuel Nuno da Silva Almeida','Rua Manuel Arriaga 310 4.2<br>Campo Valongo','Porto','Porto','PORTUGAL','4440-004','+351965414156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 11:02:30',0,NULL,3,1,3,1,'RA183624004CN\r ','manuelxnuno310\rWLIN016'),(8654,828197936012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','s1a2n3t4u5h6a7r','santuhar@gmail.com','Valentina Romancevich','Aizputes 21','Daugavpils','','LATVIA','LV-5417','26898039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 11:37:29',0,NULL,3,1,2,1,'\\','s1a2n3t4u5h6a7r\r24K 多色伞 '),(8655,746181608011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jameslove','chinacat@snet.net','Jim Scheffler','66 Echo Dr','Vernon','CT','UNITED STATES','06066-5907','(860) 875-6625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 12:06:42',0,NULL,3,1,1,1,'\\  ','jameslove'),(8656,828211553012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',7,'CASS002',60.9,'eastar4','blue_sky_2009','arifhb_2000@yahoo.com','Arif Bhuiyan','84,Windsor Avenue','sutton','London','UNITED KINGDOM','sm39ry','07814636135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 12:17:38',0,NULL,3,1,3,1,'RA183623613CN\r ','blue_sky_2009\rCAB-SS-2660\rCASS002'),(8657,746198386011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',119.99,'eastar4uk','golfdejavi','golfdejavi@hotmail.com','Javier Ordiales','21A Wharton Road','Headington Oxford','Oxfordshire','UNITED KINGDOM','ox3 8al','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 12:58:21',0,NULL,3,1,3,1,'RA183624018CN\r ','golfdejavi\rMOLO010'),(8658,828226066012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',85.98,'eastar4uk','willy33600p','morel33@hotmail.fr','ADJANOHOUN Wilfrid','27 rue de savoie','Pessac','Aquitaine','FRANCE','33600','06.69.00.80.77.','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 13:02:01',0,NULL,3,1,3,1,'RA183624154CN\r ','willy33600p\rGLOT005\r投影仪兼容眼镜'),(8659,554967517003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','sammyc6488','sammyc64@gmail.com','Sam Clarvit','505 W 37th St<br>Apt 3102','New York','NY','UNITED STATES','10018-1160','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-06 13:39:33',0,NULL,3,1,1,1,'\\  ','sammyc6488'),(8660,828245567012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','augustin3322','augustin@inbox.lv','Aleksandrs Vitanis','Hulda garborgs gate 17','Bergen','','NORWAY','5052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 13:58:02',0,NULL,3,1,3,1,'RA183623794CN\r ','augustin3322\rOTRA001'),(8661,609501553013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','allemos','almiro.lemos@gmail.com','Almiro Lemos','Av. Alexandrino de Alencar, 1362, Ap. 1202<br>Tirol','Natal','Rio Grande do Norte','BRAZIL','59015-350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 14:26:24',0,NULL,3,1,2,1,'\\  ','allemos'),(8662,746257607011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',17.98,'eastar4','marioko77','443512@gmail.com','Валерий Огарок','улица Октябрьская 29 кв 77','Железнодорожный','Московская область','RUSSIAN FEDERATION','143980','(916)5284967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 15:50:55',0,NULL,3,1,2,1,'\\  ','marioko77'),(8663,609524920013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','rolmast','rolf.mastebroek@hetnet.nl','fam. Mastebroek','Leeuwerik 2','Bunschoten','','NETHERLANDS','3752 NG','033-2987063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 15:52:22',0,NULL,3,1,2,1,'\\  ','rolmast'),(8664,609526789013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','doughyjoey5','josephmc5@gmail.com','Joseph McWilliams','801 Meadow Park Dr','Allen','TX','UNITED STATES','75002-4530','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 16:02:58',0,NULL,3,1,1,1,'\\  ','doughyjoey5'),(8665,609548819013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','california.red','pepermin1965@yahoo.com','Patty Heinemann','4531 Borgia Ct','Stockton','CA','UNITED STATES','95207-6540','(209) 271-1791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 17:12:34',0,NULL,3,1,1,1,'\\  ','california.red'),(8666,827987620012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','marshallsangster','marshallsangster@hotmail.com','Marshall Sangster','4 Oakland Road<br>Garden Flat','Bristol','Avon','UNITED KINGDOM','BS6 6ND','07971018362','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 17:14:33',0,NULL,3,1,3,1,'RA183623701CN\r ','marshallsangster\rOTGR001'),(8667,746302862011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','airkadan','info@airkadan.de','Karin Danowski','Biersdorfer Strasse 11','Herdorf','','GERMANY','57562','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 17:31:46',0,NULL,3,1,3,1,'RA183623967CN\r ','airkadan\rWWSI002+ANCN001'),(8668,746308224011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56.49,'eastar4','seicheles','marcio@sabara.org','Márcio André Pereira','Rua Vinte e Quatro de Agosto, 20 apto 402<br>Bairro Jardim Itú Sabará','Porto Alegre','Rio Grande do Sul','BRAZIL','91215280','555199666611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 17:43:46',0,NULL,3,1,3,1,'RA183623975CN\r ','seicheles\rWWSI006'),(8669,828337448012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','sabachmetallica','america2@gmx.de','christian  mack','am anger 7','ehingen','','GERMANY','91725','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 17:45:38',0,NULL,3,0,2,1,'\\  ','sabachmetallica\r已入库'),(8670,609565310013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',31.99,'eastar4','hampaed','maik@lillebodskov.de','Maik  Borkenhagen','Fischbeker Heuweg 7','Hamburg','','GERMANY','21149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 18:01:20',0,NULL,3,1,3,1,'RA183623803CN\r ','hampaed\rWWSI005'),(8671,707384475001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','sgtbundesen','bundesen@sbcglobal.net','michael bundesen','17740 Woods Way','jamestown','CA','UNITED STATES','95327-9595','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 18:08:14',0,NULL,3,1,1,1,'\\  ','sgtbundesen'),(8672,609572089013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','nenifd','ffdadalto@gmail.com','Franchescolle Dadalto','Av Cel Manoel Nunes 55<br>Jardim Tropical','Serra','Espirito Santo','BRAZIL','29162-010','(321) 831-11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 18:20:41',0,NULL,3,1,2,1,'\\  ','nenifd'),(8673,609572832013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.97,'eastar4','youofelfan','hudson_m@bellsouth.net','Wayne Hudson','3606 Windjammer Ln<br># 6','Saint Augustine','FL','UNITED STATES','32084','(904) 829-6067','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 18:25:52',0,NULL,3,1,1,1,'\\  ','youofelfan'),(8674,555048852003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',29.8,'cnfaner','choosian','choosian@yahoo.com','Choo Ong','2130 Fair Park Ave<br>Apt 212','Los Angeles','CA','UNITED STATES','90041','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-06 18:41:15',0,NULL,3,1,1,1,'\\  ','choosian'),(8675,746333218011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','kill3rchef','ahad522@hotmail.com','Adam Holm','331 Ives Dairy Rd<br>Apt 4','Miami','FL','UNITED STATES','33179-3363','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 18:47:59',0,NULL,3,1,1,1,'\\  ','kill3rchef\r兼容型3D眼镜  samsung 专用'),(8676,828381908012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',15.5,'eastar4','gercheg050525','gercheg@live.ru','Anton Palchikov','Bogatirskaya dom 34a kvartira 137','Voronezh','Voronezhskaya oblast','RUSSIAN FEDERATION','394044','89525410261','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 19:04:07',0,NULL,3,1,2,1,'\\  ','gercheg050525'),(8677,555072109003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','robthain','rob@thainboats.com','Robert Smith','1232 Rucker Ave','Everett','WA','UNITED STATES','98201-1519','(425) 303-8756','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-06 19:53:19',0,NULL,3,1,1,1,'\\  ','robthain'),(8678,828452160012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',9.5,'eastar4uk','pachemanov84','alexce11111@abv.bg','Aleksandar Pachemanov','45  Stockport Road<br>Stretham','london','London','UNITED KINGDOM','SW16 5XE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 21:34:51',0,NULL,3,1,3,1,'RA183623834CN\r ','pachemanov84\rHSPL002'),(8679,746419507011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','misiekiewa','piowarno@poczta.fm','piotr warno','ballintanning<br>waterfall','cork','cork','IRELAND','021','0876818769','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 22:05:41',0,NULL,3,1,3,1,'RA183623675CN\r ','misiekiewa\rWLAP002\r 二代卡 旧'),(8680,746434008011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','chupmagic','cathy@cathycarleton.com','Catherine Carleton','134 Shady Ln','Lansdale','PA','UNITED STATES','19446','(215) 997-0261','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 22:54:11',0,NULL,3,1,1,1,'\\  ','chupmagic'),(8681,828489284012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','wbro3614','charlie@brown.org','William Brown','947 Garnet CV','Oak Point','TX','UNITED STATES','75068-2273','(947) 294-2321','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 23:27:56',0,NULL,3,0,1,1,'\\  ','wbro3614\r已入库'),(8682,746443428011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','123oscarmauricio','neofrost37@hotmail.com','oscar mauricio niño millan','urb los lirios 2 bloque 1 bajo c','tias','Canarias','SPAIN','35572','928524655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 23:31:03',0,NULL,3,1,2,1,'\\  ','123oscarmauricio'),(8683,746444282011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','faisal_khorshid','faisalkhorshid@sasktel.net','Faisal  Khorshid','1239 9th Street E','Saskatoon','SK','CANADA','S7H 0N7','(306) 242-4438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 23:35:45',0,NULL,3,1,3,1,'RA183624070CN\r ','faisal_khorshid\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(8684,609656994013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','hollynjo','simplyholly@gmail.com','Holly Kock','32269 US Highway 34','Wray','CO','UNITED STATES','80758-9118','(970) 332-5839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 23:37:41',0,NULL,3,1,1,1,'\\ ','hollynjo'),(8685,828511703012,220594073986,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10e S9 M10',1,'BTLE2101',12.4,'eastar4','buuuy11','finn.isak@gmail.com','Finn Henriksen','Karlebotn','Varangerbotn','','NORWAY','9840','94307982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 01:01:58',0,NULL,3,1,2,1,'\\  ','buuuy11'),(8686,746465915011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','rjsmitty','smitty3.ryan@gmail.com','Ryan J Smith','1850 Bassett St<br>Apt 725','Denver','CO','UNITED STATES','80202-6192','(720) 206-6404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 01:07:41',0,NULL,3,1,1,1,'\\  ','rjsmitty'),(8687,746485371011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','wahab*09','abdul_nurdhani@fmi.com','abdul wahab nurdhani','PO BOX 37','Tembagapura','Papua','INDONESIA','99930','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 02:58:32',0,NULL,3,1,2,1,'\\  ','wahab*09\r'),(8688,738670727011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','preecha7312','preecha_scorpion@yahoo.com','Mr.Preecha Padermsakpittaya','ZTE (Thailand) Co.,Ltd. 20th Floor, Unit 2005-7 Empire Tower ,<br>195 South Sathorn Road, Yannawa, Sathorn,','Bangkok','Thailand','THAILAND','10120','669-119-9126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 03:05:49',0,NULL,3,1,2,1,'\\  ','preecha7312'),(8689,828543804012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','supertoll2009','info@ich-werd-euch-helfen.com','Matthias Reiners','Schulstr. 5','Holzhausen','','GERMANY','56357','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 03:13:20',0,NULL,3,1,3,1,'RA183623984CN\r ','supertoll2009\rWWOT003\r通用'),(8690,746498951011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','dfdcjd1','david@daviddoom.com','David Doom','816 Trees Of Kennesaw Pkwy NW','Kennesaw','GA','UNITED STATES','30152-7649','(678) 548-6700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 03:37:57',0,NULL,3,1,1,1,'\\  ','dfdcjd1\r二代卡 旧'),(8754,609175916013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','frilion','dotq@mail.ru','Artyom Frolov','Pervostroitelei str, 7,16','Kstovo','nizegorodskay obl','RUSSIAN FEDERATION','607650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 09:09:35',0,NULL,3,1,2,1,'\\ ','frilion'),(8691,609706761013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','rsole','mike.falgar@xtra.co.nz','Mike Falgar','28 Cumberland Place','Kaiapoi','','NEW ZEALAND','7630','033272672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 04:36:15',0,NULL,3,1,2,1,'\\  ','rsole\r新的'),(8692,609710624013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','mverio','marcosvalerio@yahoo.com.br','Marcos Antonio Valerio','Emerson Jose Moreira 1130, Chacara Primavera','Campinas','Sao Paulo','BRAZIL','13087-441','55 19 3256 5215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 05:07:00',0,NULL,3,1,2,1,'\\  ','mverio\racer 5pin1.25 6cm '),(8693,560680816004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','shiv_r33','shiv_zila@hotmail.com','Shalvin Chand','20 Bainbridge cr<br>Rooty Hill','Sydney','New South Wales','AUSTRALIA','2766','0296772695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 05:11:02',0,NULL,3,1,3,1,'RA183623732CN\r ','shiv_r33\rBALO007'),(8694,746538362011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','stahlhutken907','stahlhutken@yahoo.com','stahlhut, kenneth','201 Bunnell St','Anchorage','AK','UNITED STATES','99508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 07:18:39',0,NULL,3,1,1,1,'\\  ','stahlhutken907'),(8695,746541821011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','rover330','wynfrrees@aol.com','WYNFORD REES','33 BANC ROAD LLANGENNECH','LLANELLI','Carmarthenshire','UNITED KINGDOM','SA148UB','01554824328','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 07:31:39',0,NULL,3,1,3,1,'RA183623919CN\r ','rover330\rHBPH002'),(8696,746572860011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','victoriaaspen123','victoriaaspen@yahoo.co.uk','victoria lambri','Karstejnska 273','cernosice','czech republic','CZECH REPUBLIC','258 28','00420 607 897 390','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 09:15:33',0,NULL,3,1,3,1,'RA183623644CN\r ','victoriaaspen123\rHSPL015'),(8697,828636781012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','ivanovskip','ivanovskip@optusnet.com.au','Peter Ivanovski','14 Macarthur Street Sylvania','Sydney','New South Wales','AUSTRALIA','2224','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 09:34:13',0,NULL,3,1,2,1,'\\  ','ivanovskip'),(8698,560725803004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','atmega169','embedelektrik@ya.ru','Maxim Yur`evich Rakhmanin','ul. Vokzalnaya<br>d. 5, kv.18','Tver','Tver','RUSSIAN FEDERATION','170100','(904) 002-7336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 09:44:06',0,NULL,3,1,3,1,'RA183623882CN\r ','atmega169\rOTRA001'),(8699,828680642012,220806882622,'New lady Piano Rain Sun Parasol Stick Umbrella purple',1,'UM00010',24.99,'eastar4','kakuhan','eeaelke@hotmail.com','E. Groenendijk','Koningin Julianastraat 23','MOORDRECHT','','NETHERLANDS','2841VM','0653667918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 11:19:11',0,NULL,3,1,2,1,'\\','kakuhan\r钢琴美女伞'),(8700,828733336012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','ariandne.p','ariandnep@gmail.com','Ariandne Penteado','Rua Frei Francisco de Mont Alverne, 93<br>Jd Santa Genebra','Campinas','SP','BRAZIL','13080-060','55-9774-1030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 13:16:35',0,NULL,3,1,2,1,'\\  ','ariandne.p'),(8701,828770578012,220807319942,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4','dengieken','kenwynes@hotmail.co.uk','Ken Wynes','24 Highfield Rise','Althorne','Essex','UNITED KINGDOM','CM3 6DN','01621740013','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-07 14:32:29',0,NULL,3,1,2,1,NULL,'dengieken\r钢琴美女伞 \r绿色的\r由于绿色的也没了 不好再给客户说没这个颜色，所以就标记为已发货其实没发，到时客户问起来在退款'),(8702,746707494011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','indestructible_laur','laursebaying@ymail.com','Laur Davis','8113 Midland Rd','Mentor','OH','UNITED STATES','44060-7527','(440) 487-1032','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 14:34:41',0,NULL,3,1,1,1,'\\  ','indestructible_laur'),(8703,609848676013,230655991728,'New Portable Funny Wine Bottle Folding Sun Umbrella',1,'UM00030',10.99,'eastar4','m_midav','m_midav@hotmail.com','Vadim Mezhibovski','16 Zahavy Dr.','Vaughan','ON','CANADA','L4J 7R6','(905) 761-1357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 14:42:16',0,NULL,3,1,2,1,'、','m_midav\r红酒瓶伞 \r是一把红心里面有骑自行车的伞'),(8704,828784361012,220689000162,'Genuine Logitech Harmony LED 880 Remote Control+battery',1,'RCLO002',73.99,'eastar4','alex_putiatin','aleksey_v@inbox.ru','Aleksey Vdovin','Sumskoy proezd 2-3-64','Moscow','','RUSSIAN FEDERATION','117208','+79091665577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 14:54:32',0,NULL,3,1,3,1,'RA183624208CN\r ','alex_putiatin\rRCLO002\r旧的'),(8705,746727330011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',27.99,'eastar4uk','wavimages','jkeggie@yahoo.co.uk','John D Keggie','18 Waverley Park','Bonnyrigg','Lothian','UNITED KINGDOM','EH19 3BU','01316631779','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 15:14:14',0,NULL,3,1,3,1,'RA183624106CN\r ','wavimages\rOTPL001'),(8706,828813389012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',124.99,'eastar4uk','traceyread','traceyread@hotmail.co.uk','Tracey Read','8 College Glebe','Killylea','Armagh','UNITED KINGDOM','BT60 4GL','02837569565','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 15:42:33',0,NULL,3,1,3,1,'RA183624097CN\r ','traceyread\rOTSO004*3\r盒装的'),(8707,746743502011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','orange100_1','rosebutler5@googlemail.com','Rose Butler','6 The Windsors','Buckhurst Hill','Essex','UNITED KINGDOM','IG9 6DJ','07956973584','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 15:43:08',0,NULL,3,1,3,1,'RA183623848CN\r ','orange100_1\rWLAP002\r二代卡 旧'),(8708,609875775013,230641231655,'New lady lotus leaves  sun/rain stick Umbrella blue',1,'UM00002',24.99,'eastar4','dc-tech88','case55@hotmail.com','david casella','49 lake crescent','barrie','ON','CANADA','l4n6a7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 15:48:56',0,NULL,5,1,18,1,NULL,'dc-tech88\r荷叶边伞 \r客户要蓝色的  已退款'),(8709,828835450012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',6,'CASS002',52.2,'eastar4','voxstar222','twan.verschure@tjix.com','Shapeshifter / Twan Verschure','Brigittenstraat 2','Utrecht','','NETHERLANDS','3512KK','+31(0)652327752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 16:16:40',0,NULL,3,1,3,1,'RA183623865CN\r ','voxstar222\rCASS002\rCAB-SS-2660'),(8710,707805855001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','ak2000a','ak2000a@aol.com','Arthur S. Kurtz','3 Kenwood St','East Setauket','NY','UNITED STATES','11733-2049','(631) 334-8800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 16:37:03',0,NULL,3,1,1,1,'\\  ','ak2000a'),(8711,555348704003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.8,'cnfaner','phutchilo','hutchilo@att.net','Phyllis Hutchison','7327 S Ireland Cir','Centennial','CO','UNITED STATES','80016-1738','(303) 690-3082','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 16:41:26',0,NULL,3,1,1,1,'\\  ','phutchilo'),(8712,555363092003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.9,'cnfaner','murcelano','rakuns@gmail.com','Sergey Golosov','Zimnyaya 44-2','Syktyvkar','Komi Republic','RUSSIAN FEDERATION','167005','78212312647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 17:23:42',0,NULL,3,1,3,1,'RA183623879CN\r ','murcelano\rHSJA004'),(8713,555372493003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','adamcouey','acouey123@gmail.com','adam  couey','2283 pachuta trl','clarksville','TN','UNITED STATES','37040-7743','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 17:28:15',0,NULL,3,1,1,1,'\\  ','adamcouey'),(8714,746838344011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','applemancintosh','manager@gibspeed.com','Steven Bennett','3 Ashtree Lodge<br>Montagu gardens','Gibraltar','Gibraltar','GIBRALTAR','GX111AA','00350 5413 2000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 17:53:58',0,NULL,3,1,3,1,'RA183623922CN\r ','applemancintosh\rUDAP001'),(8715,746855359011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',17.4,'eastar4','daniyaru22','halzeenan@gmail.com','Liew Kwoa Hui','No.4, Spg 342-70, Perumahan STKRJ,<br>Kg. Tungku, Gadong','Bandar Seri Begawan','','BRUNEI DARUSSALAM','BE 2519','006738627795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 18:12:09',0,NULL,3,1,2,1,'\\  ','daniyaru22'),(8716,746854991011,320679575398,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',65,'WLAP002',643.5,'eastar4uk','riversidecomputers','ebay@riversidecomputers.co.uk','Riverside Computers (MR)','Unit 1 The Old Boatyard<br>Cullingham Rd','IPSWICH','Suffolk','UNITED KINGDOM','IP1 2EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 18:14:01',0,NULL,3,1,4,1,'YW866127636CN','riversidecomputers\rWLAP001+WLAP004+WLAP002\r再发10个\rApple Airport Wireless WiFi Card iMac iBook eMac+adapte'),(8717,828946025012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',10,'WLAP001+WLAP004',109.8,'eastar4uk','riversidecomputers','ebay@riversidecomputers.co.uk','Riverside Computers (MR)','Unit 1 The Old Boatyard<br>Cullingham Rd','IPSWICH','Suffolk','UNITED KINGDOM','IP1 2EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 18:25:36',0,NULL,3,1,17,0,NULL,'riversidecomputers'),(8718,828943683012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','tempt_c','greatsk1985@hotmail.com','Sukhun Wongpraretsri','858 sukumvit rd.38-40 prakanong kongtai','bangkok','bangkok','THAILAND','10110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 18:47:31',0,NULL,3,1,2,1,'\\  ','tempt_c'),(8719,829005378012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','steve80800','stephen.rhodes2@btinternet.com','Stephen Rhodes','2 Hillcroft Road','Kingswinford','West Midlands','UNITED KINGDOM','DY67EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 19:32:39',0,NULL,3,1,3,1,'RA183623661CN\r ','steve80800\rWLIN013\r通用版'),(8720,829017658012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','ducati916biposto1997','djones916@hotmail.com','Dennis Jones','1140 Mortola Dr NE','Saint Petersburg','FL','UNITED STATES','33702-1434','(727) 563-9007','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 19:48:43',0,NULL,3,1,1,1,'\\  ','ducati916biposto1997'),(8721,827463834012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.9,'eastar4uk','vaio_eby','correo.carloscabeza@yahoo.es','Carlos Cabeza Núñez-Milara','Av. Derechos Humanos, 9 4ºA','Arganda del Rey','Madrid','SPAIN','28500','609114770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 19:54:03',0,NULL,3,1,2,1,'\\  ','vaio_eby\r'),(8722,746944277011,320730088975,'NIB Visenta I4/Ifour wireless mouse w/ nano USB receive',1,'MOVI002',11.99,'eastar4uk','p.espinha','pespinha@gmail.com','Paulo Espinha','78 SHIELDS TOWER','MOTHERWELL','North Lanarkshire','UNITED KINGDOM','ML1 2HD','07883261828','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 19:57:29',0,NULL,3,1,3,1,'RA183624083CN\r ','p.espinha\rMOVI002\r黑色的'),(8723,560971284004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','bledger1','bledgerwd@gmail.com','Robert Ledgerwood','15 Oxford PL. W.','Lethbridge','AB','CANADA','T1K4V3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 20:08:19',0,NULL,3,1,3,1,'RA183623825CN\r ','bledger1\rOTRA001'),(8724,555466627003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','kenasha','johnson97362@aol.com','GEORGE JOHNSON','7336 Cayman Dr','FAYETTEVILLE','NC','UNITED STATES','28306-5612','(910) 426-1593','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 20:26:08',0,NULL,3,1,1,1,'\\  ','kenasha\r发OEM的'),(8725,746962875011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','krazywind','mbk35051@yahoo.com','Michael  B Kicker','2389 hwy 28','Columbiana','AL','UNITED STATES','35051','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 20:27:42',0,NULL,3,1,1,1,'\\  ','krazywind'),(8726,746990026011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','redstaralex','lauriewood@btinternet.com','Laurie Wood','39 Springmeadow Lane','Oldham','Greater Manchester','UNITED KINGDOM','OL36HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 21:14:28',0,NULL,3,1,3,1,'RA183624035CN\r ','redstaralex\rHBPH002'),(8727,610045530013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',17.57,'eastar4','almighty57','almighty57@wanadoo.fr','André MARTINEL','9 rue du Chemin De Fer','L\'HOPITAL','Lorraine','FRANCE','57490','0685565367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 21:23:17',0,NULL,3,1,2,1,'\\  ','almighty57\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r'),(8728,746998913011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','fazsage','fasiegh@mcs.co.za','Fasiegh Abader','MCS COMPUTER SERVICES, 5th Floor, 29 Martin Hammerschlag Way<br>Foreshore','Cape Town','WESTERN CAPE','SOUTH AFRICA','8001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 21:33:47',0,NULL,3,1,2,1,'\\  ','fazsage'),(8729,690304919008,180699061296,'New geuine Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',32.99,'au-buy','lokeloge','klakat@hotmail.com','Louis Lakat','9 Honeyeater crescent','Taylors Lakes','Victoria','AUSTRALIA','3038','0433143081','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 21:48:48',0,NULL,3,1,3,1,'RA183623905CN\r ','lokeloge\rHSJA011\r澳标'),(8730,708016959001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','harrypotterwj','wjoreilly22@gmail.com','wj o reilly','9 corry park newtown forbes','longford','Longford','IRELAND','043','0433338043','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 22:06:41',0,NULL,3,1,3,1,'RA183623953CN\r ','harrypotterwj\rBR3D004'),(8731,708020862001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','picolith','glouisr@hotmail.com','Gary Rashman','2321 Carlmont Dr<br>Apt 301','Belmont','CA','UNITED STATES','94002-3303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 22:18:13',0,NULL,3,1,1,1,'\\  ','picolith'),(8732,610066504013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',3,'WWSI005',95.97,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 22:18:28',0,NULL,3,1,3,1,'RA183624565CN\r ','update_marcelo\rWWSI005'),(8733,747046469011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','kar1os','karl@thedid.com','Karl Dyson','57 Charlock Drive','Stamford','Lincs','UNITED KINGDOM','PE9 2WP','07841686666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 23:44:11',0,NULL,3,1,3,1,'RA183623817CN\r ','kar1os\rOTHP006\r微软的'),(8734,829159433012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',104.95,'eastar4','b_lex0713','r.t.and.a.service.station@hotmail.com','ALEKSANDAR BLAGOJEVIC','526B N Gay St','KNOXVILLE','TN','UNITED STATES','37917-7422','(865) 680-8973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 00:49:32',0,NULL,3,1,1,1,'\\  ','b_lex0713\r兼容型3D眼镜 通用型'),(8735,609569089013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','zauib8','dzativ@yahoo.com','Daniel Natividad','5747 Chandler Ct','Rancho Cucamonga','CA','UNITED STATES','91739-2446','(909) 418-7430','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 00:51:23',0,NULL,3,1,1,1,'\\  ','zauib8'),(8736,829162404012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','rolando69delrio','cromosoma692001@yahoo.com','Rolando Del Rio','HC 2 Box 7403<br>Barrio Quebrada','Camuy','PR','UNITED STATES','00627-9108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 00:58:48',0,NULL,3,1,1,1,'\\  ','rolando69delrio'),(8737,747073598011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','sumatamo','manny4@internode.on.net','manny archibald','83 victoria street','east maitland','New South Wales','AUSTRALIA','2323','0249348225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 01:07:55',0,NULL,3,1,2,1,'\\  ','sumatamo'),(8738,747073821011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','secret19870305','timothyleung2016@hotmail.com','Pak Wing LEUNG','Forskarbacken 6-1210','Stockholm','','SWEDEN','114 16','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 01:11:05',0,NULL,3,1,2,1,'\\  ','secret19870305'),(8739,561065974004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','lasouza_ibz','lasouzabr@click21.com.br','Leonardo Silveira','Praca Antonio Callado 53 ,apto 113<br>cond. Cielo Vita Barra da tijuca','Rio de Janeiro','RJ','BRAZIL','22793084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 02:14:28',0,NULL,3,1,3,1,'RA183623998CN\r ','lasouza_ibz\rOTRA001'),(8748,747159094011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',35.99,'eastar4','linakt','alin2@nyc.rr.com','Anthony Lin','20/F, Tower 2, Admiralty Centre<br>18 Harcourt Road, Admiralty','default','','HONG KONG','default','(852) 341-1485 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 07:17:45',0,NULL,3,1,3,1,'RA183624579CN\r','linakt'),(8740,744454925011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.94,'eastar4','southossie','kquinn@adam.com.au','Keith Quinn','4 George St.       Parkside','Adelaide','South Australia','AUSTRALIA','5063','0882999009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 04:31:43',0,NULL,3,1,2,1,'\\ ','southossie'),(8741,829235282012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','afsharfarhad','afsharfarhad@hotmail.com','farhad afshar','714 Woodrow St<br>Apt 3','houston','TX','UNITED STATES','77006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 05:13:54',0,NULL,3,1,1,1,'Tripod  ','afsharfarhad'),(8742,610160195013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','stoober3','stoober@cox.net','Stuart Koszer','9712 Montclair Heights Ct','Las Vegas','NV','UNITED STATES','89178','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 05:27:04',0,NULL,3,1,1,1,'Tripod  ','stoober3'),(8743,747142405011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',104.95,'eastar4','shanenagorski','shane@ecocana.com','Shane Nagorski','16008 100 Ave. NW','Edmonton','AB','CANADA','T5P 0L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 05:49:44',0,NULL,3,1,3,1,'RA183624168CN\r ','shanenagorski\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(8744,747142824011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','ticks2050','damo2050@hotmail.com','Streamline Solutions','Damien Hulme<br>Level 6, 24 Albert Road','South Melbourne','Victoria','AUSTRALIA','3205','0396953800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 05:51:41',0,NULL,3,1,2,1,'\\ ','ticks2050'),(8745,610164136013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','yuexuan183','kathy1288@hotmail.com','Yuexuan Chen','1236 E 20th St','Oakland','CA','UNITED STATES','94606-3171','(510) 928-3003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 06:02:14',0,NULL,3,1,1,1,'\\','yuexuan183\r黑色的'),(8746,746594757011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',4.99,'eastar4uk','laff84','a.laffitte84@free.fr','laffitte alain','539 ch des violettes','violes','Provence-Alpes-Côte d\'Azur','FRANCE','84150','0490709186','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 06:59:49',0,NULL,3,1,2,1,'\\ ','laff84'),(8747,829256771012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','baksat','faik.mamedov@gmail.com','Faig Mammadov','Sarayevo 8<br>apt 35','Baku','','AZERBAIJAN','AZ1149','+994503106662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 07:06:23',0,NULL,3,1,3,1,'RA183624239CN\r ','baksat\r盒装的\rGLSG001*2'),(8749,829257694012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','sergeynebogatkin','snebogatkin@gmail.com','Nebogatkin Sergey','Svobody str., 81-2-95','Moscow','','RUSSIAN FEDERATION','125481','+7-926-5334197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 07:19:45',0,NULL,3,1,3,1,'RA183624185CN\r ','sergeynebogatkin\rWWOT002\rIBM版 二手'),(8750,828855923012,220806848943,'Transparent Dome Rain Sun Umbrella with purple trim',1,'UMTR001',19.99,'eastar4','greenny23','toyyyy@yandex.ru','Vizintseva Elena','st. Slonova 35/45, apt.35','saratov','saratov region','RUSSIAN FEDERATION','410078','+79372678516','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 07:21:49',0,NULL,3,0,2,1,'\\ ','greenny23\r已入库'),(8751,747168207011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','crystal-computing','alan@littlegemranch.net','Alan Donnan','600 VZCR 3435','Wills Point','TX','UNITED STATES','75169','(903) 873-6657','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 08:12:10',0,NULL,3,1,1,1,'\\ ','crystal-computing\r二代卡旧的'),(8752,555609952003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23.26,'cnfaner','shuran6913','shuran6913@gmail.com','林廷軒','新竹市林森路147號11樓之6','default','','TAIWAN','300','0912-764984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 08:23:43',0,NULL,3,1,2,1,'\\ ','shuran6913\rBALO007'),(8753,829274704012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','helga_1986','olya_lya1986@hotmail.com','Olga Zatsepilova','Shumkina St, 15, apt.67','Moscow','Moscow','RUSSIAN FEDERATION','107113','+79652652129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 08:33:24',0,NULL,3,1,3,1,'RA183624300CN\r ','helga_1986\rOTSO002'),(8755,747184445011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRTS001',6.99,'eastar4uk','numptybrown','numptybrown@yahoo.co.uk','David Brown','3 Broad Lane<br>Luddenden Foot','Halifax','West Yorkshire','UNITED KINGDOM','HX2 6JT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 09:13:09',0,NULL,3,1,3,1,'RA183624344CN\r ','numptybrown\rTRTS001'),(8756,828681414012,220748695642,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',5.9,'eastar4uk','solhjorten','hjorten.ebay@gmail.com','Jorgen Hjort','Ryttergaardsvej 28,  - 1.TH.<br>--> 1. Sal til Hoejre','3520 Farum','DK','DENMARK','DK-3520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 09:28:49',0,NULL,3,1,2,1,'\\ ','solhjorten'),(8757,610201214013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','066679671','nova3600@gmail.com','Nadav Zivyon','Yaberboim 10','Rishon Le Zion','','ISRAEL','75235','039501220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:00:21',0,NULL,3,1,2,1,'\\ ','066679671'),(8758,610201684013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',38.99,'eastar4','chaos2k1','raymond.haeb@rwth-aachen.de','Raymond Häb','Hohestr. 4b','Köln','','GERMANY','51149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:03:46',0,NULL,3,1,3,1,'RA183624287CN\r ','chaos2k1\rWLIN002'),(8759,610202706013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.48,'eastar4','viktor299','pakhutko9@sbcglobal.net','viktor pakhutko','590 S Fairfield Ave','lombard','IL','UNITED STATES','60148-2828','(630) 629-9266','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-08 10:09:08',0,NULL,3,1,1,1,'\\ ','viktor299'),(8760,690480130008,180699061927,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','xuc969','cnjbaron@gmail.com','Charles Baron','PO Box 443','Wagga Wagga','New South Wales','AUSTRALIA','2650','0427254445','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 10:11:51',0,NULL,3,1,3,1,'RA183624392CN\r ','xuc969\rOTRA001'),(8761,829304476012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.79,'eastar4uk','mike10690','mikescott1069@hotmail.com','mike scott','22 pitcombe close','bolton','Lancashire','UNITED KINGDOM','BL17PQ','01204304993','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 10:12:48',0,NULL,3,1,3,1,'RA183624295CN\r ','mike10690\rCALO001'),(8762,829306092012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','gojiralp78','gojiralp@yahoo.com','kayhan alparslan demirbag','OZ-AS etiket san.gumussuyu cad. litros yolu<br>2.matbaacilar sitesi 4NC24 6.kat C blok/Topkapi','istanbul','','TURKEY','34010','90 535 258 79 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:19:33',0,NULL,3,1,3,1,'RA183624446CN ','gojiralp78\rGLSG001*2\r盒装的'),(8763,747200529011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','anfernan1','anfernan@netcabo.pt','Antonio Fernandes','Rua Pedro Augusto Franco, Nº 9','1400-272 Lisboa','','PORTUGAL','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:29:55',0,NULL,3,1,3,1,'RA183624485CN\r ','anfernan1\rUDAP001\r客户新地址\rAntónio Fernandes\rRua Fundo do Povo, Nº 31\r5370 - 644 Suçães\rPORTUGAL'),(8764,747209218011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','p.ricardooliveira2009','p.ricardooliveira@bol.com.br','PAULO RICARDO DE OLIVEIRA PINTO','Rua Ilha da Fontoura, 184<br>Bairro Belizário','Santiago','RS','BRAZIL','97700-000','55 3251 7994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:47:36',0,NULL,3,1,2,1,'\\ ','p.ricardooliveira2009'),(8765,827788644012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','filje_vz','ivor.fischer@gmail.com','Damir Janes','Jalkovecka 100 A','VARAZDIN','CROATIA','CROATIA','42000','00385959045595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:51:30',0,NULL,3,1,2,1,'\\ ','filje_vz\r24K 多色伞 '),(8766,829322520012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','tomg5754','bixbox@btinternet.com','Tom Graham','174 Meadowgate Avenue','Sheffield','South Yorkshire','UNITED KINGDOM','s20 2rr','01142513546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 11:13:36',0,NULL,3,1,3,1,'RA183624401CN\r ','tomg5754\rRELO002'),(8767,829336312012,220807272272,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',21.99,'eastar4','sally-e.88','sallye.88@hotmail.com','Sally Easter','12 Fairlie Drive<br>Flagstaff Hill','Adelaide','South Australia','AUSTRALIA','5159','0882708490','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 11:56:39',0,NULL,3,1,2,1,'\\ ','sally-e.88\r地图伞 '),(8768,747232509011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','vwdub51','peterlea96@blueyonder.co.uk','peter letherland','51 fieldway, hedworth est','jarrow','Tyne and Wear','UNITED KINGDOM','NE32 4QQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 12:08:18',0,NULL,3,1,3,1,'RA183624375CN\r ','vwdub51\rHSJA011\r英标'),(8769,609985942013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','sourbox','marcelo.alves@xfer.info','Marcelo Alves','Rua Barao de Mesquita, 950, ap 407','Rio de Janeiro','Rio de Janeiro','BRAZIL','20540-004','(11) 6396-6611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 12:39:26',0,NULL,3,1,2,1,'\\ ','sourbox'),(8770,690532504008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','mrbester09','mr_bester@bigpond.com','Peter Anderson','10 Reginald Crt','Cranbourne West','Victoria','AUSTRALIA','3977','0359967097','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 13:20:32',0,NULL,5,1,3,1,'RA183624358CN\r ','mrbester09\rHSPL011\r澳标\r已经发货，点不了，所以改成取消。'),(8771,706333997001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK001',96,'buysia','brixner65','karlsportbar@yahoo.de','Karl Baumgartner','Pairdorf 79/b<br>Sportbar Pfeffersberg','Brixen-Pairdorf','BZ','ITALY','39042','3284388268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 13:37:21',0,NULL,3,1,3,1,'RA183618834CN\r ','brixner65\rHSAK001'),(8772,829378679012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','off_road05','off.road05@googlemail.com','Lee Ralph','Flat 16 Cuthbert Bell Tower<br>4 Pancras Way','London','London','UNITED KINGDOM','E3 2SL','07551441300','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 13:57:53',0,NULL,3,1,3,1,'RA183624225CN\r ','off_road05\rOTHP004'),(8773,829385128012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',17.5,'eastar4uk','james0407','james@jameswebster.co.uk','James Webster','22 Silverdale<br>Bicton Heath','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 5EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 14:14:44',0,NULL,3,1,3,1,'RA183621440CN\r ','james0407\rWLAP009\r旧的'),(8774,561189286004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','smot8186','motjesebastien@gmail.com','sebastien motje','les closeux','st cyr en val','Centre','FRANCE','45590','06.63.65.85.49','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 14:31:57',0,NULL,3,1,3,1,'RA183624260CN\r ','smot8186\rBALO007'),(8775,610264798013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',155,'eastar4','truck_91','truck_91@yahoo.com','Louis Bumbaco','152 Meadow Park Crescent','Sault Ste. Marie','ON','CANADA','P6A 4H2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 14:48:05',0,NULL,3,1,3,1,'RA183624503CN\r ','truck_91\rGLOT001*3\r兼容型3D眼镜 通用型'),(8776,747286637011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','ljubljana04tadeja','tadeja.04@gmail.com','TADEJA LOVRENČIČ','HERMANA POTOČNIKA 34','LJUBLJANA','','SLOVENIA','1000','00386 41 724 632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 14:54:09',0,NULL,3,1,3,1,'RA183624361CN\r ','ljubljana04tadeja\rHBPH002'),(8777,829411992012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','1087j','mbh41@hotmail.co.uk','Malcolm Guest','44 Woodford','Gateshead','Tyne and Wear','UNITED KINGDOM','NE9 6QG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 15:25:36',0,NULL,3,1,2,1,'\\ ','1087j\r英标'),(8778,747302812011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','yapipo','ebay@steinfam.com','Steve Steiner','1919 N Lynn St<br>Corporate Executive Board','Rosslyn','VA','UNITED STATES','22209-1742','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 15:32:30',0,NULL,3,1,1,1,'\\ ','yapipo'),(8779,829426858012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','ripkid01','kirk.elliott1@btopenworld.com','kirk elliott','Terrys All Locks<br>379 brockley road','brockley','london','UNITED KINGDOM','se4 2ph','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 15:57:05',0,NULL,3,1,3,1,'RA183624273CN\r ','ripkid01\r黑色的\rOTCN004*10'),(8780,829427722012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','furiousbee','furiousb33@gmail.com','Rudy Joubert','41 rue Monseigneur Adam','CAEN','Basse-Normandie','FRANCE','14000','0675409373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 16:01:57',0,NULL,3,0,2,1,'\\ ','furiousbee'),(8781,747316262011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','nailedesign23eq','nailedesign@aol.com','Rick','673 Boar Rd','Mohrsville','Pa','UNITED STATES','19541','(610) 926-0834','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 16:04:41',0,NULL,3,1,1,1,'\\ ','nailedesign23eq\r 二代卡 旧'),(8782,747323490011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','stranger_1973','se86bm@mail.ru','MIKHAIL SHALAMITSKI','ESENINA str. 23/1-203','MINSK','','BELARUS','220025','+375296221079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 16:32:38',0,NULL,3,1,2,1,'\\ ','stranger_1973'),(8783,747331736011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',2.99,'eastar4uk','hi-fey','ulrichfey@gmx.de','Ulrich Fey','Mendelssohnstraße 57','Frankfurt','Hessen','GERMANY','60325','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 16:42:11',0,NULL,3,1,2,1,'\\ ','hi-fey'),(8784,829448767012,220816785876,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',6.9,'eastar4uk','vaany','vaany@hotmail.com','Venetidis Christos','Av des Tarins 1B','Kraainem','','BELGIUM','1950','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 16:45:31',0,NULL,3,1,2,1,'\\ ','vaany'),(8785,747343317011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',118.99,'eastar4','thecoatesagency','chriscoates@thecoatesagency.com','Chris coates','1755 Woodward Drive<br>Suite 333','Ottawa','ON','CANADA','k2c0p9','(613) 225-6603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:07:21',0,NULL,3,1,3,1,'RA183624429CN\r ','thecoatesagency\rGLSG001*2'),(8786,829460127012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',95.99,'eastar4','fargalaxer','far_galaxy@i.ua','Vyacheslav Dudko','5 Gmyri Street, Apartment No.41','Kiev','','UKRAINE','02140','(380)985-351396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:12:23',0,NULL,3,1,3,1,'RA183624450CN\r ','fargalaxer\rOTKE001\r原装肯辛通 Kensington K64325 专家型轨迹球CAD制图专用'),(8787,829462792012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','yuric68','yvatutin@gmail.com','Yury Vatutin','79, Dostoevskogo str.','Krasnodar','Krasnodar','RUSSIAN FEDERATION','350901','+7 (952) 8239902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:14:03',0,NULL,3,1,2,1,'\\ ','yuric68'),(8788,747349412011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','victorfido','urufrio@hotmail.com','victor figueroa','norte nº 58 casa29<br>pedrola','zaragoza','Aragón','SPAIN','50690','651985731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:20:10',0,NULL,3,1,2,1,'\\ ','victorfido 二代卡 旧'),(8789,747359862011,320730085700,'New Atheros AR5B95 AR9285 Half Mini PCI-E+ANTENNA',1,'WLAT009+ANTY001',10.99,'eastar4uk','doiceuk','sales-doice@hotmail.co.uk','Aman Siddiquee','824 Birchwood Boulevard','Warrington','Cheshire','UNITED KINGDOM','WA3 7QZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 17:40:35',0,NULL,3,1,3,1,'RA183624211CN\r ','doiceuk\rWLAT009+ANTY001'),(8790,747367940011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','mistrtwist','mikes.p@post.cz','Miroslav Paril Skanska OISIT','Libalova 1/2348','Prague/Praha','','CZECH REPUBLIC','14900','+420 737 255 056','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 17:57:26',0,NULL,3,1,2,1,'\\ ','mistrtwist'),(8791,829486697012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','jmlesaux','jeanmarc@le-saux.fr','Jean Marc LE SAUX','320 Route de la Montagne','POISY','Rhône-Alpes','FRANCE','74330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:59:21',0,NULL,3,1,3,1,'RA183624415CN ','jmlesaux\rGLSG001*2\r盒装的'),(8792,747376261011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',5,'WLAP002',80,'eastar4','adric22','adric22@yahoo.com','The iBook Guy','405 Kevin Miller rd','Kennedale','TX','UNITED STATES','76060','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 18:12:17',0,NULL,3,1,1,1,'\\ ','adric22\r二代卡 旧'),(8793,610328681013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','blahzinho','b.marro@graphicpole.ch','Blaise Marro','Rue des Pêcheurs 10','Vevey','','SWITZERLAND','1800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 18:14:36',0,NULL,3,1,2,1,'\\ ','blahzinho'),(8794,610336237013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','filbo60','philbeaud@aol.com','Beaudoin Philippe','78 Rue Forget Crauet','Laigneville','Picardie','FRANCE','60290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 18:32:09',0,NULL,3,1,2,1,'\\ ','filbo60\r黑色的\r欧标'),(8795,829532497012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','dazzag12000','dazzag12000@ntlworld.com','Daryl Groves','483 Chorley Old Road','Bolton','Lancashire','UNITED KINGDOM','BL1 6AE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 19:16:55',0,NULL,3,1,3,1,'RA183624389CN\r ','dazzag12000\rHSPL011\r英标'),(8796,747416008011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',129.98,'eastar4','darthjohann','juancontrerasg@gmail.com','Juan Contreras Galleguillos','San Miguel 460<br>Colinas de Agua Santa','Viña del Mar','Valparaiso','CHILE','2581561','(032) 2200820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:26:27',0,NULL,3,1,3,1,'RA183624432CN\r ','darthjohann\rGLSG001'),(8797,747434800011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','igorkrylov','igor_krylov@list.ru','Igor Krylov','Izumrudnaya ul., 13k1-192','Moscow','','RUSSIAN FEDERATION','129281','(926) 316-3046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 20:03:37',0,NULL,3,1,2,1,'\\ ','igorkrylov'),(8798,824432986012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','beertrix13','beertrix13@yahoo.co.uk','Lian Halfyard','1 Boadmeadow View','Teignmouth','Devon','UNITED KINGDOM','TQ14 9BS','01626778151','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-08 20:21:08',0,NULL,3,1,2,1,'\\ ','beertrix13\r24K 多色伞 '),(8799,829566690012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','mikki_helene','nedelina_2001@mail.ru','Nedelina Elena','prospekt Prosvescheniya  99, ap. 825','Saint-Petersburg','Russian Federation','RUSSIAN FEDERATION','195299','+7(911)7464992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 20:23:56',0,NULL,3,1,2,1,'\\ ','mikki_helene\r24K 多色伞 '),(8800,747459317011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tagliat123','tagliat@sunysuffolk.edu','thomas tagliaferro','15 longacre ct','port jefferson','NY','UNITED STATES','11777','(631) 655-7306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 20:53:15',0,NULL,3,1,1,1,'\\ ','tagliat123\r二代卡 旧'),(8801,829585514012,220763389170,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',27.9,'eastar4uk','yulprocomputers','yul@yulpro.ro','Baltateanu Iulian','str Vanatori nr 85','Rasnov','Brasov','ROMANIA','505400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 20:58:22',0,NULL,3,1,3,1,'RA183624327CN\r ','yulprocomputers\rWWSI004+ANCN001'),(8802,610398778013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',4,'CCGR001',27.52,'eastar4','bulgerlock','wfbulger@bulgerlock.com','ben  bulger','11502 Lake City Way NE','seattle','WA','UNITED STATES','98125-5328','(206) 363-8797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 21:30:43',0,NULL,3,1,1,1,'\\ ','bulgerlock'),(8803,829602397012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','sammyjak','sjcolburn1@embarqmail.com','Samuel Colburn','9 Berwick Cir','Shalimar','FL','UNITED STATES','32579-2007','(850) 651-2245','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 21:37:31',0,NULL,3,1,1,1,'\\ ','sammyjak'),(8804,747415657011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','lanfear1033','bluestonebro@gmail.com','Cameron Lanphere','15 Mohegan Avenue<br>Chase Hall Box 8879','New London','CT','UNITED STATES','06320','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 22:21:07',0,NULL,3,1,1,1,'\\ ','lanfear1033'),(8805,829619152012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',19.98,'eastar4uk','pillig1','pillig@arcor.de','Giuseppe Pillitteri','Friedrich-Ebert-Straße 1','Beckingen','','GERMANY','66701','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 22:23:25',0,NULL,3,1,3,1,'RA183624335CN\r ','pillig1\rWLAP008'),(8806,610416740013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','04tiffytaffy20','tiffs20@gmail.com','Tiffany Schenck','13806 Holyoke Path','Apple Valley','MN','UNITED STATES','55124-9409','(952) 564-7616','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 22:42:29',0,NULL,3,1,1,1,'\\ ','04tiffytaffy20'),(8807,829635298012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',43.98,'eastar4','3000year','rapid@cox.net','tae sun Hwang','935 Mooresfield Rd','Wakefield','RI','UNITED STATES','02879','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-08 23:07:39',0,NULL,3,1,1,1,'\\ ','3000year'),(8808,555825449003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','awvis2','scruff1960@msn.com','Martin Repsher','3897 Stony Brook Drive','York','PA','UNITED STATES','17402','(717) 858-4436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-08 23:27:19',0,NULL,3,1,1,1,'\\ ','awvis2'),(8809,747511692011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','seicheles','marcio@sabara.org','Márcio André Pereira','Rua Vinte e Quatro de Agosto, 20 apto 402<br>Bairro Jardim Itú Sabará','Porto Alegre','Rio Grande do Sul','BRAZIL','91215280','555199666611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 23:28:02',0,NULL,3,1,2,1,'\\ ','seicheles\r无线蓝牙二合一'),(8810,829642296012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','neeerg','bal_de_steph2@yahoo.fr','stephane lemonie','108 rue de la chapelle','le puiset','Centre','FRANCE','28310','0237902278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 23:31:04',0,NULL,3,1,2,1,'\\ ','neeerg'),(8811,747514091011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','deanmew','deanmew@rogers.com','Dean Wellon','36 Normandie Avenue','Embrun','ON','CANADA','K0A1W0','(613) 443-0157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 23:37:07',0,NULL,3,1,2,1,'\\ ','deanmew\r新的'),(8812,609393313013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','meetparam','tanmeet86@yahoo.com','tanmeet singh','4110 south redwood rd','taylorsville','UT','UNITED STATES','84123','(801) 859-5185','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 00:03:06',0,NULL,3,1,1,1,'\\ ','meetparam'),(8813,829654591012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','uszajner','mzajner@gmail.com','Michael Zajner','535 Griswold St<br>Suite 111 - 603','Detroit','MI','UNITED STATES','48226-3604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 00:14:25',0,NULL,3,1,1,1,'\\ ','uszajner'),(8814,829660927012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','dressingtable3','canice.o-farrell1@ntlworld.com','Nicky O\'Farrell','19 Brookhill Way<br>Rushmere St Andrew','Ipswich','Suffolk','UNITED KINGDOM','IP4 5UL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:36:27',0,NULL,3,1,2,1,'\\ ','dressingtable3\r24K 多色伞'),(8815,610442255013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','joe_da_pera','talves@eda.pt','Tiago Alves','Estrada 25 Abril, 148','Praia da Vitória','Santa Cruz','PORTUGAL','9760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:45:59',0,NULL,3,1,2,1,'\\ ','joe_da_pera'),(8816,829667867012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','pkstars87','johnnygemme@hotmail.com','johnny gemme','621 rue Coombs','sherbrooke','QC','CANADA','j1n2b1','(819) 791-1209','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'pkstars87'),(8817,747536948011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',8,'UMTR001',135.92,'eastar4','samcraig107','justcuts107@bigpond.com','samantha hill','po box 2290<br>Wandal','ROCKHAMPTON','Queensland','AUSTRALIA','4702','0749333045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 01:03:28',0,NULL,3,0,4,1,'YW866127426CN ','samcraig107\r黄色的\r已入库'),(8818,826838339012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','tobym7629','tobym7629@hotmail.com','Toby Morrison','575 Cedar Wood Cir','Bozeman','MT','UNITED STATES','59718-8213','(406) 599-5988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 01:29:19',0,NULL,3,1,1,1,'\\ ','tobym7629'),(8819,829687000012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',12.99,'eastar4','jejhumne','cparsfield@hotmail.com','Cameron Parsfield','25 Tarcoola Street','Rochedale South / Brisbane','Queensland','AUSTRALIA','4123','61734233781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 02:03:29',0,NULL,3,1,2,1,'\\ ','jejhumne'),(8820,747555430011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','zan2theresq','susannahsnell@hotmail.com','Susannah Snell','30 Eromanga Street','Carindale','Queensland','AUSTRALIA','4152','0738435365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 02:11:08',0,NULL,3,1,2,1,'\\ ','zan2theresq'),(8821,829697403012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','jascam2002','jamiecams@gmail.com','James Cameron','50 The Oaks, Moormede Crescent','Staines','Middlesex','UNITED KINGDOM','TW18 4SG','07973685288','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 02:42:23',0,NULL,3,1,3,1,'RA183624477CN\r ','jascam2002\rHBPH003\r客户要美标\r'),(8822,610470540013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','swwilliams79','swwilliams79@yahoo.com','Scott Williams','12325 Donovan Cir','Austin','TX','UNITED STATES','78753','(512) 373-5762','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 03:03:20',0,NULL,3,1,1,1,'\\ ','swwilliams79\r通用'),(8823,829720177012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','nbook75','alexander.zaytsev.s@gmail.com','Alexander Zaytsev','8/8-10 President ave','KOGARAH','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 04:13:52',0,NULL,3,1,3,1,'RA183624494CN\r ','nbook75\rWWOT001'),(8824,708537838001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',16,'buysia','euminaka','eunaka@uol.com.br','Eurico Nakayama','Rua das Laranjeiras, 55 / 1301<br>bairro: Laranjeiras','Rio de Janeiro','Rio de Janeiro','BRAZIL','22240000','55-21-96076420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 04:15:35',0,NULL,3,1,2,1,'\\ ','euminaka'),(8825,747583595011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','ampon07','ampon7@gmail.com','ampon pintobtang','41/194 Army Training Command Royal Thai Army<br>Terddamri Rd. Samsane','Dusit','Bangkok','THAILAND','10300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 04:17:06',0,NULL,3,1,2,1,'\\ ','ampon07'),(8826,8881312864330992,111,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'',0,'eastar4uk','milliemoomarjorie','marjie.bartlett@hotmail.co.uk','Marjorie','Archibalds Barbers<br>Northfield Road','Ilfracombe','Devon','UNITED KINGDOM','EX348AL','01271865382',NULL,NULL,NULL,'2011-08-09 04:32:10',0,NULL,3,0,3,1,'RA183624463CN\r ','补发的\rGLSG001\r已入库\r提醒我自己当有号时告诉客户 让他关CASE'),(8827,609819080013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','chungkin','limiholding@gmail.com','KIN CHENG CHUNG','Cinemadreef 188','Almere','','NETHERLANDS','1325EP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 05:12:48',0,NULL,3,1,2,1,'\\ ','chungkin'),(8828,561400679004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','thomashl','thomashollier@yahoo.com','Thomas Hollier','1756 Washington Way','Venice','CA','UNITED STATES','90291-4702','(310) 463-1327','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 06:05:23',0,NULL,3,1,1,1,'\\ ','thomashl'),(8829,829753405012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',18,'eastar4','elad_sureswing','techman36@cox.net','Dale Michaud','16753 W Apache St','Goodyear','AZ','UNITED STATES','85338','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 07:04:57',0,NULL,3,1,1,1,'\\ ','elad_sureswing'),(8830,610504612013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','eli.cohen','eli.cohen@gmail.com','Eli Cohen','Anilevitch 35','Bat Yam','','ISRAEL','59428','+972524437761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:07:56',0,NULL,3,1,2,1,'\\ ','eli.cohen'),(8831,747616667011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','quintijnhgb','q.hoogenboom@antenna.nl','Quintijn Hoogenboom','Dennenkampweg','Oosterbeek','','NETHERLANDS','6861GB','0263334372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:26:14',0,NULL,3,1,2,1,'\\ ','quintijnhgb'),(8832,610507238013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','onkelklessing','jorn.leivestad@gmail.com','Jørn Leivestad','Nygardsv. 6','Holmestrand','','NORWAY','3080','+4746402396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:33:07',0,NULL,3,1,2,1,'、 ','onkelklessing'),(8833,747619932011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','uwescheid','mail@uwe-scheid.de','Uwe Scheid','Mühlenblick 16','Wiesbaden-Auringen','','GERMANY','65207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:42:41',0,NULL,3,1,2,1,'、 ','uwescheid'),(8834,690868922008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','gobie_fishie','h.leung@garvan.org.au','Helen Leung','C/O NRUDRH<br>61 Uralba Street','Lismore','New South Wales','AUSTRALIA','2480','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 08:00:51',0,NULL,3,1,3,1,'RA183624962CN ','gobie_fishie\rRELO002'),(8835,829771653012,220816365997,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',51.98,'eastar4','gsmann80','gs.mann80@gmail.com','Gagandeep Mann','5/1-7<br>Belmore Street','North Parramatta','New South Wales','AUSTRALIA','2151','0430654310','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 08:30:17',0,NULL,3,1,3,1,'RA183624976CN ','gsmann80\rUM00020\r银灰色的16骨长柄自动伞 和 一把蓝色的New 24K Ultra light w/Carbon Fiber ribs Sun umbrella\r'),(8836,747629588011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','puki247','turba@puki.sk','Marian Turba','Bodrocka 20','Bratislava','','SLOVAK REPUBLIC','82107','+421(902)980 437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 08:31:35',0,NULL,3,1,2,1,'、 ','puki247\r二代卡 旧'),(8837,829774064012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','ttk_81','tumi81@gmail.com','Tuomo Kivijärvi','Valakkatie 12','Savonlinna','','FINLAND','57600','+358442628117','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 08:36:54',0,NULL,3,1,2,1,'、 ','ttk_81\r通用版'),(8838,747630933011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','razvan87zod','dark_grave2003@yahoo.com','Razvan Andrei Calota','Bvd. Camil Ressu, Nr.57A, Bl.Y2b, Apt.123, Sector 3, Bucuresti','Bucharest','','ROMANIA','031745','+40744666207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 08:37:48',0,NULL,3,1,2,1,'、 ','razvan87zod\r欧标'),(8839,747405081011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','drillerkiller87','c.poole@virgin.net','chris poole','36 little john crescent<br>lupset','wakefield','West Yorkshire','UNITED KINGDOM','wf2 8rz','01924200647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 09:05:39',0,NULL,3,1,2,1,'\\ ','drillerkiller87\rHSJA006'),(8840,610518214013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','snup27','anup27@yahoo.com','Anoop Bhasin','2048 Smith Rd','Charleston','WV','UNITED STATES','25314-2107','(304) 342-2842','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 09:12:57',0,NULL,3,1,1,1,'\\ ','snup27'),(8841,829788448012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',42.99,'eastar4uk','ludi-2010','inter@jawattie.com','ludi haryanto','PT. JA WATTIE, Wisma BSG 8th Floor<br>Jl. Abdul Muis 40','Jakarta Pusat','DKI','INDONESIA','10160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 09:37:26',0,NULL,3,1,3,1,'RA183624830CN\r ','ludi-2010\rGLOT005\r一共买了两副投影仪兼容眼镜'),(8842,829790443012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',42.99,'eastar4uk','ludi-2010','inter@jawattie.com','ludi haryanto','PT. JA WATTIE, Wisma BSG 8th Floor<br>Jl. Abdul Muis 40','Jakarta Pusat','DKI','INDONESIA','10160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 09:45:08',0,NULL,3,1,17,0,NULL,'ludi-2010'),(8843,561436428004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','genoveva37','jerbo42@gmail.com','Mario Martinez Juan','juaquin irles n 19 (barrio de la estacion)','Novelda','Comunidad Valenciana','SPAIN','03660','965604228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 10:29:26',0,NULL,3,1,3,1,'RA183624993CN ','genoveva37\rOTRA001'),(8844,690908743008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','orogner','oystein.rognerud@gmail.com','Øystein Rognerud','Gravbergsveien','default','Braskereidfoss','NORWAY','2435','+4790184403','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 11:02:08',0,NULL,3,1,3,1,'RA183624959CN ','orogner\rHSPL005\r欧标'),(8845,829816619012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','lootlam','lootlam@netzero.net','George M. Cassidy','3289 Standing Peachtree Trl NW','Kennesaw','GA','UNITED STATES','30152','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 11:21:58',0,NULL,3,1,1,1,'\\ ','lootlam'),(8846,747694988011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','jw-shopper','jwoo_2000@hotmail.com','James Woo','2 Mountain Ash','Irvine','CA','UNITED STATES','92604-4612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 12:43:12',0,NULL,3,1,1,1,'\\ ','jw-shopper\r无线蓝牙二合一'),(8847,829857906012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.9,'eastar4','jdkfubat','jdkdomain@yahoo.com','Jeff Kenny','77 Stockton Lake Blvd','Manasquan','NJ','UNITED STATES','08736-3029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 13:28:42',0,NULL,3,1,1,1,'\\ ','jdkfubat\r美标'),(8848,553676913003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','guterierry','javiguterierry@hotmail.com','Guterierry Douglas','Virrey Cevallos<br>1485','Buenos Aires Capital Federal','capital federal','ARGENTINA','1135','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 13:31:35',0,NULL,3,1,3,1,'RA183621643CN ','guterierry\rMOOE002\r发OEM的'),(8849,747718817011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','circeananomaly','tangela.feemster@gmail.com','Tangela S Feemster','595 S River Rd<br>Unit 804','Des Plaines','IL','UNITED STATES','60016-4732','(530) 863-0142','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 14:02:05',0,NULL,3,1,1,1,'\\ ','circeananomaly'),(8850,747732188011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',35.9,'eastar4uk','litos61','karpero2mil@gmail.com','Carlos Peña, Rosal','C/. Doctor Modrego n 28, Piso 3  Puerta 1','Badalona','Cataluña','SPAIN','08918','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 14:43:33',0,NULL,3,1,3,1,'RA183624843CN ','litos61\rMOLO005\r蓝牙版旧的'),(8851,555988029003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','miba2006','miba@telesat.si','Mihael Barbo','Naselje Slavka Cerneta 34','Kranjska Gora','','SLOVENIA','SI-4280','386 41760435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 15:03:12',0,NULL,3,1,3,1,'RA183624874CN\r ','miba2006\rBALO007'),(8852,829899654012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',19.99,'eastar4uk','michaelstaus','michaelstaus@gmail.com','Michael Stausholm','Teglkaasvej 4 ST Th','Kastrup','','DENMARK','2770','234242998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 15:24:14',0,NULL,3,1,3,1,'RA183621630CN\r ','michaelstaus\rWWSI002\rIBM版'),(8853,747747938011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','broomy_j','john.broomfieldmac@me.com','John Broomfield','24 Oswald terrace<br>Grangetown','Sunderland','Tyne and Wear','UNITED KINGDOM','SR2 9RP','07595174009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 15:24:52',0,NULL,3,1,3,1,'RA183624812CN\r ','broomy_j\rUDAP001'),(8854,747762402011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','kgdcc','ken.dong@pigosoft.com','Ken Dong','39 Bowery<br>PMB 916','New York','NY','UNITED STATES','10002-6702','(917) 301-6882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 16:05:33',0,NULL,3,1,1,1,'\\ ','kgdcc'),(8855,829926470012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','woland.grin','vladimir.grin@gmail.com','Vladimir Glushakov','Sõpruse pst 215 - 34','Tallinn','Harju','ESTONIA','13422','003725521879','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 16:31:54',0,NULL,3,1,3,1,'RA183624888CN\r ','woland.grin\rHSSE004\r欧标\r\r'),(8856,829934713012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','lmn0625','lmn0625@yahoo.co.uk','Meina Lu','124 Kensington Drive<br>Great Holm','Milton Keynes','England','UNITED KINGDOM','MK8 9BN','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-09 16:49:53',0,NULL,3,1,2,1,'\\ ','lmn0625\r24K 多色伞'),(8857,829939948012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','sn0tters','william.hadden@spamcop.net','Wil Hadden','58 Farmlodge Park,','Greenisland','Antrim','UNITED KINGDOM','BT38 8YB','02890364752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 17:01:40',0,NULL,3,1,3,1,'RA183625000CN\r ','sn0tters\r英标\rHSPL011'),(8858,829941130012,220820890049,'New Grohe handheld Shower Head big water output+hose',2,'OTGR005+OTGR002',53.98,'eastar4uk','dbh724','dbh724@yahoo.com','Damian Harper','31 Junction Road<br>Edmonton','Enfield','London','UNITED KINGDOM','N9 7JS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 17:03:46',0,NULL,3,1,3,1,'RA183624857CN\r ','dbh724\rOTGR005+OTGR002\r大水量花洒'),(8859,747793783011,320730088816,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'MOLO007',149.99,'eastar4uk','loipenluder','loipenluder@gmx.de','Georg Bauer','CSCP AG<br>Kleine Reichenstr. 1','Hamburg','','GERMANY','20457','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 17:28:34',0,NULL,3,0,3,1,'RA183624790CN ','loipenluder\rHSJA009\r放INVOICE \r申报原值\r'),(8860,829953780012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','mf2011mark','ferberme@mail.ru','Mark Ferber','Orbita1, 13, kv.16','Karagandy','','KAZAKHSTAN','100022','87212773099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 17:34:43',0,NULL,3,1,2,1,'\\ ','mf2011mark'),(8861,747811591011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',6,'CASS001',52.2,'eastar4','scameron1981','cameron187@hotmail.com','Stephen Cameron','14 Ponthead Mews<br>Leadgate','Consett','Co Durham','UNITED KINGDOM','DH8 6TD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 18:02:48',0,NULL,3,1,3,1,'RA183624931CN\r ','scameron1981\rCASS001'),(8862,747818315011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','talalelkhoury','bwidowb@hotmail.com','Talal Elkhoury','825 MARCEL LAURIN','MONTREAL','QC','CANADA','H4M2M8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 18:20:27',0,NULL,3,1,2,1,'\\ ','talalelkhoury'),(8863,747820113011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','rsilverhatband','rstagaban@hotmail.com','Rachelle Silver-Tagaban','PO Box 1214','Tohatchi','NM','UNITED STATES','87325','(505) 409-1764','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 18:20:51',0,NULL,3,1,1,1,'\\ ','rsilverhatband'),(8864,830008382012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','novakandras','novaka@freemail.hu','Andras Novak','Flat 24, Mosswell House<br>Colney Hatch Lane','London','London','UNITED KINGDOM','N10 1BA','07726195709','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 19:13:19',0,NULL,3,1,3,1,'RA183624891CN\r ','novakandras\rRELO002'),(8865,610682309013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','tatan06jania','jania85@hotmail.com','Jania Rodriguez','Hallingsgatan 3E','Malmö','Skåne','SWEDEN','21763','46406931880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 19:51:18',0,NULL,3,1,2,1,'\\ ','tatan06jania\r韩版透明伞 '),(8866,830036770012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','skycrawlersl','skycrawler@mail.ru','Andrew Iliyn','Aptechniy lane, 2-47','Orel','RU','RUSSIAN FEDERATION','302006','79192054006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 20:11:17',0,NULL,3,1,2,1,'\\ ','skycrawlersl\r\r24K 多色伞 '),(8867,556095182003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','omerliv','livneom@walla.co.il','Omer Livne','Intel Israel 74 LTD, P.O.BOX 1659<br>Matam Industrial Park','Haifa','','ISRAEL','31015','972547886219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 21:07:22',0,NULL,3,1,3,1,'RA183624945CN ','omerliv\rHSJA006'),(8868,556097888003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','thundersearch','wbherald@aol.com','Wayne Herald','2992 Beaden Dr','Virginia Beach','VA','UNITED STATES','23456','(757) 430-2078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 21:17:00',0,NULL,3,1,1,1,'\\ ','thundersearch'),(8869,556102017003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','henthorn2006','dmhenthorn1@yahoo.com','david henthorn','103 noth 4th ave','paden city','WV','UNITED STATES','26159','(304) 266-0334','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 21:32:57',0,NULL,3,1,1,1,'\\ ','henthorn2006'),(8870,747923645011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','ewert21','ewert21@yahoo.com','Michael Ewert','3859 S Grant St','Englewood','CO','UNITED STATES','80113-3709','(484) 515-9027','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 22:07:10',0,NULL,3,1,1,1,'\\ ','ewert21'),(8871,708854251001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','logums','bryanlynch7601@yahoo.com','Bryan Lynch','7601 Zane Ave N<br>Apt 319','Brooklyn Park','MN','UNITED STATES','55443-3131','(763) 566-1138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 22:24:31',0,NULL,3,1,1,1,'\\ ','logums'),(8872,830100037012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 22:37:01',0,NULL,3,1,2,1,'\\ ','germanskynet\r再发一个罗技 MX1000 电池'),(8873,556117446003,130521745982,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',53,'cnfaner','ericcivil','ericcivil@gmail.com','Eric Miller','1587 2nd Ave<br>Apt 1','Walnut Creek','CA','UNITED STATES','94597','(925) 212-8142','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 22:43:41',0,NULL,3,1,1,1,'\\ ','ericcivil\r'),(8874,610732585013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','lhplessa','sockbr@gmail.com','Leonardo Haas Pecanha Lessa','rue de la Prulay 39I','Meyrin','','SWITZERLAND','1217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 22:45:05',0,NULL,3,1,2,1,'\\ ','lhplessa'),(8875,747945531011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 23:21:35',0,NULL,3,1,17,0,NULL,'germanskynet'),(8876,561630412004,140583359050,'New in box Jabra BT-2080 Wireless Bluetooth Headset',1,'HSJA005',17.9,'cnfaner','tsr85','evyatar@gmail.com','evyatar shalom','weizmann 50','yehud','Israel','ISRAEL','56240','972524700079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 23:39:43',0,NULL,3,1,3,1,'RA183624914CN\r ','tsr85\rHSJA005\r欧标'),(8877,830116495012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',2,'HSMO018',17.98,'eastar4uk','analaca','laszlo.dobranszki@gmail.com','LASZLO DOBRANSZKI','72 BUSHDROVE ROAD','Dagenham','Essex','UNITED KINGDOM','RM8 3SJ','07500336752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 23:42:00',0,NULL,3,1,3,1,'RA183624928CN\r ','analaca\rHSMO018\r英标'),(8878,830124948012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','amirda','amir2800@gmail.com','amir dayan','lechi 296','ofakim','israel','ISRAEL','87574','0544923803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 00:00:31',0,NULL,3,1,2,1,'\\ ','amirda'),(8879,830125833012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',2,'BTAC2111',24.8,'eastar4','sl2w8','mmalagelada@gmail.com','Marc Malagelada i Duch','Paisos Catalans, 60Bis 1er 2a','SALT','Girona','SPAIN','17190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 00:02:51',0,NULL,3,1,2,1,'\\ ','sl2w8\rAcer 5pin1.25 3cm '),(8880,610748432013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',3,'GLOT005',213,'eastar4','ocomprador2','ebay2@oi.com.br','JOSE ANDRADE COSTA NETO','Rua Pe Henrique, 20 - Lj 3 e 4<br>Centro','Sete Lagoas/MG','MG','BRAZIL','35.700-035','31  87092019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 00:03:40',0,NULL,3,1,3,1,'RA183624826CN\r ','ocomprador2\rGLOT005\r投影仪兼容眼镜'),(8881,747976794011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','larryjanderson','ande9520@bellsouth.net','larry anderson','671 hillpine dr ne','atlanta','GA','UNITED STATES','30306-3222','(404) 873-4724','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 01:43:50',0,NULL,3,1,1,1,'\\ ','larryjanderson\r'),(8882,708907094001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','anywhereusa','bostown544@sbcglobal.net','Joseph P Gabree','1127 Bay Tree Ct','fairfield','CA','UNITED STATES','94533','(707) 429-3833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 02:02:03',0,NULL,3,1,1,1,'\\ ','anywhereusa'),(8883,691209113008,180699060966,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','varadaanilkumar','varadaanil@hotmail.com','varada anil','149-mossfiel drive<br>hoppers crossing','melbourne','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 02:20:36',0,NULL,3,1,3,1,'RA183624980CN\r ','varadaanilkumar\rHSPL002'),(8884,610789835013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',43.9,'eastar4','sdicko84','sdicko83@live.com.au','Simon Dickson','10 McGowan Ave Unley','Adelaide','South Australia','AUSTRALIA','5061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 03:39:41',0,NULL,3,1,3,1,'RA183624619CN ','sdicko84\rMOLO004\rnew 华硕限量版'),(8885,556177727003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','ryotsuka','ryotsuke@gmail.com','Andrei Kirkouski','prospekt gazeti Zvezda d. 56 kv. 305','Minsk','Minsk','BELARUS','220117','+375 29 3421109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 04:59:47',0,NULL,3,1,3,1,'RA183624622CN ','ryotsuka\rBAZA001'),(8886,830205893012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',29,'HSSA002',318.71,'eastar4uk','modubuy82','modubuykr3@gmail.com','ChanJung Yun','#325, NKIC, 48-84, Hongeun1dong, Seodaemungu','Seoul','Seoul','KOREA,REPUBLIC OF','120101','82-7040355380','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 05:27:12',0,NULL,3,1,6,1,'EE495341119CN ','modubuy82\r黑色的'),(8887,830222124012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','831pmoutarlier','pmoutarlier@yahoo.com','philippe moutarlier','433 effey st','santa cruz','CA','UNITED STATES','95062-2632','(831) 471-9640','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 06:59:54',0,NULL,3,1,1,1,'\\ ','831pmoutarlier'),(8888,830224462012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',23.98,'eastar4uk','jessica.curto','desislava.curto@googlemail.com','Angelina Neymeyer','Oxford Street 277','London','London','UNITED KINGDOM','W1C 2DL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 07:03:00',0,NULL,3,1,3,1,'RA183624684CN ','jessica.curto\r一共买了两个\r'),(8889,830229831012,220816365997,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',26.99,'eastar4','danilalesnov10','danilalesnov@rambler.ru','KASYAN ALECIA','st. Prigorodnaia house 34 apartment 77','Brest','','BELARUS','224014','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 07:30:17',0,NULL,3,1,2,1,'、 ','danilalesnov10\r16骨长柄自动伞\r红色的'),(8890,561699511004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.99,'cnfaner','conioannou','conioannou29051995@hotmail.com','Constantinos Ioannou','4A PERSEOS','NICOSIA','AGIOS DOMETIOS','CYPRUS','2364','0035799763723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 07:33:00',0,NULL,3,1,3,1,'RA183624653CN ','conioannou\rHSNO005\r欧标'),(8891,8881312961771532,111,'2.1 Acer Aspire 5235 5335 5535',1,'BTAC2105',0,'eastar4','rob2222_de','rob2222@gmx.net','Robert Mahs','Bernardstrasse 19','Hausen / Obertshausen','','GERMANY','63179','',NULL,NULL,NULL,'2011-08-10 07:36:11',0,NULL,3,1,2,1,'\\ ','补发的 只补发一条线\racer 4pin1.25 8cm'),(8892,8881312961978765,111,' NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152  ',1,'MOAP001',0,'eastar4','izznot','mellotron2@optonline.net','Duane Sherwood','192 E 8th St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11218-3368','',NULL,NULL,NULL,'2011-08-10 07:39:38',0,NULL,3,1,3,1,'RA183624640CN ','补发的 \rMOAP001'),(8893,8881312962153817,111,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',0,'eastar4','jcrhea','john_rhea@cox.net','John C Rhea','1701 W Briddle Dr','Rogers','AR','UNITED STATES','72758-8406','',NULL,NULL,NULL,'2011-08-10 07:42:33',0,NULL,3,1,3,1,'RA183624707CN ','CCGR001 \r补发的'),(8894,830243216012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','dimitrisxeniotis','dimitriosxeniotis@hotmail.co.uk','Δημήτριος Ξενιώτης','Πύργου 12 ','Λαμία','Φθιώτιδα','GREECE','35100','+306973340842','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 08:28:58',0,NULL,3,1,2,1,'\\ ','dimitrisxeniotis\rHSSA002\r黑色的\r欧标'),(8895,830249881012,220782958082,'New Jabra BT135 BT 135 wireless Bluetooth Headset',2,'HSJA007',29.7,'eastar4','evo-offer','christopher.olstorp@hotmail.com','Christopher Olstorp','Engelsbrektsgatan 78','Borås','none','SWEDEN','50637','+46708-130867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 08:55:15',0,NULL,3,1,2,1,'\\ ','evo-offer\r欧标'),(8896,610834094013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.99,'eastar4','adikatalan','ashani@zahav.net.il','Alon Shani','Halilach 36','Beit Dagan','PO Box 2628','ISRAEL','50200','972-3-9603590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 08:57:33',0,NULL,3,1,2,1,'、 ','adikatalan\r大水量花洒'),(8897,556212471003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.9,'cnfaner','joni.sebastian.poysti','sebastian.poysti@gmail.com','joni pöysti','kekkerikuja 9 as2','imatra','','FINLAND','55610','0453213587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 09:23:31',0,NULL,3,1,3,1,'RA183624715CN\r ','joni.sebastian.poysti\rHSNO019+CCNO001'),(8898,830263767012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','yhoch88093038','yhoch3038@gmail.com','Yochonon Hochhauser','72 St. Kildas Road','London','London','UNITED KINGDOM','N16 5BX','02088093038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 09:47:07',0,NULL,3,1,3,1,'RA183618692CN\r ','yhoch88093038\r英标\rHSPL011'),(8899,610842674013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','plkm141','zahidyasin1@yahoo.co.uk','zahid yasin','73 holland road, east ham','london','London','UNITED KINGDOM','E62EP','02085523102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 09:49:33',0,NULL,3,1,2,1,'\\ ','plkm141\rCAB-6060'),(8900,748087103011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',42.9,'eastar4uk','ben_brillante','benbrillante@free.fr','Benjamin Brillante','141 rue de charenton','Paris','Île-de-France','FRANCE','75012','06.65.65.99.52','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 10:09:36',0,NULL,3,1,3,1,'RA183624741CN\r ','ben_brillante\rHDGE001'),(8901,830277728012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',5,'CASS002',52.2,'eastar4','silfides','pablo.romerogiron@hotmail.com','Enrique Romero-Giron Gomez-Pablos','C/ Luis Doreste Silva 52, 3º-1','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','928249978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 10:43:46',0,NULL,3,1,3,1,'RA183618661CN\r ','silfides\rCASS002+CASS001\rCAB-SS-2660\r再发一个CAB-2626'),(8902,747893089011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',32,'eastar4','casting21','spot@wanadoo.fr','Jacques Nicod','43 rue de la prairie','Baume les dames','Franche-Comté','FRANCE','25110','06.86.79.69.62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 10:52:59',0,NULL,3,1,3,1,'RA183624769CN ','casting21\rWLAP002\r二代卡 旧'),(8903,556231893003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','ptite_etoile_11','nana_la_netoile11@hotmail.fr','Argence Fabien','95,rue de la première armée française','cavanac','Languedoc-Roussillon','FRANCE','11570','0468797811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 11:07:36',0,NULL,3,1,3,1,'RA183624772CN\r ','ptite_etoile_11\rUDAP001\r'),(8904,830290373012,220815930167,'New Genuine DENON RC-969 Remote Control RC 969',1,'RCDE001',49.99,'eastar4uk','thegunderlero','bobby100@ntlworld.com','bobby lally','8 STIRLING CLOSE<br>CAVERSHAM PARK VILLAGE','READING','Berkshire','UNITED KINGDOM','RG4 6SH','07866600088','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 11:20:48',0,NULL,3,1,3,1,'RA183624675CN\r ','thegunderlero\rRCDE001'),(8905,748117416011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','leaf-clover','leaf_clovers@hotmail.com','Daniel Eliasson','Gokhemsgatan 5<br>Norrbotten','Pitea','BD','SWEDEN','94139','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 11:59:18',0,NULL,3,1,2,1,'\\ ','leaf-clover'),(8906,748127555011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','indyoutletcenter','indyoutletcenterebay@gmail.com','Indy Outlet Center','5054 E County Road 550 N','Pittsboro','IN','UNITED STATES','46167-9396','(317) 858-3509','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 12:30:55',0,NULL,3,1,1,1,'、 ','indyoutletcenter'),(8907,829347209012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','ailark','kirss.mina@mail.ee','Ailar Kiristaja','Kaunase pst. 19-23','Tartu','Tartumaa','ESTONIA','50704','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 12:36:35',0,NULL,3,1,3,1,'RA183624786CN\r ','ailark\rWWOT003\r通用版'),(8908,748155686011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','ianhoeboy','tubeman62@hotmail.com','ian smith','82 POYNTERS ROAD','LUTON','Bedfordshire','UNITED KINGDOM','LU40LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 13:59:31',0,NULL,3,1,3,1,'RA183624667CN\r ','ianhoeboy\rHSJA011\r英标'),(8909,610897218013,230393147374,'2.1 Acer Travelmate 4720 4320 Bluetooth Module cable',1,'BTAC2104',12.4,'eastar4','rluzell','rluzell@comcast.net','RICK LUZELL','312 WILLOWBROOK DRIVE','INDUSTRY','PA','UNITED STATES','15052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 14:14:55',0,NULL,3,1,1,1,'、 ','rluzell\racer 4pin1.25 6cm'),(8910,748165988011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','dpmdemas1976','demas1976@yahoo.com.br','Demétrius Miranda','Calle cerdeña 385, 6-4','Barcelona','Cataluña','SPAIN','08025','931875562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 14:35:30',0,NULL,3,1,2,1,'\\ ','dpmdemas1976'),(8911,830359939012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.4,'eastar4','xtrimal','xtrimal@gmail.com','Evgeniy Romanov','Griboedova st. 22 - 4','Gremyachinsk','Permskaya oblast','RUSSIAN FEDERATION','618270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 14:53:27',0,NULL,3,1,2,1,'\\ ','xtrimal\racer 8pin1.00 18cm'),(8912,748176903011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tjag1948','thom@sedonaartbydesign.com','Thom Jaggers','243 Chapel Rd','Sedona','AZ','UNITED STATES','86336','(928) 282-1145','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 15:01:12',0,NULL,3,1,1,1,'、 ','tjag1948\r二代卡 旧'),(8913,610909882013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','southernpryd38332','kevin.zuhn@gmail.com','kevin zuhn','6555 roby rd','enville','TN','UNITED STATES','38332-1849','(731) 438-0000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 15:03:18',0,NULL,3,1,1,1,'、 ','southernpryd38332'),(8914,748185275011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','connectivecommunities','bill@connectivecommunities.com','William Hennessy','2825 S Roanoke Ave','Springfield','MO','UNITED STATES','65807-3603','(417) 396-2340','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 15:25:56',0,NULL,3,1,1,1,'、 ','connectivecommunities\r二代卡 旧'),(8915,709096383001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','rhsmcw','rsalek2@verizon.net','Roland H Salek','1707 W Followthru Dr','Tampa','FL','UNITED STATES','33612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 15:46:33',0,NULL,3,1,1,1,'、 ','rhsmcw'),(8916,748195471011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',10.99,'eastar4uk','joes2283','joeshaw77@hotmail.co.uk','joe shaw','40 brook street','Congleton','Cheshire','UNITED KINGDOM','cw12 1rh','01260272304','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:51:44',0,NULL,3,1,3,1,'RA183618613CN\r ','joes2283\rWLDE002'),(8917,829978951012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',2,'HSSE005',27.8,'eastar4uk','mapapinto','mpinto@elpercutor.com','Manuel Pinto','49 calle 25-18 zona 12 Los Cedros I','Guatemala','Guatemala','GUATEMALA','01012','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 16:14:04',0,NULL,3,1,3,1,'RA183624738CN\r ','mapapinto\rHSSE005'),(8918,748204527011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','kdegener','dmdegener@cox.net','Kayleen Degener','15284 Wirt ST','Omaha','NE','UNITED STATES','68116','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 16:16:03',0,NULL,3,1,1,1,'、 ','kdegener\r红边优联'),(8919,830402717012,220825062314,'New 3.0 Bluetooth BCM92070 Module+cable Asus N43 N73',1,'BTAS3001',19.99,'eastar4','maxblc','maxblc@free.fr','Maxime BLANC','1666, ch de la ripelle cd 46','toulon','Provence-Alpes-Côte d\'Azur','FRANCE','83200','0626823247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 16:30:18',0,NULL,3,1,2,1,'\\ ','maxblc\r3.0 ASUS 6pin 6CM  '),(8920,748222388011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','jrebb','jreb@aol.com','Mike McGuire','1213 Huntington Ln','Tuscumbia','AL','UNITED STATES','35674-3302','(256) 389-8085','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 17:15:16',0,NULL,3,1,1,1,'、 ','jrebb\r 二代卡 旧'),(8921,748236210011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','splejk1','splejk@hotmail.com','Else-Marie Gavling','Skillingv. 9','Karlstad','Värmland','SWEDEN','653 46','0703610311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 17:32:50',0,NULL,3,1,2,1,'\\ ','splejk1'),(8922,746354243011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','hugo-brandao','pickmaleao70@hotmail.com','Hugo Brandão','Sítio do Pé Do Cerro.<br>Caixa Postal 55 - z','Sta. Bárbara de Nexe','Faro','PORTUGAL','8005-512','+351 913776241','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 17:45:23',0,NULL,3,1,2,1,'\\ ','hugo-brandao\r红边优联'),(8923,748250243011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRTS001',6.99,'eastar4uk','thank78','thank78@gmail.com','Keng Han Tan','37-55 63rd Street<br>1 FL','Woodside','NY','UNITED STATES','11377','(917) 459-2583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 17:58:32',0,NULL,5,0,18,0,' ','thank78\r客户想撤单'),(8924,561838691004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','chalov10','iolkin@mail.ru','VYACHESLAV CHALOV','OSENNYI BULVAR str. 12-9-960','MOSCOW','','RUSSIAN FEDERATION','121614','+79167056267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 18:23:54',0,NULL,3,1,3,1,'RA183624809CN\r ','chalov10\rOTGR002'),(8925,748266106011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','oriont','orion.gebremedhin@gmail.com','Orion Gebremedhin','4440 E. Badger way','Phoenix','AZ','UNITED STATES','85044','(480) 619-3647','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 18:30:07',0,NULL,3,1,1,1,'、 ','oriont\r新的'),(8926,610982869013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.97,'eastar4','ravibhangu','ravibhangu4u1@yahoo.com','Ravneet Bhangu','8 Dellgrove Cir','Cambridge','ON','CANADA','N1T2J8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 18:54:13',0,NULL,3,1,2,1,'\\ ','ravibhangu'),(8927,830479003012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','sparr0whawk','j@shrago.com','Jonathan Shrago','34 Wetherby Road','Harrogate','North Yorkshire','UNITED KINGDOM','HG2 7SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 19:02:48',0,NULL,3,1,3,1,'RA183618750CN\r ','sparr0whawk\rMOLO009\r旧的'),(8928,830489194012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','runetbj','runetbj@online.no','Rune Bjørge','Strandgaten 41','Svelvik','Svelvik','NORWAY','3060','+4798872439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:20:09',0,NULL,3,1,2,1,'\\ ','runetbj'),(8929,748297465011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','tougherty','tougherty@yahoo.com','Bogdan Tatarchev','j.k. \'Drujba\', bl.65, entr.A, apt.5','Sofia','Sofia','BULGARIA','1592','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:34:33',0,NULL,3,1,2,1,'\\ ','tougherty'),(8930,556366122003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.95,'cnfaner','pc_mac_works','ts@pcamw.com','PC AND MAC WORKS','8916 NE 134th Ct','Vancouver','WA','UNITED STATES','98682-3075','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-10 19:46:23',0,NULL,3,1,1,1,'、 ','pc_mac_works'),(8931,830511361012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','ofa1233','ole.asmundvaag@gmail.com','OLE ASMUNDVAAG','LINDERUDVEIEN 22','OSLO','','NORWAY','0594','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:59:38',0,NULL,3,1,3,1,'RA183624755CN\r ','ofa1233\rOTSO004*2'),(8932,709207125001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','hectoroliva2','hectoroliva2@yahoo.com','Hector Oliva','450 NE 29th Ter<br>Apt 1','Miami','FL','UNITED STATES','33137-4328','(305) 890-3358','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 20:16:39',0,NULL,3,1,1,1,'、 ','hectoroliva2'),(8933,830523376012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','trekker2005','bfulcher@live.com','Bill Fulcher','37 FELICIA WAY','CHADWELL ST MARY','Essex','UNITED KINGDOM','RM16 4JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 20:23:19',0,NULL,3,1,3,1,'RA183618689CN\r ','trekker2005\rHSPL011\r英标'),(8934,610942462013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','firkraag101','alen.friscic@gmail.com','Alen Friščić','Brace Radica 7','Ivanec','Varazdinska zupanija','CROATIA','42240','+385981621470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 21:07:34',0,NULL,3,1,2,1,'\\ ','firkraag101\r新的'),(8935,830542189012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','mopi1402','ebay@moati.fr','Pierre MOATI','99 avenue du General Leclerc','Maisons-Alfort','Île-de-France','FRANCE','94700','0033952428142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 21:16:22',0,NULL,3,1,2,1,'\\ ','mopi1402'),(8936,748361672011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','linerondan','line.rondan@gmail.com','Line Rondan','Bjørnveien 33','Oslo','Oslo','NORWAY','0774','+47 90850492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 22:00:22',0,NULL,3,1,2,1,'\\ ','linerondan\r二代卡 旧'),(8937,748368181011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','thepeddlersdaughter','cdussik@mnrubber.com','Cathy Dussik','2027 Chester St','shakopee','MN','UNITED STATES','55379-4375','(952) 233-1047','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'thepeddlersdaughter'),(8938,830566562012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','spaze1978','spaze@mail.ru','Pavel Karataev','270 Bath Road','SLOUGH','Berkshire','UNITED KINGDOM','SL1 4DX','79852228846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 22:16:48',0,NULL,3,1,2,1,'\\ ','spaze1978'),(8939,611051564013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','kilty_cauld_bum','andy.proudfoot@taskmicro.com','Andrew Proudfoot','16700 TransCanada Hwy','Kirkland','QC','CANADA','H9H 4M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 22:34:17',0,NULL,3,1,2,1,'\\ ','kilty_cauld_bum'),(8940,611065567013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','pak7155','pakjpg@gmail.com','pakorn tuwajit','57/33 serithai road<br>klongkum bungkum','bangkok','bangkok','THAILAND','10240','662 377 2820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 23:45:37',0,NULL,3,1,3,1,'RA183618701CN\r ','pak7155\rWWSI005'),(8941,748401139011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','swtcaro9','carolinehoward2@gmail.com','Caroline Howard','343 Pheasant Chase Dr','Bolingbrook','IL','UNITED STATES','60490-4511','(630) 797-8797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 00:27:22',0,NULL,3,1,1,1,'、 ','swtcaro9'),(8942,748403776011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','yonghwan0930','yonghwan0930@naver.com','Yonghwan Kim','Noblerich officetel B-dong 603-ho, Yatap-dong, Bundang-gu','Seongnam-si','Gyeonggi-do','KOREA,REPUBLIC OF','463-070','821089970900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 00:32:21',0,NULL,3,1,2,1,'\\ ','yonghwan0930\r 二代卡 旧'),(8943,830611313012,220713846354,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET+carcharger',1,'HSNO006+CCNO001',11.49,'eastar4uk','bigbigboy65','jimfagan@live.co.uk','james fagan','25 inverlochy road.','airdrie','North Lanarkshire','UNITED KINGDOM','ml6 9es','01236762216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 00:36:42',0,NULL,3,1,3,1,'RA183618675CN\r ','bigbigboy65\rHSNO006+CCNO001'),(8944,561940990004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','allen4602','allenhu88@gmail.com','Allen Hu','11 Marguerita Place<br>West Harbour','Auckland','Waitakere','NEW ZEALAND','0618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 01:16:23',0,NULL,3,1,3,1,'RA183624724CN\r ','allen4602\rHSPL015'),(8945,610771722013,230649308783,'New Japan Gentleman business Stripe Sun Rain Umbrella',1,'UM00026',25.99,'eastar4','mros5313','mariuszrosiak@yahoo.com','Mariusz Rosiak','9 Highwood Rd','Somerset','NJ','UNITED STATES','08873-1834','(848) 228-9497','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 01:17:59',0,NULL,3,1,1,1,'、 ','mros5313\r日本外贸经典条纹长柄伞 '),(8946,748423073011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','leahwilde','leahwilde@yahoo.com','Leah Wilde','104 Lakeview Estate Townhomes','Morgantown','WV','UNITED STATES','26508','(304) 594-9150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 01:47:35',0,NULL,3,1,1,1,'、 ','leahwilde'),(8947,830639806012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','duncantenero','miller.matthew.john@gmail.com','Matt Miller','7176 E 100 S','Union City','IN','UNITED STATES','47390-8571','(513) 614-7745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 02:12:22',0,NULL,3,1,1,1,'、 ','duncantenero'),(8948,709311967001,110728101635,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','dblplaya643','643dblply@gmail.com','Al Mersman','2 Bridleshire Cir','Newark','DE','UNITED STATES','19711-2484','(302) 547-2303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 02:21:47',0,NULL,3,1,1,1,'、 ','dblplaya643'),(8949,556452997003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jlceman','lilcouscous@gmail.com','Jennifer Moret','1127 Fulton Dr','Streamwood','IL','UNITED STATES','60107-2890','(847) 363-7114','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-11 02:30:18',0,NULL,3,1,1,1,'、 ','jlceman'),(8950,748457509011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','wycliffer','wraduma@gmail.com','Wycliffe Raduma','Puolikkotie 6 D 102','Espoo','Espoo','FINLAND','02230','+358(0)503517554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 04:23:51',0,NULL,3,1,2,1,'、 ','wycliffer'),(8951,748459097011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ytousignant','ytousignant@gmail.com','Yannick Tousignant','4388, rue Saint-Denis<br>Bureau 309','Montreal','QC','CANADA','H2J 2L1','(514) 942-3653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 04:29:55',0,NULL,3,1,2,1,'、 ','ytousignant'),(8952,748463353011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','yukichigai','yuki@775.net','Tim Crowley','PO Box 1089<br>33 River Vista Drive','Dayton','NV','UNITED STATES','89403-1089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 04:54:01',0,NULL,3,1,1,1,'、 ','yukichigai\r无线蓝牙二合一'),(8953,691646750008,180699061836,'New Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',29.99,'au-buy','mehedi8051','malemranh@yahoo.com','Muhammad Hasan','3 / 40 Liddiard st','Hawthorn','Victoria','AUSTRALIA','3122','61425794455','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 05:13:17',0,NULL,3,1,3,1,'RA183618746CN\r ','mehedi8051\r澳标\rHSJA010'),(8954,748468659011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','r.gladshtein','v.gladshtein@gmail.com','Reuven Gladshtein','Motzkin, 17 / 26','Netanya','Israel','ISRAEL','42460','(972) 52-7427132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 05:26:46',0,NULL,3,1,2,1,'、 ','r.gladshtein'),(8955,556477091003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','mhashimoto','mike@mhashimotophoto.com','Mike Hashimoto','1107 Fair Oaks Ave<br># 859','South Pasadena','CA','UNITED STATES','91030','(323) 878-2264','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-11 05:36:21',0,NULL,3,1,1,1,'\\ ','mhashimoto'),(8956,830685065012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','colombodk','larsen@email.dk','Peter Falk Larsen','Matthæusgade 38, 2. th<br>C/O Johannes Lilleøre','København V','-','DENMARK','1666','+45-28783842','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 05:43:02',0,NULL,3,1,2,1,'、 ','colombodk'),(8957,830690698012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',81.99,'eastar4uk','estr3549','ericstriolo@neuf.fr','ERIC STRIOLO','11 rue du Haras Res Le Boqueteau<br>Bat Les Trembles RDC Drte','Saint Michel sur Orge','Île-de-France','FRANCE','91240','0661130554','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 06:17:22',0,NULL,3,1,3,1,'RA183618825CN\r ','estr3549\rGLOT005*2\r投影仪兼容眼镜\r一个蓝色的一个白色的'),(8958,828619879012,220815930889,'New in box GENUINE NOKIA BH-103 BLUETOOTH HEADSET',1,'HSNO029',19.9,'eastar4uk','genich20','genich20@yahoo.com','Kapuza Gennady','Yona 6/7','Sderot','','ISRAEL','87063','0524448241','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 06:34:58',0,NULL,3,1,3,1,'RA183618715CN\r ','genich20\rHSNO029\r盒装的'),(8959,748483735011,320721819789,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','kruzo_rus','zmv.pochta@gmail.com','Maxim Zaborskikh','ul.Kolokolnaya, d.5, kv.24','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','191025','+79213922938','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 06:54:24',0,NULL,3,1,2,1,'\\ ','kruzo_rus\r黑底七色边彩虹伞 '),(8960,748488846011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','wauwwie','marco@wauwwie.nl','M Rijnbeek','Boomgaardweg 63','Almere','','NETHERLANDS','1326 CV','0655760606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 07:20:41',0,NULL,3,1,2,1,'、 ','wauwwie\r新的'),(8961,747519037011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','diman8282','diman82@gmail.com','Dima Medvedev','ha Histadrut 11/6 c','Givataim','','ISRAEL','53584','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 07:52:56',0,NULL,3,1,3,1,'RA183618803CN\r ','diman8282\rHBPH002'),(8962,748493082011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','davidgemma1984','david210984@gmail.com','david murdie','39 tarwick drive<br>st mellons','cardiff','Cardiff','UNITED KINGDOM','cf3 0af','07769695775','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 07:59:08',0,NULL,3,1,3,1,'RA183618729CN ','davidgemma1984\rUDAP001'),(8963,611144903013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','maxim_karban','maxim.karban@gmail.com','Maxim Karban','gen. Belova 29-2-36','Moscow','','RUSSIAN FEDERATION','115563','+79166534126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 08:00:56',0,NULL,3,1,3,1,'RA183618732CN ','maxim_karban\rWLIN014\r通用'),(8964,748498583011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kimjansen1984','kim@isin.nl','Kim Jansen','Deltastraat 12','STELLENDAM','','NETHERLANDS','3251AC','0031622253615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 08:10:21',0,NULL,3,1,2,1,'\\ ','kimjansen1984\r新的'),(8965,830715750012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','mihalyjozsef1963','mihaly1963@gmail.com','Jozsef Mihaly','Vasarhelyi 117','Szentes','Csongrad','HUNGARY','6600','+36209465389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 08:11:44',0,NULL,3,1,3,1,'RA183618817CN\r ','mihalyjozsef1963\r欧标\rOTPL001'),(8966,747268397011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',16.99,'eastar4','joslyen2007','josobyrne07@hotmail.com','Joslyen Byrne','PO BOX 203<br>10 Anthares St','Southern Cross','Western Australia','AUSTRALIA','6426','0458392682','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 08:19:39',0,NULL,3,0,2,1,'\\ ','joslyen2007\r已入库\r新地址\rJoslyen Byrne\rPO BOX 203, \rSouthern Cross Western Australia 6426\rAUSTRALIA\r0458392682\r'),(8967,748516940011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56.49,'eastar4','mobilcz','mobilcz@humlak.cz','Jiri Franek','Mobil CZ s.r.o.<br>Polska 109','Trutnov','','CZECH REPUBLIC','54101','+420608885886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 09:30:05',0,NULL,3,1,3,1,'RA184551100CN\r ','mobilcz\rWWSI006'),(8968,830736293012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','aikhome','aikbox@gmail.com','Alexey Kardashevskiy','8 Brisbane Ave','Barton','Australian Capital Territory','AUSTRALIA','2600','04 32719275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 09:36:33',0,NULL,3,1,3,1,'RA184551113CN\r ','aikhome\rWWOT002\rIBM版 二手'),(8969,611160591013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','roeiki11','roei@azachi.co.il','Roei Azachi','60 Hayarden st.','Ramat Gan','','ISRAEL','52333','972546620995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 09:37:06',0,NULL,3,1,3,1,'RA183625322CN\r ','roeiki11\rBAZA001'),(8970,691700221008,180699002013,'New Griffin PowerJolt Dual USB Micro Car Charger track#',1,'CCGR001',8.88,'au-buy','loges47','pcxcel_newcastle@bigpond.com','John W LOGAN','5 Sapphire Court','RAYMOND TERRACE','New South Wales','AUSTRALIA','2324','0249875222','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 09:52:21',0,NULL,3,1,3,1,'RA184551303CN\r ','loges47\rCCGR001'),(8971,709411303001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','wholesalelistsource','carpetupholsterycleaning@gmail.com','julie Cormier','36 Denis St','Cap-Pele','NB','CANADA','E4N 1P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 11:09:50',0,NULL,3,1,3,1,'RA184551250CN\r ','wholesalelistsource\rBR3D004'),(8972,562026502004,140584762830,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.9,'cnfaner','vvalkab0ut','walkabout@fromru.com','Roman Buznitskiy','ul. Sharapovskaya, dom 4, korp. 2, kv. 39','Mytishi','MO','RUSSIAN FEDERATION','141002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 11:17:07',0,NULL,3,1,3,1,'RA184551201CN\r ','vvalkab0ut\rWLIN014\r通用'),(8973,691724777008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','2806939','hassan.ayache@gmail.com','Hassan','Ayache<br>Level 6, 77 Castlereagh Street','SYDNEY','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 11:37:46',0,NULL,3,1,3,1,'RA184551144CN\r ','2806939\rRELO002'),(8974,611185081013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','fredwest15','tellstar15@blueyonder.co.uk','Gary Pratt','15 Locket close<br>Bentley','Walsall','West Midlands','UNITED KINGDOM','ws2 0lx','07910432205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 11:50:07',0,NULL,3,1,2,1,'\\ ','fredwest15\r不带壳的'),(8975,745534296011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','128olives','michelleannemee@gmail.com','Michelle Morgan','4 Chester Road<br>Whitehall','Bristol','Bristol','UNITED KINGDOM','BS57AX','01179738360','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 11:56:17',0,NULL,3,1,3,1,'RA184551246CN\r ','128olives\rMOAP001'),(8976,830775201012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','eaglevoody','eagle_voody@bk.ru','Dmitry Nakhimov','Borovskaya dom 2A kv.13','Tyumen','Tyumen Region','RUSSIAN FEDERATION','625053','89199517004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 11:56:51',0,NULL,3,1,2,1,'\\ ','eaglevoody\r24K 多色伞'),(8977,830776515012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','aiko-2224','reita22@hotmail.fr','Mlle Eouzan Marjolaine','les douves gourio<br>la roche','etables sur mer','Bretagne','FRANCE','22680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 11:59:27',0,NULL,3,1,2,1,'\\ ','aiko-2224\r蕾丝蝴蝶结伞 '),(8978,709339994001,110728101635,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','free8ohn','freesohn@naver.com','Woon Kook Sohn','45-2, Yeouido-dong,<br>Yeongdeungpo-gu','Seoul','Seoul','KOREA,REPUBLIC OF','150-974','821031257747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 12:25:42',0,NULL,3,1,3,1,'RA184551192CN\r ','free8ohn\rHSBS002'),(8979,556543548003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.9,'cnfaner','losevalexey','elk-ya@mail.ru','Alexey Losev','Vodnikov 5','Yavlenka','North Kazakhstan','KAZAKHSTAN','150500','+77054537513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 12:39:25',0,NULL,3,1,3,1,'RA184551158CN\r ','losevalexey\rWWSI002+ANCN001'),(8980,748568928011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','grepfnov','f.drautz@gmail.com','Tom Renneberg','z. Hd. Florian Drautz<br>Wollankstr. 5a','Berlin','','GERMANY','13187','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 12:44:56',0,NULL,3,1,2,1,'\\ ','grepfnov'),(8981,748570922011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','alekogur','alekogur@yahoo.com','GGT Aleks Gurgenidze','2440 Enterprise Dr<br>Ste U01715','Mendota Heights','MN','UNITED STATES','55120-1143','99599505580','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 12:50:32',0,NULL,3,1,1,1,'\\ ','alekogur'),(8982,830800693012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',2,'WLIN001',51.98,'eastar4','gaelellon','mailtoalli@mail.ru','Alexey Likhachev','Otkrytoe shosse<br>3-4-57','Moscow','Moscow','RUSSIAN FEDERATION','107370','+79161613741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 13:12:15',0,NULL,3,1,3,1,'RA184551334CN\r ','gaelellon\rWLIN001+UMTR001\r再发一把New Clear Transparent Dome Rain Sun Umbrella with trim'),(8983,830809427012,220816334369,'New Clear Transparent Dome Rain Sun Umbrella with trim',1,'UMTR001',15.95,'eastar4','gaelellon','mailtoalli@mail.ru','Alexey Likhachev','Otkrytoe shosse<br>3-4-57','Moscow','Moscow','RUSSIAN FEDERATION','107370','+79161613741','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 13:40:12',0,NULL,3,0,17,0,NULL,'gaelellon'),(8984,556558125003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',22.8,'cnfaner','tivin974','eliot-simon@wanadoo.fr','AMOURGOM Kevin','6 rue lafayette','Saint-Benoit','FR','REUNION','97470','+262.(0)6.92.28.35.42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 13:51:20',0,NULL,3,1,3,1,'RA184551232CN\r ','tivin974\rHSSE004'),(8985,748590595011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','macminiintel','rjnicko@me.com','Ryan Nicholson','40 Carrfields','Goole','East Riding of Yorkshire','UNITED KINGDOM','DN146YH','01405763249','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 14:01:35',0,NULL,3,1,3,1,'RA184551073CN\r ','macminiintel\rWLAP002\r二代卡旧的'),(8986,611212486013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',119,'eastar4','afianzatelecomunicaciones','gbarrio@afianza.net','Fernando Gil','Calle Descubrimiento, 5<br>Polígono Industrial Masía del Juez','Torrent, Valencia','Comunidad Valenciana','SPAIN','46900','675993886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 14:07:13',0,NULL,3,1,3,1,'RA184551229CN\r ','afianzatelecomunicaciones\rTRTT002*10'),(8987,830821559012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','brutallicamagazine','manager@brutallica.com','Chavdar Tzachkov','Grigor Parlichev Str.<br>Block 1, Apt.1','Pleven','Pleven','BULGARIA','5800','+359888363814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 14:15:07',0,NULL,3,1,3,1,'RA184551095CN\r ','brutallicamagazine\rWWOT001\r通用版 全新'),(8988,748598765011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','a1m4y92','atrosclair@newsouth.net','AMY TROSCLAIR','1816 Industrial Blvd','HARVEY','LA','UNITED STATES','70058-2314','(504) 366-1513','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 14:26:39',0,NULL,3,1,1,1,'\\ ','a1m4y92'),(8989,611219192013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','zacharypettitt','zach_believes@yahoo.com','ZACHARY PETTITT','2406 CHIPPEWA AVE','PLACENTIA','CA','UNITED STATES','92870-1527','(714) 614-3979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 14:30:12',0,NULL,3,1,1,1,'\\ ','zacharypettitt'),(8990,748603881011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','windows852','leighburke@hotmail.com','Leigh Burke','69 Knockaphunta<br>Westport Road','Castlebar','Mayo','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 14:37:45',0,NULL,3,1,2,1,'\\ ','windows852\r微软的'),(8991,562078852004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','kjumper','estores@kimh.org','kim hansen','18142 147th Ave SE','Renton','WA','UNITED STATES','98058-9228','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-11 15:31:37',0,NULL,3,1,1,1,'\\ ','kjumper'),(8992,830855130012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','rrebustillo','rassiel.rebustillo@gmail.com','Rassiel Rebustillo Galardy','7979 NW 21st St<br>SJO 10429','Doral','FL','UNITED STATES','33122-1630','(506) 318-9248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 15:45:26',0,NULL,3,1,1,1,'\\ ','rrebustillo'),(8993,830857273012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',4,'HSPL002',38,'eastar4uk','j17eln','eflynn4@tiscali.co.uk','ELEN FLYNN','4 TAN Y FYNWENT<br>CARMEL','NR CAERNARFON','Gwynedd','UNITED KINGDOM','LL54 7AR','01286881472','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 15:52:46',0,NULL,3,1,3,1,'RA184551277CN\r ','j17eln\rHSPL002'),(8994,748218583011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',53.99,'eastar4','apaffrath2010','apaffrath@ig.com.br','Alexandro Paffrath','Rua da Peróba, 20','Curitiba','Paraná','BRAZIL','82710030','4135853266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 16:10:21',0,NULL,3,1,3,1,'RA184551285CN\r ','apaffrath2010\rGLOT004\r兼容型3D眼镜  samsung 专用'),(8995,562088089004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','steve010969','ghsteve@gmail.com','Gurdip Hunjan','63 Blockley Road','N Wembley','Middlesex','UNITED KINGDOM','HA0 3LN','02089042398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 16:11:39',0,NULL,3,1,3,1,'RA184551189CN\r ','steve010969\rBALO007'),(8996,708926450001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','kyo-5827','kyo-okamoto@mail.goo.ne.jp','kyosuke okamoto','Nisiogikita 5-2-14 102','Suginami','Tokyo','JAPAN','167-0042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 16:38:41',0,NULL,3,1,3,1,'RA184551175CN\r ','kyo-5827\rHSJB001\r白色的\r\r\r'),(8997,562101597004,140583359050,'New in box Jabra BT-2080 Wireless Bluetooth Headset',1,'HSJA005',17.9,'cnfaner','route22usa','route22usa@hotmail.com','Tera Sattaterasub','43/354 Amarin 1 Village, Ramindra Rd.<br>Anusawari, Bangkhen','Bangkok','','THAILAND','10220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 17:09:56',0,NULL,3,1,3,1,'RA184551011CN\r ','route22usa\rHSJA005'),(8998,747967376011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','fken34','fken34@yahoo.com','Kehinde Obasa','1701 Hillcrest Dr<br>Apt W21','Manhattan','KS','UNITED STATES','66502-2410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 17:10:00',0,NULL,3,1,1,1,'\\ ','fken34'),(8999,748666856011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','brijad1','adelson@email.arizona.edu','Brian Adelson','120 S Houghton Rd<br>Ste 138-165','Tucson','AZ','UNITED STATES','85748-6731','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 17:27:58',0,NULL,3,1,1,1,'\\ ','brijad1'),(9000,556611394003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','meang_kr','cheerios@hanafos.com','MyeongJoo Jeong','Siyeong 4DanJi MokHwa Apt.<br>413-1104','Seoul','Jungye 2,3 Dong Nowon-Gu','KOREA,REPUBLIC OF','139-788','010-2232-1928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 17:28:30',0,NULL,3,1,3,1,'RA184551060CN\r ','meang_kr\rWLAT007'),(9001,748672705011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','aleksandrs_001','aleksandrs_b@balticom.lv','Alexander Butaev','Visku 1-29','Riga','','LATVIA','lv-1063','+37126007177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 17:42:27',0,NULL,3,1,2,1,'\\ ','aleksandrs_001\r欧标'),(9002,748680208011,320730088138,'New Replaceable Shell for logitech MX Air Mouse',1,'SHLO001',11.5,'eastar4uk','minitt007','minitt007@yahoo.es','Javier Gómez Vázquez','C/ Poggi Borsotto, 5 -Casa-','(Islas Canarias)','Santa Cruz de Tenerife','SPAIN','38007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 17:57:35',0,NULL,3,1,2,1,'\\ ','minitt007'),(9003,830923171012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','davestivens','dstivens@happas.com','david stivens','22 belton grove','GRANTHAM','Lincolnshire','UNITED KINGDOM','NG319HH','01476401411','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 18:17:58',0,NULL,3,1,3,1,'RA184551161CN\r ','davestivens\rOTHP003'),(9004,611293473013,230393140134,'2.1 Acer Aspire 5735 5735Z Bluetooth Module EDR +cable',1,'BTAC2105',12.4,'eastar4','amazon_freak','sundell.peter@gmail.com','peter sundell','Tingsgatan 21','Boras','','SWEDEN','S-50445','+4633106326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 18:41:48',0,NULL,3,1,2,1,'\\ ','amazon_freak\racer 4pin1.25 8cm'),(9005,830945708012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',12.5,'eastar4','jean-my.martinge','douis.jean_claude@aliceadsl.fr','Jean-Claude DOUIS','108 place Notre Dame','Verneuil sur avre','Haute-Normandie','FRANCE','27130','02.32.58.33.16','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 19:02:10',0,NULL,3,1,2,1,'\\ ','jean-my.martinge\racer 4pin1.25 8cm'),(9006,830950207012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','callmebert','edgedudes@aol.com','Phillip Eaton','9763 Ridgebluff Ave','Las Vegas','NV','UNITED STATES','89148-4653','(702) 795-0017','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 19:09:37',0,NULL,3,1,1,1,'\\ ','callmebert'),(9007,748716449011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','rocksclubrick','rickapplebee@gmail.com','Richard Applebee','2442 Iowa Ave<br>Apt B5','Riverside','CA','UNITED STATES','92507-7034','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 19:16:02',0,NULL,3,1,1,1,'\\ ','rocksclubrick'),(9008,611303376013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','1ste-fani1','mego-xren@rambler.ru','Dmitriy Simonenko','begicheva street house №23 room 59','Norilsk','Krasnoyarsky edge','RUSSIAN FEDERATION','663319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 19:16:22',0,NULL,3,1,3,1,'RA184551135CN\r ','1ste-fani1\rWWSI005'),(9009,830960098012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','dimiuk2310','dimiuk@tiscali.it','DiMITRIS MERTZIDIS','ATHINAS 14','PYLAIA','THESSALONIKI','GREECE','54250','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 19:27:41',0,NULL,3,1,2,1,'\\ ','dimiuk2310'),(9010,748735915011,320730083567,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',9.99,'eastar4uk','pgc0121','pgcllx1@tiscali.co.uk','peter connolly','65 new coventry rd<br>sheldon','birmingham','West Midlands','UNITED KINGDOM','b26 3ba','01217437631','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 19:55:07',0,NULL,3,1,3,1,'RA184551215CN\r ','pgc0121\rOTCN005\r白色的'),(9011,830972722012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','p.tatiana','popicheva.tatiana@gmail.com','Popicheva Tatiana','Mira, 4/76<br>Podrezkovo','Khimki, Russia','Moscow region','RUSSIAN FEDERATION','141446','8-903-294-55-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 20:14:09',0,NULL,3,1,2,1,'\\ ','p.tatiana\r24K 多色伞 '),(9012,748752727011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','bspir82al-2008','techsamaritan34@gmail.com','Osei  Daniels','10108 Brock Dr','SILVER SPRING','MD','UNITED STATES','20903-1618','(301) 318-6518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 20:30:30',0,NULL,3,1,1,1,'\\ ','bspir82al-2008'),(9013,831008395012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','hawe_wiwi','hanneswegener@googlemail.com','Hannes Wegener','Rummelsburger Strasse 61a','Hamburg','','GERMANY','22147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 21:05:24',0,NULL,3,1,2,1,'\\ ','hawe_wiwi'),(9014,610464621013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','tequilasv1','miltonloucel@gmail.com','milton loucel','1º calle oriente final 2ª Avenida norte casa #3','Soyapango','San Salvador','EL SALVADOR','503','22271343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 21:12:30',0,NULL,3,1,2,1,'\\ ','tequilasv1'),(9015,611062617013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','alpererincmusic','alperkeremerinc@gmail.com','ALPER KEREM ERINC','4281 Express Ln<br>Ste L2841','Sarasota','FL','UNITED STATES','34238-2602','941 538 6941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 21:18:50',0,NULL,3,1,1,1,'\\ ','alpererincmusic'),(9016,748780190011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','bigalyoung','young.a@tiscali.co.uk','Alan M Young','89 Abbots Park<br>Tulse Hill','London','London','UNITED KINGDOM','SW2 3QY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 21:37:56',0,NULL,3,1,3,1,'RA184551294CN\r ','bigalyoung\r微软的\rOTHP006'),(9017,748785041011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','vladiki1969','vkarchevsky@gmail.com','Vlad Karchevsky','12 Laurel Cir','Newtown','PA','UNITED STATES','18940-3221','(215) 371-2977','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 21:51:51',0,NULL,3,1,1,1,'\\ ','vladiki1969'),(9018,556694707003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','linardbr','alberto.linard@gmail.com','Francisco Alberto Alexandre Linard','Rua Padre Valdevino, 2537<br>Apt. 302B Aldeota','Fortaleza','CE','BRAZIL','60135041','+55(85)96286602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 22:03:31',0,NULL,3,1,3,1,'RA184551127CN\r ','linardbr\rHSJA006'),(9019,748789233011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','jburillo','burillo@ma4.upc.edu','Jose Burillo','Pujol 5, 2-C','Barcelona','Cataluña','SPAIN','08022','654958077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 22:04:30',0,NULL,3,1,3,1,'RA184551087CN\r ','jburillo\rUDAP001'),(9020,611376726013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',119,'eastar4','tornadoe','nwguy2002@yahoo.com','Julian R. Illescas','1623 W. Owens Way','Anthem','AZ','UNITED STATES','85086','(310) 614-8792','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-11 23:33:29',0,NULL,3,1,1,1,'\\ ','tornadoe'),(9021,831067833012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','emerth42','emerth@hotmail.com','Eric Merth','Suite 3<br>3215 14 St N.W.','Calgary','AB','CANADA','T2K1J1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 00:04:56',0,NULL,3,1,2,1,'\\ ','emerth42'),(9022,831069687012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',17.15,'eastar4','itronics-co','itronicstrading@gmail.com','Ling-Fung Ip','39398 Zacate Ave','Fremont','CA','UNITED STATES','94539-3062','(510) 739-3838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 00:12:52',0,NULL,3,1,1,1,'\\ ','itronics-co\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000'),(9023,831072863012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','swy351','swy@cs.queensu.ca','Weiyi Shang','660-A Butternut Ave','Waterloo','ON','CANADA','N2V 2K9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 00:28:23',0,NULL,3,1,2,1,'\\ ','swy351'),(9024,611395650013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','pauloeczetes','eczetes@gmail.com','Paulo Roberto Eczetes','Rua Drumond, 50 - Olaria','Rio de Janeiro','RJ','BRAZIL','21031460','55-21-25642835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 01:05:03',0,NULL,3,1,2,1,'\\ ','pauloeczetes'),(9025,748817705011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',6,'OTCN002',23.94,'eastar4','marcelobyms','byms@hotmail.com','Marcelo Siqueira','Rua Aiuba, 89<br>Anchieta','Rio de Janeiro','RJ','BRAZIL','21630-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 01:36:30',0,NULL,3,1,2,1,'\\ ','marcelobyms'),(9026,748847313011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','penbf','wise4you@yahoo.com','dionne walker','342 Church St','Catasauqua','PA','UNITED STATES','18032-2519','(229) 325-0533','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 01:51:45',0,NULL,3,1,1,1,'\\ ','penbf'),(9027,611407389013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',4,'OTCN001',15.96,'eastar4','asam7200','samsowa2004@gmail.com','Addo Samuel','264 E 165th St<br>Apt 4B','Bronx','NY','UNITED STATES','10456-6068','(347) 387-3686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 02:02:08',0,NULL,3,1,1,1,'\\ ','asam7200'),(9028,831104131012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','drydee','drydee@aol.com','Rob J Dryden','27173 W POTTER DR','BUCKEYE','AZ','UNITED STATES','85396-6953','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 02:22:03',0,NULL,3,1,1,1,'\\ ','drydee'),(9029,831113732012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','illusionarylines','dsmccann@gmail.com','David McCann','8/598 Boundary St','Spring Hill','Queensland','AUSTRALIA','4000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 03:00:13',0,NULL,3,1,2,1,'\\ ','illusionarylines'),(9030,8881313120876101,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','thermostat55','tomkingjr@rcn.com','Thomas King','29 Cherubs Way','Hampstead','NH','UNITED STATES','03841','',NULL,NULL,NULL,'2011-08-12 03:47:56',0,NULL,3,1,3,1,'RA184551348CN\r ','补发的\rMOAP001'),(9031,611443604013,230641258112,'New lady lace trim sun/rain stick Umbrella pink',1,'UM00011',24.99,'eastar4','milktee23','cafemilktee@gmail.com','Pauline Nguyen','13719 Lampting Dr','Pflugerville','TX','UNITED STATES','78660-7810','(512) 672-9602','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 05:54:29',0,NULL,3,1,1,1,'\\ ','milktee23\r蕾丝花边伞 \r粉红色的'),(9032,8881313131875617,111,' NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER FOR iPHONE IPAD  ',1,'BAZA001',0,'eastar4','charmedsuperman','marksantos702@gmail.com','Mark Santos','PO Box 30851','Las Vegas','NV','UNITED STATES','89173-0851','(702) 767-3009',NULL,NULL,NULL,'2011-08-12 06:51:15',0,NULL,3,1,3,1,'RA183625319CN\r ','补发的\rBAZA001 '),(9033,748919610011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',7,'CASS003',60.9,'eastar4','getdatgoal','pascualricky@yahoo.com','frederick pascual','167 Apo St.<br>N.S. Amoranto Ave.','Quezon','NCR','PHILIPPINES','1114','9193220522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 07:53:39',0,NULL,3,1,3,1,'RA183618975CN\r ','getdatgoal\rCASS003'),(9034,831173219012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',3,'HSJA001',71.97,'eastar4','kach0909','sauer-neuner@t-online.de','Karlheinz Neuner','Unterer Jagdeweg 2','Malsch','','GERMANY','69254','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 07:58:23',0,NULL,3,1,3,1,'RA183618984CN\r ','kach0909\rHSJA001\r欧标'),(9035,748929601011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','beta-j','manaqraxemails@gmail.com','James Baldacchino','16, Sirius,, Triq Il-migbha','Marsascala','n/a','MALTA','zbr12','79208867','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 08:39:22',0,NULL,3,1,2,1,'\\ ','beta-j\r微软的'),(9036,747193061011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','kglpass5','kglogitech4@gmail.com','ACI Express','17252 S Main St<br>Aci Express La.br (4911)','Gardena','CA','UNITED STATES','90248-3101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 08:50:52',0,NULL,3,1,1,1,'\\ ','kglpass5\r\r'),(9037,611469930013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','jefftut123','jean.quint@neuf.fr','Jean-Francois QUINT','6 rue des Pinsons','SARCELLES','Île-de-France','FRANCE','95200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 08:52:45',0,NULL,3,1,2,1,'\\ ','jefftut123'),(9038,556802729003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',3,'HSNO019',119.7,'cnfaner','den_kolomin','denis_kolomin@valerievich.info','Kolomin Denis Valerievich','per. Kolhozniy, d.48, kv.6','p. Kuragino','Krasnoyarskiy kray','RUSSIAN FEDERATION','662910','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 09:52:13',0,NULL,5,1,3,1,'RA183625282CN\r ','den_kolomin\r欧标\rHSNO019\r已发货 点不了。'),(9039,748948377011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','rjarun85','arun.ksr06@yahoo.com','Arun R','BLOCK 774,#10-22, Woodlands crescent','default','','SINGAPORE','730774','93366493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 09:58:35',0,NULL,3,1,11,1,NULL,'rjarun85\rHSJA006'),(9040,831211391012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','vamosevishal','vamose@gmail.com','Vishal Verma','Post box 57','Abu dhabi','United arab emirates','UNITED ARAB EMIRATES','57','+971552102333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 10:26:35',0,NULL,5,0,18,0,NULL,'vamosevishal\r客户要撤单'),(9041,611494058013,230641224717,'Transparent Dome Rain Sun Umbrella with yellow trim',1,'UMTR001',19.99,'eastar4','eugensuch','eugen.such@gmail.com','Eugen Suchev','Bajova 1-21','Ozersk','','RUSSIAN FEDERATION','456783','9049389445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 11:11:25',0,NULL,3,0,2,1,'\\  ','eugensuch\r黄色的\r已入库'),(9042,748962028011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','harpyja2004','giovannitorres74@hotmail.com','Giovanni Torres','15023 115TH ST','SOUTH OZONE PARK','NY','UNITED STATES','11420-3920','(646) 355-7386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 10:54:26',0,NULL,3,1,1,1,'\\  ','harpyja2004'),(9043,831224587012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',19.98,'eastar4uk','panter_l','leigh_panter@me.com','Leigh Panter','C/Burgos No 10, (BX 39)<br>URB Atalaya Park','Benijofar Alicante','Comunidad Valenciana','SPAIN','03178','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 11:11:51',0,NULL,3,1,3,1,'RA183618896CN\r ','panter_l\rWLAP008'),(9044,831229769012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','afinterman','alessandro.finterman@gmail.com','Alessandro Finterman','Rua Padre Boss, 141 Ap 201<br>Jardim America','Rio de Janeiro','RJ','BRAZIL','21240-180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 11:31:00',0,NULL,3,1,2,1,'、 ','afinterman\r'),(9045,748979353011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','wnotebooks','gayrayon@namur.be','Leonid Novikov','Rue Saint-Jacques 225<br>(St-jacques 224 en cas d\'absence SVP)','Dinant','','BELGIUM','5500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 11:55:48',0,NULL,3,1,2,1,'\\ ','wnotebooks'),(9046,556826948003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',5,'HSPL010',134.75,'cnfaner','ybentora','ybentora@yahoo.com','yaron ben tora','remba 11','ramat gan','','ISRAEL','52587','972522202108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:10:09',0,NULL,3,1,3,1,'RA183625764CN ','ybentora\rHSPL010'),(9047,748985171011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','dolfusr1bis','dolfusr1@gmail.com','Adolfo Pérez Escobar','Paseo Castellana, 259B<br>PwC','Madrid','Madrid','SPAIN','28046','638511039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:16:28',0,NULL,3,1,2,1,'\\ ','dolfusr1bis'),(9048,709822649001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',3,'OTAM001',17.97,'buysia','ktaylor347','ktaylor347@sbcglobal.net','Karen Taylor','1024 Shadowoak Dr','Ballwin','MO','UNITED STATES','63021-6546','(636) 207-9177','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 12:10:08',0,NULL,3,1,1,1,'\\  ','ktaylor347'),(9049,562329062004,140583359050,'New in box Jabra BT-2080 Wireless Bluetooth Headset',2,'HSJA005',35.8,'cnfaner','bogdanovits2011','jurasu@mail.ru','Bogdanovits Juri','Pelguranna 57-4','Tallinn','','ESTONIA','10316','+372 55 85 667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:47:11',0,NULL,3,1,3,1,'RA183625251CN\r ','bogdanovits2011\rHSJA005\r欧标'),(9050,748996973011,320721404167,'Transparent Dome Rain Sun Umbrella with black trim',1,'UMTR001',19.99,'eastar4','lavrva52','lavrva@gmail.com','Vitaliy Lavrentev','Chernorechenskaya st. 14, flat 52','Samara','','RUSSIAN FEDERATION','443030','78463368940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:55:38',0,NULL,5,0,18,1,NULL,'lavrva52\r黑色的\r已入库 退款'),(9051,748998288011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','altr2elise','olorin@iinet.net.au','Mrs Jo Westacott','4 Highlands Road','North Perth','Western Australia','AUSTRALIA','6006','0892012052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:58:52',0,NULL,3,1,2,1,'\\ ','altr2elise'),(9052,749012032011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mani005','lakhbir.shergill@gmail.com','Manvir Shergill','3 Premier Ave<br>South Morang','Melbourne','Victoria','AUSTRALIA','3752','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 13:45:20',0,NULL,3,1,2,1,'\\ ','mani005'),(9053,749014465011,320730086228,'NEW CAB-2660-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 1T',3,'CASS002',17.97,'eastar4uk','networkshop2010','geoff.bowditch@gmail.com','Geoff Bowditch','12 Dunraven Avenue','Redhill','Surrey','UNITED KINGDOM','RH1 5JW','01737773578','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 13:49:15',0,NULL,3,1,3,1,'RA183618936CN\r ','networkshop2010\rCASS002'),(9054,611225522013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',124.95,'eastar4','juxtaposa','nmcclure@internode.on.net','Neal McClure','P.O. Box 362, North Adelaide','Adelaide','South Australia','AUSTRALIA','5006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 14:28:40',0,NULL,3,1,3,1,'RA183625305CN\r ','juxtaposa\rMOAP001'),(9055,831291555012,220830150923,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',9.99,'eastar4','urip11mail.ru','urip11@bezeqint.net','Uri Farber','Shprinzak 1325','Nahariya','Haifa','ISRAEL','22210','972-525500822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 14:35:31',0,NULL,3,1,2,1,'\r\\ ','urip11mail.ru'),(9056,611544297013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','hardcolor','p.tvrdy@yahoo.com','Peter Tvrdy','J. Bottu 420','Bosany','','SLOVAK REPUBLIC','95618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 14:54:21',0,NULL,3,1,2,1,'\\  ','hardcolor\r红边优联 '),(9057,749035884011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','zertykolp','stephane.chaumont@bbox.fr','Stéphane CHAUMONT','3, rue Libéral BRUANT','DRAVEIL','Île-de-France','FRANCE','91210','06.62.46.08.76','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 14:55:19',0,NULL,3,1,2,1,'\\  ','zertykolp'),(9058,749038390011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','matthebag','mattbag@gmail.com','Matt Greybrook','VCG Kestrel<br>1 Europa Park','Witham','Essex','UNITED KINGDOM','CM8 2FN','07950884829','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 15:03:31',0,NULL,3,1,3,1,'RA183618905CN\r ','matthebag\rWLAP002\r二代卡 旧'),(9059,831306885012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','xxalexx75','jorge.nogueirarojo@gmail.com','Jorge Nogueira Rojo','C/ Minerva 78 4º B','Madrid','Madrid','SPAIN','28032','609776648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 15:16:57',0,NULL,3,1,3,1,'RA183625945CN\r ','xxalexx75\rOTSO004*2'),(9060,556868678003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','hurlymonster219','mhurley219@yahoo.com','Michael Hurley','28306 Cypress Loop','Daphne','AL','UNITED STATES','36526-6620','(251) 281-3240','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-12 15:18:02',0,NULL,3,1,1,1,'\\  ','hurlymonster219'),(9061,692203181008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','adeel4612','adil4u_3@hotmail.com','Adeel Rana','11 Arbor terrace','Avondale Heights','Victoria','AUSTRALIA','3034','0411745398','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 16:10:30',0,NULL,3,1,3,1,'RA183625075CN\r ','adeel4612\rHSPL005\r澳标'),(9062,749064497011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',32,'eastar4','overactive_drive','mperrick@sbcglobal.net','Michael Perrick','909 Kodak Dr<br>Apt 1','Los Angeles','CA','UNITED STATES','90026-2749','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 16:12:15',0,NULL,3,1,1,1,'\\  ','overactive_drive\r 二代卡 旧'),(9063,831329803012,220830150923,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',2,'OTRA003',19.98,'eastar4','cyclope-69','ivp1981@gmail.com','Iván de la Vega','Los Pastores, nº 11, 1º','Palencia','Castilla y León','SPAIN','34005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 16:14:13',0,NULL,3,1,2,1,'\\ ','cyclope-69'),(9064,749067300011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','thebman61','mrcpb98@yahoo.com','Christopher Barbera','1 Kirk Ave','Ronkonkoma','NY','UNITED STATES','11779','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 16:21:42',0,NULL,3,1,1,1,'\\  ','thebman61'),(9065,749076511011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',9,'CASS003',53.91,'eastar4uk','rymcconechy','ryan@highgreenan.com','Ryan McConechy','Voyager Networks ltd.<br>Unit 5 Newyearfield Farm','Livingston','West Lothian','UNITED KINGDOM','EH54 6TW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 16:43:59',0,NULL,3,1,3,1,'RA183618922CN\r ','rymcconechy\rCASS003'),(9066,746994994011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','sakic666','sakic666@interia.pl','Łukasz Konarski','Jarochowskiego 30a/7','Poznań','wielkopolskie','POLAND','60238','61 8663457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 16:51:57',0,NULL,3,1,2,1,'\\  ','sakic666'),(9067,749106738011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','yaegashiatsushi','hachi1974@gmail.com','Atsushi Yaegashi','21-17-207<br>Tatemukaicho','Morioka','Iwate','JAPAN','0200115','81-19-652-8364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 17:56:25',0,NULL,3,1,2,1,'\\  ','yaegashiatsushi'),(9068,611603502013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','rdresser1','r.dresser@shaw.ca','Robert Dresser','687 Foster Drive','Parksville','BC','CANADA','V9P 2L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 18:19:23',0,NULL,3,1,2,1,'\\ ','rdresser1'),(9069,709944522001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','johnd3000','silverducas@yahoo.com','John Ducas','Avenue  G.Macau 33 ','Bruxelles','','BELGIUM','1050','0474890979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 18:19:41',0,NULL,3,1,3,1,'RA183625035CN\r ','johnd3000\rBR3D008'),(9070,611613697013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Steve Wilkins','901 SE 5TH ST','Guymon','OK','UNITED STATES','73942-5427','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 18:52:05',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9071,611614758013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Charity Smith','506 Legacy Dr','Smyrna','TN','UNITED STATES','37167-5785','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 18:55:54',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9072,611616067013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Larry D. McClendon','1954 IDYLWILD DR','WRIGHTSVILLE','GA','UNITED STATES','31096-5034','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 18:58:19',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9073,611616868013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Scott Hammond','4043 N RAVENSWOOD AVE<br>STE 227','CHICAGO','IL','UNITED STATES','60613-5682','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 19:01:37',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9074,749135399011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',104.95,'eastar4','123gowrestling','georgemefford@yahoo.com','george mefford','228 Pepper Grass Ct','Bartlesville','OK','UNITED STATES','74006-2933','(918) 331-9203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 19:02:04',0,NULL,3,1,1,1,'\\  ','123gowrestling\r兼容型3D眼镜 通用型'),(9075,831405752012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','robertgeogrejones','letter4bob@hotmail.com','Robert Jones','17 Shelley Lane','Barrie','ON','CANADA','L4N 4W4','(705) 737-2845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 19:02:22',0,NULL,3,1,3,1,'RA183618879CN\r ','robertgeogrejones\rOTRA001'),(9076,831419402012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','walsermi','mi.walser@gmail.com','Michael Walser','Kirchenfeldstrasse 24','Muri','','SWITZERLAND','5630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 19:30:17',0,NULL,3,1,3,1,'RA183625279CN\r ','walsermi\rGLSG001*2\r盒装的'),(9077,611633714013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','sabanganbiay96','matusalem90@yahoo.com','Ronald Cabrales','7835 Mountain Sights<br>Apt. 89','Montreal','QC','CANADA','H4P 2B1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 19:52:11',0,NULL,3,1,2,1,'\\ ','sabanganbiay96'),(9078,749165659011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','pok-aii','hin.cheuk.lau@gmail.com','cheuk Hin Lau','flogstavägen 59f','uppsala','uppsala','SWEDEN','75273','0046704026520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 20:06:59',0,NULL,3,1,2,1,'\\ ','pok-aii'),(9079,749179609011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','aeizoon','juan@murciawireless.com','Juan Antonio Pagan','Apartado 134 Polig. OESTE','Alcantarilla','Murcia','SPAIN','30169','649920909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 20:38:59',0,NULL,3,1,3,1,'RA183618777CN\r ','aeizoon\rUDAP001'),(9080,611617950013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Veronica Avery ,','9404 ESSEX ST','ROMULUS','MI','UNITED STATES','48174-1534','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 20:54:54',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9081,611653320013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Eric Marcussen','750 East Swedesford Road','Valley Forge','PA','UNITED STATES','19482','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 20:57:35',0,NULL,3,1,1,1,' \\ ','mauriceshow'),(9082,611654243013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','John D Burke , COLORADO','8400 S UPHAM WAY<br>APT F25','LITTLETON','CO','UNITED STATES','80128-6378','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 21:00:37',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9083,749195578011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','kalladykrish','krishrukshi@gmail.com','Ramiah Krishantha','Unit 4<br>2A Chester Street','Petersham','New South Wales','AUSTRALIA','2049','0415441823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 21:20:22',0,NULL,3,1,2,1,'\\ ','kalladykrish'),(9084,831490714012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'eastar4','jimretnavy','jimretnavy@comcast.net','Jim Santiago','129 Cherry St','Tinton Falls','NJ','UNITED STATES','07724-2639','(732) 933-0080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 22:15:43',0,NULL,3,1,1,1,'\\ ','jimretnavy\r兼容型3D眼镜 通用型'),(9085,610950035013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',20.64,'eastar4','thehifiguy','shibuminow@gmail.com','Assets Intl. Inc.','2038 S 108th St','Seattle','WA','UNITED STATES','98168-1731','(206) 948-0000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 22:20:43',0,NULL,3,1,1,1,'\\  ','thehifiguy\r一共买了三个'),(9086,749216057011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','dicksonw','dickson.g.wong@gmail.com','Dickson Wong','#517 8710 Horton Road SW','Calgary','AB','CANADA','T2V 0P7','(780) 910-0941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 22:22:17',0,NULL,3,1,2,1,'\\  ','dicksonw'),(9087,749226545011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',135.99,'eastar4','rootsq8','rootskuwait@live.com','Mr.Alaa Hajjaj (Private and Confidential)','Al-Soor Finncing<br>P.O. Box 177 Safat','Kuwait','','KUWAIT','13002','+865-66575254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 23:02:49',0,NULL,3,1,3,1,'RA183625985CN\r ','rootsq8\r盒装的\rOTSO005*2\r一个粉红色的一个蓝色的'),(9088,749245399011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bigtimeleafsfan','ogradyj@hotmail.com','Jeff O\'Grady','1808- 37 Grosvenor St.<br>apt. 1808','Toronto','ON','CANADA','M4Y3G5','(416) 212-3719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 00:17:20',0,NULL,3,1,3,1,'RA183625044CN\r ','bigtimeleafsfan\rHBPH002'),(9089,749224840011,320741897531,'GPS USB receiver w/SIRF3 chip sets +antenna',1,'GPS0001',27.99,'eastar4uk','miltiadis451','m.kokkonidis@gmail.com','Miltiadis Kokkonidis','Dyonisiou 177<br>Agios Thomas - Maroussi','Athens','Greece','GREECE','151 24','302106833406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-13 00:48:31',0,NULL,3,1,3,1,'RA183625968CN\r ','miltiadis451\rGPA0001'),(9090,611701931013,230653158502,'New Germany Grohe Crystal Anion Spa Shower Head +hose',1,'OTGR004+OTGR002',39.99,'eastar4','vijaybaulevu','vjrsingh@bigpond.net.au','vijays power tools','897 botany road','mascot','New South Wales','AUSTRALIA','2020','0297008440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 00:50:33',0,NULL,3,1,3,1,'RA183625971CN\r ','vijaybaulevu\rOTGR004+OTGR002'),(9091,611455528013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',21.57,'eastar4','555rise','alan.choon@gmail.com','Alan Choon','Blk 523 Ang Mo Kio Ave 5<br>#02-4164','default','','SINGAPORE','560523','91548884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 00:54:01',0,NULL,3,1,11,1,NULL,'555rise\rWLIN013+ANTY002\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI'),(9092,831475214012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',179.99,'eastar4','mickey_beads','4evrmickey@gmail.com','Trevor or Delores Colbourne','34 Todd Street','Cambridge','ON','CANADA','N1R1G5','(519) 365-7355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 01:06:26',0,NULL,3,1,3,1,'RA183625265CN\r ','mickey_beads\rGLSG001*3'),(9093,749259214011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','oscillatingwildly','shannonrowsey@hotmail.com','Shannon Mann','2911 Dorrington Dr','Dallas','TX','UNITED STATES','75228-6041','(321) 278-0131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 01:20:26',0,NULL,3,1,1,1,'\\  ','oscillatingwildly'),(9094,562506579004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','davemc5256','dcanaday@roadrunner.com','David Canaday','136 Brome Dr','Nicholasville','KY','UNITED STATES','40356-9523','(859) 305-6379','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 01:25:00',0,NULL,3,1,1,1,'\\  ','davemc5256'),(9095,710079652001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','scubaking503','scubaking503@hotmail.com','Marc Pelletier','68 Ste Anne<br>Appt #1','Ste-Genevieve','QC','CANADA','H9H 2Z1','(514) 784-1504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 02:00:25',0,NULL,3,1,3,1,'RA183625132CN\r ','scubaking503\rBR3D008'),(9096,749274911011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','007lostinspace','nana007@centurylink.net','Philip Limpach','9728 State Route 65','Ottawa','OH','UNITED STATES','45875-1047','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 02:29:59',0,NULL,3,1,1,1,'\\  ','007lostinspace'),(9097,608436600013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',70.99,'eastar4','combo26','ray.glasson@bbsaa.com.au','Ray  Glasson','1 Sutherland Street','Port Hedland','Western Australia','AUSTRALIA','6721','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 03:25:25',0,NULL,3,1,3,1,'RA183625163CN\r ','combo26\rMOSA003'),(9098,611730581013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','ianelliana','paul.joselow@verizon.net','Paul Joselow','83 Pine Tree Ln','Tappan','NY','UNITED STATES','10983','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 03:40:53',0,NULL,3,1,1,1,'\\  ','ianelliana'),(9099,749304115011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','gainesvillemudhead','mudhead@myway.com','Marcus Harbin','1556 Biscayne Pl','Gainesville','GA','UNITED STATES','30507','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 05:11:39',0,NULL,3,1,1,1,'\\  ','gainesvillemudhead'),(9100,611743785013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','scottso22','scottso22@hotmail.com','Scott Woodward','8455 Lodgepole Ln','Riverside','CA','UNITED STATES','92508-7105','(951) 780-9164','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 05:24:24',0,NULL,3,1,1,1,'\\  ','scottso22'),(9101,749328948011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','nexas71','brettski71@netspace.net.au','Brett Fenton','PO Box 6260','Footscray West','Victoria','AUSTRALIA','3012','0396899189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 07:31:28',0,NULL,3,1,2,1,'\\ ','nexas71\r二代卡 旧'),(9102,749332485011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','tobun7','thomas@bunata.com','Thomas Bunata','Am Windschlag 17','Bad Aibling','','GERMANY','83043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 07:47:36',0,NULL,3,1,2,1,'\\ ','tobun7'),(9103,557074738003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.9,'cnfaner','rgrekov','rgrekoff@gmail.com','Roman Grekov','Rossiyskiy pr., 3-1-232','Sankt-Peterburg','','RUSSIAN FEDERATION','193231','+7 (952) 377-4594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:48:10',0,NULL,3,1,3,1,'RA184557252CN ','rgrekov\rWWSI002+ANCN001'),(9104,831650836012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',12.5,'eastar4','nick_z','nick_z@t-online.de','Nikolaus Zanzinger','Bunsenstr. 43<br>Siemens AG, E S SF REU 4 1','Erlangen','','GERMANY','91058','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 09:45:40',0,NULL,3,1,2,1,'\\ ','nick_z'),(9105,749377756011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',4,'CCGR001',27.52,'eastar4','yichieh2011','hagaiy@gmail.com','hagai yichie','zerah shaubi 6','rehoveot','','ISRAEL','76503','0547920581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 10:45:54',0,NULL,3,1,2,1,'\\ ','yichieh2011'),(9106,831682342012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','alexandjenny05','alex_jennyhopwood@bigpond.com','Alex and Jenny Hopwood','17 yvonne st','Highworth','Queensland','AUSTRALIA','4560','0754763658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 11:35:29',0,NULL,3,1,3,1,'RA183625923CN\r ','alexandjenny05\r盒装的\rOTSO004*2'),(9107,692512049008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','david-centralcoast','allthingswork2gether4good@gmail.com','David Kenneth Peters','217 Peach Orchard Road','Fountaindale','New South Wales','AUSTRALIA','2258','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 12:09:57',0,NULL,3,1,3,1,'RA183625150CN\r ','david-centralcoast\r澳标\rHSPL005'),(9108,611816752013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','volineli','elivkll@gmail.com','eli volinsky','rene kasan 63','beer sheva','israel','ISRAEL','84839','972 522 1312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 12:36:00',0,NULL,3,1,2,1,'\\ ','volineli'),(9109,749411567011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','zlan1499','zlanham53@hotmail.com','Zachary Lanham','2312 Pasadena Dr<br>Unit 74','Dubuque','IA','UNITED STATES','52001','(563) 663-2071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 12:38:09',0,NULL,3,1,1,1,'\\  ','zlan1499'),(9110,611819340013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','10012871','mfigueiredo@b-lizzard.pt','Miguel Figueiredo','B\'Lizzard Lda<br>Rua Joaquim Rocha Cabral, 14A','Lisboa','Lisboa','PORTUGAL','1600-086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 12:46:22',0,NULL,3,1,2,1,'\\ ','10012871'),(9111,831712067012,220502334252,'2.1 HP ProBook 4510S 4515S 4710S Bluetooth Module cable',1,'BTHP2104',12.4,'eastar4','jozsi966','iww183@citromail.hu','Banyai Jozsef','Rozsafa ut 37','Salgotarjan','Nograd','HUNGARY','3104','0036702726690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 12:56:42',0,NULL,3,1,2,1,'\\ ','jozsi966\rHP 8pin 1.0 18cm 4线连'),(9112,749428986011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','finkjakob','jfink@gmx.at','Jakob Fink','Schanzelgasse 17/17','Graz','','AUSTRIA','8010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 13:30:34',0,NULL,3,1,2,1,'\\ ','finkjakob'),(9113,831721614012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','methaus91','cawan91@hotmail.fr','pereira christophe','4, square paul lafargue','evry','Ile-de-France','FRANCE','91000','0669794171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 13:31:02',0,NULL,3,1,3,1,'RA183618882CN\r ','methaus91\rWWOT003'),(9114,749434421011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','johan_ii','johanblomberg@live.se','johan blomberg','vallavägen 165','default','haninge','SWEDEN','13641','0768-11 45 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 13:49:15',0,NULL,3,1,2,1,'\\ ','johan_ii\r二代卡 旧'),(9115,692548457008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',63.99,'au-buy','boronyane','reg.allsopp@westnet.com.au','reg allsopp','3 o\'connell street','little grove','Western Australia','AUSTRALIA','6330','0898444974','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 14:10:18',0,NULL,3,1,3,1,'RA183625027CN\r ','boronyane\rHBPH002'),(9116,749444760011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','fredmooij','fred.mooij@planet.nl','Fred Mooij','Valkenboskade 421','\'S-GRAVENHAGE','','NETHERLANDS','2563JB','070 3457035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 14:17:01',0,NULL,3,1,2,1,'\\ ','fredmooij\r 二代卡 旧'),(9117,611844180013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',104.95,'eastar4','tpecheux','tpecheux@aol.com','Thierry PECHEUX','La Besnardière','SAINT-PLANCHERS','Basse-Normandie','FRANCE','50400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 14:28:14',0,NULL,3,1,3,1,'RA183625353CN\r ','tpecheux\rGLOT001*2\r兼容型3D眼镜 通用型'),(9118,831753388012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',56.98,'eastar4uk','lejon72','tacsec@hotmail.com','Magnus Lund','Slåttängsgatan 53','Gothenburg','','SWEDEN','41507','+46705554494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-13 14:52:26',0,NULL,3,1,3,1,'RA183625129CN\r ','lejon72\r欧标\rHSNO019'),(9119,749472772011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','ethier04','ethier04@sympatico.ca','Robert Ethier','125 Des Canots','Pointe Claire','QC','CANADA','h9r4x3','(514) 694-6216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 15:33:31',0,NULL,3,1,2,1,'\\  ','ethier04'),(9120,749475896011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','priv93','priyankv@hotmail.co.uk','Priyank Vassantlal','99 Lancaster Road<br>Northolt','London','Middlesex','UNITED KINGDOM','UB5 4TE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:01:31',0,NULL,3,1,2,1,'\\  ','priv93\r英标'),(9121,831806383012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','matthew_smith9119','matthew.kieran.smith@hotmail.co.uk','Matthew Smith','32 George Road','Stokenchurch','Buckinghamshire','UNITED KINGDOM','HP143RN','07938010001','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-13 16:51:20',0,NULL,3,1,3,1,'RA183618763CN\r ','matthew_smith9119\rWLAP008'),(9122,831814604012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',2,'OTGR001',39.98,'eastar4','tedbink','tedbink@pacbell.net','Ted Binkley','12652 Groveview St','Garden Grove','CA','UNITED STATES','92840','(713) 534-0107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 17:10:55',0,NULL,3,1,1,1,'\\  ','tedbink'),(9123,831819671012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','libor-p','polehna.libor@gmail.com','Libor Polehna','Vystavni 2593/1','Ostrava','','CZECH REPUBLIC','70200','773932393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 17:19:25',0,NULL,3,1,2,1,'\\  ','libor-p'),(9124,749519407011,320677497999,'New Apple Macbook Reinstall Driver 8GB USB pen key',1,'UDAP002',34.49,'eastar4','gcwesley','gcwesley@yahoo.com','gc wesley','7878 apache ridge ct','manassas','VA','UNITED STATES','20109-7600','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 17:27:22',0,NULL,3,1,1,1,'\\  ','gcwesley'),(9125,749519058011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','tupy2p','jatupy@gmail.com','John A. Tupy','2401 East Ave','Gulfport','MS','UNITED STATES','39501','(703) 402-0311','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 17:33:58',0,NULL,3,1,1,1,'\\  ','tupy2p'),(9126,831850243012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','benfryer','bfryer@gmail.com','Ben Fryer','9 Seymour Grove','Sale','Cheshire','UNITED KINGDOM','M33 3AD','07980190218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-13 18:29:15',0,NULL,3,1,3,1,'RA183625101CN\r ','benfryer\rOTHP003'),(9127,611915590013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','zek21zoho','zkovacs@zoho.com','Zoltán Kovács','Nyuszi stny. 13.','Budapest','','HUNGARY','H1214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 18:31:51',0,NULL,3,1,2,1,'\\ ','zek21zoho\r一条CAB-6060\r一条CAB-2660\r'),(9128,831857690012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','danny6798','danny514_1@hotmail.com','danny migneault','6659 Sherbrooke.Ouest (apt.21)','montreal','QC','CANADA','H4B1N8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 18:39:33',0,NULL,3,0,2,1,'\\  ','danny6798\r粉红色的\r已入库'),(9129,749568620011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','domina8h','domin8ah@gmail.com','Marcel Douwstra','Minhof 24','Utrecht','','NETHERLANDS','3582 CN','0655864047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 19:16:07',0,NULL,3,1,2,1,'\\ ','domina8h\r 二代卡 旧'),(9130,831872598012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',12.5,'eastar4','rcer9762','reddcer@yahoo.com','Redentor Cervantes','220 E Broadway<br>Unit 205','Glendale','CA','UNITED STATES','91205-1009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 19:26:34',0,NULL,3,1,1,1,'\\  ','rcer9762\r华硕10pin 0.8 6cm '),(9131,611943063013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','sahs60','chavezfe@aol.com','Frank Chavez','1418 Canyon Hills Dr NE','Albuquerque','NM','UNITED STATES','87112-6396','(505) 298-8385','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 19:56:42',0,NULL,3,1,1,1,'\\  ','sahs60'),(9132,611944840013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','navcafe','oceano_azure@yahoo.com','Patricia Springer/Alexandrei Malikov','5114 County Road 7545','Lubbock','TX','UNITED STATES','79424','806 787 9227','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 20:00:52',0,NULL,3,1,1,1,'\\  ','navcafe\r新地址\rMark Sanders\r1215 Sage St\rFar Rockaway, NY \r11691-4842\rUnited States\r'),(9133,611952555013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mozgmisha','mozg71@gmail.com','Misha Ginzburg','P.O.B. 3145','Dimona','Dimona','ISRAEL','86000','972542659659','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 20:26:28',0,NULL,3,1,2,1,'\\ ','mozgmisha'),(9134,611961064013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','junkfinder99','junk900@aol.com','Edward Beck','2060 72nd St<br>Fl 1','Brooklyn','NY','UNITED STATES','11204-5819','(347) 426-7325','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 20:54:59',0,NULL,3,1,1,1,'\\  ','junkfinder99'),(9135,562749935004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',43,'cnfaner','spdracr4life','dodgedriver83@netscape.net','anas alyounes','126 Firth Dr','MANTUA','NJ','UNITED STATES','08051-1936','(856) 278-5607','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 21:44:19',0,NULL,3,1,1,1,'\\  ','spdracr4life'),(9136,831947168012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','ciula1970','gaetano.cannia@ch.sauter-bc.com','Schreibwaren Wagner /z.Hd. Micael.Cannia','Freiburger str. 73','Weil am Rhein','','GERMANY','D-79576','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 22:01:28',0,NULL,3,1,3,1,'RA183626005CN\r ','ciula1970\rOTSO004*2\r盒装的'),(9137,749648766011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','storehouse7','debbiebittinger@hotmail.com','Debbie  Bittinger','2404 Amish Rd','Grantsville','MD','UNITED STATES','21536-3216','(301) 895-5166','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 23:00:05',0,NULL,3,1,1,1,'\\  ','storehouse7'),(9138,749652999011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','glbgems','gvb@bestbanners.com','Gil Bresnick','7856 Sonoma Springs Cir<br>Apt 304','Lake Worth','FL','UNITED STATES','33463-7938','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-13 23:03:45',0,NULL,3,1,1,1,'\\  ','glbgems\r红边优联'),(9139,831971222012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',39.48,'eastar4','marcod9464','mdube@mediom.com','Marco Dube','257 Napoleon #2','Quebec','QC','CANADA','G1K 1T7','(418) 649-0749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 23:16:23',0,NULL,3,1,3,1,'RA183625092CN\r ','marcod9464\rMOLO006+HSUE004\r再发一个\rNew ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE\r'),(9140,749657699011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','dihydrogenmonoxid_h2o','metalgott@jesus.ch','Robin Bertram','Geissweg 17','Tübingen','','GERMANY','72076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 23:22:04',0,NULL,3,1,2,1,'\\ ','dihydrogenmonoxid_h2o'),(9141,749662269011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','feridoon1','famini@acm.org','Feridoon Amini','6448 Star Crk','Frisco','TX','UNITED STATES','75034-4897','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-13 23:42:16',0,NULL,3,1,1,1,'\\  ','feridoon1'),(9142,749665733011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',3,'BTDE2102',37.2,'eastar4','123-kirkp','ianwkirkpatrick@tiscali.co.uk','Ian Kirkpatrick','11 Oaklands Terrace, London Road<br>Kessingland','Lowestoft','Suffolk','UNITED KINGDOM','NR33 7PH','01502740157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 23:53:19',0,NULL,3,1,3,1,'RA183618940CN\r ','123-kirkp\rBTDE2102'),(9143,749672249011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','gofreddygo','gofreddygo@sbcglobal.net','Shelly Rader','3050 Pico Ave','Clovis','CA','UNITED STATES','93619','(559) 292-3365','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 00:21:42',0,NULL,3,1,1,1,'\\  ','gofreddygo'),(9144,831992084012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',107.98,'eastar4','barba43247','mkoruda@nc.rr.com','Mark Koruda','136 Carolina Forest Ct','Chapel Hill','NC','UNITED STATES','27516','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 00:35:27',0,NULL,3,1,1,1,'\\ ','barba43247\r兼容型3D眼镜 通用型'),(9145,749677290011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','2010ignacio63','rickydelf19@yahoo.com','maria de la torre','14202 village terrace dr','tampa','FL','UNITED STATES','33624-6936','(813) 802-3586','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 00:47:28',0,NULL,3,1,1,1,'\\  ','2010ignacio63'),(9146,749676956011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','todd1952','todd1952@pacbell.net','Todd V. Leone','500 12th Street - Suite 200<br>c/o Weaver Austin et al.','Oakland','CA','UNITED STATES','94607-4084','(510) 267-4105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 00:47:55',0,NULL,3,1,1,1,'\\  ','todd1952'),(9147,749679883011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','richportlandmaine','richportlandmaine@yahoo.com','Rich Fowles','33 Pierce St','South Portland','ME','UNITED STATES','04106-2114','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 00:53:51',0,NULL,3,1,1,1,'\\  ','richportlandmaine'),(9148,557297346003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','novaloy','nova1loy@hotmail.com','Myrna Jackson','18030 NW 7th Pl','Miami Gardens','FL','UNITED STATES','33169-4744','(786) 222-6155','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-14 00:55:36',0,NULL,3,1,1,1,'\\  ','novaloy'),(9149,612014602013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','jad816','winnowill@cox.net','Julie Dailey','2913 E Desert Ln','Phoenix','AZ','UNITED STATES','85042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 01:01:47',0,NULL,3,1,1,1,'\\  ','jad816\r旧的'),(9150,612012294013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',10,'HSNO019',399.9,'eastar4','artist8800','artist.sa@hotmail.com','ABDULAZIZ MASFER A ALHANA','4281 Express Ln<br>Ste L6848','Sarasota','FL','UNITED STATES','34238-2602','(941) 538-6941 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 01:02:32',0,NULL,3,1,4,1,'YW866127415CN ','artist8800'),(9151,749682080011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','vcbb10','vcbb10@gmail.com','Alex Denning','3002 W Bayview St','Wichita','KS','UNITED STATES','67204','(316) 640-8323','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 01:03:33',0,NULL,3,1,1,1,'\\ ','vcbb10'),(9152,749690076011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','k1ll4by73','killabyte@cfl.rr.com','Brian Clayberger','916 Southern Oak Ln','Apopka','FL','UNITED STATES','32712-2905','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 01:37:27',0,NULL,3,1,1,1,'\\  ','k1ll4by73'),(9153,749705214011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','mahithiyos','atiyos@yahoo.com','Atiyos Arthachinda (telephone 026195181)','1153 Soi Ronnachai 2, Tanon Nakorn Chai Sri','Samsain Nai, Payatai','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 02:48:30',0,NULL,3,1,2,1,'\\  ','mahithiyos'),(9154,832029400012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','aeiounix','ogredeschnique@hotmail.com','Alex Swanson','8213 E 60th St<br>Apt 1727','Tulsa','OK','UNITED STATES','74145-5012','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 03:08:17',0,NULL,3,1,1,1,'\\  ','aeiounix'),(9155,749713590011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','alpha_axeman','mpacker@challenger.com.au','Mark Packer','c/o Challenger<br>level 1, 27 Elizabeth St','Hobart','Tasmania','AUSTRALIA','7000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-14 03:24:58',0,NULL,3,1,3,1,'RA183618785CN\r ','alpha_axeman\r红边优联'),(9156,832036773012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.97,'eastar4','newt555','accounts@teleconnect.ca','Ed. McColough','32 Monterey Road','Kitchener','ON','CANADA','N2B 1V3','(519) 589-6500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 03:40:38',0,NULL,3,1,2,1,'\\ ','newt555'),(9157,612049240013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','mrseweiss','liznflores@yahoo.com','Elizabeth Weiss','8544 E Deershire Ct','Orange','CA','UNITED STATES','92869-5905','(714) 249-0110','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 04:29:44',0,NULL,3,1,1,1,'\\  ','mrseweiss\r黑色的'),(9158,749726715011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','jergth','jergth@yahoo.com','Jerry Guthrie','1323 County Road 18<br>Lot 2','Myrtle','MS','UNITED STATES','38650','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 04:38:00',0,NULL,3,1,1,1,'\\  ','jergth'),(9159,749731809011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','gkomardjaja','gkomardjaja2003@yahoo.com.au','gunawan komardjaja','17/2 King Street','Kogarah','New South Wales','AUSTRALIA','2217','0280333666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 05:06:35',0,NULL,3,1,2,1,'\\ ','gkomardjaja'),(9160,692814364008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','thompson0175','ma_thompson@bigpond.com','Megan Thompson','3 Coramba Street<br>North Balwoglah','Sydney','New South Wales','AUSTRALIA','2093','0299077941','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 05:14:34',0,NULL,3,1,3,1,'RA183625089CN\r ','thompson0175\r澳标\rHSPL011'),(9161,749750868011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','shawnizle','sjs1@ualberta.ca','Shawn Stochmanski','302 - 500 rue de la Montagne','Montreal','QC','CANADA','H3C 4T6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 06:54:10',0,NULL,3,1,2,1,'\\ ','shawnizle'),(9162,612078622013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','mskolnik1','dmskolnik@yahoo.com','Dyon Skolnik','8073 Pine Arbor Ln<br>Apt 203','Cordova','TN','UNITED STATES','38018-8201','(901) 921-7080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 07:55:49',0,NULL,3,1,1,1,'\\  ','mskolnik1\r不带壳的'),(9163,749773349011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','zdol2242','jon71us@yahoo.com','Zhan Dolinskiy','2111 Osprey Ave','Orlando','FL','UNITED STATES','32814-6521','(407) 644-2984','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 08:19:29',0,NULL,3,1,1,1,'\\  ','zdol2242'),(9164,832100165012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','ckuczera','ckuczera@googlemail.com','Christoph Kuczera','Dickstrasse 10a','Hennef','','GERMANY','53773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 08:24:02',0,NULL,3,1,2,1,'\\ ','ckuczera\rAcer 5pin1.25 3cm'),(9165,749781372011,320721819796,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','achurh01','anna.churhansen@adelaide.edu.au','anna chur-hansen','dept of psychiatry<br>university of adelaide','adelaide','South Australia','AUSTRALIA','5005','0882225785','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 08:47:57',0,NULL,3,1,2,1,' \\','achurh01\r蕾丝蝴蝶结伞 '),(9166,832131516012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','in2therain001','in2therain@gmail.com','Jae Myung Shim','18821 Gerkin Ave','Torrance','CA','UNITED STATES','90504-5612','(310) 750-8029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 09:49:23',0,NULL,3,1,1,1,'\\  ','in2therain001'),(9167,832139638012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','michavz','micha@sjaak.be','Micha van Zadelhoff','Oeral 146','UTRECHT','','NETHERLANDS','3524DZ','0302891234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 10:10:46',0,NULL,3,1,2,1,'\\  ','michavz'),(9168,562876468004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','fprowse','sue@prowsehouse.com','Sue Prowse','17 Thornton Drive<br>Thornlands','Brisbane','Queensland','AUSTRALIA','4164','0738207558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 10:34:24',0,NULL,3,1,3,1,'RA183618851CN\r ','fprowse\rWLAP008'),(9169,749852764011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',12,'CCGR001',82.56,'eastar4','misfer44','al_kaed__44@hotmail.com','misfer alnaimi','Asharqia Chamber - P.O.Box 719<br>Mobile: 0545277774','dammam','Eastern Province','SAUDI ARABIA','31421','+966545277774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 11:52:32',0,NULL,3,1,3,1,'RA183625115CN\r ','misfer44\rCCGR001\r'),(9170,612143073013,230641258112,'New lady lace trim sun/rain stick Umbrella pink',1,'UM00011',24.99,'eastar4','z4vor','zavor@inbox.lv','Vitalijs Zavorotnijs','ilukstes 107/3-37','Riga','','LATVIA','lv-1082','+37129297231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 12:04:26',0,NULL,3,1,2,1,'\\ ','z4vor\r蕾丝花边伞 \r粉红色的'),(9171,612155912013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','liva.vecvagare','liva_vecvagare@inbox.lv','Liva Vecvagare','E.Tise 46-18','Liepaja','LV','LATVIA','3411','+37128248339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 12:49:22',0,NULL,3,1,2,1,'\\  ','liva.vecvagare\r韩版透明伞'),(9172,832221800012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','parallelint','iphlex@gmail.com','Chen Howard','公道五路二段60巷8-1號','新竹市','','TAIWAN','300','0988502396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 13:17:39',0,NULL,3,1,2,1,'\\ ','parallelint'),(9173,745754757011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',10,'BR3D001',320,'eastar4','3d_aquamix','aquamix_3d@tpg.com.au','Mariusz Herok','49 Taunton Dr','CHELTENHAM','Victoria','AUSTRALIA','3192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 13:40:55',0,NULL,3,1,4,1,'YW866127404CN ','3d_aquamix'),(9174,832243751012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','thrakor','francisgag@yahoo.ca','Francis Gagnon','275 Beaubien','Rivière-du-Loup','QC','CANADA','G5R5L9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 14:01:31',0,NULL,3,1,3,1,'RA183625937CN\r ','thrakor\rOTSO004*2\r盒装的'),(9175,832261508012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','urcybermol2','nhmahiya@yahoo.com','Nestor H. Mahiya','144 Lake St','Ramsey','NJ','UNITED STATES','07446-2010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 14:35:02',0,NULL,3,1,1,1,'\\  ','urcybermol2'),(9176,749926927011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','ltvtyrj','sashik58@mail.ru','Александр Деменко','Орбитовская, 26','Сочи','','RUSSIAN FEDERATION','354340','(918)407-2486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 14:36:53',0,NULL,3,1,2,1,'\\ ','ltvtyrj\r欧标'),(9177,612194604013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','cantfind267','cantfindmykeys@hotmail.com','Shannon Lude','6745 e 1000 n','ossian','IN','UNITED STATES','46777','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 14:43:56',0,NULL,3,1,1,1,'\\ ','cantfind267\r红边优联'),(9178,749935946011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','ivangaza','ivan.gaza@gmail.com','Ivan Gaza','Aliancia Fair-play<br>Zapadny rad 39','Bratislava','','SLOVAK REPUBLIC','81104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 14:54:14',0,NULL,3,1,2,1,'\\ ','ivangaza\r二代卡 旧'),(9179,749956939011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','dymon1978','steelman2000@mail.ru','Dmitriy Barablin','Urvanceva st 6/66','Krasnoyarsk','RU','RUSSIAN FEDERATION','660118','+79232831345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 15:31:56',0,NULL,3,1,2,1,'\\  ','dymon1978\r欧标'),(9180,832300462012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','bad1979','andy@bad79.karoo.co.uk','Andrew Dinsdale','8 Enstone Garth','Hull','East Yorkshire','UNITED KINGDOM','HU7 4LF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 15:41:15',0,NULL,3,1,3,1,'RA183625234CN\r ','bad1979\rOTHP003'),(9181,832302965012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','shoaibsarwar2010','mohammadshoaib.sarwar@yahoo.com','Shoaib Sarwar','61 Kitchner Road','High Wycombe','Buckinghamshire','UNITED KINGDOM','HP11 2SH','07412171591','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 15:45:52',0,NULL,3,1,3,1,'RA183625177CN\r ','shoaibsarwar2010\rHSSE005\r英标'),(9182,832313837012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','silvang123','pcl1962@hotmail.co.uk','Silvio Pignone','101 Rickmansworth Rd','Pinner','Middlesex','UNITED KINGDOM','HA5 3TJ','07957444119','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 16:03:30',0,NULL,3,1,3,1,'RA183625194CN\r ','silvang123\rHSMO018\r英标'),(9183,832319335012,220501826380,'2.1 Bluetooth Module + Cable for acer aspire D150',1,'BTAC2119',12.4,'eastar4','delikatesseen_mx','nurivan_g@hotmail.com','JIMENA castello','av. tenorios #91 depto 25b','mexico df','distrito federal','MEXICO','14300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 16:12:38',0,NULL,3,1,2,1,'\\ ','delikatesseen_mx\racer 8pin 1.0 5cm (4连线\r\r '),(9184,749989015011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','dopanina','e.gras@airenetworks.es','Emilio Gras Cortes','Principe de Asturias 4. Ent:A-B<br>Aire Networks','Elda','Comunidad Valenciana','SPAIN','03600','656907917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 16:22:23',0,NULL,3,1,3,1,'RA183618848CN\r ','dopanina\rUDAP001'),(9185,749990722011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','alihangullu','emperor1453@yahoo.com','Alihan Güllü','**HOTEL SULTAN\'S INN**<br>Kucukayasofya Mh. Mustafapasa Sk. No:50','Sultanahmet','ISTANBUL','TURKEY','34122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 16:29:39',0,NULL,3,1,2,1,'\\  ','alihangullu'),(9186,832355806012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','spookyroos','spooky1@zonnet.nl','Nico Roos','Westkade 51','HELLEVOETSLUIS','','NETHERLANDS','3221AV','0181317854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 17:00:40',0,NULL,3,1,3,1,'RA183625910CN\r ','spookyroos\rOTSO004*2\r盒装的'),(9187,832355616012,220807319942,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4','donna5106','david.dudley4@btopenworld.com','Donna Dudley','24 Lime Grove Ramsbottom','Bury','Lancashire','UNITED KINGDOM','BL0 0BD','01706827721','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-14 17:00:49',0,NULL,3,1,2,1,'\\ ','donna5106\r钢琴美女伞 '),(9188,563007746004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','prvzv','aprvzv@gmail.com','Aleksandr Pereverzev','Leningradskoye shosse, 94-1-24','Moscow','RU','RUSSIAN FEDERATION','125565','+79161453361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 17:04:21',0,NULL,3,1,3,1,'RA183618953CN\r ','prvzv\rWWOT003+ANCN001'),(9189,832404130012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','redelmo70','aschoene@live.com','Axel Schoene','Roemerstr. 45','Mannheim','','GERMANY','68259','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 17:54:29',0,NULL,3,1,3,1,'RA183625999CN\r ','redelmo70\r盒装的\rOTSO004*2'),(9190,831317363012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',21.99,'eastar4','3-no-trumps','raza.maqsud@dsl.pipex.com','Raza Maqsud','85 Friars Close<br>Leeds Road','Ilford','Essex','UNITED KINGDOM','IG1 4AZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 18:18:58',0,NULL,3,1,2,1,'\\  ','3-no-trumps'),(9191,832435116012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','cheungc2006','johnchang8899@yahoo.com','Cheung Chang','168 W Longden Ave','Arcadia','CA','UNITED STATES','91007-8231','(626) 278-5170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 18:24:53',0,NULL,3,1,1,1,'\\  ','cheungc2006'),(9192,750095014011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','roger7766','griffiths429@btinternet.com','Roger Griffiths','16 Ashbourne Court','Aberdare','Rhondda Cynon Taff','UNITED KINGDOM','CF448HA','01685882002','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 18:31:58',0,NULL,3,1,3,1,'RA183619004CN\r ','roger7766\r红边优联\rRELO003'),(9193,563070769004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','lobe-bay','lobe.lobe@gmail.com','Jose Manuel Mancebo Blanco','C/ Alberes nº47','Pont de Molins','Cataluña','SPAIN','17706','620901478','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 18:50:22',0,NULL,3,1,3,1,'RA183618998CN\r ','lobe-bay\rOTRA001'),(9194,831157283012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','unklematt604','unklematt@gmail.com','Matthew Sawasy','Unit 209<br>2818 Main Street','Vancouver','BC','CANADA','V5T0C1','(604) 644-5578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 19:17:12',0,NULL,3,1,3,1,'RA183625058CN\r ','unklematt604\rMOLO002'),(9195,832491283012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'eastar4','liosnagcrann','bappledore@yahoo.com','Chris O\'Connell','346 N Long Beach Rd','Rockville Centre','NY','UNITED STATES','11570-3120','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 19:33:57',0,NULL,3,1,1,1,'\\  ','liosnagcrann\r兼容型3D眼镜 通用型'),(9196,750136160011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jboe8497','jimboese@sbcglobal.net','jim boese','3447 E 84th Pl','tulsa','OK','UNITED STATES','74137-1710','(918) 494-7620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 19:19:50',0,NULL,3,1,1,1,'\\  ','jboe8497'),(9197,563099117004,140583359050,'New in box Jabra BT-2080 Wireless Bluetooth Headset',1,'HSJA005',17.9,'cnfaner','gershwin20','gershwin@zahav.net.il','Gershon Shamir','Sho\'ham 27','Kfar-Yona','Israel','ISRAEL','40300','+972-54-6620857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 19:43:23',0,NULL,3,1,3,1,'RA183625248CN\r ','gershwin20\rHSJA005'),(9198,750176325011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','buckwheat50','shugan@optonline.net','Robert M. Shugan','14 Totten Dr','Bridgewater','NJ','UNITED STATES','08807-2367','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 20:18:50',0,NULL,3,1,1,1,'\\ ','buckwheat50'),(9199,749674001011,320590826661,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',119,'eastar4','pat_singer','singer.patrick@free.fr','Patrick SINGER','9 bis rue Lamartine','Saint Remy Les Chevreuse','Île-de-France','FRANCE','78470','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 20:25:52',0,NULL,3,1,3,1,'RA183625336CN\r ','pat_singer\rRCMA001'),(9200,557641623003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',2,'HSNO016',30.8,'cnfaner','mckastner','markuskastner82@web.de','Firma Tornier  (z.h. Herr Kastner)','Industriestr. 48','Burscheid','','GERMANY','51399','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 20:36:42',0,NULL,3,1,3,1,'RA183625203CN\r ','mckastner\r欧标\rHSNO016'),(9201,832540075012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','marceloperusso','mperusso@terra.com.br','marcelo perusso','rua antonio francisco lisboa nº 265','porto alegre','Rio Grande do Sul','BRAZIL','91180-040','+555133669632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 20:36:56',0,NULL,3,1,2,1,'\\ ','marceloperusso\rAcer 5pin1.25 3cm'),(9202,612380432013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',83.99,'eastar4','shlomikakon','shlomik@scepia.com','shlomi kakon','natan elbaz<br>19','sderot','IL','ISRAEL','80100','0528432840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 20:43:59',0,NULL,3,1,3,1,'RA183625340CN\r ','shlomikakon\rMOSA005'),(9203,832545582012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','bowledforaduck','mmtw@blueyonder.co.uk','M M T Ward','16 Oakhall Drive<br>Dorridge','Solihull','West Midlands','UNITED KINGDOM','B93 8UA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 20:45:16',0,NULL,3,1,3,1,'RA183625217CN\r ','bowledforaduck\rOTGR001'),(9204,750199685011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','ultima80','surf02@aliceadsl.fr','DEVOGE Patrice','Residence Les Templiers, Bt A<br>45 avenue St Philippe','BIOT','Provence-Alpes-Côte d\'Azur','FRANCE','06410','0492389455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 21:01:20',0,NULL,3,1,2,1,'\\ ','ultima80'),(9205,612387585013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','maorshitrit11','maor.shitrit@gmail.com','Maor Shitrit','58 Senkin Str.','Givataim','IN','ISRAEL','53304','+972508679663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 21:02:36',0,NULL,3,1,2,1,'\\ ','maorshitrit11\rCAB-6060'),(9206,563137853004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','729367','vevey@mail.ru','Vladimir Luzhnikov','Novoizmailovsky 39/2 fl.57','Saint-Petersburg','RUSSIA','RUSSIAN FEDERATION','196247','9112117111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 21:24:02',0,NULL,3,1,3,1,'RA183618865CN\r ','729367\rOTRA001'),(9207,612404404013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','guymeng2010','gchartsak@gmail.com','Guy Chartsak','מנחם בגין 27','קרית מוצקין','','ISRAEL','26231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 21:52:22',0,NULL,3,1,2,1,'\\ ','guymeng2010\r黑色的'),(9208,750233347011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','ddix9803','deredfire1967@hotmail.com','Dennis Dixon','566 Koerber','Akron','OH','UNITED STATES','44314','(330) 431-9255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 22:17:13',0,NULL,3,1,1,1,'\\  ','ddix9803'),(9209,832591612012,220674187115,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',7.9,'eastar4','joe8343477','gong8646@yahoo.com','Joe Gong','384 8th St','Oakland','CA','UNITED STATES','94607','(510) 325-8173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 22:39:04',0,NULL,3,1,1,1,'\\  ','joe8343477\r旧的'),(9210,612420190013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','mkovach2316','matt.kovach8@gmail.com','Matt Kovach','870 Honeysuckle Dr','Centerton','AR','UNITED STATES','72719','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 22:46:39',0,NULL,3,1,1,1,'\\  ','mkovach2316'),(9211,693296587008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','sylvred','stevendsou@hotmail.com','Steven D\'Souza','31 Investigator street','Red Hill','Australian Capital Territory','AUSTRALIA','2603','0262953668','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 23:30:18',0,NULL,3,1,3,1,'RA183625296CN\r ','sylvred\rHSPL015\r澳标'),(9212,832618874012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',53.89,'eastar4','taunsvian','s_tariq_mehmood@yahoo.com','Tariq Mahmood','GE Energy<br>Bldg 1503, Rd 1161','Al-Musalla 411','Manama','BAHRAIN','10252','(009) 733-9610 ext.: 599','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-14 23:39:40',0,NULL,3,1,3,1,'RA183625588CN\r ','taunsvian\rWWOT003'),(9213,750267760011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','paulrr','paulriscalla@mac.com','Paul Riscalla','4821 River Ave','Newport Beach','CA','UNITED STATES','92663-2409','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 00:03:34',0,NULL,3,1,1,1,'\\  ','paulrr'),(9214,693311239008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',63.99,'au-buy','mikosystem2009','mikosystem@gmail.com','Thomas Michael','302-711 East 6th Ave','Vancouver','BC','CANADA','V5T1L7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-15 00:09:27',0,NULL,3,1,3,1,'RA183625185CN\r ','mikosystem2009\rHBPH002'),(9215,750274124011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','techspringclean','onlinesalesemails@googlemail.com','Mehmood Khan','3 Swanley House<br>Grant Road,','Wealdstone, Harrow','Middlesex','UNITED KINGDOM','HA37SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 00:20:45',0,NULL,3,1,3,1,'RA183618794CN\r ','techspringclean\rUDAP001'),(9216,832636264012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',53.99,'eastar4','littlebuyer21','jsaxon@ij.net','James Saxon','7413 SW 99th Ave','Ocala','FL','UNITED STATES','34481-2576','(727) 409-7423','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 00:21:31',0,NULL,3,1,1,1,'\\  ','littlebuyer21\r兼容型3D眼镜 通用型'),(9217,563185320004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','cocosan72','druiditas@hotmail.com','Jose Antunez Mellado','C/ Narciso Monturiol, Nº 2','Alcala de Henares','Madrid','SPAIN','28806','629825695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 00:40:59',0,NULL,3,1,3,1,'RA184551762CN\r ','cocosan72\rWLAP008'),(9218,750282016011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','davewebertx','davewebtx@att.net','Dave Weber','2634 Morgan Ann Ave','Mansfield','TX','UNITED STATES','76063-3728','(817) 453-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 00:46:07',0,NULL,3,1,1,1,'\\  ','davewebertx'),(9219,557711631003,130553375752,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'cnfaner','mawaza','w.zafar@t-online.de','Mahmud Wali Zafar','Gürzenicher Str. 142','Düren','','GERMANY','52355','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 01:17:12',0,NULL,3,1,3,1,'RA183625061CN\r ','mawaza\rHSNO026\r欧标'),(9220,832671723012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','kpbrazil','kp.comercial@gmail.com','Kilder Pires / Citrovita','Rodovia Comendador Pedro Monteleone Km 206,5 - Zona Rural<br>Caixa Postal 153','Catanduva','São Paulo','BRAZIL','15804-500','005501135316097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 01:57:17',0,NULL,3,1,2,1,'\\ ','kpbrazil'),(9221,750320927011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','az_eagle','gene@logixwiz.com','Gene A. Underwood','17708 W Maui Ln','Surprise','AZ','UNITED STATES','85388-7553','(928) 778-3569','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 02:41:31',0,NULL,3,1,1,1,'\\  ','az_eagle'),(9222,612493870013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','wcwchen','wcwchen@seed.net.tw','WILLIAM CHEN','4742 Centre Ave<br>Apt 506','Pittsburgh','PA','UNITED STATES','15213-1733','(215) 917-3878','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 03:27:24',0,NULL,3,1,1,1,'\\  ','wcwchen'),(9223,8881313384118280,111,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',0,'eastar4uk','harper57bl','brucicle@optusnet.com.au','Bruce Lemin','19 Boas Place','Florey','Australian Capital Territory','AUSTRALIA','2615','0261562080',NULL,NULL,NULL,'2011-08-15 04:55:18',0,NULL,3,1,2,1,'\\ ','补发的\r只补发耳机 \rHSMO018'),(9224,750364109011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','0kaz','kasper2004@gmail.com','Slavek Kasper','201 W Dyer Rd<br>Ste C','Santa Ana','CA','UNITED STATES','92707-3426','(714) 957-1757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 06:22:44',0,NULL,3,1,1,1,'\\ ','0kaz'),(9225,750366273011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','toasted_cheezer','photographyfromdick@yahoo.com','john brannin','2016 raven','lewisville','TX','UNITED STATES','75077','(469) 671-1952','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 06:33:55',0,NULL,3,1,1,1,'\\ ','toasted_cheezer'),(9226,563245595004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','ihsanevren','evrenaltin@gmail.com','EROL UĞUR PINAR','MELİKE SK.<br>NO:32/6 İNCİRLİ','KEÇİÖREN','ANKARA','TURKEY','06000','+905546410393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 06:42:16',0,NULL,3,1,3,1,'RA183625906CN\r ','ihsanevren\rHSNO022'),(9227,557768892003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','ebenzer','diplomodena@naver.com','seung hwan shin','Seolim-Dong 103-171 3rd floor','KwanAk-Gu','Seoul','KOREA,REPUBLIC OF','151-856','(010) 908-9888 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 07:21:55',0,NULL,3,1,3,1,'RA183625870CN\r ','ebenzer\rWLAT007'),(9228,832754221012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','byck132','byck123@naver.com','seulgi lee','gaebong 2 dong 332-3<br>somang billa 401 ho','seoul','seoul gurogu','KOREA,REPUBLIC OF','152-092','010 8827 0489','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 07:38:41',0,NULL,3,1,2,1,'、 ','byck132'),(9229,8881313395112210,111,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',0,'cnfaner','hue_bui','anhuebui@hotmail.com','Anna Nguyen','16 Morven St','Old Guildford','New South Wales','AUSTRALIA','2161','',NULL,NULL,NULL,'2011-08-15 07:58:32',0,NULL,3,1,3,1,'RA183625866CN\r ','补发的 \rHSUE004'),(9230,750385881011,320730088816,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',5,'HSJA009',749.95,'eastar4uk','superpulpfiction','mario.kaufmann.sz@bluewin.ch','Prime21 AG','Mario Kaufmann<br>Baarerstrasse 77','Zug','','SWITZERLAND','6300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 08:05:09',0,NULL,5,0,18,0,' ','superpulpfiction\r欧标\rHSJA009'),(9231,562368439004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'cnfaner','army-k','armykcz@gmail.com','Jiří Jezdinský','Kladenská 833','Přelouč','','CZECH REPUBLIC','53501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 08:10:58',0,NULL,3,1,3,1,'RA183625883CN\r ','army-k\rCACN004'),(9232,612537653013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',3,'WLAT001',41.97,'eastar4','hadley.rich','hads@nice.net.nz','Hadley Rich','56 Matai Crescent<br>Highfield','Timaru','South Canterbury','NEW ZEALAND','7910','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 08:31:24',0,NULL,3,1,3,1,'RA183625954CN\r ','hadley.rich\rWLAT001'),(9233,750392275011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',3,'WLAP002',48,'eastar4','depolr','depolr@st.hinet.hr','Riccardo De Pol','Valpovacka 2','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 08:31:30',0,NULL,3,1,3,1,'RA183625897CN\r ','depolr\rWLAP002\r二代卡旧的'),(9234,832771159012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.95,'eastar4uk','daotley','nightwatch@daotley.co.uk','Patrick Atherton','Digital Activities Otley ltd<br>Westgate arcade, westgate','Otley','West Yorkshire','UNITED KINGDOM','LS21 3AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 08:43:05',0,NULL,3,1,3,1,'RA183625818CN\r ','daotley\rBALO007'),(9235,832777057012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','evanelion','evanelion_infinite@hotmail.com','Javier Suárez Domínguez','C/Andalucía nº 36 bloque A 2ndo Izquierda','Andratx (Mallorca)','Baleares','SPAIN','07150','900000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 09:07:38',0,NULL,3,1,2,1,'\\ ','evanelion'),(9236,612548518013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','lee22_13','ljlig1@student.monash.edu','Lee Ligtermoet','13 Kilvington Dr','Emerald','Victoria','AUSTRALIA','3782','0418323089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 09:34:16',0,NULL,3,1,2,1,'\\ ','lee22_13\rCACN004'),(9237,612552217013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','loud_whisper','rozhkov@dvblab.com','Alexander Rozhkov','c/Virgen de la Paloma 34 BIS 4-1','Torrevieja','Comunidad Valenciana','SPAIN','03182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 09:56:26',0,NULL,3,1,2,1,'\\ ','loud_whisper'),(9238,750421461011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','58davidm','davidmacdonald100@hotmail.com','David MacDonald','805-151 Parkdale Ave.','Ottawa','ON','CANADA','K1Y 4V8','(613) 235-4902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 10:29:28',0,NULL,3,1,3,1,'RA183625415CN\r ','58davidm\rHBPH002'),(9239,750427576011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',179.99,'eastar4','cupniiserghei','koupny@gmail.com','Cupnii Serghei','Mircea cel Batrin 22/2 ap.57','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2044','+37369540982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 10:51:02',0,NULL,3,1,3,1,'RA183625543CN ','cupniiserghei\rOTSO004*3\r盒装的'),(9240,750174728011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',64,'eastar4','hergenroderjacint','hergenroder@freemail.hu','Megyes József','Megyes József<br>Szárnyas urca 20/b','Budapest','','HUNGARY','1107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 10:54:25',0,NULL,3,1,3,1,'RA183625509CN\r ','hergenroderjacint\rWLAP002\r二代卡 旧\r一共买了四个'),(9241,563287277004,140519339941,'New Jabra BT320s StereoBluetooth Clip-On Earbud Headset',2,'HSJA003',47.4,'cnfaner','galay2007','egalay@gmail.com','eran galay','hilel zechria 20','petach tikva','','ISRAEL','49573','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 10:55:58',0,NULL,3,1,3,1,'RA183625398CN\r ','galay2007\rHSJA003'),(9242,750430500011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',33.99,'eastar4uk','michaelsmith76','groundfault@hotmail.co.uk','Mick Smith','92 Briscoe Road','Rainham','Essex','UNITED KINGDOM','RM139QG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 11:00:18',0,NULL,3,1,3,1,'RA183625557CN\r ','michaelsmith76\rGLOT001\r兼容型3D眼镜 通用型'),(9243,832812341012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','14chrisl','chris@lightsmith.com','Lightsmith','559 Humboldt Avenue','Saint Paul','MN','UNITED STATES','55107-2916','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 11:07:37',0,NULL,3,1,1,1,'\\ ','14chrisl'),(9244,832814542012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.4,'eastar4','farmageddon_va','james.fischer@gmail.com','James Fischer','340 E 93rd St<br>Apt 27C','New York','NY','UNITED STATES','10128-5549','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 11:14:46',0,NULL,3,1,1,1,'\\ ','farmageddon_va\rS10-2 8pin 1.0 8cm 五线连接'),(9245,750445587011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','astro325','astrobmw@gmail.com','Mark Wilson','6 Lloyd George Ave','Concord','New South Wales','AUSTRALIA','2137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 11:53:00',0,NULL,3,1,2,1,'\\ ','astro325'),(9246,563300040004,140550602373,'New APPLE iMac G6 Bluetooth Wireless Keyboard',1,'KBAP003',68.99,'cnfaner','shabparvosoogh','alavi.afshin@gmail.com','afshin alavi','Øvre Eikervei 116C','Drammen','','NORWAY','3048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 12:01:50',0,NULL,3,1,3,1,'RA183625472CN\r ','shabparvosoogh\rKBAP003'),(9247,750451748011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','tipubhai2010','m_sraza@hotmail.com','Muhammad Shahid Raza','36<br>hardy road','Ashfield Perth','Western Australia','AUSTRALIA','6054','0402456010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 12:20:57',0,NULL,3,1,2,1,'\\ ','tipubhai2010\r澳标'),(9248,750457365011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','admi78rus','admi78@mail.ru','Victor Rozhkov','Bogatirskii d.30, korp.1, kv.69','Saint Petersburg','Saint Petersburg','RUSSIAN FEDERATION','197372','812-716-4642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 12:32:38',0,NULL,3,1,3,1,'RA183625486CN ','admi78rus\rOTSO004\r盒装的'),(9249,750464713011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',179.99,'eastar4','anarun06','saturnin-974@hotmail.com','Cedric BOYER','27 chemin d\'Esparron','AIGUES MORTES','Languedoc-Roussillon','FRANCE','30220','04.66.53.72.60.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 13:01:07',0,NULL,3,1,3,1,'RA183625530CN ','anarun06\rOTSO004*3\r盒装的'),(9250,832850192012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',104.95,'eastar4','lawdoc819','jimbo2468@aol.com','James Bopp','41 N Suffolk Dr','Rocky Point','NY','UNITED STATES','11778-9225','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 13:01:12',0,NULL,3,1,1,1,'\\ ','lawdoc819\r兼容型3D眼镜 通用型'),(9251,832851896012,220807272244,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','sniper_40','pbailey@civica.com.au','Paul Bailey','c/- Civica Computers Pty Ltd<br>96 Lambton Road','BROADMEADOW','New South Wales','AUSTRALIA','2292','61448223801','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 13:06:24',0,NULL,3,1,2,1,'、 ','sniper_40\r向日葵长柄伞  '),(9252,832854170012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','metasy','armin@maglo.de','Armin Bührer','Schulstr.11','Malterdingen','','GERMANY','79364','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 13:12:27',0,NULL,3,1,2,1,'\\ ','metasy\r4pin 1.25 '),(9253,750471893011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','clever4auction','purchasing@clever4.net','Chris Peacock','Clever4 Limited<br>2 Bridge View, Henry Boot Way','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU4 7DW','01482575544','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 13:18:18',0,NULL,3,1,3,1,'RA183625455CN\r ','clever4auction\rMOAP001'),(9254,612596048013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',10,'WWSI005',369.9,'eastar4','thefunhouse81','marco.gacharich@hotmail.com','marco nazareth gacharich','9500 NW 77th Ave<br>Ste 14','hialeah','FL','UNITED STATES','33016-2522','(786) 220-4615','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-15 13:23:20',0,NULL,3,1,4,1,'YW866127441CN ','thefunhouse81'),(9255,557845022003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','rjgallagher253','rjgallagher206@att.net','Roger J. Gallagher','7990 Woods Edge Ct','Mentor','OH','UNITED STATES','44060','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-15 14:05:21',0,NULL,3,1,1,1,'\\ ','rjgallagher253'),(9256,711199751001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','dsect','restemey@bellatlantic.net','William Restemeyer','240 W 98th St<br>Apt 11C','New York','NY','UNITED STATES','10025-5516','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 14:20:01',0,NULL,3,1,1,1,'\\ ','dsect'),(9257,612611954013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',89.4,'eastar4','junkfinder99','junk900@aol.com','Edward Beck','2060 72nd St<br>Fl 1','Brooklyn','NY','UNITED STATES','11204-5819','(347) 426-7325','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 14:27:59',0,NULL,3,1,1,1,'\\ ','junkfinder99'),(9258,750507080011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','thriftynobucks','diana_rieck@hotmail.com','Diana Rieck','4776 The Bench Road','Windermere','BC','CANADA','V0B 2L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 15:40:38',0,NULL,3,1,2,1,'\\ ','thriftynobucks'),(9259,612631010013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',46.99,'eastar4','allegrowireless','allegro-ebay@allegrowireless.com','Gehad Alhundi','2350 Matheson Blvd. East','Mississauga','ON','CANADA','L4W5g9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 15:48:04',0,NULL,3,1,3,1,'RA183625441CN\r ','allegrowireless\rWWSI004+ANCN001'),(9260,750524936011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','ssouzzza','souzzza@yahoo.com.br','Sandro Souza','Rua dos economistas<br>977','São Paulo','São Paulo','BRAZIL','03726-060','55 11 8611 1950','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 15:49:42',0,NULL,3,1,2,1,' \\','ssouzzza\r红边优联'),(9261,750524367011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','33region','kolpakov921@gmail.com','Dmitry Kolpakov','Sovetskaya 29A-24','Murom','Vladimirskaya oblast`','RUSSIAN FEDERATION','602267','+79209011044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 15:49:58',0,NULL,3,1,2,1,'\\ ','33region\r欧标'),(9262,557060935003,130557217270,'GENUINE PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',32.99,'cnfaner','teopoh','teopoh71@gmail.com','Edwin Teo','blk 549 bedok North Avenue one # 08 – 462','default','','SINGAPORE','460549','94761334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 16:27:36',0,NULL,3,1,3,1,'RA183625490CN\r ','teopoh\rHSPL014'),(9263,750548134011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','axame72','aamelingmeyer@gmx.de','Axel Amelingmeyer','Leyerstr.150','Osnabrück','','GERMANY','49076','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 16:48:07',0,NULL,3,1,3,1,'RA183625526CN ','axame72\rOTES001\rESI maya44 声卡'),(9264,611225575013,230622403729,'New Philips SHB6102 Bluetooth Stereo Headset  ',1,'HSPH001',74.9,'eastar4','israelshoper','williamsakum@yahoo.com','Akum Williams','3 Abuhatzeira<br>Apartment 12','bene beraq','','ISRAEL','51291','0545653533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 16:56:25',0,NULL,3,1,3,1,'RA183625512CN ','israelshoper\rHSPH001\r美标'),(9265,612654260013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','mart-side','mcote@maxiflamme.com','Martin Cote','444 rue Réjean','St-Michel','QC','CANADA','J0L 2J0','(450) 454-7722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 16:58:29',0,NULL,3,1,2,1,'\\ ','mart-side\r银色的'),(9266,711266113001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',16,'buysia','brunononono','brunoricciardi@gmail.com','Bruno Ricciardi','R. Frei Luis Alevato, 1237 bl4  404 ou 504<br>,Taquara','Rio de Janeiro','Rio de Janeiro','BRAZIL','22710-325','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 17:24:17',0,NULL,3,1,3,1,'RA183625375CN\r ','brunononono\rBR3D008'),(9267,750578288011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','johnv9456','jvota@aol.com','John Vota','320 Old Route 304','New City','NY','UNITED STATES','10956-5718','(914) 588-2849','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 17:53:05',0,NULL,3,1,1,1,'\\ ','johnv9456\r二代卡 旧'),(9268,612683595013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',74.97,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Anmahian Winton Architects 			 Cambridge, MA 02','650 Cambridge St','Cambridge','MA','UNITED STATES','02141-1143','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 18:22:55',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9269,612685315013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','George Sakaguchi','5253 LANKERSHIM BLVD<br>EXTASY RECORDING STUDIO','North Hollywood','CA','UNITED STATES','91601-3111','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 18:28:12',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9270,612686685013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Sharon McKinney','Institutional Compliance, UH4, Ste 300, Rm 1.404<br>One UTSA Circle','San Antonio','TX','UNITED STATES','78249','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 18:32:14',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9271,833006608012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','duranshandz','duranshands@googlemail.com','Loren Lim','152 highstreet ruislip','ruislip','Middlesex','UNITED KINGDOM','ha4 8lj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 18:47:38',0,NULL,3,1,3,1,'RA183625469CN\r ','duranshandz\rOTSO004*2\r盒装的'),(9272,750608760011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','carolscubadiver','ckerryscubadiver@hotmail.co.uk','carol kerry','5 moor knoll close, east ardsley','nr wakefield','West Yorkshire','UNITED KINGDOM','WF32AZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 18:51:31',0,NULL,3,1,3,1,'RA183625424CN\r ','carolscubadiver\rHSPL010\r英标'),(9273,557928877003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',51.8,'cnfaner','abelevyoury30vk','georgey@bgu.ac.il','Youry Abelev','Ha-Melahim 41','Beer-Sheva','ISRAEL','ISRAEL','84510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 19:19:38',0,NULL,3,1,3,1,'RA184557249CN ','abelevyoury30vk\rWWSI002+ANCN001+HSJA005\r再发一个\rNew in box Jabra BT-2080 Wireless Bluetooth Headset\r'),(9274,612711265013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Johan B Klassen','509 NW AVENUE G','Seminole','TX','UNITED STATES','79360-2640','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:34:35',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9275,612712666013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Eric Martin','843 S Los Angeles St<br>The Park LA','Los Angeles','CA','UNITED STATES','90014-3307','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:37:47',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9276,750495268011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.5,'eastar4','gamjo06','crashpoint2@gmail.com','Gaute Mjøen','Kløversvingen 18','KONGSBERG','','NORWAY','3612','4741421509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 19:46:21',0,NULL,3,1,2,1,'\\ ','gamjo06'),(9277,612717455013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','carlos de obaldia','17885 Collins Ave<br>Apt 1902','Sunny Isles Beach','FL','UNITED STATES','33160-3173','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:49:42',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9278,612718598013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Justin Clapp','Duke University Undergrad. Financial Aid (90397)<br>2127 Campus Drive Annex','Durham','NC','UNITED STATES','27708','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:52:30',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9279,612719543013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Michael M. Anderson','9312 SE Sherrianne Ct<br>Apt 1','Milwaukie','OR','UNITED STATES','97222-1336','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:54:59',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9280,750642521011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','nzmkirka','michael.kirkaldy@gmail.com','Michael Kirkaldy','3 Tregear Place<br>Camborne','Porirua','Wellington','NEW ZEALAND','5026','+64 277548946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 19:55:47',0,NULL,3,1,2,1,'\\ ','nzmkirka'),(9281,833046423012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','slappyjaw','me@slappyjaw.com','Gregory Jordan','35 Laurelwood Dr','North Attleboro','MA','UNITED STATES','02760-2704','(508) 695-3406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 19:56:03',0,NULL,3,1,1,1,'\\ ','slappyjaw'),(9282,750656072011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',45.8,'eastar4','nitromet1','hoakster@live.com','Ron Biekx','Grand Bend Motorplex<br>70292 Grand Bend Line, Highway 81 East, Grand Bend Airport','Grand Bend','ON','CANADA','N0M 1T0','(519) 238-7223 ext.: 26','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 20:21:44',0,NULL,3,1,3,1,'RA183625384CN\r ','nitromet1\rHSSE004'),(9283,833062913012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','vecokc385','vecokc@gmail.com','Davor Vecenaj','Vinica 228','Koprivnica','Croatia','CROATIA','48000','+385913172173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 20:25:39',0,NULL,3,1,2,1,'\\ ','vecokc385'),(9284,612738623013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','anton2865','arny2865@orange.nl','anton de graaf','Achterweg 46','AMMERSTOL','','NETHERLANDS','2865XG','0182351981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 20:47:05',0,NULL,3,1,2,1,' \\','anton2865\r不带壳的'),(9285,711377864001,110728499418,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','leonmerlin0','bednarzyk@web.de','Benedikt Bednarzyk','Fichtenweg 4','Schleiden','','GERMANY','53937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 21:32:00',0,NULL,3,1,3,1,'RA183625438CN\r ','leonmerlin0\rHSBS002\r欧标'),(9286,750691426011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','zynchnod','d_mingo@yahoo.com','Gordon Nickerson','#8 - 23 Birch Street','Beford','NS','CANADA','B3N 2T8','(902) 402-6793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 21:43:07',0,NULL,3,1,2,1,'\\ ','zynchnod'),(9287,750693984011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','kajzer','zljubisic@gmail.com','Zoran Ljubisic','IX Podbrežje 2','Zagreb','','CROATIA','10020','+385992316073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 21:49:33',0,NULL,3,1,2,1,'\\ ','kajzer'),(9288,711395660001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','emilym4004','happybunny2@comcast.net','Roxanne Goulet','75 Briar Way','Greenfield','MA','UNITED STATES','01301-3851','(413) 475-3266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 22:16:27',0,NULL,3,1,1,1,'\\ ','emilym4004'),(9289,563477847004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','tonecat44','trome1@att.net','tonie nesbitt','6411 Van Buren Ave','hammond','IN','UNITED STATES','46324','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-15 22:30:44',0,NULL,3,1,1,1,'\\ ','tonecat44'),(9290,612768064013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Laureen Antes','19 Chapelridge Cir<br>Apt A','Marion','IA','UNITED STATES','52302-7260','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 22:33:00',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9291,612769112013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','William Bohnhoff','153 S Van Nortwick Ave','Batavia','IL','UNITED STATES','60510-2444','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 22:37:02',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(9292,750711834011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','ferret1964','ferret@stormwoods.com','Jerry E Goodnough','775 Foothill Dr','Eugene','OR','UNITED STATES','97405-4651','(541) 338-4911','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 22:42:23',0,NULL,3,1,1,1,'\\ ','ferret1964'),(9293,750721641011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','ocirvine','compuadmin@gmail.com','GK','58 Avignon Ave','Foothill Ranch','CA','UNITED STATES','92610-1909','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 23:19:14',0,NULL,3,1,1,1,'\\ ','ocirvine'),(9294,750734168011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','dallasnorton','dallaslandonnorton@gmail.com','Kirsti Harris','551 N 200 E<br>Apt 207','Provo','UT','UNITED STATES','84606-2734','(330) 671-1395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 00:09:05',0,NULL,3,1,1,1,'\\ ','dallasnorton'),(9295,748368181011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','thepeddlersdaughter','cdussik@mnrubber.com','Cathy Dussik','2027 Chester St','shakopee','MN','UNITED STATES','55379-4375','(952) 233-1047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 00:25:39',0,NULL,3,1,1,1,'\\ ','thepeddlersdaughter'),(9296,750746076011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','prfstein','rtstein76@yahoo.com.br','Roberto Trevisan Stein','POLÍCIA RODOVIÁRIA FEDERAL - BR-386, KM 340','Lajeado','Rio Grande do Sul','BRAZIL','95900000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 00:56:47',0,NULL,3,1,2,1,'\\ ','prfstein'),(9297,558024476003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','kdaugherty22','khaki.daugherty@gmail.com','Kathryn Daugherty','9126 Edenshire Cir','orlando','FL','UNITED STATES','32836-6596','(407) 488-7538','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 01:04:14',0,NULL,3,1,1,1,'\\ ','kdaugherty22'),(9298,750748635011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','vanihuynh','bachvand5@gmail.com','Thi Bach Van Huynh','126 Lo E c/c Hung Vuong<br>F11 Q5','default','HC','VIET NAM','70000','+84-1265650404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 01:04:21',0,NULL,3,1,2,1,'\\ ','vanihuynh'),(9299,563509491004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','stach_ignac','dwadelski@yahoo.ca','Dariusz Wadelski','1124 Kelly Gate','Milton','ON','CANADA','L9T 6G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 01:18:37',0,NULL,3,1,3,1,'RA183625367CN\r ','stach_ignac\rHSNO022'),(9300,833174418012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','lireja12','lilyremy@aol.com','Remigijus Jakstys','25215 Old Hundred Rd','Dickerson','MD','UNITED STATES','20842','(301) 801-7635','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 01:40:11',0,NULL,3,1,1,1,'\\ ','lireja12\r白色的'),(9301,563528212004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'cnfaner','irishbrett','marybethkeller1@verizon.net','Mary Beth O\'Hara-Keller','14110 Netherfield Dr','Midlothian','VA','UNITED STATES','23113','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 02:57:44',0,NULL,3,1,1,1,'\\ ','irishbrett'),(9302,833199034012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.4,'eastar4','rezidue','rezidue1@gmail.com','Damian J. Spooner','21837 Michale St','Canoga Park','CA','UNITED STATES','91304-2528','(818) 414-8142','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 03:04:56',0,NULL,3,1,1,1,'\\ ','rezidue\racer 5pin1.25 15cm'),(9303,692825952008,180699060966,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','2011uranlata1612pammi','lata.arun@rocketmail.com','uran lata','206<br>north south road','woorinen','Victoria','AUSTRALIA','3589','0413301380','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 03:27:21',0,NULL,3,1,3,1,'RA183625605CN\r ','2011uranlata1612pammi\rHSPL002'),(9304,563512797004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','limps311','michaelwaterhouse1@yahoo.com.au','lindsay waterhouse','3 java place<br>waikiki','perth','Western Australia','AUSTRALIA','6169','0893903924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 03:36:56',0,NULL,3,1,3,1,'RA183625659CN\r ','limps311\rHSJA002\r澳标'),(9305,833207837012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','xfreundyx','freundy@live.com','Ben Freund','11 Dianne St','Happy Valley','South Australia','AUSTRALIA','5159','0872880150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 03:38:05',0,NULL,3,1,3,1,'RA183625645CN\r ','xfreundyx\rOTSO004*2'),(9306,612836507013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','realfire_technologies','bmonilaws@gmail.com','Ben Monilaws','6142 Stinson Way','Edmonton','AB','CANADA','T6R 0K2','(780) 975-1582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 04:13:03',0,NULL,3,1,2,1,'\\ ','realfire_technologies'),(9307,693806547008,180699061588,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',4,'HSJA001',95.96,'au-buy','findscheaper','mark_furman@hotmail.com','rami esses','1316 Avenue M<br>Ste 2','brooklyn','NY','UNITED STATES','11230-5206','(718) 676-0368','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 04:35:04',0,NULL,3,1,1,1,'\\ ','findscheaper'),(9308,833211532012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','saketsamir','saketsamir@gmail.com','Saket Samir','139 Rivervale Street<br>#08-768','Singapore','','SINGAPORE','540139','84842594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 04:43:08',0,NULL,3,1,3,1,'RA183625591CN\r ','saketsamir\rWWOT003'),(9309,833233975012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','klepachdavid','klepach@bgu.ac.il','David Klepach','Moshe sharet 52/10','Beer Sheva','Israel','ISRAEL','84786','972-77-5430019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 05:48:03',0,NULL,3,1,3,1,'RA183625565CN\r ','klepachdavid\rOTPL001'),(9310,612848441013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',5,'HBPH004',113.94,'eastar4','tikhachev','nikolay.tikhachev@gmail.com','Nikolay Tikhachev','LK-K2 An Vien','Nha Trang','Khanh Hoa','VIET NAM','84583','84905530425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 05:48:47',0,NULL,3,1,3,1,'RA183625574CN\r ','tikhachev\rHBPH004+HBPH002\r再发一个New Philips Sonicare flexcare toothbrush Handle HX6930\r'),(9311,612852812013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','odinkim','wonjin.kim@live.no','Won Jin Kim','Bakhei 33','Vennesla','','NORWAY','4700','95724804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 06:40:24',0,NULL,3,1,2,1,'\\ ','odinkim'),(9312,557749157003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','deanjor','dean_jordan2001@yahoo.com','dean jordan','221 S Gosse Blvd','princeton','IL','UNITED STATES','61356-1913','(309) 631-4253','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 08:55:57',0,NULL,3,1,1,1,'\\ ','deanjor'),(9313,612876888013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',178.8,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+79057183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 09:03:26',0,NULL,3,1,3,1,'RA184557059CN ','michel_egorov\rWLAP008'),(9314,833281401012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','gono_1','gono_1@hotmail.com','Miguel Polaina Malo','C/ Marqués de la Ensenada nº 2','Mengíbar (Jaén)','Andalucía Ceuta y Melilla','SPAIN','23620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 09:20:59',0,NULL,3,1,3,1,'RA183629085CN ','gono_1\rOTSO004*2\r盒装的'),(9315,612880197013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','fxpremiere','dani-uk@live.com','Dani A','1 Steeple Court<br>Vicarage Road','Egham','Surrey','UNITED KINGDOM','TW20 9GL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 09:23:35',0,NULL,3,1,2,1,' \\','fxpremiere'),(9316,833281114012,220713846504,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET',1,'HSNO025',34.9,'eastar4uk','ahmttvsn','ahmet_tavsan@hotmail.com','mehmet alioğlu','Dumlupınar Mah. 1516 sok. dursun cihan apt.<br>no: 12/3 Gazi Yenişehir','Mersin','','TURKEY','33130','0-324-614 21 33','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 09:31:27',0,NULL,3,1,3,1,'RA183629032CN\r ','ahmttvsn\rHSNO025\r欧标'),(9317,612888012013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','skazka_tur','dimsam@inbox.ru','Ekaterina Ustyugova','Centralnaya 14 - 25','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610029','+79226602200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 10:04:22',0,NULL,3,1,2,1,'\\ ','skazka_tur'),(9318,8881313489104266,111,'Apple Airport Extreme BCM94321MC WIFI PCI-E 802.11n',1,'WLAP005',0,'eastar4','will752','will@will-it-rain.com','Will Anderson','65 Best Street','Fitzroy North','Victoria','AUSTRALIA','3068','0416883150',NULL,NULL,NULL,'2011-08-16 10:05:04',0,NULL,5,0,18,0,NULL,''),(9319,833297788012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','abbi123','joachim@firnhaber.biz','Joachim Firnhaber','Sonnenscheinsweg 27','Essen','','GERMANY','45149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 10:36:09',0,NULL,3,1,2,1,'\\ ','abbi123\r4pin 1.25 '),(9320,693884265008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','adeel4612','adil4u_3@hotmail.com','Adeel Rana','11 Arbor terrace','Avondale Heights','Victoria','AUSTRALIA','3034','0411745398','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 11:07:14',0,NULL,3,1,3,1,'RA183629094CN\r ','adeel4612\rHSPL005\r澳标'),(9321,612907360013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','pepepopoter','pepe10000@gmail.com','Aurelio Megias Garcia','Cl. Santa Cecilia Nº 16<br>Churriana De La Vega','Granada','Andalucía Ceuta y Melilla','SPAIN','18194','627294523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 11:44:09',0,NULL,3,1,2,1,'\\ ','pepepopoter'),(9322,750898238011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','vladamatena','vlada.matena@gmail.com','Vladimír Matěna','Kosarova 458','Praha','','CZECH REPUBLIC','19700','776608357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 12:02:06',0,NULL,3,1,2,1,'\\ ','vladamatena'),(9323,750901712011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','marian.vybostok','marian@vybostok.com','Marian Vybostok','Nam. L. Stura 10','Banska Bystrica','','SLOVAK REPUBLIC','97405','(0421) 903 846657','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 12:12:41',0,NULL,3,1,2,1,'、 ','marian.vybostok'),(9324,833316389012,220807272239,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',21.99,'eastar4','jettx1','anneatt1@optusnet.com.au','Anne Attwood','7 Kallatina Close','Wallsend','New South Wales','AUSTRALIA','2287','0249516843','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 13:12:11',0,NULL,3,1,2,1,'、 ','jettx1\r向日葵三折叠伞 '),(9325,750920412011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','sforte_rodrigues','stefanoforte@gmail.com','Stéfano Forte','Rua Odilon Soares (ou Rua Brejo Santo), 50<br>+55(85)32819905/88030123','Fortaleza','Ceará','BRAZIL','60010820','8532819905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 13:13:53',0,NULL,3,1,2,1,'\\ ','sforte_rodrigues'),(9326,833354502012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',9.5,'eastar4uk','stevoartois59','stevoartois@hotmail.com','Steve Lambert','19 Holborough Road','Snodland','Kent','UNITED KINGDOM','ME6 5PA','01634243145','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 13:23:06',0,NULL,3,1,3,1,'RA183629960CN\r ','stevoartois59\rHSPL002'),(9327,750922667011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','9054004','ctwelectronics@comcast.net','Robert Burdine','2500 S Rockport Rd<br>Apt 2708','Bloomington','IN','UNITED STATES','47403-3390','(812) 361-0988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 13:23:44',0,NULL,3,1,1,1,'\\ ','9054004\rHP 8pin 1.25 25cm '),(9328,833357918012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','howibuy','emarmont@gmail.com','Edwin Marmont','C 6, Six  Mile Road','Falkland','BC','CANADA','V0E 1W0','(902) 441-4101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 13:32:07',0,NULL,3,1,2,1,'、 ','howibuy'),(9329,563629787004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','samotugin_kos','samotugin@yandex.ru','Константин Самотугин','ул. Чернышева 2-32','Красноярск','Красноярский край','RUSSIAN FEDERATION','660130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 13:58:37',0,NULL,3,1,3,1,'RA183629015CN\r ','samotugin_kos\rMOOE001\r发OEM的'),(9330,612941891013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','vip450','vipguard@hotmail.com','Steve Roy','622, des Commissaires','Kildare','QC','CANADA','J0K 1C0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 14:17:28',0,NULL,3,1,3,1,'RA183629029CN\r ','vip450\rGLOT002+GLOT003'),(9331,612937797013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','raim_gr','raimondasgr@yahoo.com','Raimondas Grazys','Architektu 18a-27','Siauliai','','LITHUANIA','LT-78283','+37068746511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 15:51:52',0,NULL,3,1,2,1,'\\ ','raim_gr\r欧标'),(9332,612977008013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',26.1,'eastar4','fleszer','patrickchm@gmail.com','Patryk Chmarzynski','Stretford High School<br>Great Stone Road','Manchester','Lancashire','UNITED KINGDOM','M32 0XA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 16:29:46',0,NULL,3,1,2,1,'\\ ','fleszer\rCAB-6060\r一共买了三条'),(9333,750999487011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','gwinlv','garyw123@hotmail.com','gary waechter','4154 Cackling Goose Dr','north las vegas','NV','UNITED STATES','89084-2650','(702) 807-3461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 16:59:59',0,NULL,3,1,1,1,'\\ ','gwinlv'),(9334,612989766013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','klcooley','klcooley@mac.com','Kyle Cooley','306 S Macomb st','Monroe','MI','UNITED STATES','48161','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 17:09:57',0,NULL,3,1,1,1,'\\ ','klcooley'),(9335,751037067011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','polivanov','polivanovsu@gmail.com','pavel samosudov','microdistrict 1    20-54','safonovo','Smolensk','RUSSIAN FEDERATION','215500','(910)789-5273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 18:18:15',0,NULL,3,1,2,1,' \\','polivanov'),(9336,833485614012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','nightxray','bolbat.a@gmail.com','Artur Bolbat','Tolstogo 26, 6','Surgut','HMAO','RUSSIAN FEDERATION','628414','+79678819426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 18:31:04',0,NULL,3,1,2,1,' \\','nightxray'),(9337,613034862013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',2,'OMHJ001',27.98,'eastar4','macneillbookshop','macneillbookstore@sbcglobal.net','c mac neill bookdealer','3155 12 Mile Road','berkley','MI','UNITED STATES','48072','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-16 19:18:37',0,NULL,3,1,1,1,'\\ ','macneillbookshop'),(9338,751068846011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','gegest','stutzmann.gerard@orange.fr','gérard stutzmann','26 avenue de la Plaine','Carry le Rouet','Provence-Alpes-Côte d\'Azur','FRANCE','13620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 19:19:49',0,NULL,3,1,2,1,'\\ ','gegest'),(9339,833520660012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',18.99,'eastar4','hamasdegh','hovsepmelk@cox.net','Hovsep Melkonian','8709 Pappas Way','Annandale','VA','UNITED STATES','22003-4539','(703) 425-4257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 19:31:02',0,NULL,3,1,1,1,'\\ ','hamasdegh'),(9340,558267022003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','wenzen37','a_zendejas@netzero.com','Wendy Zendejas','640 S Valley View Ave<br>Apt 3','San Bernardino','CA','UNITED STATES','92408-2418','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 20:37:14',0,NULL,3,1,1,1,'\\ ','wenzen37'),(9341,751108104011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'eastar4','teleplanrich','rich.morales@teleplan.com','Rich Morales','5201 George McVay Dr<br>Ste G','McAllen','TX','UNITED STATES','78503-8886','(956) 467-5361','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 20:38:35',0,NULL,3,1,1,1,'\\ ','teleplanrich'),(9342,833558279012,220455488077,'HP TX2500 TX2500z TX2z Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',12.5,'eastar4','cms470','cstajewski@gmail.com','Chuck Stajewski','911 W Whitehall Rd','State College','PA','UNITED STATES','16801-4321','(570) 332-8195','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 20:40:38',0,NULL,3,1,1,1,' \r\\','cms470\rHP 8pin 0.8 3cm'),(9343,751085506011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRTS001',6.99,'eastar4uk','rayval_0','rayval@o2.co.uk','Rayval Rodman','25 Inchgarvie Pk','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH309RN','07752302333','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 20:44:02',0,NULL,3,1,3,1,'RA183629050CN\r ','rayval_0\rTRTS001'),(9344,833560760012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','mcnewbe','markus.stapel@gmail.com','Markus Stapel','Am Lustberg 8','Hamburg','','GERMANY','22335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 20:45:25',0,NULL,3,1,2,1,'\\ ','mcnewbe'),(9345,751114439011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','kohukemeister','jaerki@hotmail.com','Erkki Mustonen','Oismae tee 44-44','Tallinn','','ESTONIA','13512','+37258132009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 20:53:50',0,NULL,3,1,2,1,'\\ ','kohukemeister'),(9346,751126729011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','nyssoalexey','a.sitnikov@mac.com','Alexey Sitnikov','apt. 501, Time Place<br>Corrig road, Sandyford','Dublin','Dublin','IRELAND','18','0863903923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 21:21:38',0,NULL,3,1,3,1,'RA183629046CN\r ','nyssoalexey\rUDAP001'),(9347,833591947012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',271.98,'eastar4','alat8427','latosandrew@yahoo.com','Andrew Latos','1437 Fox Hound Trl','Beecher','IL','UNITED STATES','60401-5107','(708) 215-0354','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 21:54:47',0,NULL,3,1,6,1,'EE645685341CN ','alat8427'),(9348,751142436011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','artclark49','rfbunnell@atlanticbb.net','Deb Bunnell','722 Clark St','Hollidaysburg','PA','UNITED STATES','16648-2128','(814) 696-1981','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 22:04:01',0,NULL,3,1,1,1,'\\ ','artclark49'),(9349,563780542004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','camnop','dancampos2@gmail.com','Daniel Campos da Silva','Expedicionario Joao Moreira<br>135','Belo Horizonte','Minas Gerais','BRAZIL','30770330','553134115920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 22:33:26',0,NULL,3,1,3,1,'RA183629973CN\r ','camnop\rWWOT003+ANCN001'),(9350,751156292011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','slymarques','cbonneff@mac.com','Christian Bonneff','Universal Pictures International<br>Oxford House, 76 Oxford Street','London','London','UNITED KINGDOM','W1D 1BS','02073076228','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 22:47:35',0,NULL,3,1,3,1,'RA183629103CN ','slymarques\rWLAP002\r二代卡旧的'),(9351,613101151013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','65432l','lukasko@gmail.com','Lukas Simko','Podkolibska 10','Bratislava','','SLOVAK REPUBLIC','83101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 22:53:52',0,NULL,3,1,2,1,'\\ ','65432l'),(9352,833614440012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',2,'OTIN001',43.98,'eastar4','gamccorkle','geoffrey.mccorkle@live.com','Geoffrey Gordon','750 Canyon Dr<br>Time Warner Cable Ste 500','Coppell','TX','UNITED STATES','75019-3834','(214) 675-7361','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 22:59:24',0,NULL,3,1,1,1,'\\ ','gamccorkle'),(9353,833615610012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',75.99,'eastar4','d3porter','d3porter@earthlink.net','David C. Porter','4032 Declaration Ave','Calabasas','CA','UNITED STATES','91302-5741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 23:01:44',0,NULL,3,1,1,1,' \\','d3porter'),(9354,751166356011,320721404167,'Transparent Dome Rain Sun Umbrella with black trim',1,'UMTR001',19.99,'eastar4','joyxshieru','i.magination@hotmail.com','Sarai Diaz Cortes','Norte 88A#6130<br>Col.Gertrudis Sanchez','Gustavo A. Madero','Distrito federal','MEXICO','07839','5541315239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 23:27:44',0,NULL,3,0,2,1,'\\ ','joyxshieru\r紫色的\r已入库'),(9355,833640052012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.5,'eastar4uk','paul_baaske','paul_baaske@hotmail.com','Paul Baaske','The Grove 10b','London','','AUSTRIA','N6 6LB','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 00:22:35',0,NULL,3,1,2,1,'\\ ','paul_baaske'),(9356,833360133012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','go_jb_1967','jake_baruch@bigpond.com','Jacob Baruch','172 Wells Road, Aspendale Gardens','Melbourne','Victoria','AUSTRALIA','3195','0395872618','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 00:53:33',0,NULL,3,1,2,1,'、 ','go_jb_1967'),(9357,750471842011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','jsiz3865','sizemore315@bellsouth.net','Jerry Sizemore','214 Leatherneck Rdg','Mars Hill','NC','UNITED STATES','28754-0069','(864) 888-7184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 01:01:51',0,NULL,3,1,1,1,'\\ ','jsiz3865\r二代卡 旧'),(9358,751195100011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','quintinmiddle','anthonyfirst@verizon.net','Anthony Kennedy','5772 Garden Grove Blvd<br>Spc 444','Westminster','CA','UNITED STATES','92683-1855','(562) 572-3769','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 01:10:58',0,NULL,3,1,1,1,'\\ ','quintinmiddle'),(9359,751199862011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','khug7973','keh3qa@virginia.edu','Kyle Hughes','301 15th St. NW<br>Apt. 3010A2','Charlottesville','VA','UNITED STATES','22903','(214) 577-7318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 01:26:32',0,NULL,3,1,1,1,'\\ ','khug7973'),(9360,751200875011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','fmonette-mtl','francois_monette@hotmail.com','Francois Monette','64 Saint-Paul Ouest #213','Montreal','QC','CANADA','H2Y 4B8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 01:31:20',0,NULL,3,1,2,1,'\\ ','fmonette-mtl'),(9361,751196938011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','nhab5663','nagyhabib20@gmail.com','Nagy Habib','5256, Lakeview St','Pierrefonds','QC','CANADA','H8Z2N1','(514) 971-0906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 01:16:00',0,NULL,3,1,2,1,'\\ ','nhab5663'),(9362,613146985013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ithorianpresident','aaron051470@yahoo.com','Aaron Williams','882 3rd ave','Troy','NY','UNITED STATES','12182','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 02:25:01',0,NULL,3,1,1,1,'\\ ','ithorianpresident'),(9363,613149019013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','cflanca','cflanca@ig.com.br','Carlos Lanca','Rua Mateus Grou 398 Apto 41<br>Pinheiros','Sao Paulo','São Paulo','BRAZIL','05415-040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 02:34:22',0,NULL,3,1,2,1,'\\ ','cflanca'),(9364,751224682011,320698314620,'Original Jabra BT800 BT 800 wireless Bluetooth Headset',1,'HSJA008',28.7,'eastar4','tonytong08218','sarawuth_08218@hotmail.com','sarawuth sutharaphan','The Secretariat of the Senate U-Tongnai Rd.','Dusit','Bangkok','THAILAND','10300','6628319447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 03:03:18',0,NULL,3,1,2,1,'\\ ','tonytong08218'),(9365,751225488011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',125.98,'eastar4','07sundowner','graham.harding7@bigpond.com','Graham Harding','31-33 Blackbutt Ct','Burpengary','Queensland','AUSTRALIA','4505','0754978543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 03:08:33',0,NULL,3,1,3,1,'RA183629077CN','07sundowner\rOTSO004\r盒装的'),(9366,751243715011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','cef168','tingarvin@hotmail.com','Arvin Ting','3731 Maple Park Ave','Cincinnati','OH','UNITED STATES','45209-2212','(513) 593-1789','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 04:37:44',0,NULL,5,0,18,0,NULL,'cef168\r客户要撤单'),(9367,751257542011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.97,'eastar4','schumiji12','upchar@gmail.com','Xuan Ji','9/7 McMILLAN ST<br>VICTORIA PARK','Perth','Western Australia','AUSTRALIA','6100','0061425828058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 05:52:38',0,NULL,3,1,2,1,'\\ ','schumiji12'),(9368,751292645011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',5,'CASS001',43.5,'eastar4','sharmack96','sharmack96@yahoo.co.uk','S.P. Filipek','151 Silbury Blvd','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK91LH','01908545700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 08:45:40',0,NULL,3,1,3,1,'RA183629942CN\r ','sharmack96\rCASS001'),(9369,613206869013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',2,'WLIN010',39.76,'eastar4','scobako','junior4430@gmail.com','Alexandr Danilov','Zakrevskogo street, 35A, Apt (kvart) 134','Kiev','UA','UKRAINE','02217','+ 38 050 440 30 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 08:59:40',0,NULL,3,1,3,1,'RA183629939CN\r ','scobako\rWLIN010'),(9370,833536942012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','mesut-77','mesutkuskun1977@hotmail.com','mesut kuskun','sterkenburglaan 26','hellevoetsluis','','NETHERLANDS','3221bt','0181329169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 09:01:41',0,NULL,3,1,3,1,'RA183629806CN\r ','mesut-77\rWWOT001\r'),(9371,751298610011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',125.98,'eastar4','lordking123','dev.dirisan@computershare.com.au','Devaraj  Dirisan','81 Bona Vista Road<br>Bayswater','Melbourne','Victoria','AUSTRALIA','3153','0397292631','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 09:12:20',0,NULL,3,1,3,1,'RA183629117CN\r ','lordking123\rOTSO004'),(9372,751302772011,320730087234,'New IBM/ThinkPad Mini PCI Atheros 5213A AR5BMB CARD',1,'WLAT006',12.49,'eastar4uk','junzhg','junzhg@msn.com','ZHANG JUN','40 RUE REMY DUMONCEL','PARIS','ILE DE FRANCE','FRANCE','75014','0615944294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 09:29:19',0,NULL,3,1,2,1,'\\ ','junzhg'),(9373,833774276012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','rexid1','tailormoon@rambler.ru','Igor Didenko','ul. Lebedeva, d.3, kv.16','Makeevka','Donetska obl','UKRAINE','86126','+380632459537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 09:31:22',0,NULL,3,1,2,1,'\\ ','rexid1'),(9374,613215522013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','pfranck62','franck.pollet@wanadoo.fr','Franck Pollet','422 rue Pierre Dupuy','SANGATTE','Nord-Pas-de-Calais','FRANCE','62231','03 21 82 70 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 09:49:43',0,NULL,3,1,2,1,'\\ ','pfranck62\rCASS003'),(9375,612642179013,230656400124,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',74.99,'eastar4','naidan-off','naidanoff@me.com','Vitaly Naidanov','Lenin\'s 102-3','Perm','Perm','RUSSIAN FEDERATION','614068','+79097284646','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 10:04:40',0,NULL,3,1,3,1,'RA183629134CN\r ','naidan-off\rOTSA001'),(9376,833785357012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','rib8732','dscanlan@live.com','David Scanlan','390 Palatine Road<br>Northenden','Manchester','Lancashire','UNITED KINGDOM','M22 4fz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 10:13:15',0,NULL,3,1,3,1,'RA183629151CN\r ','rib8732\rHSJA010\r英标'),(9377,613220942013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',3,'OTRA003',59.97,'eastar4','omahenas','omahenas@gmail.com','Ales Omahen','Quai aux Briques 22','Brussels','','BELGIUM','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 10:20:58',0,NULL,3,1,3,1,'RA183629148CN\r ','omahenas\rOTRA003'),(9378,831991065012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','micky700630','m.mazor@gmx.de','Mike Mazor','Bockauer Talstraße 4','Aue','','GERMANY','08280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 11:38:20',0,NULL,3,1,2,1,'\\ ','micky700630'),(9379,833812445012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',42.99,'eastar4uk','adammcgillivray','adam.tammy30@gmail.com','Packo Projectors','48 Pavone Rd','GUNBOWER','Victoria','AUSTRALIA','3566','0438871421','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 11:46:33',0,NULL,3,1,3,1,'RA183626274CN\r ','adammcgillivray\rGLOT005\r投影仪兼容眼镜'),(9380,833815395012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','deborah1968rail','deborahlynnrail@aol.com','Deborah Rail','1 Greenacres<br>22 The Avenue','Bournemouth','Dorset','UNITED KINGDOM','BH13 6AJ','01202766181','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 11:54:15',0,NULL,3,1,3,1,'RA183629899CN\r ','deborah1968rail\rHBPH003'),(9381,833636387012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',225.99,'eastar4','sprelligosi','sprelligosi@yahoo.com','Heidar Gudnason','Langidalur 11','Eskifjordur','sm','ICELAND','735','003548974151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 12:05:42',0,NULL,3,1,3,1,'RA184557456CN\r ','sprelligosi'),(9382,613245880013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','prgrss','progress@pp.nic.fi','Juha Eriksson','Vallikatu 22','Loviisa','','FINLAND','07900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 12:27:48',0,NULL,3,1,2,1,'\\ ','prgrss'),(9383,751351346011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.4,'eastar4','0-8-15_seller','mrnic3guy2000@hotmail.de','Sebastian Küster','Berggate 28<br>Carparts-Online','Bochum','','GERMANY','44809','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 12:29:50',0,NULL,3,1,2,1,'\\ ','0-8-15_seller\racer 4pin1.25 6cm'),(9384,833833867012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','raidani91','schererdaniel91@gmail.com','Dániel Scherer','Kossuth Lajos<br>146/b','Érd','Pest','HUNGARY','2030','+36309567630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 12:53:08',0,NULL,3,1,2,1,'\\ ','raidani91'),(9385,833841494012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','speedy1gonzales','kamera@ralfhschlotter.com','ralf schlotter','Lychenerstr.14','Berlin','','GERMANY','10437','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 13:19:18',0,NULL,3,1,2,1,'\\ ','speedy1gonzales'),(9386,751366346011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',84.99,'eastar4uk','balcondel','balcondel@hotmail.com','José Juan Gómez Martin','Callejon de los Frailes Nº 2 - 1º A','Santa Cruz de Tenerife - Adeje','Canarias','SPAIN','38670','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 13:21:58',0,NULL,3,1,3,1,'RA183629845CN\r ','balcondel\rGLOT001*3\r兼容型3D眼镜 通用型'),(9387,613268781013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',178.8,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+79057183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 14:11:26',0,NULL,3,1,3,1,'RA183629871CN\r ','michel_egorov\rWLAP008'),(9388,751384876011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','porsche0010','halushi@arcor.de','Slavko Porsche','Andreestr. 8','München','','GERMANY','80634','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 14:17:50',0,NULL,3,1,2,1,'\\ ','porsche0010'),(9389,833871524012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',97.99,'eastar4','robsonsarreta','rsarreta@hotmail.com','ROBSON DE OLIVEIRA SARRETA','RUA MARCONDES SALGADO 866, APARTAMENTO 301','RIBEIRÃO PRETO','SÃO PAULO','BRAZIL','14010150','1678126536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 14:45:06',0,NULL,3,1,3,1,'RA183629854CN\r ','robsonsarreta\rGLOT001*2\r兼容型3D眼镜 通用型'),(9390,833875831012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','viktor_k1975','viktar.kastrou@gmail.com','Kapanets Stephen','Burdeynogo str. 45 - 385','Minsk','','BELARUS','220136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 14:52:29',0,NULL,3,1,2,1,NULL,'viktor_k1975\r一共买了三个'),(9391,751400338011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',17.95,'eastar4','tribalbase','tribalbase@hotmail.com','DARREN MILLENBACH','8 CHALGROVE CRESCENT','ILFORD','Essex','UNITED KINGDOM','IG50LU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 15:02:21',0,NULL,3,1,2,1,'\\ ','tribalbase'),(9392,833879573012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','perentin','perentin@idx.com.au','Gary Perentin','28 Shelly Beach Road','Shelly Beach','New South Wales','AUSTRALIA','2261','0243322888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 15:03:48',0,NULL,3,1,3,1,'RA183629125CN\r ','perentin\rOTSO004*2\r盒装的'),(9393,751400591011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','juatman','jumabr@msn.com','JUAN MANUEL BAILON RIVERA','Avenida de Andalucia nº8 1ºG (Edificio Los Arcos)','Atarfe','Granada','SPAIN','18230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 15:12:46',0,NULL,3,1,3,1,'RA183629911CN\r ','juatman\rUDAP001'),(9394,751404331011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','virus-kvartirus','sterlikov@mail.com','Sergej Sterlikov','Zelenaya str. 13 - 188','pos. Dubovoe','Belgorodskij r-n Belgorodskaya obl','RUSSIAN FEDERATION','308501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 15:14:59',0,NULL,3,1,3,1,'RA183629885CN\r ','virus-kvartirus\rHSNO019+CCNO001'),(9395,751418311011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','1dunerider','ashnemetz@gmail.com','Charles Nemetz','1200 Erskine Avenue','Las Vegas','NV','UNITED STATES','89123','(702) 375-8006','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 15:51:56',0,NULL,3,1,1,1,'\\ ','1dunerider\r美标'),(9396,833899766012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',84.99,'eastar4uk','vicandjoan09','victorlong223@btinternet.com','victor long','3 Saughtrees Cottage<br>Wamphray','Moffat','Dumfries and Galloway','UNITED KINGDOM','DG10 9NR','01576470297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 16:12:27',0,NULL,3,1,3,1,'RA183629837CN\r ','vicandjoan09\rGLOT001*3\r兼容型3D眼镜 通用型'),(9397,613308117013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','jcheger15','jcheger@ordinoscope.net','Jean-Christophe Heger','Chemin du Levant 2','Chavornay','','SWITZERLAND','1373','0763240525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 16:42:22',0,NULL,3,1,2,1,'\\ ','jcheger15'),(9398,751439650011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',97.99,'eastar4','crclejrk','janssensplaceab@hotmail.com','REINHARD JANSSEN','7855 ENTERPRISE DR','NEWARK','CA','UNITED STATES','94560-3410','(510) 796-6151','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 16:48:32',0,NULL,3,1,1,1,'\\ ','crclejrk\r兼容型3D眼镜  samsung 专用'),(9399,829667867012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','pkstars87','johnnygemme@hotmail.com','johnny gemme','621 rue Coombs','sherbrooke','QC','CANADA','j1n2b1','(819) 791-1209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 17:34:54',0,NULL,3,1,3,1,'RA183629766CN\r ','pkstars87\rGLSG001*2'),(9400,751458061011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','plebann','m1pleban@gmail.com','Maciej  Plebanowicz','ul. 1-go Maja 4b/12','Lublin','lubelskie','POLAND','20-410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 17:40:39',0,NULL,3,1,2,1,'\\ ','plebann\r微软的'),(9401,563992826004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'cnfaner','123kirbyb','kirby.cherlyn@shaw.ca','kirby byrne','212 Lindstrom Cres.','fort mcmurray','AB','CANADA','T9K 2S5','(780) 715-2426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 17:52:53',0,NULL,3,1,3,1,'RA183629868CN\r ','123kirbyb\rHBPH003'),(9402,831430160012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','cheka64ceslav','cheka64@yahoo.com','Ceslav Pilat','121 Beechgrove Lawns','Monaghan','Monaghan','IRELAND','','0862259407','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 17:58:19',0,NULL,3,1,2,1,'\\ ','cheka64ceslav\r英标'),(9403,833959736012,220620860324,'NEW GENUINE NOKIA BH-207 BLUETOOTH HEADSET BH 207',1,'HSNO010',24.99,'eastar4','pvv76','pichca@yandex.ru','Vladimir Pichenko','Chkalova st. 3 ap.2','Okhtyrka','Sumy','UKRAINE','42700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 18:06:40',0,NULL,3,1,2,1,'\\ ','pvv76\r欧标\r盒装的'),(9404,751478788011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','1odyssey11','odyssey1111@gmail.com','Jeremy Sheffer','155 Lick Run Rd','Mount Solon','VA','UNITED STATES','22843','(540) 435-2625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 18:19:41',0,NULL,3,1,1,1,'\\ ','1odyssey11\r新的'),(9405,613350622013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',9.8,'eastar4','space-pirate-captain-harlock','cory@ikkokukan.ca','Cory Kennerfeldt','8612 64 avenue','edmonton','AB','CANADA','t6e 0h5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 18:57:18',0,NULL,3,1,2,1,'\\ ','space-pirate-captain-harlock'),(9406,711282521001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','mewhee','ncalexpat@cox.net','Will and Jennifer Johnston','2143 NE 12th Ave<br>null','Portland','OR','UNITED STATES','97212-4307','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 19:06:20',0,NULL,3,1,1,1,'\\ ','mewhee'),(9407,751517159011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','konsscar','richandfamous@ymail.com','ΚΩΣΤΑΣ ΣΚΑΡΕΑΣ','ΚΑΡΔΑΜΥΛΗ, ΜΕΣΣΗΝΙΑ, ΜΕΣΣΗΝΙΑ<br>ΜΕΣΣΗΝΙΑ','ΚΑΡΔΑΜΥΛΗ','ΔΗΜΟΣ ΔΥΤΙΚΗΣ ΜΑΝΗΣ','GREECE','24022','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 19:36:12',0,NULL,3,1,2,1,'\\ ','konsscar'),(9408,834008712012,220815930312,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',16.95,'eastar4uk','sandy66vodka','sanmor@hotmail.co.uk','SANDRA MORRISON','C.F. BOOTH DONCASTER LTD<br>WHARF RD','DONCASTER','South Yorkshire','UNITED KINGDOM','DN1 2ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 19:40:01',0,NULL,3,1,3,1,'RA183629908CN\r ','sandy66vodka\r英标\rHSMO021'),(9409,751523954011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','perpetulo','trash@sarrata.de','Michael Kaufmann','Kirchdorfer Str. 29','Fellheim','','GERMANY','87748','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 19:50:21',0,NULL,3,1,2,1,'\\ ','perpetulo'),(9410,834017149012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 19:55:25',0,NULL,3,1,3,1,'RA183629810CN\r ','speedsterporsche\rOTGR001+OTGR002'),(9411,751542230011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','xenon_soft','xenon_soft@yahoo.es','Salvador Perugorría Lorente','Antonio Bravo 16 - 2º A','Zaragoza','Zaragoza','SPAIN','50017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 20:29:42',0,NULL,3,1,2,1,'\\ ','xenon_soft\r二代卡 旧'),(9412,712178445001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','shutterspeed75','toymagtaas@fastmail.fm','Melvin Magtaas','10 Abragan Compound<br>Sto. Rosario','Iligan City','Lanao del Norte','PHILIPPINES','9200','0632255050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 21:11:49',0,NULL,3,1,3,1,'RA183629770CN\r ','shutterspeed75\rBR3D004\r新地址\rMelvin S. Magtaas\rRoom 1, Salido Place Resort\rAngol, Boracay\rPhilippines \r5608\r\r'),(9413,751564549011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','rolasherofuve','herofuve@gmail.com','Rolando Fuentes','Rancho San Lorenzo 39 apt. 501<br>Colonia Los Girasoles III Delegación Coyoacán D.F.','Mexico City','Distrito Federal','MEXICO','04920','+525556793873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 21:19:13',0,NULL,3,1,2,1,'\\ ','rolasherofuve'),(9414,834073086012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','normyzo','dan@bigw.org','Dan Williams','402 S Washington Ave','Saint Peter','MN','UNITED STATES','56082-2026','(781) 330-6853','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 21:57:29',0,NULL,3,1,1,1,'\\ ','normyzo'),(9415,564075355004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','caasberg','christian.aasberg@hotmail.com','Christian Aasberg','Dagali','3580 Geilo','Buskerud','NORWAY','35800','+4795792215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 22:30:42',0,NULL,3,1,3,1,'RA183629925CN\r ','caasberg\rWLAP008'),(9416,613420963013,230649308317,'New Auto folding Sun Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','han2008s','han2084s@gmail.com','Hani Ebrahim','26/32 Bradford Court','Adelaide','South Australia','AUSTRALIA','5085','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 22:45:16',0,NULL,3,1,2,1,'\\ ','han2008s\r灰色的\r网眼豹纹双层网纱长柄伞  '),(9417,712216288001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','n8ihp','n8ihp@watchtv.net','DAVID J NEIFERD','5010 Liberty Union Rd','VAN WERT','OH','UNITED STATES','45891','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 23:28:01',0,NULL,3,1,1,1,'\\ ','n8ihp'),(9418,558604145003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','noble62165','allenhudson65@yahoo.com','noble hudson','3101 E 200 N','marion','IN','UNITED STATES','46952-6715','(765) 664-6125','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-17 23:38:09',0,NULL,3,1,1,1,'\\ ','noble62165'),(9419,751610175011,320441946298,'2.1 HP DV1000 DV1100 DV1300 Bluetooth Module EDR +cable',1,'BTHP2109',12.4,'eastar4','tdphotonz','tdphonerepair@gmail.com','Josh van Loon','3 Hampstead Court<br>Pyes Pa','Tauranga','BOP','NEW ZEALAND','3112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 23:56:56',0,NULL,3,1,2,1,'\\ ','tdphotonz\rHP 8pin 1.25 3cm '),(9420,613437142013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','riceman617','riceman_617@yahoo.com','David Rice','764 E Gemini Pl','Chandler','AZ','UNITED STATES','85249','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-18 00:07:03',0,NULL,3,1,1,1,'\\ ','riceman617'),(9421,834117363012,220816785876,'New Philips Standard Sonicare ProResult Toothbrush head',3,'HBPH004',20.7,'eastar4uk','mymysoleil','rosebleue85@hotmail.com','Mylène Henripin','205-3155 rue des Émeraudes','St-Hubert','QC','CANADA','J4T 3S9','(514) 962-4819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-18 00:32:50',0,NULL,3,1,3,1,'RA183626288CN\r ','mymysoleil\rHBPH004'),(9422,564110585004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','yakupcelik','yakup.celik@web.de','Yakup Celik','Fürstenberger Str. 29','40599','','GERMANY','Düsseldorf','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 01:45:46',0,NULL,3,1,3,1,'RA183629956CN\r ','yakupcelik\rHSJA002\r欧标'),(9423,564117521004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',15.5,'cnfaner','astarpilot77rg','astarpilot66@yahoo.com','Adam Cretaro','4664 Dandelion Dr','redding','CA','UNITED STATES','96002-4060','(530) 515-4401','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 02:29:44',0,NULL,3,1,1,1,'\\ ','astarpilot77rg'),(9424,751654251011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','oran2549','iam_narong@hotmail.com','POL.LT Aumphun pancharoen(Mr.Narong)','Royal Police Cadet Academy<br>90/273  M.7  T.Sampran','Sampran','Nakhonpathom','THAILAND','73110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 02:50:18',0,NULL,3,1,2,1,'\\ ','oran2549\r二代卡 旧'),(9425,751650488011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',43.16,'eastar4','pmfi1','forbes.kerryane85@gmail.com','P FORBES','1593 sarasota crescent','oshawa','ON','CANADA','L1G 8G1','(905) 571-2778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 02:50:46',0,NULL,3,1,3,1,'RA183630000CN\r ','pmfi1\rHSJA002'),(9426,751659413011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','aver3069','verma@cise.ufl.edu','Ajit Kumar Verma','3415 SW 39th Blvd<br>Apt 1012','Gainesville','FL','UNITED STATES','32608','(352) 870-4122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 03:12:09',0,NULL,3,1,1,1,'\\ ','aver3069'),(9427,834168002012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',12,'eastar4uk','top69banana','paypal@top-banana.com','Caron Livens','28 Septimus Drive<br>Highwoods','COLCHESTER','Essex','UNITED KINGDOM','CO4 9ET','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 03:43:22',0,NULL,3,1,3,1,'RA183629182CN\r ','top69banana\rWLHP002'),(9428,751668799011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','grichmond','graham@ecohaustas.com','Graham Richmond','2321 Rancheria Rd','Redwood Valley','CA','UNITED STATES','95470-9727','7074850293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 04:04:31',0,NULL,3,1,1,1,'\\ ','grichmond'),(9429,751670129011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','lazybeachcat','lazybeachcat@aol.com','Laura-Beth Fitzpatrick','2614 Front St','San Diego','CA','UNITED STATES','92103-6518','(858) 414-5767','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 04:09:49',0,NULL,3,1,1,1,'\\ ','lazybeachcat'),(9430,751676151011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','nagoya9','moto.aoki@live.com','Motonori  Aoki','4658 Red Wing Ln','Long Grove','IL','UNITED STATES','60047-5274','(847) 970-1141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 04:47:00',0,NULL,3,1,1,1,'\\ ','nagoya9'),(9431,751677907011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.99,'eastar4','kang.kemod','kangkemod@aim.com','Agtisa Virnawan','Sudirman Park Apartment Tower A Unit 33 BK<br>KH Mas Mansyur Kav. 35, Karet Tengsin, Tanah Abang','Jakarta Pusat','DKI Jakarta','INDONESIA','10220','+628155102181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 04:55:21',0,NULL,3,1,2,1,'\\ ','kang.kemod\rHP 5pin1.0 20cm '),(9432,8881313643492101,111,'CAB-6060',50,'CASS003',625,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815',NULL,NULL,NULL,'2011-08-18 04:58:12',0,NULL,3,1,12,1,'BJ8824603','客户直接打款的\rCASS003+CASS001\r一共买了\r50个 CAB-6060\r50个CAB-SS-2626 \r申报30美金\r'),(9433,834185007012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',2,'SCLO002',11,'eastar4','viktor_k1975','viktar.kastrou@gmail.com','Kapanets Stephen','Burdeynogo str. 45 - 385','Minsk','','BELARUS','220136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 05:13:18',0,NULL,3,1,17,0,NULL,'viktor_k1975'),(9434,8881313644982413,111,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',0,'eastar4','luvbead_perth','icecjan@gmail.com','Janice T Chan','PO Box 283<br>Osborne Park','Perth','Western Australia','AUSTRALIA','6017','',NULL,NULL,NULL,'2011-08-18 05:23:02',0,NULL,3,1,2,1,'\\ ','补发的\r有与上次发错颜色了\rProLee24K超轻碳纤骨长柄伞 \r深蓝色的 '),(9435,613494225013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dignatov','roof1975@rambler.ru','Dmitriy Ignatov','Karbusheva 25-165','Krasnogorsk','Moscow region','RUSSIAN FEDERATION','143408','+79161548571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 05:47:17',0,NULL,3,1,2,1,'\\ ','dignatov'),(9436,558660210003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','petropix','iwalden2@yahoo.ca','Tom Thomas','755 Berry Point Road','Gabriola','BC','CANADA','V0R 1X1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 06:01:14',0,NULL,3,1,3,1,'RA183629783CN\r ','petropix\rMOLO006'),(9437,751689090011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mocsclarinet','erica-paris@utc.edu','Erica Paris','3528 Garretts Chapel Rd','Chickamauga','GA','UNITED STATES','30707-3705','(423) 619-8562','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 06:03:10',0,NULL,3,1,1,1,'\\ ','mocsclarinet'),(9438,834202178012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.4,'eastar4','itachigai','cdu948s@gmail.com','Masaru Abe','higashitakei 890<br>abe-body','usa-shi','Oita','JAPAN','879-0309','0978-33-3773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 06:46:13',0,NULL,3,1,2,1,'\\ ','itachigai'),(9439,833788644012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','david_chch','sz_chuang@hotmail.com','Weijun Zhang','6 Lodge Place<br>Ilam','Christchruch','Canterbury','NEW ZEALAND','8041','03-3488718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 06:59:54',0,NULL,3,1,2,1,'\\ ','david_chch'),(9440,834207201012,220786834052,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',35.99,'eastar4','mega-ebuy','richard7@cantv.net','Jean Carlos Garcia','11354 Sunshine Ter','Studio City','CA','UNITED STATES','91604-3125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 07:11:19',0,NULL,3,1,1,1,'\\ ','mega-ebuy'),(9441,751707591011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.99,'eastar4','lost_boy_temp','lost_boy_lc@hotmail.com','Wil Earle','26 Colson Cres, Monterey','Sydney','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 07:41:02',0,NULL,3,1,2,1,'\\ ','lost_boy_temp\r3.0 ASUS 6PIN 12CM  '),(9442,751716448011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',2,'OTGR001+OTGR002+OTGR003',111.98,'eastar4','blackhorn888','ttk13@hotmail.com','Tan Tiew Koon','Blk 131 choa chu kang ave 1<br>#15-16','singapore','','SINGAPORE','680131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:24:09',0,NULL,3,1,3,1,'RA183629797CN\r ','blackhorn888\rOTGR001+OTGR002+OTGR003\r带花洒座的'),(9443,834227717012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*2',245.98,'eastar4','taniaturner1964','taniaturner@aapt.net.au','Tania Turner','33 Shalimar Rise<br>Currambine','Perth','Western Australia','AUSTRALIA','6028','0893053905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:43:31',0,NULL,3,1,3,1,'RA183629721CN\r ','taniaturner1964\rOTSO004*2'),(9444,833333425012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',49.98,'eastar4','arna557','arna10@rambler.ru','Екатерина Труфан','Popova,Building 12,Apartment 34','Lyubertsy','Moscow Region','RUSSIAN FEDERATION','140013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:52:02',0,NULL,3,1,3,1,'RA183629718CN\r ','arna557\rUM00008\r24K 多色伞\r一共买了两把'),(9445,751722070011,320721457656,'New lady lace trim sun/rain stick Umbrella Brown',3,'UM00011',74.97,'eastar4','ophisha','space_odt@hotmail.com','Sharon Gurman','P.O. Box 330','Qadima','ISRAEL','ISRAEL','60920','(52)8820710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:53:16',0,NULL,5,1,18,1,NULL,'ophisha\rUM00011\r蕾丝花边伞 \r客户要退款撤单'),(9446,560461246004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','marin.frankovic','marin@frankovic.net','Marin Frankovic','Pavlenski put 7F','Zagreb','Zagrebacka zupanija','CROATIA','10000','385915975666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 09:17:43',0,NULL,3,1,3,1,'RA183629735CN\r ','marin.frankovic\rOTHP004'),(9447,834236894012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',168.99,'eastar4','nickolsonn','nti_nicolet@hotmail.com','frederic nicolet','rue mitoyenne 4','OLNE','','BELGIUM','4877','043629706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 09:24:18',0,NULL,3,1,3,1,'RA183629749CN\r ','nickolsonn\rGLSG001*3'),(9448,834243314012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',19.98,'eastar4uk','canonfdfan','n.m.mckechnie@bris.ac.uk','Nicol McKechnie','1 Whytes Close','Bristol','Bristol','UNITED KINGDOM','BS9 3HU','01179501462','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 09:46:47',0,NULL,3,1,3,1,'RA183629681CN\r ','canonfdfan\rWLAP008'),(9449,751746723011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','ttpicasso','picasso@manx.net','Paul Roberts','39 Campion Way<br>Abbeyfields','Douglas','Isle of Man','UNITED KINGDOM','IM2 7DT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 10:35:39',0,NULL,3,1,3,1,'RA183629664CN\r ','ttpicasso\rHBPH002\r'),(9450,834255726012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','edst1977','edst@mail.ru','Eduard Stremyakov','Kolsky pr.<br>164-27','Murmansk','Murmanskaya obl','RUSSIAN FEDERATION','183050','+7-9217246588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 10:36:42',0,NULL,3,1,2,1,'\\ ','edst1977'),(9451,751747213011,320441575399,'2.1 Acer Aspire 7110 7000 9300 Bluetooth Module +cable',1,'BTAC2108',12.4,'eastar4','wehe65','sulzer@a1.net','Reinhold Sulzer','Kerpeng. 72','Wien','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 10:38:47',0,NULL,3,1,2,1,'\\ ','wehe65\racer 4pin1.25 18cm '),(9452,613547017013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','thierrysimon','simonthierry@free.fr','SIMON Thierry','378A Route de la mare maury','VIRVILLE','Haute-Normandie','FRANCE','76110','0235104675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 11:26:37',0,NULL,3,1,2,1,'\\ ','thierrysimon'),(9453,834272907012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.75,'eastar4','patt022010','patanasit02@gmail.com','Patanasithi Khemngern','1279 Border Patrol Police, Phahonyotin Road,<br>Samsennai,','Phayathai','Bangkok','THAILAND','10400','6622788000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 11:40:26',0,NULL,3,1,2,1,'\\ ','patt022010\r黑色的'),(9454,834282677012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','djsydau','derek@clubduh.com','Derek Jenkins','c/- CBA Group Customer Relations<br>Level 8, 309 George Street','Sydney','New South Wales','AUSTRALIA','2000','0293782243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 12:27:19',0,NULL,3,1,3,1,'RA183629528CN ','djsydau\rOTSO004*2'),(9455,834295489012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','twoold4this','twoold4this@hotmail.com','John Morrison','2, Milverton Road,<br>Giffnock','Glasgow','East Renfrewshire','UNITED KINGDOM','G467JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 12:45:51',0,NULL,3,1,3,1,'RA183629678CN\r ','twoold4this\rHSPL011\r英标'),(9456,834297144012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','aricnoss','aricnos@mail.ru','Artur Lebedev','Solodunova 38-54','Vologda','','RUSSIAN FEDERATION','160002','79115000966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 12:51:53',0,NULL,3,1,3,1,'RA183629695CN\r ','aricnoss\rOTRA001'),(9457,751789195011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','chocolatehog50','jennifer.a.good@gmail.com','Jennifer Good','2911 Benbrook Ave','McHenry','IL','UNITED STATES','60050','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 13:07:54',0,NULL,3,1,1,1,'\\ ','chocolatehog50'),(9458,613576036013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','ishooturface','mrqboy@hotmail.com','Don  Ho','89 Yishun Street 81<br>#03-03','default','','SINGAPORE','768449','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 13:43:58',0,NULL,3,1,11,1,'、 ','ishooturface\rMOAP001'),(9459,564233896004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'cnfaner','surap0ng','surapongs@gmail.com','Surapong Somrang','9/3 Krongthong Villa Park, Soi Krungthep Kreeta 7,<br>Krungthep Kreeta Rd., Huamark','Bangkapi','Bangkok','THAILAND','10240','66818541010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 14:48:21',0,NULL,3,1,3,1,'RA183629576CN\r ','surap0ng\rCACN004'),(9460,834343445012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','cwd650','pixelppc@gmail.com','Roman Nizinskyj','1 Lambert Fold<br>Dodworth','Barnsley','South Yorkshire','UNITED KINGDOM','S75 3SX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 15:07:46',0,NULL,3,1,2,1,'\\ ','cwd650'),(9461,751840678011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','clear_blue_skull','farlowfamily@comcast.net','Eric Farlow','10724 View Dr NW','Gig Harbor','WA','UNITED STATES','98332-9523','(253) 858-1767','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 15:45:43',0,NULL,3,1,1,1,'、 ','clear_blue_skull'),(9462,834371351012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','integratas','integratas@earshamhall.co.uk','Rupert Derham','Earsham Hall','Bungay','Norfolk','UNITED KINGDOM','NR352AN','01986893423','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 16:18:10',0,NULL,3,1,3,1,'RA183629196CN\r ','integratas\rHSIT001\r英标'),(9463,613623941013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','yadokhin','tohinbiz@yandex.ru','Anton Yadokhin','Stepana Razina 1, 80','Miass','Chelyabinskaya','RUSSIAN FEDERATION','456317','(908) 043 - 2817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 16:52:23',0,NULL,3,1,2,1,'\\ ','yadokhin'),(9464,558781034003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',2,'HSJA006',27.8,'cnfaner','safebrother1','rdsmit3@aol.com','RODNEY SMITH','130 SADDLE DR','NEWPORT NEWS','VA','UNITED STATES','23602-7473','(757) 874-7660','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 16:55:29',0,NULL,3,1,1,1,'\\ ','safebrother1'),(9465,751869633011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','dakul2003','dakul@hotmail.com','Dmitry Kulyba','Telmana str, 6/102','Gomel','Homel\'skaya','BELARUS','246003','+375 296 567468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 17:04:14',0,NULL,3,1,2,1,'\\ ','dakul2003'),(9466,834404314012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',4,'CASS001',23.96,'eastar4uk','coyotebofh','jcoyote@gmail.com','Juan Piera Beltran','Avenida de La Horchata 15, Piso 3, Puerta 10','Alboraya','Comunidad Valenciana','SPAIN','46120','691507097','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-18 17:35:32',0,NULL,3,1,3,1,'RA183629752CN\r ','coyotebofh\rCASS001'),(9467,751881839011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','stangslang','hoover_161@yahoo.com','Ronald Hoover','12018 County Line Rd','moundville','AL','UNITED STATES','35474-6065','(205) 535-7558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 17:41:42',0,NULL,3,1,1,1,'\\ ','stangslang'),(9468,613644547013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',2,'OTRA003',51.98,'eastar4','impsellers','asifliv@yahoo.co.uk','Asif Patel','5<br>Kingsdown Gardens','Bolton','Lancashire','UNITED KINGDOM','BL1 2JA','07742243341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 18:03:13',0,NULL,3,1,3,1,'RA183629616CN\r ','impsellers\rOTRA003'),(9469,558796785003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','adamcouey','acouey123@gmail.com','adam  couey','2283 pachuta trl','clarksville','TN','UNITED STATES','37040-7743','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 18:18:09',0,NULL,3,1,1,1,'\\ ','adamcouey'),(9470,834424725012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',12.5,'eastar4','vtsbdg','bdg_vts@yahoo.gr','BILL GALANIS','VLACHERNAS<br>23','PERISTERI','ATHENS','GREECE','12131','2130082036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 18:19:45',0,NULL,3,1,2,1,'\\ ','vtsbdg\racer 8pin1.00 15cm'),(9471,751921006011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',2,'HSJA011',39.98,'eastar4uk','attractivebeast','skar002@hotmail.com','khurram shah','8 greenbank road,  greenbank','bristol','Bristol','UNITED KINGDOM','bs5 6ey','07824804157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 19:01:41',0,NULL,3,1,3,1,'RA183629655CN\r ','attractivebeast\rHSJA011\r英标'),(9472,834460840012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',97.99,'eastar4','elgen69','gao@godata.no','Geir Olsen','Løvjomås','Froland','Froland','NORWAY','N-4820','+4737373737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 19:30:12',0,NULL,3,1,3,1,'RA183629531CN ','elgen69\rGLOT001*2\r兼容型3D眼镜 通用型'),(9473,564311618004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','tharakafernando4','tharakaf24@gmail.com','tharaka fernando','150/8, Liyanagemulla<br>Seeduwa','Seeduwa','westen','SRI LANKA','11410','0094772920696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 19:33:10',0,NULL,3,1,3,1,'RA183629633CN\r ','tharakafernando4\rHSJA002'),(9474,564315823004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',43.8,'cnfaner','b2ven','be2ven@aol.com','Philip R. LePore','26 Hialeah Dr.','Albany','NY','UNITED STATES','12205','(518) 339-0850','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 19:39:26',0,NULL,3,1,1,1,'\\ ','b2ven'),(9475,751942270011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',59.99,'eastar4','joordaan13','jda1313@hotmail.com','jordan diaz','azcarraga 17 1 drcha','gijon','Asturias','SPAIN','33208','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 19:44:40',0,NULL,3,1,3,1,'RA183629205CN ','joordaan13\rGLSG001'),(9476,751942937011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','diaz6ybq','inujosha@yahoo.com','Joshua Diaz','111 1/2 N Washington St','EL DORADO','KS','UNITED STATES','67042-1852','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 19:45:41',0,NULL,3,1,1,1,'\\ ','diaz6ybq\racer 6pin1.25 23cm'),(9477,613685639013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','artur_makejev','arturs_makejevs@inbox.lv','Arturs Makejevs','Rostokas 26 - 15','Riga','LATVIA','LATVIA','LV-1029','+37126016740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 19:59:42',0,NULL,3,1,2,1,'\\ ','artur_makejev\r红边优联'),(9478,564321277004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','wiized','nicolas.lecomte2@laposte.net','Nicolas Lecomte','251 rue Jeanne d\'arc<br>Appartement E9','Nancy','Lorraine','FRANCE','54000','0674070166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 20:09:22',0,NULL,3,1,3,1,'RA183629620CN\r ','wiized\rWLAP008'),(9479,834482147012,220807319834,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',15.95,'eastar4','mighty_mo2','m.e.vernon@open.ac.uk','Maureen Vernon','40 Golden Drive','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK65BJ','01908608898','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-18 20:10:33',0,NULL,3,1,2,1,'\\ ','mighty_mo2\r黑底七色边彩虹伞 '),(9480,613685143013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','klmvalex','klmvlksndr@rambler.ru','Александр Климов','улица Шкулёва, дом 3, квартира 26','Москва','','RUSSIAN FEDERATION','109390','(926) 4906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 20:12:51',0,NULL,3,1,3,1,'RA183629647CN\r ','klmvalex\rWLIN014\r 通用'),(9481,833076829012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','janinemcdonnell','janinemcdonnell20@hotmail.co.uk','Janine McDonnell','6, Congress Street<br>Armley','Leeds','West Yorkshire','UNITED KINGDOM','LS12 3DY','07816942457','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 20:14:43',0,NULL,3,1,3,1,'RA183629704CN\r ','janinemcdonnell\rHSJA010\r英标'),(9482,834499533012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',12.5,'eastar4','perl2k7','t.katzenberger@live.de','Tilo Katzenberger','Seidenstrasse 26','Willich','','GERMANY','47877','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 20:49:27',0,NULL,3,1,2,1,'\\ ','perl2k7\r4pin 1.25 '),(9483,613730419013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','icmcl','icypmcl@guernsey.net','Ian McLennan','Noahs Ark, Braye du Valle','St Sampson, GUERNSEY','Channel Islands','UNITED KINGDOM','GY2 4RD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 22:41:40',0,NULL,3,1,2,1,'\\ ','icmcl'),(9484,558879440003,130553128921,'Genuine Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL017',35.9,'cnfaner','honeybeedog','jamesbeved@verizon.net','Beverly James','19632 Canberra Lane','Huntington Beach','CA','UNITED STATES','92646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 22:43:53',0,NULL,3,1,1,1,'、 ','honeybeedog\r旧的'),(9485,752005908011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','buli165','markbullion@googlemail.com','pam riding','10 Abbots Road<br>Burghfield Common','Reading','Berkshire','UNITED KINGDOM','rg7 3ld','01189834794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 22:48:08',0,NULL,3,1,3,1,'RA183629559CN ','buli165\rGLSG001'),(9486,752017025011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','bibichat','bibichat@gmail.com','Julien LEMPEREUR','1 RUE DU PETIT PARIS','JOUE LES TOURS','Centre','FRANCE','37300','+33660542776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 23:10:23',0,NULL,3,1,2,1,'\\ ','bibichat\r二代卡 旧'),(9487,752025153011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','svac10050','svac10050@aol.com','maurice evans','10712 Vista Lomas Dr','el paso','TX','UNITED STATES','79935-3611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 23:39:20',0,NULL,3,1,1,1,'\\ ','svac10050\r二代卡 旧'),(9488,752027549011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',8.9,'eastar4','mikeroter','mikeroter@earthlink.net','Michael A. Roter','11 Pine Valley Rd','Livingston','NJ','UNITED STATES','07039','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 23:49:49',0,NULL,3,1,1,1,'\\ ','mikeroter'),(9489,834571197012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',97.99,'eastar4','bkooz','bkooz@cox.net','Bill Kusma','222 Oak St','South Windsor','CT','UNITED STATES','06074-2342','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 00:18:15',0,NULL,3,1,1,1,'\\ ','bkooz\r兼容型3D眼镜 通用型'),(9490,752040991011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','2muchtorque','tappy@gotalk.net.au','Robyn Tapp','6 Forrest Street','Oak Flats','New South Wales','AUSTRALIA','2529','0407917868','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 00:47:30',0,NULL,3,1,2,1,'\\ ','2muchtorque\rProLee24K超轻碳纤骨长柄伞\r蓝色的'),(9491,564390705004,140519339941,'New Jabra BT320s StereoBluetooth Clip-On Earbud Headset',1,'HSJA003',23.7,'cnfaner','lafaious','jmhirtle@gmail.com','Joel Hirtle','2054 Maple Ct.','Coldbrook','NS','CANADA','B4R1C2','(902) 365-2391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 01:14:29',0,NULL,3,1,3,1,'RA183629580CN\r ','lafaious\rHSJA003'),(9492,752048116011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','bestyears1971','flavio@utsunomiya.org','Flavio Utsunomiya','Av do Guacá, 63 - Bl B - ap 62','Sao Paulo','Sao Paulo','BRAZIL','02435000','01122368589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 01:14:33',0,NULL,3,1,3,1,'RA183629602CN ','bestyears1971\rOTSO004\r盒装的'),(9493,752051837011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','mariachole','martha_23241@hotmail.com','maria soledad acevedo chavez','C. Mariano Matamoros 662','Tepatitlan de Morelos','Jalisco','MEXICO','47670','3781028924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 01:27:46',0,NULL,3,1,3,1,'RA183629514CN ','mariachole\rOTSO004\r盒装的'),(9494,8881313718405269,111,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','papawik','papa.virus@gmail.com','Viktor Krasitskyy','50/42 Velychkovskoho str.','Lviv','UA','UKRAINE','79002','',NULL,NULL,NULL,'2011-08-19 01:46:45',0,NULL,3,1,3,1,'\\ ','WLAP008 '),(9495,613768424013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*3',287.98,'eastar4','31serg2010','wwartrading@gmail.com','Alex Vulakh','10 Shore Blvd<br>Alla Gonchar Medical Pc Apt 1G','Brooklyn','NY','UNITED STATES','11235-4056','(917) 803-9711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 01:55:39',0,NULL,3,1,6,1,'EE495341140CN ','31serg2010\r兼容型3D眼镜 通用型'),(9496,613756220013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','kyle.parry','kyle.parry@gmail.com','Kyle Parry','415 Midland Hwy','Shepparton East','Victoria','AUSTRALIA','3631','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 01:56:06',0,NULL,3,1,2,1,'\\ ','kyle.parry\r不带壳的'),(9497,834601705012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',2,'WLIN001',51.98,'eastar4','takram','tahir@ositech.com','Tahir Akram','Ositech Communications<br>430 Laird Road #5','Guelph','ON','CANADA','N1G3X7','(519) 836-8063 ext.: 241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 02:05:52',0,NULL,3,1,3,1,'RA183629593CN\r ','takram\rWLIN001'),(9498,751262850011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','fakename1111','joshblomeyer@hotmail.com','JOSHUA BLOMEYER','2317 maynard dr','Duarte','CA','UNITED STATES','91010-2623','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 02:28:08',0,NULL,3,1,1,1,'\\ ','fakename1111'),(9499,752069140011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','qmac4849','quinn_mackenzie@symantec.com','Quinn Mackenzie','8 Keith Court','Portarlington','Victoria','AUSTRALIA','3223','0352593007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 02:33:12',0,NULL,3,1,2,1,' \\','qmac4849'),(9500,712647083001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','downtoearthdean','deanhubbard@comcast.net','Dean Hubbard','6 Stone Ridge Rd','Westford','MA','UNITED STATES','01886-6308','(978) 392-0949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 02:35:41',0,NULL,3,1,1,1,'\\ ','downtoearthdean'),(9501,834611594012,220815927904,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',2.29,'eastar4uk','freddykruger3','aquarius1211@bigpond.com','Errol Verner','1 Whitcomb St','Bald Hills','Queensland','AUSTRALIA','4036','0732618826','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 02:43:00',0,NULL,3,1,2,1,'\\ ','freddykruger3'),(9502,834610646012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','wake-work-eat-sleep-repeat','mdwagner1ebay@gmail.com','Mark Wagner','308 Great Quarter Rd','Sandy Hook','CT','UNITED STATES','06482-1513','(203) 364-1111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 02:43:47',0,NULL,3,1,1,1,'\\ ','wake-work-eat-sleep-repeat'),(9503,564406786004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.8,'cnfaner','hippieloungestore','hippielounge@hotmail.com','José Ramón Aldecoa Rendón','Aguadulce #407<br>Agua Dulce','Salamanca','Guanajuato','MEXICO','36730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 02:50:13',0,NULL,3,1,3,1,'RA183629545CN','hippieloungestore\rMOMI001美标'),(9504,613517113013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','alexkeaf','keaf@mail.ru','Alexandr Ovsyannikov','tereshkovoy 8a-30','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660055','904-895-0633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 02:54:29',0,NULL,3,1,2,1,'\\ ','alexkeaf'),(9505,8881313726095197,111,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'',0,'eastar4','milanmajkut','majkutmilan@gmail.com','Milan Majkut','Bottyanhegy str. 13. 3/13.','Szekszard','Tolna','HUNGARY','H7100','',NULL,NULL,NULL,'2011-08-19 03:54:55',0,NULL,3,0,2,1,'\\ ','发一个NOKIA BH-202 的红壳'),(9506,752090937011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','tongqing141222','nabraka@hotmail.com','TongQing Wang','Apt 6 - 88 Killarney AVE.','Winnipeg','MB','CANADA','R3T 3B2','(204) 510-7264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 04:15:44',0,NULL,3,1,2,1,'\\ ','tongqing141222'),(9507,613796149013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','jvburke','john_burke100@comcast.net','john burke','119 Encline Ct','san francisco','CA','UNITED STATES','94127-1837','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 04:24:12',0,NULL,3,1,1,1,'、 ','jvburke'),(9508,752040246011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','3rd-millennium-music','michael.tarrensweeney@newcastle.edu.au','Michael Tarren-Sweeney','464 Weedons Ross Rd<br>RD5','Christchurch','','NEW ZEALAND','7675','033474906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 04:57:58',0,NULL,3,1,2,1,'\\ ','3rd-millennium-music\r二代卡 旧\r\r\r'),(9509,712677756001,110728499418,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','magnus180379','magnusoverby@gmail.com','Magnus Øverby','Bjerregaards gate 45','Oslo','','NORWAY','0174','+4741233843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 05:15:20',0,NULL,3,1,3,1,'RA183629179CN ','magnus180379\rHSBS002'),(9510,613810025013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','jmberdon2','jmberdon@gmail.com','José María Berdonces Ortega','C/Fueros de Arnedo, 7, 3ºD','Arnedo','La Rioja','SPAIN','26580','635888962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 06:14:34',0,NULL,3,1,2,1,'\\ ','jmberdon2\r红边优联'),(9511,834660627012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','lclaybay','jlukeclayton@gmail.com','Luke Clayton','3421 Birchwood Cir','Murfreesboro','TN','UNITED STATES','37128-4624','(615) 796-7649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 06:40:15',0,NULL,3,1,1,1,'、 ','lclaybay'),(9512,8881313737630458,111,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',0,'eastar4','cinemalink','gregory@clink.com.au','Cinema Link','216 Victoria St','Beaconsfield','New South Wales','AUSTRALIA','2015','',NULL,NULL,NULL,'2011-08-19 07:07:10',0,NULL,3,0,2,1,'\\ ','补发的 \r24K超轻碳纤骨长柄伞 \r蓝色的'),(9513,752124989011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','jedi-fr','newjedi@free.fr','Mathias HARY','142 Rue Gambetta','SURESNES','Île-de-France','FRANCE','92150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 07:24:33',0,NULL,3,1,2,1,'、 ','jedi-fr'),(9514,8881313738696848,111,'New IBM Atheros AR5BXB72 AR5008 T60 Z60 R61 PCI-E card',1,'WLAT001',0,'eastar4','exogen_de','richard.w.schaetzl@gmx.de','Richard Schätzl','Sutelstr.54D','Hannover','','GERMANY','30659','',NULL,NULL,NULL,'2011-08-19 07:24:56',0,NULL,3,0,2,1,'、 ','补发的盒装的WLAT011\rIBMAR5008 '),(9515,752142401011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','mcui1028','cuicui@gmail.com','Miao Cui','530 Devonshire Ct','Mountain View','CA','UNITED STATES','94043-2187','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 08:43:52',0,NULL,3,1,1,1,NULL,'mcui1028'),(9516,692167457008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','tedblurter','husbandhire@hotmail.com','Adam FRY','49 Darlingsford Blvd<br>Melton','Melbourne','Victoria','AUSTRALIA','3337','0419552731','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 09:37:41',0,NULL,3,1,3,1,'RA183629390CN\r ','tedblurter\rHSPL005\r澳标'),(9517,613840152013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','cvidgaa','cvidgaa1@mail.ru','ANDREY GEROSHENKO','dom 9<br>ui. Sovhoznaya','Pushkinskiy rayon, derevnya Talitsi','Moscow region','RUSSIAN FEDERATION','141273','916-199-9942','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-08-19 09:44:41',0,NULL,3,1,3,1,'RA183629386CN\r ','cvidgaa\r欧标\rHSNO019'),(9518,752170633011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tmswensen','sweny@yahoo.com','Thomas Swensen','2704 Adele St','North Port','FL','UNITED STATES','34291','(941) 426-2592','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 10:42:45',0,NULL,3,1,1,1,'\\ ','tmswensen'),(9519,752179426011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','fotisgotsis1','fotisgotsis13@gmail.com','ΦΩΤΙΟΣ ΓΚΟΤΣΗΣ','ΜΑΡΑΘΩΝΟΣ 5','ΑΙΓΑΛΕΩ','ΕΛΛΑΔΑ/ΑΘΗΝΑ/ΑΤΤΙΚΗ','GREECE','12244','0306947376972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 11:14:53',0,NULL,3,1,2,1,'\\ ','fotisgotsis1\r盒装的'),(9520,752180743011,320441575399,'2.1 Acer Aspire 7110 7000 9300 Bluetooth Module +cable',1,'BTAC2108',12.4,'eastar4','leleu256','leleu256@hotmail.com','Leleu Nicolas','Rue pierre curie 26<br>derriere dexia','Soumagne','','BELGIUM','4630','0498615662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 11:23:34',0,NULL,3,1,2,1,'\\ ','leleu256\racer 4pin1.25 18cm '),(9521,751962331011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',125.98,'eastar4','marciocarvalhobsb2011','marciocarvalhobsb@gmail.com','Marcio Carvalho','SQS 313 bl F apt 306','brasilia','DF','BRAZIL','70382060','(061)99896970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 11:52:00',0,NULL,3,1,3,1,'RA183626172CN ','marciocarvalhobsb2011\rOTSO004\r盒装的'),(9522,834742321012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','psandmb','nycapital@hotmail.com','Parvez Sharifipour','PO Box 1118','latham','ny','UNITED STATES','12110','(518) 378-6959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 12:00:28',0,NULL,3,1,1,1,'\\ ','psandmb'),(9523,834746168012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','rach1265','paul@gcmotors.co.uk','Mrs R Woodhouse','31 Thistle Drive<br>Upton','Pontefract','West Yorkshire','UNITED KINGDOM','WF9 1NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 12:17:01',0,NULL,3,1,3,1,'RA183629275CN\r ','rach1265\r英标\rHBPH003'),(9524,752212669011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','mrbilldo','yardbird@vermontel.net','William Ballard','PO Box 84<br>6 Oak St','saxtons river','VT','UNITED STATES','05154','(802) 869-3161','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 13:06:26',0,NULL,3,1,1,1,'\\ ','mrbilldo'),(9525,752208082011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','pc911inc','pc911ebay@yahoo.ca','Alain Surprenant','3825 Beauchemin','Brossard','QC','CANADA','J4Z 2N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 13:08:52',0,NULL,3,1,2,1,'\\ ','pc911inc'),(9526,752221811011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','ampokp','okpenrod@hughes.net','OLGA K PENROD','4973 Boyce Rd','SEAFORD','DE','UNITED STATES','19973-6637','(302) 629-3124','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 13:37:06',0,NULL,3,1,1,1,'\\ ','ampokp\r2\"44pin'),(9527,613894355013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','timbob9093','timothy.garza@gmail.com','Timothy Garza','5998 N Willowdale Ln','Boise','ID','UNITED STATES','83714-5003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 14:05:26',0,NULL,3,1,1,1,'\\ ','timbob9093'),(9528,564433686004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.7,'cnfaner','mad_bass_player','4idlik@gmail.com','Oleg Barinov','9408 West Lawrence Avenue','Schiller park','IL','UNITED STATES','60176','847 778 9534','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 14:16:01',0,NULL,3,1,1,1,'\\  ','mad_bass_player\r通用版 全新'),(9529,834706883012,220786814503,'NIB Logitech 2.4GHz Wireless Mouse M215 + Nano receiver',1,'MOLO007',28.9,'eastar4','eltarta09','sebasilber@hotmail.com','sebastian','rambam 28/5','raanana','raanana','ISRAEL','43602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 14:34:01',0,NULL,3,1,2,1,'\\ ','eltarta09'),(9530,834803001012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','skuizy77','skuizy@gmail.com','Nicolas Delaunay','13 chemin des lys','Champs sur Marne','Ile-de-France','FRANCE','77420','0770020366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 14:57:02',0,NULL,3,1,2,1,'\\ ','skuizy77'),(9531,834803551012,220502334116,'2.1 HP NW8000 NC8230 Bluetooth Module EDR + cable',3,'BTHP2101',37.2,'eastar4','spirit_of_sixstar','boron.x555@gmail.com','Shinichiro Yokokawa','Azumachyo4-3-5','Iruma','Saitama','JAPAN','358-0002','+81 (080)7019-8225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 14:57:12',0,NULL,3,1,3,1,'RA183629412CN\r ','spirit_of_sixstar\rHP 8pin 1.0 3cm\rBTHP2101'),(9532,695152243008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','zaibjahanzaib','jahanzaib777777@yahoo.com','jahanzaib saleem','10 tempy court','broadmeadows','Victoria','AUSTRALIA','3000','0404533777','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 15:02:39',0,NULL,3,1,3,1,'RA183629474CN\r ','zaibjahanzaib\rHSPL005\r澳标'),(9533,752254790011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','msgech','msgech12@rambler.ru','Монахов Сергей','Жуковского, д.13/1, к.61','Арзамас','','RUSSIAN FEDERATION','607220','(7)9051921197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 15:11:30',0,NULL,3,1,2,1,'\\ ','msgech'),(9534,564527726004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',48.99,'cnfaner','gtx_le_newbee','craig.stratton@nf.sympatico.ca','Craig G Stratton','36 Link Pond Drive','Massey Drive','NL','CANADA','A2H7T8','(709) 634-4002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 15:13:57',0,NULL,3,1,3,1,'RA183626107CN\r ','gtx_le_newbee\rRCLO006\r新的'),(9535,752257648011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',29.98,'eastar4','australiasteve','stevejackson@stevejackson.com.au','Steve Jackson','532 Brighton Road','Brighton','South Australia','AUSTRALIA','5048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 15:19:21',0,NULL,3,1,2,1,'\\ ','australiasteve'),(9536,834799558012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','mr.bleckoff','bleckoff@hotmail.com','Marco Antonio Ribeiro de Olivera','Rua Caminho do Fragoso 478 F<br>Estrada da Saudade','Petrópolis -','Rio de Janeiro CEP','BRAZIL','25610430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 15:48:07',0,NULL,3,1,3,1,'RA183626257CN ','mr.bleckoff\rOTSO004*2\r盒装的'),(9537,834824855012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.99,'eastar4','glen9752','jen_dysart@yahoo.com','Glen Gauthier','42 Hamilton Ter','New York','NY','UNITED STATES','10031-6403','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 15:51:28',0,NULL,3,1,1,1,'\\ ','glen9752'),(9538,834826118012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','agotfred','andreas@nabolaget.org','Andreas Gotfredsen','ID 27 28 86 27<br>Døgnpost 102','København N','Denmark','DENMARK','2200','0045 27288627','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 15:54:16',0,NULL,3,1,2,1,'\\ ','agotfred'),(9539,834826980012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',8.99,'eastar4uk','k.rogusz','k.rogusz@yahoo.co.uk','Chris Rogusz','67 Rugby Place','Bradford','West Yorkshire','UNITED KINGDOM','BD7 2DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 15:57:08',0,NULL,3,1,3,1,'RA183626019CN\r ','k.rogusz\rHSMO010\r英标'),(9540,559069088003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','bshel20','shermanpimpco@hotmail.com','brandon  shelton','706 6th st.','duncan','NE','UNITED STATES','68634','(402) 910-5460','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 16:58:49',0,NULL,3,1,1,1,'\\ ','bshel20'),(9541,834855494012,220806892229,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','ssmith2678','bookiemonster@sbcglobal.net','Sharon Smith','4208 Churchill Rd','Leslie','MI','UNITED STATES','49251-9716','(517) 589-5546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 17:05:15',0,NULL,3,1,1,1,'\\ ','ssmith2678\r向日葵长柄伞  '),(9542,834859340012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','swamp2781','graham@gpmills.com','Graham Mills','163 Trysull Road<br>Merry Hill','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 7JP','01902336074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 17:14:46',0,NULL,3,1,3,1,'RA183629443CN\r ','swamp2781\r黑色的 \rOTCN004*10'),(9543,613946244013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','jusepe2882','jusepe28@gmail.com','Juan Carlos Serrano Perez','Fobos 15, - 11º . C','Madrid','Madrid','SPAIN','28030','669226695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 17:24:54',0,NULL,3,1,2,1,'\\ ','jusepe2882'),(9544,834867676012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','stapostle','mail@decross.ru','Nathanael de Cross','Brateevskaya st., 18k3, 108','Moscow','Moscow','RUSSIAN FEDERATION','115408','9166413884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 17:33:39',0,NULL,3,1,2,1,'\\ ','stapostle\r24K 多色伞 '),(9545,834876048012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','henrikjoh','henrik.johansson@miun.se','Henrik Johansson','Stapelmohrs v.18A','Östersund','','SWEDEN','83142','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 17:56:15',0,NULL,3,1,2,1,'\\ ','henrikjoh\r银色的欧标'),(9546,834882202012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.4,'eastar4','loud_whisper','rozhkov@dvblab.com','Alexander Rozhkov','c/Virgen de la Paloma 34 BIS 4-1','Torrevieja','Comunidad Valenciana','SPAIN','03182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 18:05:05',0,NULL,3,1,2,1,'\\ ','loud_whisper\racer 5pin1.25 15cm'),(9547,564542803004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.7,'cnfaner','sergeipelih','serg@bruki.net','Sergiy Pelykh','Zelenograd, korp.923, kw.104','Moscow','Moscow','RUSSIAN FEDERATION','124575','79166235333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 18:07:54',0,NULL,3,1,3,1,'RA183629491CN\r ','sergeipelih\rWWOT001\r通用版 全新'),(9548,834889237012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','tormod100','tossa100@hotmail.com','Tormod Meling','Nordveien 21','Ålgård','Gjesdal','NORWAY','4330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 18:18:16',0,NULL,3,1,3,1,'RA183628085CN ','tormod100\r盒装的\rOTSO004*2'),(9549,752332194011,320443637303,'Acer Timeline 4810 5810 Bluetooth Module 2.0 EDR+ cable',1,'BTAC2001',12.5,'eastar4','sprintertje48','evdh@kpnmail.nl','E. van den Heuvel','Topaas 28','Hoorn','','NETHERLANDS','1625 RM','0628487098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 18:27:58',0,NULL,3,1,2,1,'\\  ','sprintertje48\racer 4pin 1.25 3cm \r\r\r\r\r\r\r\r\r'),(9550,834897495012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','janebrink','anders_janebrink@yahoo.se','Anders Janebrink','Prejelvagen 143','Kungalv','Kungalv','SWEDEN','44244','0046-709-776620','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 18:36:32',0,NULL,3,1,3,1,'RA183626212CN\r ','janebrink\r欧标\rHSPL009'),(9551,559108156003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',16.99,'cnfaner','nano9600','liudas.pranevicius@ktu.lt','Liudas  Pranevicius','Vilties st. 25','Kaunas','','LITHUANIA','LT-46299','37068269086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 19:14:24',0,NULL,3,1,3,1,'RA183626098CN\r ','nano9600\rHSMO017\r欧标'),(9552,752321257011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',59.99,'eastar4','minorca69','filipesilva.pt@gmail.com','FILIPE SILVA','BES SA - AG OLIVEIRA DO BAIRRO<br>AV DR ABILIO PEREIRA PINTO 27/26','OLIVEIRA DO BAIRRO','OLIVEIRA DO BAIRRO','PORTUGAL','3770-201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 18:51:47',0,NULL,3,1,3,1,'RA183626226CN ','minorca69\rGLSG001'),(9553,613984140013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',113.1,'eastar4','rrij5353','richforrestt@live.nl','Raymond Rijkbost','Floris Versterstraat 35','Almere','','NETHERLANDS','1328 CR','06 51686136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 19:30:11',0,NULL,5,1,3,1,'RA183626075CN\r ','rrij5353\rCASS001+CASS002+CASS003\r一共买了两个CAB-SS-2626\r四个CAB-2660\r七个CAB-6060\r已发货'),(9554,752370121011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',57.99,'eastar4uk','moon1star2','s.craig916@hotmail.co.uk','stuart craig','16 padstow close','crewe','Cheshire','UNITED KINGDOM','cw13xw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 19:51:49',0,NULL,3,1,3,1,'RA183626124CN\r ','moon1star2\rGLOT001*2\r兼容型3D眼镜 通用型'),(9555,613994043013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','mishikoff','xmishik@gmail.com','Michael Zbarsky','Aharon Lublin 10/31','Lod','','ISRAEL','71471','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 20:01:57',0,NULL,3,1,2,1,'\\ ','mishikoff'),(9556,834944126012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','dgk4life89','dgk_4_life_89@yahoo.com','Seymour Bush','2108 Carrollton Dr','Columbus','OH','UNITED STATES','43223-3298','(614) 537-1653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 20:20:45',0,NULL,3,1,1,1,'\\ ','dgk4life89'),(9557,564613450004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','underdog911','mik16@cox.net','Michael Ginsberg','1111 Bayside Dr<br>Ste 100','Corona del Mar','CA','UNITED STATES','92625-1704','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 20:26:22',0,NULL,3,1,1,1,'\\ ','underdog911'),(9558,834957095012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','prockey111','j.e.hamer@web.de','Bettina Kimpfbeck','Westerwaldstr. 19 A','Ehringshausen-Greifenthal','','GERMANY','35630','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 20:45:13',0,NULL,3,1,2,1,'\\ ','prockey111\r欧标'),(9559,834965716012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','972elimoses5','elimoses5@walla.com','ELI MOSES','HASHEKMA 57','LAPID','israel','ISRAEL','73133','972 8 9766603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:09:00',0,NULL,3,1,3,1,'RA183626186CN ','972elimoses5\rOTSO004*2\r盒装的'),(9560,712946251001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','abay3000','gyromite2000@hotmail.com','Tammy Vorel','909 E Kenilworth Ave<br>Unit 121','Palatine','IL','UNITED STATES','60074-6444','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 21:10:45',0,NULL,3,1,1,1,'\\ ','abay3000'),(9561,752402935011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','pete22375','riv22375@verizon.net','PETER RIVERA','8 Roberta Ln','COMMACK','NY','UNITED STATES','11725-3816','(631) 462-4234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 21:20:33',0,NULL,3,1,1,1,'\\ ','pete22375\r二代卡 旧'),(9562,752414002011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 21:45:57',0,NULL,3,1,3,1,'RA183629505CN\r ','lochearn1234\rWLAP002\r二代卡 旧'),(9563,564635618004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',15.99,'cnfaner','asishmuel','asi_sharon@hotmail.com','asi shmuel','reim<br>reim','kibbutz reim','kibbutz reim','ISRAEL','85132','08-9940389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:54:36',0,NULL,3,1,3,1,'RA183626022CN\r ','asishmuel\rHSPL002'),(9564,834984832012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','chawkie1','chawkie@gmail.com','Carmelo Garrido','C/ LOPEZ DE HOYOS, 169-171, 3 Planta<br>INSS','Madrid','Madrid','SPAIN','28002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:56:55',0,NULL,3,1,2,1,'\\ ','chawkie1'),(9565,614029496013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','jrannear','jrannear@gmail.com','John Annear','6209 S Galena Ct','Englewood','CO','UNITED STATES','80111-5429','(303) 221-2322','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 22:17:27',0,NULL,3,1,1,1,'\\ ','jrannear'),(9566,695235377008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','cehenry.2009','craigehenry@sbcglobal.net','Craig Henry','7903 Carrie Ln','Pearland','TX','UNITED STATES','77584-9577','(713) 569-3410','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 22:33:24',0,NULL,3,1,1,1,'\\ ','cehenry.2009'),(9567,559159947003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','bobbie516','vantyr1982@aol.com','Barbara Tyrrell','70 Mariners Cv','Freehold','NJ','UNITED STATES','07728','(732) 780-4788','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 22:39:02',0,NULL,3,1,1,1,' \\','bobbie516'),(9568,752430881011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',57.99,'eastar4uk','tofy5771','mmacedo7@sapo.pt','Paula Lopes','Rua Ferreira da Silva nº 2','Lisboa','Lisboa','PORTUGAL','1900-229','218473526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 22:45:31',0,NULL,3,1,3,1,'RA183626115CN ','tofy5771\rGLOT001*2\r兼容型3D眼镜 通用型'),(9569,835001213012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','djtazie','djtazie@gmail.com','Mark Russell','Interfusion Networks , 1, Parkway House<br>Western Business Park, Ballymount,','Dublin 12','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 22:49:21',0,NULL,3,1,2,1,'\\ ','djtazie'),(9570,835001574012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','awpmaster','murjihalai@yahoo.com','Murji Halai','19 Adderley Road<br>Harrow Weald','London','Middlesex','UNITED KINGDOM','HA3 7HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 22:51:00',0,NULL,3,1,3,1,'RA183629369CN\r ','awpmaster\rOTCN004*10\r黑色的'),(9571,752438579011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.8,'eastar4uk','robthegorilla','robfrew@gmail.com','Rob Frew','RMG Target<br>20 Northumberland Road','Ballsbridge','Dublin','IRELAND','4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 23:32:02',0,NULL,3,1,3,1,'RA183629426CN\r ','robthegorilla\r一共买了两个\rWLAP002'),(9572,614045500013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','sfox','grim_jack@rogers.com','Andrew Paton','15 Marshall Ave','Ottawa','ON','CANADA','K1Z 7X1','(613) 728-6023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 23:40:16',0,NULL,3,1,3,1,'RA183626141CN ','sfox\r盒装的\rOTSO004*4'),(9573,752448684011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tagliat123','tagliat@sunysuffolk.edu','thomas tagliaferro','15 longacre ct','port jefferson','NY','UNITED STATES','11777','(631) 655-7306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-19 23:54:16',0,NULL,3,1,1,1,'\\ ','tagliat123\r一共买了两个'),(9574,835020793012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','cyclepathology','cyclepathology@yahoo.com','Timothy Lines','108 Bent Tree Ln','Pacific','WA','UNITED STATES','98047-1398','(253) 735-9414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 00:04:03',0,NULL,3,1,1,1,'\\\\ ','cyclepathology'),(9575,614052160013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','satien37','micket.donald@laposte.net','SEBASTIEN BISSON','4 RUE DES VIGNES','VILLEDOMER','Centre','FRANCE','37110','33247558114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 00:19:11',0,NULL,3,1,3,1,'RA183628045CN\r ','satien37\rGLOT002+GLOT003'),(9576,752455564011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tagliat123','tagliat@sunysuffolk.edu','thomas tagliaferro','15 longacre ct','port jefferson','NY','UNITED STATES','11777','(631) 655-7306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 00:25:39',0,NULL,3,1,17,0,NULL,'tagliat123'),(9577,835032614012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','jano_66','jano_66@poczta.fm','Janusz Bystryk','6446 W 86th St','Burbank','IL','UNITED STATES','60459-2316','(773) 787-3571','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 00:55:46',0,NULL,3,1,1,1,'\\ ','jano_66'),(9578,752463864011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',1,'HSSE009',65.99,'eastar4','anthonyclerric23','clerric23@yahoo.com.au','Anthony Dentice','24 Wyeree Rd','Mandurah','Western Australia','AUSTRALIA','6210','610895868775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 01:05:11',0,NULL,3,1,3,1,'RA183628054CN ','anthonyclerric23\rHSSE009\r澳标'),(9579,614061462013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','jdin9830','jjdinand@axion.ca','Jean-Jacques Dinand','547, rue Principale','Eastman','QC','CANADA','J0E1P0','(450) 297-9962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 01:15:23',0,NULL,3,1,3,1,'RA183626209CN ','jdin9830\rHBPH005\r盒装的'),(9580,752468489011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',4,'CCGR001',27.52,'eastar4','iwant2buylow','ken.d.tom@gmail.com','Ken Tom','37 Melville Road','Arnprior','ON','CANADA','K7S 3Z8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 01:23:33',0,NULL,3,1,2,1,'\\ ','iwant2buylow'),(9581,614070845013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.98,'eastar4','jrbloom2','jrbloom.au@hotmail.com','Juan Bloom','317 Beaudesert-Nerang Rd, Nerang','Gold Coast','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 02:09:10',0,NULL,3,1,2,1,'\\ ','jrbloom2'),(9582,752492406011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','ihsbmoore','bob.moore@att.net','R Moore','6501 Linway Ter','McLean','VA','UNITED STATES','22101-4111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 03:17:42',0,NULL,3,1,1,1,'\\ ','ihsbmoore'),(9583,614085262013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','darkmauros14','dark_mauros@hotmail.com','Yensi Rivas','65 robin hood Ln','freedom','NH','UNITED STATES','03836-4541','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-08-20 03:39:24',0,NULL,3,1,6,1,'EE495341136CN ','darkmauros14\r新地址\rYensi Rivas\rVE 20010 Mauricio Gonzalez 8536 NW 66 ST Miami FL 33166\rUNITED STATES\r\r\r\r'),(9584,834863050012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','thomashl','thomashollier@yahoo.com','Thomas Hollier','1756 Washington Way','Venice','CA','UNITED STATES','90291-4702','(310) 463-1327','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 03:44:31',0,NULL,3,1,1,1,'\\ ','thomashl'),(9585,835073890012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',35,'eastar4uk','dksavage1','dksavage@gmail.com','David K. Savage','1 / 1 Pridmore Rd','Glen Osmond','South Australia','AUSTRALIA','5064','0419830093','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-20 04:21:20',0,NULL,3,1,3,1,'RA183626084CN\r ','dksavage1\rBAZA001'),(9586,695392253008,180699060966,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',3,'HSPL002',38.97,'au-buy','ronaldruthven-123','ronaldruthven@hotmail.com','Ronald Ruthven','8220 brownell rd','richmond','BC','CANADA','v6x1g4','(604) 278-4527','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 04:55:24',0,NULL,3,1,3,1,'RA183629236CN\r ','ronaldruthven-123\rHSPL002'),(9587,559214843003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',16.99,'cnfaner','gogh0','samuel.berube@polymtl.ca','Samuel Berube','1312 de Val-Brillant','Laval','QC','CANADA','H7Y 1V9','(450) 314-2217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 05:12:59',0,NULL,3,1,3,1,'RA183629240CN\r ','gogh0\rHSPL005'),(9588,835094097012,220705174904,'New Genuine Motorola H555 Bluetooth Wireless Headset',1,'HSMO008',8.99,'eastar4uk','shortsircut','shortsircut1@gmail.com','Timothy Haas','27 Elderberry Cir','Rochester','NY','UNITED STATES','14625-2614','(585) 455-6792','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-20 05:51:24',0,NULL,3,1,1,1,'\\ ','shortsircut'),(9589,752532317011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',2,'BTHP2111',24.8,'eastar4','blackrider_98','verkaeufehans@gmx.at','Hans Grosser','Beingasse 10/17','Wien','','AUSTRIA','1150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 07:13:11',0,NULL,3,1,2,1,'\\ ','blackrider_98\rHP 8pin 1.25 25cm '),(9590,614114303013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',9.99,'eastar4','slabastar','spbslaba@seznam.cz','Tomas Slaby','Okruzni 4731','Zlin','Czech republic','CZECH REPUBLIC','76005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 07:31:27',0,NULL,3,1,2,1,'\\ ','slabastar'),(9591,835117389012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',2,'HSPL005',17.98,'eastar4uk','ss.stevey','steve.senior@blueyonder.co.uk','steven senior','18,inglewood<br>darton','barnsley','South Yorkshire','UNITED KINGDOM','S755ny','01226391122','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 07:46:22',0,NULL,3,1,3,1,'RA183629267CN\r ','ss.stevey\rHSPL005\r英标'),(9592,835119757012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','alex2340','alex.williams340@btinternet.com','alex williams','9 charnwood close','hinckley','Leicestershire','UNITED KINGDOM','LE101PU','01455612113','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 07:55:56',0,NULL,3,1,3,1,'RA183629488CN\r ','alex2340\rWLAP001+WLAP004'),(9593,613002064013,230660597526,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',19.99,'eastar4','sylvain1478','tatooin@hotmail.com','sylvain JAUSSAUD','2 chemins des verrières bâtiment F','Charbonnières les Bains','Rhône-Alpes','FRANCE','69260','0679470420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 08:30:21',0,NULL,3,1,2,1,'\\ ','sylvain1478'),(9594,835135141012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','trom_player','michaelredhead04@gmail.com','MR M REDHEAD','26 Gildenburgh Avenue','Peterborough','Cambridgeshire','UNITED KINGDOM','PE1 4RF','01733760829','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 08:56:11',0,NULL,3,1,3,1,'RA183629165CN\r ','trom_player\rWLAP001+WLAP004'),(9595,752556648011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','raphaelk3288','rjk@swissonline.ch','Raphael Keene','Valeriane 109<br>Rue de la Pretaire 32a','Verbier','','SWITZERLAND','1936','41789200706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 09:02:01',0,NULL,3,1,2,1,'\\ ','raphaelk3288'),(9596,752562885011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','andreyatgb','costescu_andrei1975@yahoo.co.uk','Andrei Costescu','Laberget 94, H0203','Stavanger','Rogaland','NORWAY','4020','+4746240048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-20 09:28:20',0,NULL,3,1,2,1,'\\ ','andreyatgb'),(9597,752594956011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','rjagadee27','rk.jagadeeswaran@gmail.com','Rajesh K. Jagadeeswaran','5170 Winston Churchill Blvd<br>Suite 212','Mississauga','ON','CANADA','L5M 0P2','(416) 706-1452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 11:33:59',0,NULL,3,1,3,1,'RA183629457CN\r ','rjagadee27\rHBPH002'),(9598,614156211013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',10,'CCGR001',68.8,'eastar4','almohnds','eng.emad99@gmail.com','EMAD MOHD ALASKAR','P.O.BOX 674','HAIL','HAIL','SAUDI ARABIA','81421','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 11:35:32',0,NULL,3,1,3,1,'RA183628955CN\r ','almohnds\rCCGR001'),(9599,752600218011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','**xenon**','markus_rowe@hotmail.co.uk','Mark Rowe','17a East Street<br>Bedminster','Bristol','Avon','UNITED KINGDOM','bs3 4hh','07827915174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 11:48:52',0,NULL,3,1,3,1,'RA183629430CN\r ','**xenon**\rRELO003\r红边优联'),(9600,835246850012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','evgeniy_spb','spb_evg@rambler.ru','Evgeniy Yurshin','Pushkin, Jeleznodorognaya street, house 76 flat 47','Saint-Petersburg','','RUSSIAN FEDERATION','196606','+79213027839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 14:53:47',0,NULL,3,1,2,1,'\\ ','evgeniy_spb\r24K 多色伞 '),(9601,752662569011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','haddad30','ang_haddad@yahoo.com','Angela Haddad','34009 N 23rd Dr','Phoenix','AZ','UNITED STATES','85085-5042','(602) 690-7634','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 15:01:13',0,NULL,3,1,1,1,'\\ ','haddad30'),(9602,614205632013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','david-dc','david.decock@live.be','David De Cock','Begonialaan<br>2','Ranst','','BELGIUM','2520','0478720895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 15:08:08',0,NULL,3,1,2,1,'\\ ','david-dc\rCAB-6060'),(9603,614221615013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','dawcx','christopher_daw@live.com','Christopher Daw','11118 67 ave','Grande Prairie','AB','CANADA','T8W 0B1','(780) 833-1108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 16:13:44',0,NULL,3,1,3,1,'RA183629219CN\r ','dawcx\rWWOT001+ANCN001'),(9604,752691774011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','fernandowashington','laspalabrasquenoexisten@gmail.com','Daniel Garcia Gonzalez','Barrio Zurbaranbarri, 36 - 2B','Bilbao','País Vasco','SPAIN','48007','(679) 139-234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 16:20:56',0,NULL,3,1,2,1,'\\ ','fernandowashington\r二代卡 旧'),(9605,835289938012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','wg4711','wg4711@arcor.de','Wolfgang Garske','Helene-Engelbrecht-Str. 85','Braunschweig','','GERMANY','38124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 16:39:03',0,NULL,3,1,2,1,'\\ ','wg4711'),(9606,752711224011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','ronic1985','ronic1985@hotmail.com','ISRAEL GONZALEZ RODRIGUEZ','C/SANTIAGO Nº16','SANLUCAR LA MAYOR','SEVILLA','SPAIN','41800','675804295','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 17:10:56',0,NULL,3,1,2,1,'\\ ','ronic1985\rHP 8pin 1.25 18cm '),(9607,752715450011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','big.de','ioob@sbcglobal.net','Dennis Williams','8025 Croydon Avenue','Los Angeles','CA','UNITED STATES','90045','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 17:19:48',0,NULL,3,1,1,1,'\\ ','big.de'),(9608,564841694004,140584761903,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',34.99,'cnfaner','molodykh','a.molodykh@gmail.com','Alexander Molodykh','Marshala Vasilevskogo 7-2-212','Moscow','Moscow','RUSSIAN FEDERATION','123098','(916) 234-94-00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 17:46:19',0,NULL,3,1,3,1,'RA183628037CN\r ','molodykh\rMOMI003'),(9609,752729403011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','nenade1974','denenami@googlemail.com','Dejan Popovic','Adolf-alter-str.:3','Heilbronn','','GERMANY','74080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 17:52:11',0,NULL,3,1,2,1,'\\ ','nenade1974'),(9610,564853852004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','shusak','orders@husak.com','Stephen Husak','12209 Keats Grove Ct','Glen Allen','VA','UNITED STATES','23059','(804) 360-4584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-20 18:28:20',0,NULL,3,1,1,1,'\\ ','shusak'),(9611,752771016011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','godmadenotredameno1','godmadenotredameno1@netzero.net','Matthew Roblez','437 E. Lambourne Ave.','Salt Lake City','UT','UNITED STATES','84115','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 19:24:30',0,NULL,3,1,1,1,'\\ ','godmadenotredameno1'),(9612,835371563012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','bonyoviboidar','jovovicbozo@hotmail.com','Jovović Božidar','varošlučki put bb','72283 TURBE','Bosnia and Herzegovina','BOSNIA AND HERZEGOVINA','387','++38761285785','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-20 19:39:52',0,NULL,3,1,2,1,' \\','bonyoviboidar\r通用版'),(9613,752786735011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',32,'eastar4','thyolo','dredwd@yahoo.com','Edward A Parish','8344 Noblet Rd','Davison','MI','UNITED STATES','48423-8791','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 20:04:04',0,NULL,3,1,1,1,'\\ ','thyolo'),(9614,614293471013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',46.99,'eastar4','krekels','krekels@ej-online.de','Elektro Jansen','Grebbenerstr. 20<br>Herr Krekels','Heinsberg','','GERMANY','52525','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 20:11:33',0,NULL,3,1,3,1,'RA183626053CN\r ','krekels\rWWSI004+ANCN001'),(9615,752799982011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','klmvalex','klmvlksndr@rambler.ru','Aleksandr Klimov','ul. Shkuljova, d.3, kv.26','Moskva','','RUSSIAN FEDERATION','109390','+79264906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 20:45:05',0,NULL,3,1,2,1,'\\ ','klmvalex'),(9616,614310040013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','pitzel','chris.pitzel@usask.ca','Chris Pitzel','34 Edelweiss Crescent','Moose Jaw','SK','CANADA','S6J1E5','(306) 692-5819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 21:09:01',0,NULL,3,1,2,1,'\\ ','pitzel'),(9617,614322016013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dahinda4','hawaii4gm@wideopenwest.com','peter denando','2704 Tiffany Ct','Naperville','IL','UNITED STATES','60565-3083','(630) 390-6903','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 21:57:11',0,NULL,3,1,1,1,'\\ ','dahinda4'),(9618,559426552003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','promted','promted@hotmail.com','Seth Wiscombe','571 E 500 N<br>Apt 4','Logan','UT','UNITED STATES','84321-4192','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-20 22:04:47',0,NULL,3,1,1,1,'\\ ','promted'),(9619,835434728012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.4,'eastar4','suhheuge','suhheuge@yahoo.com','Eugene H. Suhh','18204 Sheffield Ln','Northridge','CA','UNITED STATES','91326-3609','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-20 22:17:09',0,NULL,3,1,1,1,'\\ ','suhheuge'),(9620,752634609011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','bcshutterbug','autosmith@lakecable.ca','Tim Smith','PO Box 296','Sorrento','BC','CANADA','V0E 2W0','(250) 804-7910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 22:44:19',0,NULL,3,1,2,1,'\\ ','bcshutterbug'),(9621,835445968012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',21.99,'eastar4uk','daveyg05','david@planet-mono.net','Mr David Grierson','118 Cudham Lane North<br>Cudham','Sevenoaks','Kent','UNITED KINGDOM','TN14 7QS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 22:56:10',0,NULL,3,1,3,1,'RA183629253CN\r ','daveyg05\rWWSI002+ANCN001'),(9622,614337749013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','macintorres','egtorres@ig.com.br','Eduardo Torres','Av. Santa Cruz, 11806 - Village das Hortências, Casa 45<br>Santíssimo','Rio de Janeiro','Rio de Janeiro','BRAZIL','23010-002','55 21 81037078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 23:05:57',0,NULL,3,1,2,1,'\\ ','macintorres'),(9623,614358835013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',43.5,'eastar4','xenomorphus83','patryk.wolowiec@gmail.com','Patryk Wolowiec','52 courtyard<br>watercourse road','cork','Cork','IRELAND','05','0862551430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 01:02:31',0,NULL,3,1,3,1,'RA183629222CN\r ','xenomorphus83\rCASS003\rCAB-6060'),(9624,752907278011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','bocalu99268s','bocalu99@aol.com','Benjamin H Boas','732 N Hayworth Ave','Los Angeles','CA','UNITED STATES','90046','(412) 999-2979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 03:18:50',0,NULL,3,1,1,1,'\\ ','bocalu99268s'),(9625,835516027012,220812865819,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',75.99,'eastar4','heresgreatvalue','jazsy4@aol.com','Kenneth Caracciolo','33000 Portofino Cir<br>Apt # 109','Palm Beach Gardens','FL','UNITED STATES','33418','(561) 818-2056','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 03:26:12',0,NULL,5,1,1,1,NULL,'heresgreatvalue'),(9626,835544290012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','perrij20','jez.perriman@googlemail.com','Jez Perriman','36 High Street<br>Great Paxton','St. Neots','Cambridgeshire','UNITED KINGDOM','PE196RF','447764354955','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 05:52:12',0,NULL,3,1,3,1,'RA183626067CN\r ','perrij20\rOTHP004'),(9627,564980899004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','ramezsalib','dr_ramezlotfy@yahoo.com','Ramez Salib','Chempro Chemist Mermaid Beach<br>2506 Gold Coast High Way','Mermaid Beach','Queensland','AUSTRALIA','4218','0405187377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 05:52:39',0,NULL,3,1,3,1,'RA183629355CN\r','ramezsalib\rMOOE001\r发OEM的'),(9628,752945129011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','l300van','graham.martin@tpg.com.au','Graham Martin','57 Collins St','Woody Point','Queensland','AUSTRALIA','4019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 06:51:48',0,NULL,3,1,2,1,'\\ ','l300van'),(9629,752947984011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',5,'WLAP002',80,'eastar4','spybag55','macfanosx@gmail.com','Jelle De Jong','Fiskers Lake 12','Haren Ems','','GERMANY','49733','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 07:03:27',0,NULL,3,1,3,1,'RA183629465CN\r ','spybag55\rWLAP002'),(9630,752953127011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','socionom_volos','antonakis.nikos@gmail.com','NIKOS ANTONAKIS','KAZANTZAKI 40','VOLOS','MAGNISIA','GREECE','38333','+30-24210-51568','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 07:25:08',0,NULL,3,1,2,1,'\\ ','socionom_volos'),(9631,614423014013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','darvikon','xemich@gmail.com','Stepan Polovnikov','Tropinina 61-35','Nizhniy Novgorod','Nizhniy Novgorod','RUSSIAN FEDERATION','603137','+79101033427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 08:01:16',0,NULL,3,1,3,1,'RA183626040CN\r ','darvikon\rWLIN014+MOCN001\r再发一个Bracket of half intel 5300 6250 wireless card to pci-e'),(9632,752963049011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','darvikon','xemich@gmail.com','Stepan Polovnikov','Tropinina 61-35','Nizhniy Novgorod','Nizhniy Novgorod','RUSSIAN FEDERATION','603137','+79101033427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 08:02:28',0,NULL,3,1,17,0,' ','darvikon'),(9633,752973892011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','wihbeh','wihbeh@yahoo.ca','SAMIR WIHBEH','4838 EDWARD','PIERREFONDS','QC','CANADA','H8Y2C9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 08:44:30',0,NULL,3,1,2,1,'\\ ','wihbeh\rHP 8pin 1.25 25cm '),(9634,559527730003,130458644453,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET track#',1,'HSNO015',35.99,'cnfaner','hila198','hila@odemnet.co.il','Uri Tabak','14720 184th St<br>Odem Technologies','JAMAICA','NY','UNITED STATES','11413-4056','(718) 995-2900','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-21 08:55:39',0,NULL,3,1,1,1,'\\ ','hila198'),(9635,614435981013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','vertigo0047','arnstein.aas1@gmail.com','Arnstein Aas','skarsjyveien 69','Ballstad','Ballstad','NORWAY','8373','+4747015451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:03:06',0,NULL,3,1,2,1,'\\ ','vertigo0047'),(9636,752969694011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',143.99,'eastar4','nafaenuman','mwajidali@gmail.com','Mohammed Wajid Ali','Saudi Allied Metal Industries<br>Industrial Street, Phase # 4','Jeddah P.O. Box# 3711','Western','SAUDI ARABIA','21481','+966502528853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:10:56',0,NULL,3,1,3,1,'RA183626708CN\r ','nafaenuman\rGLOT001*3\r兼容型3D眼镜 通用型\r'),(9637,835610441012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','haavard7474','haavarddw@gmail.com','Håvard Austad Wiik','Vollabakken 17A','default','Trondheim','NORWAY','7030','41437312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:42:56',0,NULL,3,1,3,1,'RA183626169CN ','haavard7474\r盒装的\rOTSO004*2'),(9638,752998441011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','voltaire.insoft','fboluda@ono.com','Francisco Boluda Montoyo','C/ San José, 15, 3º Izquierda','San Vicente del Raspeig','Comunidad Valenciana','SPAIN','03690','686014829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:49:03',0,NULL,3,1,3,1,'RA183629324CN\r ','voltaire.insoft\rWWSI002+ANCN001'),(9639,614452826013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','valera-k','valera@krilov.net','Valeriy Krylov','Osenniy bulv. 20-1-47','Moscow','','RUSSIAN FEDERATION','121614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 10:11:27',0,NULL,3,1,2,1,'\\ ','valera-k'),(9640,753025755011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','cobrose','leo.doyle@dkib.com','leo doyle','cob cottage, 7 faggot yard','Braintree','Essex','UNITED KINGDOM','CM75SJ','1376348024','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 11:03:00',0,NULL,3,1,3,1,'RA183626036CN\r ','cobrose\rRELO003\r红边优联'),(9641,614466649013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',71,'eastar4','waheeb00','waheeb_abdullah@yahoo.com','Waheeb Abdulrahman','P.O. Box 37791','Abudhabi','','UNITED ARAB EMIRATES',',','00971506224201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 11:06:55',0,NULL,3,1,3,1,'RA183628023CN ','waheeb00\rGLOT005\r投影仪兼容眼镜'),(9642,614468795013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','virtual_yowie','david.j.ridgway@gmail.com','David Ridgway','8 Ramona Court','Boronia','Victoria','AUSTRALIA','3155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 11:14:10',0,NULL,3,1,2,1,'\\ ','virtual_yowie'),(9643,753035056011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',103.47,'eastar4','basicmoto','danieljanson@me.com','Daniel Janson','32034209<br>Packstation 113','Mainhardt','','GERMANY','74535','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 11:28:25',0,NULL,3,1,3,1,'RA183629341CN\r ','basicmoto\rUDAP001'),(9644,835477334012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','cp_mailman1','cparas@iinet.net.au','Chris Paras','4 Edwin St South','Croydon','New South Wales','AUSTRALIA','2132','0297160602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 11:29:56',0,NULL,3,1,3,1,'RA183626190CN ','cp_mailman1\rOTSO004*2\r盒装的'),(9645,835680694012,220816334369,'New Clear Transparent Dome Rain Sun Umbrella with trim',1,'UMTR001',15.95,'eastar4','pimp160686','pimp009@mail.ru','Azat Timirshin (Азат Тимиршин)','Russia,Tatarstan, c. Laishevo, Melioratorov  str, 16<br>Россия,Татарстан, г. Лаишево, ул. Мелиораторов д.16)','Laishevo (Лаишево)','Tatarstan (Татарстан)','RUSSIAN FEDERATION','422610','+79061158580','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 12:36:29',0,NULL,5,0,18,0,NULL,'pimp160686\r黑色的\r等客户要撤单'),(9646,753064376011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','n4abid','mjsheu@hotmail.com','Miller Sheu','8522 River Cliff Ln','Houston','TX','UNITED STATES','77095-5193','(832) 566-1375','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 12:44:21',0,NULL,3,1,1,1,'\\ ','n4abid'),(9647,753063759011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','carolyn1219','carolyn615@hotmail.com','Carolyn Fagaly','10444 S 27th St','Vicksburg','MI','UNITED STATES','49097','(269) 327-2842','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 12:45:03',0,NULL,3,1,1,1,'\\ ','carolyn1219\r红边优联'),(9648,695908135008,180699062016,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',34.49,'au-buy','paul091277','paul808@me.com','Paul Elphinston','Mercedes Benz Sydney<br>43-47 Oriordan st','Alexandria','New South Wales','AUSTRALIA','2015','0412375808','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 12:57:43',0,NULL,3,1,3,1,'RA183629284CN\r ','paul091277\rUDAP001'),(9649,835701187012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','mehanic01','paul.pitsikalis@rogers.com','Paul Pitsikalis','3342 sundew crt.','Mississauga','ON','CANADA','L5N5X4','(905) 785-3887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 13:22:24',0,NULL,3,1,2,1,'\\ ','mehanic01'),(9650,614518029013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',26.1,'eastar4','cris-styler','christian.kaulfuss@googlemail.com','Christian Kaulfuß','Friedrich-Franz-Str. 17','Berlin','','GERMANY','12103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 14:04:06',0,NULL,3,1,2,1,'\\ ','cris-styler\rCAB-6060'),(9651,753108702011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','bruehlerjung00','engels.b@t-online.de','Bernd Engels','Wehrbachsweg 125','Brühl','','GERMANY','50321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 14:29:56',0,NULL,3,1,2,1,'\\ ','bruehlerjung00'),(9652,614522640013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','lassekl','lassekleppe@hotmail.com','Lasse Kleppe','Skjoldlia 16<br>5236 Rådal','Bergen','Hordaland','NORWAY','5239','004798628096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 14:30:16',0,NULL,3,1,3,1,'RA183626230CN ','lassekl\r盒装的\rOTSO004*4'),(9653,614529547013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','dodmcdund','fredguile@gmail.com','Frédéric Ghilini','24, rue Pétion','Paris','Île-de-France','FRANCE','75011','0618580469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 14:39:26',0,NULL,3,1,2,1,'\\ ','dodmcdund'),(9654,753133610011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','ecummins613','ecummins@rogers.com','E Cummins','2740 Moncton Road','Ottawa','ON','CANADA','K2B 7W1','(613) 421-3989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 15:22:55',0,NULL,3,1,2,1,'\\ ','ecummins613'),(9655,835792136012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','rodmaiabr','rodmaia@gmail.com','RODRIGO MAIA','AV. BOA VIAGEM, 2682 - AP. 501','RECIFE','PERNAMBUCO','BRAZIL','51020-000','+55 81 33277555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 16:12:47',0,NULL,3,1,3,1,'RA183629298CN\r ','rodmaiabr\rWWOT001\r通用版 全新'),(9656,559635750003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','eric.vander.schilden','evanders@yahoo.com','Eric van der Schilden','Kazimierza Wielkiego 118/36','Krakow','małopolskie','POLAND','30-082',' 783109485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 16:12:53',0,NULL,3,1,3,1,'RA183629315CN\r ','eric.vander.schilden\rUDAP001'),(9657,753209011011,320730548919,'3 pair 3D Active Shutter TV Glasses 4 Mitsubishi TV',1,'GLOT001*3',84.99,'eastar4uk','zbych1183','zbyszek8311@wp.pl','Zbigniew Grzelka','Sprint Point, Dolomite Avenue<br>Coventry Business Park','Coventry','West Midlands','UNITED KINGDOM','cv56us','07971723421','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 17:22:33',0,NULL,3,1,3,1,'RA183626243CN ','zbych1183\rGLOT001*3\r兼容型3D眼镜 通用型'),(9658,753212249011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','303british60','gary.arntsen@dfs.virginia.gov','Gary Arntsen','10600 Reeds Landing Cir','Burke','VA','UNITED STATES','22015-2551','(703) 335-8100 ext.: 44621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 17:28:24',0,NULL,3,1,1,1,'\\ ','303british60'),(9659,753218239011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','junecat8','cathysimi@comcast.net','Catherine Simi','128 Briar Place','Danville','CA','UNITED STATES','94526-1700','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 17:34:37',0,NULL,3,1,1,1,'\\ ','junecat8'),(9660,835927153012,220793674473,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',135.99,'eastar4','lrswafford','lisaswaf@fuse.net','Lisa Swafford','2630 Crest Rd','Cincinnati','OH','UNITED STATES','45231-1117','(513) 368-6546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 19:00:47',0,NULL,3,1,1,1,'\\ ','lrswafford\r盒装的'),(9661,835935396012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','itzik88','itzik@r-tco.com','itzik kedem','nof sadot 303','olesh','asharon','ISRAEL','42855','972-52-8742502','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 19:08:18',0,NULL,3,1,2,1,'\\ ','itzik88'),(9662,753295698011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','jmd916','famduch@cegetel.net','Jean-Marc DUCHENE','200 rue du coin','MARIGNIER','Rhône-Alpes','FRANCE','74970','0450187774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 19:12:37',0,NULL,3,1,2,1,'\\ ','jmd916'),(9663,614674839013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','jbor4700','jf.borg@yahoo.com','Jmaes Borg','3182 Ravinia CIR','Mundelein','IL','UNITED STATES','60060-6024','(847) 778-7275','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-21 19:32:44',0,NULL,3,1,1,1,'\\ ','jbor4700'),(9664,835973860012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','jrbdeal','joe_barrington@hp.com','Joe Barrington','3954 Rawhide Rd','Rocklin','CA','UNITED STATES','95677','(916) 632-1001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 19:57:50',0,NULL,3,1,1,1,'\\ ','jrbdeal'),(9665,614704220013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','marc_queiroz','marc.queiroz@gmail.com','SHIRLEI C N DE ALMEIDA','Rua Prudente de Moraes, 92. Centro.','Rolandia','Parana','BRAZIL','86600-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 20:36:47',0,NULL,3,1,2,1,'\\ ','marc_queiroz'),(9666,752488111011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',35.9,'eastar4uk','arvageo','arva@freemail.gr','George Arvanitis','Vas. Constantinou 21','Maroussi','Attica','GREECE','15122','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 20:54:35',0,NULL,3,1,3,1,'RA183628010CN ','arvageo\rMOLO005\r欧标\r蓝牙版旧的'),(9667,559790331003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',22.8,'cnfaner','mikhailkutyrev','tirlah@gmail.com','Mikhail Kutyrev','prospekt Lenina <br>dom 14 kvartira 75','Yoshkar-Ola','Mari El','RUSSIAN FEDERATION','424038','987-722-4863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 20:57:44',0,NULL,3,1,3,1,'RA183629372CN\r ','mikhailkutyrev\rHSSE003\r欧标'),(9668,836015009012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',57.99,'eastar4uk','kenny.675','kig1971@live.co.uk','paul smith','120 esk avenue<br>corkickle','whitehaven','cumbria','UNITED KINGDOM','ca288al','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 21:03:15',0,NULL,3,1,3,1,'RA183626138CN ','kenny.675\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(9669,753371787011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','mathique','mathieu_tremblay@hotmail.com','Mathieu A. Temblay','681, rue de Dublin','Mont-Saint-Hilaire','QC','CANADA','J3H 1P3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 21:15:19',0,NULL,3,1,2,1,'\\ ','mathique'),(9670,836022715012,220816376663,'4 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',132.99,'eastar4uk','shaneen321','neeny1978@hotmail.com','Lee Brown','19 Old Brickfiel Road','Aldershot','Hampshire','UNITED KINGDOM','GU11 3UE','07733335122','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 21:17:33',0,NULL,3,1,3,1,'RA183626305CN ','shaneen321\rGLSG001*4'),(9671,614723658013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','mchaavard','mcbang@online.no','Håvard Bang','Høysletta 22','Alta','','NORWAY','9517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 21:29:39',0,NULL,3,1,2,1,'\\ ','mchaavard'),(9672,755711477002,120765817881,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','fredlara10','fredlara@terra.com.br','Frederico Oliveira','Rua ruivo 73 apt 133','Sao jose dos campos','Sao Paulo','BRAZIL','12246-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 21:43:24',0,NULL,3,1,3,1,'RA183628099CN\r ','fredlara10\rHSBS002'),(9673,836037627012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','sparkbox','pcdoright@gmail.com','Matt Edler','1864 Misty Way','Columbus','OH','UNITED STATES','43232-7407','(614) 859-9090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 21:51:23',0,NULL,3,1,1,1,'\\ ','sparkbox'),(9674,753389245011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','lxweiss','lxweiss@aol.com','bonnie weiss','1000 Old Green Bay Rd','winnetka','IL','UNITED STATES','60093','(847) 441-7707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 22:04:31',0,NULL,3,1,1,1,'\\ ','lxweiss'),(9675,753397603011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','atavolario','atavolario@aol.com','E. Andrew Tavolario','916 Little Brooke Ln','Seaford','DE','UNITED STATES','19973','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 22:13:08',0,NULL,3,1,1,1,'\\ ','atavolario'),(9676,614742389013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','man9161','gonzalophila@hotmail.com','gonzalo meana','1416 S 6th St','philadelphia','PA','UNITED STATES','19147-5843','(267) 342-0678','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 22:34:20',0,NULL,3,1,1,1,'\\ ','man9161\r红边优联'),(9677,836058680012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','0101_0010','rmg-f40@hotmail.com','RAFAEL MARTI','FIRSTLINE IT - Hamilton House<br>1 b  HOWARD STREET','OXFORD','Oxfordshire','UNITED KINGDOM','OX4 3AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 22:42:59',0,NULL,3,1,3,1,'RA183629409CN\r ','0101_0010\rWLAP008'),(9678,562457957004,140519629061,'New Sony Ericsson HBH-DS220 BLUETOOTH HEADSET track#',1,'HSSE006',65.9,'cnfaner','shellsort','ewebarbosa@gmail.com','Éwerson Barbosa','Rua Jorge Pedro Norman, 35 - apto 403, Bl02','Contagem','Minas Gerais','BRAZIL','32145040','55 (31)87527478','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 23:37:51',0,NULL,3,1,3,1,'RA183628108CN\r ','shellsort\r美标\rHSSE006'),(9679,836088074012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','killzi','kzclips@hotmail.com','Keegan Woods','1480 Denver rd','Kelowna','BC','CANADA','v1y 8c2','(778) 242-2797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 00:05:17',0,NULL,3,1,3,1,'RA183626155CN\r ','killzi\rMOLO002'),(9680,836096719012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','mountainla','lguerr4137@aol.com','Laura G Guerrero','2321 Cherry Gate Way','Hacienda Heights','CA','UNITED STATES','91745-5610','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mountainla'),(9681,559848345003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',2,'OMHJ001',27.8,'cnfaner','lijdyal','laureldyal@aol.com','laurel dyal','9429 Hardy Dr','overland park','KS','UNITED STATES','66212-3229','(913) 649-4994','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-22 00:53:16',0,NULL,3,1,1,1,'\\ ','lijdyal'),(9682,751517366011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','konsscar','richandfamous@ymail.com','ΚΩΣΤΑΣ ΣΚΑΡΕΑΣ','ΚΑΡΔΑΜΥΛΗ, ΜΕΣΣΗΝΙΑ, ΜΕΣΣΗΝΙΑ<br>ΜΕΣΣΗΝΙΑ','ΚΑΡΔΑΜΥΛΗ','ΔΗΜΟΣ ΔΥΤΙΚΗΣ ΜΑΝΗΣ','GREECE','24022','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 01:14:33',0,NULL,3,1,2,1,'\\ ','konsscar'),(9683,753465407011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','makingchocolates','amyonthebrink@gmail.com','Amy Brinkerhoff','3078 Spruce Cir','Saint George','UT','UNITED STATES','84790','(435) 688-2323','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 01:39:25',0,NULL,3,1,1,1,'\\ ','makingchocolates'),(9684,836127845012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','jamie.dorn17','jamie.dorn@lander.edu','Jamie Dorn','203 wagon tree ln','Greenwood','SC','UNITED STATES','29646','(864) 554-5191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 02:14:19',0,NULL,3,1,1,1,'\\ ','jamie.dorn17'),(9685,753483606011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','klz57','kabez@yahoo.com','Kabe Zubrod','15922 Crooked Lake Way S','Cypress','TX','UNITED STATES','77433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 02:34:48',0,NULL,3,1,1,1,'\\ ','klz57'),(9686,565351395004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','gpoli30','poli814@yahoo.com','gerard policarpio','119 w prince st','tampa','FL','UNITED STATES','33612-3441','(813) 817-0606','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-22 02:44:51',0,NULL,3,1,1,1,'\\ ','gpoli30\r银色的'),(9687,836161089012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',175.87,'eastar4','russiantimes','russiantimes@panfiloff.com','Danil Panfilov','Ivanova 35A, 13','Novosibirsk','Siberia','RUSSIAN FEDERATION','630117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 03:50:47',0,NULL,3,1,3,1,'RA183626291CN ','russiantimes\rGLSG001*3+CCGR001\r\r再发一个Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS\r'),(9688,836174242012,220816366291,'New lady fashion Leopard lines w/lace Bowtie  Umbrella',1,'UM00024',24.99,'eastar4','flamebrainjanet','flamebrain34@yahoo.com','janet smith','15 little compton mews<br>snells beach','auckland','Rodney district','NEW ZEALAND','1241','09 4223221','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 04:45:30',0,NULL,3,1,2,1,'\\ ','flamebrainjanet\r野性豹纹蕾丝蝴蝶结长柄伞 '),(9689,836179751012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','epal0804','emiliopal@yahoo.ca','Emilio Palazuelos','330 McCowan Road, Suite 1511','Scarborough','ON','CANADA','M1J 3N3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 04:59:19',0,NULL,3,1,2,1,'\\ ','epal0804\rWLAP002+WLAP004\r再发一个Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026'),(9690,753525626011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','epal0804','emiliopal@yahoo.ca','Emilio Palazuelos','330 McCowan Road, Suite 1511','Scarborough','ON','CANADA','M1J 3N3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 05:52:25',0,NULL,3,1,17,0,NULL,'epal0804'),(9691,614009104013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','mohedadam2011','mohedadam@yahoo.com','Mohamed Adam','PO Box 2016','Republic of Maldives','','MALDIVES','960','9607783903','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 06:43:47',0,NULL,3,1,2,1,'\\ ','mohedadam2011'),(9692,836206267012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','moroz_sm','morozsm@gmail.com','Sergey Morozik','Odintsova st. 36/1 - 759','Minsk','','BELARUS','220136','(515)758-0321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 07:16:59',0,NULL,3,1,3,1,'RA183626393CN ','moroz_sm\r盒装的\rOTSO004*2'),(9693,8881313998628336,111,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',20,'eastar4','Guillermo Villegas','guillevillegas@gmail.com','Lucy Martirena','10830 41st Ave Corona','Ave Corona','NY 11368','UNITED STATES','','',NULL,NULL,NULL,'2011-08-22 07:37:08',0,NULL,5,1,18,0,NULL,'MOLO006 '),(9694,8881313998734354,111,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',20,'eastar4','Guillermo Villegas','guillevillegas@gmail.com','Lucy Martirena','10830 41st ','Ave Corona','NY 11368','UNITED STATES','','',NULL,NULL,NULL,'2011-08-22 07:38:54',0,NULL,3,0,3,1,'RA183626380CN ',' MOLO006 '),(9695,8881313999089056,111,'Ralink  RT2870F',5,'OTRA001',175,'eastar4','universalmajor1970','javierx7@gmail.com','Javier Andres Manriquez Gebert','El Escorial 370 depto 603','Temuco Novena Region de la Araucania n/a','','CHILE','','0056997317446',NULL,NULL,NULL,'2011-08-22 07:44:49',0,NULL,3,1,3,1,'RA183626402CN ','OTRA001 '),(9696,565396087004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','ado_civon','n4416325@student.qut.edu.au','A Dzeladinovic','9 Collett Street<br>Eight Mile Plains','Brisbane','Queensland','AUSTRALIA','4113','0422833673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 07:57:47',0,NULL,3,1,3,1,'RA183626314CN ','ado_civon\rBALO007'),(9697,559919149003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','ollie_kidd','ollie@onepizzahouse.com','Oliver Kidd','1 Alpha Court, Moe','Moe','Victoria','AUSTRALIA','3825','0437990266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 08:16:49',0,NULL,3,1,3,1,'RA184555150CN ','ollie_kidd\rHSUE002'),(9698,836227950012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','akvcg','raygsp@yahoo.com','Ray Volpe','1319 S Mitchell Dr','Tempe','AZ','UNITED STATES','85281-6359','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 08:45:40',0,NULL,3,1,1,1,'\\ ','akvcg'),(9699,753560856011,320730088816,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',149.99,'eastar4uk','superpulpfiction','mario.kaufmann.sz@bluewin.ch','Prime21 AG','Mario Kaufmann<br>Baarerstrasse 77','Zug','','SWITZERLAND','6300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 08:50:05',0,NULL,3,1,3,1,'RA183626623CN\r ','superpulpfiction\rHSJA009'),(9700,753175305011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','lode*star','mel@studiobluetang.co.uk','Mr Chris Smith','44 Brookfield St','Newton-le-Willows','Merseyside','UNITED KINGDOM','WA12 9RA','07835440704','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 09:03:03',0,NULL,3,1,3,1,'RA183626447CN\r ','lode*star\rWLAP002'),(9701,8881314004215602,111,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',11.99,'eastar4',' lemongrasshouse  ','benhobbs@h3-digital.com','Ben Hobbs','19/156 Moo7 Srisoontorn Road<br>Tambon Srisoontorn','Amphur Thalang','Phuket','THAILAND','83110','',NULL,NULL,NULL,'2011-08-22 09:10:15',0,NULL,3,1,2,1,'\\  ',' '),(9702,714000054001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','2011babis','xtzoulis@gmail.com','CHARALAMPOS TZOULIS','POLYDEFKI<br>PETRITSIA','PREVEZA','PREVEZA','GREECE','48100','6973509788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 09:13:20',0,NULL,3,1,3,1,'RA183626583CN\r ','2011babis\rBR3D008'),(9703,559928876003,130458644539,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET track#',1,'HSNO021',15.8,'cnfaner','giorgos197','ef.giorgos@gmail.com','GEORGIOS EFTHIMIOU','IGNATIOU ARTIS 10-12','IOANNINA','GREECE','GREECE','45333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 09:18:13',0,NULL,3,1,3,1,'RA183626518CN\r ','giorgos197\r欧标\rHSNO021'),(9704,753571828011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','nixondizon66','nixondizon@yahoo.com','nixon dizon','NS Royal Pensione, Juana Osmena St.','Cebu','Cebu','PHILIPPINES','6000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 09:35:56',0,NULL,3,1,3,1,'RA183626645CN\r ','nixondizon66\r盒装的\rOTSO004'),(9705,753582892011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','k4fc0122','jaka.gole@gmail.com','Jakob Gole','Kidriceva 29','Trebnje','','SLOVENIA','8210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 10:16:43',0,NULL,3,1,2,1,'\\  ','k4fc0122'),(9706,836252577012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','netdirectdeals','ebay@netdirectdeals.co.uk','NetDirectDeals','9 Gardyn Croft<br>Taverham','Norwich','Norfolk','UNITED KINGDOM','NR8 6UZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 10:17:09',0,NULL,3,1,3,1,'RA183626535CN\r ','netdirectdeals\r英标\rHSPL011'),(9707,836256920012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','surf-net-sniper1','ash747@hotmail.co.uk','Mr L. Nahar','30 Mabel Road','Bedford','Beds','UNITED KINGDOM','MK42 9JD','07946709830','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 10:38:33',0,NULL,3,1,3,1,'RA183626420CN\r ','surf-net-sniper1\rHSJA010\r英标'),(9708,836264771012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','cemballi','cemballi@hotmail.com','cem ballibaba','16405 Via Venetia W','delray beach','FL','UNITED STATES','33484-6485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 11:04:57',0,NULL,3,1,1,1,'\\  ','cemballi'),(9709,836276576012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',13.99,'eastar4uk','bartsdad123','bartsdad@orangehome.co.uk','Martin Homer','18 Rockburgh Crescent, Walmer Bridge','Preston','Lancashire','UNITED KINGDOM','PR45RD','01772615398','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 11:38:14',0,NULL,3,1,3,1,'RA183626416CN\r ','bartsdad123\r英标\rHSMO019'),(9710,614895219013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','prophet_mf','prophet_mf@hotmail.com','Frédéric Monnier','Rue de Riant-Coteau 136','Gland','','SWITZERLAND','1196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:41:21',0,NULL,3,1,2,1,'\\  ','prophet_mf\r再发一个Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card'),(9711,835126176012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',7,'WLAP008',69.93,'eastar4uk','www_nontoxic-store24_de','info@nontoxic-store24.de','Thomas Häckl','Geschwister-Scholl-Str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 11:42:08',0,NULL,3,1,3,1,'RA183626606CN\r ','www_nontoxic-store24_de\rWLAP008\r'),(9712,614896560013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','kz808a31','kz808a3@in.gr','Kostas  Zisimopoulos','Erchias 37','Koropi','Greece','GREECE','19400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:42:42',0,NULL,3,1,2,1,'\\  ','kz808a31'),(9713,836278672012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',63.9,'eastar4','pudney3000','paulhinkley@iinet.net.au','Paul Hinkley','3/40 Congdon Way','Booragoon','Western Australia','AUSTRALIA','6154','61893643775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:44:52',0,NULL,3,1,3,1,'RA183626787CN\r ','pudney3000\r澳标\rMOMI001'),(9714,753608748011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',38.99,'eastar4uk','schizoelf','lee.hamilton11@ntlworld.com','Lee Hamilton','258<br>Mungo Park Road','Rainham','Essex','UNITED KINGDOM','RM13 7PU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 11:46:16',0,NULL,3,1,3,1,'RA183626610CN\r ','schizoelf\rOTSO004'),(9715,836280144012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','schnelllangsam','scottdaniel@arcor.de','Daniel Scott','Am Frauenberg 20A','Bad Hersfeld','','GERMANY','36251','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:49:40',0,NULL,3,1,2,1,NULL,'schnelllangsam'),(9716,836281401012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','prophet_mf','prophet_mf@hotmail.com','Frédéric Monnier','Rue de Riant-Coteau 136','Gland','','SWITZERLAND','1196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 12:10:41',0,NULL,3,1,17,0,NULL,'prophet_mf'),(9717,836289080012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','pyradonisbbn','office@striedinger.eu','Udo Striedinger','Günser Straße 3d/1/2','Wiener Neustadt','','AUSTRIA','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 12:16:57',0,NULL,3,1,2,1,'\\ ','pyradonisbbn'),(9718,836304566012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',9.99,'eastar4uk','mtxit','john.cronin@mtxit.com','John Cronin','15 Fareham Enterprise Centre<br>Hackett Way','Fareham','Hampshire','UNITED KINGDOM','PO14 1TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 13:04:08',0,NULL,3,1,3,1,'RA183626549CN\r ','mtxit\rWLAT009'),(9719,753639759011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','monandcon1','moniqueheery@hotmail.com','Monique Heery','60 Wychwood Avenue','Luton','Bedfordshire','UNITED KINGDOM','LU2 7HU','07876681040','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 13:28:45',0,NULL,3,1,3,1,'RA183626597CN\r ','monandcon1\rHBPH002'),(9720,753648892011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','shelbylsp','shelbyleonwright@hotmail.com','Shelby Wright','22 Lark Hill','Bexhill','East Sussex','UNITED KINGDOM','TN40 1QZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 13:55:30',0,NULL,3,1,3,1,'RA183626495CN\r ','shelbylsp\rWLAP002'),(9721,614926788013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',46.99,'eastar4','kouzin123','kouzinoglou@gmail.com','DIMITRIS KOUZINOGLOU','Dardanelion 1-3<br>VYRONAS','ATHENS','VYRONAS','GREECE','16232','6944429841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 13:58:57',0,NULL,3,1,3,1,'RA183626552CN\r ','kouzin123\rWWSI004+ANCN001'),(9722,565470084004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','lleu1603','louis333@gmail.com','Louis Leung','Level 35<br>259 George Street','Sydney','New South Wales','AUSTRALIA','2000','0292504433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 14:36:43',0,NULL,3,1,3,1,'RA183626464CN\r ','lleu1603\rWWOT003+ANCN001'),(9723,836338294012,220759518100,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',32,'eastar4uk','pichnert','pichnert@infornax.hu','Tibor Pichner','Jozsef Attila u. 9.','Veszprem','Veszprem','HUNGARY','H-8200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 14:40:38',0,NULL,3,1,3,1,'RA183626668CN\r ','pichnert\rRCLO004'),(9724,836044337012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','brabhamyamaha','david.rawcliffe2@btinternet.com','DAVID RAWCLIFFE','51 HERONVILLE ROAD<br>HILL TOP','WEST BROMWICH','West Midlands','UNITED KINGDOM','B70 0JG','01215573604','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 14:53:36',0,NULL,3,1,3,1,'RA183626481CN\r ','brabhamyamaha\rOTCN002\r2\"44pin'),(9725,752634428011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','ruskettner','rkettner@new.rr.com','Russell Kettner','322 W South Park Ave','Oshkosh','WI','UNITED STATES','54902','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 15:01:39',0,NULL,3,1,1,1,'\\  ','ruskettner'),(9726,836349273012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','ggholman3','ggholman3@aol.com','Gordie Holman','6304 Daybreak Dr','Wake Forest','NC','UNITED STATES','27587-6455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 15:03:13',0,NULL,3,1,1,1,'\\  ','ggholman3'),(9727,836353684012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','gwithu0','gwithu@blueyonder.co.uk','Carl Bridgwater / N.W. Dial','Connect  (Wyre Forest)<br>10-12 Blackwell Street','Kidderminster','Worcestershire','UNITED KINGDOM','DY10 2DP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 15:14:11',0,NULL,3,1,3,1,'RA183626433CN\r ','gwithu0\rOTCN003'),(9728,696474352008,180699060860,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',39.99,'au-buy','gaustatrollet','hans@fleger.com','Hans-Dieter Fleger','Noerstegard 10A','ATRAA','','NORWAY','N 3656','(+47) 99777998','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 15:24:52',0,NULL,3,1,3,1,'RA183626455CN\r ','gaustatrollet\r只发耳机  \rHSNO019\r\r'),(9729,565482628004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',32.9,'cnfaner','katieloverone','duplerd@rrohio.com','Dee Dupler','4315 Brook Rd NW','Lancaster','OH','UNITED STATES','43130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-22 15:28:07',0,NULL,3,1,1,1,'\\  ','katieloverone'),(9730,836363489012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','alexus463','alexus555@yandex.ru','Perepelitsa Alex','Kudayberdy-uly, 17/4-92','Astana','Astana','KAZAKHSTAN','010009','+77015185895','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 15:37:36',0,NULL,3,1,3,1,'RA183626685CN\r ','alexus463\rHSPL009'),(9731,753691740011,320692069643,'New Apple AirPort Extreme WiFi Card A1026  G4 G5',1,'WLAP003',23.8,'eastar4','sid2066','sidblack@mt-mansfield.com','Karen Schwartz','29 Terrace St','Montpelier','VT','UNITED STATES','05602-2163','(802) 229-5983','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 15:54:28',0,NULL,3,1,1,1,'\\  ','sid2066\r二代卡新的'),(9732,614959092013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','b305sh','b305sh@yahoo.com','SYLVIA HARLAND','29 GRIMSAY ROAD','ARDROSS','Western Australia','AUSTRALIA','6153','61893153317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 16:00:39',0,NULL,3,1,3,1,'RA183626671CN\r ','b305sh\rBAZA001'),(9733,614961681013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','kuu1981','kirsi.riekki@gmail.com','Kirsi Riekki','Ohratie 16 H 241','VANTAA','','FINLAND','01370','+358407420297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 16:11:38',0,NULL,3,1,2,1,'\\  ','kuu1981'),(9734,753699927011,320618274660,'New 3.0 Bluetooth BCM2070 Module+cable for HP 5310M',1,'BTHP3004',19.99,'eastar4','lekomtsevdmitriy','lekomtsev@gmail.com','Dmitriy Lekomtsev','apt. 36, 58/3, Marshala Tukhachevskogo St.','Moscow','Moscow City','RUSSIAN FEDERATION','RU123103','+7(926)280-0127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 16:21:23',0,NULL,3,1,2,1,'\\  ','lekomtsevdmitriy\rHP 8pin1.0 8cm '),(9735,753737515011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','hozencool','hozencool@gmail.com','Kurt Durjan','3537 SW Rivera St','Port Saint Lucie','FL','UNITED STATES','34953-3718','(772) 834-1849','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 17:45:00',0,NULL,3,1,1,1,'\\  ','hozencool'),(9736,836439018012,220807295612,'3 pair 3D Active Shutter Glasses for Samsung SSG-2200AR',1,'GLOT004*3',143.99,'eastar4','tcrate2','knighthawko3@hotmail.com','chad smith','1116 n cleveland ave','russellville','AR','UNITED STATES','72801-2917','(479) 886-3208','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 18:19:50',0,NULL,3,1,1,1,'\\  ','tcrate2\r兼容型3D眼镜  samsung 专用'),(9737,753757458011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','perfectlypractical','skwwhite@hotmail.com','Brad White','721 N 200 E<br>Apt 106','Provo','UT','UNITED STATES','84606-7022','(240) 232-2723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 18:25:44',0,NULL,3,1,1,1,'\\  ','perfectlypractical'),(9738,836450236012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','st.gismo','giheim@gmail.com','Gisle Sørheim','Sørheim','Etne','Hordaland','NORWAY','5590','(474) 022-5527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 18:37:38',0,NULL,3,1,2,1,'\\  ','st.gismo'),(9739,836467487012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',17.1,'eastar4','fdias_rs','fbdias@gmail.com','Fabio de Oliveira Dias','Av Ipiranga, 1200<br>Procempa - T/TEL','Porto Alegre','RS','BRAZIL','90160091','+55 51 99574694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 19:07:31',0,NULL,3,1,2,1,'\\  ','fdias_rs\rAUI Transceiver  MX20T'),(9740,836467298012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','sandracrisis','learie_pringle@yahoo.co.uk','LEARIE PRINGLE','5 SERPENTINE ROAD','BIRMINGHAM','West Midlands','UNITED KINGDOM','B6 6SB','01212410767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 19:10:13',0,NULL,3,1,3,1,'RA183626504CN\r ','sandracrisis\rOTRA001'),(9741,836469928012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','schwigor','igor.schwartzmann@gmail.com','Igor Schwartzmann','Av. Rouxinol 533 apto 101','São Paulo','São Paulo','BRAZIL','04516-000','551183238252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 19:14:30',0,NULL,3,1,3,1,'RA183626362CN\r ','schwigor\rOTRA001'),(9742,836480202012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',168.99,'eastar4','violent_passion','rodrigo_mayta@terra.com.br','Rodrigo Machicado Mayta','Av. Casper Libero, 383 Cj. 8-C','Sao Paulo, SP','Sao Paulo, SP','BRAZIL','01033-001','+5511 33266865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 19:31:53',0,NULL,3,1,3,1,'RA183626711CN\r ','violent_passion\rGLSG001*3\r在包装上注明\rProduct Fragil'),(9743,753805256011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','maskot2006','dionunes@globo.com','DIOGENES NUNES DE OLIVEIRA','TRAVESSA TIMBO 2350 APTO 301<br>ED. POTOMAC RESIDENCE. MARCO','BELÉM','PARA','BRAZIL','66093340','+55 91 91229090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 20:13:53',0,NULL,3,1,3,1,'RA183626637CN\r ','maskot2006\rOTSO004\r盒装的'),(9744,753818335011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',25.9,'eastar4uk','martin071086','coulson.martin@googlemail.com','Martin COULSON, Canvas Hollidays','Yelloh! Village le Ranolien<br>Ploumanach','Perros-Guirec','Bretagne','FRANCE','22700','0787417133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 20:23:43',0,NULL,3,1,2,1,'\\  ','martin071086'),(9745,753820362011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','kargo27','kargo27@yahoo.com','Karl Goellner','9921 Dickens Drive','Benbrook','TX','UNITED STATES','76126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 20:26:10',0,NULL,3,1,1,1,'\\  ','kargo27'),(9746,836517160012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',2,'HSJA010',37.98,'eastar4uk','steve1120_1','westie448@hotmail.com','Mr Steven P West','37 Bemerton Gardens<br>Kirby Cross','Frinton on Sea','Essex','UNITED KINGDOM','CO13 0LQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 20:42:19',0,NULL,3,1,3,1,'RA183626570CN\r ','steve1120_1\rHSJA010\r英标'),(9747,753836727011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','dianaralf','dianastula@yahoo.de','Ralf Stula','Hindenburgallee 4a','Hünfeld','','GERMANY','36088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 21:01:09',0,NULL,3,1,3,1,'RA183626756CN\r ','dianaralf\rBR3D001'),(9748,753843097011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.5,'eastar4','secfedmtg','b.moon@earthlink.net','Bob Moon','17151 Cambury Ln','Wildwood','MO','UNITED STATES','63040-1156','(314) 249-6877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 21:18:54',0,NULL,3,1,1,1,'\\  ','secfedmtg'),(9749,753853990011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',68.98,'eastar4','anfernan1','anfernan@netcabo.pt','Antonio Fernandes','Rua Pedro Augusto Franco, Nº 9','1400-272 Lisboa','','PORTUGAL','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 21:51:15',0,NULL,3,1,3,1,'RA183626521CN\r ','anfernan1\rUDAP001\r一共买了两个'),(9750,714259626001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',16,'buysia','rockville1028','asanati@comcast.net','John Sanati','8913 Falls Chapel Way','Potomac','MD','UNITED STATES','20854','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 21:56:57',0,NULL,3,1,1,1,'\\  ','rockville1028'),(9751,836552877012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',2,'SCLO002',6.8,'eastar4uk','cbai6341','callumbaird@hotmail.com','Callum Baird','5 Carl Place<br>Unsworth Heights','North Shore City','','NEW ZEALAND','0632','(649) 442-2603','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 21:59:37',0,NULL,3,1,2,1,'\\  ','cbai6341'),(9752,753859999011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','granderlogic','r_egg@hotmail.com','Richard Eggleton','49 Brewster Gardens','London','London','UNITED KINGDOM','W10 6AQ','01865883664','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 22:02:57',0,NULL,3,1,3,1,'RA183626478CN\r ','granderlogic\rWLIN010+ANTY002'),(9753,753860918011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','m.meine76','filipemichel77@yahoo.com.br','Marcos Meine','Av. Iguaçu 306<br>Vila Yolanda','Foz Do Iguacu','Brasil','BRAZIL','85853-230','55.45.3574.3080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 22:05:25',0,NULL,3,1,3,1,'RA183626699CN\r ','m.meine76\rGLOT001\r兼容型3D眼镜 通用型'),(9754,836556371012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','stoner_lad','stonerladrules@hotmail.co.uk','Christopher Ramsay','22 glenmore park<br>Altnagelvin','Londonderry','Northern Ireland','UNITED KINGDOM','bt472jz','02871346292','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 22:08:19',0,NULL,3,1,3,1,'RA183626654CN\r ','stoner_lad\rOTSO004*2\r盒装的'),(9755,753880294011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','youcallmepops','sc_morris@hotmail.com','Sian Morris','Ryegate House<br>23 St Peters Street','Colchester','Essex','UNITED KINGDOM','CO1 1HL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 23:12:03',0,NULL,3,1,3,1,'RA183626566CN\r ','youcallmepops\rHBPH002'),(9756,615107468013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','sufibravo','yusufhusen@gmail.com','Yusuf Husen','51 Fourth Avenue<br>Klemzig','Adelaide','South Australia','AUSTRALIA','5087','0433295152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 23:56:16',0,NULL,3,1,2,1,'\\ ','sufibravo'),(9757,753892505011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','chasrakim','chusey_1@yahoo.com','charles hughes','10090 Woodstock Dr','cincinnati','OH','UNITED STATES','45215-1326','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-22 23:56:52',0,NULL,3,1,1,1,'\\  ','chasrakim'),(9758,836591326012,220711637887,'NEW in Sealed Box Genuine APPLE iPad dock',1,'MOAP002',25.99,'eastar4','mikey_maroon','michael_maroon@hotmail.com','Michael Maroon','7 The Mall','South Hurstville, Sydney','New South Wales','AUSTRALIA','2221','0295472924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 23:57:18',0,NULL,3,1,2,1,'\\  ','mikey_maroon'),(9759,753895507011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','guaraguao7','cocolobo@gmail.com','Eugenio Torres','650 Huntington Ave<br>Apt 22B','Boston','MA','UNITED STATES','02115','(617) 232-3730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 00:04:37',0,NULL,3,1,1,1,'\\  ','guaraguao7'),(9760,836596920012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','mark9386','collettemrk@gmail.com','Mark Collette','475 Arbella Loop','The Villages','FL','UNITED STATES','32162-1013','(508) 868-7237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 00:17:04',0,NULL,3,1,1,1,'\\  ','mark9386'),(9761,753895785011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','afm_63','antoniusfm@gmail.com','Jeanette Brinkhuis','37 Prince Street','Grafton','New South Wales','AUSTRALIA','2460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 00:33:45',0,NULL,3,1,2,1,'\\  ','afm_63'),(9762,753916420011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','fernandes2007','im_johnabis@hotmail.com','John Fernandes','42 james street','bolton','ON','CANADA','l7e 3g1','(905) 857-2384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 01:36:05',0,NULL,3,1,2,1,'\\  ','fernandes2007'),(9763,753933831011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',14.99,'eastar4','mike_embedded_hw','mikejo28@comcast.net','Michael Johnson','PO Box 20868','Castro Valley','CA','UNITED STATES','94546-8868','(925) 683-3500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 02:29:09',0,NULL,3,1,1,1,'\\  ','mike_embedded_hw'),(9764,753921552011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','panitank','panitan@gmail.com','Panitan Kern-amnuay','479 jarunsanitwong rd. soi 75  bangplad','bangplad','bangkok','THAILAND','10700','66-24247099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 02:40:32',0,NULL,3,1,2,1,'\\  ','panitank'),(9765,615143018013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',70.96,'eastar4','alzams0a','zayer30@gmail.com','maitham alzayer','Al-Mujama','Dhahran','Eastren','SAUDI ARABIA','31311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 02:41:18',0,NULL,3,1,3,1,'RA183626725CN\r ','alzams0a\rMOSA002\r新地址\rmaitham alzayer\rAl-Mujama\rP.O.Box 9995\rDhahran 31311, Eastern Region\rSaudi Arabia\r\r\r'),(9766,615153496013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mozartpj','mozartp_jr@hotmail.com','mozart passos junior','Rua Genebra, 510<br>Pq. Novo Oratório','Santo André-SP','São Paulo','BRAZIL','09260-260','55-11-3705-6371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 03:32:41',0,NULL,3,1,3,1,'RA183626800CN\r ','mozartpj\rCASS001+CASS002+CASS003\r一共买了三条CAB2626\r五条CAB2660\r两条CAB-6060'),(9767,836654632012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',5,'CASS002',43.5,'eastar4','mozartpj','mozartp_jr@hotmail.com','mozart passos junior','Rua Genebra, 510<br>Pq. Novo Oratório','Santo André-SP','São Paulo','BRAZIL','09260-260','55-11-3705-6371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 03:38:20',0,NULL,3,1,17,0,NULL,'mozartpj'),(9768,753951724011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',3,'CASS001',26.1,'eastar4','mozartpj','mozartp_jr@hotmail.com','mozart passos junior','Rua Genebra, 510<br>Pq. Novo Oratório','Santo André-SP','São Paulo','BRAZIL','09260-260','55-11-3705-6371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 03:47:10',0,NULL,3,1,17,0,NULL,'mozartpj'),(9769,836662614012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','tony_jackson8','tonyjackson@pacbell.net','anthony jackson','23556 saint elena','mission viejo','CA','UNITED STATES','92691-2239','(949) 586-0677','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 04:15:27',0,NULL,3,1,1,1,'\\  ','tony_jackson8'),(9770,753958733011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','joamir2011','joamircampos@hotmail.com','joamir campos','rua almirante lamego, 783 - apto 904<br>centro','Florianopolis','SANTA CATARINA','BRAZIL','88015600','+554884718561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 04:27:40',0,NULL,3,1,3,1,'RA183626858CN\r ','joamir2011\rBR3D001'),(9771,834196899012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',97.99,'eastar4','kglpass5','kglogitech4@gmail.com','ACI Express','17252 S Main St<br>Aci Express La (3850','Gardena','CA','UNITED STATES','90248-3101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 05:14:07',0,NULL,3,1,1,1,'、 ','kglpass5\r兼容型3D眼镜 通用型\r新地址\rACI Express Inc. Los Angeles Br\r17252 S.MAIN ST. (#)\rGardena, CA, 90248-3101\rUnited States\r(310) 965 9009\r'),(9772,565683640004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.99,'cnfaner','garfield1667','raytaylor.inc@gmail.com','Raymond Taylor','1047 Heidelberg Road<br>Ivanhoe','Melbourne','Victoria','AUSTRALIA','3079','0394992929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:08:56',0,NULL,3,1,3,1,'RA183626739CN\r ','garfield1667\rHSNO005\r澳标'),(9773,615176695013,230657622422,'Genuine DENON RC-970 Remote Control RC 970',1,'RCDE002',79.99,'eastar4','sunfire_1234','sorin.capra@gmail.com','Capra Virgiliu Sorin','Berkova 1814/75','Brno','-','CZECH REPUBLIC','61200','+420733149170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:23:09',0,NULL,3,1,3,1,'RA183626795CN\r ','sunfire_1234\rRCDE002'),(9774,836509688012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','volkertp','auktion@friesenstrasse55.de','Volker Paassen','Kloevensteenweg 114','Hamburg','Hamburg','GERMANY','22559','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:59:26',0,NULL,3,1,3,1,'RA183626963CN\r ','volkertp\rWWOT003'),(9775,565689864004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'cnfaner','rla1983','rla4000@gmail.com','Ryan Albrecht','10 Sunset Court Highton','Geelong','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 07:01:16',0,NULL,3,1,3,1,'RA183626760CN\r ','rla1983\rMOAS001'),(9776,752787160011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','perestk','pericaz@vip.hr','Zeljko Perica','Stankovci 267','Stankovci','Dalmatia','CROATIA','23422','00385915424772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 07:01:32',0,NULL,3,1,2,1,'\\  ','perestk\r微软的'),(9777,753992153011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','thatsaba','thatparis@hotmail.com','Sabaratnam Thatparan','123 Oyster Lane<br>CAWKWELL ENGINEERING','BYFLEET','Surrey','UNITED KINGDOM','KT14 7JW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 07:30:19',0,NULL,3,1,3,1,'RA183626773CN\r ','thatsaba\rHBPH002'),(9778,836708542012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',35,'eastar4uk','praesesx','praeses.lds@gmail.com','Dmitriy Litvinenko','prospekt Kul\'tury<br>the house 12 case 1 apartment 434','Saint Petersburg','Saint Petersburg','RUSSIAN FEDERATION','194291','+7 921 906-92-07','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 08:06:15',0,NULL,3,1,3,1,'RA184555296CN\r ','praesesx\rWWSI006+ANCN001'),(9779,615189158013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','loralinov','designarea@bezeqint.net','Larisa Hohlinov','sokolov 60','Holon','','ISRAEL','58322','972-3-6510826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 08:06:46',0,NULL,3,1,2,1,'\\ ','loralinov'),(9780,836713858012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',18.99,'eastar4uk','tore_90923550','tore@verkland.no','Tore Verkland','Sørbruveien 11 a<br>N-7088','Heimdal','','NORWAY','7088','+4790923550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 08:25:16',0,NULL,3,1,3,1,'RA184555282CN\r ','tore_90923550\rHSJA010\r欧标'),(9781,836715175012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','ilgs73','ilgarsa@e-apollo.lv','Ilgars Abdullajevs','Zaļa <br>21-33','Dobele','Latvia','LATVIA','LV3701','+37126385397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 08:31:48',0,NULL,3,1,2,1,'\\ ','ilgs73\r欧标'),(9782,615197446013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',5,'HSNO019',199.95,'eastar4','jukmak','shaka@finx.org','Jukka Mäkelä','Hiekkatie 1','Rahkonen','','FINLAND','68390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 08:45:02',0,NULL,3,1,3,1,'RA184555340CN ','jukmak\r欧标\rHSNO019'),(9783,714395114001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','adankman','alan@dankman.com','alan dankman','2212 burney way','sacramento','CA','UNITED STATES','95821-4625','(916) 925-0811','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 08:52:34',0,NULL,3,1,1,1,'\\','adankman'),(9784,696780103008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',99.98,'au-buy','jaksic9027','filthyrich@acnrep.com','Mr D M Jaksic','12 darter cl','beeliar','Western Australia','AUSTRALIA','6164','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 08:54:50',0,NULL,3,1,3,1,'RA184555353CN ','jaksic9027\rGLOT001\r兼容型3D眼镜 通用型'),(9785,754010135011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','kris99p','c.placzek@gmx.de','Christian Placzek','Kreuzstraße 9','Lörrach','','GERMANY','79540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 08:55:08',0,NULL,3,1,2,1,'\\ ','kris99p'),(9786,836721410012,220806848943,'Transparent Dome Rain Sun Umbrella with purple trim',1,'UMTR001',19.99,'eastar4','00946804336483261396','jance79@delfi.lv','Jana Gorsvāne','Robežu-70','Latvija','Ventspils','LATVIA','LV-3601','26765461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 08:55:48',0,NULL,3,0,2,1,'\\','00946804336483261396\r紫色的'),(9787,754013974011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','kungfukenny','dale.kenny@blueyonder.co.uk','dale kenny','38 Denison Road','Feltham','Middlesex','UNITED KINGDOM','tw13 4qf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 09:09:01',0,NULL,3,1,3,1,'RA183626813CN\r ','kungfukenny\rWLDE001\r'),(9788,836736824012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.9,'eastar4uk','powerbody_co_uk','info@powerbody.co.uk','Power Body Nutrition Ltd.','Unit 6, Great North Way<br>York Business Park, Nether Poppleton','York','North Yorkshire','UNITED KINGDOM','YO26 6RN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 09:54:43',0,NULL,3,1,3,1,'RA183626950CN\r ','powerbody_co_uk\rMOLO006'),(9789,754032603011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',19.99,'eastar4uk','mark112333','markprobert11@hotmail.co.uk','mark probert','40 furze lane','southsea','Hampshire','UNITED KINGDOM','po4 8ln','02392363782','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 10:22:24',0,NULL,3,1,3,1,'RA183626861CN\r ','mark112333\rHSJA011\r英标'),(9790,836253498012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.97,'eastar4','mistersakis','sakzpd@yahoo.gr','EYTHIMIOS LIAPIS','KRANEA ELASSONOS','ELASSONA - LARISAS','GREECE','GREECE','40001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 10:38:43',0,NULL,3,1,2,1,'\\ ','mistersakis\r欧标'),(9791,836755388012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','bogdanmirceam','nadgob_2001@yahoo.com','Magdici Bogdan','Calle Marrubio, Nº 13','Albacete','Castilla-La Mancha','SPAIN','02004','670601334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 10:59:27',0,NULL,3,1,3,1,'RA183626994CN\r ','bogdanmirceam\rOTRA001'),(9792,748520272011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','rbieten','rbieten@yahoo.de','Robin Offermanns','Hansjakobstraße 1','Gundelfingen','','GERMANY','79194','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 11:05:21',0,NULL,3,1,2,1,'\\ ','rbieten\rHSJA004'),(9793,836761690012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','paulp798','paulp798@hotmail.com','Paul Pritchard','67 Warburton Cres','Werrington County','New South Wales','AUSTRALIA','2747','0419008387','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 11:20:03',0,NULL,3,1,2,1,'\\ ','paulp798\r澳标'),(9794,615225799013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','samcriskirst','pentoons@tpgi.com.au','Paul Penton','22 Coolabah Cr','Glenmore Park','New South Wales','AUSTRALIA','2745','0247338473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 11:22:38',0,NULL,3,1,6,1,'EE495360002CN ','samcriskirst\rOTSO004*4\r盒装的'),(9795,754052313011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','ewalk486','toille486@comcast.net','Elliott Green','724 E Baldwin Rd','palatine','IL','UNITED STATES','60074-5461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 11:33:33',0,NULL,3,1,1,1,'、 ','ewalk486'),(9796,836767956012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','gayencan','gaye.atabey@tcmb.gov.tr','Emine Encan','TCMB Banknot Matbaasi GM Degol Cad. No:10 Besevler/ANKARA','Ankara','','TURKEY','06580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 11:41:38',0,NULL,3,1,2,1,'、 ','gayencan\r24K 多色伞'),(9797,754070625011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',10,'TRMX002',85.5,'eastar4','plc_trainer','info@plctrainer.net','Ind-Concepts LLC','1000 Batesburg hwy','Saluda','SC','UNITED STATES','29138-8962','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 12:34:02',0,NULL,3,0,1,1,'\\ ','plc_trainer\r已入库'),(9798,753711623011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','anong.123','gromkweang@hotmail.com','Anon Gromkwaeng','159/51 Puttanplace<br>Soi Thiwanon 48  Thiwanon Rd. Thasai','Nonthaburi','Thailand','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 14:27:42',0,NULL,3,1,2,1,'\\ ','anong.123'),(9799,836838328012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','mphillips261','manuel.phillips@ymail.com','MANUEL PHILLIPS','8841 nw 121st st','OKLAHOMA CITY','OK','UNITED STATES','73162-1143','(405) 823-2268','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 15:03:53',0,NULL,3,1,1,1,'\\ ','mphillips261'),(9800,754124948011,320742427755,'Genuine DENON RC-969 Remote Control RC 969',1,'RCDE002',69.99,'eastar4','burnoutbobsez','autobrokers3@qwestoffice.net','BOB BROWN','3200 1st Ave N','Billings','MT','UNITED STATES','59101-2103','(406) 245-9055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 15:21:22',0,NULL,3,1,1,1,'、 ','burnoutbobsez'),(9801,836845939012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','saulgardiner','saulgardiner@gmail.com','Saul Gardiner','306 Milton Road East','Edinburgh','Lothian','UNITED KINGDOM','EH15 2PH','01316575180','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 15:24:11',0,NULL,3,1,3,1,'RA183626901CN\r ','saulgardiner\rWLAP001+WLAP004'),(9802,754123300011,320618274660,'New 3.0 Bluetooth BCM2070 Module+cable for HP 5310M',1,'BTHP3004',19.99,'eastar4','ornery12','kleake@rapfire.net','Kenneth Leake','14835 S Boyd St','Sapulpa','OK','UNITED STATES','74066','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 15:16:05',0,NULL,3,1,1,1,'、 ','ornery12\rHP 8pin1.0 8cm '),(9803,754128942011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','loveleeme13','jcp13877@hotmail.com','Jenny Pettersson','Klövsta 9','Ösmo','','SWEDEN','148 91','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:34:02',0,NULL,3,1,2,1,'\\ ','loveleeme13\r欧标'),(9804,615285850013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ropblhbl4_nnov','deryugina.arina@mail.ru','Dmitriy Deryugin','Samochkina, 20-3','Nizhniy Novgorod','','RUSSIAN FEDERATION','603034','9159422452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:43:39',0,NULL,3,1,2,1,'\\ ','ropblhbl4_nnov'),(9805,754136727011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','patriciamary2568','patriciamarywilson@yahoo.co.uk','PATRICIA WILSON','MANOR HOUSE<br>COFFINSWELL','NEWTON ABBOT','DEVON','UNITED KINGDOM','TQ12 4SW','01803873798','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 16:02:43',0,NULL,3,1,3,1,'RA183626892CN ','patriciamary2568\rGLOT001\r兼容型3D眼镜 通用型\r'),(9806,754144873011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.5,'eastar4','cbreau246','cbreau@remax-sjnb.com','corey breau','199 chesley drive<br>suite 207','saint john','NB','CANADA','e2k4s9','(506) 650-3743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 16:15:38',0,NULL,3,1,2,1,'\\ ','cbreau246\r新地址\rCorey Breau\r25 Bentley Street\rSaint John, New Brunswick\rE2K-1B2\rCanada\r\r'),(9807,836868613012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','like-hankyeol','khk87@korea.com','Hankyeol Kim','Seodaemun-gu Hongje3-dong YoowonhanaAPT 102-1003','Seoul','','KOREA,REPUBLIC OF','120-781','821087457833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 16:19:18',0,NULL,3,1,2,1,'\\ ','like-hankyeol'),(9808,836870107012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',4,'OTCN004*10',67,'eastar4','miamicf','dsutton@cfmiami.org','Deborah Sutton','8900 SW 168th St','Palmetto Bay','FL','UNITED STATES','33157-4569','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 16:22:17',0,NULL,3,1,1,1,'、 ','miamicf\r黑色的'),(9809,754149808011,320596607503,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',5.7,'eastar4','94-red','silgrey1@comcast.net','Mark A Saboski','78 Hogbin Rd','Millville','NJ','UNITED STATES','08332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 16:26:07',0,NULL,3,1,1,1,'、 ','94-red'),(9810,836858406012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','ser-nat','gol-ser@mail.ru','Сергей Голованов','пр-т Ленина, 1-718','Самара','','RUSSIAN FEDERATION','443110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 16:57:46',0,NULL,3,1,3,1,'RA183626929CN\r ','ser-nat\rOTSO004*2\r盒装的'),(9811,836558145012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','bs-darklord','darklords2000@btinternet.com','Scott Walters','5<br>Fernleigh Avenue','Burntwood','Staffordshire','UNITED KINGDOM','WS72ES','01543321157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 17:00:24',0,NULL,3,1,3,1,'RA183626827CN ','bs-darklord\rMOLO009'),(9812,565807994004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'cnfaner','lizinzon','milaos72@gmail.com','Mila Lizinzon','ha-zionut<br>14 6','Ashdod','','ISRAEL','77456','+972 50 7365588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:02:33',0,NULL,3,1,3,1,'RA183626985CN\r ','lizinzon\rMOAS001'),(9813,754163870011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','mikychamonix','mikypatagonia@gmail.com','almonacid sotomayor juan carlos','131<br>promenade marie paradis','chamonix-mount blanc','Rhône-Alpes','FRANCE','74400','0624980431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:05:32',0,NULL,3,1,2,1,'\\ ','mikychamonix'),(9814,565816854004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'cnfaner','cruzerov','mahdal5@seznam.cz','Viktor Eyermann','V Kastankach 1073','Pecky','CR','CZECH REPUBLIC','28911','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:34:50',0,NULL,3,1,3,1,'RA183626946CN ','cruzerov\rCACN004'),(9815,560349666003,130458644539,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET track#',1,'HSNO021',15.8,'cnfaner','ilipchen','lipchenca@gmail.com','Ariel Lipchenca','Hayahalom 46','Tel Mond','','ISRAEL','40600','+972-54-4493490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:52:13',0,NULL,3,1,3,1,'RA183626889CN ','ilipchen\rHSNO021'),(9816,836935470012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.4,'eastar4','code4','jha2600@msn.com','john allen','2600 Minnick Rd','aynor','SC','UNITED STATES','29511-3827','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 18:42:41',0,NULL,3,1,1,1,'、 ','code4'),(9817,836953161012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',34.8,'eastar4','bzenobiad1970','bzenobiad@yahoo.com','Beatrice Davies','Escamplaan<br>526','DEN HAAG','','NETHERLANDS','2547EP','0652192505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 19:13:55',0,NULL,3,1,3,1,'RA183626875CN\r ','bzenobiad1970\rCAB-6060\rCASS003'),(9818,565854833004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','antongusev','antonio.gusev@gmail.com','Anton Gusev','Pribrezhny proezd 7 kv.434','Moscow','Moscow','RUSSIAN FEDERATION','125445','7(926)3410740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 19:31:26',0,NULL,3,1,3,1,'RA183626977CN\r ','antongusev\rMOOE001\r发OEM的'),(9819,697010109008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','suhovezky','polak.kz@gmail.com','Alexander Sukhovetskiy','Wasilkowsky 23/45','Kokshetau','','KAZAKHSTAN','020000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 20:16:36',0,NULL,3,1,3,1,'RA183627005CN\r ','suhovezky\rHSPL005'),(9820,697016520008,180699002013,'New Griffin PowerJolt Dual USB Micro Car Charger track#',2,'CCGR001',17.76,'au-buy','chbinak','cbinkcak@arctic.net','Cliff   Bendixen','PO Box 36<br>36 North Main Street','King Cove','AK','UNITED STATES','99612','(907) 497-2328','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 20:35:10',0,NULL,3,1,1,1,'、 ','chbinak'),(9821,754265267011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','loves-to-sell','stacit@cebridge.net','Staci   Taylor','123 Biggs Br','Pikeville','KY','UNITED STATES','41501-8149','(606) 432-0697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 20:36:57',0,NULL,3,1,1,1,'\\  ','loves-to-sell'),(9822,837026164012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',12.5,'eastar4','ubereality','scotthayden@bellsouth.net','Scott Hayden','12527 Nursery Ln','Louisville','KY','UNITED STATES','40243','(502) 310-3830','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 21:41:32',0,NULL,3,1,1,1,'\\ ','ubereality'),(9823,837031699012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','fmbmad','fernando@madruga.eu','Fernando Madruga','Br. Cx. Previdencia, Bl. E2, 4-Esq','COIMBRA','COIMBRA','PORTUGAL','3030-044','913-756-599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 21:57:31',0,NULL,3,1,2,1,'\\ ','fmbmad'),(9824,837045710012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','vladaper','vladimirvle@yahoo.com','Galstyan Artur','Armenia , erevan , isakov52/2 apartment 32','erevan','','ARMENIA','0027','0037477661188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 22:35:24',0,NULL,3,1,2,1,'\\ ','vladaper\r白色的'),(9825,754312275011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.99,'eastar4','maddax666','kurzfuendig@gmx.de','Roland Dachs','Leopoldstraße 48','München','','GERMANY','80802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 22:41:14',0,NULL,3,1,2,1,'\\ ','maddax666\r欧标'),(9826,615426409013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',143.99,'eastar4','jaimesatin','sadan10@aol.com','Jaime Satin','2516 Terrebonne Ave','San Dimas','CA','UNITED STATES','91773-1352','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-23 23:40:27',0,NULL,3,1,1,1,'、 ','jaimesatin\r兼容型3D眼镜 通用型'),(9827,754331302011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','innokha','victoriastone11@live.com','Victoria Stone','720 SW 5th St','Corvallis','OR','UNITED STATES','97333-4416','(541) 610-5767','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 23:56:36',0,NULL,3,1,1,1,'\\ ','innokha\r红边优联'),(9828,754340113011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','dazed48525793t','carolinarolling@gmail.com','Gloria J. Thornton','5264 Fox Hills Ave','Buena Park','CA','UNITED STATES','90621-1503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 00:24:27',0,NULL,3,1,1,1,'\\  ','dazed48525793t'),(9829,754348670011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',179.99,'eastar4','zengeg','easygeg@yahoo.fr','Jérôme TERROIR','Keywords Intl - Whelan House - South County Business Park','Dublin','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 01:03:03',0,NULL,3,1,3,1,'RA183626932CN\r ','zengeg\r盒装的'),(9830,754357074011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','julius8605','julius_yapv2@hotmail.com','Wae Yap','16 Adenia Road<br>Riverton','Perth','Western Australia','AUSTRALIA','6148','0433579307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 01:33:25',0,NULL,3,1,2,1,'\\ ','julius8605\rCAB-6060'),(9831,615459444013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',26.1,'eastar4','jusitnzero666','zerodeath666@hotmail.com','Justin Hantos','522 23 ave ne','Calgary','AB','CANADA','t2e 1w2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 02:05:07',0,NULL,3,1,2,1,'\\ ','jusitnzero666\r一共买了三条CAB-SS-2626\r新地址\rJustin Hantos\r37 Sunhurst Cres SE\rCalgary Alberta T2X 1W5\rCanada\r'),(9832,837119316012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',81.99,'eastar4uk','heronribeiro','heronrib@yahoo.com.br','Heron Ribeiro','Rua Gilson da Costa Xavier, 542<br>Sambaqui','Florianopolis','SC','BRAZIL','88051000','+55 48-37225358','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 02:47:20',0,NULL,3,1,3,1,'RA183628071CN\r ','heronribeiro\rGLOT005*2\r投影仪兼容眼镜'),(9833,8881314155587164,111,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',0,'eastar4','kwatoyo','kwatoyo@gmail.com','KWA Tong Yong','416 Ang Mo Kio Ave 10<br>#06-1003','Singapore','','SINGAPORE','560416','',NULL,NULL,NULL,'2011-08-24 03:13:07',0,NULL,3,1,3,1,'RA183626835CN\r ','补发的\rCCGR001'),(9834,837130468012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','11valentim','mundodoperfume@gmail.com','Valentim Vinicius','cristovao Pareira, 1184<br>Campo Belo','Sao Paulo','São Paulo','BRAZIL','04620011','+5511 99849120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 03:27:41',0,NULL,3,1,2,1,'\\ ','11valentim'),(9835,615476744013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','hello_kitty231281','madison2312009@yahoo.com','Vinh Ma','10919 malden dr','houston','TX','UNITED STATES','77075-5142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 03:33:56',0,NULL,3,1,1,1,'\\ ','hello_kitty231281\r黑色的'),(9836,615480263013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',2,'BALO001',23.98,'eastar4','4134em','ste@xplornet.ca','Steve & Emilie Torgerson','RR3 S310 Comp 114<br>#9 1017 TWP 540','Stony Plain','AB','CANADA','T7Z 1X3','(780) 968-1305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 03:56:34',0,NULL,3,1,2,1,'\\  ','4134em'),(9837,8881314161487779,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','joe_da_pera','talves@eda.pt','Tiago Alves','Estrada 25 Abril, 148','Praia da Vitória','Santa Cruz','PORTUGAL','9760','',NULL,NULL,NULL,'2011-08-24 04:51:27',0,NULL,3,1,2,1,'\\ ','补发的 '),(9838,754405268011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','joey_zeller','joeyzeller@hotmail.com','JOSEPH ZELLER','1287 VERDIER AVE<br>UNIT 19','BRENTWOOD BAY','BC','CANADA','V8M 1H1','(250) 800-0660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 05:02:39',0,NULL,3,1,2,1,'\\ ','joey_zeller'),(9839,754410360011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','bayshoreleasing','bayshoreleasing@yahoo.com','Donald Kleiner','5320 Edgeview Dr','Discovery Bay','CA','UNITED STATES','94505-9276','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 05:28:39',0,NULL,3,1,1,1,'\\ ','bayshoreleasing'),(9840,837175581012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',49.99,'eastar4','steve15647','sjmeyers@hotmail.com','Stephen Meyers','1 Arrol St','Carine','Western Australia','AUSTRALIA','6020','0893458646','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 07:02:49',0,NULL,3,1,3,1,'RA183626844CN\r ','steve15647\rGLOT001\r兼容型3D眼镜 通用型'),(9841,615509605013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','stateoftheartone1','stateoftheartone@yahoo.co.uk','AECOM c/o Mark Littler','19 Wandoo St<br>Fortitude Valley','Brisbane','Queensland','AUSTRALIA','4006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 07:39:17',0,NULL,3,1,3,1,'RA183628346CN ','stateoftheartone1\rHBPH005\r盒装的'),(9842,754439895011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','wolverton-products','tim_deeley@o2.co.uk','Tim Deeley','7 Maple Road','Halesowen','West Midlands','UNITED KINGDOM','B628JR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 08:01:34',0,NULL,3,1,3,1,'RA183628125CN\r ','wolverton-products\rWLAP002\r二代卡 旧'),(9843,754443620011,320394905532,'Acer Aspire 7110 7000 9300 Bluetooth Module 2.0 +cable',1,'BTAC2008',12.5,'eastar4','warglaya','bmeriguet@yahoo.fr','Bernard MERIGUET','22 rue de bercy','PARIS','Île-de-France','FRANCE','75012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 08:18:47',0,NULL,3,1,2,1,'、 ','warglaya\rBTAC2008\racer 4pin1.25 18cm '),(9844,560522878003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',49.9,'cnfaner','my00impreza','rbon@home.nl','Rene Bongers','kuukven 9','Baarlo','Limburg','NETHERLANDS','5991 NK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 08:25:41',0,NULL,3,1,3,1,'RA183628160CN ','my00impreza\rMOOE002\r发OEM的'),(9845,615486377013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',40,'eastar4','vladyslawus','shvedenkov@gmail.com','Vladyslav Shvedenko','11 Polevoi pereulok','Chabany','Kyiv','UKRAINE','08162','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 08:31:07',0,NULL,3,1,3,1,'RA183628289CN ','vladyslawus\rOTIN003'),(9846,714789837001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','necu2001','freddy.neculman@hotmail.com','FREDDY NECULMAN','34 ARCHIBALD CRESCENT','ROSEMEADOW','New South Wales','AUSTRALIA','2560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 09:01:10',0,NULL,3,1,3,1,'RA183628195CN ','necu2001\rBR3D008'),(9847,754455678011,320741897705,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',56.99,'eastar4uk','imroot_dd','ebay@imroot.de','Friedrich Kaden','Spittastr. 5','Dresden','','GERMANY','01309','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 09:11:35',0,NULL,3,1,3,1,'RA183628332CN ','imroot_dd\rGPS0002'),(9848,837225562012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','rtouris','rtouris@mac.com','Dimitrios Tourtouras','2, H. Popovits str.','Kozani','','GREECE','501 00','+306937578084','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 10:24:26',0,NULL,3,1,2,1,'\\  ','rtouris'),(9849,754473025011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','jinjiawen0416','jinjiawen0802@hotmail.com','JIAWEN JIN','23, Marshall Avenue, Clayton','Melbourne','Victoria','AUSTRALIA','3171','0385559998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 10:25:53',0,NULL,3,1,2,1,'\\  ','jinjiawen0416'),(9850,615419123013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','ricardo.cordeiro','ricardo.reis.cordeiro@gmail.com','Ricardo Reis Cordeiro','Travessa João Alves, 5 1ºEsq','Lisboa','','PORTUGAL','1300-316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 10:56:15',0,NULL,3,1,2,1,'\\  ','ricardo.cordeiro'),(9851,837236019012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','kassydemma','markdemarchi@hotmail.com','Mark DeMarchi','P/O Box 298','Tindal RAAF','Northern Territory','AUSTRALIA','0853','0889717343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 11:02:22',0,NULL,3,1,3,1,'RA183628068CN ','kassydemma\rOTSO004*2'),(9852,837237158012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',21.99,'eastar4uk','goroxant','gortsevsky@yahoo.com','Anton Gortsevskiy','Basseynaya ul., d.53 kv.96','St.-Petersburg','','RUSSIAN FEDERATION','196135','+7-921-7466460','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 11:06:07',0,NULL,3,1,3,1,'RA183628292CN\r ','goroxant\rWWSI002+ANCN001'),(9853,837255314012,220713846354,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET+carcharger',2,'HSNO006+CCNO001',22.98,'eastar4uk','hudson7106','keoghmichelle@yahoo.ie','Michelle Hudson','16 The Kiln<br>Railway Street','dublin','Dublin 1','IRELAND','01','018559255','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 12:05:27',0,NULL,3,1,3,1,'RA183628173CN ','hudson7106\rHSNO006+CCNO001'),(9854,837256426012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','erotss','andris.photographer@googlemail.com','Andris Berzins','2 Skerries Road','Lusk','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 12:06:16',0,NULL,3,1,2,1,'\\  ','erotss\r24K 多色伞'),(9855,754499484011,320721866865,'New lady lace trim sun/rain stick Umbrella 6 colors',1,'UM00011',15.95,'eastar4','mbelyavskaya','maria.belyavskaya@gmail.com','Maria Belyavskaya','Tverskaya 23-57','Saint Petersburg','','RUSSIAN FEDERATION','191124','+7 911 990 40 96','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 12:08:50',0,NULL,3,1,2,1,'\\ ','mbelyavskaya\r蕾丝花边伞 \r黑色带白点的'),(9856,560562116003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','claudiangelia','niuw_claudia@hotmail.com','claudia angelia','A1109/339 Sussex Street','Sydney','New South Wales','AUSTRALIA','2000','0430088928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 12:11:40',0,NULL,3,1,3,1,'RA183628258CN ','claudiangelia\rBAZA001'),(9857,754514457011,320694404638,'NIB Jabra BT-2080 Wireless Bluetooth Headset BT 2080',1,'HSJA005',17.97,'eastar4','proms.d','promsd@gmail.com','Dmitriy Vyalix','ul. Sadovaya, dom 7, kv. 205','Kurchatov','Kurskaya obl','RUSSIAN FEDERATION','307250','+79045211406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 12:46:07',0,NULL,3,1,2,1,'\\  ','proms.d\rHSJA005\r欧标'),(9858,749339259011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',135.99,'eastar4','kittypoppa','kittypoppa2000@yahoo.com.au','kerrie burdett','92 CAMPBELL STREET<br>GLEBE','sydney','New South Wales','AUSTRALIA','2037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 12:55:25',0,NULL,3,1,3,1,'RA183628315CN ','kittypoppa\rOTSO005*2\r盒装的'),(9859,560575156003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.9,'cnfaner','noahevandro','evandro_fm@hotmail.com','Evandro Miranda','Oliveira Viana, 965','Curitiba','Parana','BRAZIL','81630070','55 41 30923131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 13:18:04',0,NULL,3,1,3,1,'RA183628200CN\r ','noahevandro\rWLIN013'),(9860,754527647011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',14.81,'eastar4','nailedesign23eq','nailedesign@aol.com','Rick','673 Boar Rd','Mohrsville','Pa','UNITED STATES','19541','(610) 926-0834','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 13:29:10',0,NULL,3,1,1,1,'\\  ','nailedesign23eq\r 一代卡  旧'),(9861,615601974013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','321snapshots','321snapshots@gmail.com','edward koen','11772 Carmel Creek Rd<br>Apt 303','San Diego','CA','UNITED STATES','92130-6605','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 15:20:43',0,NULL,3,1,1,1,'\\  ','321snapshots'),(9862,837328971012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','exiledtexan','mayodunn@netreach.net','Ann M Dunn','1054 Jacksonville Rd','Ivyland','PA','UNITED STATES','18974','(267) 994-4864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 15:33:24',0,NULL,3,1,1,1,'\\  ','exiledtexan'),(9863,837358375012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','timhatch_666','timjhatch@hotmail.co.uk','Tim Hatch','20 Sycamore road','Bognor Regis','West Sussex','UNITED KINGDOM','PO22 9LD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 16:40:35',0,NULL,3,1,3,1,'RA183628947CN\r ','timhatch_666\rHSMO018\r英标'),(9864,566102914004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','vettesntrains','daddio5273@yahoo.com','Robert Ricchio','1422 Colwyn Dr','Schaumburg','IL','UNITED STATES','60194-2736','(847) 885-7696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-24 17:04:40',0,NULL,3,1,1,1,'\\  ','vettesntrains'),(9865,754615422011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','georgistanoev','georgistanoev@yahoo.com','Georgi Stanoev','3949 Wyckoff Dr','Virginia Beach','VA','UNITED STATES','23452-1874','(757) 580-2514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 17:23:45',0,NULL,3,1,1,1,'\\  ','georgistanoev'),(9866,837382910012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','superpantsboy','imeadows@hotmail.com','ian meadows','4 pett close','hornchurch','Essex','UNITED KINGDOM','rm11 1ff','07944783048','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 17:34:15',0,NULL,3,1,3,1,'RA183628244CN ','superpantsboy\rHBPH003\r英标'),(9867,754635542011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','michaelk1357','mkemp01@hotmail.com','michael kemp','21 high green road, altofts','normanton','West Yorkshire','UNITED KINGDOM','wf6 2lf','01924897476','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 18:08:01',0,NULL,3,1,3,1,'RA183628261CN ','michaelk1357\r英标\rHSPL015'),(9868,836096719012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','mountainla','lguerr4137@aol.com','Laura G Guerrero','2321 Cherry Gate Way','Hacienda Heights','CA','UNITED STATES','91745-5610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 18:19:17',0,NULL,3,1,1,1,'\\  ','mountainla'),(9869,837418530012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','rr240sx','92camaro@gmail.com','Jonathan Awe','238 grove ln','new braunfels','TX','UNITED STATES','78130-8218','(830) 392-6096','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 18:47:55',0,NULL,3,1,1,1,'\\  ','rr240sx'),(9870,560485031003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',13.45,'cnfaner','vincelatulippe','latulippe_vincent@videotron.ca','Vincent Latulippe','9385 rue de belfort   App.#105','Quebec','QC','CANADA','g1g 6j6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 19:23:14',0,NULL,3,1,3,1,'RA183628142CN\r ','vincelatulippe\rHSUE004'),(9871,754696814011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','lubalibra','lubalibra79@yahoo.com','luba ivanov','426 tooze st','Woodburn','OR','UNITED STATES','97071-4828','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 20:14:56',0,NULL,3,1,1,1,'\\  ','lubalibra'),(9872,830518556012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','haimallla','haimhaim1982@gmail.com','haim sitkoveskiy','sdrot-gat 98/28 qriat-gat<br>שדרות גת 98 דירה 28 קרית גת','qreat-gat','','ISRAEL','82092','0502248622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 20:18:40',0,NULL,3,1,2,1,'\\  ','haimallla\r白色的'),(9873,754706287011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',25.99,'eastar4uk','cawrgas','mike@hallesy.net','Mike Hallesy','A&M South Wales<br>Alloy Industrial Estate','Pontardawe , Swansea','Neath Port Talbot','UNITED KINGDOM','SA8 4EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 20:31:25',0,NULL,3,1,3,1,'RA183628156CN\r ','cawrgas\rWWOT001'),(9874,615707408013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','dewd864','jamdkd@gmail.com','Darryl   Dewalt','4610-46 Avenue','Camrose','AB','CANADA','T4V0E2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 20:48:04',0,NULL,3,1,2,1,'\\  ','dewd864'),(9875,566174324004,140482633304,'New GENUINE NOKIA HS-11W BLUETOOTH HEADSET track#',1,'HSNO023',14.98,'cnfaner','juri_196969','burikin@hot.ee','Juri Burõkin','Mahtra 25-149','Tallinn','','ESTONIA','13811','(+372) 581-60993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 20:53:43',0,NULL,3,1,3,1,'RA183628213CN ','juri_196969\rHSNO023\r欧标'),(9876,560705106003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','extra_bits_uk','jason.fell@hotmail.co.uk','Jason Fell','2 Beckley Cottages','Great Bookham','Surrey','UNITED KINGDOM','KT23 4RW','07522686855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 21:00:33',0,NULL,3,1,3,1,'RA183628235CN ','extra_bits_uk\rMOLO006'),(9877,837490879012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','emmanoelle79','emma3_smith@hotmail.com','emma hossack','51 hazelwood drive','st albans','Hertfordshire','UNITED KINGDOM','AL4 0UP','07852427566','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 21:03:32',0,NULL,3,1,3,1,'RA183628187CN ','emmanoelle79\rHBPH003\r英标'),(9878,754732883011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','eugenemelnikov','melnikaite.melnikaite@gmail.com','Eugene Melnikov','4/1-40 Cnyanskaya st.','Minsk','','BELARUS','220013','375295041301','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 21:34:35',0,NULL,3,1,3,1,'RA183628329CN ','eugenemelnikov\rGLSG001'),(9879,754733103011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','rattanakirirun','sanyang97@hotmail.com','Neal Mitcheison','15 Sea Lane Close','East Preston','West Sussex','UNITED KINGDOM','BN161NQ','07973880481','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 21:35:26',0,NULL,3,1,3,1,'RA183628301CN ','rattanakirirun\rWLAP002'),(9880,754738880011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','musicdjnash','njangra@aol.com','Naresh Jangra','15 Oakington Av<br>Hayes','London','Middlesex','UNITED KINGDOM','UB3 4AQ','02088484229','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 21:49:52',0,NULL,3,1,3,1,'RA183628350CN ','musicdjnash\rRCLO008'),(9881,837518930012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',3,'WLAT009',29.94,'eastar4','wellesximenes','suportewelles@gmail.com','Welles Freire','Padre Valdevino 1386 102/a','Fortaleza','Ceara','BRAZIL','60135040','8532683678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 22:12:55',0,NULL,3,1,2,1,'\\  ','wellesximenes'),(9882,837537231012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',25.99,'eastar4','maximnovikov1982','maxim.novikov@inbox.ru','Максим Новиков','Московская область Подольский район с. Ознобишино д. 91','Подольский район с. Ознобишино','','RUSSIAN FEDERATION','142144','+79197775575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 23:09:12',0,NULL,3,1,2,1,'\\  ','maximnovikov1982'),(9883,754763573011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','tmp_smz','tmp_smz@yahoo.com','Cameron Khor','1272 E Hudson Blvd<br>APT S','Gastonia','NC','UNITED STATES','28054-6135','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-24 23:11:31',0,NULL,3,1,1,1,'\\  ','tmp_smz\r2\"44pin'),(9884,754759703011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',2,'WLAP001',35.62,'eastar4','thannowilson','awilsonm@uol.com.br','Antonio Wilson Mattos','Rua Visconde de Inhauma, 480 - Saúde - Apto. 84-A','São Paulo','São Paulo / São Paulo','BRAZIL','04145-030','55 11 6345-0098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 23:12:35',0,NULL,3,1,3,1,'RA183628111CN ','thannowilson\rWLAP001\r一代卡  旧'),(9885,560743308003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',13.45,'cnfaner','twstdone','twstd@frontiernet.net','Chad Schafer','47 Almay Rd','Rochester','NY','UNITED STATES','14616-3707','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-25 00:04:50',0,NULL,3,1,1,1,'\\  ','twstdone'),(9886,560743887003,130553146862,'Jabra BT800 wireless Bluetooth headset BT 800 track#',1,'HSJA008',28.6,'cnfaner','mlee75','ml1975@netzero.net','marlon lee','302 New Salem St','park forest','IL','UNITED STATES','60466-1137','(708) 363-6164','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-25 00:08:28',0,NULL,3,1,1,1,'\\  ','mlee75'),(9887,566215529004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'cnfaner','kbwhisler','kwhisler@windstream.net','Kirk Whisler','265 Southern Walk Cir','Gray','GA','UNITED STATES','31032-4521','(478) 986-5145','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-25 00:25:04',0,NULL,3,1,1,1,'\\  ','kbwhisler'),(9888,615759435013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',159.96,'eastar4','01chk','brooke.percy@hotmail.com','Brooke Percy','41 Cabernet Cresent','Thornlands','Queensland','AUSTRALIA','4164','0407892564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 00:36:27',0,NULL,3,1,3,1,'RA183628275CN ','01chk\r一共买了四个\r澳标\rHSNO019'),(9889,754788504011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','derodriguez75','quiero78@live.com','Antonio Martos Baides','calle jumilla 64','San Javier','Murcia','SPAIN','30730','695727831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 00:50:56',0,NULL,3,1,2,1,'\\  ','derodriguez75'),(9890,754794813011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','akhu','jprohart@free.fr','Jean Philippe Rohart','31 rue Louis Braille','Bordeaux','Aquitaine','FRANCE','33000','06 58 16 14 08','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 01:17:33',0,NULL,3,1,2,1,'\\  ','akhu\rHP 8pin 1.25 25cm '),(9891,566247665004,140584762830,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.9,'cnfaner','mediamartcomputer','chongweelee@mediamart.com.sg','Wee Lee Chong','1 Rochor Canal Road, Sim Lim Square<br>#06-68','default','','SINGAPORE','188504','63361136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 03:20:03',0,NULL,3,1,3,1,'RA183629001CN ','mediamartcomputer\rWLIN014\r 通用'),(9892,566249575004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',32.9,'cnfaner','norm_a_1','la1raven@yahoo.com','Norman Adonis','PO Box 924','Louisville','KY','UNITED STATES','40201-0924','(502) 713-6714','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-25 03:34:15',0,NULL,3,1,1,1,'\\  ','norm_a_1'),(9893,754830920011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',14.99,'eastar4','brockanddino','robwa@iprimus.com.au','Robert Wake','14 Lindsay Street','Angaston','South Australia','AUSTRALIA','5353','0885642473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 03:43:07',0,NULL,3,1,2,1,'\\  ','brockanddino'),(9894,560778872003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',30.3,'cnfaner','glenstruan','gordondalling@hotmail.com','Gordon N. Dalling','102 - 1021 Court Ave.','Winnipeg','MB','CANADA','R2P 1V7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 03:47:59',0,NULL,3,1,3,1,'RA183628995CN\r ','glenstruan\rSCLO001+BALO001\r再发一个蓝电池新的'),(9895,754835551011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',59.99,'eastar4','armonique29achat','armonique29@wanadoo.fr','Filarmonique','91, avenue du Cabellou','CONCARNEAU','Bretagne','FRANCE','29900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 04:05:18',0,NULL,3,1,3,1,'RA183628377CN ','armonique29achat\rGLSG001'),(9896,754837991011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','macspudster','carterclanbc@gmail.com','Bryan Carter','2860 N Mule Deer Way','Meridian','ID','UNITED STATES','83646','(208) 639-2265','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 04:17:09',0,NULL,3,1,1,1,'\\  ','macspudster\r二代卡 旧'),(9897,615809132013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','tonthathung','tonthathung@yahoo.com','TONY H TONTHAT','2607 17th St','Huntington Beach','CA','UNITED STATES','92648-2419','(714) 960-9659','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 05:11:38',0,NULL,3,1,1,1,'\\  ','tonthathung'),(9898,697555126008,180699061927,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','ns00h','nathan@awh.com.au','Nathan Simpson','AWH Pty Ltd<br>250 Forest Road','Lara','Victoria','AUSTRALIA','3212','0417317411','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-25 05:20:07',0,NULL,3,1,3,1,'RA183628978CN ','ns00h\rOTRA001'),(9899,837629715012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','swabjockey3','psjbw@myfairpoint.net','Philip E. White','26 Deer St','Tilton','NH','UNITED STATES','03276-5403','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 05:06:56',0,NULL,3,1,1,1,'\\  ','swabjockey3'),(9900,0,220838632604,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.33,'eastar4','denismilea','mileadenis@gmail.com','Lutik Ratu','Mircea cel batran-23 kv.100','Kishineov','Lutic Radu','MOLDOVA, REPUBLIC OF','MD_2075','068128098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 06:12:45',0,NULL,3,1,2,1,'\\  ','denismilea'),(9901,754860055011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','isaactong','tongisaac@yahoo.com.hk','Isaac Tong','Flat RC, 59/F., Tower 3,<br>The Capitol of LOHAS Park, Tseung Kwan O, Kowloon','default','','HONG KONG','default','852-94654465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 06:29:22',0,NULL,3,1,2,1,'\\  ','isaactong'),(9902,837645350012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','belthorion','tommy.lundberg@gmail.com','Tommy Lundberg','Rosendalsvägen 12','Vallentuna','','SWEDEN','18633','0736636446','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 06:30:59',0,NULL,3,1,2,1,'\\  ','belthorion'),(9903,837646004012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','scud327','woolcot1@aol.com','ronald woolcot','21 the croft<br>great yeldham. halstead.','essex','Essex','UNITED KINGDOM','c094jd','01787237167','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 06:35:26',0,NULL,3,1,3,1,'RA183628981CN ','scud327\rHSNO005'),(9904,754863250011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','ferlanie_dajao238','ferlanie_dajao@yahoo.com','FERLANIE DAJAO','4023-F FOREST HILLS BANAWA','CEBU CITY','CEBU','PHILIPPINES','6000','32-2386257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 06:46:23',0,NULL,3,1,3,1,'RA183628394CN ','ferlanie_dajao238\rOTSO004\r一共买了两个'),(9905,754863883011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','ferlanie_dajao238','ferlanie_dajao@yahoo.com','FERLANIE DAJAO','4023-F FOREST HILLS BANAWA','CEBU CITY','CEBU','PHILIPPINES','6000','32-2386257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 06:48:49',0,NULL,3,1,17,0,NULL,'ferlanie_dajao238'),(9906,837649664012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','rudyrs21','rudyrs@juno.com','Russell Schaeffer','30592 Roaring River Dr','Coarsegold','CA','UNITED STATES','93614','(559) 676-0693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 06:51:23',0,NULL,3,1,1,1,'\\  ','rudyrs21'),(9907,8881314255098430,111,' New Grohe MultiFunction hand Shower Head',1,'OTGR001',0,'cnfaner','korwazbigniew','karolpietr@gmail.com','ZBIGNIEW PIETRZAK','3  /  9  LINCOLN  ST','SYDNEY  ','New South Wales','AUSTRALIA','2168','0488904097',NULL,NULL,NULL,'2011-08-25 06:51:38',0,NULL,3,1,3,1,'RA183628385CN ','补发的 \rOTGR001'),(9908,8881314258501953,111,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',0,'eastar4uk','topmuddle','ianadams1980@ntlworld.com','jeanette adams','12 bockhanger lane kennington','ashford','Kent','UNITED KINGDOM','tn249bn','01233629359',NULL,NULL,NULL,'2011-08-25 07:48:21',0,NULL,3,1,3,1,'RA183628403CN ','补发的\r英标 \rHSMO019'),(9909,837680186012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT004',59.98,'eastar4uk','unicorn_joc','joze.studencnik@guest.arnes.si','Jože Studenčnik s.p.','SI84947454<br>Selovec 60/B','Šentjanž pri Dravogradu','','SLOVENIA','2373','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 09:03:32',0,NULL,3,1,3,1,'RA183628479CN\r ','unicorn_joc\rGLOT004\r兼容型3D眼镜  samsung 专用'),(9910,566293171004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','12m','69m@live.nl','Marco van den Berg','De Sluiswachter 41','UITGEEST','','NETHERLANDS','1911JJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 09:21:43',0,NULL,3,1,3,1,'RA183628425CN\r ','12m\rOTRA001'),(9911,832850506012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','pigeonsgopoo','jmhey@btinternet.com','J Hey','15 King Street','Haslingden','Lancashire','UNITED KINGDOM','BB4 5RT','07584032618','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 09:51:57',0,NULL,3,1,3,1,'RA183628451CN\r ','pigeonsgopoo\rOTSO004*2'),(9912,754917572011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',12.5,'eastar4','serge020953','ve2abc@ve2abc.com','Bérubé Serge','1075 des Champs st.','St-jean Chrysostome','QC','CANADA','G6Z1V4','(418) 839-4846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 10:44:04',0,NULL,3,1,2,1,'\\ ','serge020953\racer 4pin1.25 6cm'),(9913,837710549012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',138,'eastar4','shindongin','rodolf77@hanmail.net','shin dong in','Ggummaeul Hanshin Apt.702-1403, Gwiin-dong, Dongan-gu','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 11:06:31',0,NULL,5,1,18,1,NULL,'shindongin\rGLOT005*2\r投影仪兼容眼镜\r黑色的\r客户要撤单'),(9914,754923953011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','gregoryjessica1992','greg.wills71@gmail.com','gregory wills','33 upper gibson street','smithton','Tasmania','AUSTRALIA','7330','0364523498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 11:08:02',0,NULL,3,1,2,1,'\\ ','gregoryjessica1992\r红边优联'),(9915,754934913011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','nemehac','nestorcabigting@yahoo.co.uk','Nestor Cabigting','9 Church Acre<br>Brackla','Bridgend','Bridgend','UNITED KINGDOM','CF31 2JT','01656818701','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 11:46:07',0,NULL,3,1,3,1,'RA183628553CN\r ','nemehac\rGLSG001'),(9916,697634559008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',49.99,'au-buy','boneshocker','stv@cheerful.com','Stephen Baillie','LG1 13 East Esplanade<br>Manly','Sydney','New South Wales','AUSTRALIA','2095','0412123878','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-25 11:49:45',0,NULL,3,1,3,1,'RA183628482CN\r ','boneshocker\rGLOT001\r兼容型3D眼镜 通用型'),(9917,754956262011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','sblebs2010','contato@rapidoefacil.com.br','Daniel Anverze (JANETE)','Rua Sete de Setembro, 910<br>Buenos Aires','Mafra /SC','Santa Catarina','BRAZIL','89300-000','479911-9380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 12:58:14',0,NULL,3,1,2,1,'\\ ','sblebs2010\racer 6pin1.25 23cm'),(9918,837759780012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','bloodalex-52','bloodalex999@gmail.com','Alex Kienko','Frunze<br>109/35','Bor','Nizhni Novgorod','RUSSIAN FEDERATION','606440','8-908-151-75-09','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:27:57',0,NULL,3,1,2,1,'\\ ','bloodalex-52'),(9919,754972587011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',25.9,'eastar4uk','michaelstaus','michaelstaus@gmail.com','Michael Stausholm','Teglkaasvej 4 ST Th','Kastrup','','DENMARK','2770','234242998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 13:53:39',0,NULL,3,1,3,1,'RA183628496CN\r ','michaelstaus\rWWSI004'),(9920,754844147011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','theatrealvita','theatheatre@yahoo.com','Alva Ackley','58 Sequoia Rd','Fairfax','CA','UNITED STATES','94930-1540','(415) 454-8218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 14:39:12',0,NULL,3,1,1,1,'\\  ','theatrealvita'),(9921,755001745011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','hawknfgk','hawknet@gmail.com','Fred G. Karlsen','Solbakken<br>Hanslarsanes','Ramfjord','Troms','NORWAY','9027','+4748482834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 15:23:44',0,NULL,3,1,3,1,'RA183627734CN\r ','hawknfgk\rWWSI002+ANCN001'),(9922,755011112011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','kedsudap','annixion@gmail.com','Vorapoj Vorakhunvisarn','245/102 Soi 7/6 Moo17 Chuancheun parkville Kanchanapisek Rd.<br>Salathammasop Thaweewattana','Bangkok','Thailand','THAILAND','10170','6624480867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 15:43:35',0,NULL,3,1,2,1,'\\','kedsudap'),(9923,837802784012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','legal_kp','yeskkp@gmail.com','Kwangpyo Kang','Dangsan-dong 5ga,Yongdeungpo-gu<br>hyo-sung apt 203-1707','seoul','n/a','KOREA,REPUBLIC OF','150-755','82-10-3035-4091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 16:45:04',0,NULL,3,1,2,1,'\\  ','legal_kp'),(9924,837846494012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','kidda7','kiddamufc@aol.com','stuart smith','10 cringlebarrow close<br>boothstown','manchester','Lancashire','UNITED KINGDOM','m28 1yg','01617026073','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 17:12:03',0,NULL,3,1,3,1,'RA183628448CN\r ','kidda7\rOTSO004*2\r盒装的\r'),(9925,715319599001,110731214793,'New in box AKG K 450 Premium Foldable Headphone',1,'HSAK003',54.9,'buysia','ruscie','fabioferretti1977@libero.it','Fabio Ferretti','Viale Marinai d\'Italia<br>1/c scala d int. 08','San Benedetto del Tronto','AP','ITALY','63074','+393311368104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 17:13:59',0,NULL,3,1,3,1,'RA183628465CN\r ','ruscie\rHSAK003'),(9926,837851198012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','arabella788','albert-schweitzer@gmx.de','Helena temirov','Albert-Schwetzer-Strasse 7','Laatzen','','GERMANY','30880','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 17:23:36',0,NULL,3,1,2,1,'\\ ','arabella788\r欧标'),(9927,615959138013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',53.64,'eastar4','dudu38000','dudu.clx@hotmail.fr','dutilleul','33 rue de la resistance','seyssinet pariset','Rhône-Alpes','FRANCE','38170','0665752211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 17:36:00',0,NULL,3,1,3,1,'RA183628434CN\r ','dudu38000\rWLAP008'),(9928,837873126012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','koraha-3','hannu.kora@gmail.com','Hannu Kora','Ruotsinsalmenpolku 2 d 19','Turku','Turku','FINLAND','20240','044 2589594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 18:08:35',0,NULL,3,1,2,1,'\\  ','koraha-3'),(9929,755083425011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','aeizoon','juan@murciawireless.com','Juan Antonio Pagan','Apartado 134 Polig. OESTE','Alcantarilla','Murcia','SPAIN','30169','649920909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 18:38:15',0,NULL,3,1,3,1,'RA183628505CN\r ','aeizoon\rUDAP001'),(9930,837910197012,220620860324,'NEW GENUINE NOKIA BH-207 BLUETOOTH HEADSET BH 207',1,'HSNO010',24.99,'eastar4','tsau1856','leanoo@btinternet.com','Tony Saunders','6 Edenbridge Close','Orpington','Kent','UNITED KINGDOM','BR5 3SL','01689877322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 19:21:40',0,NULL,3,1,2,1,'\\   ','tsau1856\r英标'),(9931,837938315012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','rachelsoom2011','rachelsoom@gmail.com','rachel soom','balfur 96','bat yam','israel','ISRAEL','59552','0507263626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 20:13:48',0,NULL,3,1,2,1,'\\  ','rachelsoom2011'),(9932,755131252011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','rcmorey11','rcmorey11@hotmail.com','Robert Morey','5 Technology Dr','Wallingford','CT','UNITED STATES','06492-1942','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 20:14:12',0,NULL,3,1,1,1,'\\ ','rcmorey11'),(9933,755136609011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','eoddata','todd@eoddata.com','EODData LLC','444 North Michigan Avenue<br>Suite 1200','Chicago','IL','UNITED STATES','60611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 20:25:50',0,NULL,3,1,1,1,'\\  ','eoddata\r二代卡 旧'),(9934,755137554011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','boobylou','bekki.scopes@talktalk.net','bekki scopes','48 peal close','Hoo, Rochester','Kent','UNITED KINGDOM','me3 9hz','01634256858','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 20:32:00',0,NULL,3,1,3,1,'RA183628363CN ','boobylou\rWLAP002\r二代卡 旧'),(9935,561010056003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',16.99,'cnfaner','mamawham','pamelaasbell@rocketmail.com','pamela asbell','503 E State Road 164','jasper','IN','UNITED STATES','47546-9307','(812) 309-3302','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-25 22:29:46',0,NULL,3,1,1,1,'\\ ','mamawham'),(9936,755199849011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','theroum','dv@drox.ca','Dinu Valentir','952 44th Avenue','Laval','QC','CANADA','H7R5A3','(514) 839-2500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 23:27:37',0,NULL,3,1,2,1,'\\  ','theroum'),(9937,616068099013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','blooddrench','blooddrench@gmail.com','Kenneth Cordova','5773 US Highway 6','Portage','IN','UNITED STATES','46368-4853','(219) 628-5052','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-25 23:47:24',0,NULL,3,1,1,1,'\\  ','blooddrench'),(9938,755211039011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','yeates87','yeatesie@gmail.com','James Yeates','8 Baird Court','Blackburn South','Victoria','AUSTRALIA','3130','61432484266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 00:12:22',0,NULL,3,1,2,1,'\\  ','yeates87'),(9939,838038749012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','jiyan-jiyan','dilektiskaya@hotmail.co.uk','Dilek Simsek','43 pleasant st<br>Morriston','swansea','Swansea','UNITED KINGDOM','sa6 6hh','01792515621','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 00:51:39',0,NULL,3,1,3,1,'RA183628417CN\r ','jiyan-jiyan\rHSPL011\r英标'),(9940,755241022011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','nibrofresh','nibrofresh@hotmail.com','Nibras F Bughrara','14 Bender Ave','Albany','NY','UNITED STATES','12208','(518) 207-3522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 02:07:28',0,NULL,3,1,1,1,'\\  ','nibrofresh'),(9941,755245310011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','johnie89pp','johnie89paypal@gmail.com','Jonathan McDonnell','50 The Priory','Donabate','Co Dublin','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 02:25:38',0,NULL,3,1,2,1,'\\   ','johnie89pp\r二代卡 旧'),(9942,755247308011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','danno824','francis314@yahoo.com','Dan Francis','3222 Hedgetree Lane','St. Louis','MO','UNITED STATES','63129','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 02:32:12',0,NULL,3,1,1,1,NULL,'danno824\r二代卡 旧'),(9943,8881314327099117,111,'SONG ERICSSON HBH-PV705',10,'HSSE005',0,'cnfaner','bogunovic46','zulee46@yahoo.com','Milos Djuric','Balkanska 12','Belgrade','Serbia','SERBIA','11000','',NULL,NULL,NULL,'2011-08-26 02:51:39',0,NULL,3,1,3,1,'RA183628536CN\r ','补发的\rHSSE005 '),(9944,561066003003,130554588921,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',54.99,'cnfaner','rachaeljayjay1','rachaelone27@yahoo.com','donna pasternak','31 ferguson street','broadford','Victoria','AUSTRALIA','3658','0357843038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 03:50:11',0,NULL,3,1,3,1,'RA183628540CN\r ','rachaeljayjay1\rKBFF001'),(9945,616117169013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','l.wisniewski','leewisniewski@internode.on.net','Lee Wisniewski','79 Normanby Street','East Geelong','Victoria','AUSTRALIA','3219','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 03:51:03',0,NULL,3,1,2,1,'\\   ','l.wisniewski'),(9946,561068141003,130554588383,'NEW Logitech battery 890 880 950mA',1,'BALO001',11.9,'cnfaner','michaelclark50','michaelclark50@hotmail.com','Michael Clark','2545 Crews Lake Hills Loop N','Lakeland','FL','UNITED STATES','33813','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-26 04:08:07',0,NULL,3,1,1,1,'\\   ','michaelclark50'),(9947,697944605008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',49.99,'au-buy','4900plr','peterl147@hotmail.com','Tim Michaels','93 Robey st','Maroubra','New South Wales','AUSTRALIA','2035','0404261932','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-26 04:48:57',0,NULL,3,1,3,1,'RA183628933CN\r ','4900plr\r兼容型3D眼镜 通用型'),(9948,615812388013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',86.55,'eastar4','vibs2624','james.chan@atlantictelecommunications.com.au','Atlantic Telecommunications Pty.Ltd','Level 1<br>446 Collins St','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 05:10:59',0,NULL,3,1,3,1,'RA183628916CN\r ','vibs2624\rAT-210TS  3个\rCAB-6060  3条\rCAB-2626  2条\rCAB-2660  2条'),(9949,838113779012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',12.5,'eastar4','renistan','udohoffi@aol.com','Udo Hoffmann','Finkenweg 8','Wustermark','','GERMANY','14641','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 06:06:07',0,NULL,3,1,2,1,'\\   ','renistan\racer 5pin1.25 6cm'),(9950,755288989011,320738496776,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',25.99,'eastar4','gtb5','gtb555@gmail.com','Jimmy Leung','11/F, Zung Fu Industrial Building<br>1067 King\'s Road','default','','HONG KONG','default','(852) 94903630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 06:09:22',0,NULL,3,1,2,1,'\r\\  ','gtb5\rLED发光伞'),(9951,616138466013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',143.99,'eastar4','rksantia15','rksantia15@sbcglobal.net','Roxane Santiago','876 Scarlet Ave','Henderson','NV','UNITED STATES','89002-8432','(702) 568-6044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 06:48:05',0,NULL,3,1,1,1,'\\   ','rksantia15\r兼容型3D眼镜 通用型'),(9952,755292388011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','sweatingbullets13','avinash.sabapathee@rmit.edu.au','Avinash Sabapathee','4 Santon Street<br>Greensborough','Melbourne','Victoria','AUSTRALIA','3088','0412254091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 06:50:49',0,NULL,3,1,2,1,'\\','sweatingbullets13'),(9953,838129628012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',97.99,'eastar4','89898989898911','poseidon_89@mail.ru','Andrey Krymsky','Molodejnaya 17 str. ap. 6','Novy Urengoi','Tumenskaya obl Yanao','RUSSIAN FEDERATION','629300','9642042730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 07:23:25',0,NULL,3,1,3,1,'RA183628920CN\r ','89898989898911\rGLOT001*2\r兼容型3D眼镜 通用型'),(9954,616147996013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','jazz20020_1','zafyildiz@mac.com','zafer yildiz','563 Remuera Road<br>Remuera','Auckland','','NEW ZEALAND','1050','(00)64 9 5240356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 07:49:26',0,NULL,3,1,6,1,'EE495359375CN ','jazz20020_1'),(9955,715557790001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','ifel79','ifelmail@gmail.com','Nemchenko Oksana','Kuruzova, building 5<br>flat 24','Zaporozhye','','UKRAINE','69124','(050) 454 - 5544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 07:55:29',0,NULL,3,1,3,1,'RA183628522CN\r ','ifel79\r'),(9956,755315840011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','mapri2444','hah906@googlemail.com','Hamri Aslan Hj Abu Hanafiah','No: 15 KG Delima Satu<br>Jalan Kebangsaan','Bandar Seri Begawan','Brunei-Muara District','BRUNEI DARUSSALAM','BB4713','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 08:21:51',0,NULL,3,1,2,1,'\\','mapri2444\r英标\r'),(9957,838146650012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','pgeorgiev2010','petar@georgiev.com','Petar Georgiev','17, Zlatna Vrata Str. app.11','Sofia','Sofia','BULGARIA','1408','+359897884949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 08:50:11',0,NULL,3,1,3,1,'RA184555923CN\r ','pgeorgiev2010\rWWOT001\r通用版 全新'),(9958,755334269011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',7,'OTCN002',27.93,'eastar4','daseinkaufskonto','eineinkaufskonto@arcor.de','Nickyrose Sappelt','Heinestr. 3','Hüllhorst','','GERMANY','32609','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 09:34:12',0,NULL,3,1,2,1,NULL,'daseinkaufskonto\r2\"44pin'),(9959,838166746012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','gundam**','moronic_genius@hotmail.com','chee seng choo','blk 47 circuit road #03-715','default','','SINGAPORE','370047','+6592476889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 09:49:31',0,NULL,3,1,11,1,NULL,'gundam**\rANTY001'),(9960,616173108013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',17.4,'eastar4','mooskii2009','missdonna1982@hotmail.com','Donna Sullivan','30 Golconda ave','Frankston','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 10:18:04',0,NULL,3,1,2,1,NULL,'mooskii2009\rCAB-6060'),(9961,838218312012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.5,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 12:40:25',0,NULL,3,1,3,1,'RA183628805CN\r ','grandizom\rOTCN004*10\r黑色的'),(9962,838220341012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',35,'eastar4uk','bbjuhwajuhwa','bbjuhwa@gmail.com','Juhwa Lee','844-2 Top Plaza 601<br>Byeongjeom-dong','Hwaseong-si','Gyeonggi-do','KOREA,REPUBLIC OF','445-360','(010) 318-8792 ext.: 4','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 12:48:53',0,NULL,3,1,3,1,'RA183628567CN\r ','bbjuhwajuhwa\rWWSI006+ANCN001'),(9963,838220499012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','sjentwistle','sjentwistle@yahoo.co.uk','Steve Entwistle','Kenson, Units 101/102<br>Cirencester Business Park, Love Lane','Cirencester','Gloucestershire','UNITED KINGDOM','GL7 1XD','01285647900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 13:01:05',0,NULL,3,1,3,1,'RA183627045CN\r ','sjentwistle\rOTSO004*2\r盒装的'),(9964,566621345004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'cnfaner','etibmar','tibor.marusic@gmail.com','Tibor Marušić','Filipa Latinovicza 2','Zagreb','','CROATIA','10000','00385-91-365-4341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 13:36:22',0,NULL,3,1,3,1,'RA183627898CN\r ','etibmar\rOTGR005'),(9965,838242070012,220820867499,'New Grohe Crystal Anion Spa Shower Head made in Germany',1,'OTGR004',22.99,'eastar4','etibmar','tibor.marusic@gmail.com','Tibor Marušić','Filipa Latinovicza 2','Zagreb','','CROATIA','10000','00385-91-365-4341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 13:47:06',0,NULL,3,1,17,1,'\\  ','etibmar\r加压花洒 '),(9966,616227590013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','gmussar','gary@mussar.com','Gary Mussar','53 Aero Dr.','Nepean','ON','CANADA','K2H 5E3','(613) 829-7035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 14:27:08',0,NULL,3,1,3,1,'RA183628669CN\r ','gmussar\rBAZA001'),(9967,838262102012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',10.4,'eastar4uk','ikot4862','ian.kotarski@ntlworld.com','Ian Kotarski','98 Hyde Avenue,<br>Stotfold,','Hitchin','Hertfordshire','UNITED KINGDOM','SG5 4JD','01462628641','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 14:40:27',0,NULL,3,1,3,1,'RA183628831CN\r ','ikot4862\r英标\rHSNO022'),(9968,755427938011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',19.99,'eastar4','ssuguincho','ssusong@gmx.net','Susanna Ssusong Cho','Kleinfeldchensweg 7d','Köln','','GERMANY','51109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 14:43:19',0,NULL,3,1,2,1,'\\  ','ssuguincho'),(9969,566639194004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',2,'OTRA001',75.98,'cnfaner','freddemagic','pfostersund@gmail.com','Fredrik Engberg','Brunkullavägen 4','Brunflo','','SWEDEN','83431','466323032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 14:54:17',0,NULL,3,1,3,1,'RA183628575CN\r ','freddemagic\rOTRA001'),(9970,755441666011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','matakohe21','njandeduckworth@yahoo.co.uk','Norman Duckworth','Piers Meadow<br>Lowe Lane, Wolverley','Kidderminster','Worcestershire','UNITED KINGDOM','DY11 5QR','01562851395','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 15:21:21',0,NULL,3,1,3,1,'RA183628598CN\r ','matakohe21\rHBPH002'),(9971,755453172011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',3,'HSJA011',98.97,'eastar4','braindamagefilms','darrin@braindamagefilms.com','Darrin G Ramage','7002 N Via Del Elemental','Scottsdale','AZ','UNITED STATES','85258-3902','(480) 980-6069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 15:51:30',0,NULL,3,1,1,1,'\\  ','braindamagefilms'),(9972,755475495011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','banjochar','herjourney@yahoo.com','charlene  woyan palos','99 E Perry St','tiffin','OH','UNITED STATES','44883-2310','(419) 447-2709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 16:47:50',0,NULL,3,1,1,1,'\\  ','banjochar'),(9973,838301536012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','gillyflower0_4','jillh@dsl.pipex.com','Richard Hopkins','179 Cyncoed Road<br>Cyncoed','Cardiff','Cardiff','UNITED KINGDOM','CF23 6AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 16:57:22',0,NULL,3,1,3,1,'RA183628638CN\r ','gillyflower0_4\rANCN001'),(9974,755480555011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',12.5,'eastar4','ibsale','kalimero952@yahoo.fr','olivier capron','1 rue de monchaux','verchain','Midi-Pyrénées','FRANCE','59227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 16:59:37',0,NULL,3,1,2,1,'\\  ','ibsale\racer 4pin1.25 6cm'),(9975,755427045011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',147.99,'eastar4','holtocw','chuck@mission4me.com','Chuck Holton','350 Landsing St','Mount Hope','WV','UNITED STATES','25880-9267','(304) 250-3306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 17:19:09',0,NULL,3,1,4,1,'YW867472176CN ','holtocw'),(9976,616289530013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','University of Houston Curriculum and Instruction Dept','256 Farish Hall','Houston','TX','UNITED STATES','77204-5027','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 18:09:18',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9977,616288350013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','johncg1','john.greeven@hp.com','john greeven','6825 NW Diamond Pl','Corvallis','OR','UNITED STATES','97330-9244','(541) 207-3813','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-08-26 18:09:41',0,NULL,3,1,6,1,'EE645685616CN ','johncg1'),(9978,755510756011,320602988656,'2.1 HP DV6300 DV6400 DV6500 Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','joeypent69','joeypent69@hotmail.com','Joes Computer Repair and Maintinence','238 Springer Dr','Raeford','NC','UNITED STATES','28376','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 18:09:45',0,NULL,3,1,1,1,'\\ ','joeypent69\rHP 8pin 1.25 18cm'),(9979,614837953013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Diego Botelho Gaino','1743 ALISON AVE','Santa Maria','CA','UNITED STATES','93458-1661','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 18:12:48',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9980,616290386013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','mpivv','mpi@telus.net','Kevin Hsu','2F-3, No. 28, Lane 78, Xing-Ai Rd., Nei-Hu Dist.,','Taipei','Taiwan','TAIWAN','','(886) 227-9261 ext.: 71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 18:13:24',0,NULL,3,1,3,1,'RA183627155CN\r ','mpivv'),(9981,614851344013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Jeremi Sudol','3542 Hayden Ave<br>Ipplex C/O Fourth Wall Studios Ste A','Culver City','CA','UNITED STATES','90232-2413','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 18:32:12',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9982,616311830013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Lisa Cummings','49 CLAPBOARD HILL RD','WESTPORT','CT','UNITED STATES','06880-6318','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 19:19:58',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9983,616313086013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Chris Folsom','636 Orpington Rd','Baltimore','MD','UNITED STATES','21229-2127','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 19:23:53',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(9984,838407236012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',57.99,'eastar4uk','mistahfoggo2009','mistahfoggo@live.com','Ryan Foster','69 Dillon Road','Leicster','Leicestershire','UNITED KINGDOM','LE3 9PJ','01162912429','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 20:01:42',0,NULL,3,1,3,1,'RA183627840CN\r ','mistahfoggo2009\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(9985,755584156011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',39.99,'eastar4','stefan6839','alexanderreingard@web.de','Sergej Reingard','Heinrichstr. 67','Dinklage','','GERMANY','49413','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 20:54:14',0,NULL,3,1,3,1,'RA183628743CN\r ','stefan6839\r欧标\rHSSE008'),(9986,616341869013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','troysplann','gibbut@comcen.com.au','Troy Splann','37 endeavour road','bluewater','Queensland','AUSTRALIA','4818','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 20:55:37',0,NULL,3,1,2,1,'\\  ','troysplann'),(9987,755589295011,320730087169,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',8.99,'eastar4uk','manxmann','sslaytor@iom.com','Simon Slaytor','Quarterlands<br>Port Lewaigue Close','Maughold','Isle of Man','UNITED KINGDOM','IM7 1AH','01624812761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 21:07:24',0,NULL,3,1,3,1,'RA183627822CN\r ','manxmann\rWLAT005+WLAT011\r再发一个IBM AR5008 box'),(9988,755590801011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','manxmann','sslaytor@iom.com','Simon Slaytor','Quarterlands<br>Port Lewaigue Close','Maughold','Isle of Man','UNITED KINGDOM','IM7 1AH','01624812761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 21:11:16',0,NULL,3,1,17,0,NULL,'manxmann'),(9989,616351659013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','anber_ru','anber@anber.ru','Anton Evzhakov','Starostina st. 67–51','Murmansk','Murmanskaya','RUSSIAN FEDERATION','183036','+7911364184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 21:35:56',0,NULL,3,1,2,1,'\\  ','anber_ru'),(9990,838450738012,220747230769,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',11.99,'eastar4uk','brighon','brghndvs@googlemail.com','brighon davis','Garden Flat 65<br>Stanmore Road','BIRMINGHAM','West Midlands','UNITED KINGDOM','B169SU','07831737870','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 21:44:08',0,NULL,3,1,3,1,'RA183628791CN\r ','brighon'),(9991,755616814011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','terry8188','twcole_158@yahoo.com','Terry Cole','1706 Harrington Dr','Champaign','IL','UNITED STATES','61821-6403','(217) 359-6387','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 22:27:03',0,NULL,3,1,1,1,'\\  ','terry8188'),(9992,755621814011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',57.99,'eastar4uk','omsoares','ophelia@thames-gateway.org.uk','Ophelia Soares','98<br>Norfolk Road','Seven Kings, Ilford','Essex','UNITED KINGDOM','IG3 8LJ','02085902198','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 23:01:47',0,NULL,3,1,3,1,'RA183627796CN\r ','omsoares\rGLOT001*2\r兼容型3D眼镜 通用型'),(9993,616378020013,230649288384,'New Replaceable Shell 4 logitech Anywhere MX Mouse M905',1,'SHLO005',16.99,'eastar4','kotapb','kotaprasad@hotmail.com','Kota Prasad','5239 Rosalind Blvd','Powell','OH','UNITED STATES','43065','(614) 495-1064','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 23:29:48',0,NULL,3,1,1,1,'\\ ','kotapb'),(9994,755641038011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','j8s8n','m888w@ymail.com','Kam Wah Wong','Flat 3<br>18 Alfred Street','Bath','Somerset','UNITED KINGDOM','BA1 2QU','01225319970','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 23:58:28',0,NULL,3,1,3,1,'RA183627884CN\r ','j8s8n'),(9995,755642215011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','donmyles','eugemyles@gmail.com','Donald E. Myles','5385 Tenderfoot Dr','Fontana','CA','UNITED STATES','92336-1134','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 00:05:27',0,NULL,3,1,1,1,'\\  ','donmyles'),(9996,755642597011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',17.15,'eastar4','jdseara','jdseara@gmail.com','Javier Diaz Seara','C/Monjas, Nº 5','Hinojosa del Duque  (Córdoba)','Andalucía Ceuta y Melilla','SPAIN','14270','655776410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 00:07:51',0,NULL,3,1,2,1,'\\  ','jdseara'),(9997,615591774013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','aing1557nayoung','sheisvery@naver.com','Nayoung Kang','18dong-308ho,Gepo-Jugong apartment<br>,660-12 Gepo-dong','Seoul','Gangnam-gu','KOREA,REPUBLIC OF','135-240','+82-10-2551-6456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 01:05:02',0,NULL,3,1,2,1,'\\  ','aing1557nayoung'),(9998,838513914012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','bornrox','ufg.claudio@gmail.com','Claudio Henrique Santana','Rua São Judas Tadeu Q36 L16<br>Setor Jardim Planalto','Goiânia','Goiás','BRAZIL','74333280','+556284229660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 01:25:06',0,NULL,3,1,2,1,'\\  ','bornrox'),(9999,616401190013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',83.99,'eastar4','lovetorace99','cbuvyer@hotmail.com','Craig Buvyer','#607-193 Aquarius Mews','Vancouver','BC','CANADA','V6Z2Z2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 01:38:43',0,NULL,3,1,3,1,'RA183627853CN\r ','lovetorace99\rMOSA005\r'),(10000,755666102011,320596607503,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',5.7,'eastar4','theweeb','crenshawhouse@verizon.net','Blake B Crenshaw','22626 Kathryn Ave','Torrance','CA','UNITED STATES','90505-3402','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 01:48:33',0,NULL,3,1,1,1,'\\  ','theweeb'),(10001,561333243003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','drbilley','david.billey@ge.com','David Billey','4403 Garden Hills Ln','Kingwood','TX','UNITED STATES','77345-3025','(281) 359-4501','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 02:24:16',0,NULL,3,1,1,1,'\\  ','drbilley'),(10002,616412136013,230649255567,'New Japan Cute Tadpole w/lace trim Sun stick Umbrella',1,'UM00019',24.99,'eastar4','jancyxuan','jancy_xuan@hotmail.com','Jancy Ma','CameraPro Pty Ltd<br>Suite 607, 180 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0732101300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 02:37:52',0,NULL,3,1,2,1,'\\  ','jancyxuan\r小蝌蚪长柄伞'),(10003,561187305003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','illumar','millaz2003@hotmail.com','Marta Illueca','1100 Lovering Ave','Wilmington','DE','UNITED STATES','19806-3273','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 02:42:19',0,NULL,3,1,1,1,'\\  ','illumar'),(10004,838538442012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','fairstep','fairstep@optusnet.com.au','Sam Makeham','92 Rosedale Rd','Pymble','New South Wales','AUSTRALIA','2073','61299839696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 03:04:51',0,NULL,3,1,3,1,'RA183628607CN\r ','fairstep\rOTGR001+OTGR002'),(10005,616417808013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ralv8310','tiburon20_2000@yahoo.com','Rodriguez ALVARO','24375 JACKSON AVE<br>Apt 201D','MURRIETA','CA','UNITED STATES','92562-1915','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 03:11:21',0,NULL,3,1,1,1,'\\  ','ralv8310'),(10006,755688279011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','razdrvr','razdrvr@yahoo.com','Eric Castillo','1002 S Cedar Ridge','Duncanville','TX','UNITED STATES','75137','(972) 825-6448','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 03:30:49',0,NULL,3,1,1,1,'\\  ','razdrvr'),(10007,715889721001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK002',96,'buysia','sylvania170','thrstlnd@yahoo.com','Thurston Lindo','2804 St Andrews Road Windsor Park','Regina','SK','CANADA','s4v2z9','(306) 757-9255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 03:40:59',0,NULL,3,1,3,1,'RA183627751CN\r ','sylvania170\rHSAK002'),(10008,561357672003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',23.9,'cnfaner','ttam2010ttam','ttam2010@gmail.com','Tatsuya Tamura','Rumine-Sangenjaya#205 1-36-3<br>Sangenjaya','Setagaya-ku','Tokyo','JAPAN','1540024','09033586521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 05:47:01',0,NULL,3,1,3,1,'RA183628584CN\r ','ttam2010ttam\rHSJA004'),(10009,755711875011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','helicon93','walter.decuignierre@laposte.net','Walter DECUIGNIERRE','3 résidence Baudoin','LE BOURGET','Île-de-France','FRANCE','93350','0954049192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 05:53:47',0,NULL,3,1,2,1,'\\  ','helicon93'),(10010,755718150011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','ivcrllc','jerad.forcier@gmail.com','Jerad Forcier','8819 Sendera Dr','Magnolia','TX','UNITED STATES','77354','(936) 828-0256','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:29:34',0,NULL,3,1,1,1,'\\  ','ivcrllc'),(10011,616452648013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','tomaigner','tomaigner@verizon.net','Thomas M Aigner','5033 Comstock Cir','Keller','TX','UNITED STATES','76244','(817) 741-0534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 07:36:42',0,NULL,3,1,1,1,'\\  ','tomaigner'),(10012,616465577013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',3,'HBPH004',29.97,'eastar4','michchia24','michellechia78@gmail.com','chia  michelle','167 bukit batok west ave 8 #02-234','default','','SINGAPORE','650167','91442162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 08:54:17',0,NULL,3,1,11,1,'\\ ','michchia24\rHBPH004'),(10013,755751531011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','hagaimann','hagaiman@hotmail.com','Hagai Mann','haatzmaut 47a','Binyamina','Israel','ISRAEL','30500','0524358605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 09:05:36',0,NULL,3,1,2,1,'\\  ','hagaimann'),(10014,755755444011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','chris_488','chris_richselling@hotmail.co.uk','Chris Foster','46<br>Holding','Worksop','Nottinghamshire','UNITED KINGDOM','S810TD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 09:09:15',0,NULL,3,1,3,1,'RA183627972CN\r ','chris_488\rMOAP001'),(10015,838622909012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',29.99,'eastar4uk','hansvshch','hansvshch2@forum.dk','Hans Haagensen','Ringtoften 117 2tv','Skovlunde','','DENMARK','2740','44849231 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-27 09:36:43',0,NULL,3,1,3,1,'RA183627779CN\r ','hansvshch\rGLOT004\r兼容型3D眼镜  samsung 专用'),(10016,838625761012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','vivaelchurrasco','jrtudela@hotmail.com','Jose R. Tudela Sanmiguel','Apdo. 22','Godella','Comunidad Valenciana','SPAIN','46110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 09:43:25',0,NULL,3,1,2,1,'\\  ','vivaelchurrasco'),(10017,755784759011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','ames09','ames09_02764@yahoo.com','Amy E Ouellette','1311 Tremont St','N Dighton','MA','UNITED STATES','02764-1604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 10:52:20',0,NULL,3,1,1,1,'\\  ','ames09'),(10018,755790063011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','ian-speirs101','ian-speirs@hotmail.co.uk','Ian Speirs','29<br>Calderhouse Road','Mid Calder','West Lothian','UNITED KINGDOM','EH53 0JZ','01506883209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 11:14:32',0,NULL,3,1,3,1,'RA183628880CN\r ','ian-speirs101'),(10019,755823217011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','66dclg','nichols.davidj@gmail.com','David J. Nichols','4449 Waterbury Ln','Marietta','GA','UNITED STATES','30062-8140','(770) 992-4558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 12:56:39',0,NULL,3,1,1,1,'\\  ','66dclg'),(10020,616518473013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',91.96,'eastar4','sunstorm2011','mathiasenanders@gmail.com','Anders Mathiasen','Kronprinsensgade 53, 1 tv.','Esbjerg','Region Syddanmark','DENMARK','6700','25332280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 13:06:11',0,NULL,3,1,3,1,'RA183627805CN\r ','sunstorm2011\rMOSA004'),(10021,755632550011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','almeisan71','lagace.patrick@gmail.com','Patrick Lagacé','128 De Touraine','Terrebonne','QC','CANADA','J6W 6L8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 13:24:32',0,NULL,3,1,2,1,'\\  ','almeisan71'),(10022,838699445012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','matthewfallon','matt@fallononline.co.uk','Matthew Fallon','5 - 13 Eban Avenue<br>Hillcrest','Auckland','','NEW ZEALAND','0627','64094199780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 13:27:20',0,NULL,3,1,3,1,'RA183628690CN\r ','matthewfallon\rWWOT003'),(10023,755859519011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',135.99,'eastar4uk','osprey1942','david@culpleasant.co.uk','DAVID GEDDES','1 CULPLEASANT DR','TAIN','Highland','UNITED KINGDOM','IV19 1JT','01862892137','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 14:35:16',0,NULL,3,1,4,1,'YW867472165CN ','osprey1942\rMOLO010'),(10024,838727946012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','andreybirman2005','andreybirman@hotmail.com','Andrey Birman','Haikarim 7<br>Apartment 54','Azor','','ISRAEL','58001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 14:35:52',0,NULL,3,1,2,1,'\\  ','andreybirman2005'),(10025,755867236011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','mahuzier','mahu_1@hotmail.com','Antoine Mahuzier','8 Millbrook Villas<br>Millroad','Midleton','Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 14:55:14',0,NULL,3,1,2,1,'\\  ','mahuzier\r\r新地址\rTREND MICRO\rMr MAHUZIER Antoine\rMODEL FARM ROAD\rIDA BUSINESS AND TECHNOLOGY PARK\rCORK\rCo. CORK\rIRELAND \r\r\r \r\r\r'),(10026,755870165011,320738961239,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo Y460',1,'BTLE3002',19.99,'eastar4','angie11220','jerryspears@nc.rr.com','Jerry Spears','3604 Talus Rd','Fayetteville','NC','UNITED STATES','28306-9717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 15:02:27',0,NULL,3,1,1,1,'\\  ','angie11220'),(10027,616550538013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',39.99,'eastar4','marsyanya','nickson2000@mail.ru','Vladimir Nikulenko','28 Kalarasha Street, Appartment 29','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-08-27 15:06:58',0,NULL,3,1,3,1,'RA183628828CN\r ','marsyanya\r欧标\rHSNO019'),(10028,755874992011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','heyoungyou','youheyoung@gmail.com','heyoung you','9929 Venice Blvd','los angeles','CA','UNITED STATES','90034-5111','(951) 285-0881','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 15:16:21',0,NULL,3,1,1,1,'\\ ','heyoungyou\r正红色长柄婚庆伞 '),(10029,755895393011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','zuzu_91','z_u_z_u@hotmail.fr','Julien Laborie','4, rue Marcel mandion<br>Bat B.3','Crosne','Ile-de-France','FRANCE','91560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 16:05:03',0,NULL,3,1,2,1,'\\  ','zuzu_91'),(10030,755901534011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','nat657','nat4shure@aol.com','Natalie Helm','18481 Pellett Dr','Fenton','MI','UNITED STATES','48430-8508','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 16:18:29',0,NULL,3,1,1,1,'\\  ','nat657'),(10031,838773150012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','racerex5757','racerex5@hotmail.com','Rex Morgan','108 Sanderling Walk','Yorktown','VA','UNITED STATES','23692-6142','(757) 320-1536','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 16:19:34',0,NULL,3,1,1,1,'\\ ','racerex5757'),(10032,755908860011,320667818608,'New Logitech battery 4  DJ remote diNovo keyboard 930mA',2,'BALO004',21.98,'eastar4','zhuko75','lawrenceko1@gmail.com','Lawrence Ko','452 Ormsby Road West NW','Edmonton','AB','CANADA','T5T 6B1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 16:33:50',0,NULL,3,1,2,1,'\\  ','zhuko75\r黑色'),(10033,755940901011,320574757091,'NEW GENUINE NOKIA BH-209 BLUETOOTH HEADSET N70 N93',1,'HSNO011',20,'eastar4','agus3801','arygusmao@bellsouth.net','ary gusmao','22203 majestic woods way','boca raton','FL','UNITED STATES','33428','(561) 212-9186','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-27 17:42:40',0,NULL,3,1,1,1,'\\  ','agus3801'),(10034,616600706013,230641231786,'New lady lotus leaves sun/rain stick umbrella pink',1,'UM00002',24.99,'eastar4','jandp2505','paigegarmonagain@gmail.com','Paige Percival','8982 Birch Bay Cir','Lorton','VA','UNITED STATES','22079-5659','(256) 399-2518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 17:47:40',0,NULL,3,1,1,1,'\\ ','jandp2505\r荷叶边伞 粉红色的'),(10035,838822938012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','richarda805','acorn5555@hotmail.com','Richard Solar','9645 S Ave 24 E','Wellton','AZ','UNITED STATES','85356','(805) 441-1762','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-27 17:59:17',0,NULL,3,1,1,1,'\\  ','richarda805'),(10036,838827490012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 18:18:27',0,NULL,3,1,1,1,'\\ ','revikom\r24K 多色伞 '),(10037,755962263011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','shuc8211','shucks123@yahoo.com','Shawn Hucks','4203 Woodrow Rd','Lubbock','TX','UNITED STATES','79423-4615','(806) 535-6766 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 18:26:40',0,NULL,3,1,1,1,'\\  ','shuc8211'),(10038,838843259012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','ryanmcm86','ryan.mcmurdo@hotmail.com','Ryan McMurdo','Kirkstanes<br>Terregles','Dumfries','Dumfries and Galloway','UNITED KINGDOM','DG2 9RY','07458122025','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 18:37:24',0,NULL,3,1,3,1,'RA183628765CN\r ','ryanmcm86\rHSNO005\r'),(10039,616624026013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','trytobuy777','osteve11@gmail.com','Steve Reagan','6033 De Zavala Rd<br>Apt 1625','San Antonio','TX','UNITED STATES','78249-2212','(214) 425-5564','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 18:56:14',0,NULL,3,1,1,1,'\\  ','trytobuy777'),(10040,838892408012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','kitiesque','kitikatnip13@yahoo.com','mandy lantz','16096 E Easter Cir<br>Unit 301','Aurora','CO','UNITED STATES','80016-5075','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 20:14:36',0,NULL,3,1,1,1,'\\  ','kitiesque\r蕾丝蝴蝶结伞  黑色的 带红的'),(10041,838915902012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','robanpa','johnmfox@btinternet.com','John  Fox','The Haven Carters Lane','N/R Bishops Stortford','Hertfordshire','UNITED KINGDOM','CM226AQ','07919440000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 21:04:17',0,NULL,3,1,3,1,'RA183627990CN\r ','robanpa\rOTSO004*2'),(10042,616674683013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.4,'eastar4','marcocordovacatacora','m_cordova2000@hotmail.com','Marco Cordova','1900 NW 97th Ave<br>Ste 718-6745','doral','FL','UNITED STATES','33172-2310','786 265 4880','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 21:37:03',0,NULL,3,1,1,1,'\\  ','marcocordovacatacora\rHP 8pin 1.0 23cm '),(10043,561585714003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','dan_haz','birchbark@shaw.ca','Paul Vieira','1837B Kelowna Cres.','Cranbrook','BC','CANADA','V1C 6L6','(250) 426-5983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 22:07:04',0,NULL,3,1,3,1,'RA183628726CN\r ','dan_haz\rOMHJ001'),(10044,838950437012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',25.8,'eastar4','seagundo','brendan.cundy@westnet.com.au','brendan cundy','24 Ashby Dr','BUNGENDORE','New South Wales','AUSTRALIA','2621','0262380825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 22:32:36',0,NULL,3,1,2,1,'\\  ','seagundo'),(10045,756076532011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','silver_skies','dominic@balasuriya.me','Dominic Balasuriya','64 Monash Road','Blacktown','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 23:08:55',0,NULL,3,1,2,1,'\\  ','silver_skies'),(10046,756077642011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',3,'BALO001',35.97,'eastar4','indycolbybailey123','tlw@gpa3.com','Terry Wilson','75 Endeavour Ave<br>RR 1','Hubbards','NS','CANADA','B0J 1T0','(902) 273-2292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 23:15:48',0,NULL,3,1,3,1,'RA183628709CN\r ','indycolbybailey123\rBALO001'),(10047,616700372013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','gchoro','garychoromanski@gmail.com','Gary Choromanski','8 New Windsor Road<br>Avondale','Auckland','Auckland City','NEW ZEALAND','0600','006421621966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 23:26:05',0,NULL,3,1,2,1,'\\  ','gchoro'),(10048,838970369012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','elcanados','tomjoady@hotmail.com','Renaud Gagnon','39, rue Lhomond','Paris','Île-de-France','FRANCE','75005','0675090505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 23:36:04',0,NULL,3,1,2,1,'\\  ','elcanados'),(10049,616730653013,230653156192,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',47.99,'eastar4','veramoia64','veramoia@hotmail.com','K.Krastev','843 MERRITT  dr','MILTON','ON','CANADA','L9T4J9','(905) 876-9397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 02:01:51',0,NULL,3,1,3,1,'RA183627765CN\r ','veramoia64\rHSIT001'),(10050,839017552012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','srirvine','srirvine@msn.com','Steve Irvine','6500 Sand Trap Dr.','Laytonsville','MD','UNITED STATES','20882','(240) 750-0473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 02:32:44',0,NULL,3,1,1,1,'\\  ','srirvine'),(10051,839028151012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',15.79,'eastar4','mvpelectronicsbc','bcit77@gmail.com','Paul Kim','807 Carnarvon ST.,','New Westminster','BC','CANADA','v3m 3p1','(778) 397-7100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 03:19:13',0,NULL,3,1,2,1,'\\  ','mvpelectronicsbc\r白色的'),(10052,561649580003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',2,'WLDE001',29.8,'cnfaner','tiduck','myctem@gmail.com','Mark Yong Chuen-Tze','Blk 551 Ang Mo Kio Ave 10<br>#14-2224','Singapore','','SINGAPORE','560551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 04:49:52',0,NULL,3,1,3,1,'RA183628641CN\r ','tiduck\rWLDE001'),(10053,756160350011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','f411ingst4r','porterfield_t@yahoo.com','Tim Porterfield','PO Box 125<br>29322 Silverado Canyon Road','Silverado','CA','UNITED STATES','92676-0125','(949) 690-2220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 05:33:42',0,NULL,3,1,1,1,'\\  ','f411ingst4r'),(10054,756170741011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','midas-deals','twenty1nunder@yahoo.com','Lyla-Grace mcfarquhar','1129 lenox rd','brooklyn','NY','UNITED STATES','11212-2757','(646) 319-3243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 06:33:34',0,NULL,3,1,1,1,'\\  ','midas-deals'),(10055,616774684013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',11.99,'eastar4','fernandoblazin7','fernandoblazin@gmail.com','fernando marnewick','29 rielly place<br>mount wellington','auckland','','NEW ZEALAND','1060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 06:53:09',0,NULL,3,1,2,1,'\\  ','fernandoblazin7'),(10056,616776725013,230641602614,'New lady lotus leaves outdoor sun/rain stick Umbrella',1,'UM00002',24.99,'eastar4','vanman_4','johnmoran87@gmail.com','John Moran','12/1-9 Gray St','Sutherland','New South Wales','AUSTRALIA','2232','610425854796','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 07:11:59',0,NULL,3,1,2,1,'\\  ','vanman_4\r紫色的  荷叶边伞 '),(10057,756178847011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',3,'OTSO004',188.97,'eastar4','chrisd6607','chris.brian.davis@hotmail.com','Chris Davis','PO BOX 830','ROZELLE','New South Wales','AUSTRALIA','2039','0410626175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 07:16:51',0,NULL,3,1,3,1,'RA183627782CN\r ','chrisd6607\rOTSO004'),(10058,756181430011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','retsenek','email.74@inbox.ru','Alexandr Smetanin','Naberezhnaja<br>48-36','Volgorechensk','Kostromskaja oblast','RUSSIAN FEDERATION','156901','+79066666907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 07:23:05',0,NULL,3,1,2,1,'\\  ','retsenek'),(10059,616781074013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','ralphs555','euroralph@optusnet.com.au','Ralph Somma','67 Henry St','Windsor','Victoria','AUSTRALIA','3181','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 07:32:50',0,NULL,3,1,2,1,'\\  ','ralphs555'),(10060,839099909012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','oo7xyz','oo7xyz@wp.pl','Michal Koperski','Dunclug Gardens 64','Ballymena','Antrim','UNITED KINGDOM','BT43 6NW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 08:35:54',0,NULL,3,1,3,1,'RA183627836CN\r ','oo7xyz\rMOLO009\r'),(10061,839112178012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.75,'eastar4','terrill630','ajterrill@optusnet.com.au','Allan Terrill','284 Wilson Road','Buccan','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 09:09:07',0,NULL,3,1,2,1,'\\  ','terrill630\r黑色的'),(10062,567159470004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.99,'cnfaner','hotshot6996','eagle.5916@yahoo.com.au','Keith Appelkamp','60 Narrung Road','Meningie','South Australia','AUSTRALIA','5264','0408088410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 09:45:38',0,NULL,3,1,3,1,'RA183628774CN\r ','hotshot6996\rHSNO005\r澳标'),(10063,561698672003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','areemn','areemn@yahoo.com','Malcolm Johnson','17 Elizabeth St','Yorketown','South Australia','AUSTRALIA','5576','0888522053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 09:47:44',0,NULL,3,1,3,1,'RA183628686CN\r ','areemn\r澳标\rHSJA006'),(10064,616814037013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','radishs1b','radishs@radishs.org','LO SHIH MING','10F-7 No.132 Liuyang E. St. Beitun Dist.','Taichung','','TAIWAN','406','+886-921-721-629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 10:00:44',0,NULL,3,1,2,1,'\\  ','radishs1b'),(10065,616523472013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',43.9,'eastar4','hpelsk','h.pelskamp@upcmail.nl','Henk Pelskamp','Achterzoom 33','EEFDE','','NETHERLANDS','7211NE','0575-540435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 10:03:58',0,NULL,3,1,3,1,'RA183628730CN\r ','hpelsk\rMOLO004\r华硕限量版'),(10066,839137616012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','thithirs','titirs22@hotmail.com','Roque Falcón Santana Roque Falcón Santana','Camino Cuevas de Becerril 10','Galdar','Canarias','SPAIN','35460','606643609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 10:12:58',0,NULL,3,1,3,1,'RA183628876CN\r ','thithirs\rRCLO006'),(10067,756239529011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',14.99,'eastar4','dieulinh1984','linh.nd1984@gmail.com','Dieu Linh Nguyen','Unit 2/52 Rhodes Street','Hillsdale','New South Wales','AUSTRALIA','2036','6140522065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 10:26:58',0,NULL,3,1,2,1,'\\  ','dieulinh1984'),(10068,616831104013,230510752651,'NEW GENUINE NOKIA BH-209 BLUETOOTH HEADSET BH 209',1,'HSNO011',20,'eastar4','kosmetika1','germanel@inbox.lv','Linda Germane','Vienibas, 10-39<br>Lociki','Daugavpils','','LATVIA','5462','+37129437312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 11:05:21',0,NULL,3,1,2,1,'\\ ','kosmetika1\r欧标'),(10069,839167845012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','broese','arnold.rauch@aon.at','Rauch Arnold','Fasanweg 5','Neuwindorf bei Graz','','AUSTRIA','8073','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 11:24:49',0,NULL,3,1,2,1,'\\  ','broese\r澳标'),(10070,567187075004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','raul_br','raulneto_br@yahoo.com.br','Raul Oliveira Neto','Av. Giovanni Gronchi 4855 ap 22','Sao Paulo','Sao Paulo','BRAZIL','05724-003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 11:34:14',0,NULL,3,1,3,1,'RA183628519CN\r ','raul_br\rOTGR001+OTGR002'),(10071,756271796011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','pupikduanis','eliorpupik@yahoo.com','haim duanis','levi eshkul 69 /19','tel aviv','israel','ISRAEL','69361','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 11:44:21',0,NULL,3,1,3,1,'RA183627915CN\r ','pupikduanis\rGLOT001\r兼容型3D眼镜 通用型'),(10072,839193648012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','simoncwatkins','simon.watkins@gmail.com','simon watkins','6516 Northumberland st','Pittsburgh','pa','UNITED STATES','15217-1302','(412) 352-2277','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 12:23:19',0,NULL,3,1,1,1,'\\ ','simoncwatkins'),(10073,839210490012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',49.99,'eastar4','argie61','jason.turner@kordia.com.au','Jason Turner','29 Walsh Street','Thebarton','South Australia','AUSTRALIA','5031','0404830627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 13:04:07',0,NULL,3,1,3,1,'RA183628006CN\r ','argie61\rGLOT001\r兼容型3D眼镜 通用型'),(10074,839090712012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',2,'OTIN005',168,'eastar4','jazzzlobster83','jazzzlobster@gmail.com','Viacheslav Perepelkin','Butyrsky Val street, dom.48, kvartira.16','Moscow','Moscow','RUSSIAN FEDERATION','127055','(926)390-1584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 13:28:36',0,NULL,3,1,3,1,'RA183627938CN\r ','jazzzlobster83\rOTIN005'),(10075,616872242013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','samsopium','daananiev@gmail.com','Dmitry Ananyev','Astrahanskaya, dom 193, kv. 23','Tambov','Tambov','RUSSIAN FEDERATION','392005','902-723-4180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 13:28:43',0,NULL,3,1,2,1,'\\  ','samsopium\r欧标'),(10076,616884844013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',14.98,'eastar4','naruno','narunui@gmail.com','Arunas Nastaras','Lyros str.14-39','Siauliai','Lithuania','LITHUANIA','78288','68362063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 14:08:55',0,NULL,3,1,2,1,'\\  ','naruno\r欧标'),(10077,616892351013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'eastar4','penumbra2009','arioch@penumbra.be','Tom De Vylder','Nieuwstraat 5','Kapelle-op-den-Bos','','BELGIUM','1880','0870987098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 14:29:48',0,NULL,3,1,2,1,'\\  ','penumbra2009'),(10078,567237470004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','spaceppl','shpongler@gmail.com','LEONID MEERSON','21/3 Pinkas st.','Petach Tikva','','ISRAEL','49316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 14:33:47',0,NULL,3,1,3,1,'RA183628845CN\r ','spaceppl\rHSPL015\r欧标'),(10079,616647449013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','watanyoo.thannipat','watanyoo.th@gmail.com','Watanyoo Thannipat','112 M. 8 T. Si','Khun Han','Si Sa Ket','THAILAND','33150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 14:52:17',0,NULL,3,1,2,1,'\\  ','watanyoo.thannipat'),(10080,0,130566444373,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',14.99,'cnfaner','hayabusaman05','viperman96@comcast.net','Scott Davidson','295 Apple Way','Front Royal','VA','UNITED STATES','22630-9331','(540) 635-5786','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-28 14:54:08',0,NULL,3,1,1,1,'\\  ','hayabusaman05'),(10081,567248453004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','vermeulenpaard','m.a.vermeulen@xmsnet.nl','Michel Vermeulen','Poststraat 3','ARNHEM','','NETHERLANDS','6828EK','0268452224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 15:06:15',0,NULL,3,1,3,1,'RA183628788CN\r ','vermeulenpaard\rWLAP008'),(10082,756371162011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','chriskauffman','chriskauffman@vollgas.net','Christopher A. Kauffman','12913 Trailwood Rd','Austin','TX','UNITED STATES','78727','(512) 632-4286','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 15:22:08',0,NULL,3,1,1,1,'\\  ','chriskauffman'),(10083,756378613011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',147.99,'eastar4','igoriceman','iceigor@gmail.com','Igor Ulanovsky','ha-Alon 19/36','Nesher','','ISRAEL','36811','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 15:40:57',0,NULL,3,1,3,1,'RA184552480CN ','igoriceman\rEXLO001'),(10084,839312115012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','abir4331','artimess@gmail.com','Abbas Birjandi','32 Teresa Circle','Arlington','MA','UNITED STATES','02474','(781) 646-7114','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 16:05:45',0,NULL,3,1,1,1,'\\  ','abir4331'),(10085,756406942011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','image-of-the-mind-studios','imagemindag@aol.com','Arthur Greisiger/Image of the Mind Studios','1325 Industrial highway','Southampton','PA','UNITED STATES','18966-4047','(215) 292-9787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 16:24:02',0,NULL,3,1,1,1,'\\  ','image-of-the-mind-studios'),(10086,839328718012,220815928644,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',13.5,'eastar4uk','andronomad','andro.nomad@ntlworld.com','Steve Hiles','32 Daws Avenue','Bournemouth','Dorset','UNITED KINGDOM','BH11 8SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 16:30:30',0,NULL,3,1,3,1,'RA183628672CN\r ','andronomad\rWLIN010'),(10087,756436110011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','norman4604','normanhill130@o2.co.uk','Norman Hill','189 Smithybridge Road<br>Smithybridge','Littleborough','Lancashire','UNITED KINGDOM','OL15 0DB','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-28 17:06:00',0,NULL,3,1,2,1,'\\  ','norman4604\r向日葵三折叠伞 '),(10088,839358928012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.95,'eastar4uk','richarddempster','r_dempster@tiscali.co.uk','Richard Dempster','IGM Robotic Systems<br>Unit 4 Littleton Drive','Cannock','Staffordshire','UNITED KINGDOM','WS12 4TR','07854988286','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 17:10:33',0,NULL,3,1,3,1,'RA183628615CN\r ','richarddempster\rBALO007'),(10089,756440003011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','kentpcli','kent_sue@hotmail.com','Kent Li','3511 scratchley cres','Richmond','BC','CANADA','V6X 3T2','(604) 779-0662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:10:50',0,NULL,3,1,3,1,'RA183628902CN\r ','kentpcli\rHBPH002'),(10090,561843466003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','arcanatron','arcainous@gmail.com','Paul Orszaczki','c/o Stuart Caravan Park<br>70 Larapinta Drive','Alice Springs','Northern Territory','AUSTRALIA','0870','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:14:44',0,NULL,3,1,3,1,'RA183628814CN\r ','arcanatron\rHSJA006\r澳标'),(10091,839362532012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','mrtboy69','mrtboy1@gmail.com','Csaba Németh','Búza u. 14.      5/48','Budapest','Budapest','HUNGARY','1033','+36702567084','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 17:15:05',0,NULL,3,1,2,1,'\\  ','mrtboy69'),(10092,616967800013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','stormbowler','bylund@aloevita.no','odd arild bylund','Åsvegen 11','Verdal','NTR','NORWAY','7650','+47 95722070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:22:29',0,NULL,3,1,6,1,'EE645685602CN ','stormbowler'),(10093,839371647012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','mrrudush','s.rudush@gmail.com','Sergey Rudush','Leningradskaja<br>15-6','Togliatty','Samarskaja','RUSSIAN FEDERATION','445020','89270250160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:25:57',0,NULL,3,1,2,1,'\\  ','mrrudush\r网眼豹纹双层网纱长柄伞  '),(10094,839373536012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',10.99,'eastar4uk','alisonbramble','alison@alisondowell.wanadoo.co.uk','Alison Dowell','Pasture House, Normanby,<br>Sinnington,','York.','North Yorkshire','UNITED KINGDOM','YO62 6RH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 17:28:17',0,NULL,3,1,3,1,'RA183627924CN\r ','alisonbramble\rMOMI002\r黑色的'),(10095,567309732004,140516860307,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',17.5,'cnfaner','shroff_dealer','adam.shroff@gmail.com','Adam Shroff','2141 Braeside Place','Coquitlam','BC','CANADA','V3E3L3','(604) 944-8211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:30:33',0,NULL,3,1,3,1,'RA183628624CN\r ','shroff_dealer\rWLAT008+ANTY001'),(10096,756453467011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','awii_fr','d.poussou@orange.fr','Denis POUSSOU','Couderc-haut','MONTAYRAL','Aquitaine','FRANCE','47500','0553409295','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:30:38',0,NULL,3,1,2,1,'\\  ','awii_fr\r2\"44pin'),(10097,716583489001,110731214793,'New in box AKG K 450 Premium Foldable Headphone',1,'HSAK003',54.9,'buysia','valius.d','valentinas.d@gmail.com','Nikita Deniscenko','Fern Street 131,','London','','UNITED KINGDOM','E3 3PT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:39:10',0,NULL,3,1,3,1,'RA184553975CN\r ','valius.d\rHSAK003'),(10098,616976700013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','t.dang91','tina.dang91@gmail.com','Tina Dang','16123 Edenwood Dr','Bowie','MD','UNITED STATES','20716-6315','(301) 905-7630','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 17:40:56',0,NULL,3,1,1,1,'\\ ','t.dang91\r草莓伞 '),(10099,756500891011,320730544219,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT004*2',57.99,'eastar4uk','carolanne010','david2m@tiscali.co.uk','Carolanne Tustin','45 Llangattock Rd','Fairwater','Cardiff','UNITED KINGDOM','CF5 3BQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 18:28:58',0,NULL,3,1,3,1,'RA183627031CN\r ','carolanne010\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(10100,839447775012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',75.99,'eastar4uk','bonkersbanker','hr@exeter2.wanadoo.co.uk','Humphrey W Richards','The Gatehouse<br>Courtlands, Courtlands Lane','Lympstone','Devon','UNITED KINGDOM','EX8 3NZ','07711239667','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 18:49:52',0,NULL,3,1,3,1,'RA183627986CN\r ','bonkersbanker\rOTSO004*2\r盒装的'),(10101,567363510004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','igsbox','igshal@mail.ru','Igor Shalakhin','Novomar\'inskaya st. 15 - 166','Moscow','Moscow','RUSSIAN FEDERATION','109451','+7 925 5007068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 19:05:40',0,NULL,3,1,3,1,'RA183628655CN\r ','igsbox\rWLAP008'),(10102,756551456011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','cblackpanther1','cblackpanther@yahoo.com','Charles Harris','16 Hanover St<br>Apt A','Nashua','NH','UNITED STATES','03060-3747','(978) 430-5865','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 19:22:07',0,NULL,3,1,1,1,'\\  ','cblackpanther1'),(10103,756558076011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','arildmj','amj@jensendata.com','Arild Magne Jensen','Lyngvn 2','N-2260 Kirkenaer','Hedmark','NORWAY','2260','+4762848548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 19:35:26',0,NULL,3,1,2,1,'\\  ','arildmj\r红边优联'),(10104,756562227011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','ioannisdavios66','ioannisdavios@yahoo.com','ioannis davios','66 markou mpotsari st.','petroupoli','attiki','GREECE','13231','2105596318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 19:36:56',0,NULL,3,1,2,1,'\\  ','ioannisdavios66\r欧标'),(10105,839510848012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','abdullajk','mmehairi@eim.ae','ABDULLA GHALAITA','Aramex House, Old Bath Road<br>DXB 5791','Slough, Colnbrook','Berkshire','UNITED KINGDOM','SL3 0NS','(017) 503-6898 ext.: 98','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 20:09:48',0,NULL,3,1,3,1,'RA183628859CN\r ','abdullajk\r英标\rHSSE004'),(10106,617062729013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','djfran24','djfran@ono.com','FRANCISCO MARIN CAMPILLO','C/ GRUPO DE DANZAS SIETE CORONAS<br>Nº 7 - 1ºC','PUENTE TOCINOS','Murcia','SPAIN','30006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 20:10:48',0,NULL,3,1,2,1,'\\  ','djfran24'),(10107,617075941013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','aura222222','aura222222@naver.com','Hunjoo Lee (tel 010-3056-6560)','Hansol Central Park 2 CHA 1706 HO<br>Gwanyang-dong ,Dongan-gu,','Anyang-si,','Gyeonggi-do, South Korea (Republic of Korea)','KOREA,REPUBLIC OF','431-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 20:41:00',0,NULL,3,1,2,1,'\\  ','aura222222'),(10108,617080349013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','dkbrannan','dbrannan@cox.net','Darin Brannan','6501 NW 109','Oklahoma City','OK','UNITED STATES','73162','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 20:55:04',0,NULL,3,1,1,1,'\\  ','dkbrannan'),(10109,839544562012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','rejean2k','rejeanbe@gmail.com','Rejean Bellavance','884 Bowen St.','Magog','QC','CANADA','J1X1E1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 21:00:45',0,NULL,3,1,3,1,'RA183628757CN\r ','rejean2k\rRCLO006'),(10110,756637437011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bluecuteone22','oreo5374@aol.com','Hana Allen','228 Cumberland Way SE','Smyrna','GA','UNITED STATES','30080-7763','(404) 909-0987','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 21:48:27',0,NULL,3,1,1,1,'\\  ','bluecuteone22'),(10111,617097830013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','7689henri0','henri.berkleef@gmail.com','Henri Berkleef','Hofdijk 118','Rotterdam','','NETHERLANDS','3032cg','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 21:43:06',0,NULL,3,1,2,1,'\\  ','7689henri0'),(10112,756632835011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','wolf_lupodog','lupoj@rogers.com','Joseph A Lupo','34 Sanderling Drive','Markham','ON','CANADA','L3P 6R1','(905) 201-8676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 21:38:57',0,NULL,3,1,2,1,'\\  ','wolf_lupodog'),(10113,839577695012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','financegolfer','financegolfer@msn.com','Arthur Locke','19879 Mellon Circle','Ashburn','VA','UNITED STATES','20147','(703) 216-3006','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 22:07:59',0,NULL,3,1,1,1,'\\ ','financegolfer'),(10114,756654226011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kissfan1990','allmyebaystuff@comcast.net','Ryan Fisher','628 Stoney Creek Dr','Dauphin','PA','UNITED STATES','17018','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 22:32:38',0,NULL,3,1,1,1,'\\  ','kissfan1990'),(10115,839589914012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','tamisoare','mikkidutza@hotmail.com','Tamina Basarab','17 Wicklow Drive','Toronto','ON','CANADA','M1T1R6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 22:40:16',0,NULL,3,0,2,1,'\\  ','tamisoare\r已入库\r紫色的或黑色的'),(10116,617116950013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','alexandreespiritosanto','alexandreespirito@uol.com.br','Alexandre Espirito Santo','Rua Costa Sena 942','Belo Horizonte','Minas Gerais','BRAZIL','30720-350','+55 31 34648473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 22:49:33',0,NULL,3,1,2,1,'\\  ','alexandreespiritosanto\r韩版透明伞'),(10117,617124304013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',2,'RELO003',23.96,'eastar4','smus4806','aristotelonasis@gmail.com','Silviu Musa','74 Tania Crescent','Maple','ON','CANADA','L6A2M8','(416) 800-1095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 23:17:30',0,NULL,3,1,2,1,'\\  ','smus4806红边优联\r'),(10118,839624107012,220807295612,'3 pair 3D Active Shutter Glasses for Samsung SSG-2200AR',1,'GLOT004*3',143.99,'eastar4','msmiffy79','sallybray79@hotmail.com','sally bray','4 kenilworth street','miller','New South Wales','AUSTRALIA','2168','0425376454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 00:14:13',0,NULL,3,1,3,1,'RA183627028CN\r ','msmiffy79\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(10119,756686384011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',5,'UDAP001',172.45,'eastar4','gornros','gordo.p@gmail.com','Gordon Prokscha c/o RioTinto','Level 5, 1 William St<br>(The Quadrant)','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 00:15:09',0,NULL,3,1,3,1,'RA183628712CN\r ','gornros\rUDAP001'),(10120,617142360013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.99,'eastar4','jonas679','jojuljen@gmail.com','Jonas Jensen','Hans Ross gate 3','OSLO','','NORWAY','0172','+4748421069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 00:30:05',0,NULL,3,1,2,1,'\\  ','jonas679'),(10121,756701596011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','ttgunsup','edannemiller@mac.com','Lt Chris Dannemiller','708 NW 40th St','Lawton','OK','UNITED STATES','73505-4922','(713) 398-6340','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 01:07:31',0,NULL,3,1,1,1,'\\  ','ttgunsup'),(10122,699256031008,180699061927,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','eozimek','ekozimek@optusnet.com.au','edward ozimek','8 brett place','wyndhamvale','Victoria','AUSTRALIA','3024','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 01:23:42',0,NULL,3,1,3,1,'RA183628893CN\r ','eozimek\rOTRA001'),(10123,617175594013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','emsully3093','eric_sully@yahoo.com','Eric M. Sullenberger','1103 Scudder St','Piqua','OH','UNITED STATES','45356-1721','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 02:32:55',0,NULL,3,1,1,1,'\\  ','emsully3093'),(10124,756732758011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','bazooka22','garciapris74@yahoo.com','gorki hernandez','770 20th st NE','naples','FL','UNITED STATES','34120-3623','(239) 404-1661','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 02:39:43',0,NULL,3,1,1,1,'\\  ','bazooka22'),(10125,839679809012,220823043977,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',86.9,'eastar4uk','deadlycious187','deadlycious@hotmail.com','sara Pinard Lefrançois','20 A St-Antoine','Victoriaville','QC','CANADA','G6P 4H2','(819) 604-1796','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 03:04:28',0,NULL,3,1,3,1,'RA183627059CN\r ','deadlycious187\rHBPH005\r盒装的\r'),(10126,837621812012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',2,'UM00008',49.98,'eastar4','apgrinch','apgrinch@gmail.com','Phil Walsh','16 Playfair Rd','North Curl Curl','New South Wales','AUSTRALIA','2099','0401714918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 03:43:20',0,NULL,3,1,3,1,'RA184552493CN\r ','apgrinch\rUM00008\r24K 多色伞'),(10127,756752220011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','mpwnyc','mpw97@hotmail.com','Michael Whitman','1 Devonshire Pl<br>Apt 2511','Boston','MA','UNITED STATES','02109-3517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 04:02:54',0,NULL,3,1,1,1,'\\  ','mpwnyc'),(10128,756762285011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','csh036','natechang89@gmail.com','MyungSub Maeng','157/303 Castlereagh Street','Haymarket','New South Wales','AUSTRALIA','2000','0433828824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 05:01:48',0,NULL,3,1,3,1,'RA183627875CN\r ','csh036\rUDAP001'),(10129,8881314602153254,111,'MOTOROLA HS810',1,'HSMO017',0,'eastar4uk','juliejonno','jools.johnston99@btconnect.com','Julie Johnston','35 Old Earth','Elland','West Yorkshire','UNITED KINGDOM','HX59ES','07753663753',NULL,NULL,NULL,'2011-08-29 07:15:53',0,NULL,3,1,3,1,'RA183627748CN\r ','补发的  只补发耳机 \rHSMO017'),(10130,617220164013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','dead_mozay','windowskaput@gmail.com','URIY SHAROV','Pushkina 3','s. Nizhnyaya Omka','Omskaya oblastʹ','RUSSIAN FEDERATION','646620','+79043222525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 07:32:24',0,NULL,3,1,2,1,'\\  ','dead_mozay'),(10131,839737513012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','tarvi47','martin.lauren@mail.ee','Martin Lauren','Vikerlase 15-113','Tallinn','Harju mk','ESTONIA','13616','0037256475178','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 07:33:48',0,NULL,3,1,2,1,'\\  ','tarvi47'),(10132,617222235013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Albert Prast','400 Lakewood Dr','Winter Park','FL','UNITED STATES','32789-3940','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 07:45:32',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10133,756797030011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','jimmahall','james.hall@pearson.com','James Hall','Pearson Education<br>Edinburgh Gate','Harlow','Essex','UNITED KINGDOM','CM20 2JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 08:17:07',0,NULL,3,1,3,1,'RA183627725CN\r ','jimmahall\rWLAP002'),(10134,617228480013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Dan Soulsby','2164 MIDDLETON RD','Hudson','OH','UNITED STATES','44236-1435','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 08:24:17',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10135,839754626012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','maxim_karban','maxim.karban@gmail.com','Maxim Karban','generala Belova st. 29-2-36','Moscow','','RUSSIAN FEDERATION','115563','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 08:44:48',0,NULL,3,1,2,1,'\\  ','maxim_karban'),(10136,839755166012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',17.5,'eastar4uk','acardwelluk','andrew@cardwell.co.uk','Andrew Cardwell','27 Victoria Green','Witchford','Cambridgeshire','UNITED KINGDOM','CB62XB','07920006250','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 08:52:32',0,NULL,3,1,3,1,'RA183627717CN\r ','acardwelluk\rWLAP009'),(10137,839765950012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',29.99,'eastar4uk','torvid98','tvsf@c2i.net','Vidar Fredriksen','Meldalsvei 5','3269 Larvik','','NORWAY','3269','+47033115763','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 09:26:20',0,NULL,3,1,3,1,'RA183627408CN ','torvid98\rCMLO001'),(10138,716912381001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','bilskirnir','frank@brenna.as','Frank Brenna','Bergkrystallen 29','OSLO','OSLO','NORWAY','1155','4623380686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 09:39:19',0,NULL,3,1,3,1,'RA183627221CN\r ','bilskirnir\rHDGE001'),(10139,8881314611206068,111,'1000B',1,'MOOE002',0,'cnfaner','7x7-bay','7x7@mail.ru','Vadim Tiunov','Derjavina str. 77/1, kv.36','Novosibirsk','','RUSSIAN FEDERATION','630112','+79139163330',NULL,NULL,NULL,'2011-08-29 09:46:46',0,NULL,3,0,3,1,'RA184552635CN\r ','补发个OEM的1000B的钢丝绳 '),(10140,839772480012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.95,'eastar4uk','mark19630_13','markthain@blueyonder.co.uk','Mark Thain','48 Dunkirk Drive','Chatham','Kent','UNITED KINGDOM','ME50JF','01634301039','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 09:50:07',0,NULL,3,1,3,1,'RA183627204CN\r ','mark19630_13\rBALO007'),(10141,562099849003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','katient515','fhzl0515@naver.com','In Sook Jung','421~439, Bangbae 2-dong, Seocho-gu, Seoul, Korea<br>437-4 6F','Seoul','N/A','KOREA,REPUBLIC OF','137-817','82-10-3818-8325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 09:50:56',0,NULL,3,1,3,1,'RA183627297CN\r ','katient515\rHSUE002'),(10142,839775059012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*3',84.99,'eastar4uk','baccuswolf','lorenz@slimer.biz','Lorenz Wolf  -Retail IT','56 Wimbledon Hill Road','Wimbledon','London','UNITED KINGDOM','sw197pa','07903066214','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 10:01:31',0,NULL,3,1,3,1,'RA183627266CN\r ','baccuswolf\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(10143,839779269012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',7.98,'eastar4uk','pommiebugger','rajs@aapt.net.au','Bob  Stewart','29 Abbott Street','Burnie','Tasmania','AUSTRALIA','7320','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 10:13:16',0,NULL,3,1,2,1,'\\ ','pommiebugger'),(10144,617248024013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','marclauze','marclauze@hotmail.com','Marc Lauzé','1446 rue du Bourgeon','St-Nicolas','QC','CANADA','G7A 2K6','(418) 575-2760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 10:14:30',0,NULL,3,1,2,1,'\\ ','marclauze'),(10145,756831619011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','voyt','voytmar@yandex.ru','Andrey Tuinov','Tufana 22/9 - 808','Naberezhniye Chelny','Tatarstan','RUSSIAN FEDERATION','423823','+7 927-242-66-30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 10:27:17',0,NULL,3,1,3,1,'RA183627345CN\r ','voyt\rHSLO001'),(10146,699380853008,180699061588,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.99,'au-buy','royboy5111','roybaldwin51@live.com','roy baldwin','unit6/42 Holmesdale Rd','Woodbridge','Western Australia','AUSTRALIA','6056','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 11:05:19',0,NULL,3,1,3,1,'RA183627076CN\r ','royboy5111\rHSJA001\r澳标'),(10147,839795941012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',25.9,'eastar4uk','fishsilvertrout','howemi@tiscali.co.uk','Michael   howe','Chanctonbury<br>1 Coolers Farm','Broughton Stockbridge','Hampshire','UNITED KINGDOM','SO208BN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 11:05:51',0,NULL,3,1,3,1,'RA183627195CN\r ','fishsilvertrout\rOTGR001+OTGR002'),(10148,562126269003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',16.99,'cnfaner','dpweston65','dpweston@bigpond.com','Dion Weston','Blue Bayou<br>2/97 Esplanade','Golden Beach','Queensland','AUSTRALIA','4551','0754397332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:08:56',0,NULL,3,1,3,1,'RA183627306CN\r ','dpweston65\r澳标\rHSMO018'),(10149,567583173004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','desmen74','desmen74@yahoo.com','Loh Desmond','Blk 19, Bedok South Road, #07-27','default','','SINGAPORE','460019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:14:06',0,NULL,3,1,3,1,'RA183627249CN\r ','desmen74\rHSPL015'),(10150,699405845008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','outbackers69','tedschuurmans@hotmail.com','Ted Schuurmans','1 Sassoon Place<br>North Lake','Perth','Western Australia','AUSTRALIA','6163','0414479533','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 12:29:55',0,NULL,3,1,3,1,'RA183627080CN\r ','outbackers69\r澳标\rHSPL005'),(10151,839824790012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.5,'eastar4','cytzn','cytzn@hotmail.com','Christopher Tjhia','6 Pritchard Road','Macquarie Fields','New South Wales','AUSTRALIA','2564','0296056001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:35:13',0,NULL,3,1,2,1,'\\  ','cytzn'),(10152,617283457013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','svetlanaprincess','svetlanav@iinet.net.au','Svetlana Vulin','53 c Balcombe way<br>Westminister','Perth','Western Australia','AUSTRALIA','6061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:12:49',0,NULL,3,1,3,1,'RA183627270CN\r ','svetlanaprincess\rMOSA005'),(10153,839847364012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','erpica','ales.erpic@hermes.si','Ales Erpic','Cimermanova 3','Ljubljana','Slovenia','SLOVENIA','1260','00386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:50:20',0,NULL,3,1,3,1,'RA183627120CN\r ','erpica\rWWOT003'),(10154,617295581013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.9,'eastar4','pokupatell','sexrus0@gmail.com','Burdakov Sergey','Burdakov Sergey<br>Molodezhnaya 13-24','Kemerovo','','RUSSIAN FEDERATION','650071','9626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:52:30',0,NULL,3,1,2,1,'\\ ','pokupatell'),(10155,567606390004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','meibukan','cybergnosis@gmail.com','John Silveira','Travelers Canada<br>20 Queen St W. Suite# 300','Toronto','ON','CANADA','M5H 3R3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:00:37',0,NULL,3,1,3,1,'RA183627093CN\r ','meibukan\rBALO007'),(10156,756901465011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','tomorrow1040','tomorrow1040@comcast.net','Thomas Morrow','1077 Fitch Pl','Warminster','PA','UNITED STATES','18974','(215) 957-0196','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 14:13:20',0,NULL,3,1,1,1,'\\  ','tomorrow1040'),(10157,756910477011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','chen_howen','chen.howen@gmail.com','Ivan Chen','4F, No. 270, Sec. 4, Chung-Hsiao E. Rd.','Taipei','Taiwan','TAIWAN','106','(886)227813311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:39:20',0,NULL,3,1,2,1,'\\ ','chen_howen'),(10158,567610926004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','efraym2011','efraym2000@gmail.com','efraym davidov','hachim<br>8','holon','None','ISRAEL','58232','972503443700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:46:55',0,NULL,3,1,3,1,'RA184553030CN\r ','efraym2011\rHSPL015'),(10159,839875913012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','randygolfer1963','randy.lehn@covidien.com','Randolph   Lehn','185 Goldbach Dr','Stratford','CT','UNITED STATES','06614-1817','(203) 492-8029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 14:55:38',0,NULL,3,1,1,1,'\\  ','randygolfer1963'),(10160,756922001011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','*little*nemo*','david.fichtner@gmail.com','Fichtner','Seisgasse 18 Tür 16','Wien','','AUSTRIA','1040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 15:09:14',0,NULL,3,1,2,1,'\\ ','*little*nemo*'),(10161,839883761012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',162.99,'eastar4','darkbladenrw','oliver_scharmann@gmx.de','Oliver Scharmann','Rohrkamp 66','Senden','','GERMANY','48308','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 15:16:07',0,NULL,3,1,3,1,'RA183627371CN\r ','darkbladenrw\rGLSG001*3'),(10162,617325902013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','cooperleeski','lee@premiumit.com.au','Lee Cooper','5 Finney Street','Willagee','Western Australia','AUSTRALIA','6156','0893317132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 15:40:52',0,NULL,3,1,3,1,'RA183627283CN\r ','cooperleeski\rMOSA004'),(10163,617285671013,230649292141,'New Westwood Red w/lace Boetie Sun Rain Stick unbrella',1,'UM00027',14.95,'eastar4','zin-uru9944','zin-uru9944@web.de','Gerhard Wagner','Friedrich-Ebert-Str.8','Oberhaid','','GERMANY','96173','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 15:42:11',0,NULL,3,1,2,1,'\\  ','zin-uru9944\r蕾丝蝴蝶结长柄伞   '),(10164,756939023011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','vrmeira','vrmeira@yahoo.com.br','vinicius meira','r patagonia,927,ap 201, Sion','Belo Horizonte','Minas Gerais','BRAZIL','30320080','(31)83674844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 15:56:15',0,NULL,3,1,3,1,'RA183627310CN ','vrmeira\rOTSO004'),(10165,839909399012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','pollywollywoo','polly.pang@hotmail.co.uk','Polly Pang','Flat 22 Kingswood Court','Hither Green Lane','London','UNITED KINGDOM','SE13 6TD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 16:13:49',0,NULL,3,1,3,1,'RA183627181CN\r ','pollywollywoo\rOTGR001'),(10166,699484525008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','type0','nathan@elitesat.com','Nathan Beiley','30566 Bodega Dr','Murrieta','CA','UNITED STATES','92563-7877','(951) 347-4351','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 16:21:21',0,NULL,3,1,1,1,'\\  ','type0'),(10167,617343629013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',237.99,'eastar4','curty123','wiserz10@hotmail.com','curtis medwid','p.o. box 242','Lantzville','BC','CANADA','v0r2h0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 16:42:08',0,NULL,3,1,3,1,'RA183627337CN\r ','curty123\rOTSO004*4\r盒装的'),(10168,839922286012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','audriukasz1975','audrius.zaibus@gmail.com','Audrius Zaibus','Nygårdavägen 33','Höganäs','','SWEDEN','263 91','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 16:43:17',0,NULL,3,1,3,1,'RA183627323CN ','audriukasz1975\r盒装的\rOTSO004*2'),(10169,0,320748377794,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530 #',1,'ANCN001',0.01,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:51:39',0,NULL,3,1,1,1,'\\  ','hawkeyesun\rLK020748441CN'),(10170,0,320748375567,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530 #',1,'ANCN001',0.4,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:51:41',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10171,0,320747890012,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',1.23,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:51:47',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10172,0,220838632581,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.5,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:51:52',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10173,0,230663768678,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530 #',1,'ANCN001',0.4,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:51:58',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10174,0,220839182354,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',0.4,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:52:05',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10175,0,230663382976,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',4.73,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:52:12',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10176,0,230663770619,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530 #',1,'ANCN001',0.4,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:52:18',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10177,0,220839193981,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530 #',1,'ANCN001',0.4,'eastar4','hawkeyesun','hawkeyesun@yahoo.com','Gang Sun','4907 Glickman Ave','Temple City','CA','UNITED STATES','91780-4021','(323) 271-7929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 16:52:25',0,NULL,5,0,18,0,NULL,'hawkeyesun'),(10178,562198596003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','pathumwa','pathumlk@hotmail.com','PATHUM WITHANARACHCHI','No. 253/3,<br>KANDALIYADDA PALUWA,','GANEMULLA','','SRI LANKA','11020','+94715606078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 17:13:35',0,NULL,3,1,3,1,'RA183627062CN\r ','pathumwa\rHSNO004\r英标'),(10179,617360141013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','allvv','send2andy@netvigator.com','Andy Lam','20/F Wheelock House<br>20 Pedder Street, Central, HK','default','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 17:31:11',0,NULL,3,1,2,1,'\\ ','allvv'),(10180,839951369012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','bram1874','bertbrammer@talk21.com','Robert Brammer','18,Elmsdale Court<br>Birmingham Road','Walsall','West Midlands','UNITED KINGDOM','WS1 2QN','01922612120','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 17:38:59',0,NULL,3,1,3,1,'RA183627164CN ','bram1874\rOTGR001'),(10181,839963260012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','kendangelico','kendangelico@yahoo.com','kenneth dangelico','6 Joan Ree Ter','bayonne','NJ','UNITED STATES','07002-2815','(201) 725-4237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 17:58:32',0,NULL,3,1,1,1,'\\ ','kendangelico'),(10182,839962775012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','amylynnmiles','amymiles@charter.net','Amy Miles','1553 Lewis Rd','Edwardsville','IL','UNITED STATES','62025-4105','(618) 307-5081','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 17:59:50',0,NULL,3,1,1,1,'\\  ','amylynnmiles'),(10183,756557676011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',2,'RELO003',15,'eastar4uk','arildmj','amj@jensendata.com','Arild Magne Jensen','Lyngvn 2','N-2260 Kirkenaer','Hedmark','NORWAY','2260','+4762848548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 18:02:53',0,NULL,3,1,2,1,'\\ ','arildmj\r红边优联'),(10184,617331666013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','buyingstuffonline123','buyingstuffjh@gmail.com','james hering','711 Arnold St','altamonte springs','FL','UNITED STATES','32701-7624','(407) 951-8055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 18:15:00',0,NULL,3,1,1,1,'\\  ','buyingstuffonline123'),(10185,617376298013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','tbonewailer','markkpotter@gmail.com','Mark Potter','8401 Banbury St','Cincinnati','OH','UNITED STATES','45216','(616) 914-5722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 18:17:43',0,NULL,3,1,1,1,'\\  ','tbonewailer'),(10186,567675007004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','pacifictimo','hij@timothy-kristien.be','Timothy Van Goethem','Geestenspoor 38','Ekeren','','BELGIUM','2180','0497630085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:04:27',0,NULL,3,1,3,1,'RA183627116CN\r ','pacifictimo\rOTRA001'),(10187,617381137013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','petete007','petrajulen@gmail.com','Julen Petralanda Bustinza','C/ Maria Nieves Gallastegi 12C','Usansolo','País Vasco','SPAIN','48960','609454676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:22:42',0,NULL,3,1,2,1,'\\ ','petete007'),(10188,757013338011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',23.99,'eastar4','rd1151','randy.danielson@comcast.net','Randall Danielson','265 72nd Ct','Mahtomedi','MN','UNITED STATES','55115-2224','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 18:36:44',0,NULL,3,1,1,1,'\\  ','rd1151'),(10189,717101047001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','jameswillsellthat','sinisterpower@gmail.com','James Joy','3691 Prescott Dr','Howell','MI','UNITED STATES','48843-6980','(231) 881-6156','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 18:53:51',0,NULL,3,1,1,1,'\\  ','jameswillsellthat'),(10190,838248641012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',3,'OTIN005',237,'eastar4','babri63','jimmy@wavetelecom.ca','JAMSHID GHOMI','18 CAMELLIA','IRVINE','CA','UNITED STATES','92620','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 18:55:40',0,NULL,3,1,1,1,'、 ','babri63'),(10191,840024825012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','webbart02','martin_charest@msn.com','Martin Charest','189 Bl.Hymus<br>suite 602','Pointe-Claire','QC','CANADA','H9R 1E9','(514) 426-9467 ext.: 107','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 19:42:07',0,NULL,3,1,3,1,'RA183627235CN\r ','webbart02\rHSPL009'),(10192,757091761011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','sakoppie','samueltaylor@gmx.com','Sam Taylor','P. O. Box 7392','Ewing','NJ','UNITED STATES','08628','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 20:55:43',0,NULL,3,1,1,1,'\\  ','sakoppie\r新地址\r36 West End Ave, W Trenton, NJ 08618'),(10193,562281151003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.9,'cnfaner','nikolaj_h99','shop@harboesgaard.dk','nikolaj harboesgaard','titaniavej 16','kolding','','DENMARK','6000','+4551388448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:00:50',0,NULL,3,1,3,1,'RA183627147CN\r ','nikolaj_h99\rWLDE001'),(10194,617444933013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','find-it-all','tokitotan@hotmail.com','Jason Tan','Suite 37, Hollywood Medical Centre, 85 Monash Ave','NEDLANDS','Western Australia','AUSTRALIA','6009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:10:43',0,NULL,3,1,3,1,'RA183627252CN ','find-it-all\rMOSA005'),(10195,562272064003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','bjery','bratislavbijelic@gmail.com','Bratislav Bijelic','Vojvode Bojovica 30','Prnjavor','','BOSNIA AND HERZEGOVINA','78430','+38765902381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:16:03',0,NULL,3,1,3,1,'RA183627102CN\r ','bjery\rMOAP001'),(10196,562284984003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','kostastzag','kostastzagkarakis@gmail.com','KONSTANTINOS TZAGKARAKIS','GREEK EMBASSY<br>ELVOGI GEORGIEV 103','SOFIA','','BULGARIA','1504','00359877588225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:17:49',0,NULL,3,1,3,1,'RA183627014CN\r ','kostastzag\rHSNO004\r欧标'),(10197,757101010011,320441564486,'2.1 Acer Aspire 5550 5551 5552 Bluetooth Module +cable',1,'BTAC2106',12.4,'eastar4','laptopsvc','admin@laptopsvc.com','Phillip Lover / LSC Services','6109 Rockfish Rd','Hope Mills','NC','UNITED STATES','28348-1734','(910) 922-4433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 21:21:49',0,NULL,3,1,1,1,'\\  ','laptopsvc\racer 4pin1.25 15cm '),(10198,617455807013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','zacharypettitt','zach_believes@yahoo.com','ZACHARY PETTITT','2406 CHIPPEWA AVE','PLACENTIA','CA','UNITED STATES','92870-1527','(714) 614-3979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 21:49:41',0,NULL,3,1,1,1,'\\  ','zacharypettitt'),(10199,757115032011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','glaydersenstopa','glaydersen@gmail.com','Glaydersen Gontijo','Rua Maria José Fernandes, 80 - apto 102<br>Conjunto Teixeira Dias','Belo Horizonte','Minas Gerais','BRAZIL','30644240','+553188689434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:57:36',0,NULL,3,1,3,1,'RA183627354CN ','glaydersenstopa\rOTSO004'),(10200,759180381002,120765817881,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','cressncrumpets','cressida.bruce@yahoo.com','Cressida Bruce','11 Strawberry Bank','Dundee','Angus','UNITED KINGDOM','DD2 1BJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 22:37:46',0,NULL,3,1,3,1,'RA183627133CN\r ','cressncrumpets\rHSBS002'),(10201,840129444012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','matisamd','maserter@hotmail.com','matthew serter','21 flat D<br>shrubbery road','streatham','london','UNITED KINGDOM','sw16 2as','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 00:03:08',0,NULL,3,1,3,1,'RA183627218CN\r ','matisamd\rHSPL009\r英标'),(10202,840135732012,220807295612,'3 pair 3D Active Shutter Glasses for Samsung SSG-2200AR',1,'GLOT004*3',143.99,'eastar4','andystire','craig@andystire.ca','Craig Mackenzie','146 Robie Street','Truro','NS','CANADA','b2n1l1','(902) 897-1669 ext.: 223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 00:26:05',0,NULL,3,1,3,1,'RA183627385CN ','andystire\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(10203,757160495011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',49.99,'eastar4','marcioercoelho','merk5678@hotmail.com','Marcio Emanoel Rodrigues Coelho','Av. Prefeito Manoel Vila, 585<br>Centro','Barra de Sao Francisco','Espirito Santo','BRAZIL','29800-000','27 3756 0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 00:40:25',0,NULL,3,1,3,1,'RA183627399CN\r ','marcioercoelho\rGLOT001\r兼容型3D眼镜 通用型'),(10204,757168214011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','tradingeeyore','chris@tlgusa.com','Chris Phelps','6916 Prestonshire Ln','Dallas','TX','UNITED STATES','75225-1740','(214) 368-6445','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 01:09:59',0,NULL,3,1,1,1,'\\  ','tradingeeyore'),(10205,617508428013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',97.99,'eastar4','450407010','kjansons@nine.com.au','Karl Jansons','Channel 9 Studios<br>654 Sir Samuel Griffith Drive, Mt Coot-tha','Brisbane','Queensland','AUSTRALIA','4066','0732149860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 01:47:41',0,NULL,3,1,3,1,'RA184552649CN ','450407010\rGLOT001*2\r兼容型3D眼镜 通用型'),(10206,757193652011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.99,'eastar4','prasarn_21','prasarn_21@yahoo.com','Prasarn Lerkumnueychok','1032 Moobarn Amornchai3 Rajchachonnanee Rd<br>Salathammasob Taweewattana','Bangkok','Bangkok','THAILAND','10170','66891727261','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 02:48:08',0,NULL,3,1,2,1,'、 ','prasarn_21'),(10207,840177049012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.99,'eastar4','omniglh251','omniglh25@hotmail.com','James Wilcox','1685 Pioneer Ln','White Bear Township','MN','UNITED STATES','55110-5874','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-30 02:48:54',0,NULL,3,1,1,1,'\\  ','omniglh251  E邮宝 没走了 '),(10208,757198880011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','quicksilver2002','sviken2002@hotmail.com','SAIID VIKEN','47 BROLGA ST','PORT DOUGLAS','Queensland','AUSTRALIA','4877','(047) 808-5956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 03:08:21',0,NULL,3,1,3,1,'RA183627368CN ','quicksilver2002\rHBPH002'),(10209,839878120012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','ethahaa','eteng524@gmail.com','Esther Teng','534 40th Ave','San Francisco','CA','UNITED STATES','94121-2523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 03:43:16',0,NULL,3,1,1,1,'、 ','ethahaa'),(10210,562365207003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','randomvictim','xalies@hotmail.com','Sonny Gilbert','15 Galloway Street','Kurri Kurri','New South Wales','AUSTRALIA','2327','0401583606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 04:47:05',0,NULL,3,1,3,1,'RA183627425CN ','randomvictim\rOTCR001'),(10211,8881314679744614,111,'880屏幕',100,'SCLO001',0,'eastar4',' Jiangang Lu ',' lujiangang@gmail.com',' Jiangang Lu ','104 Maddry Ct, ','Chapel Hill,','NC,','UNITED STATES','27516 ','608-692-8147',NULL,NULL,NULL,'2011-08-30 04:49:04',0,NULL,3,1,6,1,'EE645685355CN ',NULL),(10212,617545638013,230622774836,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','anedeshu','anders@inmark.se','Anders Lindkvist','Ingenjörsvägen 26','Stockholm','','SWEDEN','11759','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 05:34:22',0,NULL,3,1,3,1,'RA184587886CN\r ','anedeshu\rMOLO005'),(10213,617545965013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',13.76,'eastar4','narinderkumar','kumar_narinder@hotmail.com','Narinder Kumar','3076 N Filbert Ave','Fresno','CA','UNITED STATES','93727','(559) 451-7546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 05:36:20',0,NULL,3,1,1,1,' 、','narinderkumar'),(10214,617545777013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','robertk1427','robert.knowles@sawater.com.au','Robert Knowles','2 Frederick Street','Gilberton','South Australia','AUSTRALIA','5081','0874241350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 05:43:13',0,NULL,3,1,2,1,'、 ','robertk1427'),(10215,699740870008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','canam406','bellis1@sympatico.ca','Brian Ellis','393 Mapleveiw Dr W','Barrie','ON','CANADA','l4n 9g4','(705) 719-6513','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 05:50:30',0,NULL,3,1,3,1,'RA183627439CN ','canam406\rSCLO001'),(10216,716492378001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',16.98,'buysia','npnett1958','npnett@yahoo.com','Noppachai Sripraphai','36 Soi Intramara 7 Sutthisarn rd.<br>Samsennai Phyathai','Bangkok','Bangkok','THAILAND','10400','6612781960','NoPaymentFailure','CheckoutComplete','NotSelected','2011-08-30 06:57:30',0,NULL,3,1,3,1,'RA183627442CN ','npnett1958\rHSJB001+OTAM001\r需要再发一个5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port\rRA184552771CN\r'),(10217,617558829013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','ekerose','albert.mesalles@gmail.com','Albert Mesalles Montull','Industries 20-22 1,2','El Prat de Llobregat','Barcelona','SPAIN','08820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 07:40:27',0,NULL,3,1,2,1,'\\ ','ekerose\r'),(10218,559490782003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','milan.rancho','milhan2game@yahoo.com','A.M.Milhan','No.24.St.Lazarus Road<br>Periyamulla','Negombo','Western Province','SRI LANKA','11500','0094312220519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 08:18:05',0,NULL,3,1,3,1,'RA183627456CN ','milan.rancho\rHSNO004'),(10219,840248482012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','leadfooter69','jfowl3r@o2.co.uk','Jason Fowler','34 Riversway','Poulton-Le-Fylde','Lancashire','UNITED KINGDOM','FY6 7JT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 08:28:59',0,NULL,3,1,3,1,'RA183627500CN ','leadfooter69\rMOLO009\r英标'),(10220,840243247012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.9,'eastar4','kphok1','kphok1@dreamwiz.com','JEONG LEE','5351 Humboldt Dr.','Buena park','CA','UNITED STATES','90621','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'kphok1'),(10221,757260520011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','rob-blay','robinblay@gmail.com','Ro Blay','6 Pickwick pde','Auckland','','NEW ZEALAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 08:37:31',0,NULL,3,1,2,1,'\\ ','rob-blay'),(10222,757263127011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','cefey2011','kurgantm@mail.ru','ANDREY SHAMONIN','Kuibysheva st. 125-18','Kurgan','','RUSSIAN FEDERATION','640018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 08:49:58',0,NULL,3,1,3,1,'RA183627411CN ','cefey2011\rRCLO006'),(10223,617574468013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Joseph M. Buttitta','1144 SW Normandy Ter','Normandy Park','WA','UNITED STATES','98166-3632','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 08:57:17',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(10224,699727862008,180699062062,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',49.99,'au-buy','niceandquiet','nicenquiet@iprimus.com.au','Naomi Land','5 Heathwren Close','Frankston South','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 09:20:25',0,NULL,3,1,3,1,'RA183627544CN\r ','niceandquiet\rGLOT001\r兼容型3D眼镜 通用型'),(10225,617514847013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',26.1,'eastar4','iamchi3f','i_am_chief@live.com.au','Tim Clugston','10 Davis Ave','Nhill','Victoria','AUSTRALIA','3418','0419896557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 09:49:33',0,NULL,3,1,2,1,'\\ ','iamchi3f\rCAB-SS-2626'),(10226,757278426011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','haynxtsy79','ryan.hawaiian@gmail.com','Ryan Fernandez','1444 Glazemeadow St','Monmouth','OR','UNITED STATES','97361','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 09:50:53',0,NULL,3,1,1,1,'\\ ','haynxtsy79'),(10227,617587522013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','javierabcde','pedroabcd@mixmail.com','José Javier Losada Baños','C/ Sant Antoni M. Claret, 272, ent 2, esc Izq','Barcelona','Barcelona','SPAIN','08041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 10:12:22',0,NULL,3,1,3,1,'RA183627703CN\r ','javierabcde\rMOSA004'),(10228,840279853012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','upsmon991625','upsmon@gmail.com','Dmitrij Medvedev','Kompozitorov str., d.31, k.2, kv.187','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','194356','+7 (921) 932-24-38','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 10:30:51',0,NULL,3,1,3,1,'RA183627460CN\r ','upsmon991625\rOTSO002'),(10229,617592523013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','leobassoi','leobassoi@hotmail.com','Leonardo Bassoi','1/19-23 Herbert St<br>St Leonards','Sydney','New South Wales','AUSTRALIA','2065','610406971278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 10:42:58',0,NULL,3,1,2,1,'\\ ','leobassoi\r红边优联'),(10230,567871240004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.98,'cnfaner','gursharnsagoo','gursharn_sagoo@hotmail.com','gursharn sagoo','1/34 lightwood road','springvale','Victoria','AUSTRALIA','3171','0433755570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 10:44:23',0,NULL,3,1,3,1,'RA183627677CN\r ','gursharnsagoo\r澳标\rHSNO022'),(10231,8881314701467380,111,'SAMSUNG 2100AB',1,'GLSG001',0,'eastar4','minorca69','filipesilva.pt@gmail.com','FILIPE SILVA','BES SA - AG OLIVEIRA DO BAIRRO<br>AV DR ABILIO PEREIRA PINTO 27/26','OLIVEIRA DO BAIRRO','OLIVEIRA DO BAIRRO','PORTUGAL','3770-201','',NULL,NULL,NULL,'2011-08-30 10:51:07',0,NULL,3,1,3,1,'RA183627615CN\r ','GLSG001\r补发的  不带盒子 '),(10232,840287596012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.95,'eastar4uk','musicmaster2004','trevor.j@talktalk.net','Trevor  Jones','25 Gretdale Avenue, St,Annes, On Sea','St.,Annes On Sea','Lancashire','UNITED KINGDOM','FY82EE','01253711530','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 10:54:27',0,NULL,3,1,3,1,'RA183627487CN\r ','musicmaster2004\rBALO007'),(10233,617598408013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','correywa','wacorrey@gmail.com','Wallace Correy','145 Botany St','Randwick','New South Wales','AUSTRALIA','2031','61425815157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 11:09:39',0,NULL,3,1,2,1,'\\ ','correywa'),(10234,617620930013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',8.7,'eastar4','michaell9979','mrlkmw@optusnet.com.au','Michael Launder','6 Bambra Court','Seaford','Victoria','AUSTRALIA','3198','0416155698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 12:53:59',0,NULL,3,1,2,1,'\\ ','michaell9979\rCAB-SS-2626'),(10235,757338008011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','47401a','zarlington@yahoo.com','Zack Hudson','610 S High St','Bloomington','IN','UNITED STATES','47401-5330','(812) 361-5310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 13:15:02',0,NULL,3,1,1,1,'\\ ','47401a\r二代卡 旧'),(10236,757343054011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','miricaiulian','mirica.iulian.conturi@gmail.com','Iulian Mirica','21 Rue motte des bergers','ophain','','BELGIUM','1421','0474010939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 13:30:53',0,NULL,3,1,2,1,'\\ ','miricaiulian'),(10237,617635373013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.99,'eastar4','xasanchik2011','xasyaip@gmail.com','Igor Pakhmutov','Sobornaya pl. d. 3','Belgorod','','RUSSIAN FEDERATION','308009','89205660065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 13:55:10',0,NULL,3,1,3,1,'RA184552799CN\r ','xasanchik2011\rWLIN014\r通用'),(10238,757357474011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','fwanko78','frankwright78@hotmail.com','Frank Wright','83 Sharphill Rd','Saltcoats','North Ayrshire','UNITED KINGDOM','KA215QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 14:15:09',0,NULL,3,1,3,1,'RA184552856CN\r ','fwanko78\rGLSG001'),(10239,840361744012,220459525292,'Acer Aspire 5550 5551 5552 Bluetooth Module 2.0 +cable',2,'BTAC2006',25,'eastar4','you-tech','ashleystuartpowell@facebook.com','Ashley Powell','4,<br>Sheens Meadow','Newnham','Gloucestershire','UNITED KINGDOM','GL14 1BP','7853992515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 14:33:44',0,NULL,3,1,2,1,' \\','you-tech\racer 4pin1.25 15cm '),(10240,562465091003,130554587649,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',18.9,'cnfaner','scobarbr','pablo.marani@gmail.com','Fabiano Trambaioli','Rua Vigario Albernaz 785  - apt 12<br>- Vila Gumercindo','Sao Paulo','SP','BRAZIL','04134021','551182685280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 14:42:30',0,NULL,3,1,3,1,'RA183627558CN\r ','scobarbr\rWLIN015\r无线蓝牙二合一'),(10241,840372167012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',113.99,'eastar4uk','pauljames87','pauljames87@hotmail.com','Paul Foreman','20 keswick avenue','hornchurch','Essex','UNITED KINGDOM','rm111xr','01708444102','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 15:00:49',0,NULL,5,0,18,0,NULL,'pauljames87\r客户要撤单\r已经撤单'),(10242,839773072012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',2,'OTHP003',23,'eastar4uk','ruisaraiva1974','ruijorgesaraiva@hotmail.com','Rui Saraiva','Rua da Alemanha, 292 - 3º Dtº<br>Qtª de S. Gonçalo','Carcavelos','Portugal','PORTUGAL','2775-397','+351962003758','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 15:09:47',0,NULL,3,1,3,1,'RA183627663CN\r ','ruisaraiva1974\rOTHP003'),(10243,840378479012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',29.98,'eastar4','fm.xs','fm.xs@web.de','Köllen Druck + Verlag','Ernst-Robert-Curtius-Straße 14<br>z.Hd. Martin Seitz','Bonn-Buschdorf','','GERMANY','53117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 15:18:45',0,NULL,3,1,2,1,'\\ ','fm.xs\rIBM版'),(10244,567937555004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',127,'cnfaner','meibi1','meibi@t-online.de','Wolfgang Meibert','Toosbüystraße 9','Flensburg','','GERMANY','24939','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 15:53:00',0,NULL,3,1,3,1,'RA184552842CN\r ','meibi1\rRCMA001'),(10245,562482313003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','pwjohnson2001','pw.johnson@cox.net','Paul JOhnson','3511 Nashe Ct','Virginia Beach','VA','UNITED STATES','23462-7023','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-30 15:54:08',0,NULL,3,1,1,1,'\\ ','pwjohnson2001'),(10246,840415179012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',24.99,'eastar4','malinka7535','alicja7535@wp.pl','Alicja Krol','17 Gloucester Road','Doncaster','South Yorkshire','UNITED KINGDOM','DN2 4JQ','004475982693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 16:43:10',0,NULL,3,1,2,1,'\\ ','malinka7535\r蕾丝花边伞 \r黑色的'),(10247,617684735013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','vulgarcustoms','bienkowski131@gmail.com','Bret Bienkowski','113 S Newport Ave<br>Apt 3','Tampa','FL','UNITED STATES','33606-1910','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 16:54:55',0,NULL,3,1,1,1,'\\ ','vulgarcustoms'),(10248,567955440004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','jazz147','stevejazz1@hotmail.com','Steve   Strickland','10514 180th St SE','Snohomish','WA','UNITED STATES','98296-8121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-30 17:01:59',0,NULL,3,1,1,1,'\\ ','jazz147'),(10249,567963927004,140584762830,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',33.9,'cnfaner','skulz41','dmitry106@yahoo.com','Leonid Dvoskin','270 54th St','Brooklyn','NY','UNITED STATES','11220-2611','(347) 228-1065','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-30 17:30:00',0,NULL,3,1,1,1,'\\ ','skulz41\r 通用'),(10250,757439204011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','aladin_91','aladin91@gmail.com','alain le douaron','80 quai voltaire<br>EMC 2 - River Ouest','Bezons','Ile-de-France','FRANCE','95876','0673761982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 17:43:14',0,NULL,3,1,3,1,'RA184552768CN\r ','aladin_91\rUDAP001'),(10251,840451252012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',21.99,'eastar4uk','petrict','t.petric@siol.net','Tomaz Petric','Askerceva 34','Smarje Sap','SI','SLOVENIA','1293','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 17:57:29',0,NULL,3,1,3,1,'RA184552785CN\r ','petrict\rWWSI002+ANCN001'),(10252,567980837004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','daras0411','daras385@gmail.com','Darko Smolčić','Cvetkovačka 23','Jastrebarsko','','CROATIA','10450','+385915054303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 18:23:07',0,NULL,3,1,3,1,'RA183627473CN\r ','daras0411\rBALO007'),(10253,617722038013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','larsdans','lhmail@get2net.dk','Lars Hollmann','Hjulets Kvarter 150','Odense SO','','DENMARK','5220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 18:41:38',0,NULL,3,1,2,1,'\\ ','larsdans'),(10254,617723649013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','rgbuck','ronnieb46@embarqmail.com','Ronnie G Buck','165 Skytop Dr','Henderson','NV','UNITED STATES','89015-5937','(702) 566-1946','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 18:44:37',0,NULL,3,1,1,1,'\\ ','rgbuck'),(10255,840476436012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','joanlesley1977','lesleyjoan@hotmail.com','lesley mowat','54 cummings park drive','aberdeen','Aberdeen City','UNITED KINGDOM','ab16 7bb','07961785847','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 18:48:01',0,NULL,3,1,3,1,'RA183627694CN\r ','joanlesley1977\rHSNO005+CCNO001'),(10256,617731048013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','kmihaila','mihailk@list.ru','Mihail Krestyancev','Osvobojdeniya, 9','Rostov-on-Don','','RUSSIAN FEDERATION','344079','+79185522419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 19:07:54',0,NULL,3,1,2,1,'\\ ','kmihaila\r欧标'),(10257,757515079011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','frut02','frut02@gmail.com','Nicholas Rutter','10 Poplar Walk','Stradishall','Suffolk','UNITED KINGDOM','cb8 9yb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 20:07:01',0,NULL,3,1,3,1,'RA183627629CN\r ','frut02\rGLSG001'),(10258,840537043012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','2010karen123456','xx.kirsty.mxx@hotmail.co.uk','Kirsty Mander','30 Bridley Moor Road','Redditch','England','UNITED KINGDOM','B97 6HU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 20:34:09',0,NULL,3,1,2,1,'\\ ','2010karen123456'),(10259,757566716011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','daw-sol','d.a.wareing@btinternet.com','David Wareing','Verdict  Aerospace Components<br>3 Chiltern Hill','Chalfont St. Peter','Buckinghamshire','UNITED KINGDOM','SL9 9YZ','01753890922','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 22:07:30',0,NULL,3,1,3,1,'RA183627495CN\r ','daw-sol\rHSPL015\r英标'),(10260,757574734011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',29.99,'eastar4','brothermanjr','imaxjr@verizon.net','Maxell Brown Jr','PO Box 10603','Virginia Beach','VA','UNITED STATES','23450-0603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 22:33:27',0,NULL,3,1,1,1,' \\','brothermanjr'),(10261,757575776011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','raponchito','jc.naranjo@terra.es','Jair Naranjo','C/ Leon y Castillo, 128 - Local Comercial','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 22:39:08',0,NULL,3,1,2,1,'\\ ','raponchito\rHP 8pin 1.25 18cm '),(10262,840600808012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',2,'OTHP001',57.98,'eastar4','2007_sara','ciloguerra@ig.com.br','Ercilio S Guerra','Rua Joao Batista Ortiz Monteiro, 503','Cacapava','Sao Paulo','BRAZIL','12287-310','55 12 36554604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 23:16:13',0,NULL,3,1,3,1,'RA183627632CN\r ','2007_sara\rOTHP001'),(10263,562616555003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','jonnywarren1985','paranoiatothemax@yahoo.com.au','Jonny Warren','108 Alawoona Rd<br>Munno Para','Adelaide','South Australia','AUSTRALIA','5115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 23:48:02',0,NULL,3,1,3,1,'RA183627527CN\r ','jonnywarren1985\rBAZA001'),(10264,840613187012,220815928951,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',23.99,'eastar4uk','naghas','naghas@netvisao.pt','Tiago Manuel Ourives Gomes','Rua dos Loureiros , Lote 2, 2 direito','Tortosendo','Tortosendo','PORTUGAL','6200782','969616308','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 00:00:18',0,NULL,3,1,3,1,'RA184553233CN ','naghas\rMOMI003\r新地址\rFilipe Miguel Cola?o Pinto\rRua Dr. Farinhote 858, \rMoreira Maia\r4470-602\rPORTUGAL\r\r'),(10265,617823198013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','jrlbuyer','johnrleigh@optusnet.com.au','John Leigh','12 Duff Street','Sandringham','Victoria','AUSTRALIA','3191','0395331910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 00:28:18',0,NULL,3,1,3,1,'RA183627685CN\r ','jrlbuyer\rCASS001+CASS003\r\r两条CAB-SS-2626\r再发三条CAB-6060'),(10266,757605337011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',26.1,'eastar4','jrlbuyer','johnrleigh@optusnet.com.au','John Leigh','12 Duff Street','Sandringham','Victoria','AUSTRALIA','3191','0395331910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 00:31:51',0,NULL,3,1,17,0,NULL,'jrlbuyer'),(10267,840627777012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','ck_42','ck42@bellsouth.net','Chris Kelly','426 Deepstream Xing','Canton','GA','UNITED STATES','30115-4799','(404) 963-8649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 00:50:22',0,NULL,3,1,1,1,'\\ ','ck_42'),(10268,757616313011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',62.99,'eastar4','philipsak81','philipsak@rediffmail.com','Philips Abraham','1/2 Grampian St','Preston','Victoria','AUSTRALIA','3072','0430727428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 01:14:07',0,NULL,3,1,3,1,'RA183627535CN\r ','philipsak81\rOTSO004'),(10269,757621808011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','sandygoesshopping','sandykeith49@yahoo.com','Sandy Keith','127 Brook Stone','Cibolo','TX','UNITED STATES','78108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 01:31:19',0,NULL,3,1,1,1,'\\ ','sandygoesshopping'),(10270,840652557012,220816365997,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',28.99,'eastar4','em.m','em.m@shaw.ca','hennie  wagner','750 Wharncliffe Rd,','Duncan','BC','CANADA','V9L 2K1','(250) 710-4648','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 02:17:19',0,NULL,3,1,2,1,'\\ ','em.m\r16骨长柄自动伞\r黑色的'),(10271,840657567012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',2,'WLAT007+ANTY001',33.9,'eastar4','markd_vuw','mark@ecs.vuw.ac.nz','Mark Davies','Room 358, Cotton Building, Victoria University<br>Kelburn Parade','Wellington','Wellington','NEW ZEALAND','6012','+6444635055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 02:36:08',0,NULL,3,1,3,1,'RA183627646CN\r ','markd_vuw\rWLAT007+ANTY001'),(10272,757636944011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','cybermarkkus','fortier.marc@hotmail.ca','Marc Fortier','1337, Ave James-LeMoine','Quebec City','QC','CANADA','G1S 1A5','(418) 523-6388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 02:46:05',0,NULL,3,1,2,1,'\\ ','cybermarkkus'),(10273,617862289013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',64.99,'eastar4','daonenonly','mardeep22@aol.com','Mario Fryczynski','314 GARFIELD ST','LINDEN','NJ','UNITED STATES','07036-1447','(201) 522-7920','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 03:39:59',0,NULL,3,1,1,1,'\\ ','daonenonly'),(10274,617864362013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','melamed2006','melamed1@hotmail.com','David  Melamed','32 Surrey Grove<br>Point Cook','Melbourne','Victoria','AUSTRALIA','3030','04120868857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 03:47:33',0,NULL,3,1,3,1,'RA184552989CN\r ','melamed2006\rMOSA005'),(10275,617864020013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','akira51','french6@internode.on.net','Jason French','7 Beechwood Road','Maleny','Queensland','AUSTRALIA','4552','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 03:49:48',0,NULL,3,1,3,1,'RA183627561CN\r ','akira51\rHBPH005'),(10276,840319730012,220714515908,'New Logitech MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO002',38.9,'eastar4','avi1093','aviy@aipm.co.il','avi jacob','hahida 15<br>4329 ltd','hadera','','ISRAEL','38100','46349381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 04:31:02',0,NULL,3,1,3,1,'RA184552975CN\r ','avi1093\rMOLO002'),(10345,758089409011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.7,'eastar4','ericthebolt','gunstone@deakin.edu.au','eric gunstone','5 Archer Place','Mill Park','Victoria','AUSTRALIA','3082','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 02:23:04',0,NULL,3,1,2,1,'\\ ','ericthebolt'),(10277,840690227012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','cthulhuas','cthulhuas@gmail.com','Alain Savignac','340 Champigny','Terrebonne','QC','CANADA','j6y1e7','(514) 500-0673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 04:59:28',0,NULL,3,1,2,1,'\\ ','cthulhuas'),(10278,567863041004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'cnfaner','dr_beny','dr_benny@bezeqint.net','benny riahi','hapardes 13','ramat hasharon','','ISRAEL','47405','050-2535887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:21:18',0,NULL,3,1,3,1,'RA183627650CN\r ','dr_beny\rOTGR005'),(10279,757673593011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',10.99,'eastar4uk','arunavo123','arunavo.chatterji@gmail.com','Arunavo Chatterji','34 Portrona Drive','stornoway','Western Isles','UNITED KINGDOM','HS1 2HE','01851706951','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 05:32:51',0,NULL,3,1,3,1,'RA183627513CN\r ','arunavo123\rOMHJ001'),(10280,840700290012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',35,'eastar4','msym_msym','maksym.0xff@gmail.com','Maksim Parfenov','10/91, Ul. Sadovaya','Kurgan','','RUSSIAN FEDERATION','640004','7 9128318172 ','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:56:42',0,NULL,3,1,3,1,'RA184552961CN\r ','msym_msym\rOTIN002'),(10281,617882397013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','daninauta','juandanielmarin@gmail.com','juan daniel marin palacios','juan perez zuñiga, 20<br>ARTURO SORIA SUITES HOTEL','madrid','Madrid','SPAIN','28027','696610263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 06:00:55',0,NULL,3,1,3,1,'RA184552992CN\r ','daninauta\rMOSA005'),(10282,562674964003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',21.95,'cnfaner','ekvilla','ekvilla85@hotmail.com','Eric Villaruz','31311 10th Ave S','Federal Way','WA','UNITED STATES','98003','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-31 06:24:06',0,NULL,3,1,1,1,'\\ ','ekvilla'),(10283,840713325012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','kiwiray11','raytrish@slingshot.co.nz','Raymond Winter','51 Herbert Street','Invercargill','Southland','NEW ZEALAND','9810','0064 32146329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 07:06:18',0,NULL,3,1,3,1,'RA184552913CN\r ','kiwiray11\rGLSG001*3'),(10284,8881314776650497,111,'New original Nokia LD-3W Bluetooth Wireless GPS Module',2,'OTCR001',0,'eastar4',' arvindm0   ','arvind0@gmail.com','Arvind Mukundan','5555 Darlington road','Pittsburgh','PA ','UNITED STATES','15217','',NULL,NULL,NULL,'2011-08-31 07:44:10',0,NULL,3,0,3,1,'RA183627575CN\r ','补发的  只补两块电池 \rOTCR001'),(10285,840725016012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','kmurphey77','averagejoe@verizon.net','Kevin W Murphey','5537 Kendrick LN','Burke','VA','UNITED STATES','22015-1941','(703) 425-8975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 07:47:44',0,NULL,3,1,1,1,'\\ ','kmurphey77'),(10286,617901780013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','fjdiazal','fjdiazalonso@telefonica.net','Francisco Jose Diaz Alonso','C/ Valcarlos 13, 5 B<br>Las Tablas','Madrid','Madrid','SPAIN','28050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 08:06:42',0,NULL,3,1,3,1,'RA184552944CN\r ','fjdiazal\rMOSA006'),(10287,840733392012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',122.99,'eastar4','brod_1','brodjs@hotmail.com','Brod Stanowski','Apra<br>Level 26, 400 George Street','Sydney','New South Wales','AUSTRALIA','2000','0292103036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 08:21:13',0,NULL,3,1,3,1,'RA184552935CN\r ','brod_1\r盒装的\rOTSO004*2'),(10288,617903834013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','christhommo1','cthomas55@optusnet.com.au','Chris Thomas','P O Box 947','Wahroonga','New South Wales','AUSTRALIA','2076','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'christhommo1'),(10289,617909881013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','auitdebulten','tigertje@gmail.com','Alexander uit de Bulten','Kolibristraat 2 huis','Amsterdam','','NETHERLANDS','1022 BJ','+31629123890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 08:56:03',0,NULL,3,1,2,1,'\\ ','auitdebulten'),(10290,840748014012,220815930312,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',16.95,'eastar4uk','ionauan','prokopis.liontos@vodafone.com','Prokopios Liontos','16, Pericleous str.','Melissia-Athens','','GREECE','15127','+306944444767','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 09:18:14',0,NULL,3,1,2,1,'\\ ','ionauan\r新的 欧标'),(10291,757722454011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','timothyc808','timothycrowley@talktalk.net','timothy crowley','ground floor flat, Glen View<br>bickland water road','falmouth','Cornwall','UNITED KINGDOM','tr115bn','01326212532','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 09:20:39',0,NULL,3,1,3,1,'RA184553105CN\r ','timothyc808\rMOAP001'),(10292,617913166013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Thomas R. Shears','633 N Linden St','Marshall','MI','UNITED STATES','49068-1054','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 09:21:57',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(10293,8881314784498536,111,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',0,'eastar4','2010sameeraranga','godayamu@gmail.com','Sameera Ranga','252,Yamuna Katuwana Road,<br>Homagama','Colombo','Westen Province','SRI LANKA','10200','9411718355926',NULL,NULL,NULL,'2011-08-31 09:54:58',0,NULL,3,1,2,1,'\\ ','补发的 '),(10294,8881314785010937,111,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',0,'cnfaner','mhashimoto','mike@mhashimotophoto.com','Mike Hashimoto','1107 Fair Oaks Ave<br># 859','South Pasadena','CA','UNITED STATES','91030','(323) 878-2264',NULL,NULL,NULL,'2011-08-31 10:03:30',0,NULL,3,1,3,1,'RA184553074CN\r ','补发的  只补发耳机  挑个成色好点的 '),(10295,757737106011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','kwame2503','ekophi2503@yahoo.com','Emmanuel Osei Owusu','9203 New Hampshire Ave<br>Apt 202','Silver spring','MD','UNITED STATES','20903-3600','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 10:15:39',0,NULL,3,1,1,1,'\\ ','kwame2503'),(10296,757742614011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',110.99,'eastar4','ceosaints','saints_187@hotmail.com','Marc Ashman','14 smith rd Artarmon','Sydney','New South Wales','AUSTRALIA','2064','0294124143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 10:37:40',0,NULL,3,1,3,1,'RA184553180CN\r ','ceosaints\rOTSO005*2\r一个蓝色的一个粉红色的'),(10297,568177658004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','oskr101','obenito@gmail.com','Oscar Benito','C/ Industria nº16','Teia','Barcelona','SPAIN','08329','657827357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 11:29:09',0,NULL,3,1,3,1,'RA184553128CN\r ','oskr101\rOTRA001'),(10298,840764817012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','mrfunbro','packy06@bigpond.com','Michael Packman','33a Lumeah Drive','Mount Coolum','Queensland','AUSTRALIA','4573','0754461985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 11:51:55',0,NULL,3,1,3,1,'RA184585015CN ','mrfunbro\rGLSG001*3'),(10299,840785297012,220806785571,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',38.98,'eastar4','jctemprado','thempra@ieee.org','Jose Carlos Temprado Morales','C/ Olmo, 14 -4A','Albacete','Albacete','SPAIN','02005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 11:26:48',0,NULL,3,1,3,1,'RA184553202CN\r ','jctemprado\rOTRA001'),(10300,617731622013,230641231655,'New lady lotus leaves  sun/rain stick Umbrella blue',1,'UM00002',24.99,'eastar4','dalia11','laplante_d@hotmail.com','Diane Laplante','2245 Des Abeilles','Laval','QC','CANADA','H7K 2C6','(450) 667-7014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:11:49',0,NULL,3,1,2,1,'\\','dalia11\r荷叶边伞 '),(10301,757772096011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',3,'CASS003',17.97,'eastar4uk','grainneandstephenflynn','grainnepatriciacarroll@hotmail.co.uk','Stephen Flynn','Citco, Custom House Plaza, Block 5<br>IFSC','Dublin','Dublin','IRELAND','1','0862423751','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 12:20:47',0,NULL,3,1,2,1,'\\ ','grainneandstephenflynn\r'),(10302,617950402013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','140146','kenrobinson46@hotmail.com','ken   robinson','11 Sheridan way','TELFORD','Shropshire','UNITED KINGDOM','TF74HX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:24:39',0,NULL,3,1,2,1,'\\ ','140146'),(10303,757782306011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',2,'UM00012',39.98,'eastar4','romgrom','shtirlizrg@gmail.com','Tatyana Dobrokhotova','Nagornaya Street, house 15 / 4, apt.# 102','Moscow','Moscow','RUSSIAN FEDERATION','117186','(792) 626-7700 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:51:27',0,NULL,3,1,5,1,'CP227167676CN ','romgrom\rUM00012+UM00009+UM00014\r西瓜伞 \r再发两把黑底七色边彩虹伞 \r一把美女涂鸦伞 '),(10304,568194140004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','margaret1395','woolford@bigpond.net.au','Mike Woolford','Water Corporation<br>629 Newcastle St','Leederville','Western Australia','AUSTRALIA','6150','0893196109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:55:50',0,NULL,3,1,3,1,'RA184553057CN\r ','margaret1395\rOTRA001'),(10305,757783553011,320721819789,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',2,'UM00009',49.98,'eastar4','romgrom','shtirlizrg@gmail.com','Tatyana Dobrokhotova','Nagornaya Street, house 15 / 4, apt.# 102','Moscow','Moscow','RUSSIAN FEDERATION','117186','(792) 626-7700 ext.: 7','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 12:55:58',0,NULL,8,1,17,0,NULL,'romgrom'),(10306,617957733013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','qurnah','kalghazi@gmail.com','Khaled Alghazi','35 Corringa Way','Craigieburn','Victoria','AUSTRALIA','3064','0390090524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:56:20',0,NULL,3,1,2,1,'\\ ','qurnah\rCAB-6060'),(10307,840821788012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','romgrom','shtirlizrg@gmail.com','Tatyana Dobrokhotova','Nagornaya Street, house 15 / 4, apt.# 102','Moscow','Moscow','RUSSIAN FEDERATION','117186','(792) 626-7700 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:19:33',0,NULL,8,1,17,0,NULL,'romgrom'),(10308,840823029012,220815930479,'New GENUINE NOKIA BH-700 BLUETOOTH HEADSET',1,'HSNO028',13.39,'eastar4uk','shay28sinead','shayjanemc@hotmail.com','sinead mckinley','12 townfields','hatfield','Hertfordshire','UNITED KINGDOM','al10 0ay','01707257428','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 13:23:46',0,NULL,3,1,3,1,'RA183627601CN\r ','shay28sinead\rHSNO028\r英标'),(10309,839286279012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','martin3gb','cmgargi@gmail.com','Carol Gilmore','4117 Washington Street','Downers Grove','IL','UNITED STATES','60515','(630) 968-6921','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 14:17:02',0,NULL,3,1,1,1,'\\ ','martin3gb'),(10310,617978479013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','sclinchy','clinchys@embarqmail.com','Matt Brady','337 Rio Rd W<br>Lowr Level','Charlottesville','VA','UNITED STATES','22901-1311','(540) 220-6908','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 14:24:56',0,NULL,3,1,1,1,'\\ ','sclinchy\r一共买了两个'),(10311,617979218013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','sclinchy','clinchys@embarqmail.com','Matt Brady','337 Rio Rd W<br>Lowr Level','Charlottesville','VA','UNITED STATES','22901-1311','(540) 220-6908','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 14:27:56',0,NULL,3,1,17,0,NULL,'sclinchy'),(10312,562761053003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','marshalldanner','mddgz4@mizzou.edu','marshall danner','4378 W Country Hill Dr','columbia','MO','UNITED STATES','65203-0510','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-31 14:30:44',0,NULL,3,1,1,1,'\\ ','marshalldanner'),(10313,617985177013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','golzera8','henrique@duosite.com.br','Henrique  Stefan Neto','Av. Rubens de Arruda Ramos, 1540 apto 201','Florianópolis','SC','BRAZIL','88015700','55 48 84063458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 14:49:22',0,NULL,3,1,2,1,'\\ ','golzera8'),(10314,757846716011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','tgbini','tgbini@freesurf.ch','Sven Bini','Poststrasse 7','Kümmertshausen','','SWITZERLAND','8586','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 15:55:59',0,NULL,3,1,2,1,'\\ ','tgbini'),(10315,618004618013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','future1168','hienminh80@yahoo.com','Hien Minh Ton Tho (Trieu An Corporation)','10551 Bolsa Ave','Garden Grove','CA','UNITED STATES','92843-5251','714 862 1990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 16:07:07',0,NULL,3,1,1,1,'\\ ','future1168\r红边优联'),(10316,618002167013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',34.8,'eastar4','lietchi','naclement@hotmail.com','Sam Lekens','Streekbaan 71','Vilvoorde','','BELGIUM','1800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 16:07:34',0,NULL,3,1,3,1,'RA184553012CN\r ','lietchi\rCASS001\rCAB-SS-2626'),(10317,757861195011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','mrit5860','marittenhouse@yahoo.com','Maria A','319 W 18th St','Ship Bottom','NJ','UNITED STATES','08008-4421','(609) 294-8003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 16:33:36',0,NULL,3,1,1,1,'\\ ','mrit5860'),(10318,840906515012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','klementromanov','klement.romanov@gmail.com','Klement Romanov','Pashilaichiu 6-94','Vilnius','','LITHUANIA','LT-06116','370-674-74729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 16:51:23',0,NULL,3,1,2,1,'\\ ','klementromanov'),(10319,562801286003,130554587649,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',18.9,'cnfaner','knj6684','kenji_muro@yahoo.co.jp','Kenji Murohashi','Nisisiroi 2-16-27','Shiroi','Chiba','JAPAN','270-1408','(047)491-6450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 17:12:00',0,NULL,3,1,3,1,'RA184553065CN\r ','knj6684\rWLIN015\r无线蓝牙二合一'),(10320,836281626012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',7,'WLAP008',69.93,'eastar4uk','don-bx11','hae_tho_don@gmx.de','Thomas Häckl','Geschwister-Scholl-str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 17:13:41',0,NULL,3,1,3,1,'RA183627592CN\r ','don-bx11\rWLAP008\r'),(10321,562805182003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','hmistry71','hmistry@pacbell.net','Hitesh Mistry','429 Kentmere Ct.','Mountain View','CA','UNITED STATES','94040','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-31 17:21:33',0,NULL,3,1,1,1,'\\ ','hmistry71'),(10322,562806952003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','geovanny42','geoive42@verizon.net','GEOVANNY MATAMOROS','20 E 190th St<br>APT 1J','BRONX','NY','UNITED STATES','10468-4508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-31 17:27:02',0,NULL,3,1,1,1,'\\ ','geovanny42'),(10323,757898618011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',19.8,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick Welsh','6 Langford Pl<br>Renfrewshire','Glasgow','Renfrewshire','UNITED KINGDOM','g53 7hz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 17:56:55',0,NULL,3,1,3,1,'RA184553131CN\r ','lochearn1234\rWLAP002'),(10324,757901770011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','01kz','myplacekz@gmail.com','Nurlan Box 284','Bogenbai batyr, 134','Almaty','','KAZAKHSTAN','050000','+77017520752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 18:04:05',0,NULL,3,0,2,1,'\\ ','01kz'),(10325,618061835013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','000odessa000','grisartico2@gmail.com','Mario Bustamante Cabo','Avenida de la Ilustracion 49 Atico F','vitoria','País Vasco','SPAIN','01015','685884575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 18:46:03',0,NULL,3,1,3,1,'RA184585032CN\r ','000odessa000\rMOSA004'),(10326,618063198013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','jhayami','hayami@rogers.com','Jamie L Hayami','3 Athena Way','Nepean','ON','CANADA','K2G 6S1','(613) 843-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 18:48:56',0,NULL,3,1,2,1,'\\ ','jhayami'),(10327,618075509013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'eastar4','jeffreymatt','ebay@lectern.ca','Jeffrey Matt','14 Electric Street','Ottawa','ON','CANADA','K1M 1X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 19:19:47',0,NULL,3,1,2,1,'\\ ','jeffreymatt'),(10328,756249336011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',25.99,'eastar4uk','trmsw','trmsw@yahoo.co.uk','T Schutzer-Weissmann','Avenue de Tervueren, 90A, 1ere etage','Bruxelles','','BELGIUM','1040','0472386229','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 19:44:52',0,NULL,3,1,3,1,'RA184553193CN\r ','trmsw\rWWOT001'),(10329,618084868013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',2,'OTRA003',51.98,'eastar4','bbaa8210','benobaars@gmail.com','B. Baars','Lindenhoflaan 5','Wassenaar','','NETHERLANDS','2241WP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 19:46:57',0,NULL,3,1,3,1,'RA184553145CN\r ','bbaa8210\rOTRA003'),(10330,840491287012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','kevinj76600','joly_kevin@orange.fr','kevin joly','135 rue rene cance','le havre','Haute-Normandie','FRANCE','76600','0679325045','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 20:02:35',0,NULL,3,1,2,1,'\\ ','kevinj76600'),(10331,618092049013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','willowbaker','robert@robertbaker.org.uk','Robert Baker','3 Haydock Road','Bangor Isycoed','Wrexham','UNITED KINGDOM','LL13 0JD','01978780580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 20:03:54',0,NULL,3,1,2,1,'\\ ','willowbaker'),(10332,562864646003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','inazuma_de','cayza@arcor.de','Jens Kaiser','Immanuel-Kant-Höfe 14','Heiligenhaus','','GERMANY','42579','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 20:26:20',0,NULL,3,1,3,1,'RA184553114CN\r ','inazuma_de\rUDAP001\r'),(10333,841027285012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','bestbriar','wnapier1@woh.rr.com','Will Napier','951 Amlin Dr','Xenia','OH','UNITED STATES','45385-1301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 20:34:33',0,NULL,3,1,1,1,'\\ ','bestbriar'),(10334,562885764003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','compyfun','mroman@ihac.com','Michael A Roman','33 Ivan Road','Toronto','ON','CANADA','M1C 1V1','(416) 282-4111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 21:30:21',0,NULL,3,1,3,1,'RA184553159CN\r ','compyfun\rBALO007'),(10335,841073248012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',49.99,'eastar4','jcruzdf','jcruz.df@gmail.com','Julio Cesar Cruz','QNG 21 CASA 22<br>TAGUATINGA NORTE','BRASILIA','DF','BRAZIL','72130210','556184020672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 22:18:59',0,NULL,3,1,3,1,'RA183627589CN\r ','jcruzdf\rGLOT001\r兼容型3D眼镜 通用型'),(10336,618135357013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','berkstreet','berkan72@gmail.com','berkan olmez','1 collins st<br>coburg','Melbourne','Victoria','AUSTRALIA','3058','0393543151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 22:23:33',0,NULL,3,1,2,1,'\\ ','berkstreet'),(10337,841081628012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','wa69yne','waynerhysroberts@yahoo.co.uk','Wayne Roberts','148 Llanllienwen rd<br>Cwmrhydycierw','Swansea','Swansea','UNITED KINGDOM','sa66lt','01792798435','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 22:43:17',0,NULL,3,1,3,1,'RA184553043CN\r ','wa69yne\rHSPL011\r英标'),(10338,758033044011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','sbacelic','bids@el8.info','Slaven Bacelic','Strojarska 2','Zagreb','Croatia','CROATIA','10000','00385912516951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 22:47:59',0,NULL,3,1,3,1,'RA184553091CN\r ','sbacelic\rHBPH002'),(10339,758033420011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','duce501','michael@brokenroses.com','Michael Dattolico','4 Honeysuckel Hl','Flagler Beach','FL','UNITED STATES','32136-4937','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 22:50:02',0,NULL,3,1,1,1,'\\ ','duce501'),(10340,568365234004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','yessii11','yasser.al-dhaibi@live.com.au','yessii dee','5 hunter avenue','lurnea','New South Wales','AUSTRALIA','2170','0451514004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 23:14:05',0,NULL,3,1,3,1,'RA184553088CN\r ','yessii11\rMOOE001\r发OEM的'),(10341,562914257003,130458358283,'New  NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'HSNO006+CCNO001',16.95,'cnfaner','j-v-m-1','jevama1@yahoo.com','Jesus Vazquez Matias','Brida Mza.355-A Lt. 14<br>Col Miguel de la Madrid Iztapalapa','Mexico','Distrito Federal','MEXICO','09698','5558325855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 23:48:09',0,NULL,3,1,3,1,'RA184553026CN\r ','j-v-m-1\rHSNO006+CCNO001'),(10342,758058465011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','lylefire2','lylefire2@aol.com','Stephen Wiley','3325 Wilshire Blvd<br>Wmm Associates - Steve Wiley Ste 632','Los Angeles','CA','UNITED STATES','90010-1703','(213) 948-3892','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-01 00:26:12',0,NULL,3,1,1,1,'\\ ','lylefire2\rProLee24K超轻碳纤骨长柄伞\r红色的'),(10343,568386445004,140584810504,'New Grohe handheld Shower Head big water output+hose',1,'OTGR005+OTGR002',39.9,'cnfaner','raul_br','raulneto_br@yahoo.com.br','Sueli Martin Oliveira','Av. Giovanni Gronchi 4855 ap22','Sao Paulo','Sao Paulo','BRAZIL','05724-003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 01:17:14',0,NULL,3,1,3,1,'RA184585029CN\r ','raul_br\rOTGR005+OTGR002'),(10344,841141500012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','nicko2392','nickortiz_5@msn.com','NICK ORTIZ','320 W Brinker Dr','AVONDALE','AZ','UNITED STATES','85323','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 02:14:42',0,NULL,3,1,1,1,'、 ','nicko2392'),(10346,758106150011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','thedude306','huntitup@sasktel.net','Brad Taylor','810 15th St E','saskatoon','SK','CANADA','S7N 0R1','(306) 222-7399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 03:36:28',0,NULL,3,1,2,1,'\\ ','thedude306'),(10347,618202021013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',143.99,'eastar4','72fayez','fnmrenderingfayez@hotmail.com','Fayez El Danawi','63 seventh ave','Altona north','Victoria','AUSTRALIA','3025','0411112527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 03:58:48',0,NULL,3,1,3,1,'RA184585117CN ','72fayez\rGLOT001*3\r兼容型3D眼镜 通用型'),(10348,562958557003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','arts2010','aj0945@telus.net','Art Stevenson','6505 50A ave','Camrose','AB','CANADA','t4v3e7','(780) 608-9551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 04:19:39',0,NULL,3,1,3,1,'RA184585148CN ','arts2010\rHSMO019'),(10349,618207972013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','lbaugustine','lbanh@telus.net','Brian Augustine','7925 McKay Avenue','Burnaby','BC','CANADA','V5J 3T4','(604) 222-8883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 04:44:38',0,NULL,3,1,3,1,'RA184585151CN ','lbaugustine\rMOSA005'),(10350,568420315004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','ivanovvv','vitekvvv@rambler.ru','Viktor Ivanov Valerevich','Svyazistov 109  kv 18','Novosibirsk','','RUSSIAN FEDERATION','630107','89529021581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 05:02:09',0,NULL,3,1,3,1,'RA184553247CN ','ivanovvv\r欧标\rHSPL015'),(10351,700556858008,180716874781,'New Ralink RT2870F USB Adapter replace WIS09ABGN',1,'OTRA001',39.99,'au-buy','edwards_paulj','edwards_paulj@hotmail.com','Paul Edwards','130 Fox Valley Road','Wahroonga','New South Wales','AUSTRALIA','2076','0412794816','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 05:05:40',0,NULL,3,1,3,1,'RA184553255CN ','edwards_paulj\rOTRA001'),(10352,562966017003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','kronolog','jestercela@gmail.com','Alec Yin','#8, The Elegance<br>60 Tai Hang Road','default','','HONG KONG','default','+852 9689 9990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 05:25:38',0,NULL,3,1,3,1,'RA184585134CN ','kronolog\rHSPL009'),(10353,758126184011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','cibermania2','javi28_@hotmail.com','JAVIER TEJUELO MARTINEZ','C/  LOS ARCOS 12, 2H','ORIHUELA','ALICANTE','SPAIN','03300','654875097','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 05:30:39',0,NULL,3,1,3,1,'RA184553220CN ','cibermania2\rGLOT001\r兼容型3D眼镜 通用型'),(10354,618215686013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','manish_chhabra','manish.chief@gmail.com','Girish Chhabra','19 Bronhill Vista','Point Cook','Victoria','AUSTRALIA','3030','0434641629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 05:44:30',0,NULL,3,1,3,1,'RA184553176CN ','manish_chhabra\rMOSA005'),(10355,758129776011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','tvojmuc','roman.kelhar@sandoz.com','Roman Kelhar','koroskega bataljona 13','Ljubljana','Ljubljana','SLOVENIA','1000','+386 31 607728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 05:53:24',0,NULL,3,1,2,1,'\\ ','tvojmuc'),(10356,841191040012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','jimmione','jimmione@aol.com','James Penrose','28 N 1st St #303','San Jose','CA','UNITED STATES','95113','(408) 295-6800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 06:05:45',0,NULL,3,1,1,1,'\\ ','jimmione'),(10357,562974109003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','ecoluo','zhongkui.luo@csiro.au','Zhongkui Luo','Room 128, Butler Lab., CSIRO Land and Water<br>Clunies Ross St.','ACTON','Australian Capital Territory','AUSTRALIA','2601','0262465587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 06:38:32',0,NULL,3,1,3,1,'RA184553162CN ','ecoluo\rOTCR001'),(10358,8881314859632187,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',74.7,'cnfaner','raj96766 ','dsi@lauhala.com','Peter Jacobs','290 Walnut Street','Costa Mesa','CA','UNITED STATES','92627-2242','',NULL,NULL,NULL,'2011-09-01 06:47:12',0,NULL,3,1,3,1,'RA184585125CN ','MOAP001 '),(10359,758142816011,320741897705,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',56.99,'eastar4uk','erdmannheinz','clean-home@gmx.de','heinz erich hubert  erdmann','wilhelminenhofstrasse.43','berlin','','GERMANY','12459','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 07:04:20',0,NULL,3,1,3,1,'RA184587047CN\r ','GPS0002\r'),(10360,840082917012,220786834052,'Microsoft Explorer 3.0 USB Gaming Mouse SK X06 Ver',1,'MOMI003',35.99,'eastar4','byandrewlestat','k26lestat@yahoo.com','Andrey Mechev','170 Bay 31st St','Brooklyn','NY','UNITED STATES','11214-5231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 07:05:38',0,NULL,5,1,1,1,NULL,'byandrewlestat'),(10361,758143714011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',46.99,'eastar4','whiskey1953','knaggs@xtra.co.nz','Roger Knaggs','74 Regency Cr<br>Redwood','Christchurch','','NEW ZEALAND','8051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 07:08:44',0,NULL,3,1,3,1,'RA184553295CN ','whiskey1953\rGLSG001'),(10362,568437124004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','dimeadozenshane','seaman.s.g.cameron@hotmail.com','shane cameron','10/10 ATV, c/o Navy admin,<br>RAAF Base WAGGA,','Forest Hill','New South Wales','AUSTRALIA','2650','0449900015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 07:24:51',0,NULL,3,1,3,1,'RA184553216CN ','dimeadozenshane\rHSPL015\r澳标'),(10363,758157061011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','babarbabar123','babarihsan42@yahoo.com','babar ihsan','247 cheney st apt # c','reno','NV','UNITED STATES','89502','(775) 348-6019','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 08:12:29',0,NULL,3,1,1,1,'\\ ','babarbabar123'),(10364,8881314865518744,111,'tyco antenna *3',1,'ANTY002',0,'eastar4','jedi-fr','newjedi@free.fr','Mathias HARY','142 Rue Gambetta','SURESNES','Île-de-France','FRANCE','92150','',NULL,NULL,NULL,'2011-09-01 08:25:18',0,NULL,3,1,3,1,'RA184553304CN ','补发的 \rANTY002'),(10365,758162977011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','grau7','wtoroy@freenet.de','Marina   Polinger','Schützenstr. 26','Zeitz','','GERMANY','06712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 08:40:49',0,NULL,3,1,3,1,'RA184585205CN ','grau7\rGLSG001*2'),(10366,8881314868547294,111,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',50,'ANTY002',150,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320',NULL,NULL,NULL,'2011-09-01 09:15:47',0,NULL,3,1,6,1,'EE645685576CN ','白线100条 黑线50条\r\r\r'),(10420,840000054012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','natan555','natan.veksler@gmail.com','Natan Veksler','Meirovich 53','Rishon le Zion','','ISRAEL','75319','00972526449623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 04:35:23',0,NULL,3,1,2,1,'\\  ','natan555'),(10367,568459648004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','jackie221104','jackie221104@gmail.com','Joseph Raheb','7 Boronia St<br>Concord West','Sydney','New South Wales','AUSTRALIA','2138','0419433439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 10:00:50',0,NULL,3,1,3,1,'RA184585593CN ','jackie221104\rOTGR001+OTGR002'),(10368,8881314872589490,111,'New HP Wireless Comfort Mobile wireless mouse 2.4G',2,'MOHP001',0,'eastar4uk','jessica.curto','desislava.curto@googlemail.com','Desislava Curto','Mladost 142-5-109','Varna','','BULGARIA','9020 ','',NULL,NULL,NULL,'2011-09-01 10:23:09',0,NULL,3,1,3,1,'RA184585562CN ','MOHP001\r补发的 \r旧的已退回'),(10369,758191084011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','bbos8768','beatb@gmx.ch','Beat BOSSHARD','2,la Haute Poterie','St-Mars la Jaille','Pays de la Loire','FRANCE','44540','06 32 01 45 78','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 10:37:15',0,NULL,3,1,2,1,'\\  ','bbos8768'),(10370,618262085013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','coolmathun','coolmat@vipmail.hu','Attila Magyar','Erzsébet Királyné str. 45/A','Esztergom','Komárom - Esztergom','HUNGARY','2500','0036304656588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 10:55:42',0,NULL,3,1,2,1,'\\  ','coolmathun'),(10371,758196390011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','cireec','cireebay@yahoo.com','Eric Choong','92 Hargreaves Circus','Georgetown','Penang','MALAYSIA','11600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 10:58:05',0,NULL,3,1,3,1,'RA184585491CN ','cireec\rBR3D001'),(10372,563012444003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','mjzihan','zihanjj@yahoo.com','5Zihan Mohamed','141, Sri Vajiragnana Mw,','Colombo 09','Western','SRI LANKA','0094','+94773295334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 11:00:19',0,NULL,3,1,3,1,'RA184585474CN ','mjzihan\rOTCR001 投递不成功退回\r\r\r\r\r'),(10373,618280122013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','tluxtech','t.tornros@gmail.com','Tobias Törnros','Stenmarksvägen 13 C','Umeå','UMEÅ','SWEDEN','90345','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 12:25:50',0,NULL,3,1,2,1,'\\  ','tluxtech'),(10374,758223518011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','speedegarland','garlandr@hughes.net','Paul R. Garland','6943 Garland Rd','Maryville','TN','UNITED STATES','37801-1272','(865) 856-3178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 12:33:15',0,NULL,3,1,1,1,'\\  ','speedegarland'),(10375,618286625013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','davo-dos','davodos@internode.on.net','David Jeal','40 Langdon Crescent<br>Craigieburn','Melbourne','Victoria','AUSTRALIA','3064','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 12:56:41',0,NULL,3,1,2,1,'\\  ','davo-dos'),(10376,841297599012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.9,'eastar4','retrotecnic','jjebay@telefonica.net','Jesús Jurado Tercero','C/ San Antonio 21 Bajo','Catarroja','Comunidad Valenciana','SPAIN','46470','606380133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:05:20',0,NULL,3,1,2,1,'\\  ','retrotecnic\racer 8pin1.00 15cm'),(10377,758239116011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','crowing2010','mmturnbull@bigpond.com','Madeline Turnbull','Po Box 537','Walkerville','South Australia','AUSTRALIA','5081','0883443687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:25:49',0,NULL,3,1,3,1,'RA184585465CN\r ','crowing2010\rBR3D001'),(10378,841307190012,220815931272,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',36.99,'eastar4uk','johnhyde62','johnhyde2005@yahoo.co.uk','john hyde','35 carl street','walsall','West Midlands','UNITED KINGDOM','ws2 7be','01922615795','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 13:33:48',0,NULL,3,1,3,1,'RA184587957CN\r ','johnhyde62\rKBFF001'),(10379,841317039012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',3,'WLAT009',29.97,'eastar4uk','ulvster2','ulvster@gmail.com','Øivind Bakke','Tingnesvegen 393','NES','HEDMARK','NORWAY','2350','99710068','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 14:02:55',0,NULL,3,1,3,1,'RA184585528CN ','ulvster2\rWLAT009'),(10380,568504343004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',49.9,'cnfaner','oniukas','info@verzle.lt','Ona Minderiene','J.Dobkeviciaus g. 8-409','Vilnius','Vilnius','LITHUANIA','LT-02189','370 60800900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 14:05:04',0,NULL,3,1,3,1,'RA184585531CN\r ','oniukas\rMOOE001\r发OEM的'),(10381,758256592011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRTS001',6.99,'eastar4uk','rayval_0','rayval@o2.co.uk','Rayval Rodman','25 Inchgarvie Pk','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH309RN','07752302333','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 14:20:44',0,NULL,3,1,3,1,'RA184585559CN\r ','rayval_0\rTRTS001'),(10382,758266198011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jab1973','jbabcock@mnsi.net','Jeff Babcock','144 Ontario Street','Wardsville','ON','CANADA','N0L 2N0','(519) 693-4415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 14:49:49',0,NULL,3,1,2,1,'\\  ','jab1973'),(10383,841334804012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','duarte_correia','duarte.correia@gmail.com','Duarte Correia','Av. Arriaga, 21A - 2º Piso','Funchal','Portugal','PORTUGAL','9004-528','+351916662722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 14:52:47',0,NULL,3,1,2,1,'\\  ','duarte_correia'),(10384,618315359013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','svetila391','svetila_@mail.ru','Sergey Kolomiytsev','16 Prospekt Koroleva<br>apt.428','Korolev','Moscow area','RUSSIAN FEDERATION','141078','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 15:00:16',0,NULL,3,1,2,1,'\\  ','svetila391'),(10385,841356204012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','folian1','alexjubner@hotmail.com','Alexander Jubner','Upplandsgatan 62','Stockholm','Stockholm','SWEDEN','11328','0046733145850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 15:49:31',0,NULL,3,1,2,1,'\\  ','folian1'),(10386,563075723003,130553375752,'New GENUINE NOKIA HS-36W BLUETOOTH HEADSET HS 36W',1,'HSNO026',15.5,'cnfaner','sclinchy','clinchys@embarqmail.com','Matt Brady','337 Rio Rd W<br>Lowr Level','Charlottesville','VA','UNITED STATES','22901-1311','(540) 220-6908','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-01 16:03:17',0,NULL,3,1,1,1,'\\ ','sclinchy\r三星电源'),(10387,758292321011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','hama655','hama655@aol.com','Paul M Hamilton','Avocet, 15, Station Road','Foulsham','Norfolk','UNITED KINGDOM','NR20 5RD','01362680065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 16:03:25',0,NULL,3,1,3,1,'RA184585412CN\r ','hama655\rWLAP002'),(10388,618336933013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','ij860','zodiac860@gmail.com','eduard hechoyan','holmogorova<br>31-67','izhevsk','','RUSSIAN FEDERATION','426000','+7912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 16:22:15',0,NULL,3,1,3,1,'RA184585580CN\r ','ij860\rMOSA005'),(10389,841371127012,220815929174,'New APPLE iMac G6 Bluetooth Wireless Keyboard',1,'KBAP003',44.99,'eastar4uk','hus1983','huseyintaskin@hotmail.com','Huseyin Taskin','10 Signature House<br>Edgware','Lonodn','London','UNITED KINGDOM','HA8 7FP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 16:26:39',0,NULL,3,1,3,1,'RA184585633CN\r ','hus1983\rKBAP003'),(10390,563084130003,130554589408,'New Philips Sonicare toothbrush kit w/ Handle HX6930',1,'HBPH002+HBPH003+HBPH004',87.99,'cnfaner','evan_xp','heavenlybird@mail2000.com.tw','Amy Liang','PO Box 2390<br>Runcorn','Brisbane','Queensland','AUSTRALIA','4113','0733455678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 16:36:48',0,NULL,3,1,3,1,'RA184585647CN ','evan_xp\rHBPH002+HBPH003+HBPH004'),(10391,758310235011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','thibthib02','thibthib02+ebay@gmail.com','Thibaut MORET','7, avenue de la victoire<br>appartement 3','MONTESCOURT LIZEROLLES','Picardie','FRANCE','02440','06.86.21.62.51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 16:49:55',0,NULL,3,1,2,1,'\\  ','thibthib02\racer 4pin1.25 8cm'),(10392,841389765012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.5,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 17:10:19',0,NULL,3,1,3,1,'RA184585602CN ','grandizom\rOTCN004*10'),(10393,618352441013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','roi_besor','roi_besor@yahoo.com','Roi Bsor','Migdal David 23 apartment 72','Modi\'in','','ISRAEL','71702','972-52-8484803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 17:15:19',0,NULL,3,1,3,1,'RA184585576CN ','roi_besor\rMOSA005'),(10394,618353559013,230657622422,'Genuine DENON RC-970 Remote Control RC 970',1,'RCDE002',79.99,'eastar4','luislamlm','ladrero@ladrero.com','Luis Lamberto Ladrero Mosquera','Av. Doctor Rico, nº 6 - bloque 4 - 4ºC','Alicante','Comunidad Valenciana','SPAIN','03005','629172704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 17:20:06',0,NULL,3,1,3,1,'RA184585430CN\r ','luislamlm\rRCDE002'),(10395,758326305011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','vmsoftware2008','vmsoftware@live.co.uk','nick moulds','146 skircoat moor road','halifax','West Yorkshire','UNITED KINGDOM','hx30hu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 17:28:01',0,NULL,3,1,3,1,'RA184585620CN\r ','vmsoftware2008\rGLSG001'),(10396,841384537012,220708794349,'New IBM Atheros AR5BXB6 AR5424 MINI PCI-E Card+antenna',1,'WLAT005+ANTY001',11.89,'eastar4','raubvogel','raub@afn.org','Mauricio Tavares','3611 SW 34th St<br>Apt 5','Gainesville','FL','UNITED STATES','32608','(352) 214-7607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 17:39:48',0,NULL,3,1,1,1,'\\  ','raubvogel'),(10397,618388277013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','fersnk','fernandorossignolli@gmail.com','Fernando Rossignolli','Vereador Bento Rodrigues number: 153','Caieiras','São Paulo','BRAZIL','07700-000','55-11-7998-5061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:04:17',0,NULL,3,1,2,1,'\\  ','fersnk'),(10398,0,230666180448,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',45.99,'eastar4','hjvp2806','hjvp_2806@clix.pt','Helder Pires','Praceta Paiva Couceiro, 5 - 2º Esq.','Mem Martins','Mem Martins','PORTUGAL','2725410','351.93.660.11.00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:05:34',0,NULL,3,1,3,1,'RA184585616CN\r ','hjvp2806\rGLSG001'),(10399,758376823011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','rafool23','rauliscool_606@hotmail.com','Raul Garcia Balderas','1014 North St','Logansport','IN','UNITED STATES','46947-2887','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 19:13:30',0,NULL,3,1,1,1,' \\ ','rafool23'),(10400,618395938013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','basakykt','basak.hoca@hotmail.com','TÜRKAN YAKUT','Volkangul sok. Saray Ap no:15 D:11<br>Dumlupınar mahallesi (Fikirtepe)/KADIKÖY','İSTANBUL','TÜRKİYE','TURKEY','34720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:23:36',0,NULL,3,1,2,1,'\\  ','basakykt'),(10401,757760341011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','prydan08','pricelle_mangune@yahoo.com','pricelle mangune','6th floor AL JAZEERA TOWER CONFERENCE CENTRE ST. NO. 850 WEST BAY','doha','','QATAR','30249','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:38:56',0,NULL,3,1,2,1,'\\  ','prydan08'),(10402,563141750003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'cnfaner','ralphso','ralph.sonderegger@bluewin.ch','Ralph Sonderegger','Höhenweg 17','Bronschhofen','','SWITZERLAND','9552','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:45:12',0,NULL,3,1,3,1,'RA184585443CN\r ','ralphso\rHBPH002'),(10403,0,220842337502,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',82,'eastar4','explosivebg','dodofun@abv.bg','Adriyan Mihaylov','MLADOST 1, ANDREY SAHAROV BLVD., BLOCK 54A,ENTRY 4 ,APT 17<br>MLADOST 1, ANDREY SAHAROV BLVD., BLOCK 54A,ENTRY 4 ,APT 17','Sofia','','BULGARIA','1784','359885305480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:55:37',0,NULL,3,1,3,1,'RA184585695CN\r ','explosivebg\rGLSG001*2'),(10404,718366314001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK002',96,'buysia','salsero99','juan-manuel.fernandez@apg.ch','juan manuel fernandez','hohenstieglen 10','glattbrugg','','SWITZERLAND','8152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 20:25:52',0,NULL,3,1,3,1,'RA184585655CN ','salsero99\rHSAK002\r黑色的'),(10405,758418801011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',3,'CASS003',17.97,'eastar4uk','ne*nick','nelvidge@gmail.com','Nick Elvidge','58 Magdalene Gardens','Edinburgh','Midlothian','UNITED KINGDOM','EH15 3DW','01316571209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 20:37:51',0,NULL,3,1,3,1,'RA184585426CN\r ','ne*nick\rCASS003'),(10406,841497968012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.9,'eastar4','abbi123','joachim@firnhaber.biz','Joachim Firnhaber','Sonnenscheinsweg 27','Essen','','GERMANY','45149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 20:38:38',0,NULL,3,1,2,1,'\\  ','abbi123\r4pin 1.25'),(10407,839211577012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','mazertm','mazerbka@gmail.com','Mark Stokkebaek','Vesterfaelledvej 2, 5th','Koebenhavn V','','DENMARK','1750','+4520143253','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 20:54:08',0,NULL,3,1,2,1,'\\ ','mazertm'),(10408,841523668012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','mpiotrowska','martaptrwsk@gmail.com','Marta Piotrowska','57 Stamford Street<br>Flat 13','London','London','UNITED KINGDOM','SE1 9DJ','07912107343','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 21:36:50',0,NULL,3,1,3,1,'RA184585457CN\r ','mpiotrowska\rOTHP004'),(10409,758449850011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','lbai4812','lbailey@restorationhardware.com','Leila Bailey','20 Mallard Road','Belvedere','CA','UNITED STATES','94920','(415) 497-5351','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 21:54:45',0,NULL,3,1,1,1,'\\  ','lbai4812'),(10410,841536279012,220594073986,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10e S9 M10',1,'BTLE2101',12.4,'eastar4','dubbs.scott','sdubbs@lewistown.k12.mt.us','Scott Dubbs','215 7th Ave S','Lewistown','MT','UNITED STATES','59457-2921','(406) 535-8777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 22:14:07',0,NULL,3,1,1,1,'\\  ','dubbs.scott'),(10411,758458469011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','antoniojpd','antoniopd@jerez.es','Antonio Jesus Perdigones Díaz','Calle Romanito Nº 3 Piso 7','Jerez de la Frontera','Andalucía Ceuta y Melilla','SPAIN','11406','650194108','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 22:22:38',0,NULL,3,1,3,1,'RA184585704CN\r ','antoniojpd\rGLOT001\r兼容型3D眼镜 通用型'),(10412,567918764004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','tequilakez','tijuanakez@gmail.com','Carey O\'Sullivan','47 Coomera Crt','Helensvale','Queensland','AUSTRALIA','4212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 22:32:42',0,NULL,3,1,3,1,'RA184585488CN ','tequilakez\rWLAP008'),(10413,758480913011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','marek4530','marek.direr@gmail.com','Marek Direr','9 Wood Close','Hatfield','Hertfordshire','UNITED KINGDOM','AL10 8TY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 23:46:52',0,NULL,3,1,3,1,'RA184585505CN\r ','marek4530\rWLAP002'),(10414,758293704011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','pemartins1804','pemartins18@gmail.com','Pedro Martins','Rua Nascer do Sol, lote 3','Atalaia - Lourinhã','','PORTUGAL','2530 009','00351918388856','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 00:14:56',0,NULL,3,1,3,1,'RA184585514CN ','pemartins1804\r欧标\rHSPL015'),(10415,618482563013,230655991728,'New Portable Funny Wine Bottle Folding Sun Umbrella',1,'UM00030',10.99,'eastar4','tranalm','tranlam15298@yahoo.com','ha tran','8295 Hemley St','Bayou La Batre','AL','UNITED STATES','36509-2723','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 00:58:39',0,NULL,3,1,1,1,'\\  ','tranalm\r红酒瓶伞\r客户要买带hello kitty 的'),(10416,841585566012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','rhea.belbin1993','rhea.belbin@aol.com.au','rhea1993 belbin','8 melrose street','huonville','Tasmania','AUSTRALIA','7109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 01:03:03',0,NULL,3,0,2,1,'\\  ','rhea.belbin1993\r已入库'),(10417,563222215003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','09palaski20','littlefilly1964@yahoo.com','Deborah Crandall','661 Campbell Rd','Fort Pierce','FL','UNITED STATES','34945','(772) 468-0908','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 01:58:23',0,NULL,3,1,1,1,'\\  ','09palaski20'),(10418,618513433013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','zebji2008','bushrazeb_89@hotmail.com','Bushra Zeb','28 premier Place.','Brampton','ON','CANADA','l6s3w1','(905) 598-5992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 03:39:40',0,NULL,3,1,2,1,'\\  ','zebji2008\rCAB-6060'),(10419,758545376011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.95,'eastar4','sauga_07','chris.deluca06@gmail.com','Christopher De Luca','2391 Hammond Road','Mississauga','ON','CANADA','L5K 1T3','(905) 855-1221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 04:30:47',0,NULL,3,1,2,1,'\\  ','sauga_07'),(10421,758547744011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',14.99,'eastar4','longspringak','wlr_cardinal@yahoo.com','Wyatt Rivard','684 Wolf Point Ct','Oceanside','CA','UNITED STATES','92057-6346','(509) 670-8001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 04:45:42',0,NULL,3,1,1,1,'\\  ','longspringak'),(10422,563251856003,130554589408,'New Philips Sonicare toothbrush kit w/ Handle HX6930',1,'HBPH002+HBPH003+HBPH004',87.99,'cnfaner','supasn','supasn@hotmail.com','Tithima Sutatongthai','83/12 Rusada Road<br>Tubtiang','Muang','Trang','THAILAND','92000','0897242003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 05:42:18',0,NULL,3,1,3,1,'RA184585752CN\r ','supasn\rHBPH002+HBPH003+HBPH004'),(10423,840966263012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','smokinthedopest','crackman209@yahoo.com','israel hernandez','765 Ozark Ct','stockton','CA','UNITED STATES','95215-6065','(209) 323-4949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 05:44:40',0,NULL,3,1,1,1,'\\  ','smokinthedopest'),(10424,618531991013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','abc0092008','mt_01@gray.plala.or.jp','MANABU TANOUE','3-102 ASAKURADANCHI 1-14<br>TSUTSUJIGAOKA','CHITA','Aichi','JAPAN','4780054','0562551853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 05:57:49',0,NULL,3,1,2,1,'\\  ','abc0092008'),(10425,568711395004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','matthew_exon','ebay.mexon@spamgourmet.com','Lachlan Ma','5301 Central Plaza<br>18 Harbour Road','Wanchai','','HONG KONG','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 06:09:32',0,NULL,3,1,3,1,'RA184585678CN\r ','matthew_exon\rHSPL015'),(10426,758566825011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','shellzncheeze','jpoet37@hotmail.com','shellie poet','2035 NW Elm St','Toledo','OR','UNITED STATES','97391-1004','(541) 270-2578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 06:35:45',0,NULL,3,1,1,1,'\\  ','shellzncheeze'),(10427,758567297011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',38.99,'eastar4uk','dianne8917','reveroflatem@gmail.com','Dianne Becher','9 Grant Street','Drouin','Victoria','AUSTRALIA','3818','0356253049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 06:38:02',0,NULL,3,1,3,1,'RA184585681CN\r ','dianne8917\rOTSO004'),(10428,758161145011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','kalinskia','k.tsekoff@gmail.com','Kalin Tsekov','Vardar 38/29','Pernik','Pernik','BULGARIA','2300','359899666643','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 06:47:14',0,NULL,3,1,3,1,'RA184585664CN\r ','kalinskia\r欧标\rHSPL015'),(10429,758571956011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',13.99,'eastar4','atkei','evipeoglou@hotmail.com','Evi Peoglou','Paionias 1','Axioupoli','Kilkis','GREECE','61400','6936975377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 07:01:25',0,NULL,3,1,2,1,'\\ ','atkei'),(10430,618153351013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','max_el_duke','exemplenoir@hotmail.com','Gilles Morin','4374 des Erables','Montreal','QC','CANADA','H2H2C8','(514) 608-7030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 07:33:03',0,NULL,3,1,3,1,'RA184585973CN ','max_el_duke\rMOSA005'),(10431,758581858011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',46.99,'eastar4','gts-r','alx78@mail.ru','Potapov  Andrei  Vladimirovich (Потапов Андрей Владимирович)','Ventseka 81-27 (Венцека 81-27)','Samara (Самара)','','RUSSIAN FEDERATION','443020','+79272092884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 08:00:28',0,NULL,3,1,3,1,'RA184586007CN ','gts-r\rGLSG001'),(10432,8881314950591880,111,' Original Allied Telesyn AUI AT-210T Transceiver10Base-T  ',1,'TRMX002',0,'eastar4','plc_trainer','info@plctrainer.net','Ind-Concepts LLC','1000 Batesburg hwy','Saluda','SC','UNITED STATES','29138-8962','',NULL,NULL,NULL,'2011-09-02 08:03:11',0,NULL,3,0,3,1,'RA184585987CN ','补发的\rTRMX002 \r已入库'),(10433,836344957012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',19.9,'eastar4','allstarempire','leader.atxs@gmail.com','Gergely Szabó','Aranyvirág sétány 5/3 2.em 10','Budapest','Budapest','HUNGARY','1098','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 08:14:09',0,NULL,3,1,2,1,'\\ ','allstarempire'),(10434,8881314951269321,111,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',0,'eastar4','0kaz','kasper2004@gmail.com','Slavek Kasper','201 W Dyer Rd<br>Ste C','Santa Ana','CA','UNITED STATES','92707-3426','(714) 957-1757',NULL,NULL,NULL,'2011-09-02 08:14:29',0,NULL,3,1,3,1,'RA184585995CN ',' '),(10435,8881314951956958,111,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',0,'eastar4','razvan87zod','dark_grave2003@yahoo.com','Razvan Andrei Calota','Bvd. Camil Ressu, Nr.57A, Bl.Y2b, Apt.123, Sector 3, Bucuresti','Bucharest','','ROMANIA','031745','+40744666207',NULL,NULL,NULL,'2011-09-02 08:25:56',0,NULL,3,0,3,1,'RA184585960CN ','补发一个壳 '),(10436,841685090012,220807319834,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',15.95,'eastar4','flisu420','ville.pepe@hotmail.com','Ville Peltoperä','kantelettarentie 4 D 37','Helsinki','Uusimaa','FINLAND','00420','0407695612','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 08:32:33',0,NULL,3,1,2,1,'、 ','flisu420\r黑底七色边彩虹伞 '),(10437,618553635013,230538135586,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT  TV 40\"-55\"',1,'MOSA002',64.99,'eastar4','kitesurf4ever','kitesurf4ever@gmx.net','H. Hoffmann c/o LAS Burg 11206','Hauptstrasse 396','Weil am Rhein','','GERMANY','79576','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 08:43:58',0,NULL,3,1,3,1,'RA184585911CN ','kitesurf4ever\rMOSA002'),(10438,618568614013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.7,'eastar4','79-marco','79dragon@gmx.de','Marco Uhrig','Altheimer Str 26<br>----','Münster','','GERMANY','64839','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 09:57:42',0,NULL,3,1,2,1,'、 ','79-marco\rCAB-6060'),(10439,758615169011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','vegardhilstad','ebay@hilstad.net','VEgard Hilstad','CO / Rolls Royce PES<br>Janaflaten 28','Bergen','Hordaland','NORWAY','5882','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 10:19:04',0,NULL,3,1,2,1,'、 ','vegardhilstad'),(10440,758615576011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.95,'eastar4','solarkorenwolf','fh.jager@quicknet.nl','Frank Jager','Lettenburg 46','Hoofddorp','','NETHERLANDS','2135DG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 10:20:06',0,NULL,3,1,2,1,'、 ','solarkorenwolf'),(10441,618571905013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','dillyd33','daleendreyer@yahoo.com','Daleen Dreyer','2/262 Darlington Drive','Banora Point','New South Wales','AUSTRALIA','2486','0266743513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 10:22:45',0,NULL,3,1,3,1,'RA184553851CN\r ','dillyd33\rGLOT001*2\r兼容型3D眼镜 通用型'),(10442,618572997013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','pbw022','petterw@stud.ntnu.no','Petter Westby','Oystein Moylas vei 8','Trondheim','','NORWAY','7037','+47 41290675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 10:35:44',0,NULL,3,1,2,1,NULL,'pbw022'),(10443,758619907011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','hitchntrailer','lfweyers@gmail.com','Lorne Weyers','37 Minford Avenue','Scarborough','ON','CANADA','M1R2B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 10:36:42',0,NULL,3,1,2,1,NULL,'hitchntrailer'),(10444,568759535004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','12577frank','elvis77@three.com.au','frank  cutuli','72 grandview rd','wheelers hill','Victoria','AUSTRALIA','3150','0395611829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 11:27:12',0,NULL,3,1,3,1,'RA184553539CN\r ','12577frank\rOTRA001'),(10445,758352695011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',32.99,'eastar4','nancydances','gramabark@aol.com','Nancy Barker','PO BOX 922','PARSONS','KS','UNITED STATES','67357','(831) 206-2144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 11:38:27',0,NULL,3,1,1,1,'\\  ','nancydances'),(10446,618591007013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','i-am-supermat','mathieu.rouillard@gmail.com','Mathieu Rouillard','21 Bis Rue Charles Nungesser<br>Les Jardins de L\'Aulnay','LA CHAPELLE SUR ERDRE','Pays de la Loire','FRANCE','44240','0630534248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 11:58:58',0,NULL,3,1,2,1,'\\  ','i-am-supermat'),(10447,841744104012,220763389031,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',19.99,'eastar4uk','stuartwilson1968','swilson@wisintl.com','Stuart Wilson','8 Caledonia Road','Salcoats','North Ayrshire','UNITED KINGDOM','KA21 5AE','01294465247','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 12:08:16',0,NULL,3,1,3,1,'RA184553278CN\r ','stuartwilson1968\rWWSI002'),(10448,758646092011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','bohobolo','bohobolo@gmail.com','Glenn T Jayaputera','21 Ray Drive<br>Victoria','Balwyn North','Victoria','AUSTRALIA','3104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 12:11:13',0,NULL,3,1,2,1,'\\  ','bohobolo'),(10449,752739928011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',4,'CASS002',174,'eastar4','sabinel','sabinl74@yahoo.com','Sabin Lucea','Str. Episcopiei Nr.2 Ap.17','Arad','','ROMANIA','310023','+40 722 391482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 12:17:01',0,NULL,3,1,5,1,'CP237979731CN','sabinel\rCASS001+CASS002+CASS003\r再发六个CAB-2626\r十个\rCAB-6060\rCP227167693CN \r\r'),(10450,841747295012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','axengusi','andelcampo@gmail.com','ANDRES DEL CAMPO MARTÍNEZ','C/ SOMADILLA 13-B','AYORA','Comunidad Valenciana','SPAIN','46620','606119906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 12:18:17',0,NULL,3,1,2,1,'\\  ','axengusi\rAUI Transceiver  MX20T'),(10451,563311500003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','dkiss-2009','dkiss@yandex.ru','Denis Kiselev','Krasnobogatyrskaya st. 79-120','Moscow','RU','RUSSIAN FEDERATION','107076','79104096927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 12:18:39',0,NULL,3,1,3,1,'RA184553321CN\r ','dkiss-2009\rWLAT007'),(10452,758656653011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','tigran-felixich','hasmik1983@mail.ru','Tigran Sargsyan','Arghutyan 13','Yerevan','Yerevan','ARMENIA','0051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 12:46:29',0,NULL,3,1,3,1,'RA184587965CN\r ','tigran-felixich\rOTSO004'),(10453,758666911011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','techstarone','techstarone@yahoo.ca','RADU  NICU','7 ASHFORD CRT','CARLISLE','ON','CANADA','L0R 1H2','(905) 690-1499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:19:14',0,NULL,3,1,2,1,'\\  ','techstarone'),(10454,841769299012,220713846397,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET',1,'HSNO017',13.29,'eastar4uk','julie6360','mark@cmc-limited.co.uk','mark lintin','133 sheffield road','chesterfield','Derbyshire','UNITED KINGDOM','S417JH','01246550050','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 13:23:02',0,NULL,3,1,3,1,'RA184553661CN\r ','julie6360\rHSNO017\r英标'),(10455,563327588003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.8,'cnfaner','pvalenzu','pvalenzu@gmx.net','Patricio Valenzuela','Mañio 159<br>Higueras','Talcahuano','8 Region','CHILE','4265106','5641984384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:35:52',0,NULL,3,1,3,1,'RA184553675CN\r ','pvalenzu\rHSJA001\r欧标'),(10456,841776657012,220546768421,'1000000000000000% New Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','selkirk14','acrk@adam.com.au','Andrea Selkirk','WILSON PARKING<br>27 Austin Street','ADELAIDE','South Australia','AUSTRALIA','5000','0883575134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:44:09',0,NULL,3,1,2,1,'\\  ','selkirk14'),(10457,618614878013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','bjorntn','bjorn.nostvold@gmail.com','Bjorn Tore Nostvold','1006-9939 115 ST NW','Edmonton','AB','CANADA','T5K 1S6','(780) 935-0899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:47:21',0,NULL,3,1,2,1,'\\  ','bjorntn'),(10458,563331803003,130554588383,'NEW Logitech battery 890 880 950mA',2,'BALO001',23.8,'cnfaner','10tons','rbarnaby@telusplanet.net','RICHARD BARNABY','92 DEERCROSS RD SE','CALGARY','AB','CANADA','T2J6C1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:56:49',0,NULL,3,1,3,1,'RA184553383CN\r ','10tons\rBALO001'),(10459,618623836013,230522884834,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV 37\"',1,'MOSA001',58.99,'eastar4','nikpap1984','nikp1984@yahoo.gr','NIKOLAOS PAPAMICHELAKIS','DEINOSTRATOU 82, NEOS KOSMOS<br>NEOS KOSMOS','ATHENS','ATTIKI','GREECE','11743','6936848442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 14:22:36',0,NULL,3,1,3,1,'RA184553729CN\r ','nikpap1984\rMOSA001'),(10460,568805577004,140482633357,'New genuine NOKIA HS-12W BLUETOOTH HEADSET track#',1,'HSNO025',58.9,'cnfaner','sclinchy','clinchys@embarqmail.com','Matt Brady','337 Rio Rd W<br>Lowr Level','Charlottesville','VA','UNITED STATES','22901-1311','(540) 220-6908','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 15:06:45',0,NULL,3,1,1,1,'\\  ','sclinchy'),(10461,618635042013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',44.98,'eastar4','sclinchy','clinchys@embarqmail.com','Matt Brady','337 Rio Rd W<br>Lowr Level','Charlottesville','VA','UNITED STATES','22901-1311','(540) 220-6908','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 15:06:45',0,NULL,3,1,1,1,'\\  ','sclinchy'),(10462,841807589012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','nazbash786','mohammedbashir35@yahoo.co.uk','mr mohammed bashir','47 field road','reading','Berkshire','UNITED KINGDOM','rg1 6ap','07400800859','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 15:08:34',0,NULL,3,1,3,1,'RA184553692CN\r ','nazbash786\r英标\rHSMO017'),(10463,618634646013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','kappys','steve.selby@kappys.com','Steven L Selby','216 Border St','East Boston','MA','UNITED STATES','02128-1618','(617) 567-9500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 15:09:14',0,NULL,3,1,1,1,'\\  ','kappys'),(10464,758706263011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','melodyyuki','yukihyh@live.cn','YUE HAN HUANG','6 Range Road<br>Burwood East','Melbourne','Victoria','AUSTRALIA','3151','6104037387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 15:16:52',0,NULL,3,1,3,1,'RA184553318CN\r ','melodyyuki\rUDAP001'),(10465,841817024012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','julin760625','julmihdim@gmail.com','Yuliyan Dimitrov','k-s Chaika,bl.41,et.7,ap.28','Varna','Varna','BULGARIA','9010','+359888816273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 15:32:46',0,NULL,3,1,3,1,'RA184553794CN\r ','julin760625\rOTSO004*2'),(10466,618642249013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','margie8270','reeboksmm82@msn.com','FRANK MELENDEZ','5401 Chelsea Cv N','HOPEWELL JUNCTION','NY','UNITED STATES','12533-7105','(917) 692-0623','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 15:39:31',0,NULL,3,1,1,1,'\\  ','margie8270\r兼容型3D眼镜 通用型'),(10467,618644036013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','ahiska01','f.toker@yandex.ru','Ferhat Toker','Brusilovskogo 68/42','Almaty','Almaty','KAZAKHSTAN','050005','77016115115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 15:43:22',0,NULL,3,1,6,1,'EE495359389CN ','ahiska01\rOTSO004*4\r'),(10468,618647380013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','sandul_81','sandul_vladimir@mail.ru','Vladimir Sandul','st. Korolyova 64b flat 27','Odessa','','UKRAINE','65104','+380509051153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 15:56:05',0,NULL,3,1,2,1,'\\  ','sandul_81'),(10469,841839465012,220455477514,'HP 8710w nw9440 nx9420 Bluetooth Module EDR 2.0 +cable',1,'BTHP2005',9.9,'eastar4','lassidor510','chris.morris@clmnetwork.com','Christopher Morris','830 S Holland Sylvania Rd','Toledo','OH','UNITED STATES','43615-6308','(419) 472-7501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 16:29:12',0,NULL,3,1,1,1,'\\  ','lassidor510\rHP 8pin 1.0 20cm '),(10470,758738870011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',10,'TRMX002',75.7,'eastar4','ovelcj','caldonovelson@gmail.com','Caldon Ovelson','3527-22 st','Edmonton','AB','CANADA','t6t1w2','(780) 466-9666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 16:46:21',0,NULL,3,0,3,1,'RA184553882CN\r ','ovelcj\r已入库\rTRMX002'),(10471,618661434013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','hole_in_one72','bluedeville@hotmail.com','Sung Hoon Kim','25 Kingsbridge Garden Circle Ste. 2908','Mississauga','ON','CANADA','L5R4B1','(416) 737-4556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 16:46:50',0,NULL,3,1,3,1,'RA184553785CN\r ','hole_in_one72\rMOSA005'),(10472,758743918011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',46.99,'eastar4','21rafa','rafaeldaniel21@hotmail.com','RAFAEL DANIEL GARCIA FERNANDEZ','c/cruz de melilla 14 b1 2ºc','cartama','Malaga','SPAIN','29570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 16:58:52',0,NULL,3,1,3,1,'RA184588250CN\r ','21rafa\rGLSG001'),(10473,758745423011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mr.meatcurtain','chris-hodges@ouhsc.edu','Christopher Hodges','2600 Coachlight Dr<br>Apt E','Midwest City','OK','UNITED STATES','73110-7854','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 17:00:52',0,NULL,3,1,1,1,NULL,'mr.meatcurtain'),(10474,563382855003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','noahdarlene','noah.shuler@gmail.com','Noah Shuler','5328 Dekle St','Graceville','FL','UNITED STATES','32440','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 17:26:49',0,NULL,3,1,1,1,'\\  ','noahdarlene'),(10475,758755672011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','fraghass','bamsens@gmail.com','Bjørn Olesen','Skoletoften 2','Virring (skanderborg)','','DENMARK','8660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:28:47',0,NULL,3,1,2,1,'\\  ','fraghass'),(10476,618667247013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',34.99,'eastar4','allmaz1','bullterrier@live.ru','Alla Mazur','Chebrikova st. 40/523','Sochi','','RUSSIAN FEDERATION','354057','(7) 9183048883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:12:09',0,NULL,3,1,3,1,'RA184553750CN\r ','allmaz1\rWLIN002'),(10477,758758923011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','ronit8658','o.blonder@gmail.com','Oren Blonder','Arar 5<br>Appartment #3','Modiin','','ISRAEL','71702','(972) 523-2469 ext.: 56','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:35:39',0,NULL,3,1,3,1,'RA184553511CN\r ','ronit8658\rRCLO006'),(10478,758760157011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','jgscontact','jgs.contact@aliceadsl.fr','SCHERER JEAN GEORGES','33 RUE DES PECHEURS','THAL MARMOUTIER','Alsace','FRANCE','67440','0609534576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:38:30',0,NULL,3,1,2,1,'\\  ','jgscontact'),(10479,618676751013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','p37u','petri_huusko@hotmail.com','petri huusko','Otavankatu 6 as 12','iisalmi','','FINLAND','74100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:46:43',0,NULL,3,1,2,1,'\\  ','p37u'),(10480,841877226012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','silver_roadie','irbuddie@gmail.com','K or P Wowchuk','apt.411, 3611-145 Avenue NW','Edmonton','AB','CANADA','T5Y2L7','(780) 965-8906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:58:37',0,NULL,3,1,2,1,'\\  ','silver_roadie'),(10481,841878757012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','djuniqu3','uniqu3@sbcglobal.net','Gregorio Cervantes','2935 Missouri Ave','South Gate','CA','UNITED STATES','90280-4111','(323) 569-3386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 17:58:39',0,NULL,3,1,1,1,'\\  ','djuniqu3\rAUI Transceiver  MX20T'),(10482,618688529013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','mazda2001','sandak78@zahav.net.il','Daniel Lutskiy','Haim Barlev 6B /19','Beer Sheva','','ISRAEL','84277','0578172980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 18:17:01',0,NULL,3,1,3,1,'RA184553936CN\r ','mazda2001\rMOLO008'),(10483,758780569011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','twincities2011','tcwireless2011@gmail.com','Mohamad Hamod','615 66th Ave N<br>null','Brooklyn Center','MN','UNITED STATES','55430-1667','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 18:28:00',0,NULL,3,0,1,1,'\\  ','twincities2011'),(10484,841895036012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',29.97,'eastar4uk','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 18:32:18',0,NULL,3,1,3,1,'RA184553525CN\r ','avextra-co-uk\rOTCN004*10'),(10485,841898020012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',26.38,'eastar4','cgif1147','cgifford@augustaga.gov','Charles Gifford','507 Telfair Street','Augusta','GA','UNITED STATES','30901','(706) 836-0506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 18:39:21',0,NULL,3,1,1,1,'\\  ','cgif1147'),(10486,758788048011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','rebeccaschofield1993','rebecca_schofield1993@hotmail.co.uk','Rebecca Schofield','66<br>centurion row','runcorn','Cheshire','UNITED KINGDOM','wa7 2lf','01928576213','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 18:42:42',0,NULL,3,1,3,1,'RA184553454CN\r ','rebeccaschofield1993\rWLAP002'),(10487,758795128011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','scrapleap','tommyleaps@hotmail.com','Tom Leaper','Flat 30 Pavilion Mansions<br>10 Brighton Terrace','Brixton','London','UNITED KINGDOM','SW9 8DG','07859383738','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 19:00:54',0,NULL,3,1,3,1,'RA184553689CN\r ','scrapleap\rMOAP001'),(10488,758797800011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','sharmddht','sharm-ddht@mail.ru','Александр Колесников','ул. Циолковского, д. 24, кв. 62','Таганрог','Ростовская область','RUSSIAN FEDERATION','347916','+79185043915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 19:06:55',0,NULL,3,1,3,1,'RA184588025CN\r ','sharmddht\rGLSG001*2'),(10489,563413448003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','mariaesp44','hanky44@gmail.com','maria espinoza','3510 Conrad Ln','katy','TX','UNITED STATES','77449-5307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 19:14:19',0,NULL,3,1,1,1,'\\  ','mariaesp44'),(10490,840243247012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',55.9,'eastar4','kphok1','kphok1@dreamwiz.com','JEONG LEE','5351 Humboldt Dr.','Buena park','CA','UNITED STATES','90621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 19:17:55',0,NULL,3,1,1,1,'\\  ','kphok1\r美标'),(10491,841917216012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','5206019351','lming0_0@hotmail.com','liming liang','11300 66th St<br>Apt 204','largo','FL','UNITED STATES','33773','(727) 475-6036','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 19:18:40',0,NULL,3,1,1,1,'\\  ','5206019351\r美女涂鸦伞 '),(10492,841923406012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','pedrohbr','pedrohuebner@hotmail.com','Pedro Huebner dos  Reis','2811 Thurman Dr.<br>Carroll Hall','Raleigh','NC','UNITED STATES','27607','919 523 3995','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 19:30:50',0,NULL,3,1,1,1,'、 ','pedrohbr\rAcer 5pin1.25 3cm'),(10493,758814441011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',19.8,'eastar4uk','ukbytes11','ukbytes@gmail.com','Patrick Welsh','41 Bellflower Ave<br>South Park Village','Glasgow','Glasgow (City of)','UNITED KINGDOM','g53 7yd','01418817898','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 19:40:24',0,NULL,3,1,3,1,'RA184553370CN\r ','ukbytes11\rWLAP002'),(10494,563428363003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',33.4,'cnfaner','vincelatulippe','latulippe_vincent@videotron.ca','Vincent Latulippe','9385 rue de belfort   App.#105','Quebec','QC','CANADA','g1g 6j6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 20:04:55',0,NULL,3,1,3,1,'RA184553445CN\r ','vincelatulippe\rHSUE004+HSUE002\r再发一个\rNEW ULTIMATE EARS METRO.FI 220 EARPHONE '),(10495,758841687011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',3,'TRMX001',22.71,'eastar4','computerbytes73','c_hanson@wbcable.net','Clinton Hanson','978 SW Hall Ave','Mill City','OR','UNITED STATES','97360','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 20:43:22',0,NULL,3,0,1,1,'\\  ','computerbytes73'),(10496,841964271012,220812859649,'3DConnexion SpacePilot USB 3D Motion Controller mouse',1,'MOLO010',219.99,'eastar4','yura001','spirit@mail.zp.ua','Yura Matyashev','Voronina 31-48','Zaporozhye','Zaporozhye state','UKRAINE','69120','+380-612-674041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 20:58:24',0,NULL,3,1,5,1,'CP227167680CN ','yura001'),(10497,758848773011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','ronnie2112','ronnie.meyerson@gmail.com','Ronald A Meyerson','7 Magnolia Pkwy','Hawthorn Woods','IL','UNITED STATES','60047','(224) 688-5570','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 21:02:30',0,NULL,3,1,1,1,'\\  ','ronnie2112'),(10498,841967824012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','murillodias','mega_pixels@hotmail.com','Murillo Dias de Arruda','Av. Sangradouro Nº 879<br>Centro','Cáceres','MT','BRAZIL','78200-000','(65) 3223-4782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:08:19',0,NULL,3,1,2,1,'\\  ','murillodias'),(10499,758851144011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',93.98,'eastar4','aithor1','aithor11@hotmail.com','Aithor  Tagua Antón','C/ Afan de Ribera, 253 1ºK','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41006','697376598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:09:08',0,NULL,3,1,3,1,'RA184588039CN\r ','aithor1\rGLSG001'),(10500,841970955012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',9.9,'eastar4','inforea','thomas.rea@wanadoo.fr','Thomas REA','19bis chemin de la fouillouse','SAINT PRIEST','Rhône-Alpes','FRANCE','69800','0640596488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:14:49',0,NULL,3,1,2,1,'\\  ','inforea\racer 8pin1.0 3cm '),(10501,618750759013,230518594351,'UNLOCKED HS2300 SIERRA MC8775 3G for Dell/lenovo/Ace​r',1,'WWSI001',30.99,'eastar4','danniel_maher','danniel_maher@msn.com','Danniel Maher','Rua Mario Agostinelli 155 apt:1001 bl:2<br>Condominio Rio2 - Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22775046','55 21 91631254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 22:03:04',0,NULL,3,1,3,1,'RA184553397CN\r ','danniel_maher\rWWSI001'),(10502,718792009001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','ggellert','ggellert1@verizon.net','Ginger Gellert','706 Hickory St','Liverpool','NY','UNITED STATES','13088-4419','(315) 457-4892','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 22:14:05',0,NULL,3,1,1,1,'\\  ','ggellert'),(10503,842002665012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT004*3',132.99,'eastar4','lasersr2','rayza71@hotmail.com','Ray B Matchett','84 elizabeth street<br>geelong west','Geelong','Victoria','AUSTRALIA','3218','0352293104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 22:45:25',0,NULL,3,1,3,1,'RA184553848CN\r ','lasersr2\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(10504,618768324013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','angelfm80','afmateo@gmail.com','Angel Fernandez','Av. Lisboa Nº20 2ºB','Coslada','Madrid','SPAIN','28822','686201124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 22:58:28',0,NULL,3,1,2,1,'\\  ','angelfm80'),(10505,618776831013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','marknorris2','lilnarra@optusnet.com.au','Mark Norris','44 Narrabeen Park Parade','Warriewood','New South Wales','AUSTRALIA','2102','0299132563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 23:42:01',0,NULL,3,1,2,1,'\\  ','marknorris2'),(10506,758900218011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','etrigan420','etrigan420@gmail.com','Matt Miller','4736 Mount Baker Loop','Mount Vernon','WA','UNITED STATES','98273-9439','(360) 720-4812','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-02 23:54:19',0,NULL,3,1,1,1,NULL,'etrigan420'),(10507,618790151013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','sentinal_oz','mjbblack@hotmail.com','Trophy Cards','81 Hughes Street','Mile End','South Australia','AUSTRALIA','5031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 00:59:09',0,NULL,3,1,3,1,'RA184553763CN\r ','sentinal_oz\rMOSA006'),(10508,758917652011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','oliveirarosajr','lforj@globo.com','Luiz Felipe Oliveira Rosa Junior','Estrada Fazenda dos Cavaleiros,N146,Apto:202<br>Glória','Macaé','Rio de Janeiro','BRAZIL','27937-670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 01:17:52',0,NULL,3,1,3,1,'RA184553635CN\r ','oliveirarosajr\rBR3D001'),(10509,758935213011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jcn30067','jcn30067@gmail.com','John Nichols','4565 Fountain Dr NE','Marietta','GA','UNITED STATES','30067','(404) 394-6389','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 02:39:18',0,NULL,3,1,1,1,'\\  ','jcn30067'),(10510,618809774013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',74.97,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Anna Kaufman','1504 Gotthard St SW','Sugarcreek','OH','UNITED STATES','44681-9323','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 03:00:38',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10511,618813078013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','forsythe1953','forsyth1@bigpond.net.au','william forsythe','51 parkside drive, thornlie','perth','Western Australia','AUSTRALIA','6108','0894933482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 03:18:51',0,NULL,3,1,3,1,'RA184553922CN\r ','forsythe1953\rMOLO008'),(10512,842078950012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',2,'GLOT004*3',265.98,'eastar4','kmd0528','kaciemdalrymple@yahoo.com','Bruce Craft','5306 Hidden Trails Dr','Arlington','TX','UNITED STATES','76017-2170','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 04:09:31',0,NULL,3,1,6,1,'EE645685409CN ','kmd0528\r这个客户补钱了，发6付原装SSG-2100AB\r\r\r\r'),(10513,760885781002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'',119.99,'buysia','langepas2020','lange2005@inbox.ru','Яичников Вячеслав','Нежнова 72 корпус 1. кв 47','Пятигорск','Россия','RUSSIAN FEDERATION','357500','9288246101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 04:26:10',0,NULL,3,0,3,1,'RA184581985CN\r ','langepas2020'),(10514,758959332011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','shakmal','shakmal@hotmail.com','SHAFIQ AKMAL ISMAIL','0733 7TH FLR BRUNSFIELD RIVERVIEW SERVICE APMT<br>NO 3 JL YOGA 13/42 SEK 13','SHAH ALAM','SELANGOR','MALAYSIA','40100','0122050534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 04:50:27',0,NULL,3,1,3,1,'RA184553777CN\r ','shakmal\rOTSO004'),(10515,758960621011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',8.99,'eastar4','icerealms','james1281@gmail.com','James Cole','516 Daniel Boone Rd.','Gate City','VA','UNITED STATES','24251','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 04:57:55',0,NULL,3,1,1,1,'\\  ','icerealms\r 一代卡  旧'),(10516,618826707013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','moneyguy5555','moneyguy@telus.net','Gerold Haukenfrers','3932 Valewood Drive','Nanaimo','BC','CANADA','V9T 6B9','(250) 729-9822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 05:01:18',0,NULL,3,1,3,1,'RA184553803CN\r ','moneyguy5555\rMOSA005'),(10517,842098940012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','successdiet','succesdiet@aol.com','Rosemary Garrison','47708 N Shore Dr','Belleville','MI','UNITED STATES','48111','(734) 699-7673','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 05:58:55',0,NULL,3,1,1,1,'\\  ','successdiet'),(10518,842106906012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','pc_always','cjflake@hotmail.com','david mathews','42 lachlan st','maquarie','Australian Capital Territory','AUSTRALIA','2614','0432288824','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 06:41:16',0,NULL,3,1,2,1,'\\  ','pc_always'),(10519,618842682013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','n0n0_be','n000n000@gmail.com','Marie Bellon','Georgia-Pacific<br>Drève Richelle 167','Waterloo','','BELGIUM','1410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 07:07:43',0,NULL,3,1,2,1,'\\  ','n0n0_be'),(10520,754273626011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',16,'eastar4','saad0659','saadene@live.fr','saadene SOUICI','ROGER SALENGRO<br>139','DRANCY','Ile-de-France','FRANCE','93700','0659544097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 07:39:46',0,NULL,3,1,2,1,'\\  ','saad0659'),(10521,842141136012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','andrewantoinette','isemonger@mac.com','Andrew Wells','Isemonger Farm<br>Rolvenden road','Tenterden','Kent','UNITED KINGDOM','TN30 6ub','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 09:00:02',0,NULL,3,1,3,1,'RA184553485CN\r ','andrewantoinette\rHBPH003'),(10522,759013986011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','atife09','atifete.nikqi@mail.dk','Atifete Nikqi','Mjølnerparken 52, 4.th','København','N','DENMARK','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:17:21',0,NULL,3,1,3,1,'RA184553715CN\r ','atife09\rOTSO004'),(10523,759013645011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','abdullahrozi','abdullah.rozi@hotmail.com','Abdullah Bukhari','1902/148 Elizabeth st, sydney','Sydney','New South Wales','AUSTRALIA','2000','6142165677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:18:58',0,NULL,3,1,2,1,'\\  ','abdullahrozi'),(10524,842148126012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',13.19,'eastar4','anndingo','anndingo@westnet.com.au','warren painter','54 Summerfield road','Serpentine','Western Australia','AUSTRALIA','6125','0895252655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:25:47',0,NULL,3,1,2,1,NULL,'anndingo\r澳标'),(10525,569014253004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','lcbakkie','cornebakkenes@chello.nl','Corne Bakkenes','Wittenburg 105','Nijkerk','','NETHERLANDS','3862ED','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:26:17',0,NULL,3,1,3,1,'RA184553471CN\r ','lcbakkie\rHSJA002\r欧标'),(10526,758761766011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',2,'HSSA003',27.8,'eastar4','ksiped1981','ksiped@hotmail.com','alexandros pediaditis','etnikis antistaseos 33','chania','lentariana','GREECE','73133','2821051137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:33:26',0,NULL,3,1,2,1,'\\  ','ksiped1981\r欧标'),(10527,759020219011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','krypton1965','navass1@telefonica.net','José Luis Martínez','Arte-9. Calle Doctor Esquerdo 6','Madrid','Madrid','SPAIN','28028','914029608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:41:03',0,NULL,3,1,3,1,'RA184588087CN\r ','krypton1965\r带碟的'),(10528,563565606003,130554588383,'NEW Logitech battery 890 880 950mA',1,'BALO001',11.9,'cnfaner','chuckypool','chris@chaliam.com','Chris Payne','PO Box 91617<br>Victoria Street West','Auckland','','NEW ZEALAND','1142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 10:18:51',0,NULL,3,1,3,1,'RA184553746CN\r ','chuckypool\rBALO001'),(10529,618881370013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','danaigh','greythorn@live.com','Daniel R. Duran','67 Heritage Drive','Mill Park','Victoria','AUSTRALIA','3082','(039) 408-6111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 10:46:19',0,NULL,3,1,2,1,'\\  ','danaigh'),(10530,842172520012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','simonlenihan','lenihan.simon@gmail.com','Simon Lenihan','53b Glen Rd<br>Raumati South','Paraparaumu','','NEW ZEALAND','5032','027 418 4518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 10:46:39',0,NULL,3,1,3,1,'RA184553595CN\r ','simonlenihan\rOTSO004*2'),(10531,842173306012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','hrushch2011','hrushch@gmail.com','Roman Hrusik','Shevchenka 41','Pidgaitsi','Ternopilska','UKRAINE','48000','+380673430398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 10:49:11',0,NULL,3,1,2,1,'\\  ','hrushch2011'),(10532,842186392012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','dibanoff','dibanoff@mail.ru','Vladislav Dibanov','Parashutnaya street<br>31-2-239','Saint-Petersburg','','RUSSIAN FEDERATION','197371','+79112617318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 11:32:00',0,NULL,3,1,2,1,'\\  ','dibanoff'),(10533,563583675003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',3,'HSNO005+CCNO001',44.97,'cnfaner','blex3330','blex3330@aol.com','Brian Lex','9045 E Kings Hwy','Shreveport','LA','UNITED STATES','71115-2735','(318) 797-6035','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-03 11:50:37',0,NULL,3,1,1,1,'\\  ','blex3330'),(10534,618898950013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','petarpetrovi','nobradovic@gmail.com','Marija Bjekovic-Obradovic','5, rue de Kirchberg','Luxembourg','','LUXEMBOURG','L-1858','352621452044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:22:39',0,NULL,3,1,3,1,'RA184553940CN\r ','petarpetrovi\rMOLO008'),(10535,618904760013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',5.96,'eastar4','vda76','vda_vork@mail.ru','Dmitry Voronov','Shaumyana st.<br>house 20/1 flat 15','Taganrog','Rostov region','RUSSIAN FEDERATION','347909','+79281274110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:38:53',0,NULL,3,1,2,1,'\\  ','vda76'),(10536,842211240012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.95,'eastar4uk','ervinspolis','ervins789@inbox.lv','Ervins Polis','27 Lielirbes str.','Riga','Riga','LATVIA','LV-1046','+37129223515','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 12:44:00',0,NULL,3,1,2,1,'\\  ','ervinspolis'),(10537,759077686011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','buzzwil','bazzw@blueyonder.co.uk','Barry Wilson','43, Colman Avenue','South Shields','Tyne and Wear','UNITED KINGDOM','NE349AG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 12:54:30',0,NULL,3,1,3,1,'RA184553627CN\r ','buzzwil\rHBPH002'),(10538,759077072011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',119.98,'eastar4','idanash007','amit471@gmail.com','idan ash','iris<br>2','matan','matan','ISRAEL','0547244916','0547244913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:59:31',0,NULL,3,1,3,1,'RA184553834CN\r ','idanash007\rOTSO004'),(10539,842234102012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','zzz6jigolo6zzz','jigolo@mail.ru','Igor Safronov','Avidan Shimon 8    apt 3','Rishon LeZion','','ISRAEL','75339','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 13:48:23',0,NULL,3,1,2,1,'\\  ','zzz6jigolo6zzz'),(10540,759094413011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','p4610yz','dp4610yz@gmail.com','Yang Zheng Poh','102 Rivervale Walk #10-46','Singapore','','SINGAPORE','540102','6596864690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 13:51:24',0,NULL,3,0,11,1,'\\ ','p4610yz'),(10541,618925862013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ewjili','bajili@hotmail.com','Catherine Ann Healey','1672 Snowball Way','Tallahassee','FL','UNITED STATES','32301-6871','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-03 14:06:54',0,NULL,3,1,1,1,'\\  ','ewjili'),(10542,759068404011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',43.98,'eastar4uk','pitxalo','gonrodriguez2008@gmail.com','Gonzalo Rodríguez','Ibáñez de Bilbao 11-1A','Bilbao','País Vasco','SPAIN','48009','628094998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 14:22:08',0,NULL,3,1,3,1,'RA184553335CN\r ','pitxalo\rUDAP001'),(10543,563617158003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','gwoman2','love2kid@yahoo.com','Sandi A Stenberg','1075 Rockport Ceralvo Rd','Centertown','KY','UNITED STATES','42328','(270) 232-4903','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-03 14:22:38',0,NULL,3,1,1,1,'\\  ','gwoman2'),(10544,618930474013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','xap4o','zahariev.zahari@gmail.com','Zahari Zahariev','Strelbishte, str. Traianovi vrata, bl. 101, entr. 3, app. 51','Sofia','BG','BULGARIA','1408','+359885241145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:24:45',0,NULL,3,1,2,1,'\\  ','xap4o'),(10545,759115868011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','rhui3667','chicago921@comcast.net','Richard Huitema','1122 W Catalpa Ave #613','Chicago','IL','UNITED STATES','60640','(773) 275-0485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 14:43:45',0,NULL,3,1,1,1,'\\ ','rhui3667'),(10546,759116286011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.4,'eastar4','fhrdmrbs','fade69@gmail.com','Fahri Demirbas','Alte Gladbacherstr.28','Krefeld','','GERMANY','47805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:46:02',0,NULL,3,1,2,1,'\\  ','fhrdmrbs\racer 5pin1.25 4cm '),(10547,569084082004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',26,'cnfaner','cruzerov','mahdal5@seznam.cz','Irena Mahdalova','Podlesi II 4937','Zlín','Czech Republic','CZECH REPUBLIC','76005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 15:06:13',0,NULL,3,1,3,1,'RA184553701CN\r ','cruzerov\rCACN004'),(10548,569087525004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.99,'cnfaner','nivtv','niv.tvizer@gmail.com','niv tvizer','egoz<br>5','reut','israel','ISRAEL','77919','+972543318758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 15:17:39',0,NULL,3,1,3,1,'RA184553879CN\r ','nivtv\rOTTP001'),(10549,842278590012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','djdtr','dpgoymer@gmail.com','David Goymer','21 Clyde Crescent','Chelmsford','Essex','UNITED KINGDOM','CM1 2LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 15:36:56',0,NULL,3,1,3,1,'RA184553366CN\r ','djdtr\rWLAP008'),(10550,842282501012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','tex._murphy','murphytex@free.fr','Philippe Sannier','20/8 rue des Aubépines','Abbeville','Picardie','FRANCE','80100','03.22.31.37.84','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 15:46:13',0,NULL,3,1,2,1,'\\  ','tex._murphy'),(10551,618964889013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.9,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 16:23:25',0,NULL,3,1,2,1,NULL,'germanskynet\r华硕 8pin 1.0 6cm '),(10552,842302351012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','aitor_1986','puros_arpuros@hotmail.com','Aitor Arberas Larrinaga','c Avila<br>nº 1 8ºD','Bilbao','País Vasco','SPAIN','48012','944210140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 16:34:09',0,NULL,3,1,2,1,'\\  ','aitor_1986'),(10553,842305442012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','costasioannou','costasioa@yahoo.gr','Costas Ioannou','Constandinoupoleos 7','Malounda','Nicosia','CYPRUS','2612','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 16:36:06',0,NULL,3,1,3,1,'RA184553499CN\r ','costasioannou\rOTSO004*2'),(10554,842309890012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','amykeithwright12','kwright128@comcast.net','Keith Wright','227 Glyndon Dr','Reisterstown','MD','UNITED STATES','21136-2131','(443) 394-7555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 16:48:27',0,NULL,3,1,1,1,'\\  ','amykeithwright12'),(10555,618978843013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','dvoina01','daniel.voina@gmx.com','Daniel Voina','31 Nicolae Titulescu','Sighetu Marmatiei','','ROMANIA','435500','+40723 292751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 17:11:56',0,NULL,3,1,2,1,'\\  ','dvoina01'),(10556,842328482012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',67.99,'eastar4uk','juananduran','pirulax@terra.es','Juan Antonio Duran Sanz','calle los arces 15 Duplicado - 5º A','Alcorcon','Madrid','SPAIN','28922','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 17:34:21',0,NULL,3,1,3,1,'RA184588189CN\r ','juananduran\rGLSG001*2'),(10557,563322178003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.9,'cnfaner','kelvintan','kelvin.ebay.sg@gmail.com','Kelvin Tan','51 Nim Green','default','','SINGAPORE','805307','(65) 9710-8892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 17:57:12',0,NULL,3,1,3,1,'RA184553352CN\r ','kelvintan\rWWSI002+ANCN001'),(10558,842357961012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','dj-kmusic','k.mcdiarmid@ntlworld.com','KEVIN McDiarmid','17 DARLEY CLOSE, HOUGH GREEN','WIDNES','Cheshire','UNITED KINGDOM','WA8 4EB','01514240901','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 18:27:26',0,NULL,3,1,3,1,'RA184553613CN\r ','dj-kmusic\rHBPH003'),(10559,619006378013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','marbleeyehunter','walleyeinlund@yahoo.com','Hiawatha Farm and Home','2114 Oregon St<br>Don Koontz','Hiawatha','KS','UNITED STATES','66434','(785) 742-2200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 18:33:54',0,NULL,3,1,1,1,'\\  ','marbleeyehunter'),(10560,842395835012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','quipzephyr','jwong87@gmail.com','James Wong','1350 NW 8th Court, Apt. 408','Miami','FL','UNITED STATES','33136','(919) 452-8226','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 19:46:19',0,NULL,3,1,1,1,'\\  ','quipzephyr'),(10561,759261311011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','fx12studio','stanley@filipinowebmasters.com','Stanley Dumanig','L3-B Mother Theresa St., Marfori 2','Davao','','PHILIPPINES','8000','0822264698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 20:26:58',0,NULL,3,1,2,1,'\\  ','fx12studio'),(10562,842440126012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','artkimmy','kakleppen@aol.com','Art Kleppen','CK Worldwide Inc<br>3501 Cst NE','Auburn','WA','UNITED STATES','98002','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 21:28:36',0,NULL,3,1,1,1,'\\  ','artkimmy\r兼容型3D眼镜 通用型'),(10563,719187289001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','photoartdc','coumaris@yahoo.com','Tom Coumaris','1413 S St NW','Washington','DC','UNITED STATES','20009-3819','(202) 234-3953','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 22:24:57',0,NULL,3,1,1,1,'\\  ','photoartdc'),(10564,759304218011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','lisy1222','lisywisy@hotmail.com','lisa williams','5205 Cutshaw Ave','Richmond','VA','UNITED STATES','23226-1103','(804) 647-8036','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 22:25:57',0,NULL,3,1,1,1,'\\  ','lisy1222'),(10565,759328011011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','dangr22','robert.dang22@gmail.com','Robert Dang','53 Kulgun Circuit','Inala Brisbane','Queensland','AUSTRALIA','4077','0434011882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 23:56:00',0,NULL,3,1,2,1,'\\  ','dangr22'),(10566,842485605012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','vanakmom','cartman_13@hotmail.com','Nicolas Lapointe','843 rue joffre <br>appartement 2','Shawinigan','QC','CANADA','g9n1x1','(819) 537-3730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 23:53:51',0,NULL,3,1,2,1,'\\  ','vanakmom'),(10567,759344747011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','galacticgoof','brucenorthway@shaw.ca','Bruce Northway','20143 49A Ave.','Langley','BC','CANADA','V3A 3S2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 01:07:43',0,NULL,3,1,3,1,'RA184553410CN\r ','galacticgoof\rHBPH002'),(10568,569236022004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','boke819naoto','boke819@gmail.com','Naoto Nakanishi','Yatsu3-1<br>Yatsu ParkTown15-310','Narashino-shi','Chiba','JAPAN','275-0026','81-47-452-7523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 01:45:24',0,NULL,3,1,3,1,'RA184553600CN\r ','boke819naoto\rHBPH003'),(10569,618205645013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',4,'WLIN013',71.96,'eastar4','sillyadrian','adrian@creative.net.au','Adrian Chadd','PO Box 948','Balcatta','Western Australia','AUSTRALIA','6914','0894453371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 01:55:51',0,NULL,3,1,3,1,'RA184588643CN\r ','sillyadrian\rWLIN013'),(10570,759365567011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','thodoreos','xenakis.thodoris@hotmail.com','THEODOROS XENAKIS','KONDILI 4','ATHENS','ATIKI','GREECE','15122','+30 6977808275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 02:45:16',0,NULL,3,1,2,1,'\\  ','thodoreos\r欧标'),(10571,759373663011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','yinghanz','harvey.1988@hotmail.com','yinghan zhang','94 Grosvenor St ，sandy bay','hobart','Tasmania','AUSTRALIA','7005','06130402711991','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 03:25:01',0,NULL,3,1,2,1,'\\  ','yinghanz\r红边优联'),(10572,619128686013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','omozuwa','princessmoz2000@yahoo.com','Elizabeth cherry','495 Odell Ave<br>Apt 3J','yonkers','NY','UNITED STATES','10703-1140','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 03:29:20',0,NULL,3,1,1,1,'\\  ','omozuwa'),(10573,842544955012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','somissfan1','somissfan@yahoo.com','James Fenton','301 1st St S','Reform','AL','UNITED STATES','35481-8013','(205) 375-2959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 04:06:37',0,NULL,3,1,1,1,'\\  ','somissfan1'),(10574,759385308011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','abuelo324','mocapr52@aol.com','Hector Malave','3227 Utopia Pkwy','FLUSHING','NY','UNITED STATES','11358-1941','(718) 353-7141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 04:31:43',0,NULL,3,1,1,1,'\\  ','abuelo324'),(10575,563803988003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','turbo-auction','turbojose@sbcglobal.net','JOSE LEYVA','1631 ascension dr','san mateo','CA','UNITED STATES','94402-3614','(510) 213-9000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-04 04:34:47',0,NULL,3,1,1,1,'\\  ','turbo-auction\rUE 220如果没有了，就发220VI吧'),(10576,761292378002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'',119.99,'buysia','permilzyfranchise','milesfrancis@hotmail.com','Miles Francis','96 Rundle Street','Kent Town','South Australia','AUSTRALIA','5067','0883634300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 05:19:09',0,NULL,3,0,3,1,'RA184587055CN\r ','permilzyfranchise'),(10577,619143802013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','kklwin7','kyawko7@gmail.com','Kyaw Ko Lwin','PO Box-17114, DUSUP Pipeline Office<br>Jebel Ali Ind.1','Dubai','Dubai','UNITED ARAB EMIRATES','-','+971504508274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 05:30:57',0,NULL,3,1,3,1,'RA184553644CN\r ','kklwin7\rMOSA005'),(10578,569270545004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','lindows-by','joshhhab@gmail.com','Andrey Burkov','boulevard Komsomolskiy 59-2','Kamensk-Uralskiy','Sverdlovskaya oblast','RUSSIAN FEDERATION','623430','+7-915-290-14-59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 06:23:06',0,NULL,3,1,3,1,'RA184553349CN\r ','lindows-by\rWLAP008'),(10579,759404192011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','lrdslewis','rlewis@agl.com.au','Randall Lewis','Level 22<br>120 Spencer Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 06:30:04',0,NULL,3,1,2,1,'\\  ','lrdslewis'),(10580,619157297013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','klmvalex','klmvlksndr@rambler.ru','Aleksandr Klimov','ul. Shkuljova, d.3, kv.26','Moskva','','RUSSIAN FEDERATION','109390','+79264906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 07:06:33',0,NULL,3,1,3,1,'RA184553264CN\r ','klmvalex\rWLIN014'),(10581,842584053012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','rahome22','raffi155@verizon.net','Aline K','5025 N Treanor Ave','Covina','CA','UNITED STATES','91724-1425','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 07:26:30',0,NULL,3,1,1,1,'\\  ','rahome22'),(10582,759413107011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',147.99,'eastar4','izoaraman','izoara@hotmail.com','BYUNG-HOON KONG','Unit 48 / 12 Chaliis St','Dickson','Australian Capital Territory','AUSTRALIA','2602','0432430174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 07:30:14',0,NULL,3,1,4,1,'YW867471955CN ','izoaraman\r燕文告知无人领取 需要邮件▲'),(10583,619166347013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','awesome_healer','tomthpom@hotmail.com','Tom Heal','3 myoora St','Pymble','New South Wales','AUSTRALIA','2073','0294889790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 07:56:15',0,NULL,3,1,2,1,'\\  ','awesome_healer'),(10584,842592313012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',63.98,'eastar4uk','cecholda','ogronier@gmail.com','Dr Gronier','6, rue des Cigognes','Strasbourg','Alsace','FRANCE','67000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 07:56:34',0,NULL,3,1,3,1,'RA184553865CN\r ','cecholda\rGLOT005\r投影仪兼容眼镜'),(10585,562848064003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','059152470','seven2@walla.co.il','BAT-SHEVA MARK','AREY BEN ELIEZER 9<br>HADAR GANIM','PETACH-TIKVA','','ISRAEL','49744','+972-3-9337251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 07:56:43',0,NULL,3,1,3,1,'RA184553281CN\r ','059152470\rOMHJ001'),(10586,842595895012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','vpoz1','boleslaw@posmyk.com','boleslaw m posmyk','havelock grange practice, one life<br>park road','hartlepool','Cleveland','UNITED KINGDOM','ts24 7pw','01740644505','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 08:06:02',0,NULL,3,1,3,1,'RA184553953CN\r ','vpoz1\rGLOT005\r投影仪兼容眼镜'),(10587,619172431013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','qchivr','quentin.dechivre@gmail.com','Quentin de Chivré','42, rue des Martyrs','Paris','Île-de-France','FRANCE','75009','0614615842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 08:25:37',0,NULL,3,1,3,1,'RA184553468CN\r ','qchivr\rMOSA005'),(10588,759440492011,320586620486,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOSA001',58.99,'eastar4','flashy69','myglock17@gmail.com','MARIOS MICHAIL','GRIGORIOU KOUSIDOU 7','ZOGRAFOU','ATHENS, GREECE','GREECE','15773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 08:46:31',0,NULL,3,1,3,1,'RA184553732CN\r ','flashy69\rMOSA001'),(10589,759456556011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','mcbuyer123','mcarol.pearce1@sky.com','carol pearce','15 marshall avenue<br>hall green','Wakefield','West Yorkshire','UNITED KINGDOM','wf4 3ld','01924258919','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 09:30:56',0,NULL,3,1,3,1,'RA184553573CN\r ','mcbuyer123\rHBPH002'),(10590,842629617012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','xtrimal','xtrimal@gmail.com','Aleksandr Vasyanin','Egerskiy bulvar , 47 - 5','Cheboksary','Chuvashiya','RUSSIAN FEDERATION','428027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 09:39:43',0,NULL,3,1,2,1,'\\  ','xtrimal'),(10591,759481293011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',16,'BALO001',191.84,'eastar4','bw2045','trent@avitechusa.net','TD Johnson','1314 E Las Olas Blvd<br># 288','Fort Lauderdale','FL','UNITED STATES','33301-2334','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 10:38:14',0,NULL,3,1,1,1,'\\  ','bw2045'),(10592,619211060013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','emilystubbs','nonacarolina@yahoo.com','emily stubbs','28B Hardy Ave','North Ocean Shores','New South Wales','AUSTRALIA','2483','0431298572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 11:50:02',0,NULL,3,1,3,1,'RA184553896CN\r ','emilystubbs\rHBPH005'),(10593,619241600013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',20,'CASS001',174,'eastar4','tenna69','tenna@manxmedia.com.au','George Maniakis','140 Cobden Street','South Melbourne','Victoria','AUSTRALIA','3205','0396992194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 12:45:35',0,NULL,3,1,4,1,'YW867471830CN ','tenna69'),(10594,619243460013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','unitorian','panagiotis_h@hotmail.com','Panagiotis Hatzianastassiou','Digeni Akrita 46','Keratsini','Piraeus','GREECE','18755','00302104009911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 12:51:02',0,NULL,3,1,2,1,'\\  ','unitorian'),(10595,619255656013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','johnnyrockets007','jtomala64@hotmail.com','John Tomala','55 Chelmsford Ave','Port Kennedy','Western Australia','AUSTRALIA','6172','0895930648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 13:28:56',0,NULL,3,1,3,1,'RA184553825CN\r ','johnnyrockets007\rGLOT001*3\r兼容型3D眼镜 通用型'),(10596,619257346013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','manolisev','manolisev@yahoo.es','Manuel Arguelles Escribano','C/ Porrassa, nº 7 - Esc. 4  Pta. 3-4','L\'Hospitalet de L\'Infant','Cataluña','SPAIN','43890','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 13:34:32',0,NULL,3,1,2,1,'\\  ','manolisev'),(10597,759554281011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','kelb75','kelbym75@hotmail.com','Kelby Myers','13 Gunton Cct','ESPERANCE','Western Australia','AUSTRALIA','6450','0400233069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 13:37:25',0,NULL,3,1,2,1,'\\  ','kelb75'),(10598,619260595013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','petr200610','petrzg2006@gmail.com','IRINA SCHERBAKOVA','AVRAMENKO STREET 18 APT.199','ZAPORIZHYA','UKRAINE','UKRAINE','69120','067 972 1315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 13:43:09',0,NULL,3,1,2,1,'\\  ','petr200610'),(10599,842742471012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','gats001','brassardg@videotron.ca','Gaetan Brassard','1495 rue du Vignoble','Québec','QC','CANADA','G2L1P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 13:57:20',0,NULL,3,1,3,1,'RA184588175CN\r ','gats001\rGLSG001*3'),(10600,759578624011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','carlrc','carlrc12@gmail.com','On Line Sales','173 Monmouth Rd','Oakhurst','NJ','UNITED STATES','07755','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 14:27:34',0,NULL,3,1,1,1,'\\  ','carlrc'),(10601,842782976012,220763389170,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',27.9,'eastar4uk','saulius19780330','ravotas@one.lt','SAULIUS','NESS FARM,NESS ROAD,ERWARTON','IPSWICH','Suffolk','UNITED KINGDOM','IP9 1LW','07523820757','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 15:07:46',0,NULL,3,1,3,1,'RA184553406CN\r ','saulius19780330\rWWSI004+ANCN001'),(10602,759601850011,320735074988,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',48.99,'eastar4uk','maddoc1380','maddoc5979@yahoo.com','Madhu Mahadevan','Medibank Health Solutions<br>200 Elizabeth Street','Hobart','Tasmania','AUSTRALIA','7000','0411289568','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 15:10:18',0,NULL,3,1,3,1,'RA184553998CN\r ','maddoc1380\rGLOT002+GLOT003'),(10603,842800683012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','danny.ml','danny-ml@hotmail.com','Daniel Monroy Lopez','Cerro el Vigilante #109 Col. Romero de Terreros','Mexico','Distrito Federal','MEXICO','04310','(55) 5539 0837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 15:41:08',0,NULL,3,1,2,1,'\\  ','danny.ml'),(10604,619316639013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','mgkeck','mick@keckfamily.org','Micky Keck','1109 Springfield Pike','Wyoming','OH','UNITED STATES','45215-2103','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 16:01:07',0,NULL,3,1,1,1,'\\  ','mgkeck'),(10605,619318197013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','chlomi86','shlomi986@gmail.com','shlomi zaguri','mevo hasharvitan bilding 6 apatement 13','ashdod','israel','ISRAEL','77566','0543130634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 16:05:07',0,NULL,3,1,2,1,'\\  ','chlomi86'),(10606,619327593013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','roby200687','roby200487@yahoo.com','Robert Bakos','Streiului nr.1 ap.40','Cluj-Napoca','Cluj','ROMANIA','400599','040753055280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 16:23:02',0,NULL,3,1,2,1,'\\  ','roby200687'),(10607,619328395013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','gaetan9313','bibitte01@hotmail.com','gaetan maher','2 kennedy','sept-iles','QC','CANADA','g4r4e7','(418) 962-0425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 16:25:17',0,NULL,3,1,3,1,'RA184553984CN\r ','gaetan9313\rGLOT002+GLOT003'),(10608,759661725011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','garyv810','cooky76@budweiser.com','gary vipond','89 galashields road grindon','sunderland','Tyne and Wear','UNITED KINGDOM','sr4 8jn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 16:44:51',0,NULL,3,1,3,1,'RA184553817CN\r ','garyv810\rGLOT001*3\r兼容型3D眼镜 通用型'),(10609,759667240011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','2010rapide','uprapat@gmail.com','Uprapa Tirananda','954/3 <br>Nakhonchaisri Road','Dusit','Bangkok','THAILAND','10300','660818206983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 16:52:09',0,NULL,3,1,3,1,'RA184588161CN\r ','2010rapide\rGLSG001*2'),(10610,842856781012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','alf19691969','alfonsosierra@hotmail.com','alfonso sierra carvajal','sofia 56, 3ºB','madrid','Madrid','SPAIN','28022','913069146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 16:53:28',0,NULL,3,1,2,1,'\\  ','alf19691969'),(10611,842862559012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','di.jeferson','dijeferson@gmail.com','Jeferson A Santos','Av. Celso Garcia, 1907 - Bl.27 Ap.74<br>Belem','Sao Paulo','Sao Paulo','BRAZIL','03015000','551198882578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 17:05:25',0,NULL,3,1,2,1,'\\  ','di.jeferson'),(10612,759678182011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','xxooe','numsound@gmail.com','hani albader','57 W 86th St<br>apt 2a','new york','NY','UNITED STATES','10024-3661','(212) 947-2641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 17:07:39',0,NULL,3,1,1,1,'\\  ','xxooe'),(10613,759678920011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','lances111','lances@hockenbergs.com','Lance Strecker','8704 W 113th St','Overland Park','KS','UNITED STATES','66210-1725','(913) 544-7140','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 17:11:20',0,NULL,3,1,1,1,'、 ','lances111'),(10614,719542750001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','beth122245','beth1222@insightbb.com','beth clark','4746 shenandoah dr','louisville','KY','UNITED STATES','40241-1749','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 17:12:33',0,NULL,3,1,1,1,'\\  ','beth122245'),(10615,619362414013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','sfas9622','sfascetti@comcast.net','Shirley Fascetti','125 Dyers Stone Drive','Eighty Four','PA','UNITED STATES','15330','(724) 969-1678','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 17:24:42',0,NULL,3,1,1,1,'\\  ','sfas9622'),(10616,759697224011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','championblue','pierre.campion@scarlet.be','Pierre Campion','54, rue du Bourgmestre','Bruxelles','','BELGIUM','1050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 17:30:28',0,NULL,3,1,2,1,'\\  ','championblue'),(10617,842897689012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','nofcking','kubri.ck@siol.net','Andraž Cvar','Gabrsko 62','Trbovlje','PR','SLOVENIA','1420','035643426','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 17:38:30',0,NULL,3,1,2,1,'\\  ','nofcking\rOTHP004'),(10618,759718363011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','paullpaull','paul@thelovejoys.co.uk','Paul A Lovejoy','25 William Place','Stevenage','Hertfordshire','UNITED KINGDOM','SG2 9DJ','07795822412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 17:50:16',0,NULL,3,1,3,1,'RA184553560CN\r ','paullpaull\rHSJA011\r英标'),(10619,842918428012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','nick5*nicholas','nick_1666@hotmail.com','Nicholas Smith','8B Penlee Road<br>Stoke','Plymouth','Devon','UNITED KINGDOM','PL3 4AT','01752563862','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 18:03:38',0,NULL,3,1,3,1,'RA184553905CN\r ','nick5*nicholas\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(10620,759751643011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',88.99,'eastar4','dkkilich','dkkilich@mac.com','Dogan Kilich','101 Chalupa Cir','Del Rio','TX','UNITED STATES','78840','(830) 765-4697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 18:23:04',0,NULL,3,1,1,1,'\\  ','dkkilich\r兼容型3D眼镜  samsung 专用'),(10621,759757294011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',177.99,'eastar4','guybenari','guy_benari@hotmail.com','Guy Ben Ari','935 Marina Village Pkwy<br>Edward Jones','Alameda','CA','UNITED STATES','94501-1048','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-09-04 18:47:08',0,NULL,3,1,1,1,'\\  ','guybenari'),(10622,842971361012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','salvador68jughead','stevebenn68@hotmail.com','Steve Benn','Aurora Cottage<br>Wantage Road,','Hungerford','Berkshire','UNITED KINGDOM','RG17 0PN','01488686452','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 18:55:51',0,NULL,3,1,17,0,NULL,'salvador68jughead'),(10623,759783903011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',35.9,'eastar4uk','salvador68jughead','stevebenn68@hotmail.com','Steve Benn','Aurora Cottage<br>Wantage Road,','Hungerford','Berkshire','UNITED KINGDOM','RG17 0PN','01488686452','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 19:02:01',0,NULL,3,1,3,1,' RA184587387CN\r','salvador68jughead\rMOLO005+MOLO009\r再发一个罗技 MX1000 mouse used'),(10624,759809451011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','benaskew2222','benaskew@hotmail.com','Ben Askew-Renaut','Calle Ibiza 32, 6-C','Madrid','Madrid','SPAIN','28009','696314431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 19:29:29',0,NULL,3,1,2,1,'\\  ','benaskew2222'),(10625,619466623013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','kcwizkid','aheidari@sc.rr.com','Ahmad Heidari','5 Brittany way','Columbia','SC','UNITED STATES','29212-0938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 20:12:51',0,NULL,3,1,1,1,'\\  ','kcwizkid'),(10626,759818053011,320520042459,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',17.5,'eastar4','jyna44','jyneau@free.fr','NEAU JEAN-YVES','6 AVENUE DES JONQUILLES','BOUGUENAIS','loire atlantique','FRANCE','44340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 19:45:52',0,NULL,3,1,2,1,'\\  ','jyna44'),(10627,757619008011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','calabriarush','adrenalinepush@aol.com','Ron Cornforth','2626 8th ave','Greeley','CO','UNITED STATES','80631-8412','(970) 290-4062','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 20:50:48',0,NULL,3,1,1,1,'\\  ','calabriarush'),(10628,759871045011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',177.99,'eastar4','pbbforlife','pbbforlife@gmail.com','Mladen Topic','Pavlovac bb','Banja Luka','Bosnia And Herzegovina','BOSNIA AND HERZEGOVINA','78000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 21:09:37',0,NULL,3,1,3,1,'RA184553556CN\r ','pbbforlife\rOTSO004*3'),(10629,759875138011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','frasergm','frasergm@aol.com','George Fraser','The Pool House<br>Cooksey Green Lane','cooksey Green','Worcestershire','UNITED KINGDOM','B61 9EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 21:14:42',0,NULL,3,1,3,1,'RA184553587CN\r ','frasergm\rHBPH002'),(10630,843075743012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.4,'eastar4','yabeshakee039297213','stephenzucker@yahoo.com','STEPHEN ZUCKER','813 Dulce Tierra Dr','EL PASO','TX','UNITED STATES','79912','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 21:15:49',0,NULL,3,1,1,1,'\\  ','yabeshakee039297213\racer 5pin1.25 15cm'),(10631,619497243013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','alsatgitgel','sertac.keles@gmail.com','Sertac Keles','Inonu Bulvari, No 36, Hazine Mustesarligi<br>Oda No 702, Emek','Ankara','N/A','TURKEY','06510','(905) 325-9646 ext.: 69','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 21:33:25',0,NULL,3,1,3,1,'RA184553423CN\r ','alsatgitgel\rMOSA005'),(10632,759888453011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','mickybeautron','mickireland@hotmail.com','michael morris','6 meathville tce<br>long lane','dublin 8','Dublin','IRELAND','8','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 21:45:36',0,NULL,3,1,2,1,'\\  ','mickybeautron\rCACN004'),(10633,759888454011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','panamacarl','carl.dismukes@gmail.com','Carl Dismukes','5055 North Point Parkway<br>4th Floor','Alpharetta','GA','UNITED STATES','30022','(404) 277-2213','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 21:45:52',0,NULL,3,1,1,1,'\\  ','panamacarl\r新地址\rCarl Dismukes\r402 Azalea St.\rPanama City Beach, FL 32407\r'),(10634,843100390012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','walters227','walters227@hotmail.com','brad walters','95 eastman ave','london','ON','CANADA','n5w 2m5','(519) 451-9108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 22:11:01',0,NULL,3,1,3,1,'RA184588246CN\r ','walters227\rGLSG001*3'),(10635,843093200012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','nucliozephyr','matthew@tellier.co.uk','Matthew Tellier','10 Marina Gardens','Felixstowe','Suffolk','UNITED KINGDOM','IP11 2HW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 21:55:58',0,NULL,3,1,2,1,'\\  ','nucliozephyr\rAcer 5pin1.25 3cm'),(10636,564154193003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','818rudat','srudat@gmail.com','Scott Rudat','12006 Phinney Ave N','Seattle','WA','UNITED STATES','98133-8134','(425) 766-4383','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-04 22:30:21',0,NULL,3,1,1,1,'\\  ','818rudat'),(10637,759911648011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','martijnvr1975','martijnvr@hotmail.com','Martijn van Rooijen','Henri Dunantlaan 203','Apeldoorn','','NETHERLANDS','7312BA','+31628658711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 22:51:00',0,NULL,3,1,2,1,'\\  ','martijnvr1975\r(2\"44pin)'),(10638,619521250013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',1,'HBPH004',9.99,'eastar4','moneyboys','jmackey61@gmail.com','Jennifer M Mackey','rr 1','Chatsworth','ON','CANADA','n0h 1g0','(519) 372-7340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 23:02:31',0,NULL,3,1,2,1,'\\  ','moneyboys'),(10639,843120509012,220759427766,'New SAMSUNG WMN1000C ULTRA SLIM WALLMOUNT LED TV  60-65',1,'MOSA003',39.99,'eastar4uk','craigr247','craigr@hacel.co.uk','Craig Russell','Hacel Lighting<br>The Silverlink','Wallsend','Newcastle Upon Tyne','UNITED KINGDOM','NE28 9ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 23:06:56',0,NULL,3,1,3,1,'RA184553658CN\r ','craigr247\rMOSA003'),(10640,759946865011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','pepadumi2011','pepadumi@yahoo.com.br','Gustavo Sylvestrin','RUA RIO GRANDE DO SUL, 116<br>Apto. 54','Curitiba','Parana','BRAZIL','80620-080','005541 98409977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 00:57:54',0,NULL,3,1,3,1,'RA184553542CN\r ','pepadumi2011\rOTSO004'),(10641,843173237012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','vpol30','vpmira8@gmail.com','Vadim Polyakov','156 Coral Ln','Wheeling','IL','UNITED STATES','60090-3944','(847) 845-2883','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 01:49:54',0,NULL,3,1,1,1,'\\  ','vpol30\r兼容型3D眼镜 通用型'),(10642,759964407011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','sugabear00','sugabear@earthlink.net','Doug Wilson','32 Harding Ter, 2nd fl.','Newark','NJ','UNITED STATES','07112','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 01:53:19',0,NULL,3,1,1,1,'\\  ','sugabear00'),(10643,759977457011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','ed_sears','edsears@tampabay.rr.com','Edward Sears','401 S Shore Crest Dr','Tampa','FL','UNITED STATES','33609-3625','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 02:42:47',0,NULL,3,1,1,1,'\\  ','ed_sears'),(10644,719815781001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','naitsirhc87','c.berrios718@hotmail.com','Christian Berrios','2801 Dewey ave<br>Apt 2D','Bronx','NY','UNITED STATES','10465-2817','(347) 657-0882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 03:00:34',0,NULL,3,1,1,1,'\\  ','naitsirhc87'),(10645,564211934003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','milanberjan','9588333@graniteschools.com','Milan, Miljan Berjan','3833 Clare Dr','West Valley','UT','UNITED STATES','84119-5759','(801) 635-4362','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 03:35:15',0,NULL,3,1,1,1,'\\  ','milanberjan'),(10646,759990131011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','vavd8421','vlad.avdeev@gmail.com','Vladimir Avdeyev','218-b Floyd Ave.','Toronto','ON','CANADA','M4J 2J1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 03:35:37',0,NULL,3,1,2,1,'\\  ','vavd8421'),(10647,0,230667814104,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',43.99,'eastar4','adamandcassandra','adamandcassandra@hotmail.com','Adam Storey','307 Mawson Lakes Blvd','Mawson Lakes','South Australia','AUSTRALIA','5095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 03:42:44',0,NULL,3,1,3,1,'RA184587988CN\r ','adamandcassandra\rGLSG001'),(10648,619583634013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','tremie67','eimertvdmeer@gmail.com','Eimert van der Meer','Zanddijk 132','Rozenburg','','NETHERLANDS','3181HW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 03:44:19',0,NULL,3,1,2,1,'\\  ','tremie67'),(10649,759995027011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','warrenda','warrend@invisibleagent.com','Warren Daly','OPUS Cambodia<br>Suite 3FN1, VTRUST OFFICE CENTRE','PARKWAY SQUARE, PHNOM PENH','','CAMBODIA','0000','089288107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 04:01:12',0,NULL,3,1,2,1,'\\  ','warrenda\r(2\"44pin)'),(10650,760001726011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','frump_er','rik@taylor.to','Rik Taylor','c/o School of IT and Electrical Engineering<br>Room 78-516, GP South Building, Staff House Road','University of Queensland','Queensland','AUSTRALIA','4072','61413748408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 04:34:18',0,NULL,3,1,2,1,'\\  ','frump_er'),(10651,564218119003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','robertdkatzmd1','rdkatzmd@earthlink.net','ROBERT KATZ','1717 Comstock Ave','LOS ANGELES','CA','UNITED STATES','90024-5322','(310) 779-4741','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 04:46:43',0,NULL,5,0,18,0,' ','robertdkatzmd1\r\rpaypal付款有问题 款已经撤\r'),(10652,843221246012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',70.99,'eastar4uk','iconaustralia','presidentsydneycycling@yahoo.com.au','Barry Doosey','3/21 Wellington St','Bondi','New South Wales','AUSTRALIA','2026','0411014144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 04:59:13',0,NULL,3,1,3,1,'RA184587081CN\r ','iconaustralia\rOTSO004*2'),(10653,843222607012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','sbow9096','stephenbowan@yahoo.com','Stephen Bowan','12959 Palmetto Glade Dr','Jacksonville','FL','UNITED STATES','32246-1075','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 05:03:19',0,NULL,3,1,1,1,'\\  ','sbow9096'),(10654,619607499013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','alexchikoff','alex.chikoff@gmail.com','ALEXEY CHIKOV','Fontanka river 139 31','St. Petersburg','','RUSSIAN FEDERATION','190068','+79213435815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 06:38:01',0,NULL,3,1,3,1,'RA184587020CN\r ','alexchikoff\r欧标\rHSNO019'),(10655,760035178011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','jaslth2009','jaslth@gmail.com','Jason Lim Tow Hee','Block 323, Jurong East Street 31, #08-218','default','','SINGAPORE','600323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 07:28:56',0,NULL,3,1,11,1,'\\ ','jaslth2009\rRELO002'),(10656,760039969011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','pedrosz1','pedro.szlit@gmail.com','Pedro Shalit','POB 2120<br>Almon 7','Ramat Ishay','','ISRAEL','30095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 07:51:30',0,NULL,3,1,3,1,'RA184587104CN\r ','pedrosz1\rRCLO006'),(10657,8881315209432910,111,'Item Title:#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'BR3D003',69.99,'eastar4',' fernandomvo  ','fernandomottavillares@hotmail.com','Fernando M. V. de Oliveira','Rua Padre Joao Manuel 1179apto 11G','Sao Paulo','SP','BRAZIL','01411-001 ','',NULL,NULL,NULL,'2011-09-05 07:57:12',0,NULL,3,1,3,1,'RA184587974CN\r ','BR3D003\r这是eusmile 店的 '),(10658,760039651011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','kmeletis','kmel@otenet.gr','KONSTANTINOS MELETIS','11th OKTOBPIOY 2<br>KTIPIO OTE','KOZANI','KOZANI','GREECE','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 07:59:25',0,NULL,3,1,3,1,'RA184587078CN ','kmeletis\rGLSG001*2'),(10659,8881315209638437,111,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'BR3D003',69.99,'eastar4',' 1842_osman   ','camilloo7@hotmail.com','Mohamad Osman','Hasselkroken 22','langhus','ski','NORWAY','1405 ','',NULL,NULL,NULL,'2011-09-05 08:00:38',0,NULL,3,1,3,1,'RA184587095CN\r ','BR3D003\r这是eusmile 店的  '),(10660,619620398013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','darkklaus','uglydragon@tochka.ru','Nikolay Levashov','Leningradsky prospekt 62 49','Moscow','Moscow','RUSSIAN FEDERATION','125167','+7(916)641-3939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 08:01:37',0,NULL,3,1,2,1,'\\  ','darkklaus'),(10661,843259059012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','dom48223','domorak@nextra.sk','Juraj Domorák','M. R. Štefánika 59','Cífer','','SLOVAK REPUBLIC','91943','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 08:05:04',0,NULL,3,1,2,1,'\\ ','dom48223\r'),(10662,843261931012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','kodavoit','3d@tpg.com.au','Ray Moxom','46 Glenayr Ave','West ryde','New South Wales','AUSTRALIA','2114','61298745447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 08:09:48',0,NULL,3,1,3,1,'RA184587033CN\r ','kodavoit\rGLOT001\r兼容型3D眼镜 通用型'),(10669,843291103012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','saintnickle','nlleather@aol.com','nick leather','15 lewis close,adlington','preston','Lancashire','UNITED KINGDOM','pr74ju','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 09:58:54',0,NULL,3,1,3,1,'RA184587271CN\r ','saintnickle\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(10663,843265918012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',138.99,'eastar4','gravelrash100','gravelrash100@hotmail.com','Mike  Halliday','Thisldo<br>11 Cormack Park','Rothienorman','Aberdeenshire','UNITED KINGDOM','AB51 8GL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 08:25:03',0,NULL,3,1,3,1,'RA184587991CN\r ','gravelrash100\rGLSG001*3'),(10664,619625432013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.95,'eastar4','castiron11','fatihak555@hotmail.com','VEDAT AKKUŞ','MECLİS MAH ŞEHNAZ SOK. NO:6/13','İSTANBUL','SANCAKTEPE','TURKEY','34785','(905) 446-9795 ext.: 03','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 08:57:19',0,NULL,3,1,2,1,'\\ ','castiron11'),(10665,759976299011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','jon14c','chuanjack@hotmail.com','Jonathan Eg','10 Leedon Rd #04-03','default','','SINGAPORE','267833','81836009','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 08:57:52',0,NULL,3,1,11,1,'\\ ','jon14c\r红边优联\rRELO003'),(10666,760061137011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','paul.haywood75','paul.haywood@live.co.uk','Paul Haywood','54 Tunwell Avenue<br>Parson Cross','Sheffield','South Yorkshire','UNITED KINGDOM','S5 9FE','07733042893','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 09:19:02',0,NULL,3,1,3,1,'RA184587170CN\r ','paul.haywood75\rWLAP002'),(10667,843284942012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','nt08jmt','johnthewlis@yahoo.co.uk','John Thewlis','Thistledome, Deer Park Lane','Tavistock','Devon','UNITED KINGDOM','PL19 9HD','01822615174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 09:38:05',0,NULL,3,1,3,1,'RA184587118CN\r ','nt08jmt\rWLAP001+WLAP004'),(10668,619638138013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','alexjlt92','alex.jlt@gmail.com','Alexandra MARCHAL','Appart n 18<br>83 rue de Strasbourg','COURBEVOIE','Île-de-France','FRANCE','92400','0672386220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 09:45:32',0,NULL,3,1,3,1,'RA184587121CN\r ','alexjlt92\rMOSA005'),(10670,760079544011,320520045587,'HP Broadcom BCM94322 bcm4322 half mini PCI-E card+2 an',1,'WLHP002+ANTY001',19.5,'eastar4','naumoid','dnaumov@gmail.com','Dmitry Naumov','Bolshoy Kislovskiy<br>13','Moscow','Moscow region','RUSSIAN FEDERATION','125009','+79166715317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 10:29:31',0,NULL,3,1,2,1,'\\ ','naumoid'),(10671,569722930004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','icbm6715','icbm465@hanmail.net','Won Suk Choi','3-17 Kuwal-2dong Namdong-Ku<br>Inchon South Korea','Inchon','Namdong-Ku','KOREA,REPUBLIC OF','405-222','032-465-6715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 10:33:46',0,NULL,3,1,3,1,'RA184587223CN\r ','icbm6715\rWLDE002'),(10672,760041746011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','amourkmoi','amourkmoi@msn.com','Isabela Oliveira','Av. de la Gare 23','Conthey','','SWITZERLAND','1964','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 10:44:38',0,NULL,3,1,3,1,'RA184587395CN','amourkmoi\rGLSG001*2'),(10673,619649604013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','mc_pavlovski','mariopavlovski@optusnet.com.au','Mario Pavlovski','91 Park Road','Kogarah Bay','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 10:47:10',0,NULL,3,1,3,1,'RA184587152CN\r ','mc_pavlovski\rMOSA004'),(10674,843318105012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','derrammler','andreas_frei@swissonline.ch','Andreas Frei','Nordstrasse 1','Zizers','','SWITZERLAND','7205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 11:28:28',0,NULL,3,1,2,1,NULL,'derrammler'),(10675,619659682013,230641641998,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',15.95,'eastar4','coliwallin','k.packham@sky.com','Kerry Nicholls','15 Moor View Close<br>Meare','Glastonbury','Somerset','UNITED KINGDOM','BA6 9TB','07933739307','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-05 11:36:22',0,NULL,3,1,2,1,'、 ','coliwallin\r换成向日葵 \r折叠伞 一把'),(10676,760103165011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','maikolcorners','yelusl5@hotmail.com','Miguel Ángel Esquinas Requena','c/Polvorin, 19','Villarrobledoº','Castilla-La Mancha','SPAIN','02600','625252147','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 11:50:30',0,NULL,3,1,2,1,'\\ ','maikolcorners\r红边优联'),(10677,619663431013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','kandycane69','kathyl@dodo.com.au','kate larkham','28 allison street','goulburn','New South Wales','AUSTRALIA','2580','0421104401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 11:54:12',0,NULL,3,1,6,1,'EE645685412CN ','kandycane69'),(10678,619668152013,230641641998,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',15.95,'eastar4','ipodelin','elindaemroen@hotmail.no','Elin Dæmroen','Furuvegen 5','FURNES','Ringsaker','NORWAY','2320','+4790657918','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 12:15:01',0,NULL,5,1,2,1,NULL,'ipodelin\r向日葵长柄伞  \r问客户要不要折叠伞\r客户不回复，我们取消订单。'),(10679,760112207011,320730087674,'New Logitech Digital IO Writing Pen +IO notebook',1,'NTLO001+NTLO002',23.99,'eastar4uk','ecodoodah','admin@ecodoodah.com','David Wingfield','93 Longton Avenue','London','London','UNITED KINGDOM','SE26 6RF','2086993107','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 12:19:44',0,NULL,3,1,3,1,'RA184587210CN\r ','ecodoodah\rNTLO001+NTLO002'),(10680,760112276011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',117.99,'eastar4','sabd1753','akz95@hotmail.com','syed ibrahim abdulkader','27 bld henri dunant','gousssainville','Île-de-France','FRANCE','95190','0673724779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 12:21:21',0,NULL,3,1,3,1,'RA184587356CN\r ','sabd1753\rOTSO005*2\r两个粉红色的'),(10681,619676133013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jmxox','jeanmay@mail.com','Jeanmay Kerr-Tang','Unit 14<br>76 Hume Highway','Lansvale','New South Wales','AUSTRALIA','2166','0414328190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 12:49:02',0,NULL,3,1,3,1,'RA184587149CN\r ','jmxox\rMOSA005'),(10682,760124683011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','dekel_unchick','dekel_u@walla.co.il','Dekel Unchick','Almogan 19','Modiin','ID','ISRAEL','71700','089703128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 12:56:48',0,NULL,3,0,2,1,'\\ ','dekel_unchick'),(10683,619680528013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','stjerna2007','mortenstj@gmail.com','Morten Stjernstedt','Smørbukkveien 19','Kongsvinger','Norway','NORWAY','2212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:07:13',0,NULL,3,1,3,1,'RA184587064CN\r ','stjerna2007\rMOSA005'),(10684,843357963012,220815928079,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',19.99,'eastar4uk','contiva','james.hardy.2009@googlemail.com','james hardy','3 blair place','falkirk','Falkirk','UNITED KINGDOM','fk2 7gx','01324611608','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 13:25:50',0,NULL,3,1,3,1,'RA184587245CN\r ','contiva\rOTIN002'),(10685,760138893011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','thmanca','thmanca@yahoo.ca','Ty Huynh','4568 Centretown way','Mississauga','ON','CANADA','l5r 0E2','(416) 846-1405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:41:59',0,NULL,3,1,3,1,'RA184587339CN\r ','thmanca\rOTSO004'),(10686,760134093011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.49,'eastar4','stephenc_01','scilesio@gmail.com','Stephen Cilesio','83 Holborow St','Sydney','New South Wales','AUSTRALIA','2133','0423421463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:48:07',0,NULL,3,1,3,1,'RA184587206CN\r ','stephenc_01\rCASS002+CASS003\r一共买了两条CAB6060\r两条CAB2660'),(10687,760142018011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.49,'eastar4','stephenc_01','scilesio@gmail.com','Stephen Cilesio','83 Holborow St','Sydney','New South Wales','AUSTRALIA','2133','0423421463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:49:01',0,NULL,3,1,17,0,NULL,'stephenc_01'),(10688,619691474013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','72leto72','leto72@yandex.ru','Dmitry Zazybo','Permskaya str. 8-118','Nizhnevartovsk','HMAO-Yugra','RUSSIAN FEDERATION','628624','79226553684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:50:45',0,NULL,3,1,2,1,'\\ ','72leto72'),(10689,760143963011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',16.58,'eastar4','stephenc_01','scilesio@gmail.com','Stephen Cilesio','83 Holborow St','Sydney','New South Wales','AUSTRALIA','2133','0423421463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:54:23',0,NULL,3,1,17,0,NULL,'stephenc_01'),(10690,760146714011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','chenicourt','colin.stephane@ovi.com','Stéphane COLIN','3, rue du Château d\'eau - Chenicourt','SENANTES','Centre','FRANCE','28210','02.37.82.59.52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 14:02:53',0,NULL,3,1,2,1,'\\ ','chenicourt'),(10691,760154713011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',55.98,'eastar4','bldfroger','bldeb1@gmail.com','Kenneth Duncan','451 Brown Chapel Rd','Saint Cloud','FL','UNITED STATES','34769-1935','(407) 301-8148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 14:25:27',0,NULL,3,1,1,1,'\\  ','bldfroger'),(10692,843387729012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','free-fingers','djawhite@gmail.com','David White','30 Falkland Place<br>Temple Herdewyke','Southam','Warwickshire','UNITED KINGDOM','CV47 2UD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 14:41:37',0,NULL,3,1,2,1,'\\ ','free-fingers'),(10693,760162331011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','dipz1284','deepteshbhundia@hotmail.com','Deeptesh Bhundia','27 Brinkburn Gardens','Edgware','Middlesex','UNITED KINGDOM','HA8 5PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 14:45:16',0,NULL,3,1,3,1,'RA184587183CN\r ','dipz1284\rWLAP002'),(10694,843390523012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','jonnie4300','office@jonathanmckee.co.uk','Jonathan Mckee','76 Curragh Road','Coleraine','Londonderry','UNITED KINGDOM','BT514BS','02870868546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 14:47:41',0,NULL,3,1,2,1,'\\ ','jonnie4300'),(10695,760167550011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','lzwobota','zwobota@aol.com','Linda Zwobota','102 Harbour Sound Dr','Chester','MD','UNITED STATES','21619-2524','(410) 643-4160','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 14:58:27',0,NULL,3,1,1,1,'\\  ','lzwobota'),(10696,564330500003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jaypoonblue','jwilson_2222@comcast.net','jamie wilson','60 Watsons Mill Rd','elmer','NJ','UNITED STATES','08318-2918','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 15:01:34',0,NULL,3,1,1,1,'\\ ','jaypoonblue'),(10697,843401492012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',70.99,'eastar4uk','rusinov83','rus666777@gmail.com','Alexander Rusinov','ul.Khabarovskaya<br>15-59','Vladivostok','Primorskiy kray','RUSSIAN FEDERATION','690078','+7-914-678-01-00','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 15:14:22',0,NULL,3,1,3,1,'RA184587311CN\r ','rusinov83\rOTSO004*2'),(10698,843397617012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','ctaptc','ctaptc@teleline.es','JOSE ENRIQUE BRAVO TORRES','Alcalde Díaz Zafra, 10-2ºC','MALAGA','Malaga','SPAIN','29006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 15:15:07',0,NULL,3,1,3,1,'RA184587400CN\r ','ctaptc\rGLOT001\r兼容型3D眼镜 通用型'),(10699,760175627011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','icewoman76','iceipm@aol.com','ISEL PINEDA','620 W 42nd St<br># S28A','NEW YORK','NY','UNITED STATES','10036-2014','(646) 416-2224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 15:18:12',0,NULL,3,1,1,1,'\\  ','icewoman76'),(10700,760178267011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','basketsteffen','steffen@torridal.com','Steffen Sørheim','Slettebrotan 64<br>4715','Øvrebø','','NORWAY','4715','47381314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 15:23:50',0,NULL,3,1,3,1,'RA184587342CN\r ','basketsteffen\rOTSO004\r一共买了两幅'),(10701,760178885011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','basketsteffen','steffen@torridal.com','Steffen Sørheim','Slettebrotan 64<br>4715','Øvrebø','','NORWAY','4715','47381314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 15:25:14',0,NULL,3,1,17,0,NULL,'basketsteffen'),(10702,843408367012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','vicentejairo','vicentealvarez@mac.com','VICENTE JAIRO ALVAREZ FERNANDEZ','CESAR CONTI 22<br>BAJO','O BOLO','Galicia','SPAIN','32373','988323052','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 15:29:23',0,NULL,3,1,2,1,'\\ ','vicentejairo'),(10703,760186234011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','leungcar','carlyleung1@hotmail.com','Carly Leung','Block 13 Flat 17E<br>Chi Fu Fa Yuen','Pokfulam','','HONG KONG','-','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 15:43:30',0,NULL,3,0,2,1,'\\ ','leungcar'),(10704,619724967013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','p.m.a.1985','p_mikhail.85@mail.ru','Mikhail Papko','Baltiyskoe shosse, 116, 33','Kaliningrad','','RUSSIAN FEDERATION','236013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 15:48:56',0,NULL,3,1,3,1,'RA184587475CN\r ','p.m.a.1985\rMOSA004'),(10705,843458284012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','baccy18','alanrbaxter@hotmail.com','Alan Baxter','48 Hawksworth Avenue<br>Forest Town','Mansfield','Nottinghamshire','UNITED KINGDOM','NG19 0DG','01623650794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 17:10:43',0,NULL,3,1,3,1,'RA184587254CN\r ','baccy18\rOTGR001'),(10706,619751913013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',5.96,'eastar4','hidebouss','suzawa@mail.goo.ne.jp','HIDETO SUZAWA','202 inagedai modern corp.<br>31-7 inagedaichou inageku','chiba city','Chiba','JAPAN','2630032','09067049361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 17:11:35',0,NULL,3,1,2,1,'\\ ','hidebouss'),(10707,760229157011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','atolation','rlifas@gmail.com','Roberto Lifschitz','Rua Dom Paulo Pedrosa, 720 - Ap 44','Sao Paulo','SP','BRAZIL','05687001','1130780242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 17:15:49',0,NULL,3,1,3,1,'RA184587325CN\r ','atolation\rOTSO004'),(10708,619756649013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.99,'eastar4','asxcho70','asxcho@mail.ru','Khachatur Asatryan','Mashtots 19/7','Yerevan','','ARMENIA','0002','0037491405415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 17:18:37',0,NULL,3,1,2,1,'\\ ','asxcho70'),(10709,619759664013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','bonsey_digs_you','miss_murderd_my_cat@hotmail.com','Dani Clancy','10 knightwood crescent<br>New malden','surrey','Surrey','UNITED KINGDOM','KT35JS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 17:27:22',0,NULL,3,1,2,1,' \\','bonsey_digs_you'),(10710,843476416012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',140.99,'eastar4uk','innovagolffer','marko.voutilainen85@gmail.com','Marko Voutilainen','Ahorannantie 17','Savonlinna','Oletus','FINLAND','57710','+358503410148','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 17:44:30',0,NULL,3,1,6,1,'EE645685426CN ','innovagolffer'),(10711,843489951012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','jbraddockm','muhkeles@gmail.com','Muhammet Keles','138 Saint Paul\'s Road','Smethwick','West Midlands','UNITED KINGDOM','B66 1HA','07590456900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 18:05:44',0,NULL,3,1,3,1,'RA184587299CN\r ','jbraddockm\rWLAP008'),(10712,760263450011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','chuckboat','chhooper@comcast.net','Chuck Hooper','3225 eastbend Ct','Abingdon','MD','UNITED STATES','21009','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 18:19:25',0,NULL,3,1,1,1,'\\  ','chuckboat'),(10713,760264737011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','nemuiko','neko.nemu.nyan@gmail.com','Verónica Madrigal Fernández','C/ Marcelo Usera 164, 11º 1ª','Madrid','Madrid','SPAIN','28026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 18:21:36',0,NULL,3,1,2,1,'\\ ','nemuiko\r正红色长柄婚庆伞 '),(10714,760266414011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','313877607','malchin.natalia@gmail.com','Natalia Malchin','Iftah 16/7','Tel aviv','none','ISRAEL','67314','52-8373-546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 18:24:55',0,NULL,3,1,2,1,'\\  ','313877607'),(10715,563616135003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','isadore529','johneforges@hotmail.com','Johne Forges','12241 Fairfield House Dr<br>Apt 311','Fairfax','VA','UNITED STATES','22033-3954','(202) 746-6348','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 19:12:06',0,NULL,3,1,1,1,'\\  ','isadore529'),(10716,760294426011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',68.98,'eastar4','jab0417','tboich@gmail.com','Anthony Boich','24403 Ward St','Torrance','CA','UNITED STATES','90505-6516','(310) 999-1569','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 19:13:29',0,NULL,3,1,1,1,'\\  ','jab0417'),(10717,843541597012,220845317453,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',79.99,'eastar4','mockelae1','thomas.moeckel@online.de','Thomas Möckel','Klingenthaler Straße 30 A','Auerbach','','GERMANY','08209','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 19:26:09',0,NULL,3,1,3,1,'RA184587308CN\r ','mockelae1\rHBPH001'),(10718,760303392011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jegers898','jegersfamily@msn.com','Christine M. Jegers','513 Fieldcrest Ct','Sartell','MN','UNITED STATES','56377','(320) 656-1323','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 19:28:57',0,NULL,3,1,1,1,NULL,'jegers898'),(10719,564426443003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','brother.bud','geezluweez@gmail.com','Bud Oertle','103 S Hamlin Dr','ARLINGTON','WA','UNITED STATES','98223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 19:41:40',0,NULL,3,1,1,1,'\\  ','brother.bud'),(10720,760311172011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','folio_mk','mak.kov@gmail.com','Maksym Kovalenko','pr. Pravdy, 106. kv 118','Kiev','','UKRAINE','04208','675055099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 19:44:00',0,NULL,3,1,2,1,'\\ ','folio_mk'),(10721,760313360011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',8.99,'eastar4','denisgyoung','youndeni@gmail.com','denis young','PO Box 151','rexford','NY','UNITED STATES','12148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 19:47:41',0,NULL,3,1,1,1,'\\  ','denisgyoung'),(10722,760311898011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',41.33,'eastar4','sunvus','regvus@gmail.com','Yevgeniy Demyan','Entuziastov st. 24/124','Dubna','RU','RUSSIAN FEDERATION','141983','79265978962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 19:53:32',0,NULL,3,1,3,1,'RA184587197CN\r ','sunvus\rCASS002+TRTT002+CASS003\r一共买了一条CAB2660\r三条CAB6060\r一个210T'),(10723,843581159012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',2,'GLOT004*2',105.98,'eastar4uk','mikegomaz','mikegomaz91@hotmail.co.uk','mike gommersall','86 castlehall','tameworth','Staffordshire','UNITED KINGDOM','b77 2eg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 20:30:10',0,NULL,3,1,3,1,'RA184587268CN\r ','mikegomaz\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(10724,619841036013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','jram3573','jeff@juanmramos.jazztel.es','Juan Manuel Ramos Gálvez','Avenida de Burgos 16B, portal2, 13ºA','Madrid','Madrid','SPAIN','28036','677416321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 20:44:10',0,NULL,3,1,2,1,'\\ ','jram3573'),(10725,619846318013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','noamh001','noamh001@gmail.com','Noam Hameiri','36 Shlonski St.','Tel Aviv','','ISRAEL','69410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:01:57',0,NULL,3,1,3,1,'RA184587237CN\r ','noamh001\rMOLO008\r银色的或红色的'),(10726,843604862012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','tgalvao','telmo.galvao@gmail.com','Telmo Galvão','Rua 9 de agosto de 1990, n12, 4esq','Alverca do Ribatejo','Lisboa','PORTUGAL','2615-279','963258100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:18:49',0,NULL,3,1,2,1,'\\ ','tgalvao'),(10727,760367782011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','doehmke','doehmke@cox.net','Debra Oehmke','1425 E Kay St','Derby','KS','UNITED STATES','67037-3612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 21:36:36',0,NULL,3,1,1,1,'\\  ','doehmke'),(10728,843615561012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','sadik007','sadik@sadik.net','Sadik Crnovrsanin','Bakareviceva Br 1 / 4','Sarajevo','Bosnia','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 21:40:06',0,NULL,3,1,2,1,'\\ ','sadik007\r黑色的'),(10729,564466467003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','rayc2173','ray101@bellsouth.net','ray calloway','211 Dove Dr','vidalia','GA','UNITED STATES','30474-7068','(912) 538-7759','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 21:42:38',0,NULL,3,1,1,1,'\\  ','rayc2173'),(10730,619863644013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','alekscvejic','acvejic@yahoo.fr','Aleksandar CVEJIC','3302, avenue Cedar','Westmount','QC','CANADA','H3Y1Z8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:06:02',0,NULL,3,1,3,1,'RA184587135CN\r ','alekscvejic\rMOSA005'),(10731,843630526012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','lawyers999','peter@legals.com.au','Peter Harris','P.O. Box 2110','Noosaville BC','Queensland','AUSTRALIA','4566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:15:15',0,NULL,3,1,2,1,'\\ ','lawyers999'),(10732,843631795012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','loftec','info@loftec.de','Jürgen Gaube','Goethestr 24','Eisenach','','GERMANY','99817','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 22:18:58',0,NULL,3,1,2,1,'\\ ','loftec\r欧标'),(10733,760391506011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','jsugisa','sugisawa@pacbell.net','Junji Sugisawa','1220 Pierce st','Santa Clara','CA','UNITED STATES','95050','(408) 616-5827','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 22:49:11',0,NULL,3,1,1,1,'\\  ','jsugisa'),(10734,617903834013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',134,'eastar4','christhommo1','cthomas55@optusnet.com.au','Chris Thomas','P O Box 947','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:49:16',0,NULL,3,1,3,1,'RA184587285CN\r ','christhommo1\rHBPH005'),(10735,564482452003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','wise9119','bwise.157@gmail.com','Brian Wise','3597 Motts Place Ct','Canal Winchester','OH','UNITED STATES','43110-9693','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 22:56:16',0,NULL,3,1,1,1,'\\  ','wise9119'),(10736,760395013011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',16.98,'eastar4','jasc-com-au','sales@jasc.com.au','Andrew Campbell','19 John Street','Basin View','New South Wales','AUSTRALIA','2540','0421511747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:59:12',0,NULL,3,1,2,1,'\\','jasc-com-au\r再发一个MX20T'),(10737,843646442012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','jasc-com-au','sales@jasc.com.au','Andrew Campbell','19 John Street','Basin View','New South Wales','AUSTRALIA','2540','0421511747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 23:01:31',0,NULL,3,1,17,0,NULL,'jasc-com-au'),(10738,564486437003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','nocook102','nocook102@aol.com','Steven Jackson','120 Calvary Rd','Oxford','PA','UNITED STATES','19363-1160','(610) 932-8551','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 23:17:12',0,NULL,3,1,1,1,'\\  ','nocook102'),(10739,759337350011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',13.76,'eastar4','kkrider','klongrider11@yahoo.com','kl keele','PO Box 101','greenwood','CA','UNITED STATES','95635-0101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 23:39:43',0,NULL,3,1,1,1,'\\  ','kkrider'),(10740,760417225011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','mattpreston18','mpreston18@yahoo.com','Matt Preston','5050 Meadow Dr','Abilene','TX','UNITED STATES','79606-5333','(325) 513-6909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 00:21:06',0,NULL,3,1,1,1,'\\  ','mattpreston18'),(10741,619900625013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','grammyroberts','tallboypro@earthlink.net','Bryan Roberts','1526 Liberty Pike','Franklin','TN','UNITED STATES','37067-8568','(571) 228-2373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 00:42:18',0,NULL,3,1,1,1,'\\  ','grammyroberts\r兼容型3D眼镜 通用型'),(10742,569954406004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','toni_munozrb','tonimunozrb@gmail.com','Antonio Muñoz de Rivera Bueno','Linde 7, local 14 (peluqueria)','sevilla','Andalucía Ceuta y Melilla','SPAIN','41008','617157850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 01:02:43',0,NULL,3,1,3,1,'RA184587166CN\r ','toni_munozrb\rOTRA001'),(10743,760436226011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','theserious','joshjoshchia@yahoo.com.au','KayWee Chia','5B Wentworth Rd','Eastwood','New South Wales','AUSTRALIA','2122','0298654573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 01:34:35',0,NULL,3,1,2,1,'\\ ','theserious\r澳标'),(10744,843696198012,220815928685,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO003',21.9,'eastar4uk','mawmawwheat','dana.whitfield@centerpointenergy.com','Dana Whitfield','2781 S Columbia Rd<br>Ste D','Bogalusa','LA','UNITED STATES','70427-7962','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mawmawwheat'),(10745,760461276011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','mamolapin','matthew@studio205.net.au','Matthew Tucker','c/- Screen Australia<br>Level 4, 150 William Street','Woolloomooloo, Sydney','New South Wales','AUSTRALIA','2011','0281131033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 03:16:30',0,NULL,3,1,2,1,'\\ ','mamolapin'),(10746,8881315281813354,111,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',0,'eastar4','tagliat123','tagliat@sunysuffolk.edu','thomas tagliaferro','15 longacre ct','port jefferson','NY','UNITED STATES','11777','(631) 655-7306',NULL,NULL,NULL,'2011-09-06 04:03:33',0,NULL,3,1,3,1,'RA184587912CN\r ','补发的\rWLAP002 '),(10747,619942298013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.99,'eastar4','rzepek2007','rzepek2007@gmail.com','pawel czechowicz','7410 W Addison St','chicago','IL','UNITED STATES','60634-3418','(773) 220-1876','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 04:10:44',0,NULL,3,1,1,1,'\\ ','rzepek2007'),(10748,8881315282449417,111,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',0,'eastar4','h3h3548','hani3li@gmail.com','Hani Ali Hassan','House:1291 Road:1538 Block::815','Isa Town','','BAHRAIN','1291','97339084472',NULL,NULL,NULL,'2011-09-06 04:14:09',0,NULL,3,1,3,1,'RA184587926CN\r ','CCGR001 \r补发的'),(10749,8881315282770759,111,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',0,'eastar4','northernlad17','shayneb@sympatico.ca','shayne beattie','63 virginia street','welland','ON','CANADA','l3c7a4','',NULL,NULL,NULL,'2011-09-06 04:19:30',0,NULL,3,1,2,1,'\\ ','补发的 '),(10750,760480562011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','roscog63','rsgulka@shaw.ca','Ross Gulka','916 Chaplin St W','Swift Current','SK','CANADA','s9h 0g5','(306) 773-8332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 05:00:25',0,NULL,3,1,2,1,'\\ ','roscog63'),(10751,760480049011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.99,'eastar4','gosonicaustralia','chad@gosonic.com.au','Chad Rowe','PO Box 8292','Gold Coast Mail Centre','Queensland','AUSTRALIA','4217','0755381745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 04:56:47',0,NULL,3,1,2,1,'\\ ','gosonicaustralia'),(10752,760482537011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','tkirk0819','tkirk0819@yahoo.com','Tiffany Kirk','50 Tyne Ave','Bowling Green','KY','UNITED STATES','42101-0575','(270) 792-9271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 05:20:11',0,NULL,3,1,1,1,'\\','tkirk0819'),(10753,619953367013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','PowerPC-PTY8704','2250 NW 114th Ave<br>Unit 1P','Miami','FL','UNITED STATES','33172-3652','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 05:37:37',0,NULL,3,1,1,1,'\\ ','mauriceshow'),(10754,619956540013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',29.87,'eastar4','jmartosl','jmartos50765@gmail.com','Juan B- Martos Lopez','Calvo Sotelo,89, 5º B','Sarria (Lugo)','Galicia','SPAIN','27600','629151451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 06:03:08',0,NULL,3,1,2,1,'\\ ','jmartosl\r再发一个Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac\r'),(10755,843762354012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','karategal21','jagap1@hotmail.com','Melanie Agapiou','17 Glendye Court<br>corio','Geelong','Victoria','AUSTRALIA','3214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 06:40:04',0,NULL,3,1,3,1,'RA184588008CN\r ','karategal21\rOTSO004*2'),(10756,619967207013,230518594351,'UNLOCKED HS2300 SIERRA MC8775 3G for Dell/lenovo/Ace​r',1,'WWSI001',30.99,'eastar4','rolandoespiritu','rolando.espiritu@gmail.com','Zenaida J. Espiritu','Block 31 lot 12 Kimberly<br>Vista Verde North Novaliches','Quezon City','','PHILIPPINES','1422','6329842587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 07:22:39',0,NULL,3,1,3,1,'RA184587943CN\r ','rolandoespiritu\rWWSI001'),(10757,570010104004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',26.99,'cnfaner','gok_2007','ebay@kvernstuen.no','Geir Ottar Kvernstuen','Ragna Nielsens vei 21','Oslo','Oslo','NORWAY','0592','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 07:27:42',0,NULL,3,1,3,1,'RA184587930CN\r ','gok_2007\rHSJA010\r欧标'),(10758,702761917008,180699002013,'New Griffin PowerJolt Dual USB Micro Car Charger track#',1,'CCGR001',8.88,'au-buy','al4onok13','al4onok39@gmail.com','Alla Anoshina','Severnyy bul\'var, 1, 56','Moscow','Russian Federation','RUSSIAN FEDERATION','127566','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 07:51:05',0,NULL,3,1,3,1,'RA184587872CN ','al4onok13\rCCGR001'),(10759,618904107013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','vda76','vda_vork@mail.ru','Dmitry Voronov','Shaumyana st.<br>house 20/1 flat 15','Taganrog','Rostov region','RUSSIAN FEDERATION','347909','+79281274110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 07:55:14',0,NULL,3,1,2,1,'\\ ','vda76'),(10760,8881315296879731,111,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',50,'ANCN001',100,'eastar4','akarama','garantitek@gmail.com','Mouin Abdallah','Uhlandstr. 2    Keine Nachbarschaftsabgabe','Kleinblittersdorf','','GERMANY','66271','',NULL,NULL,NULL,'2011-09-06 08:14:39',0,NULL,3,1,3,1,'RA184587869CN ','ANCN001 '),(10761,760527600011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.99,'eastar4','4174ferdi','bettyandferdi53@gmail.com','Ferdi van de Wetering','245/2 Falcon Way','Tweed Heads South','New South Wales','AUSTRALIA','2486','0414812907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 08:55:55',0,NULL,3,1,2,1,'\\ ','4174ferdi'),(10762,619979756013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','toanhangbangben','atchiller@yahoo.com.au','anton Doan','65 Sackville St','Fairfield','New South Wales','AUSTRALIA','2165','0420955516','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:02:18',0,NULL,3,1,6,1,'EE645685545CN ','toanhangbangben'),(10763,619979415013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','forta2006','rillettes@ebuyclub.com','allan fort','1 RUE DES BLEUETS<br>LA GERBRIE','DOMPIERRE SUR CHARENTE','Poitou-Charentes','FRANCE','17610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:04:53',0,NULL,3,1,2,1,'\\ ','forta2006'),(10764,760531965011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',59.98,'eastar4','benjr07','benjrmarine@msn.com','Ben G Pelzel Jr','6333 E. Mockingbird Ln.<br>Ste 729','Dallas','TX','UNITED STATES','75214-2316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 09:11:19',0,NULL,3,1,1,1,'\\ ','benjr07'),(10765,843802676012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','china_russell','rlathomas@bigpond.com','Russell Thomas','20 Warranilla Avenue','Rosebud','Victoria','AUSTRALIA','3939','0359868617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:25:08',0,NULL,3,1,2,1,'\\ ','china_russell'),(10766,619982604013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','karolisarbis','karolis.arbaciauskas@gmail.com','Karolis Arbaciauskas','Gardino 25','Alytus','LT','LITHUANIA','62154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:38:37',0,NULL,3,1,2,1,'\\ ','karolisarbis'),(10767,760540535011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','eshoppingshop','wyau78@yahoo.com','Wing-Yip Yau','Unit 3/17 Mallard Way Cannington','Perth','Western Australia','AUSTRALIA','6107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:46:21',0,NULL,3,1,2,1,'\\ ','eshoppingshop'),(10768,843821743012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',11,'CASS003',93.39,'eastar4','vernong5380','vernongun@hotmail.com','Vernon Gunawardana','No 27<br>Chishlom cr','Narrewareen South','Victoria','AUSTRALIA','3805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 10:40:57',0,NULL,3,1,4,1,'YW865546184CN ','vernong5380\rCAB-6060\r'),(10769,719403902001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','russelhammond','alyzwunderland@aol.com','michelle schnee','763 quailwoods dr','loveland','OH','UNITED STATES','45140-6906','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 10:45:15',0,NULL,3,1,1,1,'\\  ','russelhammond'),(10770,760559536011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','james_d','mivan_tg@yahoo.de','Ivan Mestrovic','Posthornweg 11','Mannheim','Baden-Württemberg','GERMANY','68219','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 10:59:07',0,NULL,3,1,2,1,'\\  ','james_d'),(10771,620006264013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','ac9475','chakas40@hotmail.com','Arpan Chakravarti','33/15 Coranderrk Street<br>City','Canberra','Australian Capital Territory','AUSTRALIA','2600','0421320067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 11:07:41',0,NULL,3,1,3,1,'RA184587458CN\r ','ac9475\rGLOT001*3\r兼容型3D眼镜 通用型'),(10772,843827885012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','b3bel','belaciano@012.net.il','Biniamin Belaciano','Rehov Hanita 85<br>APT 4','Haifa','','ISRAEL','32446','(972) 774-5200 ext.: 46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 11:18:02',0,NULL,3,1,2,1,'\\  ','b3bel'),(10773,843839649012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','triominos.ru','admin@triominos.ru','Stepan Chizhov','ul.B.Serpuhovskaya 34/36-6','Moscow','','RUSSIAN FEDERATION','115093','926 2232876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 11:39:08',0,NULL,3,1,2,1,'\\  ','triominos.ru\r黑色的'),(10774,720368687001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','richard1697honda','richard.silva@ntlworld.com','richard silva','121 birchwood hill','leeds','West Yorkshire','UNITED KINGDOM','ls178nt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 11:41:03',0,NULL,3,1,3,1,'RA184587577CN\r ','richard1697honda\rBR3D008'),(10775,569095757004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','zejkeee','glsoldier@yandex.ru','Sergey Istominov','st. Blagoeva 4, fl. 110','Krasnodar','Krasnodar region','RUSSIAN FEDERATION','350065','+7 (961) 51-606-44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 11:43:47',0,NULL,3,1,3,1,'RA184587546CN\r ','zejkeee\rOTRA001'),(10776,620023788013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','sallybear_07','amadeus0777@hotmail.com','P Roberts','1 Gosford Street<br>Hectorville','Adelaide','South Australia','AUSTRALIA','5073','0417841190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 12:27:05',0,NULL,3,1,2,1,'\\  ','sallybear_07'),(10777,760587505011,320730088138,'New Replaceable Shell for logitech MX Air Mouse',1,'SHLO001',11.5,'eastar4uk','listsuk','ebay@listsuk.com','Dennis Brown','Bears Cottage<br>58 Upper Park Road','Camberley','Surrey','UNITED KINGDOM','GU15 2EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 12:32:45',0,NULL,3,1,3,1,'RA184587625CN\r ','listsuk\rSHLO001'),(10778,720385583001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','presingd','presingdj@hotmail.com','Duane Presing','9 Scarborough Ct','Stafford','VA','UNITED STATES','22554','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 12:38:46',0,NULL,3,1,1,1,'\\  ','presingd'),(10779,843862207012,220455473916,'HP DV2000 DV2100 DV2200  Bluetooth Module 2.0+ cable',1,'BTHP2003',9.9,'eastar4','orguborgu','fkmaia@gmail.com','Filipe Kunzler de Oliveira Maia','SQN 213 Bloco i ap 413<br>Asa Norte','Brasilia','Distrito Federal','BRAZIL','70872-090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 12:39:43',0,NULL,3,1,2,1,NULL,'orguborgu\rHP 8pin 1.0 12cm '),(10780,760594172011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','lindenwood0','trelaire@earthlink.net','Dr. Kathleen Speeth','900 Linden Road','Chapel HIll','NC','UNITED STATES','27517','(919) 933-1727','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 12:54:30',0,NULL,3,1,1,1,'\\  ','lindenwood0'),(10781,760598163011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','vojtasks','vojta.tranta@volny.cz','Vojtěch Tranta','Volyňská 12','Prague 10','Prague','CZECH REPUBLIC','100 00','+420 604 927 521','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 13:06:23',0,NULL,3,1,2,1,'\\  ','vojtasks\r红边优联'),(10782,843880533012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',2,'HSSE006',79.8,'eastar4uk','items2buy4','beammeup@bigpond.net.au','Scott Ellis','28 Laura St','Highgate Hill','Queensland','AUSTRALIA','4101','0734551363','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 13:32:59',0,NULL,3,1,3,1,'RA184587682CN\r ','items2buy4\r澳标\rHSSE006'),(10783,843880489012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','lynxdar','iren_energodar@inbox.ru','Iryna Zagorulko','Skifskaya str. 20, ap.11','Energodar','Zaporozhye region','UKRAINE','71504','0667435861','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 13:36:42',0,NULL,3,1,3,1,'RA184587427CN\r ','lynxdar\rMOMI001'),(10784,760609653011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','mullie68','alan.mullett@uwa.edu.au','Alan Mullett','16 Lyndoch Crescent','Greenwood','Western Australia','AUSTRALIA','6024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 13:40:49',0,NULL,3,1,2,1,'\\  ','mullie68'),(10785,564631039003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','joe_big','frank@cotto.com.au','Frank Cecere','68b Woodville Road','Adelaide','South Australia','AUSTRALIA','5011','0403237605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 13:58:51',0,NULL,3,1,3,1,'RA184587563CN\r ','joe_big\rHSMO019\r澳标'),(10786,570084284004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','mercefriken','liggunna@hotmail.com','Bent Magnussen','Nordhagen 25','Bergen','Haukeland','NORWAY','5268','+4755244597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:09:22',0,NULL,3,1,3,1,'RA184587461CN ','mercefriken\rBALO007'),(10787,620049260013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Pratt (Target Container), Inc.','3610 ATLANTA INDUSTRIAL DR NW','Atlanta','GA','UNITED STATES','30331-1028','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:12:32',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10788,620051364013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Anne Alexander','3839 SPINNAKER CT','FREMONT','CA','UNITED STATES','94538-6537','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:19:14',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10789,620052132013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','kevin mattern			 ENID, OK','4109 ROSE TREE LN','Enid','OK','UNITED STATES','73703-3650','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:21:44',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10790,620052782013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Peter Pokolev','702 H St NW<br>Fl 2nd','WASHINGTON','DC','UNITED STATES','20001-3874','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:24:56',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10791,620053551013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','george knapp','23500 Cristo Rey Dr<br>Unit 312D','cupertino','CA','UNITED STATES','95014-6527','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:29:23',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10792,0,120773425254,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',18.6,'buysia','bud788','dtfreeden@sasktel.net','Duane Freeden','Box 533','Lampman','SK','CANADA','S0C 1N0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:31:19',0,NULL,3,1,3,1,'RA184587679CN\r ','bud788\rBR3D007'),(10793,620054657013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Fernando C Ogando','8529 Villa La Jolla Dr<br>Apto H','La Jolla','CA','UNITED STATES','92037-2399','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:33:12',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10794,620055950013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Liz Petrides , NJ','1551 Deer Run Dr','Manasquan','NJ','UNITED STATES','08736-2501','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:36:54',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10795,843903880012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','avesave','lelkipasztor@hotmail.com','Gyorgy A Cseh','13115 Woodward Dr','Hudson','FL','UNITED STATES','34667-6957','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:39:05',0,NULL,3,1,1,1,'\\  ','avesave'),(10796,843907461012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','hannahkanggg','hannah.k4ng@gmail.com','Hannah Kang','UR 2520<br>28 Westhampton Way','University of Richmond','VA','UNITED STATES','23173-0001','(213) 434-0939','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:55:42',0,NULL,3,0,1,1,'\\  ','hannahkanggg\r已入库'),(10797,760636539011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',93.98,'eastar4','willemy2006','wilandjen@msn.com','andre willemy','01 rue de la pomponnette','le mee sur seine','Île-de-France','FRANCE','77350','0170095577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:57:20',0,NULL,3,1,3,1,'RA184587360CN\r ','willemy2006\rGLSG001'),(10798,760637030011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',27.99,'eastar4','ncsfl2000','om@ncs.net','National Computer Solutions','7205 NW 68th St<br>Ste 4','Miami','FL','UNITED STATES','33166-3016','(305) 805-9003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 14:59:19',0,NULL,3,1,1,1,'\\  ','ncsfl2000'),(10799,843917101012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',184.99,'eastar4','robflyer','robmeyer@1scom.net','Robert A, Meyer','11900 Copper Creek Dr','Keller','TX','UNITED STATES','76244-4561','(817) 821-1541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 15:08:57',0,NULL,3,1,6,1,'EE645685531CN ','robflyer'),(10800,760634821011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','computeralliance','sales@computeralliance.co.uk','Faisal Noman','PC<br>Unit 3, 82-96 Old Kent Road','London','London','UNITED KINGDOM','SE1 4NX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 15:11:51',0,NULL,3,1,3,1,'RA184587529CN\r ','computeralliance\rWLAP002'),(10801,843924804012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',12.99,'eastar4','maryh1079','hawkes.josh@googlemail.com','colin page','11 the highway lewes road','brighton','East Sussex','UNITED KINGDOM','bn2 4gb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 15:26:27',0,NULL,3,1,2,1,'\\  ','maryh1079'),(10802,843929428012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','gmatthews73gerrard','gednikki2000@yahoo.co.uk','gerrard matthews','7 WOBURN CLOSE','liverpool','Merseyside','UNITED KINGDOM','L13 6RP','01512843426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 15:37:09',0,NULL,3,1,2,1,'\\  ','gmatthews73gerrard'),(10803,620077729013,230622774836,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.9,'eastar4','petermswart','pmswart@hotmail.com','Peter Swart','2000 West Loop S<br>P/A Panachem Ste 2020','Houston','TX','UNITED STATES','77027','(713) 993-0900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 15:54:12',0,NULL,3,1,1,1,'\\  ','petermswart\r蓝牙版 '),(10804,760655595011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bthelm01','bthelm01@yahoo.com','Brian T Helm','3762 Old South 5','Camdenton','MO','UNITED STATES','65020','(573) 346-3572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:00:42',0,NULL,3,1,1,1,'\\  ','bthelm01'),(10805,620057882013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','John Hammervold','455 ARDATH DR','GRANTS PASS','OR','UNITED STATES','97526-6805','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:02:25',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10806,760662979011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','scottydog0797','jon_rudge@hotmail.co.uk','Jonathan Rudge','Lyncroft, Badley Wood<br>Whitbourne','WORCESTER','Worcestershire','UNITED KINGDOM','WR65SJ','07971566938','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 16:06:34',0,NULL,3,1,3,1,'RA184587585CN\r ','scottydog0797\rMOAP001'),(10807,760658628011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','candace4848','lovely_h_k@yahoo.com','candace bodnar','728 E 1st St','hazleton','PA','UNITED STATES','18201','(570) 459-4442','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:06:57',0,NULL,3,1,1,1,'\\  ','candace4848'),(10808,620082011013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Wayne Kryduba','1 Twins Way<br>Minnesota Twins Baseball Club','Minneapolis','MN','UNITED STATES','55403-1418','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:08:47',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10809,620083515013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','beverly ator','25101 Bear Valley Rd<br>PMB 169','TEHACHAPI','CA','UNITED STATES','93561-8311','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:14:29',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10810,620084878013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Claudia Arenas','9935 NW 88th Ave','Medley','FL','UNITED STATES','33178-1450','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:18:22',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10811,620086072013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','John C Cash','242 W Main St<br># 406','Hendersonville','TN','UNITED STATES','37075-3318','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:21:52',0,NULL,3,1,1,1,'\\  ','mauriceshow'),(10812,760671919011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','a.mathieu20','a.mathieu@videotron.ca','Andre Mathieu','607, 39e Avenue','St-Jerome','QC','CANADA','J7Z2G2','(514) 824-7678','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 16:25:23',0,NULL,3,1,17,0,NULL,'a.mathieu20'),(10813,620088326013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','olganik3','9567756@gmail.com','Olga Nikolaeva','2-Murinsky, d.15, kv.22','Saint-Petersburg','','RUSSIAN FEDERATION','194156','79219567756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:27:24',0,NULL,3,1,2,1,'\\  ','olganik3'),(10814,760673048011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','a.mathieu20','a.mathieu@videotron.ca','Andre Mathieu','607, 39e Avenue','St-Jerome','QC','CANADA','J7Z2G2','(514) 824-7678','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 16:28:01',0,NULL,3,1,3,1,'RA184587648CN\r ','a.mathieu20\rWLAP002\r一共买了两个'),(10815,570121391004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.99,'cnfaner','watlow7777','alex_aktau@nm.ru','Alexey Arkhipov','Microdistrict 29, bldg.28, apt.40','Aktau','','KAZAKHSTAN','130000','77776316540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:30:06',0,NULL,3,1,3,1,'RA184587696CN\r ','watlow7777\rOTTP001'),(10816,760678669011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',18.99,'eastar4','dreygo64','dreygo64@yahoo.com','Chris Robinson','1838 Middlebury St','Elkhart','IN','UNITED STATES','46516-4711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:41:29',0,NULL,3,1,1,1,'\\  ','dreygo64'),(10817,760682861011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','061287','87brooks@gmail.com','Barbara Brooks','619 S 184th St','Elkhorn','NE','UNITED STATES','68022-5681','(402) 885-6985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 16:52:43',0,NULL,3,1,1,1,'\\  ','061287'),(10818,564682620003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','catmom2760','debbie@debbiebathurst.net','Debra L Bathurst','1111 Highland Park','Fallbrook','CA','UNITED STATES','92028-5419','(760) 731-6074','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-06 17:18:04',0,NULL,3,1,1,1,'\\  ','catmom2760'),(10819,843976311012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','dicky1230_3','richardgreensmith@hotmail.co.uk','Richard Greensmith','County Supplies, Rolleston Drive<br>Arnold','Nottingham','Nottinghamshire','UNITED KINGDOM','NG5 7JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 17:18:49',0,NULL,3,1,3,1,'RA184587501CN\r ','dicky1230_3\rGLOT005*2'),(10820,702933539008,180699061124,'New GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',23.99,'au-buy','lz2kc','ilkokaraatanasov@gmail.com','Ilko Karaatanassov','29, Osvobojdenie Str. vhod 2','Veliko Tarnovo','Veliko Tarnovo','BULGARIA','5000','0888431994','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 17:23:15',0,NULL,3,1,3,1,'RA184587634CN\r ','lz2kc\r欧标\rHSPL011'),(10821,843991812012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.48,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 17:48:58',0,NULL,3,1,3,1,'RA184587651CN\r ','grandizom\rOTCN004*10\r黑色的'),(10822,720502214001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','latinoprrafael','rvelez7@carolina.rr.com','Rafael Velez','2913 Firewood Dr','Matthews','NC','UNITED STATES','28105-0874','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 17:55:27',0,NULL,3,1,1,1,'\\  ','latinoprrafael'),(10823,0,120773424935,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',18.5,'buysia','gredar1983','felipefiladelfo@hotmail.com','Felipe Leite','Praceta Gaspar Corte Real lote 60 11º esquerdo','carregado','Lisboa','PORTUGAL','2580-480','00351912942341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:02:00',0,NULL,3,1,3,1,'RA184587373CN\r ','gredar1983\rBR3D006'),(10824,620122488013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','sourpussfiji','dirkfiji@hotmail.com','Dirk Rosenkranz','Kelsterbacher Str. 20B','Hattersheim','','GERMANY','65795','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:07:55',0,NULL,3,1,3,1,'RA184587435CN\r ','sourpussfiji\rMOSA005'),(10825,620126728013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.5,'eastar4','solomatin56rus','mail@it-56.ru','Anton Solomatin','70 let VLKSM, d. 6, kv. 49','Orenburg','Orenburgskaya oblast','RUSSIAN FEDERATION','460000','+79225484747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:18:09',0,NULL,3,1,2,1,'\\  ','solomatin56rus'),(10826,620122878013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','dyvik','sloksli@broadpark.no','Steinar Løksli','Amtmann Aalls gt 32','Skien','telemark','NORWAY','3717','+4791880877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:21:48',0,NULL,3,1,6,1,'EE645685528CN ','dyvik'),(10827,760729013011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',7.99,'eastar4','spoky09','andrijaspoky@gmail.com','Andrija Špoljarec','Pilatušćak 7','Zagreb','Croatia','CROATIA','10 060','0989121909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:26:26',0,NULL,3,0,2,1,'\\  ','spoky09'),(10828,844021578012,220815929125,'NEW AKE BC 188 Inside hide PCMCIA to eSATA SATA Cardbus',1,'ADAK002',8.29,'eastar4uk','alwyn029','alwyn_lewis@talk21.com','Alwyn Lewis','74 Dorchester Road','IPSWICH','Suffolk','UNITED KINGDOM','IP3 8RH','01473712503','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 18:39:19',0,NULL,3,1,3,1,'RA184587515CN\r ','alwyn029\rADAK002'),(10829,620138932013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','greenberg9329','bob@greenbe.net','Robert R. Greenberg','9329 Weathervane Pl','Montgomery Village','MD','UNITED STATES','20886','(301) 926-4940','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 18:49:03',0,NULL,3,1,1,1,'\\  ','greenberg9329'),(10830,760745775011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','fiva1328','fiva13@gmail.com','Vadym Finyagin','ulica Oleny Stepanivny, dom 35a, kvartira 5','Lvov','Lvovskaya oblast','UKRAINE','79018','+380673742218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 18:56:59',0,NULL,3,1,2,1,'\\  ','fiva1328\r24K超轻碳纤骨长柄伞  '),(10831,844043543012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','stephen5333','karen.thompson40@ntlworld.com','Stephen Thompson','75 Warren Avenue, Shirley Warren','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO16 6AF','02380323063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 19:17:04',0,NULL,3,1,2,1,'\\  ','stephen5333\racer 6pin1.25 23cm'),(10832,760768571011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','cotinusa1','javier.fornell@gmail.com','J. Javier Montes de Oca Fornell','c/ Albina del Puente nº 9 - A','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','655438340','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 19:37:16',0,NULL,3,1,2,1,'\\  ','cotinusa1'),(10833,844056178012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','tjon5394','anntony.jones2@btinternet.com','terence jones','25 epsom road<br>moreton','wirral','Merseyside','UNITED KINGDOM','ch461pt','01516771696','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 19:38:06',0,NULL,3,1,3,1,'RA184587444CN\r ','tjon5394\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(10834,844050015012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','zoran17','ocko@siol.com','Zoran Ocko','Ulica bratov Šanda 3','Rogatec','','SLOVENIA','SI-3252','0038635827033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 19:30:45',0,NULL,3,1,2,1,'\\  ','zoran17\r黑色的'),(10835,844058432012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','glauciogsoares','glaucio22@gmail.com','Glaucio Goncalves Soares','QR 122 Conjunto 02<br>Casa 21','Samambaia Sul','Distrito Federal','BRAZIL','72304202','61 8441-0485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 19:52:14',0,NULL,3,1,3,1,'RA184587413CN\r ','glauciogsoares\rGLOT001\r兼容型3D眼镜 通用型'),(10836,760757421011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','kreiz1','t.rytterager@hotmail.com','Oyvind Saltnes','Salaroyveien 1480','Tromso','Kvaloysletta','NORWAY','9100','+4790180931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 20:01:26',0,NULL,3,1,2,1,'\\  ','kreiz1\r欧标'),(10837,570210419004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','warcon4166','warcon@juno.com','Warren Painter','53 Long Acre Rd','Scottsville','VA','UNITED STATES','24590-4634','(434) 286-3742','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-06 20:50:34',0,NULL,3,1,1,1,'\\  ','warcon4166'),(10838,620187599013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.4,'eastar4','chapola64','mchapola@uol.com.br','Marcelo Chapola','Rua Ibitirama 662<br>Vila Prudente','São Paulo','São Paulo','BRAZIL','03134001','551123470626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 20:57:16',0,NULL,3,1,2,1,'\\  ','chapola64\rHP 8pin 1.0 23cm '),(10839,844103753012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','tomski9','tom_kielpinski@hotmail.com','Thomas J Kielpinski','5990 FICKETT LN','PARADISE','CA','UNITED STATES','95969-5519','(530) 877-4828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 21:00:43',0,NULL,3,1,1,1,'\\  ','tomski9'),(10840,570215253004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','rs-2010','cool_rene@web.de','Rene Schneider','Viersener Straße 94','Willich','','GERMANY','47877','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:06:01',0,NULL,3,1,3,1,'RA184587532CN ','rs-2010\rWLDE002'),(10841,620197974013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',76.37,'eastar4','aka_falsh','vladislav.falfushinsky@gmail.com','Vladislav Falfushinsky','Levamevskogo, 8','Brovary','Kiev','UKRAINE','07401','+380969665513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:27:59',0,NULL,3,1,3,1,'RA184587617CN\r ','aka_falsh\rWWOT001+ANCN001+ANTY002+WLIN014\r再发一个New Intel Centrino Advanced N WiMAX 6250 622ANXHMW\r一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r\r'),(10842,0,130571458237,'New Philips Toothbrush Sonicare Travel Charger base US',1,'HBPH003',13.99,'cnfaner','misialinac','michalinacieslewicz@hotmail.com','michalina cieslewicz','1/3 lamond street','airlie beach','Queensland','AUSTRALIA','4802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:32:33',0,NULL,3,1,3,1,'RA184587603CN\r ','misialinac\rHBPH003'),(10843,760831066011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','eddoussi','e.a.usmanij@gmail.com','Edwin Usmany','Da Costastraat 34','OOSTERHOUT NB','','NETHERLANDS','4904EP','0031162424861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 22:00:18',0,NULL,3,1,2,1,'\\  ','eddoussi'),(10844,564776498003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','seemeforparts','pureh20source@gmail.com','Robert Willson','55 Chestnut Ln','levittown','NY','UNITED STATES','11756-4016','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-06 22:02:37',0,NULL,3,1,1,1,NULL,'seemeforparts'),(10845,760843565011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','kyorll','simclou13@hotmail.com','Simon Cloutier','118 Virginia Street Apt. 302','Kingston','ON','CANADA','K7K 5Y4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 22:19:09',0,NULL,3,1,3,1,'RA184587492CN\r ','kyorll\rOTSO004'),(10846,620215973013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','coolhotwheelsdude','yellow1951f1@usa.net','David Fette','205 Central Ave N','faribault','MN','UNITED STATES','55021-5212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 22:34:06',0,NULL,3,1,1,1,'\\  ','coolhotwheelsdude'),(10847,760846428011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','jamesmdorgan','james.m.dorgan@googlemail.com','James  Dorgan','70 Common Road<br>Chandlers Ford','Winchester','Hampshire','UNITED KINGDOM','SO53 1HB','02380269440','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 22:34:16',0,NULL,3,1,3,1,'RA184588538CN\r ','jamesmdorgan\rUDAP001'),(10848,844151262012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','rosekay50','bpnabours@hotmail.com','brenda nabours','3174 Miller Ln','lake charles','LA','UNITED STATES','70605','(337) 794-3468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-06 22:52:22',0,NULL,3,1,1,1,'\\  ','rosekay50'),(10849,841222139012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',184.99,'eastar4','smek08110105','sami110105@yahoo.ca','Sami Marji','303-65 Diamond Head Crt','Moncton','NB','CANADA','E1G 0V6','(506) 389-4180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 23:15:17',0,NULL,3,1,6,1,'EE645685514CN ','smek08110105'),(10850,760861549011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','zan2theresq','susannahsnell@hotmail.com','Susannah Snell','30 Eromanga Street','Carindale','Queensland','AUSTRALIA','4152','0738435365','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 23:17:15',0,NULL,3,1,2,1,'\\  ','zan2theresq\r红边优联'),(10851,620219585013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','gdeluca65','ginodeluca@rogers.com','Gino De Luca','59 Grampian Avenue','Maple','ON','CANADA','L6A 1Z6','(905) 417-1532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 23:27:40',0,NULL,3,1,6,1,'EE645685505CN ','gdeluca65'),(10852,564801998003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','id57chev','sandydan99@msn.com','Dan H. Crawford','2441 N. Oconner Ave','Meridian','ID','UNITED STATES','83646','(208) 888-9222','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 00:04:07',0,NULL,3,1,1,1,'\\  ','id57chev'),(10853,564802611003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',5,'HSPL010',134.75,'cnfaner','alav9004','lavoie.steve58@gmail.com','andre lavoie','po box 538<br>40 karin dr','central village','CT','UNITED STATES','06332','(860) 334-7196','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 00:04:58',0,NULL,3,1,1,1,'\\  ','alav9004'),(10854,760876983011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','1mozambique1','yoyomin@hotmail.com','XueHao Ying','6910 VIAU','Montreal','QC','CANADA','h1t 2z1','(514) 729-5602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 00:07:21',0,NULL,3,1,2,1,'\\  ','1mozambique1'),(10855,760883871011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','topshopmtl','klakson.nord@yahoo.com','Gennadiy Sokolovskyy','2192 John Mccurdy','St-Laurent','QC','CANADA','H4R3H9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 00:31:07',0,NULL,3,1,2,1,'\\ ','topshopmtl'),(10856,760893249011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','gbkwon','geebum.kwon@doosan.com','GEEBUM KWON','110-702, DAEDONG WHOANGTOBANG APARTMENT,<br>DAEBANGDONG, SUNGSANGU','CHANGWONCITY','KYOUNGNAM','KOREA,REPUBLIC OF','641-901','+82-10-8783-3831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 01:01:20',0,NULL,3,1,3,1,'RA184581971CN ','gbkwon\rOTSO004'),(10857,760637681011,320730481767,'New Japan Gentleman business Stripe Rain Stick Umbrella',1,'UM00026',26.99,'eastar4','robohobomk2','oystein.espedal@gmail.com','Øystein Espedal','Nedre Stølen 4 E','Bergen','Hordaland','NORWAY','5003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 01:37:21',0,NULL,3,1,2,1,'\\ ','robohobomk2\r日本外贸经典条纹长柄伞 '),(10858,620259552013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','anabel7777777','anabel7777777@hotmail.com','Anabel Debelak','67 Bungan head road','Newport  SYDNEY','NEW SOUTH WALES','AUSTRALIA','2106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 01:37:35',0,NULL,3,1,2,1,'\\  ','anabel7777777'),(10859,703126187008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','tehrealgsus','curtis.taylor@shaw.ca','Curtis Taylor','960 Abbotsford Drive NE','Calgary','AB','CANADA','T2A5Y6','(403) 569-9478','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 01:41:04',0,NULL,3,1,3,1,'RA184587550CN ','tehrealgsus\rSCLO001'),(10860,844205713012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','psgidaho','ricsto@cableone.net','richard stokes','5445 n Rosa Springs Ave','Meridian','ID','UNITED STATES','83646-5833','(208) 284-0276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 01:42:35',0,NULL,3,1,1,1,'\\  ','psgidaho'),(10861,564546186003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','trumpd007','john@sydneycellular.com.au','John Gharib','Sydney Cellular Repairs, lower ground floor<br>17 Castlereagh St','SYDNEY','New South Wales','AUSTRALIA','2000','0292238311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 01:42:54',0,NULL,3,1,3,1,'RA184587594CN\r ','trumpd007\rHSMO019\r澳标'),(10862,620269581013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.4,'eastar4','jdfaria2','jdfaria@comcast.net','Joseph Faria','45 Field rd','Marstons Mills','MA','UNITED STATES','02648-2108','(508) 420-0778','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 02:18:05',0,NULL,3,1,1,1,'\\  ','jdfaria2\rHP 8pin 1.0 23cm ');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (10863,720688422001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','hatwin2011','hatwin1976@gmail.com','Ate He','2421 W Longhorn Dr','Chandler','AZ','UNITED STATES','85286-6103','(480) 678-5388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 02:21:31',0,NULL,3,1,1,1,'\\  ','hatwin2011'),(10969,570633162004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'cnfaner','t.rex!','tj@purdie.com','Trevor Purdie','Imp. de la Crêta 4','Neyruz','','SWITZERLAND','1740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 07:45:20',0,NULL,3,1,3,1,'RA184581910CN ','t.rex!\rOTGR005'),(10864,620282602013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','vioka210','vioka210@gmail.com','carmen medina','7380 SW 98th St','Pinecrest','FL','UNITED STATES','33156-2938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 03:21:11',0,NULL,3,1,1,1,'\\  ','vioka210'),(10865,760943495011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','ogdigital3','og3hree@gmail.com','Stephen O\'Grady','1523 West 3rd  - 3rd Floor','vancouver','BC','CANADA','V6J 1H2','(778) 668-7501','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ogdigital3'),(10866,570306345004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.6,'cnfaner','hyunseok123','handong96@naver.com','HyunSeok Kim','Handong University, Buk-Gu<br>Policy and PR Team','Pohang','GyunSangBu-do','KOREA,REPUBLIC OF','791-708','(821) 025-8802 ext.: 54','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 04:43:19',0,NULL,3,1,3,1,'RA184587705CN\r ','hyunseok123\rWLAP008'),(10867,844254717012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',105.99,'eastar4uk','martialllaw','adam.french1974@gmail.com','Adam French','Australian Aerospace<br>112 Pandanus Avenue','Pinkenba','Queensland','AUSTRALIA','4008','0402095160','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 04:45:23',0,NULL,3,1,3,1,'RA184581968CN ','martialllaw\rOTSO004*3'),(10868,844254919012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','jasc-com-au','sales@jasc.com.au','Andrew Campbell','19 John Street','Basin View','New South Wales','AUSTRALIA','2540','0421511747','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jasc-com-au'),(10869,760950958011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','boby811','boqn_love_you@abv.bg','ALYOSHA KARAFEZIEV','CREST LODGE CARE HOME<br>CHURT ROAD','HINDHEAD','Surrey','UNITED KINGDOM','GU26 6PS','07544058250','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 04:53:01',0,NULL,3,1,3,1,'RA184581906CN ','boby811\rGLOT001*3\r兼容型3D眼镜 通用型\r'),(10870,758562713011,320721418293,'Genuin Samsung SSG-2200AR Rechargeable Adult 3D glasses',7,'GLSG006',195.96,'eastar4','arocho263','vmajr0263@frontier.com','Victor M. Arocho, Jr.','2719 New York St','Lake Station','IN','UNITED STATES','46405-1477','(219) 962-8865','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\  ','arocho263\r就发四个'),(10871,564859766003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','dereknang','dareeves@bigpond.net.au','Angela Reeves','PO Box 3183<br>Loganholme','Brisbane','Queensland','AUSTRALIA','4129','0408789992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 05:57:36',0,NULL,3,1,3,1,'RA184588630CN\r ','dereknang\rHSMO019\r澳标'),(10872,760965408011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','brendanj10','brendanjhoward@hotmail.com','Brendan Howard','PO Box 5171<br>Algester Rd Algester','Brisbane','Queensland','AUSTRALIA','4115','0732722128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 06:18:15',0,NULL,3,1,2,1,'\\  ','brendanj10'),(10873,620171728013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','tantrumddc','daviddelcanto@hotmail.com','David Del Canto Astorga','francesc ferrer i guardia 11 5º 1ª','Mollet del Valles','Cataluña','SPAIN','08100','610779247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 06:42:47',0,NULL,3,1,2,1,'\\  ','tantrumddc'),(10874,760977874011,320394892496,'Acer Aspire 5735 5735Z Bluetooth Module 2.0 EDR +cable',1,'BTAC2005',9.9,'eastar4','art102','artin102@yahoo.com','Artin Eivazian','8617 Lehigh Ave','Sun Valley','CA','UNITED STATES','91352','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 07:24:39',0,NULL,3,1,1,1,'\\  ','art102\racer 4pin1.25 8cm '),(10875,8881315381558533,111,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',0,'cnfaner','freddemagic','pfostersund@gmail.com','Fredrik Engberg','Brunkullavägen 4','Brunflo','','SWEDEN','83431','466323032',NULL,NULL,NULL,'2011-09-07 07:45:58',0,NULL,3,1,3,1,'RA184588657CN\r ','补发的 \rOTRA001 '),(10876,844295342012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','jamieyn2006','jamieyn@optusnet.com.au','Jamie Yoon','c/ Optus<br>Level 3/1260 Hay Street','West Perth','Western Australia','AUSTRALIA','6005','0402327017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 07:56:39',0,NULL,3,1,2,1,'\\  ','jamieyn2006'),(10877,620328482013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.59,'eastar4','gkgeorgiadis','g_k_georgiadis@yahoo.gr','George Georgiadis','paralia livanaton','Livanates','Fthiotida','GREECE','35007','6948208609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 08:33:56',0,NULL,3,1,3,1,'RA184588569CN\r ','gkgeorgiadis\rMOLO008'),(10878,760995169011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','tdamary','taldamary@gmail.com','Shahar Damary','Degania Road 46<br>Apartment 18','Netanya','Israel','ISRAEL','42376','972528907946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 08:34:30',0,NULL,3,1,3,1,'RA184588572CN\r ','tdamary\rRCLO006'),(10879,844308260012,220763418811,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',5.8,'eastar4uk','kuhne9478','fernanda@civicart.com','Fernanda Pedrotti','Eric R. Kuhne<br>15 - 27 GEE STREET','LONDON','London','UNITED KINGDOM','EC1V 3RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 08:48:53',0,NULL,3,1,3,1,'RA184587890CN\r ','kuhne9478\rPOLO001'),(10880,761004989011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','babycatts','paulcatt67@sky.com','Paul Catt-Camfield','187 Lower Road','Great Bookham','Surrey','UNITED KINGDOM','KT23 4AU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 09:14:57',0,NULL,3,1,3,1,'RA184581251CN ','babycatts\rMOAP001'),(10881,620339813013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','psychichiq','juanita.hinds@btinternet.com','Juanita Hinds','3840 W Hillsboro Blvd<br>Ste 3650','Deerfield Beach','FL','UNITED STATES','33442-9478','3604690205','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 09:38:24',0,NULL,3,1,1,1,'、 ','psychichiq'),(10882,758697634011,320741897705,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',56.99,'eastar4uk','hasbijabah1','johanahasbi@gmail.com','HASBI JABAH','JS1E/363 ABF HOUSING,PESIARAN<br>TEMENGGONG OYONG','BINTULU','SARAWAK','MALAYSIA','97000','086-253013','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 10:46:16',0,NULL,3,1,3,1,'RA184581177CN ','hasbijabah1\rGPS0002'),(10883,570362059004,140583346708,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',46,'cnfaner','pukalux','pvaiciulis@yahoo.com','Paulius Vaiciulis','Parko 5','Zemaitkiemis','Ukmerges r','LITHUANIA','LT-20368','37060025511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:04:22',0,NULL,3,1,3,1,'RA184581115CN ','pukalux\rOTPL001'),(10884,760645598011,320740565588,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',9.9,'eastar4uk','lwe884689','lwedwards@hotmail.com','Mr L Edwards','9 Malthouse Drive','Dudley','West Midlands','UNITED KINGDOM','DY1 2BY','01384234545','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 11:25:02',0,NULL,3,1,3,1,'RA184581282CN ','lwe884689\rWLAP002'),(10885,620360489013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','milanskuplik','milan.skuplik@seznam.cz','Milan Skuplik','Pekarska 50','Opava','','CZECH REPUBLIC','74601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:29:43',0,NULL,3,1,3,1,'RA184581132CN ','milanskuplik\rWWOT001+ANCN001'),(10886,720804704001,110731214793,'New in box AKG K 450 Premium Foldable Headphone',1,'HSAK003',58.9,'buysia','pedrocopo','neco-cuenca@hotmail.com','RENE CUENCA MARIACA','DISCOBOLO Nº 68 2 º C','MADRID','Madrid','SPAIN','28022','912331079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:33:37',0,NULL,3,1,3,1,'RA184581044CN ','pedrocopo\rHSAK003\r'),(10887,844363365012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','rhezzy','ri.heslop@btinternet.com','Richard Heslop','34 Grey Court','Wakefield','West Yorkshire','UNITED KINGDOM','WF1 3HL','01924825246','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 11:55:20',0,NULL,3,1,3,1,'RA184581163CN ','rhezzy\rOTHP004'),(10888,564916240003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','urb001','ambsom01@hotmail.com','andrew bailey','65 millfold road             middleton','manchester','Lancashire','UNITED KINGDOM','m241df','01616547563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:55:29',0,NULL,3,1,3,1,'RA184581234CN\r ','urb001\rMOLO006'),(10889,761060432011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','nytortis45','mikkeewil@yahoo.com','MICHAEL RICHARDSON','24 Cook St<br>Apt 4B','BROOKLYN','NY','UNITED STATES','11206-4041','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 12:29:51',0,NULL,3,1,1,1,'\\  ','nytortis45'),(10890,844376566012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',70.99,'eastar4uk','calisto0284','calisto1@inbox.lv','Aleksandrs Lushins','Strautu Street 24 - 26','Riga','','LATVIA','LV-1035','+371 26704432','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 12:36:42',0,NULL,3,1,3,1,'RA184581013CN\r ','calisto0284\rOTSO004*2\r申报十美金'),(10891,564927310003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','slavasektor','sektormen@rambler.ru','Ярослав Лапин','ул Ленинградская дом 65 кв 46','Пушкин','Санкт Петербург','RUSSIAN FEDERATION','196607','89216333166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 12:47:38',0,NULL,3,1,3,1,'RA184581101CN\r ','slavasektor\rBALO007'),(10892,570384725004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','valemarcos','valemarcos@hotmail.com','Marcos Vale','Santa Luiza street, 259/apt 203','Rio de Janeiro','Rio de Janeiro / Maracanã','BRAZIL','20511030','+55 21 86685221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 12:58:33',0,NULL,3,1,3,1,'RA184581089CN ','valemarcos\rOTRA001'),(10893,844390864012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','tinguely_de','cesar.perera@bluewin.ch','Cesar Perera','Rebmattweg 30','Merlischachen','','SWITZERLAND','6402','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:13:34',0,NULL,3,1,2,1,'\\  ','tinguely_de'),(10894,761077525011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','guyrgs','rgs_soft@belgacom.net','Guy Roels','Begijnhof 21','Aalst','','BELGIUM','9300','0484/278420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:24:34',0,NULL,3,1,3,1,'RA184581058CN ','guyrgs\rGLSG001*2'),(10895,570392125004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','top_tap','yukio-m@bekkoame.ne.jp','Yukio Miyamoto','Matubacho 3-8','Tokorozawasi','Saitama','JAPAN','359-0044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:34:41',0,NULL,3,1,3,1,'RA184581092CN ','top_tap\rOTGR002'),(10896,844403303012,220815928079,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',19.99,'eastar4uk','saspro_uk','saspro@me.com','Simon Treadaway','26 Fulbourn<br>Eureka Road','Kingston','Surrey','UNITED KINGDOM','KT1 3JQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 13:47:52',0,NULL,3,1,3,1,'RA184581129CN\r ','saspro_uk\rOTIN002'),(10897,761086490011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','alvinlee114','alvinlee00@yahoo.com.hk','Wai Wah Lee','Rm.1103, Hong On Hse.,<br>Cheung Hong Est., Tsing Yi, N.T.','default','','HONG KONG','default','96898554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:49:40',0,NULL,3,1,2,1,'、 ','alvinlee114'),(10898,761090254011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','smithmfgmailcom','smithmf@gmail.com','Michael Smith','17 Braganza Street','London','London','UNITED KINGDOM','se17 3rd','0205821409','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 13:59:52',0,NULL,3,1,3,1,'RA184581305CN ','smithmfgmailcom\rRELO003\r红边优联'),(10899,844407524012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','gavinatkinson','gavin.atkinson@ury.york.ac.uk','Gavin Atkinson','Computing Service<br>University of York','York','Yorkshire','UNITED KINGDOM','YO10 5DD','07779167164','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 14:04:04',0,NULL,3,1,3,1,'RA184581075CN ','gavinatkinson\rWLIN013'),(10900,761094987011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','***foggy***','chris_fogg@me.com','Mr C Fogg','A613 Adana Building<br>Conington Road','Lewisham','London','UNITED KINGDOM','SE13 7FD','07429144258','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 14:14:36',0,NULL,3,1,3,1,'RA184581185CN ','***foggy***\rUDAP001'),(10901,761100823011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','drimbach1','david@ibsfl.org','David Rimbach','429 Lakeview Ave','Winter Park','FL','UNITED STATES','32789-3536','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 14:34:35',0,NULL,3,1,1,1,NULL,'drimbach1'),(10902,844420757012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','dalos_t_123','dalos_t@freemail.hu','Tibor Dalos','Dózsa György út 84/b.','Budapest','Pest','HUNGARY','1068','+3612358904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 14:40:52',0,NULL,3,1,3,1,'RA184581217CN ','dalos_t_123\rGLOT005'),(10903,844432492012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','oag163','ag-o@yandex.ru','Andrey Ochkasov','The Moscow prospectus the<br>house 11 apartment 348','Tolyatti','The Samara region','RUSSIAN FEDERATION','445032','+79372170471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:04:11',0,NULL,3,1,3,1,'RA184581248CN ','oag163\rOTSO004*2'),(10904,761128808011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','ethno2405','konstantin2005@gbg.bg','Konstantin Tenekedzhiev','25, Budapest str.<br>2nd floor, flat 6','Sofia','Sofia','BULGARIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:43:46',0,NULL,3,1,2,1,'\\  ','ethno2405'),(10905,570427259004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','eecs','dshahemail@gmail.com','Deepak Shah','1873 Los Olivos Rd','Santa Rosa','CA','UNITED STATES','95404-2015','(707) 324-3150','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 15:56:50',0,NULL,3,1,1,1,'、 ','eecs'),(10906,620427161013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','pouliche_sunny_daze','val_pl19@hotmail.com','Valérie Plante Lepage','8840, rue des Pigamons','Québec','QC','CANADA','G1G 0E1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:58:40',0,NULL,3,1,3,1,'RA184587815CN ','pouliche_sunny_daze\rMOSA006'),(10907,844465003012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','hertsessex','contact.us@alarm1.co.uk','Philip Cook','Herts and Essex Alarms Ltd<br>Unit 3 Woodgates Farm','Broxted','Essex','UNITED KINGDOM','CM6 2BN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 16:21:42',0,NULL,3,1,2,1,'\\  ','hertsessex\r英标'),(10908,844395953012,220759518239,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',29.99,'eastar4uk','ver364','ver364@voliacable.com','Yuriy Lebedenko','Groznenskaya, 18<br>kv.118','Kyiv','','UKRAINE','04086','(044)440-7996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 16:38:36',0,NULL,3,1,3,1,'RA184581336CN ','ver364\rCMLO001'),(10909,761164878011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','lpsalem2011','lpsalem@gmail.com','Evangelia Piperi','Antheon 8 Pigadakia Voula','Athens','','GREECE','16673','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 17:08:17',0,NULL,3,1,3,1,'RA184581027CN ','lpsalem2011\rGLOT001\r兼容型3D眼镜 通用型'),(10910,844493601012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','southernfist','sifu@xingyi.co.uk','Colin MacKenzie','9 Fletcher Close<br>Merchants Court','Beckton','London','UNITED KINGDOM','E6 6FT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 17:15:21',0,NULL,3,1,2,1,'\\  ','southernfist\rMX20T'),(10911,761170592011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','applegeek','christinecooper@roadrunner.com','Christine Cooper','1336 N Richman Knls','Fullerton','CA','UNITED STATES','92835','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 17:19:42',0,NULL,3,1,1,1,'\\  ','applegeek'),(10912,761186676011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','saladin_der_weise','alexander.michel.90@gmx.de','Alexander Michel','Aarstraße 29','Wiesbaden','','GERMANY','65195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 17:52:08',0,NULL,3,1,2,1,'\\  ','saladin_der_weise'),(10913,761193269011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',2,'RCLO007',59.98,'eastar4','mote2','raycer60@aol.com','Raymundo Aguirre','3000 Weslayan St<br>Ste 235','Houston','TX','UNITED STATES','77027-5749','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 18:05:08',0,NULL,3,1,1,1,'、 ','mote2'),(10914,844532777012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.9,'eastar4','dionisakaden','denakaolya@gmail.com','Denis Chervinsky','Bney-Or 1246','Beer-Sheva','','ISRAEL','84453','054-213-0871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 18:27:24',0,NULL,3,1,2,1,'\\  ','dionisakaden\racer 5pin1.25 6cm '),(10915,844537911012,220848552975,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','rucanada','maickl@pisem.net','Mikhail Persiiantsev','130 Banbrooke Cres','Newmarket','ON','CANADA','L3X 2W7','(416) 399-1927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 18:35:07',0,NULL,3,0,3,1,'RA184581353CN\r ','rucanada'),(10916,620480782013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','piyushm704','simba_50@hotmail.com','DIPAN PATEL','618 E 9th St','Charlotte','NC','UNITED STATES','28202-3126','(704) 779-2480','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 18:35:35',0,NULL,3,1,1,1,'\\  ','piyushm704'),(10917,761214772011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','gugux_fr','guigui@gugux.net','Guillaume Courtois','13 rue des petits carreaux','Paris','Ile-de-France','FRANCE','75002','0142211590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 18:47:46',0,NULL,3,1,3,1,'RA184588762CN ','gugux_fr\rGLSG001*2'),(10918,844529979012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','slightlymadcat','git.user@gmail.com','Alexander Fomichev','Komsomolskaya 2/9 194','Serpukhov','Moscow reg','RUSSIAN FEDERATION','142205','+79165307803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 18:51:42',0,NULL,3,1,2,1,'\\  ','slightlymadcat'),(10919,844560202012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','jad200','jdenny@sky.com','John A Denny','19 Carpenters Way','Hailsham','East Sussex','UNITED KINGDOM','BN27 3XD','01323849372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 19:12:02',0,NULL,3,1,3,1,'RA184581225CN ','jad200\rOTCN004*10\r黑色的'),(10920,844561168012,220763388880,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',10.98,'eastar4uk','andrews6627','ja003w2214@blueyonder.co.uk','jan andrews','6 maltby road','chessington','Surrey','UNITED KINGDOM','kt9 2bx','02082863980','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 19:13:08',0,NULL,3,1,3,1,'RA184581194CN ','andrews6627\rWLAP001+WLAP004'),(10921,761230432011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','spidi-4810','schmidt-trudi@t-online.de','Lothar Schmidt','Rupertistrasse 60','Trostberg','','GERMANY','83308','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 19:16:01',0,NULL,3,1,3,1,'RA184581296CN ','spidi-4810\rHBPH002'),(10922,844563033012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','woodlandplace','deecee3@sky.com','Mr D Griffiths','36 Heol Dylan<br>North Cornelly','Bridgend','Bridgend','UNITED KINGDOM','CF33 4LE','01656740809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 19:16:47',0,NULL,3,1,3,1,'RA184581061CN ','woodlandplace\rOTGR001+OTGR002'),(10923,570501939004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','alonsojuridica1','alonsojuridica@gmail.com','Fernando Alonso Pereda','Rua Antonio Iruleguy 327<br>Vila Luiza - Umbú','Santana do Livramento','RS','BRAZIL','97575-040','55-91283009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 19:44:04',0,NULL,3,1,3,1,'RA184581146CN ','alonsojuridica1\rOTRA001'),(10924,761255203011,320394913302,'Acer Aspire 4520 4520G Bluetooth Module EDR 2.0+cable',1,'BTAC2014',9.9,'eastar4','rolandtaylordaniel','chaos_45@hotmail.com','Roland Daniel','3165 Bartley rd','West Point','GA','UNITED STATES','31833-6046','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 19:57:32',0,NULL,3,1,1,1,'、 ','rolandtaylordaniel\racer 5pin1.25 20cm '),(10925,570515314004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','jfil4637','filek@vzw.blackberry.net','joseph filek','6150 nancy dr','la mesa','CA','UNITED STATES','91942-3822','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 20:18:53',0,NULL,3,1,1,1,'\\  ','jfil4637'),(10926,620532454013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','pinchass','pstern@zahav.net.il','Pinchas Stern','10 Panim Meirot','Jerusalem','','ISRAEL','94423','972-2-5372108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 20:49:03',0,NULL,3,1,2,1,'\\  ','pinchass'),(10927,565070281003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','xxjimexx','jtnguy26@gmail.com','Norris Tran Duc','7675 Phoenix Dr<br>Apt 1008','Houston','TX','UNITED STATES','77030-4717','(832) 492-2164','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 20:51:24',0,NULL,3,1,1,1,'\\  ','xxjimexx'),(10928,761283814011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.9,'eastar4uk','sbel1166','steve.bellerby@benchconsultingassociates.co.uk','steve bellerby','15 Sandhurst Drive','Wilmslow','Cheshire','UNITED KINGDOM','SK9 2GP','07748146324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 20:53:36',0,NULL,3,1,3,1,'RA184581203CN ','sbel1166\rOTSO002'),(10929,844618502012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','bertie_uk','richard.bertouche@gmail.com','Richard A Bertouche','63 Milldale Avenue','Buxton','Derbyshire','UNITED KINGDOM','SK17 9BG','07773774128','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 20:53:56',0,NULL,3,1,3,1,'RA184581035CN ','bertie_uk\rGLOT005*2'),(10930,844625665012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','skorpeom','ninja@blixtmail.se','Mikael Rajakontu','Lars Wivallius 49','Orebro','Orebro','SWEDEN','70359','070-4593033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 21:11:11',0,NULL,3,1,2,1,'\\  ','skorpeom'),(10931,761304912011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','228leema','leema228@sbcglobal.net','Mary Lee','600 Dorado Ter','San Francisco','CA','UNITED STATES','94112-1762','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 21:44:41',0,NULL,3,1,1,1,'\\  ','228leema'),(10932,620554995013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','lechimm','brouimic@sympatico.ca','Michel Brouillard','344 Bellefleur','St-Jean-sur-Richelieu','QC','CANADA','J3B1L3','(450) 346-4494 ext.: 178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 22:07:29',0,NULL,3,1,2,1,'\\  ','lechimm'),(10933,620561798013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','jplee0203','scar0203@hotmail.com','Jin Pyo Lee','9 Wildwood Dr.','Port Moody','BC','CANADA','V3H4M8','(604) 469-9284','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 22:35:51',0,NULL,3,1,3,1,'RA184581150CN ','jplee0203\rBAZA001'),(10934,761320018011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','bill-bonnet','billbonnet@hotmail.co.uk','WILL','unit 3 A stubcroft farm<br>tile barn lane','east wittering','West Sussex','UNITED KINGDOM','po20 8pj','01243670041','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 22:45:15',0,NULL,3,1,3,1,'RA184581279CN ','bill-bonnet\rRELO003\r红边优联'),(10935,620564105013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','zaza4302','schurosh@aol.com','Serena Churosh','4702 E Arcadia Ln','Phoenix','AZ','UNITED STATES','85018-2850','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 22:45:19',0,NULL,3,1,1,1,'、 ','zaza4302'),(10936,844660178012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','audanne619','yerduachi@aol.com','Audrey Harling','2917 Moon Lake Dr','West Bloomfield','MI','UNITED STATES','48323-1843','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'audanne619'),(10937,570556560004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'cnfaner','zenith8282','zenith828@gmail.com','Jordan Grider','1701 Townsend Dr<br>Wadsworth Hall - 0563E','Houghton','MI','UNITED STATES','49931-1193','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 23:01:01',0,NULL,3,1,1,1,'、 ','zenith8282\r红边优联'),(10938,761335474011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','ses_2002','david.d.shafer@gmail.com','Susan Sherman','7992 Barristers Ct','Kirtland','OH','UNITED STATES','44094-9285','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 23:27:15',0,NULL,3,1,1,1,NULL,'ses_2002'),(10939,844676253012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','kdakla1969','driverkda@hotmail.com','KEVIN AYERS','105 PIERCE ST','PLYMOUTH','PA','UNITED STATES','18651-2430','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 23:31:42',0,NULL,3,1,1,1,'\\  ','kdakla1969'),(10940,844678554012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','mau264821','mostak01@hotmail.co.uk','mostak ullah','12 ellery house<br>beckway street','london','London','UNITED KINGDOM','se171tn','07535551664','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 23:37:03',0,NULL,3,1,3,1,'RA184581265CN ','mau264821\rHSJA010\r英标'),(10941,620581573013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','novosel_d','dnovosel@gmail.com','David Novosel','2-475 Lisgar St.','Ottawa','ON','CANADA','K1R5H2','(613) 262-2734','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 00:15:31',0,NULL,3,1,2,1,'\\  ','novosel_d'),(10942,721087149001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','ryankellyjeep','jeepblk_1999@yahoo.com','Ryan Kelly','1339 park ave','plainfield','NJ','UNITED STATES','07060','(908) 642-0471','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 00:38:37',0,NULL,3,1,1,1,'、 ','ryankellyjeep'),(10943,844695493012,220816785876,'New Philips Standard Sonicare ProResult Toothbrush head',2,'HBPH004',13.8,'eastar4uk','franjue','francois@megaquebec.net','Francois Leduc','2180 de la Coupole','Quebec','QC','CANADA','G2B 5A8','(418) 845-5991','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 00:39:11',0,NULL,3,1,2,1,'\\  ','franjue'),(10944,761358942011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','twisted_visions','scott@twistedvisions.net','Scott Maclean','490 Quebec Street','London','ON','CANADA','N5W 3Y5','(519) 913-0734','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 01:15:40',0,NULL,3,1,2,1,'\\ ','twisted_visions'),(10945,620602593013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','pukka911','fibertech@shaw.ca','Philip Sparrow','319 Midvalley Way SE','Calgary','AB','CANADA','T2X 1J7','(403) 640-0718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 02:03:06',0,NULL,3,1,3,1,'RA184587909CN ','pukka911\rMOSA005'),(10946,620611116013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.5,'eastar4','dlepp56','spam56@gto.net','Dion Lepp','24 Barber Ave','Guelph','ON','CANADA','N1H 5E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 02:41:09',0,NULL,3,1,2,1,'\\  ','dlepp56'),(10947,761384636011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','tofuture7803','tofuture78@naver.com','Seungwoo Kang','52 Sinbang-ri, Dong-eup, Uichang-gu<br>Daehan APT, 101-108','Changwon-si','Gyeongsangnam-do','KOREA,REPUBLIC OF','641-865','82-10-9919-6930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 02:45:54',0,NULL,3,1,2,1,'、 ','tofuture7803\racer 8pin1.00 15cm '),(10948,761390718011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','dosdall67','timdegelman@gmail.com','Tim Degelman','3-2685 2nd Ave W.','Prince Albert','SK','CANADA','S6V 5E3','(306) 764-2288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 03:09:50',0,NULL,3,1,2,1,NULL,'dosdall67'),(10949,620617639013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','djamarindo','mauricioantonioli@msn.com','Maurício A. Schmitz','Av: Góis Monteiro N: 541','Sertão','Rio Grande do Sul','BRAZIL','99170-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 03:19:05',0,NULL,3,1,2,1,'\\ ','djamarindo'),(10950,844739955012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',39.9,'eastar4','derek_smalls7','dereksmalls7@gmail.com','Ryan Williams','620 Pamela Rd','Waco','TX','UNITED STATES','76708-7095','(254) 733-8830','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 03:21:02',0,NULL,3,1,1,1,'、 ','derek_smalls7'),(10951,0,140601411439,'New Philips Toothbrush Sonicare Travel Charger base US',1,'HBPH003',13.99,'cnfaner','gbhal','gbhaldeman@comcast.net','Glenn Haldeman','1212 Anchorage View Ct','Baltimore','MD','UNITED STATES','21224-4992','(410) 982-7930','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-08 03:37:00',0,NULL,3,1,1,1,'、 ','gbhal'),(10952,620622653013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',2,'MOSA006',139.8,'eastar4','2011-barbiedoll','bkrcil@yahoo.com','B.Krcil','30 East St','Whitehall','MT','UNITED STATES','59759-8662','(406) 287-9160','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 03:53:35',0,NULL,3,1,3,1,'RA184581897CN ','2011-barbiedoll\rMOSA006\r申报成Christmas Present'),(10953,570606355004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',19.9,'cnfaner','arik-s','arik.shaked@gmail.com','Arik Shaked','13 Pinkas street','Ramat Gan','','ISRAEL','52286','972544975426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 03:59:59',0,NULL,3,1,3,1,'RA184581923CN','arik-s\rOTGR001'),(10954,570608515004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',37.99,'cnfaner','n00bz0r','minhmai@hotmail.com','Minh Mai','8 Woolshed Avenue','Cairnlea','Victoria','AUSTRALIA','3023','0421187005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:19:06',0,NULL,3,1,3,1,'RA184581945CN','n00bz0r\rOTRA001'),(10955,844755092012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','beaubarre','np@newtale.com','Nguyen Phi','48 boulevard Murat','Paris','Île-de-France','FRANCE','75016','06.76.16.19.99','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 04:23:11',0,NULL,3,1,2,1,'、 ','beaubarre'),(10956,761405267011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','auvancott','torut@hotmail.com','Toru Tanino','3-22-41-512 Yoshida','Nagano-shi','Nagano','JAPAN','3810043','(090-4464-4390)  -','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:24:32',0,NULL,3,1,3,1,'RA184581866CN ','auvancott\rOTSO004'),(10957,570554871004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'cnfaner','windamere123','davidfgriffiths@gmail.com','David Griffiths','15 Louisa Road<br>Birchgrove','Sydney','New South Wales','AUSTRALIA','2041','0411888444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:30:15',0,NULL,3,1,3,1,'RA184581937CN ','windamere123\rOTGR005'),(10958,844758044012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','taifatcat','a.korennoy@gmail.com','Aleksey Korennoy','ul.Kalinina dom 142 kv.322','Blagoveschensk','Amurskaya oblast','RUSSIAN FEDERATION','675028','79246700818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:37:46',0,NULL,3,1,2,1,'、 ','taifatcat'),(10959,8881315456993234,111,'New Plantronics Voyager 851/855  Bluetooth headset',1,'',0,'cnfaner','kronolog','jestercela@gmail.com','Alec Yin','#8, The Elegance<br>60 Tai Hang Road','default','','HONG KONG','default','+852 9689 9990',NULL,NULL,NULL,'2011-09-08 04:43:13',0,NULL,3,0,2,1,'、 ','只补发一个英标头 '),(10960,844764310012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','cornrow','ebay@cornrow.org','Tynan','584 Castro St<br># 805','San Francisco','CA','UNITED STATES','94114-2512','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 05:11:14',0,NULL,3,1,1,1,'、 ','cornrow'),(10961,620634634013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','ffrozza','fabiofrozza@gmail.com','Fábio Frozza','Praca XV de Novembro 329 - 2. andar<br>Banco do Brasil/Besc','Florianópolis','SC','BRAZIL','88010-400','554884825737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:14:00',0,NULL,3,1,2,1,'、 ','ffrozza'),(10962,761414567011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','zuza1970','ebay@m-it.pl','Ewa Polecińska','Długa 158A','Borowa Góra','mazowieckie','POLAND','05-140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:17:43',0,NULL,3,0,2,1,'、 ','zuza1970\r已入库'),(10963,565161698003,130554587961,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'cnfaner','rodnette_1','rodlynnat@gmail.com','Rod Richards','18 Nords Wharf Rd','Nords Wharf','New South Wales','AUSTRALIA','2281','0414925417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:43:27',0,NULL,3,1,3,1,'RA184582005CN ','rodnette_1\rOTGR001+OTGR002+OTGR003'),(10964,620637394013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','cybermp3','cyberr.007@gmail.com','Remy Sicard','1885, rue de Foucault','Terrebonne','QC','CANADA','J6X2P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:44:53',0,NULL,3,1,3,1,'RA184581954CN ','cybermp3\rMOSA005'),(10965,620639044013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','bombtrack09','josh.bombtrack@gmail.com','Josh Smith','311 Lehmans Road Rangiora','Christchurch','North Canterbury','NEW ZEALAND','7471','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:53:55',0,NULL,3,1,2,1,'、 ','bombtrack09'),(10966,570330958004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56,'cnfaner','kglpass12','kglogitech11@gmail.com','ACI Express','17252 S Main St<br>Aci Express La','Gardena','CA','UNITED STATES','90248-3101','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-08 06:31:13',0,NULL,3,1,1,1,'\\ ','kglpass12\r\r'),(10967,844781379012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','yusik81','eradesign@mail.ru','Juliya Safonova','Ferganskaya<br>18/1 kv. 45','Moscow','','RUSSIAN FEDERATION','109444','+7(916)6525919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 06:38:09',0,NULL,3,1,2,1,'、 ','yusik81\r24K 多色伞 '),(10968,620645866013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','skrudj','skrudjandry@gmail.com','Andrey Deryabin','m-n.50a,Altay-2, App.22','Almaty','Kasakhstan','KAZAKHSTAN','050039','+7(727)2527335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 06:40:23',0,NULL,3,1,3,1,'RA184581870CN ','skrudj\rOTSO004*4'),(10970,761446960011,320730087169,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',8.99,'eastar4uk','buneech','bojan@buneech.com','Bojan Bunić','Frankovo naselje 172','Škofja Loka','','SLOVENIA','4220','041 265 961','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 08:04:53',0,NULL,3,1,2,1,'、 ','buneech'),(10971,761447317011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.89,'eastar4','barrapanduro','fox_mldr@hotmail.com','Carlos Angulo Mencia','Juana de ibarbourou nº 12 conserjeria','Zaragoza','Aragón','SPAIN','50013','615274574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 08:07:22',0,NULL,3,1,3,1,'RA184581999CN ','barrapanduro\rGLOT004\r兼容型3D眼镜  samsung 专用'),(10972,763226582002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'',119.99,'buysia','bkkclassic','dont_wakeme@hotmail.com','Tanapon Jutavarakul','56 Treepetch road, Wangburapapirom','Bangkok','Pranakorn','THAILAND','10200','661-811-4282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 08:15:02',0,NULL,3,0,3,1,'RA184581821CN ','bkkclassic'),(10973,620662243013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','maximnovikov1982','maxim.novikov@inbox.ru','Максим Новиков','Московская область Подольский район с. Ознобишино д. 91','Подольский район с. Ознобишино','','RUSSIAN FEDERATION','142144','+79197775575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 08:32:00',0,NULL,3,1,2,1,'、 ','maximnovikov1982'),(10974,761454258011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',92.99,'eastar4','domrep1970','domrep1307@gmx.de','Stefan Liebich','Am Wasserfall 15','Velbert','','GERMANY','42551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 08:38:15',0,NULL,3,1,3,1,'RA184581835CN ','domrep1970\rGLSG001*2'),(10975,761461675011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','tigran-felixich','hasmik1983@mail.ru','Tigran Sargsyan','Arghutyan 13<br>Arghutyan 13','Yerevan','Yerevan','ARMENIA','0051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:08:59',0,NULL,3,1,3,1,'RA184581883CN ','tigran-felixich\rOTSO004'),(10976,620669842013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','nayfin1','prharris@bigpond.net.au','Peter Harris','Level 20, 175 Liverpool Street','Sydney','New South Wales','AUSTRALIA','2000','0292852726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:17:21',0,NULL,3,1,3,1,'RA184581764CN ','nayfin1\rMOSA006'),(10977,620668677013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.59,'eastar4','pvdung73','dungpham85@hotmail.com','Phung Hoang Long','60 phung tram street','bac giang','bg','VIET NAM','21999','84977148933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:19:45',0,NULL,3,1,3,1,'RA184581849CN ','pvdung73\rMOLO008'),(10978,721190654001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','nzcanucks','imb4u1@hotmail.com','Jayesh Solanki','9 Hogarth Rise<br>West Harbour','Auckland','','NEW ZEALAND','0618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:23:25',0,NULL,3,1,3,1,'RA184581852CN ','nzcanucks\rBR3D005'),(10979,620674604013,230656400124,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','dremas79','rdryoma@gmail.com','Роман Сердюченко','9-я Тихая 5-219','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:43:40',0,NULL,3,1,3,1,'RA184581486CN\r ','dremas79\rOTSA001'),(10980,844831697012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','bidder012345','ebay@itsolutions.uk.com','Andrew Bibby','2 Hemlingford Road','Sutton Coldfield','West Midlands','UNITED KINGDOM','B76 1JQ','08703850487','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 10:02:43',0,NULL,3,1,3,1,'RA184581526CN\r ','bidder012345\rOTHP004'),(10981,620318596013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Craig Casale','109 N Gold Dr','Robbinsville','NJ','UNITED STATES','08691-1603','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 10:46:58',0,NULL,3,1,1,1,NULL,'mauriceshow'),(10982,620686728013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','mauriceshow','andersonmaurice.ma@gmail.com','Super Paperboys','124 E Center st','Medina','NY','UNITED STATES','14103-1621','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 10:51:15',0,NULL,3,1,1,1,NULL,'mauriceshow'),(10983,620688277013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',13.99,'eastar4','ser_vo','servo@land.ru','Sergey Voznesensky','Nevskaya ul., d.3, kv.83<br>Сергей Вознесенский, Невская ул., д.3., кв.83','Leningradskaya oblast, Vsevolozhsk','Russia','RUSSIAN FEDERATION','188645','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 11:00:00',0,NULL,3,1,2,1,NULL,'ser_vo'),(10984,638135425005,150657903085,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','mukesh11feb76','mukesh11276@gmail.com','Mukesh Dubey','5/20 Belmore St','Ryde','New South Wales','AUSTRALIA','2112','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 11:04:02',0,NULL,3,0,3,1,'RA184581509CN\r ','mukesh11feb76\r\r发货了，但点不了。'),(10985,761495000011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.99,'eastar4','alexhector','jpv@logintegral.com','Jesús Javier Paniagua Vaquero','C/. PABLO GARGALLO, 2, PORTAL 3, ATICO','PINTO','Madrid','SPAIN','28320','653654026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 11:20:14',0,NULL,3,1,3,1,'RA184581322CN ','alexhector\rGLSG001'),(10986,761498670011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','benbofh','benstook@gmail.com','Ben Stook','507 Abernethy Road','KEWDALE','Western Australia','AUSTRALIA','6105','0893525246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 11:30:32',0,NULL,3,1,2,1,'\\ ','benbofh'),(10987,844869729012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','klibais_tarps','putns@ml.lv','Didzis Putns','Murjanu 34 - 48','Riga','LA','LATVIA','LV-1024','(371)29103589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:04:47',0,NULL,3,1,2,1,NULL,'klibais_tarps'),(10988,565222277003,130554589408,'New Philips Sonicare toothbrush kit w/ Handle HX6930',2,'HBPH002+HBPH003+HBPH004',175.98,'cnfaner','supasn','supasn@hotmail.com','Tithima Sutatongthai','83/12 Rusada Road<br>Tubtiang','Muang','Trang','THAILAND','92000','0897242003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:14:34',0,NULL,3,1,6,1,'EE645685491CN ','supasn\rHBPH002+HBPH003+HBPH004'),(10989,761513320011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','delineator333a','roger_gaspar@hotmail.com','Roger Gaspar','5 Peck Hay Road, 05-08','default','','SINGAPORE','228307','(656) 527-5770','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'delineator333a'),(10990,620705137013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 12:20:29',0,NULL,3,1,1,1,'\\ ','revikom'),(10991,570682480004,140583346708,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',46,'cnfaner','unforgettablesouvenirs','phdoar@gmail.com','Pnina Hertz','POB 5645','Haifa','','ISRAEL','31055','972-4-8663956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:31:18',0,NULL,3,1,3,1,'RA184581469CN\r ','unforgettablesouvenirs\rOTPL001'),(10992,844879999012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','pokupatelvasya86','myakushin_v@mail.ru','Vasya Myakushin','Solnechnaya st. 15/17','Saransk','RU','RUSSIAN FEDERATION','430017','89272763761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:39:21',0,NULL,3,1,3,1,'RA184581557CN\r ','pokupatelvasya86\rWWOT003+ANCN001\r再发一个3G wwan 天线'),(10993,703706695008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','unforgettablesouvenirs','phdoar@gmail.com','Pnina Hertz','POB 5645','Haifa','','ISRAEL','31055','972-4-8663956','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 12:43:20',0,NULL,3,1,3,1,'RA184581591CN\r ','unforgettablesouvenirs\rHSPL015'),(10994,761523098011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','emvion','pa@emvion.gr','Antony A Poupoulidis','34, Erythrou Stavrou Ave..','Kavala','Macedonia','GREECE','65 403','+30 694 5104046','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 12:50:35',0,NULL,3,1,3,1,'RA184581472CN\r ','emvion\rUDAP001'),(10995,620710884013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','pokupatelvasya86','myakushin_v@mail.ru','Vasya Myakushin','Solnechnaya st. 15/17','Saransk','RU','RUSSIAN FEDERATION','430017','89272763761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:45:05',0,NULL,8,1,17,0,NULL,'pokupatelvasya86\rANCN001'),(10996,620717180013,230656400124,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','lesolide2','lesolide@hotmail.com','Bruno Lepage','176 Av. Du Manoir,app.2','Ile Bizard','QC','CANADA','h9c 2r4','(514) 915-2893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 13:13:05',0,NULL,3,1,3,1,'RA184581490CN\r ','lesolide2\rOTSA001'),(10997,844889403012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.99,'eastar4','boonie11794','boonie11795@gmail.com','Daniel Boonstra','11795 Cloverview Dr','Ravenna','MI','UNITED STATES','49451-9488','(231) 853-5795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 13:18:37',0,NULL,3,1,1,1,'\\ ','boonie11794\r美标'),(10998,565244718003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','recl5','bloomer503@hotmail.com','Paul Holm','503 Monroe Ave','Cloquet','MN','UNITED STATES','55720-1275','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-08 14:00:06',0,NULL,3,1,1,1,NULL,'recl5'),(10999,761549632011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','spowell044','sharon.borden@gmail.com','sharon borden','3701 S George Mason Dr<br>Unit 409N','Falls Church','VA','UNITED STATES','22041','(703) 340-5905','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 14:11:59',0,NULL,3,1,1,1,'\\ ','spowell044'),(11000,844915825012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','t-kurasz-2008','gikerr@o2.pl','Tomasz Kurasz','33 Alexandra grove','London','London','UNITED KINGDOM','n12 8he','02084454352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 14:12:27',0,NULL,3,1,2,1,NULL,'t-kurasz-2008\rAUI Transceiver  MX20T'),(11001,844920317012,220807295612,'3 pair 3D Active Shutter Glasses for Samsung SSG-2200AR',1,'GLOT004*3',132.99,'eastar4','discoweirdogreg','discoweirdo@hotmail.com','Greg Weir','239 konnongorring west road','Konnongorring','Western Australia','AUSTRALIA','6603','0427274895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 14:25:08',0,NULL,3,1,3,1,'RA184581455CN ','discoweirdogreg\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(11002,761555036011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','lokejul','ebay.ca@360pan.com','Julian Loke','130 Carlton Street Apt 1010','Toronto','ON','CANADA','M5A4K3','(416) 928-2733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 14:27:54',0,NULL,3,1,2,1,NULL,'lokejul'),(11003,620694922013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','alexey_elshin','frodo8787@mail.ru','Alexej El\'shin','Mikrorajon Shkol\'nij','Vlasiha','Moskovskaja Oblast\'','RUSSIAN FEDERATION','143010','(903)240-4226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 14:46:31',0,NULL,3,1,2,1,NULL,'alexey_elshin'),(11004,844936039012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',196.99,'eastar4','ogay','andrew_ogay@mail.ru','Andrey Ogay','Timiryazev st. 36 flat .10','Almaty','','KAZAKHSTAN','050090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 15:04:54',0,NULL,3,1,3,1,'RA184581367CN\r ','ogay\rGLSG001*4'),(11005,761569413011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',99.99,'eastar4uk','szanel38','sonika5@o2.pl','magda oleskiewicz','32 dartmouth avenue','bath','Avon','UNITED KINGDOM','ba2 1at','07593741329','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 15:07:08',0,NULL,3,1,3,1,'RA184581441CN ','szanel38\rGLSG001*3'),(11006,761573264011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','toms-secondhand','ebay@grundschober.at','Thomas Grundschober','Wiener Strasse 24','Stockerau','','AUSTRIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 15:18:47',0,NULL,3,1,2,1,NULL,'toms-secondhand'),(11007,761572380011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.99,'eastar4','nedkoivanov','regned@gmail.com','Nedko Ivanov','district Poligona block 35, entrance 1, apartment 1','Sofia','','BULGARIA','1784','+359888978448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 15:26:12',0,NULL,3,1,3,1,'RA184581438CN ','nedkoivanov\rGLSG001'),(11008,844948128012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','garryrhys123','grandmastagaz@aol.com','Garry Sage','Blaengarw Workmens Hall<br>Blaengarw','Bridgend','Bridgend','UNITED KINGDOM','CF32 8AW','01656871911','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 15:37:43',0,NULL,3,1,3,1,'RA184581319CN\r ','garryrhys123\rGLOT001*3\r兼容型3D眼镜 通用型'),(11009,761609194011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',43.16,'eastar4','brooks4015','brooks4015@netzero.com','william  Brooks','4015 Evans Chapel Rd','Baltimore','MD','UNITED STATES','21211-1639','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 16:46:56',0,NULL,3,1,1,1,NULL,'brooks4015'),(11010,761620193011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',35.99,'eastar4uk','portela82','kutenkind82@hotmail.com','John Portela','52/2 Macquarie rd','Auburn','New South Wales','AUSTRALIA','2144','0413249624','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 17:14:22',0,NULL,3,1,3,1,'RA184581407CN\r ','portela82\rOTSO004'),(11011,760535591011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',8.99,'eastar4','mykmyk86','soul@ukr.net','Mykola Gladchenko','2972 Columbia St<br>Ste 6682','Torrance','CA','UNITED STATES','90503-3806','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 17:21:14',0,NULL,3,1,1,1,'\\ ','mykmyk86'),(11012,845000943012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','saqi_0007','saqi_0007@yahoo.co.uk','Y Razaq','60 Spencer Rd','Bradford','West Yorkshire','UNITED KINGDOM','BD7 2EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 17:27:27',0,NULL,3,1,3,1,'RA184581398CN\r ','saqi_0007\rGLOT001*2\r兼容型3D眼镜 通用型'),(11013,761629021011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','wendybrad_2008','wendybrad@sbcglobal.net','Wendy Harrison','1224 east Cty M','River Falls','WI','UNITED STATES','54022','(612) 414-4275','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 17:38:17',0,NULL,3,1,1,1,NULL,'wendybrad_2008'),(11014,845011370012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','trecaabade','trecaa@virginmedia.com','Steven Roe','3 Proctor Road<br>Sprowston','Norwich','Norfolk','UNITED KINGDOM','nr67pe','01603412776','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 17:46:56',0,NULL,3,1,3,1,'RA184581543CN','trecaabade\rOTCN002'),(11015,845012649012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',9.9,'eastar4','manutenfruit','manutenfruits@gmail.com','Manuel Díez Frutos','1275 3rd St<br>Shreve Hall, Room 702','West Lafayette','IN','UNITED STATES','47906-4228','626 656 3439','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 17:49:57',0,NULL,3,1,1,1,NULL,'manutenfruit\racer 8pin1.0 3cm'),(11016,761637753011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','mjleal','lealm1@msn.com','Michael Leal','1029 Pine St','Palmer','MA','UNITED STATES','01069-1309','(508) 410-0125','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 17:51:50',0,NULL,3,1,1,1,NULL,'mjleal'),(11017,761660792011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','frank1002us','frank1002us@yahoo.com','a atighehchi','61 35 98 st<br>3n','rego park','NY','UNITED STATES','11374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 18:32:05',0,NULL,3,1,1,1,'\\ ','frank1002us'),(11018,721375701001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','rennykitenour','kenny_pegasusair@yahoo.com','Kenneth Ritenour','1560 Moffett Dr','Winchester','VA','UNITED STATES','22601-3186','(831) 435-5095','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 18:38:37',0,NULL,3,1,1,1,NULL,'rennykitenour'),(11019,0,110739901809,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',11.5,'buysia','fredy6125','fredy_darkjean@hotmail.es','Alfredo Martinez Carrillo','122 135th st','ocean city','MD','UNITED STATES','21842-4507','(443) 859-4620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 18:42:00',0,NULL,3,1,1,1,'\\ ','fredy6125'),(11020,845043373012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.5,'eastar4uk','icolea85','icolea@yahoo.com','Andrei Form','23<br>Barttelot Road','Horsham','West Sussex','UNITED KINGDOM','RH12 1DQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-08 18:43:11',0,NULL,3,1,3,1,'RA184581605CN\r ','icolea85\rOTHP003'),(11021,761674469011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','andross3000','andross3000@gmail.com','Anderson Yip','3074 San Fernando Way','Union City','CA','UNITED STATES','94587-2808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 19:03:39',0,NULL,3,1,1,1,'\\ ','andross3000'),(11022,565340112003,130554589408,'New Philips Sonicare toothbrush kit w/ Handle HX6930',1,'HBPH002+HBPH003+HBPH004',87.99,'cnfaner','idrissous','idriss@mec.etsmtl.ca','idriss ammara','5262 de lorimier','montreal','QC','CANADA','h2h 2c2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 19:26:52',0,NULL,3,1,3,1,'RA184581530CN\r ','idrissous\rHBPH002+HBPH003+HBPH004'),(11023,761710771011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','trondbrandsen','trond.gulbrandsen@gmail.com','Trond Gulbrandsen','Bekkenstenveien 40','Oslo','','NORWAY','0976','004790781895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 20:08:17',0,NULL,3,1,3,1,'RA184581795CN\r ','trondbrandsen\rOTSO004'),(11024,619189070013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','rpj05','rpj0555@iinet.net.au','Ryan Johnson','c/- Broens Pty Ltd<br>20 Williamson Road','Ingleburn','New South Wales','AUSTRALIA','2565','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 20:16:59',0,NULL,3,1,3,1,'RA184581415CN\r ','rpj05\rMOSA005'),(11025,565360461003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','mikie3865','mbeachman@aol.com','Mike Beach','2709 Date Palm Dr','Edgewater','FL','UNITED STATES','32141-5809','(386) 402-4757','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-08 20:30:39',0,NULL,3,1,1,1,NULL,'mikie3865'),(11026,761725747011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','jiggabebe','bryankoo@yahoo.com','Bryan Koo','1690 W 135th Dr','Westminster','CO','UNITED STATES','80234-1013','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 20:34:54',0,NULL,3,1,1,1,NULL,'jiggabebe'),(11027,620861132013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','mecuy','michael.uy@sbcglobal.net','Michael Uy','10 Universal City Plaza<br>Bldg 1440, 15th Flr / D12','Universal City','CA','UNITED STATES','91608','(323) 662-0641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 20:45:48',0,NULL,3,1,1,1,NULL,'mecuy'),(11028,845124139012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.9,'eastar4uk','daratach','michael.oberg@live.com','Michael Öberg','Limvägen 30','Sandarne','Hälsingland','SWEDEN','82022','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 21:05:19',0,NULL,3,1,2,1,'\\ ','daratach'),(11029,845126037012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','wujekstaszek12345','cienki7@wp.pl','Karl Kowalski','20 Garnish Square, Waterville<br>Blanchardstown','Dublin','Dublin','IRELAND','15','0872607586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 21:09:29',0,NULL,3,1,2,1,NULL,'wujekstaszek12345\rAUI Transceiver  MX20T'),(11030,638358559005,150657903085,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','dj_gate$','acarter-griffith@hotmail.com','Anderson Carter-Griffith','251 James Street West','Gravenhurst','ON','CANADA','p1p1j7','(705) 394-8781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 21:35:59',0,NULL,3,0,3,1,'RA184581424CN\r ','dj_gate$\r\r发货了，但点不了。'),(11031,843696198012,220815928685,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO003',21.9,'eastar4uk','mawmawwheat','dana.whitfield@centerpointenergy.com','Dana Whitfield','2781 S Columbia Rd<br>Ste D','Bogalusa','LA','UNITED STATES','70427-7962','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 21:52:49',0,NULL,3,1,1,1,NULL,'mawmawwheat\r旧的'),(11032,0,110739901902,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','marco73car','mrnaz67@msn.com','marco navarro','5685 91st Ave','pinellas park','FL','UNITED STATES','33782-5014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 21:54:10',0,NULL,3,1,1,1,NULL,'marco73car'),(11033,761758724011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','semyon415','samsherstinsky@yahoo.com','semyon sherstinsky','742 32nd Ave','san francisco','CA','UNITED STATES','94121-3502','(415) 386-0186','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 21:59:44',0,NULL,3,1,1,1,NULL,'semyon415'),(11034,761764104011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','filmcameraholic','asenru@gmail.com','Asen Rupchev','Lulin, bl. 907, entr. A, ap. 3','Sofia','','BULGARIA','1324','+359897839432','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 22:11:29',0,NULL,3,1,2,1,NULL,'filmcameraholic\r欧标'),(11035,845176992012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.9,'eastar4','mafiauno','mafiabike@yahoo.de','Pedro de Almeida','Eisenbahnstr.45','Stuttgart','','GERMANY','70372','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 23:31:36',0,NULL,3,1,2,1,NULL,'mafiauno\r4pin 1.25 '),(11036,761787291011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',17.6,'eastar4','berylie4','nannyluv@gmail.com','Beryl Turcich','2491 Kingsview Way','Carson City','NV','UNITED STATES','89703-5378','(775) 882-2150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 23:33:48',0,NULL,3,1,1,1,NULL,'berylie4'),(11037,845185641012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.9,'eastar4','mj_winterfall','bargrizoon@gmail.com','M.Javad  Talesh lar','Bartfai U.49. VI.EM.19','Budapest','Budapest','HUNGARY','1115','0036706612882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:01:31',0,NULL,3,1,2,1,NULL,'mj_winterfall\r华硕10pin 0.8 6cm '),(11038,761794583011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ncruze','ncruze@yahoo.com','Nnamdi Jideani','801 Rhode Island Ave NW<br>Apt 603','Washington','DC','UNITED STATES','20001-3176','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 00:01:35',0,NULL,3,1,1,1,NULL,'ncruze\r红边优联'),(11039,620912362013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.95,'eastar4','wdhop66','wdhop66@aol.com','Dwight Hopkins','317 Cambridge Rd','Pasadena','Md','UNITED STATES','21122','(443) 817-2166','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-09 00:04:42',0,NULL,3,1,1,1,'\\\r ','wdhop66'),(11040,0,110739901828,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',19.49,'buysia','tbg633storekeeper','twoblackpandas@yahoo.ca','Kenny Park','6412 Silver Ridge Way N.W.','Calgary','AB','CANADA','T3B3X6','(403) 510-7628','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:33:07',0,NULL,3,1,3,1,'RA184581512CN\r ','tbg633storekeeper\rBR3D006'),(11041,761806321011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','manny*marieclaude','morel.marie-claude@videotron.ca','marie claude morel','116 desjardins','ste anne des plaines','QC','CANADA','j0n1h0','(514) 850-1677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:47:02',0,NULL,3,1,2,1,'\\ ','manny*marieclaude'),(11042,620924856013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','pierob0143','piebu@yahoo.com','Piero Buitano','2903 Silverberry Trl','Kingwood','TX','UNITED STATES','77345-5445','(713) 569-5132','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 01:03:23',0,NULL,3,1,1,1,NULL,'pierob0143'),(11043,761811765011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','takascreations','takasfive@gmail.com','justin takas','144 huntington ct','hamburg','NY','UNITED STATES','14075','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 01:07:53',0,NULL,3,1,1,1,NULL,'takascreations'),(11044,721511967001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','barbarabatgirlnurse','batgirlnurse@zoominternet.net','barbara tackett','90 twp 1288','chesapeake','OH','UNITED STATES','45619','(304) 617-5627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 01:22:12',0,NULL,3,1,1,1,NULL,'barbarabatgirlnurse'),(11045,0,110739901879,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',15.5,'buysia','pipelion','occupie@chartermi.net','Allan Laidman','315 Valerie Ct','Essexville','MI','UNITED STATES','48732-1601','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 01:31:37',0,NULL,3,1,1,1,NULL,'pipelion'),(11046,845212515012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','maychen316','mchen316@gmail.com','YIHUI CHEN','3025 Courthouse Dr W<br>Apt 3B','West Lafayette','IN','UNITED STATES','47906-1039','(765) 714-0501','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'maychen316'),(11047,845212754012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','quixoticrick','mister.rickchen@gmail.com','Rick Chen','2211 Carleton St<br>Apt 17','Berkeley','CA','UNITED STATES','94704-3235','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 01:34:56',0,NULL,3,1,1,1,NULL,'quixoticrick'),(11048,845218018012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','tubut','tubut.tubut@gmail.com','Ruedi Aschwanden','261 East 11th Street','North Vancouver','BC','CANADA','V7L 2G8','(604) 307-1929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 01:51:47',0,NULL,3,1,2,1,'\\ ','tubut\racer 8pin1.00 8cm'),(11049,564842272003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','ubertrampy','surpluscommunications@hotmail.com','donald lavigne','1272 Market St<br>Rm 305','san francisco','CA','UNITED STATES','94102-4801','(408) 242-9042','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 01:51:54',0,NULL,3,1,1,1,NULL,'ubertrampy'),(11050,761830680011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','83electropro','electropro83@gmail.com','Colby Taylor','4100 E 50th St<br>Apt 509','Odessa','TX','UNITED STATES','79762','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 02:22:31',0,NULL,3,1,1,1,NULL,'83electropro'),(11051,761834242011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','miguelangelvalderramatorres','miguelangelvalderrama@yahoo.com','Miguel valderrama','9153 River Falls Dr','Fort worth','TX','UNITED STATES','76118-7764','214 886 6716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 02:34:35',0,NULL,3,1,1,1,NULL,'miguelangelvalderramatorres'),(11052,620792696013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','esperox','esperox42@hotmail.com','Nathan Roberson','2216 w 2075 n','Clinton','UT','UNITED STATES','84015-5714','(801) 645-7877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 02:39:28',0,NULL,3,1,1,1,NULL,'esperox'),(11053,845231695012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','orangealec7','alecbarnard@live.com','Alec Barnard','15516 30th Ave SE','Mill Creek','WA','UNITED STATES','98012-5889','(425) 343-3693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 02:40:47',0,NULL,3,1,1,1,NULL,'orangealec7'),(11054,761753524011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',20,'TRMX001',151.4,'eastar4','larscominc','larscominc@comcast.net','Yuriy Yakhnes','11706 Garrison Forest Rd','Owings Mills','MD','UNITED STATES','21117-2214','(410) 363-1452','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 02:59:29',0,NULL,3,0,4,1,'YW865546173CN ','larscominc\r已入库'),(11055,620952843013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','gustavolsj','gustavolsj@gmail.com','Gustavo Lozano','Lago armentia 54 col. anahuac<br>Del. Miguel Hidalgo','Mexico','Distrito Federal','MEXICO','11320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 03:10:24',0,NULL,3,1,2,1,'\\ ','gustavolsj'),(11056,761847704011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','poolekp','kylefpoole@gmail.com','Kyle Poole','11126 Calavar Dr','Austin','TX','UNITED STATES','78726','(512) 249-8384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 03:29:56',0,NULL,3,1,1,1,NULL,'poolekp'),(11057,620959287013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jhe900','hyoeun.jeong@gmail.com','HyoEun Jeong','38 Dudley Street','Asquith','New South Wales','AUSTRALIA','2077','0430300590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 03:44:51',0,NULL,3,1,3,1,'RA184581588CN\r ','jhe900\rMOSA005'),(11058,8881315540102448,111,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',0,'eastar4','iceberg457','ian_jones30@hotmail.com','Ian Jones','58 Runswick Rd<br>Brislington','Bristol','Bristol','UNITED KINGDOM','BS4 3HY','01179774015',NULL,NULL,NULL,'2011-09-09 03:48:22',0,NULL,3,1,3,1,'RA184581565CN\r ','TRMX003\r补发的'),(11059,761861112011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','cappy82288','rylmeyer@gmail.com','Ryan Meyer','1509 Pershing Pl<br>Apt B','Rolla','MO','UNITED STATES','65401-2679','(636) 328-6646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 04:35:34',0,NULL,3,1,1,1,'\\ ','cappy82288'),(11060,721552462001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','bud788','dtfreeden@sasktel.net','Duane Freeden','Box 533','Lampman','SK','CANADA','S0C 1N0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 04:36:53',0,NULL,3,1,3,1,'RA184581645CN ','bud788\rBR3D006'),(11061,761873132011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','mrtooongp','mrtooon@hotmail.com','Mr.Suebphong Tioyuenyong','336/3 Shijun.RD,  T.Naimaung,<br>A.MaungKhonkaen','Khonkaen','Khonkaen','THAILAND','40000','+6681-873-1990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 05:46:10',0,NULL,3,1,3,1,'RA184581659CN ','mrtooongp\r带碟的\rGLSG001*2'),(11062,761873586011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','michael16874','m.streck@online.de','Michael Streck','Forststrasse 18','Rheinfelden','','GERMANY','79618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 05:46:49',0,NULL,3,1,3,1,'RA184581628CN ','michael16874\rHBPH002'),(11063,845272824012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','gromkii1978','petrov.jevgeni@gmail.com','Jevgeni Petrov','Mahtra 12-40','Tallinn','Harjumaa','ESTONIA','13811','+3725169870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 05:59:39',0,NULL,3,1,2,1,'\\ ','gromkii1978\r黑色的'),(11064,620978113013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','tstar*','tstar@live.com.au','Tri Pham','33 South Rd','Braybrook','Victoria','AUSTRALIA','3019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 06:00:58',0,NULL,3,1,3,1,'RA184581574CN\r ','tstar*\rMOSA005'),(11065,565462157003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','2011bobsbobs','voronin_boris@mail.ru','Boris Voronin','Prospect Hudozhnikov, 31/1. app. 242','St.-Peterburg','','RUSSIAN FEDERATION','194295','921-182-7777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 06:01:48',0,NULL,3,1,3,1,'RA184581631CN ','2011bobsbobs\rMOOE002\r发OEM的'),(11066,761881957011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','alfmarquezpadilla','alfredobmp@prodigy.net.mx','ALFREDO MARQUEZ PADILLA','SENDERO DE LOS SAUCES 61<br>FRACCIONAMIENTO PUERTA DE HIERRO','ZAPOPAN','ZAPOPAN, JALISCO','MEXICO','45116','+523336112128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 06:47:10',0,NULL,3,1,2,1,'\\ ','alfmarquezpadilla'),(11067,721575543001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','lcab6039','lc2cab@aol.com','Leonardo Cabrera','50D 11th Ave','Key west','FL','UNITED STATES','33040-5869','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 06:59:41',0,NULL,3,1,1,1,'\\ ','lcab6039'),(11068,845285784012,220844128244,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',17.99,'eastar4','azza_langstone','aaron_langstone@hotmail.com','aaron langstone','11 karall street','ormeau','Queensland','AUSTRALIA','4208','0755466632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 07:09:06',0,NULL,3,0,2,1,'、 ','azza_langstone'),(11069,845286714012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','abraxasja','abraxasj@korea.com','JANG MIN HONG','Garwol-dong, Yongsan-gu,<br>14-60 samsung electronics service center','Yongsan-gu','Seoul','KOREA,REPUBLIC OF','140808','(82) 10-9198-1575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 07:17:04',0,NULL,3,1,2,1,'、\r\r ','abraxasja'),(11070,565471464003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.9,'cnfaner','felka_s','sevafeldman@yahoo.com','Seva Feldman','Asher bar levy 3/15','Petah Tikva','none','ISRAEL','49558','+972544346089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 07:25:23',0,NULL,3,1,3,1,'RA184581693CN ','felka_s\rWLDE001'),(11071,845291085012,220815931195,'New Logitech/Asus Limit MX518 MX 518 Gaming mouse USB',1,'MOLO004',26.5,'eastar4uk','redryzo123','zozosms2@btinternet.com','susan stuart','1 Elmdene Road','Kenilworth','Warwickshire','UNITED KINGDOM','CV8  2BW','07729895904','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 07:30:42',0,NULL,3,1,3,1,'RA184581614CN ','redryzo123\rMOLO004\r华硕限量版'),(11072,620990419013,230655991728,'New Portable Funny Wine Bottle Folding Sun Umbrella',1,'UM00030',10.99,'eastar4','turboambulance','alien4ux@gmail.com','Andrey Podgornov','Dobroslobodskaya 12-5','Moscow','Moscow','RUSSIAN FEDERATION','105066','+79265279951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 07:54:52',0,NULL,3,1,2,1,'\\\r ','turboambulance\r红酒瓶伞\r带小熊  的\r再发一把白色的带树的'),(11073,8881315555866683,111,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',0,'cnfaner','jvl082450','jvanliew@gmail.com','John Van Liew','10 Alta Hill Way','Walnut Creek','CA','UNITED STATES','94595','',NULL,NULL,NULL,'2011-09-09 08:11:06',0,NULL,3,1,3,1,'RA184581702CN ','补发的  只补发耳机一个 \rHSPL010'),(11074,845304361012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','sijones_uk','sijones2010@googlemail.com','Simon Jones','77 Westminster Road','Ellesmere Port','Cheshire','UNITED KINGDOM','CH65 2BX','07897490420','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 08:29:42',0,NULL,3,1,3,1,'RA184581680CN ','sijones_uk\rOTHP004'),(11075,845127214012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','biljanaandrejevic','andrejevic.sinisa@gmail.com','Andrejevic Sinisa','Kumodraska br.87','Belgrade','Serbia','SERBIA','11000','+381641429520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 08:33:26',0,NULL,3,1,3,1,'RA184581676CN\r ','biljanaandrejevic\r兼容型3D眼镜  samsung 专用\rGLOT004'),(11076,8881315559428465,111,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',0,'eastar4','nontouchs','non.touch@hotmail.com','Nontouch Srisuksa','70/29  Room 619 Soi Petchburi 7<br>Petchburi Road','Phyathai','Bangkok','THAILAND','10400','66891361048',NULL,NULL,NULL,'2011-09-09 09:10:28',0,NULL,3,1,3,1,'RA184581747CN ','补发的用原包装的盒子\rBAZA001\r '),(11077,621011787013,230576481551,'10 pcs AUI Ethernet 10Base-T RJ45 Transceiver track#',1,'TRMX003*10',75,'eastar4','elarauzo','elarauzo@hotmail.com','Camara Decimavilla, S.L. (Jairo Arauzo)','c/ Condado de Treviño, 71','BURGOS','BURGOS','SPAIN','09001','607477032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 09:40:54',0,NULL,3,1,3,1,'RA184581662CN\r ','elarauzo\rTRMX003*10\r'),(11080,845331427012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','faer9','jetro.saarti@gmail.com','Jetro Saarti','Ketunpolku 37','Kangasala','','FINLAND','36200','+358504989982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 10:12:44',0,NULL,3,1,3,1,'RA184559165CN\r ','faer9\rGLOT005'),(11078,761926634011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',19.99,'eastar4','46ford','dpscurti@earthlink.net','Don Scurti','1323 S Golden Vista Dr','West Covina','CA','UNITED STATES','91791-3727','(626) 919-8120','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 09:59:49',0,NULL,3,1,1,1,'\\ ','46ford\r西瓜伞 '),(11079,761928190011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.89,'eastar4','alebrelluem','blm_stgt_o@arcor.de','Bela Ludwig Müller','Werderstr.:28','Stuttgart','','GERMANY','70190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 10:01:45',0,NULL,3,1,3,1,'RA184588983CN\r ','alebrelluem\rGLOT004\r兼容型3D眼镜  samsung 专用'),(11081,761937328011,320730529602,'NEW Auto pop 3-section Sun umbrella  w/Paris Eiffel',1,'UM00015',24.99,'eastar4','aramyansuren','aramyan1940@mail.ru','Galina Radchenko','lane Sunny 4 a','Village Essentukskya','Stavropol territory','RUSSIAN FEDERATION','357350','8928-3679115','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 10:37:59',0,NULL,3,1,2,1,'、 ','aramyansuren\r银胶巴黎铁塔 \r酒红色'),(11082,845340164012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','morts.mum','joannemortimore@hotmail.co.uk','Joanne Luce','Frymaster Technical Service<br>First Floor, 9 North Street','Rugby','Warwickshire','UNITED KINGDOM','CV21 2AB','01788537111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 10:41:50',0,NULL,3,1,3,1,'RA184559593CN\r ','morts.mum\rOTGR001'),(11083,845343306012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',9,'CASS003',76.41,'eastar4','andre.iacono','lorenalive@hotmail.co.uk','Lorena Oliveira','SRTVS, Qd 701 - Bloco K - Sala 725<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 10:53:23',0,NULL,3,1,3,1,'RA184559545CN\r ','andre.iacono\rCASS003\rCAB-6060'),(11084,761956407011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','lostjackal42','info@discofealey.co.uk','William Fealey','1 Sycamore Close','Uttoxeter','Staffordshire','UNITED KINGDOM','ST14 7NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 11:43:26',0,NULL,3,1,3,1,'RA184559580CN\r ','lostjackal42\rCACN004'),(11085,570969756004,140550602491,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',146.99,'cnfaner','magnusofnorway','magnus@mgs.no','Magnus Strand','Badehusgata 41','Stavanger','','NORWAY','4014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 11:51:35',0,NULL,3,1,4,1,'YW865546512CN\r ','magnusofnorway\rEXLO001'),(11086,621009083013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','redwitem','anred80@mail.ru','Andrey Krasnov','ul. Yablonevaya<br>d. 17','Novocheboksarsk','Chuvashskaya respublika','RUSSIAN FEDERATION','429950','(8352)67-98-89','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 12:16:43',0,NULL,3,1,3,1,'RA184559222CN\r ','redwitem\rMOSA005'),(11087,761581611011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',98.99,'eastar4','gibadullin_erik','gibadullinerik@gmail.com','Erik Gibadullin','Komsomolskaya 28-97','Ufa','Bashkortostan','RUSSIAN FEDERATION','450098','+79373671446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 12:17:12',0,NULL,3,1,3,1,'RA184559085CN\r ','gibadullin_erik\rGLSG001*2'),(11088,621047572013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','b_bruce2009','b_bruce@live.com','justin bryce','42 penno parade north<br>belair','adelaide','South Australia','AUSTRALIA','5052','0882788192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 12:43:26',0,NULL,3,1,3,1,'RA184559148CN\r ','b_bruce2009\rMOSA005'),(11089,621048761013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',89.4,'eastar4','junkfinder99','junk900@aol.com','Edward Beck','2060 72nd St<br>Fl 1','Brooklyn','NY','UNITED STATES','11204-5819','(347) 426-7325','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 12:46:57',0,NULL,3,1,1,1,'\\ ','junkfinder99'),(11090,845381686012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','chandra_mad','ruben.tomas.alonso@gmail.com','Rubén Tomás Alonso','CMonseñor Oscar Romero Nº69 3ºD','Madrid','Madrid','SPAIN','28047','677626449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 12:50:27',0,NULL,3,1,2,1,'\\ ','chandra_mad\racer 6pin1.25 23cm '),(11091,621050375013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','4783alainb','alain@benzakin.net','BENZAKIN','ESPACE SFR<br>13 BD DE STRASBOURG','TOULON','Provence-Alpes-Côte d\'Azur','FRANCE','83000','0033611011515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 13:12:44',0,NULL,3,1,3,1,'RA184559151CN\r ','4783alainb\rMOSA005'),(11092,565536437003,130553375553,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',10.99,'cnfaner','sboralli','silvioboralli@terra.com.br','Silvio Boralli Rocha','Rua Lucio Costa, 636<br>Jardim Indaia','Embu','Sao Paulo','BRAZIL','06846-730','(5511) 8174-8120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 13:26:57',0,NULL,3,1,3,1,'RA184559324CN\r ','sboralli\rHSNO030'),(11093,761993550011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','ch4466','chris@herron.net','Craigy Hopkins','aql<br>11-15 Hunslet Road','Leeds','North Yorkshire','UNITED KINGDOM','LS10 1JQ','01512860602','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 13:37:25',0,NULL,3,1,3,1,'RA184554517CN\r ','ch4466\rUDAP001\r\r新地址\rChris Herron\r40 Vogan Ave\rCrosby\rLiverpool\rMerseyside   L23 0SQ\rUnited Kingdom\r\r\r'),(11094,845400415012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',21.99,'eastar4uk','markusglaser74','markusglaser74@yahoo.de','Markus Glaser','c/o Moosmann<br>Martin-Empl-Ring 10b','München','','GERMANY','81829','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 13:42:43',0,NULL,3,1,3,1,'RA184559443CN\r ','markusglaser74\rWWSI002+ANCN001'),(11095,761998229011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','innkeepersnakey','goodstuff18@comcast.net','cheryl a grono','883 Baltimore Pike','Chadds Ford','PA','UNITED STATES','19317-9305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 13:54:16',0,NULL,3,1,1,1,'\\ ','innkeepersnakey'),(11096,721684982001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','asiaromantik2009','lylong@hotmail.fr','ly long nyia yi','2717 Sebastan Ln','stockton','CA','UNITED STATES','95212-2847','(866) 824-6515','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 14:12:49',0,NULL,3,1,1,1,'\\ ','asiaromantik2009'),(11097,762005840011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',71.98,'eastar4','thehonestdad','eric@hatz.fsnet.co.uk','E Hatton','27 Elderberry Way<br>Almondsbury','Bristol','Avon','UNITED KINGDOM','BS32 4FH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 14:14:16',0,NULL,3,1,3,1,'RA184559488CN\r ','thehonestdad\rCCZG001+HBPH002\r再发一个 New Philips Sonicare flexcare toothbrush Handle HX6930 \r '),(11098,845421574012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','monsteragain11','monsteragain@gmail.com','Sergey Dubenko','12A Oktyabrskij avenue Apt 15','Mykolaiv','Mykolaivska oblast','UKRAINE','54034','0636399848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 14:44:24',0,NULL,3,1,3,1,'RA184554962CN\r ','monsteragain11\r兼容型3D眼镜 通用型'),(11099,762023683011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','bostonbuddy01','wjones5101@cfl.rr.com','William Jones','527 Pauma Valley Ct<br>Melbourne','Melbourne','FL','UNITED STATES','32940','(321) 544-3240','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 15:02:39',0,NULL,3,1,1,1,'\\ ','bostonbuddy01'),(11100,845440027012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','newterrestrial','mailmarat@gmail.com','Marat Seysenbayev','ul. Polyarnaya d.52 korpus 5. kv.25','Moscow','Moscow','RUSSIAN FEDERATION','127282','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,5,1,'CP235627808CN ','newterrestrial\r再发两条CAB2660\r十五条CAB6060'),(11101,762029572011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','jeremyporter.me','jporter.me@gmail.com','Jeremy Porter','112 penhallow st','portsmouth','NH','UNITED STATES','03801-3833','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 15:36:56',0,NULL,3,1,1,1,'\\ ','jeremyporter.me'),(11102,621093996013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','jocelico','jocelyn_labrie@hotmail.com','Jocelyn Labrie','2567 rue Montgomery','Montreal','QC','CANADA','H2K 2S3','(514) 524-2710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 15:42:13',0,NULL,3,1,2,1,'\\ ','jocelico'),(11103,762042927011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',2,'HBPH003',39.98,'eastar4','buellbuy','buellmail@charter.net','Julie Buell','3721 Ridglea Country Club Dr.','Fort Worth','TX','UNITED STATES','76116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 15:52:04',0,NULL,3,1,1,1,'\\ ','buellbuy'),(11104,762043291011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',25.47,'eastar4','mihrivode','praamar@hotmail.com','Amar Prasovic','Gaißacherstr. 17','München','','GERMANY','81371','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 15:53:11',0,NULL,3,1,2,1,'\\ ','mihrivode\rAmar Prasovic\rGaissacher Strasse 17\r81371 Munich\rGermany\r'),(11105,761515124011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.99,'eastar4','almentis1mbc','almentis@aol.com','Ann Mentis','PO Box 2881','Gulf Shores','AL','UNITED STATES','36547-2881','(251) 967-4706','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 16:03:56',0,NULL,3,1,1,1,'\\ ','almentis1mbc'),(11106,565583458003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','emmym18','k.connelly@yahoo.com','Kayla Barduca','42259 Fountain Park Dr N<br>Apt 230','Novi','MI','UNITED STATES','48375-2541','(248) 756-7577','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 16:36:33',0,NULL,3,1,1,1,'\\ ','emmym18'),(11107,621111222013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','yoav_seg1','segman@gmail.com','Yoav Segman','kipodan 23 Apt\' 1','modiein','israel','ISRAEL','71705','(972)-57-6633353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 16:41:33',0,NULL,3,1,3,1,'RA184559430CN\r ','yoav_seg1\rWWOT001+ANCN001'),(11108,845476589012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','rratravismansfield','tra.man@randyreed.com','Travis Mansfield','9550 NW Prairie View Rd<br>Randy Reed Buick Gmc','Kansas City','MO','UNITED STATES','64153-1816','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 16:52:17',0,NULL,3,1,1,1,'\\ ','rratravismansfield'),(11109,621119085013,230646252028,'New Philips Sonicare toothbrush kit w/ Handle HX6930',1,'HBPH002+HBPH003+HBPH004',87.99,'eastar4','bonneyantiques','antiques1@bonney.org','Bonney Antiques','16 Oliver St<br>Apt 2','Watertown','MA','UNITED STATES','02472-4715','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 17:05:49',0,NULL,3,1,1,1,'\\  ','bonneyantiques'),(11110,845492470012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','tmonno25852','gearhead528@aol.com','timothy monno','2905 preston ave','alexandria','VA','UNITED STATES','22306-1728','(703) 768-1420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 17:30:36',0,NULL,3,1,1,1,'、 ','tmonno25852  LK100550575CN'),(11111,845495434012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.4,'eastar4','bnydam42','bnydam42@hotmail.com','Brad Nydam','11270 Cascade Rd','Lowell','MI','UNITED STATES','49331','(616) 901-8118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 17:35:35',0,NULL,3,1,1,1,'\\ ','bnydam42'),(11112,762087806011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','kcs9022','kcs9022@earthlink.net','Keith C Shepherd','20023 Labrador St','Chatsworth','CA','UNITED STATES','91311-5536','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 17:40:13',0,NULL,3,1,1,1,'\\ ','kcs9022'),(11113,762088339011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','jkh23','johnholweger@hotmail.com','John Holweger','1105 Landeco Ln<br>Apt 28','Grand Forks','ND','UNITED STATES','58201-8717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 17:41:39',0,NULL,3,1,1,1,'\\ ','jkh23'),(11114,762090324011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','aniaowca1','ania_owca1@interia.pl','Anna Golab','1 Houfton Crescent','Bolsover','Derbyshire','UNITED KINGDOM','s44 6bp','07756369929','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 17:44:59',0,NULL,3,1,3,1,'RA184559355CN\r ','aniaowca1\rGLOT001\r兼容型3D眼镜 通用型'),(11115,565603974003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','lazlo_hollifeld','lazlo_hollifeld@hotmail.com','Jason Costa','375 Ralph McGill Blvd NE<br>Apt 1507','Atlanta','GA','UNITED STATES','30312-1249','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 17:51:27',0,NULL,3,1,1,1,'\\ ','lazlo_hollifeld'),(11116,565387497003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','oromirio','roman.opalko@gmail.com','Roman Opalko','Stroitelej 14/5','Kiev','','UKRAINE','02100','+380634153739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 18:01:50',0,NULL,3,1,3,1,'RA184559457CN\r ','oromirio\rHSUE002'),(11117,762102352011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',179.97,'eastar4','juifar','juifa@hotmail.com','JAVED AKHTER','P.O.Box.9887,Saudi Binladin Group,Sulaimaniya.(Abrugragama)','Jeddah','Not Applicable','SAUDI ARABIA','21423','00966502529539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 18:11:14',0,NULL,3,1,3,1,'RA184559077CN\r ','juifar\rGLSG001'),(11118,762109291011,320441575447,'2.1 Acer Aspire 7730 7730G 7730Z Bluetooth Module+cable',1,'BTAC2112',12.4,'eastar4','andreasstachel','andreasstachel@web.de','Andreas Dorn','Packstation 101<br>Kundennummer 36698524','Aken/Elbe','','GERMANY','06385','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 18:24:56',0,NULL,3,1,2,1,'\\ ','andreasstachel\racer 5pin1.25 4cm'),(11119,571071964004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','fxdx2000','tddockery2@hotmail.com','Thomas D. Dockery II','63 Keokuk Rd','Royersford','PA','UNITED STATES','19468','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 18:33:20',0,NULL,3,1,1,1,'\\ ','fxdx2000'),(11120,845531636012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','anna-banana76','anna-banana1@hotmail.com','Gleb Yenin','15001 Lexington Farms Dr','Alpharetta','GA','UNITED STATES','30004','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 18:40:33',0,NULL,3,1,1,1,'/  ','anna-banana76\r蓝天白云长柄伞 '),(11121,845533707012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','mojocomp','m.mcclelland@talktalk.net','MCCLELLAND MAUREEN','16 BERNARD ROAD<br>EDLINGTON','DONCASTER','South Yorkshire','UNITED KINGDOM','DN12 1LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 18:47:56',0,NULL,3,1,3,1,'RA184559386CN\r ','mojocomp\rSCLO004'),(11122,762123936011,320730087487,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'OTCN005',87.99,'eastar4uk','itology','john.wood@itologysystems.com','John Wood','10 Gulvain Place, Chadderton park','Oldham','Greater Manchester','UNITED KINGDOM','OL90NB','07808474408','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 18:54:48',0,NULL,3,0,3,1,'RA184559240CN\r ','itology\rEXLO001\r已入库'),(11123,621188986013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','dugsbid','dougsbid@teksavvy.com','Doug Stuebing','#413 - 11 Overlea Dr (Door buzzer #216)','Kitchener','ON','CANADA','N2M 5C8','(519) 745-8913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 20:32:01',0,NULL,3,1,2,1,'\\ ','dugsbid'),(11124,845592701012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',140.99,'eastar4uk','stevet4615','stevie_tighe@yahoo.ie','Steve Tighe','36 Broadford Hill','Ballinteer','Dublin','IRELAND','16','012142124','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 20:41:40',0,NULL,3,1,6,1,'EE495359450CN\r','stevet4615'),(11125,621194082013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','gumer2k','rxastre@gmail.com','Rafael Perez Xastre','Rua Domiciano Leite Ribeiro, 51 - Apto 43 - Bloco 1<br>Vila Guarani','Sao Paulo','São Paulo','BRAZIL','04317-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 20:48:14',0,NULL,3,1,2,1,'\\ ','gumer2k'),(11126,762186520011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','htk33','harry@fixmecar.com','Harry Krummrey','2850 Airport Rd','Jackson','MI','UNITED STATES','49202-1253','(517) 262-3443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 21:10:45',0,NULL,3,1,1,1,'\\ ','htk33'),(11127,762200466011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','dfmepaybackshell','bigtallguitarist@earthlink.net','Jimmy Ray','9051 Cub Run Dr','Concord','NC','UNITED STATES','28027-5407','(704) 425-3195','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 21:49:20',0,NULL,3,1,1,1,'\\ ','dfmepaybackshell'),(11128,762199440011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',177.99,'eastar4','emanraik','emanraikes@gmail.com','Emanuel Novais','Parque Residencial Fonte Seca lot 6B segundo direito','Braga','Fraião','PORTUGAL','4715-229','00351919295078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 21:51:36',0,NULL,3,1,3,1,'RA184559196CN\r ','emanraik\rOTSO004*3'),(11129,762216553011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','cactusman77','mattpops77@hotmail.com','matt popplewell','23 kings road','hayling island','Hampshire','UNITED KINGDOM','PO110PD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 22:38:46',0,NULL,3,1,3,1,'RA184559465CN\r ','cactusman77\rHBPH002'),(11130,621224120013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','wit1311','st-witus@mail.ru','Виталий Шорстов','м-н Южный д.10 кв.8','Старый Оскол','Белгородская обл','RUSSIAN FEDERATION','309507','+79045389700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 22:52:40',0,NULL,3,1,3,1,NULL,'wit1311\r欧标\rHSNO019'),(11131,621229519013,230641258112,'New lady lace trim sun/rain stick Umbrella pink',1,'UM00011',24.99,'eastar4','thuongthuong04','lyndalee04@yahoo.com','Lynda Lethuy Phamlee','4555 N Pershing Ave<br>Ste 31','Stockton','CA','UNITED STATES','95207-6743','(209) 298-2950','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 23:16:17',0,NULL,3,1,1,1,'、 ','thuongthuong04\r给他发个其他颜色的吧  红色的'),(11132,621238142013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',2,'GLOT001*3',265.98,'eastar4','kauaidavis','scott.francini@gmail.com','scott davis','459 Crystal Spring Dr','Draper','UT','UNITED STATES','84020-5300','(801) 556-7771','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 00:01:55',0,NULL,3,1,6,1,'EE495359429CN','kauaidavis\r兼容型3D眼镜 通用型\r\r'),(11133,621241028013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.76,'eastar4','kelleymiller05','kelley@millerfive.net','Kelley Miller','1608 Mulberry Rd','Saint Cloud','MN','UNITED STATES','56303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 00:18:05',0,NULL,3,1,1,1,'\\  ','kelleymiller05'),(11134,845670878012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','fionaoz','fionaoz@optusnet.com.au','Fiona King','8 Bristow Drive','Forest Hill','Victoria','AUSTRALIA','3131','61398930147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 00:42:22',0,NULL,3,1,3,1,'RA184559205CN\r ','fionaoz\rOTSO004*2'),(11135,845678056012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',4,'WLAT009',39.92,'eastar4','sk_dreams','sarabjit376@yahoo.com','Sarabjit Khanuja','5488 Marvell Ln<br>Bldg-2, 4th Floor, 2.4.132','Santa Clara','CA','UNITED STATES','95054-3606','(973) 978-4178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 01:09:00',0,NULL,3,1,1,1,'\\  ','sk_dreams'),(11136,721909209001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','lhg27','calilhg@yahoo.com','Chris E. Fortune','11165 Dell Cliffs Ct','Las Vegas','NV','UNITED STATES','89144-1643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 01:11:41',0,NULL,3,1,1,1,'\\ ','lhg27'),(11137,762251817011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',2,'ANTY002',5.98,'eastar4uk','iosif_g','giosif@gmail.com','George Iosif','Flat 17, Shelley Court<br>46 London Road','Reading','Berkshire','UNITED KINGDOM','RG15DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 01:06:00',0,NULL,3,1,3,1,'RA184559369CN\r ','iosif_g\rANTY002'),(11138,571177078004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.99,'cnfaner','rh073','ricntrud@tpg.com.au','Ricky Harvey','4 Emuglen Place','Brisbane','Queensland','AUSTRALIA','4055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 02:36:41',0,NULL,3,1,3,1,'RA184559885CN\r ','rh073\rOTTP001'),(11139,621264300013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Mahalaxmi Majumdar','327 Monroe St<br>Apt 2','Hoboken','NJ','UNITED STATES','07030-6691','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 02:42:47',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11140,621267841013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','audradonoghue','audra.donoghue@bigpond.com','tim donoghue','PO BOX 240','LOWER PLENTY','Victoria','AUSTRALIA','3093','0400139744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 02:45:42',0,NULL,3,1,2,1,'\\ ','audradonoghue'),(11141,621267893013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Joey Luder','9104 CHIVALRY CT','FRISCO','TX','UNITED STATES','75033-7167','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 02:48:29',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11142,621269751013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Chris Burtner','1014A Carlyon Ave SE','Olympia','WA','UNITED STATES','98501-3506','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 02:58:57',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11143,621270629013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Michael Kuskin','1718 STATE ROUTE 71','BELMAR','NJ','UNITED STATES','07719-3140','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 03:05:59',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11144,762290162011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','kikijijimarkc','kikijijimark@gmail.com','Kiyomi Ishii','5-6-45-615 Toyosu<br>Koto-ku','Tokyo','Tokyo','JAPAN','135-0061','81-3-5560-3577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 04:07:52',0,NULL,3,1,3,1,'RA184559412CN\r ','kikijijimarkc\rHBPH002'),(11145,621289787013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.4,'eastar4','rescuer_thor','thorwm@yandex.ru','Сергей Третейкин','ул. Школьная д.124 кв.60','Санкт-Петербург','','RUSSIAN FEDERATION','197374','+7(950)0310375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 05:17:38',0,NULL,3,1,2,1,'\\ ','rescuer_thor\racer 4pin1.25 15cm '),(11146,762303475011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','bostonguitarproject','slguitarist@gmail.com','Steven Lin','11083 Bel Aire Ct','Cupertino','CA','UNITED STATES','95014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 05:27:27',0,NULL,3,1,1,1,'\\  ','bostonguitarproject'),(11147,0,120773423831,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',42,'buysia','stevedadrummer','stevedadrummer@hotmail.com','Steven Jackson','303 South Forth St.','Alvin','TX','UNITED STATES','77511','(979) 549-7864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 05:52:27',0,NULL,3,1,1,1,'\\ ','stevedadrummer'),(11148,621303249013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','suwichak','hirunrat@hotmail.com','Suwichak Buengprasoetsuk','80/91 The Emerald Garden 4,<br>Ratcha Phruek Rd. ,Bang Phlap','Pak Kret','Nonthaburi','THAILAND','11120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 06:58:20',0,NULL,3,1,2,1,'\\ ','suwichak'),(11149,571216172004,140583346708,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',46,'cnfaner','ctamoi23','ctamoi@hotmail.com','Daniel Hebert','86 de la chasse galerie','Quebec','QC','CANADA','g1b1y3','(418) 686-0849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 07:52:38',0,NULL,3,1,3,1,'RA184559505CN\r ','ctamoi23\rOTPL001'),(11150,621314811013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','sheffer85','freakazoid85@gmail.com','amit sheffer','hafikus 13','oranit','','ISRAEL','44813','0505-624639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:10:37',0,NULL,3,1,2,1,'\\ ','sheffer85'),(11151,638854965005,150657903085,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','holdens_4ever_2007','holdenbronco08@gmail.com','Andrew Huet','87 O\'quinn Street','Toowoomba','Queensland','AUSTRALIA','4350','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-10 08:12:20',0,NULL,3,0,3,1,'RA184559426CN\r ','holdens_4ever_2007\r'),(11152,762335614011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',1,'HSSE009',65.99,'eastar4','milamber621','brenton.reimann@fusion.org.au','Brenton Reimann','PO BOX 841','WODEN','Australian Capital Territory','AUSTRALIA','2606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:13:44',0,NULL,3,1,3,1,'RA184559871CN\r ','milamber621\rHSSE009\r澳标'),(11153,845773878012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.97,'eastar4','sirgeoffrey0_0','geoffreysfox@hotmail.com','GEOFFREY FOX','70 ARCTIC ROAD','COWES','Isle of Wight','UNITED KINGDOM','PO317PF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:33:13',0,NULL,3,1,2,1,'\\ ','sirgeoffrey0_0'),(11154,621320075013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',5.96,'eastar4','maximgm','maxx_kyiv@ukr.net','Maksym Goruk','pr-t Georgiya Gongadze, 7, ap. 74','Kyiv','','UKRAINE','04208','+380674475501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:40:13',0,NULL,3,1,17,0,'\\ ','maximgm'),(11155,621320308013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','maximgm','maxx_kyiv@ukr.net','Maksym Goruk','pr-t Georgiya Gongadze, 7, ap. 74','Kyiv','','UKRAINE','04208','+380674475501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:41:38',0,NULL,3,1,2,1,'\\ ','maximgm\r在发两个3G WWAN antenna\rANCN001'),(11156,762344521011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.99,'eastar4','danyl_off','danyloff@gmail.com','Andrew Danilov','Gagarin st. 33-2','Demyansk','Novgorod region','RUSSIAN FEDERATION','175310','(906)2008800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:43:05',0,NULL,3,1,17,0,'\\ ','danyl_off'),(11157,845777536012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','danyl_off','danyloff@gmail.com','Andrew Danilov','Gagarin st. 33-2','Demyansk','Novgorod region','RUSSIAN FEDERATION','175310','(906)2008800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:47:13',0,NULL,3,1,2,1,'\\ ','danyl_off\r\r欧标\r再发一个NEW  NOKIA BH-203 \rHSNO007'),(11158,621323421013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','helenamar','helporo@hotmail.com','Helena Poropat','13 Wolli Avenue<br>Earlwood','Earlwood','New South Wales','AUSTRALIA','2206','0000000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:59:11',0,NULL,3,1,2,1,'\\ ','helenamar'),(11159,845782328012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',26.99,'eastar4uk','vedder_eleven','ruben11.castro@hotmail.com','hugos Pet House','Rua S. Joao Baptista RC Loja sul<br>S. João Ponte','Guimarães','guimarães','PORTUGAL','4805-091','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 09:03:09',0,NULL,3,1,3,1,'RA184559267CN\r ','vedder_eleven\rGLOT004\r兼容型3D眼镜  samsung 专用'),(11160,621324465013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','dnkybe','dannykyoto@gmail.com','Mahazani Mohamad','Dept of Electrical Engineering,<br>Faculty of Engineering, University of Malaya','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50603','0162099075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 09:03:17',0,NULL,3,1,2,1,'\\ ','dnkybe'),(11161,845786287012,220449147548,'Samsung R18 R20 R25 Bluetooth Module 2.0 EDR+cable',1,'BTSA2003',9.9,'eastar4','mojaec','butyrin07@bk.ru','alexandr butyrin','gorodok, dom 64, kvartira 35','Kolomna-1','Moskovskaya oblast','RUSSIAN FEDERATION','140401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 09:17:04',0,NULL,3,1,2,1,'\\ ','mojaec'),(11162,845791092012,220815931195,'New Logitech/Asus Limit MX518 MX 518 Gaming mouse USB',1,'MOLO004',26.5,'eastar4uk','pilzbauer','gelberdoktor@web.de','Alexander Schütz','Saarstraße 98','Nalbach','','GERMANY','66809','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 09:35:07',0,NULL,3,1,3,1,'RA184559749CN\r ','pilzbauer\rMOLO004\r华硕限量版'),(11163,845794876012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','raminzarei','raminzarei@hotmail.com','ramin zarei','4 mariner drive','sheidow park','South Australia','AUSTRALIA','5158','0883878446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 09:46:39',0,NULL,3,1,3,1,'RA184559275CN\r ','raminzarei\rGLOT001\r兼容型3D眼镜 通用型'),(11164,571237368004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','david.hdmovies','david.brouwers.nz@gmail.com','David Brouwers','14 Opal Place<br>Casebrook','Christchurch','','NEW ZEALAND','8051','(643) 963-5429','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 09:55:32',0,NULL,3,1,3,1,'RA184559783CN\r ','david.hdmovies\rWLDE002'),(11165,845812021012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','supersaq','syed_saqab@hotmail.com','syed saqab','28 cambridge road<br>seven kings','Ilford','Essex','UNITED KINGDOM','ig38lu','02085977534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 10:43:33',0,NULL,3,1,3,1,'RA184559032CN\r ','supersaq\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11166,762378173011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','jodz22','xxjodiexx150@hotmail.com','Jodie Clement','58 Richard Street','Maerdy','Rhondda Cynon Taff','UNITED KINGDOM','CF43 4AN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 10:44:07',0,NULL,3,1,3,1,'RA184559718CN\r ','jodz22\rRELO003\r红边优联'),(11167,845815235012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','fotojunk','wjpostma@ziggo.nl','Wim Postma','Schaepmanstraat 49','HOOGEZAND','','NETHERLANDS','9602GS','0613352323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 10:51:15',0,NULL,3,1,3,1,'RA184559298CN\r ','fotojunk\rGLOT004\r兼容型3D眼镜  samsung 专用'),(11168,762381208011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','karim2020','karim_kmchich@yahoo.co.uk','karim Mchich','5 cecile park','London','London','UNITED KINGDOM','n8 9ax','07590276561','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 10:55:39',0,NULL,3,1,3,1,'RA184559562CN\r ','karim2020\rGLSG001'),(11169,845818508012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','d.foussat','damienfoussat@hotmail.com','damien foussat','17 Rue de Geneve','Saint genis pouilly','Rhône-Alpes','FRANCE','01630','0675222103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 11:03:49',0,NULL,3,1,3,1,'RA184559063CN\r ','d.foussat\rGLSG001*3'),(11170,762389063011,320745265525,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',15.95,'eastar4','chimppaul','paul.dutton5@btopenworld.com','Paul Dutton','18 Devonshire Place<br>Handbridge','Chester','Cheshire','UNITED KINGDOM','CH4 7BZ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-10 11:20:34',0,NULL,3,1,2,1,'\\ ','chimppaul\r蓝天白云长柄伞'),(11171,845833316012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','ramiz5561','kaktus_25@hotmail.com','R.Trtovac','Jacob Klaaijsenstraat 16','goes','','NETHERLANDS','4461VL','0031619693985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 11:44:57',0,NULL,3,1,3,1,'RA184559253CN\r ','ramiz5561\rGLOT005'),(11172,845842257012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',49.9,'eastar4','milod9','miloslav.konecny@homesweethome.cz','Miloslav Konecny','Home Sweet Home<br>Jindrisska 17','Prague 1','Prague','CZECH REPUBLIC','11000','+420732972196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 12:14:38',0,NULL,3,1,3,1,'RA184559721CN\r ','milod9\rWWOT002'),(11173,845848972012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','wodzu_44','bartas_23@o2.pl','Bartosz Mindak','9 Finedon Road','Wellingborough','Northamptonshire','UNITED KINGDOM','NN8 4EB','07928361240','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-10 12:30:20',0,NULL,3,1,2,1,'\\ ','wodzu_44\r24K 多色伞'),(11174,762413907011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','brendansdad19','andycook19@verizon.net','Andrew W Cook','16 Whitman Dr','Chatham','NJ','UNITED STATES','07928-1711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 12:40:08',0,NULL,3,1,1,1,'\\  ','brendansdad19'),(11175,762425405011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','pbk6','pk@kemmis.net','Patrick Kemmis, Thousand Suns Ltd','2nd Floor, 19 Britton Street','London','London','UNITED KINGDOM','EC1M 5NQ','07973381157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:13:54',0,NULL,3,1,3,1,'RA184559806CN\r ','pbk6\rHBPH002'),(11176,762428426011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',119.98,'eastar4','tarkustws','sigbres@zeelandnet.nl','Tonny Sigmond','Ghistelkerke 113','BRESKENS','','NETHERLANDS','4511JD','0031 117 385014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:22:52',0,NULL,3,1,3,1,'RA184559409CN\r ','tarkustws\rOTSO004'),(11177,762429135011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','jumartinez449','jumartinez449@hotmail.com','JUAN MARTINEZ','449 E Arenas Rd<br>Apt 716','PALM SPRINGS','CA','UNITED STATES','92262-6664','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 13:24:21',0,NULL,3,1,1,1,'\\  ','jumartinez449'),(11178,762432570011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','mwynn1919','mwynn312@aol.com','morris wynn','1919 veterans pkwy','columbus','GA','UNITED STATES','31904-8902','(706) 681-9638','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 13:36:19',0,NULL,3,1,1,1,'\\ ','mwynn1919'),(11179,621382143013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','diego.ospina','dospinah@netscape.net','Diego Ospina Hernández CBOX 122218BB0CO','1770 NW 96th Ave.<br>SUITE CBOX 122218BB0CO','Doral','FL','UNITED STATES','33172-2317','(786) 206-5300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 13:40:02',0,NULL,3,1,1,1,'\\  ','diego.ospina'),(11180,621385750013,230658778017,'Original Yamaha AV Remote control RAV255 WE45880 EU',1,'RCYA001',43.99,'eastar4','zandenm2011','zanden.m.vd@gmail.com','Mark van der Zanden','koekoekstraat 36','Utrecht','','NETHERLANDS','3514CX','0624871886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:46:52',0,NULL,3,1,3,1,'RA184559559CN\r ','zandenm2011\rRCYA001'),(11181,621387283013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',79.9,'eastar4','adrianc82','adrian.daniel.collins@gmail.com','Adrian Collins','Level 8<br>30 The Esplanade','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:53:40',0,NULL,3,1,3,1,'RA184559117CN\r ','adrianc82\rMOSA004'),(11182,571271018004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.09,'cnfaner','andreitallinn2009','underground.83@mail.ru','Andrei Gassilin','Jaama 177 - 32','Tartu','Tartumaa','ESTONIA','50705','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:59:57',0,NULL,3,1,3,1,'RA184559735CN\r ','andreitallinn2009\r欧标\rHSNO005'),(11183,565832957003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jsetrucking','jsetrucking@yahoo.com.ar','sergio castano','308 Birchwood Dr','Orem','UT','UNITED STATES','84057-4107','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-10 14:02:06',0,NULL,3,1,1,1,'\\ ','jsetrucking'),(11184,845885700012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','tryname','tryname@dasatec.at','DASATEC Sicherheitstechnik GmbH','Ketzergasse 278<br>06766286178','Wien','','AUSTRIA','1230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 14:10:41',0,NULL,3,1,2,1,'\\ ','tryname\r黑色的'),(11185,0,110739901856,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',51,'buysia','salika','steve@kelpmonster.com','Steven John Salika','110 Cardiff Ct','Santa Cruz','CA','UNITED STATES','95060-2434','(831) 469-9741','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 14:23:41',0,NULL,3,1,1,1,'\\ ','salika'),(11186,0,110739901867,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',43.99,'buysia','warlordd10','warlord@cgocable.ca','mark lamothe','369 rue marceau','thetford mines','QC','CANADA','g6g 1r1','(418) 331-0717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 14:24:26',0,NULL,3,1,3,1,'RA184559695CN\r ','warlordd10\rBR3D002'),(11187,762451829011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','surfinglifeguard2fgo','surfinglifeguard@aol.com','Megan Field','3317 Whitesworth Rd','Phoenix','MD','UNITED STATES','21131-1401','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 14:28:09',0,NULL,3,1,1,1,'\r\\ ','surfinglifeguard2fgo'),(11188,845895171012,220448653799,'Acer Aspire 5540 5542 Bluetooth Module 2.0 EDR + cable',1,'BTAC2002',9.9,'eastar4','1061terry','terrytubby@yahoo.com','Terry Potter','ISS Facility  workshop C/O Hewlett Packard<br>Amen Corner Cain Road','Bracknell','Berkshire','UNITED KINGDOM','RG12 1HN','07785545568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 14:30:30',0,NULL,3,1,2,1,'\\ ','1061terry\racer 4pin1.25 4cm'),(11189,845904305012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',140.99,'eastar4uk','rishad_uddin','rishad.uddin@live.com','Rishad Uddin','5 Lymington Close','Coventry','West Midlands','UNITED KINGDOM','CV65TG','07851338740','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 14:57:44',0,NULL,3,1,6,1,'EE495359415CN\r ','rishad_uddin\r'),(11190,565849411003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',13.45,'cnfaner','masterfiasco5','dpubrat@yahoo.ca','David Pubrat','448 Southland Crescent','Oakville','ON','CANADA','L6L3N8','(416) 436-7922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 15:06:54',0,NULL,3,1,3,1,'RA184559908CN\r ','masterfiasco5\rHSUE004'),(11191,762467108011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','chiffawn','chiffawnp@hotmail.com','Chiffawn Poulin','1764 Bayswater Cres.','London','ON','CANADA','N6G5M9','(519) 473-8750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 15:07:44',0,NULL,3,1,2,1,'\\ ','chiffawn'),(11192,621408064013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','josjos1412','josjos@telefonica.net','jose rodriguez castaño','c/ espigol nº12','lliça de vall','Barcelona','SPAIN','08185','938439119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 15:08:36',0,NULL,3,1,2,1,'\\ ','josjos1412'),(11193,845910842012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',70.99,'eastar4uk','kelanbonbelan','matthew@cattaway.com','Matthew Cattaway','David Lloyd Heston<br>Southall Lane','London','London','UNITED KINGDOM','TW5 9PE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 15:10:05',0,NULL,3,1,3,1,'RA184559182CN\r ','kelanbonbelan\rOTSO004*2'),(11194,845923463012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','agent-309','melkeinkiltti@gmail.com','Tuomas Pentinmäki','Keskisenkatu 8 B 40','Tampere','','FINLAND','33710','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 15:38:58',0,NULL,3,1,2,1,'\\ ','agent-309\r欧标'),(11195,845922996012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',2,'GLOT004*2',105.98,'eastar4uk','jing2005ch','dingjing_sz@yahoo.com.cn','Jing2005ch','Flat 12, 220<br>Harbourne Park Road','Birmingham','West Midlands','UNITED KINGDOM','B17 0BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 15:42:25',0,NULL,3,1,6,1,'EE495359401CN ','jing2005ch\r兼容型3D眼镜  samsung 专用\r\r'),(11196,762483451011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','firstone957','vorlonus@mail.ru','Maxim Tarasevich','ul. Uzhno-Moravskaya d.13 kv.148','Voronezh','Voronezhskaya oblast','RUSSIAN FEDERATION','394065','+7-920-461-17-77','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 15:48:19',0,NULL,3,1,3,1,'RA184559284CN\r ','firstone957\rOTSO004'),(11197,722120528001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','embosstech','mccain@nc.rr.com','Matthew McCain','156 Mc Wilder Rd','Louisburg','NC','UNITED STATES','27549-7521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 15:51:20',0,NULL,3,1,1,1,'\\ ','embosstech'),(11198,621423062013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','jpetion77','wesleyfel@yahoo.com','Jean Petion','2030 NW 124th St','Miami','FL','UNITED STATES','33167-2020','(305) 761-7393','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 15:58:59',0,NULL,3,1,1,1,'\\ ','jpetion77'),(11199,845934620012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','vitodin1979','vitodin@gmail.com','Yevgeniy Vytiagov','Komsomolskaya street 3-40','Odintsovo','MOSCOW REGION','RUSSIAN FEDERATION','143006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 16:05:50',0,NULL,3,1,2,1,'\\ ','vitodin1979'),(11200,845946053012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.24,'eastar4','mr-fiero123','curtis@mr-fiero.com','mr-fiero.com','Box 11','Raymond','AB','CANADA','t0k 2s0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 16:26:57',0,NULL,3,1,2,1,'\\ ','mr-fiero123\r白色的'),(11201,722142965001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','dolomb12bx','dolomb@aol.com','Dolores E. Biggett','9077 Whitfield Dr','Estero','FL','UNITED STATES','33928-4409','(239) 949-1158','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 16:51:17',0,NULL,3,1,1,1,'\\ ','dolomb12bx\rDolores Biggett\r6312 Colonial View\rFairburn, GA 30213'),(11202,621440952013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','lordmoya','lordmoya@hotmail.com','Eduardo Moya','1636 Peregrine falcons way<br>Apt 203','orlando','FL','UNITED STATES','32837-8048','(407) 844-3580','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 16:54:58',0,NULL,3,1,1,1,'\\ ','lordmoya\r黑色的'),(11203,762519198011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.99,'eastar4','kamilla_m','kamilla_a@mail.ru','Kamila Melnikova','Radostovsa 34 - 41','Almaty','','KAZAKHSTAN','050009','(777)555-5775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 17:12:10',0,NULL,3,1,2,1,'\\ ','kamilla_m'),(11204,621452292013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',2,'HBPH004',19.98,'eastar4','zoltantheking','erzsi1938@yahoo.com','ZSUZSA TARNAI','VAN LEIJENBERGHLAAN<br>28','AMSTERDAM','','NETHERLANDS','1082GM','31 207754576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 17:29:42',0,NULL,3,1,2,1,'\\ ','zoltantheking'),(11205,845979668012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',9.5,'eastar4uk','pban6953','puffnstuff@talktalk.net','P. Bance','28 Fleetwood Court,<br>Madeira Road','West Byfleet','Surrey','UNITED KINGDOM','KT14 6BE','01932352940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 17:36:20',0,NULL,3,1,3,1,'RA184559823CN\r ','pban6953\rHSPL002'),(11206,565884987003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','y2k07','shellynv@sbcglobal.net','Michelle Newman','1555 Delucchi Ln<br>Unit J','Reno','NV','UNITED STATES','89502-6537','(775) 624-9176','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-10 17:38:11',0,NULL,3,1,1,1,'\\ ','y2k07'),(11207,0,110739901820,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',13.4,'buysia','wongkamfai51','wongkamf@hotmail.com','kam wong','1974 W 5th St','brooklyn','NY','UNITED STATES','11223-2650','(917) 582-6689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 17:42:01',0,NULL,3,1,1,1,'\\  ','wongkamfai51'),(11208,845986364012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','montecarlosusan','srbarton3@msn.com','Tom Collins','2255 Oakhurst Dr','Delaware','OH','UNITED STATES','43015-9587','(740) 441-7156','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 17:51:09',0,NULL,3,1,1,1,'\\ ','montecarlosusan'),(11209,845993533012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','montecarlosusan','srbarton3@msn.com','Susan Barton','PO Box 99<br>6265 Mangrove st','Scottsmoor','FL','UNITED STATES','32775-0099','(321) 268-5324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 18:02:08',0,NULL,3,1,1,1,'\\ ','montecarlosusan'),(11210,762549687011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','dr.schven','tmntnshit@yahoo.com','phil harris','543 s. center','casper','WY','UNITED STATES','82601-3533','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 18:18:04',0,NULL,3,1,1,1,'\\ ','dr.schven'),(11211,762550899011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',9.9,'eastar4','buccaneers1','phil@pdr60.com','Philip Rautine','240 Charlotte Dr','Oakland','TN','UNITED STATES','38060-4518','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 18:18:28',0,NULL,3,1,1,1,'\\ ','buccaneers1\rHP 8pin 1.0 3cm '),(11212,0,110739901911,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','valdirmagalhaes1','valdirmagalhaes@ig.com.br','FRANCISCO VALDIR ALVES MAGALHAES','RUA ALVARO MENDES, 1313 SEXTO ANDAR','TERESINA','PIAUI','BRAZIL','64000-915','8688026200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 18:52:42',0,NULL,3,1,3,1,'RA184559845CN\r ','valdirmagalhaes1\rBR3D008'),(11213,571373289004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','pongsiric','pongsiric@gmail.com','Pongsiri Chutacharat','31 Soi Ramintra 14 Yak 8 Ramintra Road<br>Tharang Bangkhen','Bangkok','','THAILAND','10230','(66)817541246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 19:09:52',0,NULL,3,1,3,1,'RA184559854CN\r ','pongsiric\rHSPL015'),(11214,762583926011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mgl462','blacknight46@sbcglobal.net','michael green','258 Union St','manchester','CT','UNITED STATES','06042-1982','(860) 281-9553','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 19:28:18',0,NULL,3,1,1,1,'\\ ','mgl462'),(11215,846050373012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.4,'eastar4','oxikon','ugur_shen@hotmail.com','Ugur SEN','Buyukdere Mahallesi Davet Sokak Donerce Sitesi A.Blok Kat:3 No:6','Eskisehir','','TURKEY','26040','+905542278484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 19:52:29',0,NULL,3,1,2,1,'\\ ','oxikon\rHP 6pin 1.0 12cm '),(11216,762597511011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','salmon25gt','bt25@inbox.ru','Dmitriy Krupenko','Krasnoarmeyskaya street 58 flat 5','Krasnogorskiy district Nakhabino','Moscow region','RUSSIAN FEDERATION','143430','89263524860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 19:56:07',0,NULL,3,1,2,1,'\\ ','salmon25gt'),(11217,621505951013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','ztraina1','ztraina@gmail.com','Zach Traina','1220 Washington St','West Newton','MA','UNITED STATES','02465-2147','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 20:03:05',0,NULL,3,1,1,1,'\\ ','ztraina1'),(11218,762601541011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','bustorp','hangar13@telia.com','Mats Persson','Hangarvagen 13','Kallinge','Blekinge','SWEDEN','37250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 20:17:30',0,NULL,3,1,2,1,'\\ ','bustorp'),(11219,621511786013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',17.4,'eastar4','jjmccowan','j_mccowan@comcast.net','Jason Mccowan','176 N Lake Franklin Dr','Mount Dora','FL','UNITED STATES','32757-5938','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 20:20:24',0,NULL,3,1,1,1,'\\ ','jjmccowan\rCAB-SS-2626'),(11220,762612579011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ragliddon','ragliddon@hotmail.com','Rachel Gliddon','49 Ringswell Avenue','Exeter','Devon','UNITED KINGDOM','EX13EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 20:28:27',0,NULL,3,1,3,1,'RA184559797CN\r ','ragliddon\rRELO003\r红边优联'),(11221,846068775012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','afinlay','allanfinlay@aol.com','Allan Finlay','1 Heath Road','Breachwood Green','Hertfordshire','UNITED KINGDOM','SG48PL','01438833907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 20:32:05',0,NULL,3,1,3,1,'RA184559050CN\r ','afinlay\rGLOT001*3\r兼容型3D眼镜 通用型'),(11222,846077847012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','milemaster1','milemaster@frontier.com','M I LeMaster','2906 High St','Logansport','IN','UNITED STATES','46947-2141','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 20:47:49',0,NULL,3,1,1,1,'\\ ','milemaster1'),(11223,621525873013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','toi_aussi','toi_aussi@hotmail.com','Nguyen Tu Charles Truong','333 Lorne-Worsley','Vaudreuil-Dorion','QC','CANADA','J7V 0J6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 21:05:14',0,NULL,3,1,2,1,'\\ ','toi_aussi'),(11224,762632419011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','8tiggerjay','jasonparkinson2@gmail.com','Jason Parkinson','82 Rosethorn Ave','Toronto','ON','CANADA','M6N 3L1','(416) 885-6476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 21:16:03',0,NULL,3,1,2,1,'\\ ','8tiggerjay'),(11225,846091359012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','ed2324','elarli@nycboe.net','Edward Larli','16635 9th ave<br>Apt 3B','whitestone','NY','UNITED STATES','11357-2021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 21:17:41',0,NULL,3,1,1,1,'\\ ','ed2324'),(11226,762638950011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',4,'HSNO007',55.96,'eastar4','lisamarianne10','athinis@btinternet.com','MAZDAROTARYPARTS/RBEUROPE/SHYAUTO','The Old Rectory Business Centre<br>Springhead Road','Northfleet','Kent','UNITED KINGDOM','DA11 8HN','01474361800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 21:35:17',0,NULL,3,1,3,1,'RA184559925CN\r ','lisamarianne10\r英标\rHSNO007'),(11227,845511330012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','vladimirleznov','vladimir.leznov@gmail.com','Vladimir Leznov','Marhlevskogo, 31A-25','Ivanovo','Ivanovo','RUSSIAN FEDERATION','153003','+79206783056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 21:38:13',0,NULL,3,1,2,1,'\\ ','vladimirleznov\r网眼豹纹双层网纱长柄伞 \r咖啡色'),(11228,762643779011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','yvesbadara','andreakuril@hotmail.com','Andrea Kurilova/Lena Mouza Diagne','21 Hunt Road','London','Middlesex','UNITED KINGDOM','UB2 4PZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 21:48:03',0,NULL,3,1,3,1,'RA184559770CN\r ','yvesbadara\rRELO003\r红边优联\r '),(11229,762648114011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','nwoojpol','jeff@fastmail.fm','Jeffrey Polson','1997 Coffee Ln','Sebastopol','CA','UNITED STATES','95472-9613','(707) 243-4126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 21:59:52',0,NULL,3,1,1,1,'\\ ','nwoojpol'),(11230,846122953012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','tkelly365','tkellyvipcom@hotmail.com','anthony christie','144 st marys road','lLford','Essex','UNITED KINGDOM','ig11qy','07956842680','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 22:40:45',0,NULL,3,1,3,1,'RA184559942CN\r ','tkelly365\rOTCN003'),(11231,846123794012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',25.9,'eastar4uk','linmar765','lschofield@yahoo.com','Linda Schofield','36/20 Warwick Ave','Cammeray','New South Wales','AUSTRALIA','2062','0293517840','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 22:46:42',0,NULL,3,1,3,1,'RA184559752CN\r ','linmar765\rOTGR001+OTGR002'),(11232,721470846001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','josimp1','simpjo@gmail.com','Jo Ann Simpson','638 Madison Ave<br>C/O City Of Covington # 243','Covington','KY','UNITED STATES','41011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 23:05:08',0,NULL,3,1,1,1,'\\ ','josimp1'),(11233,762670806011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','susanblacksusanblack','susanblack4@gmail.com','Susan Black','27 Brook Crest Way','Ormond Beach','FL','UNITED STATES','32174-1840','(386) 316-0616','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 23:17:28',0,NULL,3,1,1,1,'\\ ','susanblacksusanblack'),(11234,762676829011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','fordfan5859','steve@mascotmont.com.au','Steve Canard','17 Lakeview drive','Nth Bundaberg','Queensland','AUSTRALIA','4670','0741544544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 23:36:24',0,NULL,3,1,3,1,'RA184559046CN\r ','fordfan5859\rGLOT001*3\r兼容型3D眼镜 通用型'),(11235,621564318013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','cbjuice','cbjuice@earthlink.net','Clifford Huling','12526 Kempston Ln','woodbridge','VA','UNITED STATES','22192-5063','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 23:44:26',0,NULL,3,1,1,1,'\\ ','cbjuice'),(11236,762679486011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','riverred105','thisguyhere105@gmail.com','Jason Wells','2001 Westheimer Rd<br>Apt 327','Houston','TX','UNITED STATES','77098-1585','(281) 217-6303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 23:46:04',0,NULL,3,1,1,1,'\\ ','riverred105'),(11237,565991286003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','thedysh','jhko@earthlink.net','John Ko','2121 S Houston Ave','Humble','TX','UNITED STATES','77396-1512','(281) 446-4930','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-10 23:49:57',0,NULL,3,1,1,1,'\\ ','thedysh'),(11238,722299679001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','gk.viji','gopalkrishnan1975@gmail.com','Gopalakrishnan Paramasivam','1415 Churchill Ct<br>Apt L104','Mundelein','IL','UNITED STATES','60060-4326','(224) 778-0729','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-10 23:50:53',0,NULL,3,1,1,1,'\\ ','gk.viji'),(11239,621568210013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','junior2410','johnwest4444@msn.com','Wellesley Johnson','30 Colonel Butler Drive','Markham','ON','CANADA','L3P6B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 00:03:01',0,NULL,3,1,2,1,'\\ ','junior2410'),(11240,846154791012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','kesitter1','kesitter@hotmail.com','Keith Sitter','28193 Glenside CT','MENIFEE','CA','UNITED STATES','92584-7734','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 00:33:36',0,NULL,3,1,1,1,'、 ','kesitter1'),(11241,0,120773426496,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',19.02,'buysia','hjvp2806','hjvp_2806@clix.pt','Helder Pires','Praceta Paiva Couceiro, 5 - 2º Esq.','Mem Martins','Mem Martins','PORTUGAL','2725410','351.93.660.11.00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 00:41:39',0,NULL,3,1,3,1,'RA184559899CN\r ','hjvp2806\rBR3D006'),(11242,621578032013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','mangus1000','angusterry@gmail.com','Angus Terry','ICT Department, Wodonga TAFE<br>87 Mckoy Street','Wodonga','Victoria','AUSTRALIA','3690','0400077525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 00:55:36',0,NULL,3,1,2,1,'\\ ','mangus1000'),(11243,621592268013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','vonwestfalen','speed1993@gmail.com','Anastasiya Yasukevich','1734 71st St<br>Apt 2R','Brooklyn','NY','UNITED STATES','11204-5220','(347) 488-9151','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 02:41:46',0,NULL,3,1,1,1,'\\ ','vonwestfalen\r韩版透明伞'),(11244,762721685011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','wagsellis','wagse@aol.com','Ellis Wagner','25 Joval Ct','Brooklyn','NY','UNITED STATES','11229-5966','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 02:43:29',0,NULL,3,1,1,1,'\\ ','wagsellis'),(11245,846205806012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','jmoy9002','jacksonmoy@yahoo.com','Jackson Moy','122 Lazarus Dr','Ledgewood','NJ','UNITED STATES','07852-2346','(973) 252-0477','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 04:02:05',0,NULL,3,1,1,1,'\\ ','jmoy9002\racer 6pin1.25 23cm '),(11246,846221751012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','abegil','abegil4@bezeqint.net','Abraham Gilboa','6, Golomb str','Ramat Hasharon','Israel','ISRAEL','47414','+97235492011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 05:26:03',0,NULL,3,1,2,1,'\\ ','abegil'),(11247,762768656011,320756093124,'New Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','yuki_yuki_918','yuki918@yahoo.com','Lily C','INTERNATIONAL PLAZA 4411<br>10 ANSON ROAD','default','','SINGAPORE','079903','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 06:50:25',0,NULL,3,1,3,1,'RA184554976CN\r ','yuki_yuki_918\rMOLO008\r红色的'),(11248,621639398013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','vladimirbagma','mtolopilo@gmail.com','Marina Tolopilo','Zelenodolskaya<br>7-16','Khanty-Mansiysk','Khanty-Mansiyskiy AO','RUSSIAN FEDERATION','628001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 07:16:21',0,NULL,3,1,2,1,'\\ ','vladimirbagma'),(11249,846268174012,220815928079,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',19.99,'eastar4uk','add1u','adecebay@gmail.com','Karolina Sil-Dec Museums Galleries Scotland','1 Papermill Wynd<br>Mcdonald Rd','Edinburgh','Midlothian','UNITED KINGDOM','EH7 4QL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 08:25:49',0,NULL,3,1,3,1,'RA184559956CN\r ','add1u\rOTIN002'),(11250,762803741011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','tommyknockerz99','renaud.henrotte@gmail.com','Renaud Henrotte','Rue Prince Henri,31','Hondelange','','BELGIUM','6780','063233094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 08:49:09',0,NULL,3,1,2,1,'\\ ','tommyknockerz99'),(11251,762805936011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.99,'eastar4','cupids24','cupids1@ozemail.com.au','Peter George','PO Box 565','MOOROOLBARK','Victoria','AUSTRALIA','3138','0397273295','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 08:58:26',0,NULL,3,1,2,1,'\\ ','cupids24'),(11252,846286349012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','ales791','dr_elmir@yahoo.co.uk','Elmir Alasgarov','Natavan dongasi 2/6','Baku','Sabail Rayonu','AZERBAIJAN','AZ1005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 09:18:28',0,NULL,3,1,3,1,'RA184559810CN\r ','ales791\rWWOT003'),(11253,621672626013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','olicorbel','olicorbel@yahoo.fr','Olivier CORBIN','Avenue Joseph Jongen, 20','Bruxelles','','BELGIUM','1180','0478800409','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 09:43:21',0,NULL,3,1,6,1,'EE495359392CN ','olicorbel\r\r'),(11254,566097142003,130554589035,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',72.99,'cnfaner','demionn','dem-789@mail.ru','Dmitry Kopysov','Lunacharskogo str. 10-6','Kushva','Sverdlovskaya oblost','RUSSIAN FEDERATION','624300','89068030777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 10:29:05',0,NULL,3,1,3,1,'RA184559868CN\r ','demionn\rKBNO001'),(11255,621690733013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','davefranken','frankend@zonnet.nl','Dave Franken','Nellen Weer 57','ASSENDELFT','','NETHERLANDS','1566LT','0756877499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 10:46:24',0,NULL,3,1,3,1,'RA184559837CN\r ','davefranken\rMOSA003'),(11256,566098149003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','mortnyc','mortezia@gmail.com','Morteza Ahmadi','14 ave du Mail','Geneve','','SWITZERLAND','1205','(078) 881-1123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 10:32:24',0,NULL,3,1,3,1,'RA184559620CN\r ','mortnyc\rMOAP001'),(11257,846139550012,220815929174,'New APPLE iMac G6 Bluetooth Wireless Keyboard',1,'KBAP003',44.99,'eastar4uk','gozitanapache','yosef.magro@gmail.com','Yosef Magro','47, Dun Pawl Micallef Str.','Victoria','Gozo','MALTA','VCT 104','+35699802488','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 11:03:34',0,NULL,3,1,3,1,'RA184554066CN\r ','gozitanapache\rKBAP003'),(11258,571564123004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','pink_sos_65','pinksos65@yahoo.com.au','wendy wallace','49 coast rd','macleay island','Queensland','AUSTRALIA','4184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:18:49',0,NULL,3,1,3,1,'RA184559616CN\r ','pink_sos_65\rOTGR002'),(11259,846342451012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.9,'eastar4','baksis70','aldispg38@inbox.lv','Aldis Izaks','59 Estcourt street','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU9 2RR','01482320290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:26:12',0,NULL,3,1,2,1,'\\ ','baksis70\racer 8pin1.00 18cm'),(11260,621704395013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','edgar.073','et.cj1@bigpond.com','Edgar Johns','12 Michael Street','Wynnum West','Queensland','AUSTRALIA','4178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:34:25',0,NULL,3,1,2,1,'\\ ','edgar.073\r红边优联'),(11261,762892500011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','spruce123456','willem@spruce.nl','Willem Sparreboom','Uithofslaan 8','The Hague','','NETHERLANDS','2544 NV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 12:32:42',0,NULL,3,1,2,1,'\\ ','spruce123456'),(11262,846379952012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','jsap6168','jsap01@earthlink.net','Joe Sapinsky','131 Clark Creek Ln','Longview','WA','UNITED STATES','98632-9623','(360) 425-2216','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 13:05:17',0,NULL,3,1,1,1,'\\ ','jsap6168'),(11263,846390579012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','11relaxing','chloe4211@gmail.com','Chloe Mahe','28 alveley loop<br>Butler','Perth','Western Australia','AUSTRALIA','6036','0895620545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:10:05',0,NULL,3,1,2,1,'\\ ','11relaxing\r蕾丝蝴蝶结伞 '),(11264,846398476012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','rcgzantvoo','rcgvanzantvoort@home.nl','T.a.v. Rick van Zantvoort','Lagerwey Wind B.V.<br>Anthonie Fokkerstraat 2','Barneveld','','NETHERLANDS','3772 MR','+31622444547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:25:35',0,NULL,3,1,2,1,'\\ ','rcgzantvoo'),(11265,762887113011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','stever53','stevef@tecsys.com','Steve Fliehman','1363 Gettysburg Rd','Long Grove','IL','UNITED STATES','60047-5074','(847) 634-6561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 13:29:07',0,NULL,3,1,1,1,'\\ ','stever53'),(11266,762913215011,320730083567,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',9.99,'eastar4uk','gav1612','gavin@accentvoiceanddata.co.uk','Gavin Moore','180 Markfield Road','Groby','Leicestershire','UNITED KINGDOM','LE6 0FS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 13:31:12',0,NULL,3,1,3,1,'RA184559704CN\r ','gav1612\rOTCN005\r白色的'),(11267,621735954013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','nemonline','martijn.hoogendijk@gmail.com','Martijn Hoogendijk','Utrechtsestraat 45','Arnhem','','NETHERLANDS','6811LT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:35:57',0,NULL,3,1,2,1,'\\ ','nemonline'),(11268,846411729012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','theobeau','nsclau@yahoo.com','Namson Lau','8 Castlereagh Street','Concord','New South Wales','AUSTRALIA','2137','0413345979','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 13:50:49',0,NULL,3,1,2,1,'\\ ','theobeau'),(11269,621753327013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','mose_allison','psgillan@btinternet.com','Paul Sayers-Gillan','10 OTTER CLOSE<br>CHESTNUT GROVE, NORTH LANE','ALDERSHOT','Hampshire','UNITED KINGDOM','GU12 4FR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 14:04:28',0,NULL,3,1,3,1,'RA184559338CN\r ','mose_allison\rMOSA006'),(11270,566157071003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','ulipetri1','ulipetri@terra.com.br','Ulisses Petriche','rua Vigario Albernaz 523 apt 33','Sao Paulo','SP','BRAZIL','04134021','11 94616694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 14:04:55',0,NULL,3,1,3,1,'RA184559681CN\r ','ulipetri1\rOMHJ001'),(11271,621754613013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','buttonit110','a.rowett@blueyonder.co.uk','anthony rowett','110 button hill','sheffield','South Yorkshire','UNITED KINGDOM','S119HJ','01142353367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 14:07:49',0,NULL,3,1,2,1,'\\ ','buttonit110'),(11272,762940524011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','plume47','cecile.blanconnier@gmail.com','Chantal BLANCONNIER','Bernat','AURADOU','Midi-Pyrénées','FRANCE','47140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 14:14:00',0,NULL,3,1,2,1,'\\ ','plume47\r红边优联'),(11273,621761368013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','kievukr','feliks.08@mail.ru','Ludmila Lykhovskaja','M.Jitomirska 20-30','Kiev','','UKRAINE','02001','380442798543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 14:28:27',0,NULL,3,1,2,1,'\\ ','kievukr'),(11274,722563066001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','lorim6231','morton@gbtel.ca','Lori Morton c/o Penn Automotive','RR 1','Hepworth','ON','CANADA','N0H 1P0','(519) 935-3850','NoPaymentFailure','CheckoutComplete','NotSelected','2011-09-11 15:08:39',0,NULL,3,1,3,1,'RA184559678CN\r ','lorim6231\rOTAM001'),(11275,762974566011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','ben225514','ben225514@gmail.com','Chi Yung Chiu','2762 E4th Ave','Vancouver','BC','CANADA','v5m 1k6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 15:14:46',0,NULL,3,1,2,1,'\\ ','ben225514'),(11276,763023321011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','rbramblett','rbramblett1@charter.net','randall bramblett','115 raccoon row','athens','GA','UNITED STATES','30605-4445','(706) 543-2688','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 16:28:22',0,NULL,3,1,1,1,'\\ ','rbramblett'),(11277,846519608012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',21.99,'eastar4uk','1simon1','simondonovan@btinternet.com','simon  donovan','3 underhill avenue','midsomer norton','Somerset','UNITED KINGDOM','BA32SE','0773993522','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 16:32:54',0,NULL,3,1,3,1,'RA184559474CN\r ','1simon1\rUDAP002'),(11278,763035508011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','4017jamesm','jamesmartindale@hotmail.com','James Martindale','16 Downs Road<br>Penenden Heath','Maidstone','Kent','UNITED KINGDOM','ME14 2JL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 16:46:59',0,NULL,3,1,3,1,'RA184559372CN\r ','4017jamesm\rGLSG001'),(11279,763042399011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','kershdog','seankershner@hotmail.com','Sean Kershner','Po Box 10744','Phoenix','AZ','UNITED STATES','85064','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 16:53:20',0,NULL,3,1,1,1,'\\ ','kershdog'),(11280,0,120773426545,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',28,'buysia','laabner','laabner3079@aol.com','Laura Abner','7845 Northfork Ln','Okeana','OH','UNITED STATES','45053-9641','(513) 238-9268','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 16:59:14',0,NULL,3,1,1,1,'\\ ','laabner'),(11281,721544316001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','malemanct','ideliver4you@hotmail.com','Donald Siering Jr','119 Seymour St<br>Back Breezeway','waterbury','CT','UNITED STATES','06708-3707','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 17:23:40',0,NULL,3,1,1,1,'\\ ','malemanct'),(11282,846580741012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','antindog','watsonla@btconnect.com','Mr L Watson','Cranbrook<br>Chappel Road, Great Tey','Colchester','Essex','UNITED KINGDOM','co61jw','01206213876','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 17:42:49',0,NULL,3,1,3,1,'RA184559664CN\r ','antindog\rOTCN003'),(11283,763117618011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','swl1951','swladue@charter.net','Stephen Ladue','895 Cumberland Head Rd','Plattsburgh','NY','UNITED STATES','12901-7003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 18:15:20',0,NULL,3,1,1,1,'\\ ','swl1951'),(11284,621875098013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','jarino','jumokea@rogers.com','Jumoke Awoniyi','12 Fallharvest Ave','Brampton','ON','CANADA','L6Y0P2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 18:03:17',0,NULL,3,1,3,1,'RA184559125CN\r ','jarino\rMOSA006'),(11285,846623739012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','danjay83','dan-kop@hotmail.co.uk','Dan Harding','20 Silk Street','Ipswich','Suffolk','UNITED KINGDOM','IP4 2PA','07938901434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 18:21:13',0,NULL,3,1,3,1,'RA184559341CN\r ','danjay83\rGLOT004\r兼容型3D眼镜  samsung 专用'),(11286,763145854011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','leadmanvic','leadman1085@aol.com','vic litz','63 W Miller Ave','milan','MI','UNITED STATES','48160-1043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 18:43:34',0,NULL,3,1,1,1,'/ ','leadmanvic'),(11287,566323493003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jim51p','jimraija@earthlink.net','James D. Reed','1600 W Kitty Hawk Way','Tucson','AZ','UNITED STATES','85755-8890','(800) 477-6111 ext.: 9158','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-11 19:24:43',0,NULL,3,1,1,1,'\\ ','jim51p'),(11288,571778062004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',3,'RELO003',35.94,'cnfaner','rockit4','rockit@lisco.com','OTIS R. BOWLES','227 E 5th St','OTTUMWA','IA','UNITED STATES','52501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-11 19:25:52',0,NULL,3,1,1,1,'\\ ','rockit4\r红边优联'),(11289,763196764011,320721866947,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',13.95,'eastar4','aah_786','qkhan_786@live.co.uk','anum  khan','92 etwall road','birmingham','West Midlands','UNITED KINGDOM','b28 0le','01217772430','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-11 19:43:23',0,NULL,3,1,2,1,'\\ ','aah_786\r草莓伞 '),(11290,846707192012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','tdaines','tracyann38uk@yahoo.com','MRS TRACY DAINES','460 LONDON ROAD','ASHFORD','Middlesex','UNITED KINGDOM','TW15 3AD','07810722360','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 19:50:54',0,NULL,3,1,3,1,'RA184559766CN\r ','tdaines\rHSSA002\r英标\r黑色的'),(11291,763214179011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','smally525','smallzy007@yahoo.co.uk','mark small','112 egerton road<br>bishopston','bristol','Avon','UNITED KINGDOM','bs7 8hp','07886870044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 20:05:29',0,NULL,3,1,3,1,'RA184559094CN\r ','smally525\rGLOT001*2\r兼容型3D眼镜 通用型'),(11292,621969469013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jc.clark08','jcclark08@gmail.com','Chelsie Clark','4681 Marble Ct','Newburgh','IN','UNITED STATES','47630-8727','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 20:38:33',0,NULL,3,1,1,1,'\\ ','jc.clark08'),(11293,722811569001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','kkkostarasss','kkkostasss@yahoo.gr','Kostas Kalogerakis','Strimonos 23','Athens','Greece/Athens/ilion','GREECE','13122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 20:48:33',0,NULL,3,1,3,1,'RA184559647CN\r ','kkkostarasss\rBR3D007'),(11294,846753867012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','tpjpact','pj.thomas@free.fr','THOMAS Pierre-Jean','49 rue des chaffauds','Angers','Pays de la Loire','FRANCE','49000','0241665331','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 20:54:51',0,NULL,3,1,3,1,'RA184559236CN\r ','tpjpact\rGLOT005'),(11295,846756768012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','sigurdurr6025','sgunn15@simnet.is','Sigurdur Ragnarsson','Middalur 14','Vogar','','ICELAND','190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 21:05:06',0,NULL,3,1,3,1,'RA184559103CN\r ','sigurdurr6025\rGLOT001*2\r兼容型3D眼镜 通用型'),(11296,846768122012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',10.99,'eastar4uk','philipgreen99','piratez_99@hotmail.com','Matthew Green','7 Fairmont Terrace<br>North Road','Sherborne','Dorset','UNITED KINGDOM','DT9 3JS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 21:24:25',0,NULL,3,1,3,1,'RA184559633CN\r ','philipgreen99\rMOMI002\r黑色的'),(11297,846771856012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.9,'eastar4','nnssii','m.rosellen@gmx.de','Markus Rosellen','21341174<br>Packstation 148','Bedburg','','GERMANY','50181','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 21:27:43',0,NULL,3,1,2,1,'\\ ','nnssii\r4pin 1.25'),(11298,846773317012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.9,'eastar4uk','julianwood','ebay@julianwood.com','Julian Wood','Invesco<br>30 Finsbury Square','London','London','UNITED KINGDOM','EC2A 1AG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 21:33:22',0,NULL,3,1,3,1,'RA184559528CN\r ','julianwood\rMOLO006'),(11299,846776320012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','brndimcc','brndimcc@hotmail.com','Brandi McConnell','546 Atwood St<br>Apt 2','Longmont','CO','UNITED STATES','80501-5548','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 21:41:09',0,NULL,3,1,1,1,'\\ ','brndimcc'),(11300,621994980013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','glodif','jitzgosu@gmail.com','Christian Caballero','61 Blair Street','Toronto','ON','CANADA','M4B 3N5','(416) 731-4947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 21:46:18',0,NULL,3,1,3,1,'RA184559219CN\r ','glodif\rMOSA005'),(11301,722838890001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',10.99,'buysia','graniterazy10','graniterazy@yahoo.com','Gustavo Vazquez','1594 Birmingham Dr','perris','CA','UNITED STATES','92571-3709','(909) 578-0839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 21:50:33',0,NULL,3,1,1,1,'\\ ','graniterazy10'),(11302,621995372013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','donetsk77','dsamoilenko@yahoo.com','Dmitry Samoilenko','Shakespear st. 19<br>number 77','Donetsk','Donetskaya','UKRAINE','83050','0969803717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 22:04:31',0,NULL,3,1,2,1,'\\ ','donetsk77'),(11303,763297153011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','8608871220','jan_j_akus@sbcglobal.net','Jan J Akus','14 Elm Ave','Norwich','CT','UNITED STATES','06360-2302','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 22:58:04',0,NULL,3,1,1,1,'\\ ','8608871220'),(11304,846813469012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',21.99,'eastar4','shammoria200912966','shammoria@shammoria.com','Brett Parker','90 Buckley Street<br>St Anthonys School','Noble Park','Victoria','AUSTRALIA','3174','0428636762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 23:14:16',0,NULL,3,1,2,1,'\\ ','shammoria200912966'),(11305,763308085011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','carrieanne139','carrie.loraine@gmail.com','Carrie Loraine','2020 E Kerr St<br>Apt G305','Springfield','MO','UNITED STATES','65803-8742','(417) 350-0669','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 23:40:57',0,NULL,3,1,1,1,'\\ ','carrieanne139'),(11306,846825594012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',2,'OTHP001',57.98,'eastar4','mauromk','mauromk@yahoo.com.br','Mauro Miki','Rua Buarque de Macedo, 50 - Apt 402<br>Flamengo','Rio de Janeiro','RJ','BRAZIL','22220-030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 23:47:33',0,NULL,3,1,3,1,'RA184559576CN\r ','mauromk\rOTHP001'),(11307,846826891012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','shirzaman1','shir_haidari@yahoo.com','Shir Zaman','7332 Southern Blvd','Boardman','OH','UNITED STATES','44512-5622','(216) 526-9144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-11 23:51:13',0,NULL,3,0,1,1,'\\ ','shirzaman1\r发210TS\r已入库'),(11308,763315618011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','shaun-cass','shaunchrislopez@yahoo.com','shaun lopez','114 Dardanelli Ln<br>Apt 40','los gatos','CA','UNITED STATES','95032-1436','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 00:02:20',0,NULL,3,1,1,1,'\\ ','shaun-cass'),(11309,846833149012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','luziust','luziust@yahoo.com','Timothy Luzius','5728 Sandy Ct SE','Kentwood','MI','UNITED STATES','49548-5955','(616) 364-5402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 00:07:37',0,NULL,3,1,1,1,'\\ ','luziust\racer 8pin1.00 8cm'),(11310,846833258012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','alisky2011','sky-sky-77@hotmail.com','ALI AL MANSOUR','4 Riley House<br>Manor House Drive','Coventry','West Midlands','UNITED KINGDOM','CV1 2EB','07413001906','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 00:08:18',0,NULL,3,1,3,1,'RA184559514CN\r ','alisky2011\rHSPL009\r英标'),(11311,763335088011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',35.99,'eastar4uk','bhabibi79','babak@habibis.net','Babak Habibi','601/40 King St.','Wollstonecraft','New South Wales','AUSTRALIA','2065','0280218401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 00:58:47',0,NULL,3,1,3,1,'RA184559390CN\r ','bhabibi79\rOTSO004'),(11312,763347287011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','wings31','helwink@comcast.net','Chris Helwink','189 W Vallette St','Elmhurst','IL','UNITED STATES','60126-4301','(630) 932-1973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 01:32:47',0,NULL,3,1,1,1,'\\ ','wings31'),(11313,566434913003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','fendi04','christopher@munichllc.com','Christopher Picardi','8306 Wilshire Blvd<br># 1','Beverly Hills','CA','UNITED STATES','90211-2382','(310) 621-3641','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 01:38:37',0,NULL,3,1,1,1,'\\ ','fendi04\rWMN1000B OEM'),(11314,763347720011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','cfvaldez09','c4t134@yahoo.com','christopher valdez','2429 Loftyview Dr','Torrance','CA','UNITED STATES','90505-7219','(310) 325-5812','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 01:46:41',0,NULL,3,1,1,1,'\\ ','cfvaldez09'),(11315,622068468013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','dallascowboysdepot','dallascowboysdepot1@gmail.com','Ron Park','7970 Shay Dr','Oakland','CA','UNITED STATES','94605-4219','(214) 699-8386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 02:29:17',0,NULL,3,1,1,1,'\\ ','dallascowboysdepot\r红边优联'),(11316,622073912013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','nmyn5434','vladm1234@gmail.com','Nataliya Myndru','1736 orchard st','des plaines','IL','UNITED STATES','60018','(224) 636-0422','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 02:50:39',0,NULL,3,1,1,1,'/  ','nmyn5434\r兼容型3D眼镜 通用型'),(11317,566455183003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','littlemarty1','js.petree@verizon.net','Sandra Petree','1550 E. Los Flores Dr','San Bernardino','CA','UNITED STATES','92404-2059','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 03:23:51',0,NULL,3,1,1,1,'\\ ','littlemarty1'),(11318,622083934013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','rosecelly','zhangyo@yahoo.com','Yong Zhang','347 Ellesmeer Ave','Kingston','ON','CANADA','K7P 3C8','(613) 531-5860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 03:41:34',0,NULL,3,1,2,1,'\\ ','rosecelly'),(11319,622085931013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','greedyeee','eastonrutkoski@gmail.com','Easton Rutkoski','11447 Country Knoll Rd','South Jordan','UT','UNITED STATES','84095','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 03:54:26',0,NULL,3,1,1,1,'\\ ','greedyeee\r黑色的'),(11320,566459599003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','chkandula','khemachandra@hotmail.com','Hemachandra Kandula','101 Washington Ave<br>Apt 226','Oakmont','PA','UNITED STATES','15139-2125','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 03:56:58',0,NULL,3,1,1,1,'\\ ','chkandula'),(11321,571915235004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','rkolacz1984','rafalkolacz@hotmail.com','Rafal Kolacz','5039 s lotus ave','chicago','IL','UNITED STATES','60638','(773) 937-6405','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 03:57:04',0,NULL,3,1,1,1,'\\ ','rkolacz1984'),(11322,763391587011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','jwkamp','jwkamp@yahoo.com','Jared Wetenkamp','413 Sunshine Way','Turlock','CA','UNITED STATES','95382-7374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 04:15:27',0,NULL,3,1,1,1,'\\ ','jwkamp'),(11323,566464372003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','battman000','cb73000@yahoo.com','Christopher S Battad','4230 Albertville Way','Antelope','CA','UNITED STATES','95843-5274','(906) 705-6338','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 04:32:34',0,NULL,3,1,1,1,'\\ ','battman000'),(11324,622098048013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','bulletx','bulletx@ameritech.net','Stephen Corfias','14425 Drexmore Rd','Shaker Heights','OH','UNITED STATES','44120-2433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 05:21:55',0,NULL,3,1,1,1,'\\ ','bulletx'),(11325,846903281012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','evilaziojr','evilaziojunior@hotmail.com','EVILÁZIO JUNIOR - DAEE','RUA ZULMIRA CANAVARROS Nº 95<br>BAIRRO: CENTRO NORTE','CUIABÁ','MATO GROSSO','BRAZIL','78005-200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 05:38:19',0,NULL,3,1,2,1,'\\ ','evilaziojr'),(11326,622100856013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',55.99,'eastar4','ffl59a','flament.frederic@gmail.com','Frederic FLAMENT','206 Rue Leon Bathiat','DOUAI','Nord-Pas-de-Calais','FRANCE','59500','06.37.05.12.89','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 05:40:58',0,NULL,3,1,3,1,'RA184559939CN\r ','ffl59a\rOTIN003'),(11327,763408127011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',15,'TRMX002',113.55,'eastar4','fati_zee','actualtestking747@hotmail.com','ZSM Inc.','502 Shaw Rd<br>Ste 105','Sterling','VA','UNITED STATES','20166-9435','(440) 840-3343','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 05:48:37',0,NULL,3,0,1,1,' /','fati_zee\r'),(11328,846935931012,220815930312,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',16.95,'eastar4uk','lee3538bikes','leehale@sky.com','Lee Mossman','78 Woodlands','Lakenheath','Suffolk','UNITED KINGDOM','IP27 9JE','07971264236','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 06:17:05',0,NULL,3,1,3,1,'RA184559655CN\r ','lee3538bikes\rHSMO021\r英标\r新的'),(11329,846937745012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','timoojal','timo.ojala@gmail.com','Timo Ojala','Kauppilantie 10 C12','Oulu','Pohjois-pohjanmaa','FINLAND','90230','+358504867635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 06:30:17',0,NULL,3,1,2,1,'\\ ','timoojal'),(11330,846941150012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',63.98,'eastar4uk','partybourbonbaby','dieandscott@bigpond.com','diane abed','28 Yanco Cresent','Toronto','New South Wales','AUSTRALIA','2283','0249597887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 06:42:53',0,NULL,3,1,3,1,'RA184559134CN\r ','partybourbonbaby\rGLOT005'),(11331,622113830013,230649308783,'New Japan Gentleman business Stripe Sun Rain Umbrella',1,'UM00026',26.99,'eastar4','kamisama666','noursipuce@free.fr','Jean-Luc Berrivin','49 av Jean Jaures','Crosne','Île-de-France','FRANCE','91560','0660788165','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 07:17:33',0,NULL,3,1,3,1,'RA184554083CN\r ','kamisama666\rUM00026+\rUM00008\r日本外贸经典条纹长柄伞 \r再发一把\r24K 多色伞'),(11332,846947730012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','kamisama666','noursipuce@free.fr','Jean-Luc Berrivin','49 av Jean Jaures','Crosne','Île-de-France','FRANCE','91560','0660788165','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 07:22:05',0,NULL,3,1,17,0,'RA184554083CN\r ','kamisama666\r24K 多色伞'),(11333,846954971012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','shthse-123','georgeterzis@optusnet.com.au','george terzis','51 fourth ave<br>campsie','sydney','New South Wales','AUSTRALIA','2194','0297180985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 07:44:50',0,NULL,3,1,3,1,'RA184581716CN\r ','shthse-123\rOTSO004*2'),(11334,622119192013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',414.98,'eastar4','yo.patel','yogesh.patel@y7mail.com','Yogesh Patel','P.O.Box 1276<br>Surrey Hills North LPO','Mont Albert','Victoria','AUSTRALIA','3127','0414490101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 07:51:47',0,NULL,3,1,6,1,'EE645685474CN ','yo.patel\r一共买了七副\r\r'),(11335,763434956011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.95,'eastar4','meshek101','chicolastudio@gmail.com','Moshe Shuella','Hagefen 335','Beit Arye','Beit Arye','ISRAEL','71947','+972522503704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 07:59:48',0,NULL,3,1,2,1,'\\ ','meshek101'),(11336,763436288011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',2,'HSSE004',45.8,'eastar4','george2010m','g_mizas1@yahoo.gr','GEORGE MOUTSELAKIS','37-39 SOKRATOUS STREET','EVOSMOS-THESSALONIKI','GREECE','GREECE','56224','00302311200036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 08:17:25',0,NULL,3,1,3,1,'RA184559531CN\r ','george2010m\rHSSE004\r欧标'),(11337,622128454013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',25,'MOAP001',624.75,'eastar4','yankee_doodle_dandy','nealmcclure@internode.on.net','David Braun','TafeSA, CIC Reception Desk - Building 6<br>100 Smart Road','Modbury','South Australia','AUSTRALIA','5092','0882078175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 08:49:32',0,NULL,3,1,4,1,'YW865546523CN\r ','yankee_doodle_dandy'),(11338,763449141011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',9.9,'eastar4','highflyer660660','highflyer660@gmail.com','Phil Wallis','59 Marlow st<br>St Kilda','Dunedin','Otago','NEW ZEALAND','9012','034559519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 08:59:52',0,NULL,3,1,2,1,'\\ ','highflyer660660\rHP 8pin 1.0 23cm'),(11339,763450893011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','ianp9774','ian@ipattinson.freeserve.co.uk','Ian Pattinson','Silox UK Ltd, The Heath Business & Technical Park','Runcorn','Cheshire','UNITED KINGDOM','WA7 4QX','01928573157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 09:07:19',0,NULL,3,1,3,1,'RA184559315CN\r ','ianp9774\rGLOT001\r兼容型3D眼镜 通用型'),(11340,622135175013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',2,'HBPH005',268,'eastar4','erikz','erik@rethinking.com.au','Erik Pizzorni','25 Cardinal Street','Mosman','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 09:33:39',0,NULL,3,1,4,1,'YW865546490CN\r ','erikz'),(11341,846988734012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','gary-lawrence','nikki-gary@hotmail.com','gary lawrence','23 maxwell cres','sanctuary point','New South Wales','AUSTRALIA','2540','0244433381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 09:53:16',0,NULL,3,1,3,1,'RA184559015CN\r ','gary-lawrence\rGLOT001*2\r兼容型3D眼镜 通用型'),(11342,763468478011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','markntracy2011','mr7ky@hotmail.co.uk','mark jones','56 Robins Crescent','Witham st Hughs','Lincolnshire','UNITED KINGDOM','LN6 9UU','01522869494','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 10:16:33',0,NULL,3,1,3,1,'RA184559602CN\r ','markntracy2011\r英标\rHSJA011'),(11343,847001283012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','malisonx','malisonx@gmail.com','Kovacs Attila','To u. 8. 2.lh. 2.em.','Nyergesujfalu','','HUNGARY','2536','+36304838448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 10:35:46',0,NULL,3,1,2,1,'\\ ','malisonx'),(11344,8881315824356288,111,'Item Title:New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4',' snguyen3310   ','stevenusa@gmail.com','Steven Nguyen','3310 209th Pl SW','Lynnwood','WA','UNITED STATES','98036-8965 ','',NULL,NULL,NULL,'2011-09-12 10:45:56',0,NULL,3,1,1,1,'\\ ','这票没下来 '),(11345,846905383012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','andehroo','ajackson.ualberta@gmail.com','Andrew Jackson','10649 Saskatchewan Dr.<br>#605 Buz1027','Edmonton','AB','CANADA','T6E6S8','(780) 224-1832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 10:54:44',0,NULL,3,1,3,1,'RA184559029CN\r ','andehroo\rGLOT001*2\r兼容型3D眼镜 通用型'),(11346,763483510011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','ldbl3000','dbryanl@aol.com','David Ling','11272 Chatham Road','Spencer','OH','UNITED STATES','44275','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 11:08:51',0,NULL,3,1,1,1,'\\ ','ldbl3000\racer 8pin1.00 15cm '),(11347,847012839012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','schottensocke','crazydiver1970@aol.com','Gino Golinelli','Elisabethstr. 11','Schildow','','GERMANY','16552','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 11:13:40',0,NULL,3,1,3,1,'RA184554070CN\r ','schottensocke\rGLSG001*3'),(11348,763485937011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','benbunyip','ben.schwabe@gmail.com','Ben Schwabe','c/o Monkii<br>Level 6, 180 Flinders Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 11:19:25',0,NULL,3,1,2,1,'\\ ','benbunyip\r澳标'),(11349,622158492013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','design_14','moscow_design@inbox.ru','Vycheslav Sokolov','ul. Sadovaya d.8 kv.71','Odintsovo','Moscow region','RUSSIAN FEDERATION','143002','(965) 193-3359','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 11:27:44',0,NULL,3,1,2,1,'\\ ','design_14'),(11350,847026391012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','soupkitchen555','peter_shaw555@hotmail.com','Peter Shaw','1 Tutor Bank Drive<br>Newton-Le-Willows','Merseyside','Merseyside','UNITED KINGDOM','WA129LZ','07970127331','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 11:58:59',0,NULL,3,1,3,1,'RA184559987CN\r ','soupkitchen555\rGLOT005*2'),(11351,622165894013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','xtr_nl','xlj.nicolas@gmail.com','Xavier NICOLAS','284 rue des Cireries','Olivet','Centre','FRANCE','45160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 12:00:21',0,NULL,3,1,2,1,'\\ ','xtr_nl'),(11352,847030290012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.39,'eastar4','ragioos','50000082888000@yahoo.co.uk','baljit singh','12/10<br>Oaks av dee why','sydney','New South Wales','AUSTRALIA','2099','0061402667042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 12:07:27',0,NULL,3,1,2,1,'\\ ','ragioos\r澳标'),(11353,763501191011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ilan2101','ilanpeery@gmail.com','Ilan Peery','6 B, Igal Mosinzon','Gedera','','ISRAEL','70700','972-524449948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 12:08:24',0,NULL,3,1,2,1,'\\ ','ilan2101'),(11354,847039608012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','andalthebest','abrennernet@gmail.com','Andreas Brenner','Hauptstr. 46','Bad Feilnbach/Au','','GERMANY','83075','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 12:34:49',0,NULL,3,1,3,1,'RA184566081CN ','andalthebest\rGLOT005'),(11355,622190110013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','toytech97','sdhayes1980@yahoo.com','Stephen Hayes','2 Viewridge Ct<br>Apt H','Baltimore','MD','UNITED STATES','21236-3552','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 13:42:01',0,NULL,3,1,1,1,'\\ ','toytech97'),(11356,723085097001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','trudatyung','zimbobin@gmail.com','Harold E Saylor','24121 Main Street Ext','Mardela Springs','MD','UNITED STATES','21837','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 14:00:32',0,NULL,3,1,1,1,'\\ ','trudatyung'),(11357,622197185013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','seesixtyfour','hanspetterandersen@gmail.com','Hans Petter Andersen','Forusmyra 8','Stavanger','','NORWAY','4033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 14:09:00',0,NULL,3,1,2,1,'\\ ','seesixtyfour'),(11358,847076919012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','ranger_rick2011','kinnunenrichard@yahoo.com','Richard Kinnunen','4806 6th Ave N<br>Apt 1','Grand Forks','ND','UNITED STATES','58203-2665','(701) 757-0517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 14:21:37',0,NULL,3,1,1,1,'\\ ','ranger_rick2011'),(11359,847081525012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',7.98,'eastar4uk','willi7949','willi.schmidt@web.de','Willi  Schmidt','Hafenstrasse 16','Tornesch','','GERMANY','25436','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 14:29:08',0,NULL,3,1,2,1,'\\ ','willi7949'),(11360,847083526012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','carlopher','carlopher@hotmail.com','carlos hernandez','dr delgado roig 2 2c','sevilla','Sevilla','SPAIN','41003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 14:35:04',0,NULL,3,1,3,1,'RA184554052CN\r ','carlopher\rGLOT001\r兼容型3D眼镜 通用型'),(11361,622203949013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','pedro646059','pedrorubial@hotmail.com','pedro rubial magadan','plaza manuel de falla 2 3b','ponferrada','Castilla y León','SPAIN','24400','605968131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 14:44:30',0,NULL,3,1,2,1,'\\ ','pedro646059'),(11362,622206219013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','clnunes10','clnunes@gmail.com','Cristiano Nunes','Rua vinte e dois de agosto 505 - Apto 162-2<br>Vila Bela Vista','São Paulo','São Paulo','BRAZIL','02617000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 15:09:27',0,NULL,3,1,2,1,'\\ ','clnunes10'),(11363,622215240013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','thanh_ng','qthanh@gmail.com','Joseph Nguyen','Langelunden 4, 1. tv.','Nivaa','','DENMARK','2990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 15:16:03',0,NULL,3,1,2,1,'\\ ','thanh_ng'),(11364,847099257012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','fittididi','dieter.hemmann@kabelmail.de','Dieter Hemmann','Krähenberg 85','Celle','','GERMANY','29225','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 15:16:14',0,NULL,3,1,3,1,'RA184560000CN\r ','fittididi\rGLOT005\r白色的'),(11365,847101321012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','the-yorkist','pollaxe@yahoo.com','Dr J P Flynn','Kirkstone<br>Leys Hill','Ross on Wye','Herefordshire','UNITED KINGDOM','HR9 5QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 15:19:57',0,NULL,3,1,3,1,'RA184554049CN\r ','the-yorkist\rWLAP008'),(11366,847102536012,220785819830,'NIB 3D Active Shutter TV Glasses 4 Mitsubishi Japan TV',1,'GLOT001',44.89,'eastar4','strouds51','glenndonson@hotmail.com','Glenn Donson','613 Casa De Leon','Redlands','CA','UNITED STATES','92373-5787','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 15:25:42',0,NULL,3,1,1,1,'\\ ','strouds51\r兼容型3D眼镜 通用型'),(11367,622224817013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','johnaniamaia','jmoyer4@twcny.rr.com','John Moyer','PO Box 377<br>80 Covington St','Fort Covington','NY','UNITED STATES','12937-0377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 15:50:23',0,NULL,3,1,1,1,'\\ ','johnaniamaia'),(11368,847114279012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','gkk1969a','gkk1969@yahoo.com','Georgi Kostadinov','39 Christie Park Hill SW','Calgary','AB','CANADA','T3H 2E8','(403) 802-0850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 15:50:33',0,NULL,3,1,2,1,'\\ ','gkk1969a'),(11369,622224102013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','theitlegend','buebel@netspace.net.au','Brett Uebel','BusinessLink, Loading Dock, 23-31 Moore Street<br>Liverpool','Sydney','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 15:57:40',0,NULL,3,1,2,1,'\\ ','theitlegend'),(11370,622228194013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','jonelias_123','jonelias@online.no','Jon Eliassen','Ulefossvegen 132','Skien','','NORWAY','3728','004791139812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 16:00:55',0,NULL,3,1,3,1,'RA184559973CN\r ','jonelias_123\r兼容型3D眼镜 通用型\rGLOT001*2'),(11371,763586275011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT004',89.78,'eastar4','63dieselear','jfinn07@peoplepc.com','John Finn','PO Box 1161<br>100 Third St','Olathe','CO','UNITED STATES','81425-1161','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 16:16:35',0,NULL,3,1,1,1,'/  ','63dieselear\r兼容型3D眼镜  samsung 专用'),(11372,763590033011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','1fremgen','fremgen@cableone.net','William Fremgen','5262 N Papago PL','Boise','ID','UNITED STATES','83713','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 16:17:22',0,NULL,3,1,1,1,'\\ ','1fremgen'),(11373,622236805013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','chozen03','padfoo@yahoo.com','Garrick Paddyfoote','2459 Quarry Ridge Ln','Raleigh','NC','UNITED STATES','27610-5666','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 16:30:42',0,NULL,3,1,1,1,'\\ ','chozen03'),(11374,622238209013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','d_stenvig','d_stenvig@hotmail.com','Daniev Stenvig','Siloveien 4','Oslo','','NORWAY','0576','+4797568960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 16:33:02',0,NULL,3,1,2,1,'\\ ','d_stenvig'),(11375,622245937013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','schollenfischer','anscho@onlinehome.de','Andreas Scholz','Platanenstr. 29','Reichenbach','','GERMANY','08468','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 16:55:52',0,NULL,3,1,2,1,'\\ ','schollenfischer'),(11376,622255185013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Mark Andersen','6450 NE 183rd St','Kenmore','WA','UNITED STATES','98028-7910','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 17:24:54',0,NULL,3,1,1,1,'\\ ','321expressllc\r一共买了两个'),(11377,622256799013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Mark Andersen','6450 NE 183rd St','Kenmore','WA','UNITED STATES','98028-7910','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 17:26:59',0,NULL,3,1,17,0,'\\ ','321expressllc'),(11378,622257636013,230560589392,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','david guzman','2501 BELLEVIEW RD','Upland','CA','UNITED STATES','91784-1196','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 17:30:30',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11379,622260636013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','neromester','banfai.gabor@freemail.hu','Gabor Banfai','20. Bewdley Grove<br>Broughton','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK10 9NL','07877161563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 17:37:16',0,NULL,3,1,2,1,'\\ ','neromester'),(11380,566615820003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','Sergio Nacht','11C GREAT MEADOW LN<br>TOP#74911','EAST HANOVER','NJ','UNITED STATES','07936','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 17:39:07',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11381,622261269013,230646254414,'New Philips Standard Sonicare ProResult Toothbrush head',2,'HBPH004',19.98,'eastar4','j109856','strongjohn10856@gmail.com','John McCarthy','9990 Lake Forest Way','Roswell','GA','UNITED STATES','30076','(843) 597-1660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 17:39:49',0,NULL,3,1,1,1,'\\ ','j109856'),(11382,847168280012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','kvaksiukee','ugne.motuzaite@yahoo.com','Ugne Motuzaite','Lyros 11-56','Šiauliai','Siauliai','LITHUANIA','78275','+37068351312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 17:42:41',0,NULL,3,1,2,1,'\\ ','kvaksiukee\r24K 多色伞 '),(11383,566618436003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','Robert Switzer','65 Nelson Rd','Mifflintown','PA','UNITED STATES','17059-7557','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 17:43:48',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11384,566619921003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','SUSAN JENNINGS','360 MARTIN DR','BOULDER','CO','UNITED STATES','80305-3445','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 17:48:01',0,NULL,3,1,1,1,'\\ ','321expressllc'),(11385,847178168012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','fbzandbaozhong','fbzand@hotmail.com','baozhong feng','54 lucien st','markham','ON','CANADA','l3r5c9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 17:55:17',0,NULL,3,1,3,1,'RA184559995CN\r ','fbzandbaozhong\rGLOT001*2\r兼容型3D眼镜 通用型'),(11386,847181017012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',7.8,'eastar4','privateconan','jeff0302@hotmail.com','Young In Choi','31/20 Beissel st.<br>Belconnen','Canberra','Australian Capital Territory','AUSTRALIA','2617','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 18:01:54',0,NULL,3,1,2,1,'\\ ','privateconan'),(11387,847181787012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','jsveillette','j_veillette@yahoo.com','Jean-Sébastien Veillette','245 Randill','Châteauguay','QC','CANADA','J6J 2P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 18:03:01',0,NULL,3,1,2,1,'\\ ','jsveillette'),(11388,763642123011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','roehlk','pascalrohlk@yahoo.de','Eva Baha','24772 Daphne West','Mission Viejo','CA','UNITED STATES','92691','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 18:05:17',0,NULL,3,1,1,1,'\\ ','roehlk'),(11389,847197778012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','osatronix','osatronx@gmail.com','Lukasz Osojca','Flat 5 Blenheim House<br>Finchett Drive','Chester','Cheshire','UNITED KINGDOM','CH1 4DW','07849427311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 18:29:00',0,NULL,3,1,2,1,'\\ ','osatronix'),(11390,847204999012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','jwallace2007','ajcyprus@virginmedia.com','James wallace','83 falkirk road','Bonnybridge','Falkirk','UNITED KINGDOM','Fk4 1ba','01324874858','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 18:40:52',0,NULL,3,1,3,1,'RA184554021CN\r ','jwallace2007\rHSPL011\r英标'),(11391,763668292011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','rickaleman','rickyricardorockero@hotmail.com','Ricardo Aleman','2030 W Baseline Rd<br>Ste 182-220','Phoenix','AZ','UNITED STATES','85041-6574','(602) 393-8174','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 18:50:59',0,NULL,3,0,1,1,'\\ ','rickaleman'),(11392,763672374011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','serious_networker','advisnet@gmail.com','Ahmet Özgündogan','Knöllgasse 8 / 1','Vienna','','AUSTRIA','1100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 19:04:45',0,NULL,3,1,3,1,'RA184559960CN\r ','serious_networker\rTRTS001*10'),(11393,763678980011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','timisu87','ip96@newpaltz.edu','Alan Ip','38 sylvan pl','valley stream','NY','UNITED STATES','11581-1311','(516) 603-7690','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 19:09:02',0,NULL,3,1,1,1,'\\ ','timisu87'),(11394,847235591012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',2,'CRLO001',27.98,'eastar4','chess1111','daniel.r.eden@lmco.com','Dan   Eden','2100 Eden Wood Ln','Gambrills','MD','UNITED STATES','21054-2101','(410) 721-5358','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 19:27:54',0,NULL,3,1,1,1,'\\ ','chess1111'),(11395,723232173001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','ddmg11','molinadorian@hotmail.com','dorian molina gonzalez','7979 NW 21st St<br>SJO 043817','Doral','FL','UNITED STATES','33122-1630','(305) 867-4798','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 19:36:43',0,NULL,3,1,1,1,'\\ ','ddmg11'),(11396,618093232013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','twocatgolf','twocatgolf@msn.com','Patrick A Benson','3661 S mission Pkwy','Aurora','CO','UNITED STATES','80013-2442','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 19:42:08',0,NULL,3,1,1,1,'\\ ','twocatgolf'),(11397,763702160011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.99,'eastar4','jerardo1973305','jerardo1973@yahoo.com','dianelys ramos','4771 NW 167th St','Miami Gardens','FL','UNITED STATES','33055','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-12 19:48:25',0,NULL,3,1,1,1,'\\ ','jerardo1973305'),(11398,622317134013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','bhagawadgita','leahcim_2002de@yahoo.de','Michael Becker','Kreisstraße 9','Halle/Westf.','','GERMANY','33790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 19:51:13',0,NULL,3,1,2,1,'\\ ','bhagawadgita'),(11399,763708835011,320721819789,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','olgabogu','ockar7@gmail.com','Olga Boguslavsky','Levontin 13','Rishon Le-Zion','Hamerkaz','ISRAEL','75315','0522907923','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 20:00:58',0,NULL,3,1,2,1,'\\ ','olgabogu\r黑底七色边彩虹伞 '),(11400,763717358011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','13rosenstolz','cori.hartmann@web.de','Corinna Hartmann','Dornbergsweg 39a','Wernigerode','','GERMANY','38855','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 20:16:51',0,NULL,3,1,2,1,'\\ ','13rosenstolz'),(11401,847269491012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','transcend2000','jane@onewaylife.co.uk','Jane Boyes','5 Hawthorne Drive','Leeds','West Yorkshire','UNITED KINGDOM','LS277YJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 20:25:22',0,NULL,3,1,3,1,'RA184559911CN\r ','transcend2000\rWLAP008'),(11402,723262492001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','reshad_the_one','resadk@gmail.com','Resad Kesedzic','Hisingsgatan 1','Goteborg','','SWEDEN','41703','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 20:39:00',0,NULL,3,1,3,1,'RA184554106CN\r ','reshad_the_one\rBR3D005'),(11403,723263493001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','2236joseph','joe667@verizon.net','joseph piotti','136 Thomas Ave','maple shade','NJ','UNITED STATES','08052-3237','(856) 667-5465','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 20:39:51',0,NULL,3,1,1,1,'\\ ','2236joseph'),(11404,847284262012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.9,'eastar4','sweetslover2','ana_old@yahoo.co.uk','Marta Dolna','232 Formartine Road','Aberdeen','Aberdeen City','UNITED KINGDOM','AB24 2RD','1224480978','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 20:52:49',0,NULL,3,1,2,1,'\\ ','sweetslover2\racer 4pin1.25 8cm'),(11405,846488685012,220815930312,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',22.93,'eastar4uk','j.adel','e.adel@arcor.de','JALCO Autoteile','Dahlien Str. 4 a<br>(Gewerbegebiet Rosenstrasse)','Bad Segeberg','','GERMANY','23795','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 21:02:18',0,NULL,3,1,3,1,'RA184554097CN\r ','j.adel\r欧标\rHSMO021+CCGR001\r再发一个Griffin Dual USB Car Charger for iPhone ipad iPad2\r'),(11406,622343671013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.9,'eastar4','rjr104','rjrabenberg@qwest.net','Russell Rabenberg','PO Box 711<br>243 E. 3rd Street','Parker','SD','UNITED STATES','57053-0711','(605) 659-0743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 21:04:10',0,NULL,3,1,1,1,'\\ ','rjr104'),(11407,763748997011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','pablito23455','pablito23@centrum.sk','Pavol Zagrapan','C/O John Bogue<br>Dublin Road','Monaghan','Monaghan','IRELAND','default','0857444083','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 21:25:32',0,NULL,3,1,3,1,'RA184554018CN\r ','pablito23455\rHSJA011\r英标'),(11408,763745843011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','marcelogpinto','marcelogap@gmail.com','Roberto Galvão de Almeida Pinto','Rua Miguel Petroni, 4900<br>Casa 307, Condominio Res. Eldorado','São Carlos','São Paulo','BRAZIL','13563-470','+55(16)97025751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 22:25:51',0,NULL,3,1,3,1,'RA184559179CN\r ','marcelogpinto\rOTSO004'),(11409,763679670011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','gamjo06','crashpoint2@gmail.com','Gaute Mjøen','Kløversvingen 18','KONGSBERG','','NORWAY','3612','4741421509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 22:26:50',0,NULL,3,1,2,1,'\\ ','gamjo06'),(11410,566714266003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','kaptmike1','kaptmike1@aol.com','Mike Mobley','570 Old Alabama Rd SE','Cartersville','GA','UNITED STATES','30120','(678) 794-3899','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 22:33:21',0,NULL,3,1,1,1,'\\ ','kaptmike1'),(11411,847326791012,220815928644,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',13.5,'eastar4uk','hariharpal123','hariharpal@vodafone.ie','Hariharpal Singh','25 Colpe View<br>Deepforde','Drogheda','Co Meath','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 22:39:03',0,NULL,3,1,3,1,'RA184554035CN\r ','hariharpal123\rWLIN010'),(11412,844254919012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','jasc-com-au','sales@jasc.com.au','Andrew Campbell','19 John Street','Basin View','New South Wales','AUSTRALIA','2540','0421511747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 22:49:23',0,NULL,3,1,2,1,'\\ ','jasc-com-au'),(11413,763778534011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jeremyb1282','beesleyjeremy@yahoo.com','jeremy beesley','8278 limekiln rd','lyons','NY','UNITED STATES','14489-9350','(315) 483-4326','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 22:52:09',0,NULL,3,1,1,1,'\\ ','jeremyb1282'),(11414,723314135001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',32.98,'buysia','cardman37125801','cardman3@suddenlink.net','keith j bowling','463 hunt ave','beckley','wv','UNITED STATES','25801','(304) 252-6185','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 23:17:48',0,NULL,3,1,1,1,'\\ ','cardman37125801\r\r怪兽屋和爱丽丝两张碟'),(11415,763512808011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','schumiji12','upchar@gmail.com','Xuan Ji','9/7 McMILLAN ST<br>VICTORIA PARK','Perth','Western Australia','AUSTRALIA','6100','0061425828058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 23:36:17',0,NULL,3,1,2,1,'\\ ','schumiji12'),(11416,763794896011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','sbg594','gibbys@bellsouth.net','Scott Gibby','339 Beverly Rd NE','Atlanta','GA','UNITED STATES','30309-2728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 23:50:54',0,NULL,3,1,1,1,'\\ ','sbg594'),(11417,763796199011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','chamoy20006','michelchapoytx@hotmail.com','Michel Chapoy','12317 La guardia Ln','Del Valle','TX','UNITED STATES','78617-3661','(512) 964-7199','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 23:54:59',0,NULL,3,1,1,1,'\\ ','chamoy20006'),(11418,763802722011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.9,'eastar4','sergent253','sguenin25@hotmail.com','Sebastien GUENIN','974 MARMIER','LONGUEUIL','QC','CANADA','J4K4S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 00:19:41',0,NULL,3,1,2,1,'\\ ','sergent253'),(11419,763809814011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','redsun03','goku00000000@yahoo.com','Man Hui','698 Taylor Dr','Monterey Park','CA','UNITED STATES','91755','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 00:46:35',0,NULL,3,1,1,1,'\\ ','redsun03'),(11420,845860051012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','bpigs123','rachaelgiorgini@iinet.net.au','rachael giorgini','12 challenge place<br>balcatta','perth','Western Australia','AUSTRALIA','6021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 02:16:40',0,NULL,3,1,3,1,'RA184559307CN\r ','bpigs123\rOTSO004*2'),(11421,844660178012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','audanne619','yerduachi@aol.com','Audrey Harling','2917 Moon Lake Dr','West Bloomfield','MI','UNITED STATES','48323-1843','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 02:19:10',0,NULL,3,1,1,1,'\\ ','audanne619'),(11422,763836592011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.99,'eastar4','meacod','meacod@gmail.com','Ana Vranjes','41 McDonald Street','Herne Hill','Western Australia','AUSTRALIA','6056','0892964561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 02:25:03',0,NULL,3,1,2,1,'\\ ','meacod'),(11423,763840974011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',139.99,'eastar4','jhar9591','joseinfinity10@yahoo.com','james harrison','5839<br>stagecoach rd','rex','GA','UNITED STATES','30273','(678) 523-0024','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 02:39:27',0,NULL,3,1,1,1,'/','jhar9591'),(11424,763853131011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','yellownuts88','stanley_diep@hotmail.com','Long Diep','132 Glynde Ave','Burnaby','BC','CANADA','V5B 3J2','(778) 861-7766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 03:31:52',0,NULL,5,0,18,0,NULL,'yellownuts88\r客户要撤单 已退款'),(11425,846230407012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','andyl1977','andrewloucas@hotmail.com','Andrew Loucas','33 Windella Quadrant, Doncaster','Melbourne','Victoria','AUSTRALIA','3108','0398916446','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'andyl1977'),(11426,763865202011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','aaronldoyle','aaronleedoyle@gmail.com','Aaron Doyle','1692 Jefferson Ave','Kingsport','TN','UNITED STATES','37664','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 04:29:53',0,NULL,3,1,1,1,'\\ ','aaronldoyle'),(11427,763867654011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2',113.99,'eastar4','gilbertofdez56','gylmachy01@yahoo.com','gilberto fernandez','8024 Tatum Waterway Dr<br>Apt 4B','miami beach','FL','UNITED STATES','33141-5311','(786) 376-3018','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 04:44:05',0,NULL,3,1,1,1,'/  ','gilbertofdez56\r带张碟'),(11428,566776099003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',4,'WLDE001',59.6,'cnfaner','todor7004','todor_p@yahoo.com','TODOR PETKOV','4428 N CENTRAL AVE<br>Apt 2E','CHICAGO','IL','UNITED STATES','60630','(773) 807-0471','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 04:44:12',0,NULL,3,1,1,1,'\\ ','todor7004'),(11429,847426838012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','helderambo','helderkeitaro@hotmail.com','helder ambo','rua oscar rodrigues de oliveira<br>Ed. Delorme nº731 apto. 101','vitoria','Espírito santo','BRAZIL','29060720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 04:45:48',0,NULL,3,1,2,1,'\\ ','helderambo'),(11430,763869409011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','hermesau','hsurjani@iinet.net.au','Hermanto Surjani','20 Walters Rd','Blacktown','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 04:54:05',0,NULL,3,1,2,1,'\\ ','hermesau'),(11431,847458219012,220455488077,'HP TX2500 TX2500z TX2z Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',9.9,'eastar4','radimg73','radoslavmg@gmail.com','Radoslav Georgiev','Bratia Bakston bl208 entr.J(7) ap.20','Sofia','','BULGARIA','1618','+359/897356942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 07:20:50',0,NULL,3,1,2,1,'\\ ','radimg73\rHP 8pin 0.8 3cm'),(11432,566796818003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','hebeda','martin.hoehne@minipci.biz','Martin Hoehne','minipci.biz<br>forststrasse 16','Leipzig','','GERMANY','04229','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 07:29:17',0,NULL,3,1,3,1,'RA184554477CN\r ','hebeda\rWLIN016'),(11433,723418993001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','richard1697honda','richard.silva@ntlworld.com','richard silva','121 birchwood hill','leeds','West Yorkshire','UNITED KINGDOM','ls178nt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 07:41:04',0,NULL,3,0,3,1,'RA184554145CN\r ','richard1697honda\rBR3D005\r已入库'),(11434,622469781013,230518594351,'UNLOCKED HS2300 SIERRA MC8775 3G for Dell/lenovo/Ace​r',1,'WWSI001',30.99,'eastar4','5huj44u','ahmedshujaau@gmail.com','Nasrulla Mohamed','MA.Dhubuge 2nd Floor 2B<br>Saimaa Goalhi','Male','Asia','MALDIVES','20245','+ 960 7783096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 08:00:54',0,NULL,3,1,3,1,'RA184554928CN\r ','5huj44u\rWWSI001'),(11435,572266776004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','jsaarela','jiisaa@me.com','Jere Saarela','Purjehtijankatu 19 A','Rauma','','FINLAND','26200','358-400-809070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 08:40:15',0,NULL,3,1,3,1,'RA184554914CN\r ','jsaarela\r欧标\rHSPL015'),(11436,847252647012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'eastar4','omejc84','ziga.omejc@gmail.com','Ziga Omejc','Kovorska cesta 43','Trzic','Europe','SLOVENIA','4290','+38670821919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 08:45:21',0,NULL,3,1,2,1,'\r\\ ','omejc84'),(11437,847487546012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','proefect','gaston_007@hotmail.com','Marcos Sisto','21550 Provincial Blvd<br>Apt 1022','katy','TX','UNITED STATES','77450-7569','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 09:21:36',0,NULL,3,1,1,1,'\\ ','proefect'),(11438,847484057012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.99,'eastar4','private0786','sfpatka@pol.net','Shahida Patka','3621 Burning Tree Ct','Martinez','GA','UNITED STATES','30907-9503','(706) 868-0466','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 09:31:31',0,NULL,3,1,1,1,'\\ ','private0786'),(11439,763928919011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','a.shev','alex.shevelev@gmail.com','Alex Shevelev','11 / 131 Macquarie St','Sydney','New South Wales','AUSTRALIA','2000','0425316540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 09:39:13',0,NULL,3,1,2,1,'\\  ','a.shev\rHSUE002\r'),(11440,847506016012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',1,'HSJA006',9.49,'eastar4uk','g3fox','blue.bellfarm@btconnect.com','Geoff fox','Bluebell Farm<br>Spa Common','North Walsham','Norfolk','UNITED KINGDOM','NR28 9AJ','01692500146','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 10:28:17',0,NULL,3,1,3,1,'RA184554715CN\r ','g3fox\rHSJA006\r英标'),(11441,8881315909789070,111,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',5,'UDAP001',165,'eastar4','rctienda','sixtysiete@gmail.com','Carlos Velasco','Eladia Baylina 38 1-C','Ponferrada','Leon','SPAIN','24400 ','',NULL,NULL,NULL,'2011-09-13 10:29:49',0,NULL,3,0,3,1,'RA184554154CN\r ','UDAP001 '),(11442,763941476011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',59.99,'eastar4','romanrabinovich','boris86@gmail.com','Rabinovich Boris','Shimshon Hagibor 5/5','Herzeliya','','ISRAEL','46790','972522459150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 10:36:54',0,NULL,3,1,3,1,'RA184554945CN\r ','romanrabinovich\rGLSG001'),(11443,723457601001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','tonycmsoh2008','tonycmsoh@gmail.com','Soh Chun Ming TONY','38/F., One Kowloon , 1 Wang Yuan Street, Kowloon Bay, Hong Kong','default','','HONG KONG','default','852-98606278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 10:48:09',0,NULL,3,0,2,1,'\\  ','tonycmsoh2008\rOTSB001'),(11444,763949217011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','adara95','gh@frarominternational.ro','Gheorghe Olarescu','10 Lascar Catargi','IASI','Iasi','ROMANIA','700107','+40744530195','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 10:55:08',0,NULL,3,1,3,1,'RA184554772CN\r ','adara95\rHSPL015\r欧标'),(11445,763972576011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','texas-fm','gorecbay@gmail.com','Aleksanr Gorskiy','Tulaka st., 14-44','Volgograd','Volgogradkaya obl','RUSSIAN FEDERATION','400119','905-063-8383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 12:15:08',0,NULL,3,1,2,1,'\\  ','texas-fm\r微软的'),(11446,622521341013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','paramount_world_coins','paramount@numismatics.com.au','Walter Eigner','123/11 - Unit B504 Montrari Condominium<br>Moo 1, Jomtien Beach Rd','Na Jomtien, Sattahip','Chon Buri','THAILAND','20250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 12:36:10',0,NULL,3,1,2,1,'\\ ','paramount_world_coins'),(11447,847548045012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','ow3w','gacruz2@live.com','Guillermo Cruz','1212 n howard ave','tampa','FL','UNITED STATES','33607-5322','(813) 494-1583','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 12:40:05',0,NULL,3,1,1,1,'\\ ','ow3w\racer 8pin1.00 8cm'),(11448,763978662011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','cbar5225','christophertbarrow@yahoo.com','CHRISTOPHER BARROW','7945 Cherrywood Ct','CINCINNati','OH','UNITED STATES','45224-1113','(513) 886-4400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 12:35:17',0,NULL,3,1,1,1,'\\  ','cbar5225'),(11449,763984557011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','boldogt','tboldog@gmail.com','Tamás Boldog','Csokonai u. 3/12','Szigetszentmiklós','Pest','HUNGARY','2310','+36702365341','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 12:53:05',0,NULL,3,1,2,1,'\\  ','boldogt'),(11450,847551012012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',70.99,'eastar4uk','karaoke_kangaroo','karaokekangaroo@optusnet.com.au','Trevor McGrath','44  Bellara  Dr','Mooroolbark','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 12:55:42',0,NULL,3,1,3,1,'RA184554980CN\r ','karaoke_kangaroo\rOTSO004*2'),(11451,764001156011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','lkeller88','louella_keller88@hotmail.com','Louella Keller','11 Jacqueline Pl','Pakenham','Victoria','AUSTRALIA','3810','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 13:43:41',0,NULL,3,1,2,1,'\\ ','lkeller88'),(11452,847570791012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','arturtikkerberi','artur.tikkerberi@itk.ee','Artur Tikkerberi','Valjaku 6a-27','Jyri','Harjumaa','ESTONIA','75301','+37256638265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 13:46:09',0,NULL,3,1,2,1,'\\  ','arturtikkerberi'),(11453,761513320011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','delineator333a','roger_gaspar@hotmail.com','Roger Gaspar','5 Peck Hay Road, 05-08','default','','SINGAPORE','228307','(656) 527-5770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 13:49:36',0,NULL,3,1,3,1,'RA184554905CN\r ','delineator333a\rHBPH002'),(11454,847574109012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',4,'HSPL011',55.4,'eastar4uk','gd_n','gd_n2@yahoo.com','Georgi Nalbantov','Slavianska 85','Plovdiv','Plovdiv','BULGARIA','4000','+359878440198','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 13:53:02',0,NULL,3,1,3,1,'RA184554790CN\r ','gd_n\r欧标\rHSPL011'),(11455,764004267011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',43.98,'eastar4uk','therussellnewton','russellnewton@mac.com','Russell Newton','62 Bairro Che Lagoense','Lagoa','','PORTUGAL','8400-303','+351968600599','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 13:53:26',0,NULL,3,1,3,1,'RA184554786CN\r ','therussellnewton\rUDAP001'),(11456,764013233011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',2,'RELO003',15,'eastar4uk','no_dos','j.jekabsons@web.de','J.Jekabsons  c/o  Krzywdzinski','Boddinstr.21','Berlin','','GERMANY','12053','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 14:19:50',0,NULL,3,1,2,1,'\\  ','no_dos\r红边优联'),(11457,847584206012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','florfilla19','florian.lointier@gmail.com','LOINTIER Florian','8 rue Pierre Chausson','Paris','Île-de-France','FRANCE','75010','0676677048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 14:20:48',0,NULL,3,1,2,1,'\\  ','florfilla19'),(11458,622513697013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','ulitsa Varshavskaya dom19 korpus 1 kvartira 113','Sankt-Peterburg','','RUSSIAN FEDERATION','196128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 14:26:12',0,NULL,3,1,3,1,'RA184554724CN\r ','levbarkan\rWWSI005'),(11459,764019675011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','poloshop','cdmiddlebrooks@gmail.com','Charles Middlebrooks','5717 Woodcastle Dr','Waco','TX','UNITED STATES','76710-1551','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 14:37:29',0,NULL,3,1,1,1,'\\ ','poloshop'),(11460,622549943013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','shifty25','paypal@shifty.org','Jason Genung','938 Peachtree St NE<br>Ste 200','Atlanta','GA','UNITED STATES','30309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 14:39:50',0,NULL,3,1,1,1,'\\  ','shifty25'),(11461,764020511011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','slamster1','lornegoldman@gmail.com','Lorne Goldman','932 Chemin Panneton','Labelle','QC','CANADA','J0T 1H0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 14:44:34',0,NULL,3,1,3,1,'RA184554865CN\r ','slamster1\rHBPH002'),(11462,764030041011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',3,'CASS003',17.97,'eastar4uk','kwekwe2010','kdidipg@yahoo.com','Eric Dadzie','153 Tiverton road<br>selly oak','Birmingham','Gb','UNITED KINGDOM','B29 6BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 15:06:12',0,NULL,3,1,3,1,'RA184554741CN\r ','kwekwe2010\rCASS003'),(11463,572350988004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','ohmeitanaka1966','ohmei.tanaka@nifty.com','Kazuhiro Tanaka','Deiki 1-28 A-906<br>Kanazawa-ku','Yokohama','Kanagawa','JAPAN','236-0021','045-784-2316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 15:33:23',0,NULL,3,1,3,1,'RA184568961CN ','ohmeitanaka1966\rWWOT003+ANCN001'),(11464,847612020012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','philippe-mouse','philippe.claesens@telenet.be','philippe claesens','moerstraat 9','nevele','','BELGIUM','9850','+3293718771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 15:34:42',0,NULL,3,1,3,1,'RA184554959CN\r ','philippe-mouse\rGLOT001*2\r兼容型3D眼镜 通用型'),(11465,764042715011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',10.39,'eastar4uk','tomcat1lynch','grahamalynch1@btinternet.com','graham lynch','9 moretons lane','wareham','Dorset','UNITED KINGDOM','bh20 4hn','01929552176','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 15:37:16',0,NULL,3,1,3,1,'RA184554675CN\r ','tomcat1lynch\rWLAT008'),(11466,764043202011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',15.14,'eastar4','przandy1','andype@swbell.net','Andy Perez','8610 Silent Oaks','San Antonio','TX','UNITED STATES','78250-6228','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 15:48:50',0,NULL,3,0,1,1,'\\ ','przandy1\r已入库'),(11467,845212515012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','maychen316','mchen316@gmail.com','YIHUI CHEN','3025 Courthouse Dr W<br>Apt 3B','West Lafayette','IN','UNITED STATES','47906-1039','(765) 714-0501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 15:56:02',0,NULL,3,1,1,1,'\\  ','maychen316'),(11468,847603206012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','snoplo','pokey994@hintonet.net','donna j wheeler','po box 247','hinton','OK','UNITED STATES','73047-0247','(405) 542-6196','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 15:59:13',0,NULL,3,1,1,1,'\\ ','snoplo'),(11469,764052945011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','markmarrs','markmarrs@yahoo.com','John Marrs','245 Sunday Dr','Burnet','TX','UNITED STATES','78611-4546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 16:04:25',0,NULL,3,1,1,1,'\\  ','markmarrs'),(11470,622577003013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','rickteh','rickteh@melbpc.org.au','Rick Teh','92 Lakeview Ave','ROWVILLE','Victoria','AUSTRALIA','3178','0421059870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:10:41',0,NULL,3,1,2,1,'\\  ','rickteh'),(11471,622577588013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','kebabb','kenneth.nygard@gmail.com','Kenneth Nygård','Haresporet 23','Førde','Norway','NORWAY','6800','004797769302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:11:58',0,NULL,3,1,2,1,'\\ ','kebabb'),(11472,764056352011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','msti6657','marksti@verizon.net','Mark Stiegelbauer','20910 41st Ave<br>Apt 5F','Bayside','NY','UNITED STATES','11361-1907','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 16:12:44',0,NULL,3,1,1,1,'\\ ','msti6657'),(11473,847634037012,220815929174,'New APPLE iMac G6 Bluetooth Wireless Keyboard',1,'KBAP003',44.99,'eastar4uk','yoodoll','liberalmeaning@hotmail.com','Sophie Hatton','11 Ashford Close<br>Cosham','Portsmouth','Hampshire','UNITED KINGDOM','PO6 3UB','02392428775','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 16:21:31',0,NULL,3,1,3,1,'RA184569009CN ','yoodoll\rKBAP003'),(11474,620898018013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.98,'eastar4','malvite','manalvi@msn.com','Manuel Alvite Buigues','C/ SA GERRERIA, 5 3-7ª','Ibiza','Baleares','SPAIN','07800','639837558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:26:48',0,NULL,3,1,2,1,'\\  ','malvite'),(11475,572366203004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',35.6,'cnfaner','maleorderbride','coemery@ucdavis.edu','PC Repair and Education','916 Pennsylvania Pl','Davis','CA','UNITED STATES','95616-2310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 16:30:14',0,NULL,3,1,1,1,'\\ ','maleorderbride'),(11476,566913327003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.9,'cnfaner','taoseno4349','gfuller818@comcast.net','  Guy Fuller','818 Gonzales Rd','Santa Fe','NM','UNITED STATES','87501-8925','(505) 983-4439','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 17:00:24',0,NULL,3,1,1,1,'\\  ','taoseno4349'),(11477,622592511013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',50.94,'eastar4','kamel.assameur','abdelkrim.assameur@laposte.net','ASSAMEUR Abdelkrim','20 RUE ROUSSELLE','PUTEAUX','Ile-de-France','FRANCE','92800','+33649890421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 17:08:34',0,NULL,3,1,3,1,'RA184554830CN\r ','kamel.assameur\rCASS003'),(11478,764086951011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','lenta15','emstraver@wanadoo.nl','E. Straver','Noppenstraat 60','Zwaanshoek','','NETHERLANDS','2136AJ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 17:22:13',0,NULL,3,1,3,1,'RA184554843CN\r ','lenta15\rGLOT001\r兼容型3D眼镜 通用型'),(11479,847662978012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','kenpatken','leraypatrick@msn.com','patrick LERAY','36 compayne gardens,flat 2','LONDON','London','UNITED KINGDOM','NW63DR','02076253627','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 17:26:01',0,NULL,3,1,3,1,'RA184554667CN\r ','kenpatken\rWLAP008   投递不成功退回'),(11480,622600733013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','aadvincol','vincentblans@ziggo.nl','Vincent Blans','Loosduinse Hoofdstraat 1152','\'S-GRAVENHAGE','','NETHERLANDS','2552AT','+31644902490','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'aadvincol'),(11481,847670927012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',10,'MOAP001',249.9,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','American River College - Receiving','4700 College Oak Dr','Sacramento','CA','UNITED STATES','95841-4286','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 17:40:03',0,NULL,3,1,4,1,'YW865546733CN ','321expressllc'),(11482,764096027011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',2,'CASS003',11.98,'eastar4uk','pierredacres','pierre_dacres@hotmail.com','Pierre Dacres','6 oxford Street','Watford','Herefordshire','UNITED KINGDOM','wd18 0es','07795266281','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 17:40:03',0,NULL,3,1,3,1,'RA184554826CN\r ','pierredacres\rCASS003'),(11483,847699691012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',49.98,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Brett M Gee','498 N Kays Dr<br>Ste 110','Kaysville','UT','UNITED STATES','84037-4151','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 18:29:18',0,NULL,3,1,1,1,'\\  ','321expressllc'),(11484,847703402012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Maja Ozvaldic','1145 46th Ave<br>Asymptote Architecture','LONG ISLAND CITY','NY','UNITED STATES','11101-5208','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 18:35:07',0,NULL,3,1,1,1,'\\  ','321expressllc'),(11485,566946919003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','hcla3284','hugh_clark@btinternet.com','hugh clark','forest view<br>ashdown forest','forest row','East Sussex','UNITED KINGDOM','rh18 5nd','01342823189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 18:43:02',0,NULL,3,1,3,1,'RA184554888CN\r ','hcla3284\rBALO007'),(11486,764136614011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','dewardde','edward.h.deng@gmail.com','Edward Deng','109 Constitution Road','West Ryde','New South Wales','AUSTRALIA','2114','0288196609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 18:58:58',0,NULL,3,1,2,1,'\\ ','dewardde'),(11487,571899015004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',47.99,'cnfaner','ricardoturco','ricolmsilva@yahoo.com.br','Ricardo Luiz M Silva','R. Udelio Scodro, 183 -Apto. 42.<br>Bq. das Juritis','Ribeirao Preto','Sao Paulo','BRAZIL','14021-680','551681110416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 19:01:46',0,NULL,3,1,3,1,'RA184554809CN\r ','ricardoturco\rOTRA001'),(11488,764151830011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','mngu5797','sn1499@verizon.net','Son Nguyen','613 Morning View Way','Murphy','TX','UNITED STATES','75094','(972) 384-1933','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 19:23:44',0,NULL,3,1,1,1,'\\  ','mngu5797\r微软的'),(11489,761248496011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','ellio2011','ardit.shpk@hotmail.com','Lami Algert','Posta Libonik Maliq<br>Korce','default','Albania MAliq Libonik','ALBANIA','7001','+355674000239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 19:33:59',0,NULL,3,1,2,1,'\\  ','ellio2011\r欧标'),(11490,622649106013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','sherpro2','psherlock@sherlocksos.com','Peter A Sherlock','PO Box 945','Mackay','Queensland','AUSTRALIA','4740','074950652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 19:34:12',0,NULL,3,1,2,1,'\\ ','sherpro2'),(11491,764170520011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','pooh0016justin','pooh0016@gmail.com','Justin Ju','7777 S Jones Blvd<br>Apt 1036','Las Vegas','NV','UNITED STATES','89139-6152','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 19:59:29',0,NULL,3,1,1,1,'\\  ','pooh0016justin'),(11492,763636041011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','nockeramc','mel.andrew@lineone.net','Andrew  Norris  Room 212','Hotel Gasthof Brandstatter<br>Munchner Bundesstr 69','Salzburg','','AUSTRIA','A-5020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 20:00:44',0,NULL,3,1,3,1,'RA184554738CN\r ','nockeramc\rHBPH002'),(11493,847758849012,220815929174,'New APPLE iMac G6 Bluetooth Wireless Keyboard',1,'KBAP003',44.99,'eastar4uk','gilesclayden30','justgiles@yahoo.com','Giles Clayden','Dundridge Gardens','Harberton','Devon','UNITED KINGDOM','TQ9 7PP','07536069703','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 20:06:07',0,NULL,3,1,3,1,'RA184568992CN ','gilesclayden30\rKBAP003'),(11494,764177143011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','rc45164','rsc089-ebay@yahoo.com','Robert Cantalupo','1530 Lincoln Ave','Bohemia','NY','UNITED STATES','11716-1412','(631) 589-2053','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 20:12:37',0,NULL,3,1,1,1,'\\ ','rc45164'),(11495,847769585012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','w.dude','wlodzimierz.d@gmail.com','Wlodzimierz Duda','29 Pelham Road','Norwich','Norfolk','UNITED KINGDOM','NR3 3NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 20:25:28',0,NULL,3,1,3,1,'RA184566078CN\r ','w.dude\rGLOT005'),(11496,764184994011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bizhe2006','xiaodonghao@hotmail.com','Xiaodong Hao','47263 Lyndon Ave','Canton','MI','UNITED STATES','48187-1482','(734) 737-9986','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 20:33:14',0,NULL,3,1,1,1,'\\  ','bizhe2006'),(11497,622682110013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','jopares11','sylviepares11@hotmail.fr','jonathan pares','5 rue des macabeus','Ponteilla','Languedoc-Roussillon','FRANCE','66300','0647555593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 21:04:37',0,NULL,3,1,2,1,'\\  ','jopares11'),(11498,764202488011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','kiwiray11','raytrish@slingshot.co.nz','Raymond Winter','51 Herbert Street','Invercargill','Southland','NEW ZEALAND','9810','0064 32146329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 21:08:15',0,NULL,3,1,3,1,'RA184581733CN\r ','kiwiray11\rGLSG001*2'),(11499,764212227011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','jay_berlino','jay59@web.de','Karin Jahn','Wulfsheinstrasse 4','Berlin','','GERMANY','10585','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 21:29:33',0,NULL,3,1,3,1,'RA184554891CN\r ','jay_berlino\rKBNO001'),(11500,847801053012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',205.99,'eastar4','alkimex95','ron.heidel@ab.telus.net','Ron  Heidel','6013-53 Ave.','Lloydminster','AB','CANADA','T9V 2T1','(780) 808-5209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 21:30:20',0,NULL,3,1,6,1,'EE495359446CN ','alkimex95'),(11501,847815081012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','shauk2010','shauk786@hotmail.co.uk','Shaukat  Hayat','23 bolton road, moses gate<br>farnworth','bolton','Lancashire','UNITED KINGDOM','bl4 7jn','01204578618','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-13 22:06:30',0,NULL,3,1,3,1,'RA184554874CN\r ','shauk2010\rHSSE004\r英标'),(11502,764229001011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',15.99,'eastar4','caminoreal_nm','areal78@hotmail.com','Jesus A Real','304B Norht Pueblo Road','Taos','NM','UNITED STATES','87571','(575) 751-4210','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 22:16:08',0,NULL,3,1,1,1,'\\ ','caminoreal_nm'),(11503,567021803003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','jdb968','jdbradford@iprimus.com.au','J Bradford','23 Orange Valley Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892934665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 22:52:52',0,NULL,3,1,3,1,'RA184554769CN\r ','jdb968\rOMHJ001'),(11504,847830084012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',75.99,'eastar4','roman-vlasov','roman.o.vlasov@gmail.com','Roman Vlasov','Gavanskaya street 2/97-12','St.Petersburg','','RUSSIAN FEDERATION','199106','+79117011932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 23:05:00',0,NULL,3,1,3,1,'RA184554857CN\r ','roman-vlasov\rOTSO002'),(11505,764245772011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','canis513','lukezeller@hotmail.com','Luke Zeller','242 S Beck Ave<br>Apt 140','Tempe','AZ','UNITED STATES','85281-2405','(480) 241-0387','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 23:16:06',0,NULL,3,1,1,1,'\\ ','canis513'),(11506,764260894011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',71.98,'eastar4uk','2020hugh','hugh.seaton@mac.com','Hugh Seaton','P O Box 774','Bowral','New South Wales','AUSTRALIA','2576','0409745756745756','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 00:17:07',0,NULL,3,1,3,1,'RA184554993CN\r ','2020hugh\rOTSO004'),(11507,764263450011,320737015281,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',75.99,'eastar4','nanoneri2011','nanoneri@gmail.com','ADRIANO CRUZ NERI BARBOSA','AV. INAJAR DE SOUZA 3847','SÃO PAULO','SÃO PAULO','BRAZIL','02717-000','11 3985-5671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 00:29:36',0,NULL,3,1,3,1,'RA184580123CN ','nanoneri2011\rOTSO003\r\r新地址\rADRIANO CRUZ NERI BARBOSA\rRua Benta Pereira N49, São Paulo, Brasil,CEP 02451-000\rBRAZIL\r\r'),(11508,847859512012,220501826426,'2.1 New Acer Aspire 3810 3810T  Bluetooth Module+cable',1,'BTAC2118',12.4,'eastar4','cybas7er','gundam_wing_zero@hotmail.com','Christopher Woo','312-33 Cox Blvd','Markham','ON','CANADA','L3R8A6','(647) 206-5559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 00:30:44',0,NULL,3,1,2,1,'\\ ','cybas7er\racer 8pin1.0 3cm'),(11509,764271125011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','psychogab','psychogab@hotmail.com','Gabriel Fallon','411 des trinitaires','st-jean-sur-richelieu','QC','CANADA','j3b 2x4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 00:53:50',0,NULL,3,1,2,1,'\\ ','psychogab'),(11510,567044729003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','nfro7979','nfrostbutter@gmail.com','nick frostbutter','3410 Bayside Forest Ct','huntingtown','MD','UNITED STATES','20639-2300','(443) 684-0705','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 01:05:40',0,NULL,3,1,1,1,'\\  ','nfro7979'),(11511,572506019004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',127,'cnfaner','fabio.crisafulli','fabiocrisafulli@gmail.com','Fabio Alves','Av. Santo Amaro 5750 apt 31','São Paulo','São Paulo','BRAZIL','04702001','551199711130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 01:10:32',0,NULL,3,1,3,1,'RA184554931CN\r ','fabio.crisafulli\rRCMA001'),(11512,572510253004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',127,'cnfaner','fabio.crisafulli','fabiocrisafulli@gmail.com','Fabio Crisafulli Rodrigues Alves','Rua São Benedito 953<br>Santo Amaro','São Paulo','São Paulo','BRAZIL','04735-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 01:21:23',0,NULL,3,1,3,1,'RA184581000CN\r ','fabio.crisafulli\rRCMA001'),(11513,622744189013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',69.9,'eastar4','remash','ash1rsco@msn.com','Ash Fakhoury','20 Yvonne Cres','Georges Hall','New South Wales','AUSTRALIA','2198','0297257473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 01:34:48',0,NULL,3,1,3,1,'RA184555000CN\r ','remash\rMOSA006'),(11514,622752711013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','lordmoya','lordmoya@hotmail.com','Eduardo Moya','1636 Peregrine falcons way<br>Apt 203','orlando','FL','UNITED STATES','32837-8048','(407) 844-3580','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 02:10:50',0,NULL,3,1,1,1,'\\ ','lordmoya\r黑色的'),(11515,847891378012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.48,'eastar4','danielmeneses','daniel7708@msn.com','Daniel Meneses','Rua Ministro Eduardo Eleri Barreira<br>N-60, 901','Fortaleza','Ceara','BRAZIL','60810010','8532410191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 02:13:48',0,NULL,3,1,3,1,'RA184554812CN\r ','danielmeneses\rOTCN004*10\r黑色的'),(11516,847898077012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','chyronn','deenkurrimbux@blueyonder.co.uk','J Kurrimbux','12 St Pauls Road','Thornton Heath','Surrey','UNITED KINGDOM','CR7 8NB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 02:35:39',0,NULL,3,1,3,1,'RA184554755CN\r ','chyronn\rOTCN003'),(11517,567063506003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',3,'HSJA001',71.7,'cnfaner','abaker4047','abaker4047@yahoo.com','Andy Baker','2660 Kay Ellen Dr','Indianapolis','IN','UNITED STATES','46229-1237','(812) 219-4101','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 02:47:56',0,NULL,3,1,1,1,'\\ ','abaker4047'),(11518,723781684001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','star-gem','star-gem@msn.com','Linda A. Walling','1700 174th Pl SE','Bothell','WA','UNITED STATES','98012-6489','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 02:51:51',0,NULL,3,1,1,1,'\\  ','star-gem'),(11718,724688928001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','netaderi19','netta54321@hotmail.com','neta deri','47 adam st. p.o.b 8019','jerusalem','israel','ISRAEL','91080','972547700229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:09:49',0,NULL,3,1,17,0,NULL,'netaderi19'),(11519,847908077012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','nalcomis75','nalcomis75@yahoo.com','Erik Fairbanks','3682 Fenley Dr','Los Alamitos','CA','UNITED STATES','90720-2210','(562) 594-0154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 03:13:12',0,NULL,3,0,1,1,'\\  ','nalcomis75'),(11520,622771252013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',2,'BAZA001',115.98,'eastar4','hncrown','naveedzafar007@gmail.com','Naveed zafar','201-600 Lolita Gardens','Mississauga','ON','CANADA','L5A3K8','(647) 895-5517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 03:54:33',0,NULL,3,1,3,1,'RA184581720CN\r ','hncrown\rBAZA001'),(11521,572549143004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.09,'cnfaner','diegoarmas2011','darmascuba@hotmail.com','Diego Enrique Armas Cuba','Jr. Ruben Paoli N° 242 - P.J. Buenos Aires- Victor Larco Herrera','Trujillo','La Libertad','PERU','13009','+51044-286711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 05:42:16',0,NULL,3,1,3,1,'RA184554123CN\r ','diegoarmas2011\rHSNO005'),(11522,764336486011,320394916388,'Acer Aspire 5570 5570Z Bluetooth Module EDR 2.0+cable',1,'BTAC2015',9.9,'eastar4','rudykruger','rudy.kruger@gmail.com','Rudolf Kruger','456 Rocky Ridge Cove NW','Calgary','AB','CANADA','T3G4J6','(403) 241-1942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 05:43:22',0,NULL,3,1,2,1,'] ','rudykruger\racer 6pin1.25 23cm'),(11523,764337425011,320745265525,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',15.95,'eastar4','jk.wright','jenny.wright@live.se','Jenny Wright','Tranbärsvägen 11','Askersund','','SWEDEN','SE-69634','004658314800','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 05:48:15',0,NULL,3,1,2,1,'] ','jk.wright\r蓝天白云长柄伞'),(11524,764340836011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','priarvget','arvget@mail.ru','David Danielyan','Armenia, Yerevan,<br>Vilnius street 30/21','Yerevan','YEREVAN','ARMENIA','0059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 06:08:44',0,NULL,3,1,2,1,'] ','priarvget'),(11525,847946769012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','reriska-biker','reriska.biker@seznam.cz','Romana Rerichova','Severni 1169/18','Ostrov','Czech Republic','CZECH REPUBLIC','36301','00420604505613','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 06:20:05',0,NULL,3,1,2,1,']','reriska-biker'),(11526,706307357008,180699061044,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','mrtboy69','mrtboy1@gmail.com','Csaba Németh','Búza u. 14.      5/48','Budapest','Budapest','HUNGARY','1033','+36702567084','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 06:20:57',0,NULL,3,1,3,1,'RA184554137CN\r ','mrtboy69\rHSPL005\r欧标'),(11527,847951377012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',3,'HSJA006',28.47,'eastar4uk','konradf2','konradg2@wp.pl','konrad fus','141 boyn valey road','maidenhead','Berkshire','UNITED KINGDOM','sl64dt','077724240982','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 06:41:29',0,NULL,3,1,3,1,'RA184554707CN\r ','konradf2\rHSJA006\r英标'),(11528,847963672012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','kristoffer.grenryd','grenryd@gmail.com','kristoffer grenryd','ejdervägen 26','nyköping','','SWEDEN','61162','+4615870338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 07:41:30',0,NULL,3,0,2,1,'] ','kristoffer.grenryd\r已入库'),(11529,572568011004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','kosherski','k_kosherski@abv.bg','Kalin Kosherski','55 P.R.Slaveikov str.','Pleven','Pleven','BULGARIA','5800','+359878367459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 08:00:07',0,NULL,3,1,3,1,'RA184554684CN\r ','kosherski\rBALO007'),(11530,8881315987937646,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4uk','silver_girl21','amanda.lwin@gmail.com','Amanda Lwin','566A Kingsland Road','Dalston','London','UNITED KINGDOM','E8 4AH','',NULL,NULL,NULL,'2011-09-14 08:12:17',0,NULL,3,1,3,1,'RA184554698CN\r ','补发的\rMOAP001 '),(11531,764367702011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','batusaixix','yinyamina@yahoo.com.ph','Reyes Miguel','Blk 690C Choa Chu Kang Crescent<br>#03-90','Singapore','','SINGAPORE','683690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 08:15:15',0,NULL,3,1,11,1,'RA184554110CN\r ','batusaixix\rANTY002'),(11532,764372294011,320667818608,'New Logitech battery 4  DJ remote diNovo keyboard 930mA',1,'BALO004',10.99,'eastar4','wei803','weiwei803@hotmail.com','Ng Kan Wei','114, Jalan 19,<br>Kampung Sri Indah A,','Sungai Buloh','Selangor','MALAYSIA','47000','0126979362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 08:34:06',0,NULL,3,1,2,1,'\\  ','wei803\r黑色的'),(11533,764375509011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','sbknight2008','hal_corner2@yahoo.com','Yuanhao Li','2183 Wild Flower Ln','chino hills','CA','UNITED STATES','91709-1718','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 08:48:45',0,NULL,3,1,1,1,'、 ','sbknight2008\r红边优联'),(11534,8881315990861319,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',0,'eastar4uk','musicmaster2004','trevor.j@talktalk.net','Trevor  Jones','25 Gretdale Avenue, St,Annes, On Sea','St.,Annes On Sea','Lancashire','UNITED KINGDOM','FY82EE','01253711530',NULL,NULL,NULL,'2011-09-14 09:01:01',0,NULL,3,1,3,1,'RA184554551CN\r ','BALO007\r补发的 '),(11535,764379689011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','xeron29','mamisarak@mynet.com','Muhammet SARAK','800 Konutlar GEneral Fehmi Tuncali caddesi B15 blok Daire 9<br>Tozkoparan GüngörenIstanbul','Istanbul','Marmara bölgesi','TURKEY','34169','0905547628787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 09:07:38',0,NULL,3,1,2,1,'\\  ','xeron29'),(11536,847988728012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'eastar4','romanbreznican','itservis@zoznam.sk','Roman Breznican','SNP 1448/50','Povazska Bystrica','Slovakia','SLOVAK REPUBLIC','01707','+421905955711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 09:14:39',0,NULL,3,1,2,1,'\\  ','romanbreznican'),(11537,847991071012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','xenols','etroitskiy@gmail.com','Evgeniy Troitskiy','Profsouznaya ul, 89, kv. 178','Rostov-na-Donu','Rostovskaya oblast\'','RUSSIAN FEDERATION','344004','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 09:26:02',0,NULL,3,1,2,1,'\\  ','xenols\r欧标'),(11538,723423535001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','mmm0047','matrem@online.no','Magnus Matre','ordføreringebeiktsens gt 13','Drammen','','NORWAY','3045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 09:44:59',0,NULL,3,1,3,1,'RA184554344CN\r ','mmm0047\rBR3D007'),(11539,848005464012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','friz_family','james.frisbee@virginmedia.com','Mr James Frisbee','65 Kinross Crescent<br>Drayton','Portsmouth','Hampshire','UNITED KINGDOM','PO6 2NP','02392795439','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 10:14:31',0,NULL,3,1,3,1,'RA184554300CN\r ','friz_family\rGLOT001*3\r兼容型3D眼镜 通用型'),(11540,764398376011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.49,'eastar4','dani.as','daniel.zxr@gmail.com','daniel asoulin','columbia 2/15','jerusalem','israel','ISRAEL','96583','972-54-7555-339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:17:07',0,NULL,3,1,2,1,'\\ ','dani.as\r带麦的'),(11541,764399261011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',3,'RELO002',38.94,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:23:19',0,NULL,3,1,3,1,'RA184554463CN\r ','masteroll2010\rRELO002'),(11542,848010652012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001',89.78,'eastar4','xronis09','redbull27@windowslive.com','Xronis Galifas','3 str, Nikitara','Magoula Attikis','Athens','GREECE','19600','+306972479192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:31:29',0,NULL,3,1,3,1,'RA184554256CN\r ','xronis09\rGLOT001\r兼容型3D眼镜 通用型'),(11543,848011511012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','warehousedeals4u','hendnova@yahoo.com','Grant Henderson','9 Barfleur lane<br>deptford','London','London','UNITED KINGDOM','SE83DD','02083202190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 10:34:04',0,NULL,3,1,3,1,'RA184554295CN\r ','warehousedeals4u\rHSPL009\r英标'),(11544,764401996011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','mbro3734','b.marek@optusnet.com.au','Marek Bronowiecki','14 Bellevue Ave','Malvern East','Victoria','AUSTRALIA','3145','61412222138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:42:28',0,NULL,3,1,3,1,'RA184554327CN ','mbro3734\rBR3D001'),(11545,847449335012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','sacvi3tboi','sacvietboi05@yahoo.com','Ngan Ly','6395 CALVINE RD','Sacramento','CA','UNITED STATES','95823-5778','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 11:09:44',0,NULL,3,1,1,1,'\\ ','sacvi3tboi'),(11546,848022250012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','konstantin.timofeyev','timofeev82@rambler.ru','Konstantin Timofeyev','Konakovskiy proezd, home12/1, appt 100 ','Moscow','Moscow','RUSSIAN FEDERATION','125565','8-962-970-8928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 11:10:25',0,NULL,3,1,3,1,'RA184554335CN\r ','konstantin.timofeyev\rOTIN005'),(11547,764416829011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','chrisb2829','chris.boyle@eds.com','Chris Boyle','71 Glenluce Drive<br>Farringdon Park','Preston','Lancs','UNITED KINGDOM','PR1 5TD','07790492930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 11:23:16',0,NULL,3,1,3,1,'RA184554361CN\r ','chrisb2829\rRELO003\r红边优联'),(11548,764426911011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','traktoriano','trakitoriano@yahoo.com.br','Rafael Gomes de Araujo','Laerte Monteiro de Oliveira N 247<br>Jd São Conrado','Campo Limpo Paulista','São Paulo','BRAZIL','13231-100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 11:56:34',0,NULL,3,1,2,1,'\\  ','traktoriano'),(11549,848037980012,220816384299,'3 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*3',78.99,'eastar4uk','trevo666','andrewt@tgmgroup.com','Andrew Trevisan','P O Box 77BK','Black Hill','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 11:59:10',0,NULL,3,1,3,1,'RA184554168CN\r ','trevo666\rGLOT001*3\r兼容型3D眼镜 通用型'),(11550,848038644012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','murrrdogg','duner@abv.bg','Dzhuneyt Syulyush','J.K. \"V.Aprilov\" bl.12 , vh.B apt.7','Isperih','Razgrad','BULGARIA','7400','+359898554245','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 11:59:23',0,NULL,3,1,3,1,'RA184566064CN\r ','murrrdogg\rGLOT005'),(11551,764190373011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',25.99,'eastar4uk','srakanov','stefan@volicon.com','Stefan Rakanov','Vitoshko Lale 5','Kostinbrod','Bulgaria','BULGARIA','2230','+359898551205','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 11:47:47',0,NULL,3,1,3,1,'RA184554260CN\r ','srakanov\rWWOT001'),(11552,764430750011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','tuomore','tuomore@gmail.com','Tuomo Renkonen','Kotikatu 4 B 25','Tampere','-','FINLAND','33710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 12:07:54',0,NULL,3,1,3,1,'RA184554389CN ','tuomore\rGLOT001\r兼容型3D眼镜 通用型'),(11553,848045492012,220691756846,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET+car charger',1,'HSNO006+CCNO001',15.99,'eastar4','sashokmgn_74rus','sashok198423@mail.ru','Alexander Gorshkov','68 Sovetskaya Street, Appartment 104','Magnitogorsk','Chelyabinsk region','RUSSIAN FEDERATION','455025','+79028995717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 12:19:39',0,NULL,3,1,2,1,'\\  ','sashokmgn_74rus'),(11554,567150198003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','jhol8669','jholloman@kc.rr.com','Jim Holloman','5293 Foxridge Dr. Apt 304','Mission','KS','UNITED STATES','66202','(913) 451-1569','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 12:22:13',0,NULL,3,1,1,1,'、 ','jhol8669'),(11555,764446251011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'eastar4','ytathnbnb1','dragom_vikti@mail.ru','Виктория Драгомирецкая','Пулковская 3, корп.1, кв.50','Москва','','RUSSIAN FEDERATION','125493','(916) 0554483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 12:55:13',0,NULL,3,1,3,1,'RA184554242CN ','ytathnbnb1\r地图伞 \rUM00007'),(11556,848062135012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','sotirisbladex23','bladex2@yahoo.gr','sotiris lykouris','kriezotou 39, Maniatika<br>Maniatika','Peiraeus','Peiraeus','GREECE','18543','+306957046745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 13:05:54',0,NULL,3,1,3,1,'RA184554375CN ','sotirisbladex23\rGLOT001\r兼容型3D眼镜 通用型'),(11557,848064319012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','maxzealand','max.paulousky@gmail.com','Siarhei Pantsialei','Adzintsova 5-114','Minsk','','BELARUS','220018','+375 29 5029090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 13:14:49',0,NULL,3,1,2,1,'\\  ','maxzealand'),(11558,723917928001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','richard1697honda','richard.silva@ntlworld.com','richard silva','121 birchwood hill','leeds','West Yorkshire','UNITED KINGDOM','ls178nt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 13:15:52',0,NULL,3,1,3,1,'RA184554401CN\r ','richard1697honda\rBR3D006'),(11559,764455730011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','alface2277','fabriciomuniz@hotmail.com','Fabricio A F Muniz','Av. Bartolomeu Mitre, 824 - apto 506 - Leblon','Rio de Janeiro','RJ','BRAZIL','22431-004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 13:24:38',0,NULL,3,1,2,1,'\\ ','alface2277\r24K超轻碳纤骨长柄伞  \r红色的'),(11560,764458897011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','duce501','michael@brokenroses.com','Michael Dattolico','4 Honeysuckel Hl','Flagler Beach','FL','UNITED STATES','32136-4937','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\  ','duce501\r再发一个Logitech Harmony RF extender 890 pro 1000 1100'),(11561,764474027011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','vvdkvvdk','vvdk@bernard.fr','vincent vandekerkove','27 rue emile zola','neuville en ferrain','Nord-Pas-de-Calais','FRANCE','59960','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 14:17:02',0,NULL,3,1,3,1,'RA184554450CN\r ','vvdkvvdk\rGLOT001\r兼容型3D眼镜 通用型'),(11562,723945476001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','ed-in-highdesert','davcer@msn.com','Ed Davis','9343 MAPLE AVE','HESPERIA','CA','UNITED STATES','92345','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 14:42:48',0,NULL,3,1,1,1,'\\  ','ed-in-highdesert'),(11563,764487994011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','andrewbull99','andrewbull99@yahoo.co.nz','Andrew Bull','1 Linver Rd<br>Ground Floor Flat','London','London','UNITED KINGDOM','SW6 3RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 14:55:53',0,NULL,3,1,3,1,'RA184554432CN\r ','andrewbull99\rHBPH002'),(11564,567184716003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','karenzander','kzander@att.net','Karen Zander','7339 W Franklin Ave','Saint Louis Park','MN','UNITED STATES','55426-2013','(952) 542-1878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 14:56:32',0,NULL,3,1,1,1,'\\\r ','karenzander'),(11565,622902487013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','vladislav.kravchenko','vkravchenko@gmail.com','Vladislav Kravchenko','Musy Djalilja<br>36/1/170','Moscow','Russia','RUSSIAN FEDERATION','115573','(916)473-9421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 15:23:31',0,NULL,3,1,2,1,'\\ ','vladislav.kravchenko'),(11566,622905530013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','dr.shtopor','excler@next-one.ru','GRIGORII FROLOV','pr-t Kanatchikov 1 kv. 96','Volgograd','Volgogradskaja oblast\'','RUSSIAN FEDERATION','400031','+79047530741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 15:33:57',0,NULL,3,1,2,1,'\\ ','dr.shtopor'),(11567,848121131012,220816847682,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',14.99,'eastar4uk','tonjg','info@tonyspcrepairs.com','Anthony Griffiths','47 Ferrers Avenue','Tutbury','Staffordshire','UNITED KINGDOM','DE13 9JP','01283812365','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 15:38:18',0,NULL,3,1,3,1,'RA184554415CN\r ','tonjg\rOTIN001'),(11568,764508423011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',29.99,'eastar4','poppy9780','poppy9780@gmail.com','J. Larry Willis','3044 Sewells Point Rd','Norfolk','VA','UNITED STATES','23513-3713','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 15:50:11',0,NULL,3,1,1,1,'、 ','poppy9780'),(11569,848121196012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',8.99,'eastar4uk','oli910_0','oli.91@free.fr','Mr BLEUSE OLIVIER','1 HAMEAU DE L\'EPINEUSE','GIREMOUTIERS','Île-de-France','FRANCE','77120','0164333790','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 15:50:57',0,NULL,3,1,2,1,'\\ ','oli910_0\r欧标'),(11570,572670168004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','milonmaggie','jennystutler@yahoo.com','Jennifer Stutler','2109 Cypress Point Dr','McKinney','TX','UNITED STATES','75070-7263','(972) 529-0901','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 16:10:34',0,NULL,3,1,1,1,'\\ ','milonmaggie'),(11571,848142396012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',26.38,'eastar4','phcarneiro','paulohc_21@hotmail.com','Paulo Henrique Carneiro','rua 261 B Nº 250<br>Setor Universitario','Goiânia','Goiás','BRAZIL','74610270','+55 62 81171163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 16:25:50',0,NULL,3,1,2,1,'\\  ','phcarneiro\r一共买了两个'),(11572,848141437012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',2,'',61.98,'eastar4','e-vander1','e-vander@go2.pl','Marcin Felicki','Zlocieniowa 36','Lodz','','POLAND','91-358','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 16:35:50',0,NULL,3,0,3,1,'RA184554239CN ','e-vander1'),(11573,622928380013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','tim8tom','tim4tom@gmail.com','Timothy Fenech','25, Emm. Attard Str.,','St. Venera','','MALTA','SVR 1332','79044004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 16:46:46',0,NULL,3,1,3,1,'RA184554185CN\r ','tim8tom\rMOLO009'),(11574,572685022004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.09,'cnfaner','oscarchavesalvarado','oscar.alaorden@gmail.com','Oscar Chaves','7979 NW 21st St<br>Oscar Chaves Alvarado # SJO 45304','DORAL','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 17:00:54',0,NULL,3,1,1,1,'、 ','oscarchavesalvarado'),(11575,848165843012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','mfc100','johnbell6@sky.com','John Bell','28 Greensted Road','Loughton','Essex','UNITED KINGDOM','Ig103dl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 17:11:20',0,NULL,3,1,3,1,'RA184554273CN\r ','mfc100\r英标\rHSSE004'),(11576,764547400011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',10.39,'eastar4uk','miroslav_novotny','miroslav.novotny@post.cz','Miroslav Novotny','Miroslav Novotny<br>Dvorni 9','Luzice u Hodonina','','CZECH REPUBLIC','69618','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 17:18:36',0,NULL,3,1,2,1,'\\  ','miroslav_novotny'),(11577,567230967003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',14.99,'cnfaner','ekes8695','kuvita09@gmail.com','Emil Kestel','8230 Elmwood Ave. #306','Skokie','IL','UNITED STATES','60077','(847) 982-1081','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-14 17:37:07',0,NULL,3,1,1,1,'、 ','ekes8695'),(11578,622946907013,230649288384,'New Replaceable Shell 4 logitech Anywhere MX Mouse M905',1,'SHLO005',16.99,'eastar4','yhac_pcd130mm','mk2trance@m4.dion.ne.jp','Masayoshi Kanada','Nakagawa-ku Housei-chou 1-3-513','Nagoya-shi','Aichi','JAPAN','454-0803','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 17:40:38',0,NULL,3,1,2,1,'、 ','yhac_pcd130mm'),(11579,848198423012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','renatowci10','renatowci@hotmail.com','Renato ---','Rua Bergamota n388 apt132','Sao Paulo','Sao Paulo','BRAZIL','05468000','55 87654877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 18:09:19',0,NULL,3,1,3,1,'RA184554392CN\r ','renatowci10\rGLOT001\r兼容型3D眼镜 通用型'),(11580,764580079011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','lepamplat.2101','solovei23012009@yandex.ru','Tatjana Vogel','Am Vorwerk 6','Leipzig','','GERMANY','04329','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 18:20:41',0,NULL,3,1,2,1,'\\  ','lepamplat.2101'),(11581,572713488004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23.26,'cnfaner','pansof_72','pansof@narod.ru','Arthur Pustovoyt','Michurinskiy prospect, 25-2-118','Moscow','Moscow','RUSSIAN FEDERATION','119607','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 18:23:01',0,NULL,3,1,3,1,'RA184554358CN\r ','pansof_72\rBALO007'),(11582,764579527011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',37.99,'eastar4','maor_a18','maor0247@gmail.com','Maor Avraham','Hatothanim 8/4','Kiryat-Gat','','ISRAEL','82201','0546574449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 18:27:34',0,NULL,3,1,3,1,'RA184554313CN\r ','maor_a18\rHSNO015'),(11583,848212199012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','filthy_razor','hav0k@hav0k.net','Charles Range','100 S Glenview Dr<br>Apt A','Carbondale','IL','UNITED STATES','62901-2238','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 18:32:53',0,NULL,3,1,1,1,'\\ ','filthy_razor'),(11584,764592027011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',92.99,'eastar4uk','duluxmont21','duluxmont@msn.com','MYRIAM DUMONT','3 ROUTE DE DIJON','NUITS SAINT GEORGES','Bourgogne','FRANCE','21700','0380269891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 18:43:10',0,NULL,3,1,3,1,'RA184566152CN\r ','duluxmont21\rGLOT005*3'),(11585,764610018011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','bhushan.bharambe','bhushan.bharambe@gmail.com','Bhushan Bharambe','37, Canterbury Road','Harrow','Middlesex','UNITED KINGDOM','HA1 4PD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 19:14:18',0,NULL,3,1,3,1,'RA184554211CN\r ','bhushan.bharambe\rGLOT001*2\r兼容型3D眼镜 通用型'),(11586,567274558003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','vas_sam','samtchev@telus.net','Vassili Samtchenko','67 Douglasbank Dr. S.E.','Calgary','AB','CANADA','T2Z 2B6','(403) 228-4891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 19:40:18',0,NULL,3,1,3,1,'RA184554446CN\r ','vas_sam\rHSJA001'),(11587,848264291012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','gogs-bruce','gogsbruce@yahoo.co.uk','Gordon Bruce','Western VW<br>454 Gorgie Road','Edinburgh','Midlothian','UNITED KINGDOM','EH11 4RN','01313461661','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 19:56:29',0,NULL,3,1,3,1,'RA184554171CN\r ','gogs-bruce\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11588,623002731013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','kostasalevizos','kostas.alevizos@gmail.com','Harry Alevizos','Perikleous 16','Marousi','Attica','GREECE','15122','00302106142247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 20:00:42',0,NULL,3,1,3,1,'RA184554548CN\r ','kostasalevizos\rWLIN014'),(11589,848286166012,220815929156,'New in box Iqua bluetooth Smart Badge BHS-608 BHS 608',1,'HSIQ001',29.99,'eastar4uk','satsuma3841','john.g.mclaren@bt.com','John Mclaren','8 Kilchurn Court, Craigievar Wynd','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH128GN','01313399033','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 20:36:08',0,NULL,3,1,3,1,'RA184554429CN\r ','satsuma3841\rHSIQ001\r英标'),(11590,848299347012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',99.99,'eastar4','tiengotop','lucianotiengo@hotmail.com','Luciano Tiengo','Rua Amazonas, 88 - Centro','Águas de Lindóia','São Paulo','BRAZIL','13940-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 21:06:26',0,NULL,3,1,3,1,'RA184554208CN\r ','tiengotop\rOTKE001'),(11591,848303687012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','brendanf82','brenfarq@gmail.com','Brendan Farquharson','7 Claremont Villas','Glenageary','Dublin','IRELAND','0','0863055055','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 21:08:19',0,NULL,3,1,3,1,'RA184554485CN\r ','brendanf82\rWLAP008'),(11592,764674629011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',125.99,'eastar4','ccrooks106','crookscw106@yahoo.com','clayton crooks','8115 Cantura Mls<br>null','Converse','TX','UNITED STATES','78109-3260','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 21:18:04',0,NULL,3,1,1,1,'\\  ','ccrooks106'),(11593,764678568011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',71.98,'eastar4uk','greggie18','ghtiling@live.com.au','Greg Hardy','44 The Court','Leopold','Victoria','AUSTRALIA','3224','0352502651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 21:27:47',0,NULL,3,1,3,1,'RA184554199CN\r ','greggie18\rOTSO004'),(11594,572778633004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','toverboom','theo.overboom@magictree.nl','Theo Overboom','De Breeacker 92','OOSTERHOUT','','NETHERLANDS','6678DJ','+31647215688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 21:30:45',0,NULL,3,1,3,1,'RA184554494CN\r ','toverboom\rHSJA002\r欧标'),(11595,764531154011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','rakkikoira71','jaakko.laeslahti@pp1.inet.fi','Jaakko Laeslahti','Tyrnitie 8','Lapijoki','Eurajoki','FINLAND','27150','(050)3592252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 21:49:01',0,NULL,3,1,3,1,'RA184554225CN\r ','rakkikoira71\rRCLO008'),(11596,764705145011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','mkmisp','kurten@matrix.com.br','Marcos K Michels','Senador Nereu Ramos street, 1445 room 05','Braco do Norte','Santa Catarina','BRAZIL','88750-000','(48) 9987-0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 22:44:09',0,NULL,3,1,2,1,'、 ','mkmisp'),(11597,764719732011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mustangpeter69','montesanti2@hotmail.com','Peter Montesanti','8 Nissitissit Ln','Pepperell','MA','UNITED STATES','01463-1417','(978) 265-4206','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 23:40:39',0,NULL,3,1,1,1,'\\  ','mustangpeter69'),(11598,572811951004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','31199luc','lucandcol@gmail.com','Luc Maltais','6596 Des Chouettes Lane','Ottawa','ON','CANADA','K1C 6N3','(613) 830-8941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 00:21:35',0,NULL,3,1,3,1,'RA184554503CN\r ','31199luc\rHBPH003'),(11599,848376851012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.9,'eastar4','jyl_24','jyl_5@hotmail.com','Jose Manuel Perez Diaz','C/Padre Espla nº10  4ºC','Alicante','Comunidad Valenciana','SPAIN','03013','639645304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 00:48:13',0,NULL,3,1,2,1,'、 ','jyl_24\racer 4pin1.25 8cm '),(11600,764738999011,320475111586,'2.0 New ASUS Bluetooth Module +cable for V1S E99 F8 N80',1,'BTHU2002',9.9,'eastar4','tobsta','mail@tstaudte.de','Tobias Staudte','969 Ellsworth Dr','Grayslake','IL','UNITED STATES','60030-3365','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 00:54:59',0,NULL,3,1,1,1,'\\ ','tobsta\r华硕10pin 0.8 10cm '),(11601,623083130013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',34.99,'eastar4','hansley13','hansley.wang@gmail.com','Hai Han Wang','613-3260 Barrington Street','Halifax','NS','CANADA','B3K 2X7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 01:18:32',0,NULL,3,1,3,1,'RA184554287CN\r ','hansley13\rWLIN002'),(11602,848389046012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','zerotimesinfinity','sudoman@ninthfloor.org','Andrew Engelbrecht','37 Bowdoin St<br>Unit 30','Boston','MA','UNITED STATES','02114-4201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 01:37:51',0,NULL,3,1,1,1,'\\  ','zerotimesinfinity'),(11603,623087433013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',50.94,'eastar4','ipv4v6','ngkuanheng@hotmail.com','Ng kuan heng','128 Rivervale Street<br>#11-818','Singapore','','SINGAPORE','540128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 01:40:55',0,NULL,3,1,3,1,'RA184554582CN\r ','ipv4v6\rCASS003\r新地址\rNg kuan heng\rBlock 128 Rivervale Street, #11-818. Singapore 540128\rSINGAPORE\r65-9455 6905\r\r\r'),(11604,848392884012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','j_amend','j.amend@gmail.com','Jonathan Amend','4220 Rue Brebeuf Apt. 15','Montreal','QC','CANADA','H2J3K7','(514) 708-8433','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'j_amend'),(11605,764756803011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','blesajc','blesajc2004@gmail.com','JUAN BLESA','169 ROCKY RIDGE CLOSE NW','CALGARY','AB','CANADA','T3G 4X2','(403) 454-9767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 02:01:13',0,NULL,3,1,2,1,'\\  ','blesajc'),(11606,572846918004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','ozziedvl','david.c.fenech@gmail.com','Dave Fenech','38 Roselyn Crescent','Boronia','Victoria','AUSTRALIA','3155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 03:38:54',0,NULL,3,1,3,1,'RA184554619CN\r ','ozziedvl\rHSJA002\r澳标'),(11607,724216469001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','dxf','dodgeneon619@yahoo.com','DAN WAGATSUMA','344 W Puainako St','HILO','HI','UNITED STATES','96720-2745','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 03:49:36',0,NULL,3,1,1,1,'\\  ','dxf'),(11608,623115354013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','dnlwild86','dnlwild@ig.com.br','Daniel Dobrioglo','RUA REGINO ARAGAO, 155 - APT 72<br>MOINHO VELHO','SAO PAULO','São Paulo','BRAZIL','04285-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 04:00:20',0,NULL,3,1,2,1,'\\ ','dnlwild86'),(11609,567380837003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','fcukinky69','pauly@fcukinky.com','Paul Bahry','1323/100 Belmore Street','Meadowbank','New South Wales','AUSTRALIA','2114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 04:03:28',0,NULL,3,1,3,1,'RA184554622CN ','fcukinky69\rUDAP001'),(11610,623117674013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','johnkel2000','johnkel2000@comcast.net','Kelvin D Johnson','1900 Canal St<br>Apt 2B','Blue Island','IL','UNITED STATES','60406-3036','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 04:18:36',0,NULL,3,1,1,1,'\\  ','johnkel2000'),(11611,764791826011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','dumbasses21','dumbasses21@hotmail.com','bradyn cook','8 munday court','skye','Victoria','AUSTRALIA','3977','0397826524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 04:32:32',0,NULL,3,1,2,1,'\\ ','dumbasses21'),(11630,623178606013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','crisbeto','cristiano_oliv@hotmail.com','CRISTIANO OLIVEIRA','RUA DA ALDEIA, 790','CORTEGACA','','PORTUGAL','3885-233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 10:52:56',0,NULL,3,1,2,1,'\\ ','crisbeto'),(11612,848443345012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',2,'WLIN012',57.98,'eastar4','crowsnest-1','targ_net@hotmail.com','Paul K Bingham','2848 Vista Acedera','Carlsbad','CA','UNITED STATES','92009-6900','(760) 473-9473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 05:03:48',0,NULL,3,1,1,1,'\\ ','crowsnest-1'),(11613,764827428011,320394892477,'Acer Aspire 5235 5335 5535 Bluetooth Module 2.0 +cable',1,'BTAC2005',9.9,'eastar4','mdragon_es','mdragon@teleline.es','Boris Pérez Montes','Joan Mascaro i Fornes  80 2º Izquierda','Palma de Mallorca','Islas Baleares','SPAIN','07010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 07:40:14',0,NULL,3,1,2,1,'\\ ','mdragon_es\racer 4pin1.25 8cm'),(11614,764832636011,320737032375,'4 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*4',278,'eastar4','sgngirliegirl','sgndolphin@hotmail.com','Sandra Navarrete','2561 35th St<br>Unit 1','Astoria','NY','UNITED STATES','11103-4861','(646) 464-4127','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 08:04:51',0,NULL,3,1,6,1,'EE495359485CN ','sgngirliegirl'),(11615,0,110743203455,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',18.19,'buysia','sgngirliegirl','sgndolphin@hotmail.com','Sandra Navarrete','2561 35th St<br>Unit 1','Astoria','NY','UNITED STATES','11103-4861','(646) 464-4127','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 08:19:08',0,NULL,3,1,17,0,NULL,'sgngirliegirl'),(11616,0,110743203752,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.5,'buysia','sgngirliegirl','sgndolphin@hotmail.com','Sandra Navarrete','2561 35th St<br>Unit 1','Astoria','NY','UNITED STATES','11103-4861','(646) 464-4127','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 08:20:18',0,NULL,3,1,1,1,NULL,'sgngirliegirl\r再发一个Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW'),(11617,845311519012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','davylynne','lynnewj@gmail.com','Lynne Webster-Jaggard','16 High Street<br>Brampton','Huntingdon','Cambridgeshire','UNITED KINGDOM','PE28 4TU','01480455249','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 08:22:04',0,NULL,3,1,3,1,'RA184554636CN\r ','davylynne\rOTHP004'),(11618,724266847001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','gidrub','gid_rub@netvision.net.il','Gideon Rubin','59 Shunit<br>Beit Herut','Kfar Vitkin','Israel','ISRAEL','40291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 08:28:10',0,NULL,3,1,3,1,'RA184554640CN','gidrub\rBR3D005'),(11619,764834664011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','tmopen','tomerp1@013.net','Tomer Peretz','Ha\'hartzit 35/3','Modi\'in','ISRAEL','ISRAEL','71708','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 08:30:59',0,NULL,3,1,2,1,'\\ ','tmopen'),(11620,623155817013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','0417micka','mick.bell@orrcon.com.au','Michael Bell','49 Baroda street Coopersplains','Brisbane','Queensland','AUSTRALIA','4108','0417793804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 08:43:16',0,NULL,3,0,3,1,'RA184566957CN ','0417micka\r客户补了三十美金差价\r换成\rOTSO004\r2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250\r\r'),(11621,764841979011,320394892496,'Acer Aspire 5735 5735Z Bluetooth Module 2.0 EDR +cable',1,'BTAC2005',9.9,'eastar4','motogalo2010','motogalo@hotmail.com','Henrique M. C. Rodrigues','lugar do barreiro','paçô','arcos de valdevez','PORTUGAL','4970-236','+351939539595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 08:51:13',0,NULL,3,1,2,1,'\\ ','motogalo2010\racer 4pin1.25 8cm'),(11622,848495109012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','cellinall','investinlife@sbcglobal.net','Ray LaVigne','8559 S Indiana Ave','Chicago','IL','UNITED STATES','60619-5622','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 09:02:00',0,NULL,3,1,1,1,'\\ ','cellinall'),(11623,572891663004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','liovch','lev.zelensky@gmail.com','Lev Zelenskiy','48/21 Cossington Smith Crescent','Canberra','Australian Capital Territory','AUSTRALIA','2602','0416525197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 09:17:03',0,NULL,3,1,3,1,'RA184554605CN ','liovch\rWLAP008'),(11624,623154533013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.9,'eastar4','g.charlier','gcharlier@tpg.com.au','Glen Charlier','2/101 Milson Rd','Cremorne Point','New South Wales','AUSTRALIA','2090','0424457494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 09:20:38',0,NULL,3,1,2,1,'\\ ','g.charlier'),(11625,572893279004,140584764416,'NEW Ralink RT2870F Wi-Fi USB Adapter replace WIS09ABGN',1,'OTRA001',47.99,'cnfaner','claudiobari','spaccami@yahoo.it','Claudio Guglielmo','circonvallazione nomentana 100<br>CASERMA AMIONE','roma','RM','ITALY','00162','3408116523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 09:32:22',0,NULL,5,1,3,1,' ','claudiobari\rOTRA001\r'),(11626,848507188012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'eastar4','matejgemza','satanko@email.cz','Matej Gemza','Zahradna 9','Spisska Bela','','SLOVAK REPUBLIC','05901','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 09:47:26',0,NULL,3,1,2,1,'\\  ','matejgemza'),(11627,8881316081171536,111,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',0,'eastar4','jmberdon2','jmberdon@gmail.com','José María Berdonces Ortega','C/Fueros de Arnedo, 7, 3ºD','Arnedo','La Rioja','SPAIN','26580','635888962',NULL,NULL,NULL,'2011-09-15 10:06:11',0,NULL,3,1,2,1,'\\  ','补发的红边优联'),(11628,8881316081322456,111,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',0,'eastar4','danny6798','danny514_1@hotmail.com','danny migneault','6659 Sherbrooke.Ouest (apt.21)','montreal','QC','CANADA','H4B1N8','',NULL,NULL,NULL,'2011-09-15 10:08:42',0,NULL,3,0,2,1,'\\ ','补发的\r粉红色的\r已入库 '),(11629,764864596011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','royvdk','poweroy@gmail.com','Roy van de Korput','Foxtrotstraat 12','Venray','','NETHERLANDS','5802 NK','0650743346','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 10:20:46',0,NULL,3,1,2,1,'\\ ','royvdk'),(11631,848358259012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','mreagan2601','mark.reagan@comcast.net','Mark Reagan','33 Simon Hill Rd','Norwell','MA','UNITED STATES','02061','(781) 659-2077','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 11:00:52',0,NULL,3,1,1,1,'\\ ','mreagan2601'),(11632,764878431011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',59.99,'eastar4','hyilgor','hyilgor@gmail.com','hasan yilgor','eski londra asfalti  no:6<br>sefakoy','istanbul','','TURKEY','34295','905422852637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 11:13:17',0,NULL,3,1,3,1,'RA184580049CN ','hyilgor\rGLSG001'),(11633,623184129013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','itssick','its.sick@gmail.com','Yitzhak Abudi','10/76 Harimon st.','Givat Shmuel','','ISRAEL','54403','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 11:20:33',0,NULL,3,1,2,1,'\\ ','itssick'),(11634,764887269011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','vitaz007','vit.spalek@gmail.com','Vit Spalek','Edhouse s.r.o<br>Vavreckova 5262','Zlin','','CZECH REPUBLIC','76001','420737814908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 11:43:55',0,NULL,3,1,2,1,'\\ ','vitaz007'),(11635,764892097011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','stephen77b','causdog@yahoo.com','Robert Causey','1900 Dunbar Rd','Cayce','SC','UNITED STATES','29033','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 11:59:39',0,NULL,3,1,1,1,'\\ ','stephen77b'),(11636,848546401012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','zik-kislota','zik2004@hotmail.com','Dmitri Ponomarjov','Ehitajate-tee<br>45-68','Tallinn','','ESTONIA','12613','+37258382911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 12:02:22',0,NULL,3,0,3,1,'RA184580021CN ','zik-kislota'),(11637,764895214011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',35.99,'eastar4uk','308rob308','patricia.stevens4@bigpond.com','Rob Steven','5 Thunder Way','Bunbury','Western Australia','AUSTRALIA','6230','0897955221','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 12:10:47',0,NULL,3,1,3,1,'RA184568989CN ','308rob308\rOTSO004'),(11638,848558180012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','jaxk111','kkatrib@optusnet.com.au','Khalid Katrib','25 Kemp St','Mortdale','New South Wales','AUSTRALIA','2223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 12:41:56',0,NULL,3,1,3,1,'RA184568975CN ','jaxk111\rOTSO004*2\r新地址\rKhal Katrib\rC/- Capital Insight\rLevel 6,\r77 Berry Street, \rNorth Sydney, NSW, 2060, Australia\r\r'),(11639,567381143003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','ber1074','ber631@yahoo.com','moses berger','107 Skillman St<br># 4-R','BROOKLYN','NY','UNITED STATES','11205-2875','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-15 12:46:59',0,NULL,3,1,1,1,'\\ ','ber1074'),(11640,764912415011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001*2',211.98,'eastar4','sakurambo11','maarjoriiie@hotmail.fr','Christophe Castro','avenue de Capestang<br>7 clos Saint Thomas','Ouveillan','Languedoc-Roussillon','FRANCE','11590','0612138376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:13:25',0,NULL,3,1,6,1,'EE495359463CN ','sakurambo11'),(11641,623212901013,230653158502,'New Germany Grohe Crystal Anion Spa Shower Head +hose',1,'OTGR004+OTGR002',39.99,'eastar4','min_isis','md_tr@msn.com','cuneyt ozcan','Turan Cetin TUP bebek merkezi 100. yil mh. 85017 sk No: 9/A','Adana','Cukurova','TURKEY','01360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:29:59',0,NULL,3,1,3,1,'RA184580145CN','min_isis\rOTGR004+OTGR002'),(11642,623164063013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','zappeastusa3','zappusa3@gmail.com','Andrei Third','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 13:44:38',0,NULL,3,1,1,1,'、 ','zappeastusa3\r兼容型3D眼镜 通用型\r在包装上写上230641567591'),(11643,848119055012,220448702976,'Acer Aspire 6935 6935G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',9.9,'eastar4','flegel63','ffmoelbis@t-online.de','Falk Flegel','Str.des Friedens 45','MÖLBIS','','GERMANY','04579','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:48:22',0,NULL,3,1,2,1,'\\ ','flegel63\racer 8pin0.8 16cm '),(11644,848583573012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','olenaphoto','olenamykhaylova@yahoo.com','Olena Mykhaylova','Dom 148, Kvartira 119<br>Kirova street','Sumy','SUMY REGION','UKRAINE','40021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:51:34',0,NULL,3,1,2,1,'\\  ','olenaphoto'),(11645,848585664012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','poonambakshi842010','poonambakshi84@gmail.com','poonam bakshi','# 3/72<br>gove street','springvale','Victoria','AUSTRALIA','3171','0430679525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:57:34',0,NULL,3,1,2,1,'\\ ','poonambakshi842010\r澳标'),(11646,623105817013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',19.99,'eastar4','shaifbhuiyan79','shaif79@gmail.com','Mohammad Bhuiyan','12 Heston Avenue<br>Manchester','MANCHESTER','Greater Manchester','UNITED KINGDOM','M13 0UW','01614783909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 13:59:12',0,NULL,3,0,2,1,'\\ ','shaifbhuiyan79\r已入库'),(11647,623222316013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','kevjustice','kevjustice@yahoo.com','Kevin Justice','8307 Arden Dr','Salisbury','MD','UNITED STATES','21804-2233','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 14:22:07',0,NULL,3,1,1,1,'\\ ','kevjustice'),(11648,760943495011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','ogdigital3','og3hree@gmail.com','Stephen O\'Grady','1523 West 3rd  - 3rd Floor','vancouver','BC','CANADA','V6J 1H2','(778) 668-7501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 14:23:24',0,NULL,3,1,2,1,'\\ ','ogdigital3'),(11649,764942817011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','een1bhs','bensurtees@gmail.com','Ben Surtees','308 1re Avenue<br>Lasalle','Montreal','QC','CANADA','H8P2E8','(001) 514-2947 ext.: 273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 14:39:31',0,NULL,3,1,3,1,'RA184554534CN ','een1bhs\rUDAP001'),(11650,623230612013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.5,'eastar4','tamo3103','a-s-hakim@gmx.de','Ahmad Shah Hakim','Karl-Marx-Ring 24','München','','GERMANY','81735','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 14:42:18',0,NULL,3,1,2,1,'\\ ','tamo3103'),(11651,764943846011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','barry8085','barry-walsh@ntlworld.com','Barry Walsh','12 Little Aston Road','Romford','Essex','UNITED KINGDOM','RM3 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 14:42:58',0,NULL,3,1,3,1,'RA184582212CN\r ','barry8085\rOTHP006\r微软的'),(11652,764959740011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','johnson_elaine','elaine@garymjohnson.com','Elaine Johnson','931 140th Ln NW','Andover','MN','UNITED STATES','55304-4126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 15:33:31',0,NULL,3,1,1,1,'\\ ','johnson_elaine'),(11653,567416141003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',2,'BAZA001',115.8,'cnfaner','jasa-order','jasa_order@yahoo.com','Kantor IOM (Eko Andri)','Jl. Gatot Subroto KM5<br>Villa Taman Pinang Blok D no. 2','Tanjungpinang','Kepulauan Riau','INDONESIA','29123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 15:39:30',0,NULL,3,1,3,1,'RA184580035CN ','jasa-order\rBAZA001'),(11654,623245863013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','marikat1','marikmills@gmail.com','Marik A. Mills','325 9th st','atlantic beach','FL','UNITED STATES','32233-5437','(310) 402-3802','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 15:39:56',0,NULL,3,1,1,1,'\\  ','marikat1\r黑色的'),(11655,847624562012,220815928236,'GENUINE Plantronics Voyager 851/855 Bluetooth headset',1,'HSPL017',21.99,'eastar4uk','zhementor','zhementor2010@gmail.com','Evgenia Olykainen','Maalinauhantie 8 c 45','Vantaa','','FINLAND','01280','+358452592980','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 16:41:38',0,NULL,3,1,3,1,'RA184580185CN ','zhementor\rHSPL017\r欧标'),(11656,765010474011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','garrickfonti','gwfonti@gmail.com','garrick fontilus','Roodborstlaan 8','BUSSUM','','NETHERLANDS','1403EL','0356917926','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 17:31:18',0,NULL,3,1,2,1,'\\  ','garrickfonti\r红边优联'),(11657,765010299011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','bayles152','rickspokeraccount@yahoo.com.au','Richard Bayley','4 kambara Drive','Mulgrave','Victoria','AUSTRALIA','3170','0395464405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 17:31:37',0,NULL,3,1,2,1,'\\ ','bayles152'),(11658,848676524012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','digoq3','rodrigo.rcm@gmail.com','rodrigo moraes','rua8, 680 apt601 ed kennedy','goiania','go','BRAZIL','74013-030','62-32133389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 17:34:33',0,NULL,3,1,2,1,'\\  ','digoq3'),(11659,623306625013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','schelleau','schelle.au@gmail.com','Michelle Whitehead','130 Eagle Creek Road','Werombi','New South Wales','AUSTRALIA','2570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 18:54:35',0,NULL,3,1,2,1,'\\ ','schelleau'),(11660,765062805011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','shj503','shj503@hotmail.com','Jun Shin','7 Monroe Dr','Pelham','AL','UNITED STATES','35124','(205) 317-2218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 19:10:57',0,NULL,3,1,1,1,'\\ ','shj503'),(11661,623324440013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','darthdilbert','darthdilbert@hotmail.com','Robert Brink','2251 Watt Ave<br>Apt 141','Sacramento','CA','UNITED STATES','95825-0515','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 19:33:15',0,NULL,3,1,1,1,'\\ ','darthdilbert'),(11662,845638289012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','nkj2010','nkjhall@ymail.com','NIRAJ KUMAR','111 CLARK RD<br>COMPTON','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 9PA','07940091199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 20:17:01',0,NULL,3,1,3,1,'RA184580052CN ','nkj2010\r英标\rHSJA010'),(11663,623341410013,230518594351,'UNLOCKED HS2300 SIERRA MC8775 3G for Dell/lenovo/Ace​r',1,'WWSI001',30.99,'eastar4','sylvanas3','azraelle.takagi@gmail.com','Philip Macharadze','4th Sovietskaya st., 15-11','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','191036','+7(812)717-44-14','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 20:17:58',0,NULL,3,1,3,1,'RA184554525CN ','sylvanas3\rWWSI001'),(11664,847087760012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','michelle_33_123','belle_33@hotmail.co.uk','michelle wakeman','24 Deerhurst Place','Quedgeley','Gloucestershire','UNITED KINGDOM','GL2 4WN','01452728810','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 20:40:13',0,NULL,3,1,3,1,'RA184554565CN ','michelle_33_123\rHSPL011\r英标'),(11665,848779939012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','jeembo1980','jeembobay@gmail.com','Istvan Justin','Ady Endre utca 37.','Gárdony','Fejér','HUNGARY','2483','36204628979','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 20:44:09',0,NULL,3,1,3,1,'RA184582226CN ','jeembo1980\rGLOT005'),(11666,848789205012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','knysh2000','janddknysh@shaw.ca','John Knysh','348 Bronx Avenue','Winnipeg','MB','CANADA','r2k0z1','(204) 669-1389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 20:57:10',0,NULL,3,0,2,1,'\\  ','knysh2000\r已入库\r紫色的'),(11667,765137988011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',127.98,'eastar4','zoezuniga','karina.kras86@yahoo.com','gustavo zuniga','2530 N Talman Ave','chicago','IL','UNITED STATES','60647-1812','(773) 627-2985','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-15 21:56:12',0,NULL,3,1,1,1,'\\ ','zoezuniga'),(11668,765145513011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','m33canada','hzarrabi@compuzar.com','Hossein Zarrabi Tabrizi','1507 - 3070 Guildford Way<br>Buzzer #95','Coquitlam','BC','CANADA','V3B7R8','(604) 984-9328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 22:17:30',0,NULL,3,1,2,1,'\\ ','m33canada'),(11669,567627227003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','moti9878','moticohanim@gmail.com','Moti Cohanim','8 Roter','Holon','Tel Aviv','ISRAEL','58316','052-6007260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:00:22',0,NULL,3,1,3,1,'RA184554653CN ','moti9878\rHSMO018'),(11670,848838653012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',35,'eastar4','shammoria200912966','shammoria@shammoria.com','Brett Parker','61 Coolart Road','Balnarring','Victoria','AUSTRALIA','3926','0428636762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:08:52',0,NULL,3,1,3,1,'RA184554596CN ','shammoria200912966\rOTIN002'),(11671,848837619012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','beeruu','beer_uu@yahoo.com','ida bagus aditya','br. candra asri blok g no 85, batubulan, sukawati','gianyar','bali','INDONESIA','80582','628123610938','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:11:38',0,NULL,3,0,3,1,'RA184580097CN ','beeruu'),(11672,623389594013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','jacques8001','jiel2000@hotmail.com','Jacques Leclerc','7965 Naples','Brossard','QC','CANADA','J4Y 1V8','(450) 656-0751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:21:48',0,NULL,3,1,2,1,'\\ ','jacques8001'),(11673,848844270012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','griva1973','griva73@nadlanu.com','Igor Stojanovic','Vojvode Stepe 152','Belgrade','Serbia','SERBIA','11040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:30:06',0,NULL,3,0,3,1,'RA184580018CN ','griva1973'),(11674,567632998003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','kieltyka83','januszkieltyka@ymail.com','Janusz Kieltyka','8647 W Foster Ave<br>Apt 1B','Chicago','IL','UNITED STATES','60656-3088','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-15 23:33:22',0,NULL,3,1,1,1,'\\ ','kieltyka83'),(11675,848834743012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',11.99,'eastar4uk','258high','nkleinmd@yahoo.com','Nicholas Klein','258 High Ave','Nyack','NY','UNITED STATES','10960-2407','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 23:35:01',0,NULL,3,1,1,1,'\\ ','258high'),(11676,765179209011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','er65nsunny','er65nsunny@aol.com','Edward Ratkiewicz','1500 4th St S','Great Falls','MT','UNITED STATES','59405-4245','(406) 454-2873','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 00:21:35',0,NULL,3,1,1,1,'\\  ','er65nsunny\racer 8pin1.00 8cm '),(11677,0,120776684433,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',15,'buysia','franciscohugo','hugozuniga1962@aol.com','Francisco Zuniga','7962 Sioux Ln','Lakeland','FL','UNITED STATES','33810-2180','(863) 859-2414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 00:44:08',0,NULL,3,1,1,1,'\\ ','franciscohugo\r新地址\rFrancisco Zuniga\r7477 Hunters Greene Circle,Lakeland,Fl.33810\rUNITED STATES\r(863) 859-2414'),(11678,847888098012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','spiceislandcaraudio','grenada-spiceisland@rogers.com','Brian Buckmire','118 Froster crest.','Brampton','ON','CANADA','L6V3M8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 00:47:23',0,NULL,3,1,2,1,'\\ ','spiceislandcaraudio'),(11679,724593370001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','alexfuriagfc','tekko1309@yahoo.com.br','alexandre ricardo seneme','sebastiao alves n 465 bairro jd eulina','campinas','sao paulo','BRAZIL','13063350','1932422181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 01:13:33',0,NULL,3,1,3,1,'RA184554579CN ','alexfuriagfc\rBR3D008'),(11680,848878622012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','alvds','axel@vandersypt.fr','Axel Van Der Sypt, Chez M. Buso','Chemin des Tamaris<br>Résidence Les Lucioles, Batiment A2','Aix-en-Provence','Provence-Alpes-Côte d\'Azur','FRANCE','13100','0625962893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 01:27:49',0,NULL,3,1,2,1,'\\ ','alvds'),(11681,765197935011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','farley9522','mfarley0005@yahoo.com','Mark Farley','210 4th St<br>FOURTH STREET MOTOR CO.','Farmville','VA','UNITED STATES','23901-1533','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 01:44:33',0,NULL,3,1,1,1,'\\ ','farley9522'),(11682,765206892011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',44.89,'eastar4','alexminmadrid','alexmin@gmail.com','Alessandro Miniggio','C/Los Hueros, 1, 6C','Alcala de Henares','Madrid','SPAIN','28806','912854167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 02:10:14',0,NULL,3,1,3,1,'RA184580106CN ','alexminmadrid\rGLOT004\r兼容型3D眼镜  samsung 专用'),(11683,848892286012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','ethicalhacker404','deadly_frogg@live.com','Jeremy Westbrook','3345 Resource Pkwy<br>Apt F2','Dekalb','IL','UNITED STATES','60115-5318','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 02:10:45',0,NULL,3,1,1,1,'\\ ','ethicalhacker404\racer 6pin1.25 23cm'),(11684,848894441012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','wibevie','wibevie@hotmail.com','Wilbur Forry,','10 Carson Ln','Red Lion','PA','UNITED STATES','17356-8687','(717) 757-7035','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 02:19:48',0,NULL,3,1,1,1,'\\ ','wibevie'),(11685,848894540012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','benjak99','benlauzer@gmail.com','Ben Lauzer','81 Henry street','Trenton','ON','CANADA','k8v3t6','(613) 961-9894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 02:22:20',0,NULL,3,1,2,1,'\\ ','benjak99'),(11686,623433247013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.99,'eastar4','kenbotwinick','kenbotwinick@mac.com','Kenneth M Botwinick','2 Willow Ter<br>Apt 1','Newton Center','MA','UNITED STATES','02459-1833','(617) 584-2755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 02:43:29',0,NULL,3,1,1,1,'\\ ','kenbotwinick'),(11687,765217485011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','snaponcom','lotforsale@bellsouth.net','Dan Garland','18406 Success Rd','Brooksville','FL','UNITED STATES','34604','(352) 799-0910','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 02:48:17',0,NULL,3,1,1,1,'\\ ','snaponcom'),(11688,567667425003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','cardiac22','cardiac220901@att.net','ROGER BYASSEE','2348 Gerrard Ave','SPEEDWAY','IN','UNITED STATES','46224','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 02:48:38',0,NULL,3,1,1,1,'\\ ','cardiac22'),(11689,765218877011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','bugszieb','bugszieb@ispnet.ca','Michael J Bevington','12 Kyle Crt   RR#1','Lynden','ON','CANADA','L0R1T0','(519) 647-3582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 02:50:42',0,NULL,3,1,3,1,'RA184580110CN ','bugszieb\rRCLO007+POLO001+RCLO008*4'),(11690,848903564012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','talpigsikoly','talpigsikoly@yahoo.com','Jozsef Papp','17461 Elkwood St','Northridge','CA','UNITED STATES','91325-4432','(323) 839-0627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 02:50:58',0,NULL,3,0,1,1,'\\  ','talpigsikoly'),(11691,848909862012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','natheria32','beqcrazy@gmail.com','Brian Hawthorne','6489 County Road 30','Bloomfield','NY','UNITED STATES','14469-9328','(585) 351-9104','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 03:16:49',0,NULL,3,1,1,1,'\\  ','natheria32'),(11692,848179317012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','cesarin1983','cesarin-1983@hotmail.com','cesar mendoza','132 summit ave','cliffside park','NJ','UNITED STATES','07010-1026','(201) 496-7991','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 03:24:20',0,NULL,5,0,18,0,NULL,'cesarin1983\r客户要撤单需要退款\r已退款'),(11693,848912906012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',30.99,'eastar4','wynnrocky','topped@cox.net','Winfield Young, MD','1212 Lake James Dr<br>Ste C','Virginia Beach','VA','UNITED STATES','23464-6779','(757) 523-0155','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 03:31:47',0,NULL,3,0,1,1,'\\  ','wynnrocky'),(11694,765239682011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','cinderella0105','lmcdonald2001@hotmail.com','Leanne I McDonald','857 County Route 402','Westerlo','NY','UNITED STATES','12193-3200','(518) 229-4256','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 04:36:01',0,NULL,3,1,1,1,'\\  ','cinderella0105'),(11695,848930242012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'',30.99,'eastar4','robynblom1984','robynblom@hotmail.com','Robyn Blom','846 Maitland Ave.','Ottawa','ON','CANADA','K2A 2S3','(613) 699-5867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 04:54:46',0,NULL,3,0,3,1,'RA184580137CN ','robynblom1984'),(11696,765245259011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','kutiepi87','irinazevelyov@gmail.com','Irina Zevelyov','6240 Muhlhauser Rd','West Chester','OH','UNITED STATES','45069-4988','(408) 839-3240','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 05:07:13',0,NULL,3,1,1,1,'、 ','kutiepi87'),(11697,623457053013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','quicksilver2002','sviken2002@hotmail.com','SAIID VIKEN','47 BROLGA ST','PORT DOUGLAS','Queensland','AUSTRALIA','4877','(047) 808-5956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 05:16:18',0,NULL,3,1,2,1,'、 ','quicksilver2002'),(11698,848936618012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','sbtworld','sales@sbtworld.com','Julio C. Vargas','544 E Ogden Ave<br>STE 700-176','Milwaukee','WI','UNITED STATES','53202-2698','(414) 334-1040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 05:29:51',0,NULL,3,1,1,1,'、 ','sbtworld'),(11699,573159662004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',26.18,'cnfaner','nenenene12pq','lisab@gpcom.net','Lisa M. Berger','1120 Central Ave','Grant','NE','UNITED STATES','69140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 05:31:04',0,NULL,3,1,1,1,'、 ','nenenene12pq'),(11700,623459791013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','yanivfbi','yanivfbi@yahoo.com','yaniv siani','414 Elmwood Ave<br>Apt 5C','brooklyn','NY','UNITED STATES','11230-2635','(347) 893-3288','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 05:38:50',0,NULL,3,1,1,1,'\\','yanivfbi\r黑色的'),(11701,623460314013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.99,'eastar4','avishaym','avishaym@kkl.org.il','avishay mizrachi','kanfei nesharim 24','jerusalem','israel','ISRAEL','95464','050-6386404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 05:51:40',0,NULL,3,1,2,1,'、 ','avishaym'),(11702,847832877012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',24.99,'eastar4','monicalouisiana','monicaleighwright@gmail.com','Monica Wright','116 Miller St','Lafayette','LA','UNITED STATES','70503-2520','(337) 408-3273','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 06:12:57',0,NULL,3,1,1,1,'、 ','monicalouisiana'),(11703,848503793012,220785812343,'New original ASUS N554 bluetooth mouse+manual',2,'MOAS001',79.8,'eastar4','cfinshafer','choide091@hotmail.com','vu manh hung','to 3 xom hu0ng.p tho xuong','bac giang','bac giang','VIET NAM','10000','(129) 294-7683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 06:22:40',0,NULL,5,1,18,1,NULL,'cfinshafer\rMOAS001  paypal 有问题 已经撤款'),(11704,567695777003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','larrabee1161','bobby.dolly411@gmail.com','Bobby Dolly','9871 Mount Madera St','Las Vegas','NV','UNITED STATES','89178-7518','(702) 813-6884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 06:25:24',0,NULL,3,1,1,1,'、 ','larrabee1161'),(11705,623465787013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','anxsol','dankers@iinet.net.au','David Ankers','38 Jessie Street','Northcote','Victoria','AUSTRALIA','3070','0404457899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 06:25:47',0,NULL,3,1,2,1,'、 ','anxsol'),(11706,848945614012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','broese','arnold.rauch@aon.at','Rauch Arnold','Fasanweg 5','Neuwindorf bei Graz','','AUSTRIA','8073','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 06:13:39',0,NULL,3,1,2,1,'、 ','broese\r欧标'),(11707,765260907011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',9.9,'eastar4','prielle09','gammar1976@gmail.com','Prielle Corner Porta /Gábor','Kaposvár 18','Budapest','','HUNGARY','1117','2129877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 06:32:10',0,NULL,3,1,2,1,'、 ','prielle09\racer 8pin1.00 15cm'),(11708,707156044008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','kingchola','pathmakumar@msn.com','Pathmakumar Murugan','163A Cooma Street','Queanbayen','New South Wales','AUSTRALIA','2620','0420438343','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 06:54:41',0,NULL,3,1,3,1,'RA184580083CN ','kingchola\r澳标'),(11709,8881316158887398,111,'New NOKIA BH-202 BLUETOOTH HEADSET +Carcharger',1,'',0,'cnfaner','j-v-m-1','jevama1@yahoo.com','Jesus Vazquez Matias','Brida Mza.355-A Lt. 14<br>Col Miguel de la Madrid Iztapalapa','Mexico','Distrito Federal','MEXICO','09698','5558325855',NULL,NULL,NULL,'2011-09-16 07:41:27',0,NULL,3,0,3,1,'RA184580070CN ','CCNO001 \r补发一个车充'),(11710,848964367012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','maxpeck','cbodin@usa.net','Carl Bodin','5514 Roundtree Dr<br>Apt D','Concord','CA','UNITED STATES','94521-3936','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 07:48:28',0,NULL,3,1,1,1,'\\','maxpeck\r兼容型3D眼镜 通用型'),(11711,765278347011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','amigo-6','amigoz@pobox.sk','Stefan Zavoda','Nizny Orlik 5','Vysny Orlik','','SLOVAK REPUBLIC','09011','421904347492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 08:01:06',0,NULL,3,1,2,1,'、 ','amigo-6'),(11712,8881316160114789,111,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','batmankule','kustrak@gmail.com','Hrvoje Kustrak','Klakovec 3.','zagreb','zagreb','CROATIA, REPUBLIC OF','10000','+38598265584',NULL,NULL,NULL,'2011-09-16 08:01:54',0,NULL,3,0,3,1,'RA184580066CN ','没下来 我补的'),(11713,848970512012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'',31.49,'eastar4','alexsimmata','alexsimsas@gmail.com','ΣΤΑΜΑΤΙΑ ΚΕΜΠΕΣΗ','ΑΤΛΑΝΤΟΣ 5<br>ΝΙΚΑΙΑ','ΠΕΙΡΑΙΑΣ','προεπιλογή','GREECE','18450','2104935205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 08:16:56',0,NULL,3,0,3,1,'RA184580208CN ','alexsimmata'),(11714,848979031012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','avextra-co-uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 08:46:11',0,NULL,3,1,3,1,'RA184580171CN ','avextra-co-uk\rOTCN004*10'),(11715,765290347011,320730544219,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT004*2',52.99,'eastar4uk','smiffy2708','njsmithy_1@hotmail.com','Neil Smith','19 Windsor Place<br>Mangotsfield','Bristol','Bristol','UNITED KINGDOM','BS16 9DB','07590021030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 08:54:33',0,NULL,3,1,3,1,'RA184580168CN ','smiffy2708\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11716,765292374011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',1,'CASS001',8.29,'eastar4','peter1104peter','peterbengtsson2@gmail.com','Peter Bengtsson','Daadyrvej 2, Ejby','Ejby','Lille Skensved','DENMARK','4623','(+45) 60823344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 08:58:12',0,NULL,3,1,2,1,'、 ','peter1104peter'),(11717,724688188001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','netaderi19','netta54321@hotmail.com','neta deri','47 adam st. p.o.b 8019','jerusalem','israel','ISRAEL','91080','972547700229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:06:49',0,NULL,3,1,3,1,'RA184580242CN ','netaderi19\rBR3D005+BR3D008\r再发一张New 3D Blu-ray The offical 2010 FIFA World Cup Film'),(11719,573189675004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',19.95,'cnfaner','yaeltomer','tomeryael@gmail.com','Tomer Yael','HaShalhevet<br>22','Or Yehuda','','ISRAEL','60322','+972524214264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:10:13',0,NULL,3,1,3,1,'RA184580256CN ','yaeltomer\rOTHP004'),(11720,623492503013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','cmabl','bleow70@shaw.ca','Benedict Leow','3744 Price Street','Burnaby','BC','CANADA','V5G 2K8','(604) 306-7308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:13:18',0,NULL,3,1,3,1,'RA184580239CN ','cmabl\rMOSA005'),(11721,765297221011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','ivgeni-topivision','ivgeni@topivision.com','Ivgeni Basionok','Sderot Hatmarim 10A/3','Ramat Gan 52602','','ISRAEL','52602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:20:08',0,NULL,3,1,2,1,'、 ','ivgeni-topivision'),(11722,848992169012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','oskarsrubikis','oskars.rubikis@inbox.lv','oskars rubikis','20 oil mill lane','wisbech','Cambridgeshire','UNITED KINGDOM','pe13 1nw','07552500366','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 09:39:18',0,NULL,3,1,3,1,'RA184566121CN\r\r ','oskarsrubikis\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11723,8881316166386522,111,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',0,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334',NULL,NULL,NULL,'2011-09-16 09:46:26',0,NULL,3,1,3,1,'RA184566149CN\r ','UM00008\r补发的 \r24K 多色伞 '),(11724,764813295011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','filo_yakuza','cereal_killer@aanet.com.au','Deo Santos','PO Box 5395, Clayton Post Shop','Clayton','Victoria','AUSTRALIA','3168','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 10:09:38',0,NULL,3,1,2,1,'、 ','filo_yakuza'),(11725,765312615011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','daniel.spaniel','james.aston@yahoo.co.uk','James Aston','230 Beacon Street','Lichfield','Staffordshire','UNITED KINGDOM','WS13 7BH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 10:21:45',0,NULL,3,1,3,1,'RA184580225CN ','daniel.spaniel\r英标\rHSJA011'),(11726,765314596011,320730085829,'New Atheros AR9287 BGN 300M Half PCI-E card',1,'WLAT007',9.7,'eastar4uk','diambid','bd20868@gmail.com','Brian Diamond','1a James Street<br>Brightlingsea','Colchester','Essex','UNITED KINGDOM','CO7 0DA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 10:28:48',0,NULL,3,1,3,1,'RA184580211CN ','diambid\rWLAT007'),(11727,848960387012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',176.98,'eastar4uk','yellowbabecorsa','trinaawisdom@hotmail.com','trina wisdom','104 lion road','bexleyheath','Kent','UNITED KINGDOM','DA68PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 10:40:54',0,NULL,3,1,6,1,'EE495359494CN ','yellowbabecorsa\r一共买了5副'),(11728,765325397011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','justbleed','kollif@gmail.com','Peter Koleff','3 HANLEY STREET','POORAKA','South Australia','AUSTRALIA','5095','0882625314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:09:00',0,NULL,3,1,2,1,'\\ ','justbleed'),(11729,567743973003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','llccrft','mobilecraft1@yahoo.com','Todd MacKenzie','7138 E Grandview ST','MESA','AZ','UNITED STATES','85207','(480) 544-1550','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 11:23:17',0,NULL,3,1,1,1,'\\  ','llccrft'),(11730,765329667011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','bad.mother.trucker','jesse_pearce@hotmail.com','Jesse Pearce','200 Sorensons Road','Kuttabul','Queensland','AUSTRALIA','4741','0428308126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:24:40',0,NULL,3,1,3,1,'RA184580857CN\r ','bad.mother.trucker\rGLSG001*2'),(11731,765329956011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','cofayx','cofayx@hotmail.com','Carlos de Renovales Gozalbo','Urbanización el Pantano (Alcora) C/ Los cipreses  Nº 43','Alcora','Comunidad Valenciana','SPAIN','12110','669813355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:26:22',0,NULL,3,1,2,1,'\\  ','cofayx'),(11732,623515768013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',64.99,'eastar4','meerettich','c_rurainski@yahoo.de','C. Rurainski','Auenbruggerstr. 46a','München','','GERMANY','80999','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:30:36',0,NULL,3,1,3,1,'RA184582671CN\r ','meerettich\rMOSA005\r换发成2000B'),(11733,567750880003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','p4elkamaya','mayarahimova@yahoo.com','Mahizar Rahimova','12/1222 Narimanov region, AS Texnika LLC','Baku','','AZERBAIJAN','AZ1029','(994) 12 - 514 27 44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 12:01:00',0,NULL,3,1,3,1,'RA184580945CN\r ','p4elkamaya\rHSNO004'),(11734,765369491011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',2.99,'eastar4uk','rana_iftikhar_ahmad','fresh.noun@yahoo.com','RANA IFTIKHAR AHMAD','19<br>STEPHENSON WHARF','HEMEL HEMPSTEAD','Hertfordshire','UNITED KINGDOM','HP3 9WZ','07950390209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 13:34:55',0,NULL,3,1,3,1,'RA184580534CN\r ','rana_iftikhar_ahmad\rANTY002'),(11735,567774537003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','jtrigsby','jtrigsby@jtrigsby.com','Thom Rigsby','169 Windwood Drive','Huntsville','AL','UNITED STATES','35811','(256) 513-9606','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 13:51:49',0,NULL,3,1,1,1,'\\  ','jtrigsby'),(11736,765379853011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',36.99,'eastar4uk','dianne8917','reveroflatem@gmail.com','Dianne Becher','9 Grant Street','Drouin','Victoria','AUSTRALIA','3818','0356253049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 14:07:36',0,NULL,3,1,3,1,'RA184566444CN\r ','dianne8917\rOTSO004'),(11737,765386013011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.99,'eastar4','alexsakovich','sakovich@mail.ru','Artiom Rostokin','3-a/11 Studenchesky proezd','Gomel','Belarus','BELARUS','246012','+375 29 673-40-30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 14:27:46',0,NULL,3,1,2,1,'\\  ','alexsakovich\r欧标'),(11738,765396892011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','pquang2199','pquang@gmail.com','Peter Quang','2199 Esprit Dr.','Ottawa','ON','CANADA','K4A 4Z1','(613) 841-8210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 14:55:50',0,NULL,3,1,3,1,'RA184566550CN\r ','pquang2199\rOTSO004'),(11739,724798770001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','redjerseylinda','varady1@optonline.net','Linda Varady','205 Stillhouse Rd','Millstone Township','NJ','UNITED STATES','08510-7967','(732) 414-1109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 15:41:43',0,NULL,3,1,1,1,'\\  ','redjerseylinda'),(11740,765427619011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',2,'GLOT001',53.98,'eastar4uk','sottah_eshop','sylvesterottah@yahoo.co.uk','Sylvester Ottah','9 Clydach Road','Enfield','Middlesex','UNITED KINGDOM','EN1 3SL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 16:15:24',0,NULL,3,1,3,1,'RA184580790CN\r ','sottah_eshop\rGLOT001\r兼容型3D眼镜 通用型'),(11741,849134525012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',21.99,'eastar4','gigadata','gigadataus@gmail.com','Beyin IT','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(862) 234-5966','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 16:26:25',0,NULL,3,1,1,1,'\\  ','gigadata'),(11742,849137595012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','dn9ah','dn9ah@yahoo.co.uk','Mr Nitesh Dave','69 Artisan Crescent','St Albans','Hertfordshire','UNITED KINGDOM','AL3 5UJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 16:34:36',0,NULL,3,1,3,1,'RA184580605CN\r ','dn9ah\rWLAP008'),(11743,623592277013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','littleprincess2010isabella','senoragonzalez@gmail.com','Wendy Gonzalez','5007 Cobblestone Dr','Danville','VA','UNITED STATES','24540-5255','(434) 724-4000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 16:36:24',0,NULL,3,1,1,1,'\\  ','littleprincess2010isabella\r红边优联'),(11744,765439635011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','craig-taylor99','craigtaylor99@gmail.com','Craig Taylor','3 hinckley court','congleton','Cheshire','UNITED KINGDOM','CW124WE','01260277276','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 16:45:08',0,NULL,3,1,3,1,'RA184580551CN\r ','craig-taylor99\rGLOT001\r兼容型3D眼镜 通用型'),(11745,765456198011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','topchippy1','ashleyziebart@aol.com','Ashley Ziebart','Rose Villa, Sandbank','Wisbech St.Mary','Cambridgeshire','UNITED KINGDOM','PE134SE','01945410337','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 17:23:07',0,NULL,3,1,3,1,'RA184580715CN\r ','topchippy1\rGLOT001*2\r兼容型3D眼镜 通用型'),(11746,623611520013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','janush','janush@gmail.com','janus hao','4463 Westerly Cmn','Fremont','CA','UNITED STATES','94538','(510) 870-1598','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 17:36:02',0,NULL,3,1,1,1,'\\  ','janush'),(11747,849167744012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','scordz','francocuzzola@hotmail.com','FRANCO CUZZOLA','1259 HUNTERBURN CR. N.W','CALGARY','AB','CANADA','T2K4T1','(403) 510-5015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 17:38:14',0,NULL,3,0,3,1,'RA184580636CN\r ','scordz'),(11748,848909925012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','djses121410','djs032575@yahoo.com','Dennis Steigerwald','68 chester ave<br>apt. 2f','brooklyn','NY','UNITED STATES','11218-2034','(917) 662-8401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 17:56:34',0,NULL,5,0,18,0,NULL,'djses121410 客户要撤单 已经退款'),(11749,848667724012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','nvilliere','nicolasvilliere@aol.com','villiere michel','3 route de renauvoid','sanchey','Lorraine','FRANCE','88390','0329352278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 18:07:56',0,NULL,3,1,3,1,'RA184580874CN\r ','nvilliere\rGLSG001*3'),(11750,848693452012,220812859649,'3DConnexion SpacePilot USB 3D Motion Controller mouse',1,'MOLO010',219.99,'eastar4','navixhobby','navixhobby@gmail.com','Aleksandr Pugachev','Sovetskoi Armii st. 219/5','Samara','RU','RUSSIAN FEDERATION','443011','(903)300-7142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 18:22:27',0,NULL,3,1,3,1,'RA184582186CN ','navixhobby\rMOLO010'),(11751,567854332003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','arj00','ajohnson.mph@gmail.com','abrea johnson','522 Hannifin Dr','Blacklick','OH','UNITED STATES','43004-8012','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 18:50:31',0,NULL,3,1,1,1,'\\  ','arj00'),(11752,849212680012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','stevenburnley','steven@burnleyconsulting.com','Steven Burnley','4147 Sinclair Pl','Land O Lakes','FL','UNITED STATES','34639-4294','(813) 996-6588','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 19:05:48',0,NULL,3,0,1,1,'\\  ','stevenburnley'),(11753,573335380004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',15.98,'cnfaner','bogdan077777','bogdan0777@gmail.com','Sergiy Mykhalkov','Sholom Alejhema Street, 17-A, fl. 22','Kiev','KIEV','UKRAINE','02156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 19:24:22',0,NULL,3,1,3,1,'RA184580812CN\r ','bogdan077777\rCCZG001+BAZA001\r再发一个New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD'),(11754,849223627012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','scalix','sirpcgeek@gmail.com','Gleviston Cunha','23 Exeter St','Toronto','ON','CANADA','M6N1G3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 19:25:48',0,NULL,3,1,2,1,'\\  ','scalix'),(11755,764570841011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','buymorelady','borland@atlsolutions.com','Judy Borland','1050 Coral St','Fort Pierce','FL','UNITED STATES','34982-7605','(772) 467-2669','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 19:35:02',0,NULL,3,1,1,1,'\\  ','buymorelady'),(11756,849234638012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','roare123','roarevensen@gmail.com','Roar Evensen','Fagertunvegen 7','Levanger','','NORWAY','7600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 19:47:05',0,NULL,3,0,3,1,'RA184580619CN\r ','roare123'),(11757,765530668011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',31,'eastar4uk','fanarsenal','fanarsenal4@googlemail.com','WILLIAM TSANG','FLAT 2 18/F BLK B, MANHATTAN PLAZA<br>SAI CHING STREET, YUEN LONG, NT','default','','HONG KONG','default','0085239918536','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 20:04:14',0,NULL,3,1,3,1,'RA184580565CN\r ','fanarsenal\rWWOT003\r'),(11758,567880255003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','bogdan077777','bogdan0777@gmail.com','Sergiy Mykhalkov','Sholom Alejhema Street, 17-A, fl. 22','Kyiv','','UKRAINE','02156','+380672317021','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 20:08:07',0,NULL,8,1,17,0,NULL,'bogdan077777'),(11759,765539400011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','tretyo','prejes2@yahoo.fr','Tresor pemosso','1701 NW 46th St<br>Apt 126','oklahoma city','OK','UNITED STATES','73118-2250','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 20:21:01',0,NULL,3,0,1,1,'\\  ','tretyo'),(11760,765534616011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',42.9,'eastar4uk','gaborhingyig','hingyig@gmail.com','Hingyi Gabor','Toldi<br>5','Dunaharaszti','','HUNGARY','2330','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 20:21:35',0,NULL,3,1,3,1,'RA184580843CN\r ','gaborhingyig\rHDGE001'),(11761,849252041012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','jnns89','astrom89@hotmail.com','Jens Åström','Frejgatan 1','Boden','Norrbotten','SWEDEN','96133','+46702937768','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 20:23:17',0,NULL,3,1,3,1,'RA184580769CN\r ','jnns89\rGLOT005'),(11762,623671600013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','rflowersii','rudolph1@myself.com','Rudolph Flowers II','7054 Glen Mist','San Antonio','TX','UNITED STATES','78239-3701','(210) 564-8305','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 20:35:23',0,NULL,3,1,1,1,'\\  ','rflowersii'),(11763,849288735012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','iainmackenzie','iainandlaura@yahoo.co.uk','iain mackenzie','8 Brueacre Road','Wemyss Bay','Renfrewshire','UNITED KINGDOM','PA186ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 21:51:00',0,NULL,3,1,3,1,'RA184580738CN\r ','iainmackenzie\rGLOT004*2\r兼容型3D眼镜  samsung 专用 投递不成功退回'),(11764,765597843011,320741897531,'GPS USB receiver w/SIRF3 chip sets +antenna',1,'GPS0001',27.99,'eastar4uk','kornas','amoszamir@lycos.com','amos zamir','26 hohit','ramat hasharon','','ISRAEL','47226','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 23:08:38',0,NULL,3,1,3,1,'RA184580830CN\r ','kornas\rGPS0001'),(11765,765619053011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','nosoupforme','ebay@davedreibelbis.com','David A Dreibelbis','8686 Christopher Lee Circle','Las Vegas','NV','UNITED STATES','89129','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 00:51:55',0,NULL,3,1,1,1,'\\  ','nosoupforme'),(11766,849339835012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',39.9,'eastar4','irocls9','luislopezss@live.com','luis lopez','2053 Iola st','aurora','CO','UNITED STATES','80010-1239','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 00:53:52',0,NULL,3,1,1,1,'\\  ','irocls9'),(11767,567945512003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',127.96,'cnfaner','jddept56','sajohn8256@att.net','JOHN DELOACH','42 ROSEHEART','SAN ANTONIO','TX','UNITED STATES','78259-2264','(210) 326-7338','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-17 01:24:34',0,NULL,3,1,1,1,'\\  ','jddept56'),(11768,849347821012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','joaocoman','joaocoman@aol.com','Pio J Cevallos','103 N Princeton ave','Ventnor City','NJ','UNITED STATES','08406-2255','(609) 742-0531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 01:25:38',0,NULL,3,0,1,1,'\\  ','joaocoman'),(11769,765634360011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',16.98,'eastar4','ksha1082','ksharp82@yahoo.com','Kim Sharp','1508 Marie Ter','Arlington','TX','UNITED STATES','76010-4938','(817) 504-1797','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-17 01:45:51',0,NULL,3,1,1,1,'\\  ','ksha1082'),(11770,623739596013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','miroslaw021','mike5water@hotmail.com','Miroslaw Sienkiewicz','4 Bamboo Gr. Kelston','Waitakere','','NEW ZEALAND','0602','021-577739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 01:55:30',0,NULL,3,1,3,1,'RA184580905CN\r ','miroslaw021\rGLOT002+GLOT003'),(11771,849357501012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','dondada469','daveellinger@gmail.com','David Ellinger','838 Eucalyptus Ave<br>Apt 3','Vista','CA','UNITED STATES','92084-6260','(760) 270-0206','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 02:02:56',0,NULL,3,1,1,1,'\\  ','dondada469\r兼容型3D眼镜 通用型'),(11772,849358585012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','coorsore1970','johnnynashv@yahoo.com','Janos Toth','707 Albar Dr','Nashville','TN','UNITED STATES','37221-2601','(615) 481-3408','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 02:07:21',0,NULL,3,1,1,1,'\\  ','coorsore1970'),(11773,707516530008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','veroskut','jamie_howlett@hotmail.com','James Howlett','3 Gisele Drive','Hamilton','ON','CANADA','L9B 2M5','(905) 977-4858','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 03:03:16',0,NULL,3,1,3,1,'RA184580548CN\r ','veroskut\rSCLO001'),(11774,765653361011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','interruptstorm','josephbreihan@hotmail.com','Joseph Breihan','801 Rue Sherbrooke E<br>Apt 902','Montreal','QC','CANADA','H2L 0B7','(514) 652-9038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 03:09:42',0,NULL,3,1,2,1,'\\  ','interruptstorm'),(11775,765668569011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','g14classified','mrwhero77@gmail.com','wayne lee','444 2nd Ave<br>Apt 16E','new york','NY','UNITED STATES','10010-2515','(917) 334-2953','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 04:35:55',0,NULL,3,1,1,1,'\\  ','g14classified'),(11776,623777892013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',4,'WLAT001',55.96,'eastar4','dreamcatcher7','david.schmalz@gmail.com','David Schmalz','Ch. du Fief-de-Chapitre 3','Petit-Lancy','','SWITZERLAND','1213','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 06:26:41',0,NULL,3,1,3,1,'RA184580517CN\r ','dreamcatcher7\rWLAT001'),(11777,765688732011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','bondi972','katzbb@bezeqint.net','Bondi Dov Katz','33 Rupin','Rehovot','','ISRAEL','76345','972 8 9461888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 06:35:42',0,NULL,3,1,3,1,'RA184580640CN\r ','bondi972\rHBPH002'),(11778,567987316003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','arcticeric','eric@swedenmail.com','Eric Voelz','Ankarskatavagen 86 H','PITEA','BD','SWEDEN','94164','(467) 052-4750 ext.: 9','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 06:52:57',0,NULL,3,1,3,1,'RA184580494CN\r ','arcticeric\r欧标\rHSMO018'),(11779,849418374012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','kakolik','kakoli.gupta@gmail.com','Krishna Satyanarayana','Studio M Hotel<br>#3 Nanson Road','default','','SINGAPORE','238910','919886605054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 07:03:40',0,NULL,3,1,3,1,'RA184580596CN\r ','kakolik\rWWOT003'),(11780,849420823012,220815928644,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',13.5,'eastar4uk','chernuha90','chernuha2002@gmail.com','Nick Chernuha','Mishol Hatzav<br>8/2','Carmiel','Hatzafon','ISRAEL','21871','+972522820551','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-17 07:13:58',0,NULL,3,1,2,1,'\\  ','chernuha90'),(11781,849424395012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','harshboy666','flameguru5@comcast.net','Zach Harsh','310 Wilton Dr','Strasburg','PA','UNITED STATES','17579','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 07:29:47',0,NULL,3,1,1,1,'\\  ','harshboy666'),(11782,765702622011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mitch788','middy50@hotmail.com','mitchell lovell','49 oswin st acacia ridge','brisbane','Queensland','AUSTRALIA','4110','0402637092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 07:41:03',0,NULL,3,1,2,1,'\\  ','mitch788'),(11783,849440434012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','fernandoblazin7','fernandoblazin@gmail.com','fernando marnewick','29 rielly place<br>mount wellington','auckland','','NEW ZEALAND','1060','64212328976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:31:36',0,NULL,3,1,2,1,'\\  ','fernandoblazin7'),(11784,573467666004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','sh3d2','sh4dy@o2.pl','karol kaczmarek','dlugosza 6/5','swidnica','dolnośląskie','POLAND','58-100','792635474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:46:59',0,NULL,3,1,3,1,'RA184580503CN\r ','sh3d2\rWLDE002'),(11785,765719447011,320730530130,'New Lady Wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','goddessavenue','mtranseth@gmail.com','Mona-Lisa Transeth','Olav M. Troviksvei 22<br>H0104','OSLO','Norway','NORWAY','0864','4797983066','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 08:47:33',0,NULL,3,1,2,1,'\\  ','goddessavenue\r正红色长柄婚庆伞 '),(11786,765723080011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',13,'TRMX002',98.41,'eastar4','hypernetwork','ciscocampus.com@gmail.com','Andrew','81 Division Ave','Garfield','NJ','UNITED STATES','07026-3621','(973) 341-5990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 09:01:35',0,NULL,3,1,1,1,'\\  ','hypernetwork'),(11787,623812662013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.59,'eastar4','cinkew','clausa@optusnet.com.au','Claus Andreasen','31 Baker Ave','Kew East','Victoria','AUSTRALIA','3102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 09:54:10',0,NULL,3,1,3,1,'RA184580698CN\r ','cinkew\rMOLO008'),(11788,765744062011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','hiviz44','wleung44@shaw.ca','wilson leung','#1208-2012 fullerton ave','north vancouver','BC','CANADA','v7p3e3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 10:21:50',0,NULL,3,1,3,1,'RA184580525CN\r ','hiviz44\rBALO001'),(11789,765321189011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',35.99,'eastar4uk','lildru','andrewmorriso8@live.co.uk','drew morris','90 Claymill House<br>Raglan Road','plumstead','London','UNITED KINGDOM','se18 7hx','02082657530','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 10:25:53',0,NULL,3,1,3,1,'RA184566461CN\r ','lildru\rOTSO004'),(11790,0,120776685331,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','valdirmagalhaes1','valdirmagalhaes@ig.com.br','FRANCISCO VALDIR ALVES MAGALHAES','RUA ALVARO MENDES, 1313 SEXTO ANDAR','TERESINA','PIAUI','BRAZIL','64000-915','8688026200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 10:42:05',0,NULL,3,1,3,1,'RA184580707CN\r ','valdirmagalhaes1\rBR3D008'),(11791,765752910011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','eddwalton','edd.walton@sky.com','EDWARD WALTON','22 DARBY CRESCENT','SUNBURY ON THAMES','Middlesex','UNITED KINGDOM','TW165LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 10:51:21',0,NULL,3,1,3,1,'RA184580273CN\r ','eddwalton\rHBPH002'),(11792,849493682012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','bloozedup','dave@microsolve.freeserve.co.uk','David Bound','71 Garden Suburb','Dursley','Gloucestershire','UNITED KINGDOM','GL114EN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 11:29:58',0,NULL,3,1,2,1,'\\  ','bloozedup'),(11793,849505545012,220807272265,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','giget971','charmed05@optusnet.com.au','Kym Hamilton','12 Mallawa Dr','Palm Beach','Queensland','AUSTRALIA','4221','0410531971','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 12:04:15',0,NULL,3,1,2,1,'\\  ','giget971\r钢琴美女伞 \r粉红色的'),(11794,765785226011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','twofatpigeons','liane@lianes.co.uk','Liane Withington','41 Uttoxeter Road<br>Hill Ridware','Rugeley','Staffordshire','UNITED KINGDOM','WS153qr','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 12:34:51',0,NULL,3,1,3,1,'RA184580959CN\r ','twofatpigeons\rRCLO008'),(11795,623856152013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','saarzali','saar_zaliah@yahoo.com','saar zaliah','DUDU DOTAN 2 APT.16<br>APT.16','NETANYA','','ISRAEL','42659','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 13:13:41',0,NULL,3,1,3,1,'RA184566489CN\r ','saarzali\rMOSA005'),(11796,765802966011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','adrocks42','adrock42@msn.com','Adam Dickinson','94 Ayers Avenue<br>Daw Park','Adelaide','South Australia','AUSTRALIA','5041','0881771571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 13:26:21',0,NULL,3,1,2,1,'\\  ','adrocks42'),(11797,849543817012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','dovkedar','dovkedar@bezeqint.net','Dov Kedar','HASMINIT 9','mahlla adummim','','ISRAEL','98314','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 13:46:26',0,NULL,3,1,3,1,'RA184566427CN\r ','dovkedar\rOTSO004*2'),(11798,573532535004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','chysti_alex','chysti@mail.ru','Alexander Chisty','iftach 16/13','tel-aviv','gush-dan','ISRAEL','62374','+972547601384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 13:55:49',0,NULL,3,1,2,1,'\\  ','chysti_alex'),(11799,849547766012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',13.99,'eastar4uk','tonks712','nobbytop@gmail.com','John Nottage','Coppicewood<br>Field Avenue','Tydd St Giles','Cambridgeshire','UNITED KINGDOM','PE13 5LJ','07850777722','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 13:57:02',0,NULL,3,1,3,1,'RA184580675CN\r ','tonks712\rOTGR001'),(11800,0,110743204623,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.02,'buysia','giunta1965','lorrainegiunta082@hotmail.com','lorraine giunta','5638 E Waltann Ln','scottsdale','AZ','UNITED STATES','85254-1833','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 14:11:14',0,NULL,3,1,1,1,'\\  ','giunta1965'),(11801,849552233012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001',89.78,'eastar4','nisan2106','nisan0673@gmail.com','nisan yosupov','mapily egoz<br>26/13','tel aviv','israel','ISRAEL','67297','+972526235556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 14:12:30',0,NULL,5,0,18,0,NULL,'nisan2106  客户撤单 已经退款'),(11802,849554203012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','nadavcj','nadavcj1@walla.com','nadav cohen - jonathan','Hanasi 14/6','Givat Shemoel','','ISRAEL','54021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 14:12:58',0,NULL,3,0,3,1,'RA184580579CN ','nadavcj\r'),(11803,849553495012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','oksurya','suryafernandez@mac.com','Surya Fernandez','17570 Atlantic Blvd<br>Apt 408','Sunny Isles Beach','FL','UNITED STATES','33160-2837','(786) 487-1288','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-17 14:13:19',0,NULL,3,1,1,1,'\\  ','oksurya'),(11804,849553029012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','brentmille','brentmil@earthlink.net','Brent Miller','8445 Harvard Park Dr','Sandy','UT','UNITED STATES','84094-1204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 14:15:32',0,NULL,3,1,1,1,'\\  ','brentmille\r兼容型3D眼镜 通用型'),(11805,623885544013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','calculator.md','office@calculator.md','Stăvilă Gavril','BUTUCULUI 16 Apt. 54<br>+37369439610','CHISINAU','Moldova','MOLDOVA, REPUBLIC OF','2060','(373) 694 39610','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-09-17 15:04:31',0,NULL,3,1,3,1,'RA184580375CN\r ','calculator.md\rHSNO019'),(11806,765840147011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','538kjg','kgillissie@sbcglobal.net','Ken Gillissie','4460 Hialeah Dr','Parma','OH','UNITED STATES','44134-6212','(440) 886-1459','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 15:06:30',0,NULL,3,1,1,1,'\\  ','538kjg'),(11807,765832058011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','dramatic2001','davidmdavis@yahoo.com','Davis Davis','6949 Laurel Canyon Blvd<br>Apt 115','North Hollywood','CA','UNITED STATES','91605-6804','(310) 279-0087','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 15:13:33',0,NULL,3,1,1,1,'\\  ','dramatic2001'),(11808,765852061011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','gowisco02','tripdale@gmail.com','Robert Dale','1340 Alpine Pass','Golden Valley','MN','UNITED STATES','55416-3502','(612) 710-9561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 15:32:05',0,NULL,3,1,1,1,'\\  ','gowisco02'),(11809,765861237011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','multimadia','rharass@gmail.com','RHARASS Imad','2 bis allees jean jaures','lavaur','Midi-Pyrénées','FRANCE','81500','06.69.29.24.10','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-17 16:21:34',0,NULL,3,1,3,1,'RA184580389CN\r ','multimadia\rHSPL015\r欧标'),(11810,849620984012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',2,'HSMO014',31.9,'eastar4uk','bigj7810','jtaylor78@hotmail.co.uk','james taylor','70 white park close','middlewich','Cheshire','UNITED KINGDOM','CW10 9GD','07748250979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 16:40:50',0,NULL,3,1,3,1,'RA184580622CN\r ','bigj7810\r英标\r黑色的'),(11811,849628142012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',28.99,'eastar4','lodanz','khaled_nasr@hotmail.com','Khaled Nasr','1368 Academy Ln','Teaneck','NJ','UNITED STATES','07666','(347) 400-8698','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 16:54:09',0,NULL,3,1,1,1,'\\  ','lodanz'),(11812,765903054011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','lona_smith','shabbypink@me.com','Lona Smith','2011 Via Mariposa W<br>Unit B','Laguna Woods','CA','UNITED STATES','92637','(949) 583-7546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 17:24:23',0,NULL,3,1,1,1,'\\  ','lona_smith'),(11813,765916927011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','mrbiggr','grosano@computerworks.com','Greg Rossano','8175 Arville St<br># 230','Las Vegas','NV','UNITED STATES','89139-7111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 17:55:05',0,NULL,3,1,1,1,'\\  ','mrbiggr'),(11814,573608478004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','idyagilev','dgli@mail.ru','Igor Dyagilev','Vilisa Latsisa street, 42-129','Moscow','','RUSSIAN FEDERATION','125480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 18:17:29',0,NULL,3,1,2,1,'\\  ','idyagilev'),(11815,765930388011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','semyon415','samsherstinsky@yahoo.com','semyon sherstinsky','742 32nd Ave','san francisco','CA','UNITED STATES','94121-3502','(415) 386-0186','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 18:51:38',0,NULL,3,1,1,1,'\\  ','semyon415'),(11816,765970384011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','g_uru22','psychoman@interia.pl','Rafal Pyzowski','breadside 32','New Haw','Surrey','UNITED KINGDOM','kt153bj','07858102997','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 19:39:19',0,NULL,3,1,3,1,'RA184580313CN ','g_uru22\rCACN004'),(11817,849724313012,220501830523,'2.1 Acer Aspire 5570 5570Z Bluetooth Module EDR+cable',1,'BTAC2116',12.4,'eastar4','shazzzadam','ekelunds@charter.net','Adam Ekelund','511 W Channing Ave','Fergus Falls','MN','UNITED STATES','56537-3214','(218) 998-5320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 19:55:34',0,NULL,3,1,1,1,'\\  ','shazzzadam\racer 6pin1.25 23cm'),(11818,849725143012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','rudie_t','tboger@hotmail.com','Thomas Boger','5 meadowcroft ct','Montgomery Village','MD','UNITED STATES','20886-1340','(240) 426-4296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 19:55:57',0,NULL,3,1,1,1,'\\  ','rudie_t\r一共买了三个'),(11819,765979636011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.95,'eastar4','annairena77','bg73@o2.pl','Anna Gniady','32 goverton square','nottingham','Nottinghamshire','UNITED KINGDOM','ng6 9dg','07514497024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 19:58:01',0,NULL,3,1,2,1,'\\  ','annairena77'),(11820,725323879001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','larry00237234','larnar6928@gmail.com','Larry Narodowg','3010 Karla Dr','Mesquite','TX','UNITED STATES','75150-1820','(972) 270-1304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 20:12:28',0,NULL,3,1,1,1,'\\  ','larry00237234'),(11821,849726495012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'',31.49,'eastar4','dimme1','momtsos@hotmail.com','Dimitris Momtsos','Norra Skeppspromenaden 4','Göteborg','Västra götaland','SWEDEN','41763','0762375999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 20:16:49',0,NULL,3,0,3,1,'RA184580335CN\r ','dimme1'),(11822,849737021012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','cshyen13','cshyen@hotmail.com','andy goh','blk 94 geylang bahru #13-3092','default','','SINGAPORE','330094','6591058280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 20:24:33',0,NULL,3,1,3,1,'RA184580667CN\r ','cshyen13\rGLOT001\r兼容型3D眼镜 通用型'),(11823,849751826012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','fiesta035','mueller.j@aon.at','Josef Müller','Nr. 161','Stronsdorf','','AUSTRIA','2153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 21:04:19',0,NULL,3,1,2,1,'\\  ','fiesta035\racer 8pin1.00 8cm'),(11824,766010140011,320730083567,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',9.99,'eastar4uk','transitmagna45','dp.systems@sky.com','David Peake','12 Brant Ave<br>Milehouse','NEWCASTLE UNDER LYME','Staffordshire','UNITED KINGDOM','ST5  9DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 21:06:53',0,NULL,3,1,3,1,'RA184580741CN\r ','transitmagna45\rOTCN005\r白色的'),(11825,766016557011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','netgods','netgods@sympatico.ca','Pierre Robinson','2307 Rang St-Anne','L\'Original','ON','CANADA','K0B 1K0','(613) 675-2541','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 21:24:41',0,NULL,3,1,2,1,'\\  ','netgods'),(11826,849767430012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','sibcat77','insur_job@mail.ru','Fedor Aksenov','Molodcova dom 29 korpus 2 kvartira 220','Moscow','','RUSSIAN FEDERATION','127081','79268771070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 21:27:35',0,NULL,3,1,2,1,'\\  ','sibcat77'),(11827,568218499003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','passionfruit001','rachealanthony@gmail.com','racheal anthony','5601 Edenfield Rd<br>Apt 902','jacksonville','FL','UNITED STATES','32277-9430','(904) 382-6251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-17 22:26:24',0,NULL,3,1,1,1,'\\  ','passionfruit001'),(11828,849797123012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','edson0055','edson@proxy.com.br','Edson Alves','Rua Congo 500','Jundiaí','São Paulo','BRAZIL','13207340','005511 4587-3148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 22:51:53',0,NULL,3,1,3,1,'RA184580463CN ','edson0055\rGLOT001\r兼容型3D眼镜 通用型'),(11829,766048065011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','twcsupport','tconnor@sc.rr.com','TWConnor','122 Obannon Ct','Summerville','SC','UNITED STATES','29483-7549','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 22:59:58',0,NULL,3,1,1,1,'\\  ','twcsupport'),(11830,849812748012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','ynakahar_gogo','ynakahar.0808@jcom.home.ne.jp','Yuki Nakahara','929-10 Nakagawa Minuma Saitama City','default','Saitama','JAPAN','337-0043','0486872657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 23:49:26',0,NULL,3,1,2,1,'\\  ','ynakahar_gogo'),(11831,849827307012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','macromrj','marcos@mfnconsultoria.com.br','MARCOS NASCIMENTO','RUA DO OUVIDOR, 11<br>OUTEIRO','BELFORD ROXO','RIO DE JANEIRO','BRAZIL','26.185-140','+55 21 27591086','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 00:38:17',0,NULL,3,1,2,1,'\\  ','macromrj\r微软的'),(11832,849845598012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','rudie_t','tboger@hotmail.com','Thomas Boger','5 meadowcroft ct','Montgomery Village','MD','UNITED STATES','20886-1340','(240) 426-4296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 01:44:29',0,NULL,3,1,17,0,' ','rudie_t'),(11833,766090567011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','hillbilly1140','bigze4@frontier.com','Kevin Ziemba','114 Dewberry Lane','Burnsville','NC','UNITED STATES','28714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 01:47:02',0,NULL,3,1,1,1,'\\  ','hillbilly1140'),(11834,849851836012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',3,'SCLO002',16.17,'eastar4','myesgacct','orders@visualscriptures.org','Marvin Harrison','PO Box 513','Denver','CO','UNITED STATES','80201-0513','(303) 731-3458','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 02:08:18',0,NULL,3,1,1,1,'\\  ','myesgacct'),(11835,568268539003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','fedg3717','fredge23@yahoo.com','fredrick edge','1441 deer forest dr<br>null','fort mill','SC','UNITED STATES','29707-7738','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-18 03:23:00',0,NULL,3,1,1,1,'\\  ','fedg3717'),(11836,766116629011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','gcourts','gcourts@aol.com','Greg Courts','4004 Taylor Ave','Cincinnati','OH','UNITED STATES','45209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 03:46:25',0,NULL,3,1,1,1,'\\  ','gcourts'),(11837,849878555012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','lapoule450','celimi@videotron.ca','Michel Guèvremont','70<br>Adélaide','Sorel-Tracy','QC','CANADA','J3P 1W5','(450) 742-5415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 04:04:46',0,NULL,3,0,3,1,'RA184580327CN\r ','lapoule450'),(11838,766131602011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','tilawat','tilawat@hotmail.com','Chumpon Tilawat','605/26 LPN thailand Culture Center','Huakwang','Bangkok','THAILAND','10310','(+66)81-778-8989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 05:14:34',0,NULL,3,1,2,1,'\\  ','tilawat'),(11839,573740758004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'cnfaner','gnk2121','gkreimer@msn.com','Greg Kreimer','21 CAPTAINS RD','VALLEY STREAM','NY','UNITED STATES','11581','(212) 669-3851','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-18 05:21:05',0,NULL,3,1,1,1,'\\  ','gnk2121'),(11840,766145153011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','piotr30x','piotr.noszczak@wilo.pl','Piotr Noszczak','Lasek Brzozowy 16 m. 24','Warszawa','mazowieckie','POLAND','02792','604 288114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 06:32:45',0,NULL,3,1,2,1,'\\  ','piotr30x'),(11841,623125883013,230519434246,'New Brand SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT LED TV',1,'MOSA002',64.99,'eastar4','ercan.yapalak','yapalak@hotmail.com','Ercan Yapalak','Mörburgstraße 13','Schutterwald/Höfen','','GERMANY','77746','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 07:03:24',0,NULL,3,1,3,1,'RA184580300CN ','ercan.yapalak\rMOSA002'),(11842,624121053013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','khameeshb2010','khameeshb@saudi.net.sa','khamis Alyousef','147-29 182nd Street','Springfield Gardens','NY','UNITED STATES','11413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 07:33:34',0,NULL,3,1,1,1,'\\  ','khameeshb2010'),(11843,849927299012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',17.98,'eastar4uk','mergs06','mergs@hotmail.com','Troy Murgatroyd','The Groves<br>Unit 111, 11 West Dianne Street','Lawnton','Queensland','AUSTRALIA','4501','0408474422','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 07:55:53',0,NULL,3,1,2,1,'\\  ','mergs06\r澳标\r一共买了两个'),(11844,849931498012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','alexandranorton','alexnorton88@gmail.com','Alexandra Norton','21 Sandpiper Place<br>Kenthurst','Sydney','New South Wales','AUSTRALIA','2156','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'alexandranorton'),(11845,624128929013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','alexandranorton','alexnorton88@gmail.com','Alexandra Norton','21 Sandpiper Place<br>Kenthurst','Sydney','New South Wales','AUSTRALIA','2156','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'alexandranorton'),(11846,849941913012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','1982zvi','mio201a@gmail.com','zvi obsgard','lachish','kiryat-yam','haifa','ISRAEL','29073','+972-052-5556395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:33:55',0,NULL,3,0,3,1,'RA184580415CN\r ','1982zvi'),(11847,766179550011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','promted','promted@hotmail.com','Seth Wiscombe','571 E 500 N<br>Apt 4','Logan','UT','UNITED STATES','84321-4192','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 08:37:38',0,NULL,3,1,1,1,'\\  ','promted'),(11848,766179098011,320441575818,'2.1 Acer Travelmate 5520 5530 Bluetooth Module+cable',1,'BTAC2109',12.4,'eastar4','11cvi','vladimir.i.chernov@gmail.com','Vladimir Chernov','ul. Kommunisticheskaya d.30 kv.11','Novocheboksarsk','Chuvashiya','RUSSIAN FEDERATION','429950','+79176542579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:45:30',0,NULL,3,1,2,1,'\\  ','11cvi\racer 4pin1.25 20cm'),(11849,624135570013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','solracgui','carlos.guinovart@gmail.com','carlos guinovart','Calle Madrazo 109 2º, 2ª','Barcelona','Cataluña','SPAIN','08021','609099246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:48:08',0,NULL,3,1,3,1,'RA184566492CN\r ','solracgui\rMOSA005'),(11850,849962826012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',72.99,'eastar4uk','spergabite','max.jenkins@btinternet.com','Max Jenkins','11 Talbot Road, Knowle','Bristol','Avon','UNITED KINGDOM','BS4 2NE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 09:25:20',0,NULL,3,1,3,1,'RA184566501CN\r ','spergabite\rOTSO004*2'),(11851,766213684011,320737015281,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',75.99,'eastar4','neoheo','7215570@gmail.com','Ivan Ershov','Lobachevskogo, 64-23','Moscow','','RUSSIAN FEDERATION','119454','7(903)7215570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 10:06:42',0,NULL,3,1,3,1,'RA184580772CN\r ','neoheo\rOTSO003'),(11852,849986972012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','robertravona','ravona@gmail.com','Robert Ravona','Hakotzer 7','Ramat Hasharon','Israel','ISRAEL','47411','+972505866728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 10:21:44',0,NULL,3,0,3,1,'RA184580392CN\r ','robertravona'),(11853,849991907012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'',31.49,'eastar4','z-pit','pjotr.zonin@gmail.com','Pjotr Zonin','Oismae tee 66-117','Tallinn','Harju','ESTONIA','13512','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 10:32:36',0,NULL,3,0,3,1,'RA184580344CN ','z-pit'),(11854,624168878013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',68.85,'eastar4','rutin_f','fartunin@gmail.com','Aleksey Fartunin','Shipilovskiy Proezd 49/1-172','Moscow','','RUSSIAN FEDERATION','115551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 10:34:52',0,NULL,3,1,3,1,'RA184582107CN ','rutin_f\rCACN004'),(11855,850004615012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','lilolindalinda','lilolinda@inbox.lv','Linda Vasilevska','3 Pear Tree Cottage<br>91 the Village','York','North Yorkshire','UNITED KINGDOM','Yo32 9Up','07523291821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 10:57:34',0,NULL,3,1,3,1,'RA184580653CN ','lilolindalinda\rHBPH003'),(11856,850009508012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','ibedo75','aliibedo@gmail.com','ALI IBEDO','ABU DHABI - AL SAADA STREET','ABU DHABI','ABU DHABI','UNITED ARAB EMIRATES','31414','00971508198689','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 11:08:59',0,NULL,3,1,3,1,'RA184580826CN\r ','ibedo75\rHSIT001'),(11857,568360139003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','pierovic1','piervellinga@hotmail.com','Vellinga','Kuinder 70','Drachten','','NETHERLANDS','9204 AD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 11:20:37',0,NULL,3,1,3,1,'RA184580446CN\r ','pierovic1\rBALO007'),(11858,766248193011,320441946507,'2.1 HP M2000 M2200 M2500 Bluetooth Module EDR +cable',1,'BTHP2109',12.4,'eastar4','rileylovers37','thecreeds@bigpond.com','R.J & K.M. CREED','170 CRYSTAL BROOK RD','WATTLE GROVE','Western Australia','AUSTRALIA','6107','0893593307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 11:26:40',0,NULL,3,1,2,1,'\\  ','rileylovers37\rHP 8pin 1.25 3cm '),(11859,850028267012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','rumpelstiltskin555','crazyjacko007@hotmail.com','Karen Jackson','151 ,London Road,','Wickford','Essex','UNITED KINGDOM','SS12 0EX','01268767063','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 11:47:51',0,NULL,3,1,3,1,'RA184580786CN\r ','rumpelstiltskin555\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11860,766269708011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','kimspence1961','kimi_spence@hotmail.com','Kim Spence','RSA<br>The Melon Ground, Hatfield Park','Hatfield','Hertfordshire','UNITED KINGDOM','AL9 5NB','07850383728','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 12:20:08',0,NULL,3,1,3,1,'RA184580401CN\r ','kimspence1961\rHBPH002'),(11861,850046000012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','oogabooga14','pr3dator@msn.com','Viet Nguyen','32 Ford St','Ottoway','South Australia','AUSTRALIA','5013','0882400456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 12:25:12',0,NULL,3,1,2,1,'\\  ','oogabooga14'),(11862,8881316349256486,111,'Genuine Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',0,'eastar4uk','keithkleonard','keithmleonard4@hotmail.co.uk','Keith Leonard','4 Mead Way<br>Balderton','Newark','Nottinghamshire','UNITED KINGDOM','NG24 3GA','01636684093',NULL,NULL,NULL,'2011-09-18 12:34:16',0,NULL,3,1,3,1,'RA184580485CN\r ','HSJA011\r补发的 \r只补发耳机 '),(11863,766283507011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','n1ckston3','nickston3@gmail.com','Nick Stone','Unit 5 43 Herbert St<br>Atarmon','Sydney','New South Wales','AUSTRALIA','2065','0434566529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 12:44:54',0,NULL,3,1,2,1,'\\  ','n1ckston3'),(11864,766286130011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','longleggedfriend','mattbadger@mail.com','Matt Badger','10 Brynhedydd<br>Mathry','Haverfordwest','Pembrokeshire','UNITED KINGDOM','SA62 5EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 12:49:10',0,NULL,3,1,3,1,'RA184580358CN\r ','longleggedfriend\rMOAP001'),(11865,766295653011,320678793994,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',8.99,'eastar4uk','bearmountain62','barnes_raymond@bellsouth.net','Raymond W. Barnes','2202 Turnage Ln','Brownsville','TN','UNITED STATES','38012-2112','(901) 517-6974','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 13:09:41',0,NULL,3,1,1,1,'\\  ','bearmountain62\rHSMO006\r粉红色的'),(11866,624219884013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','knutarild1978','kaskybak@online.no','Knut Arild Skybakmoen','Nordby','default','Våler i Solør','NORWAY','2436','004691335457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 13:11:38',0,NULL,3,1,3,1,'RA184580755CN ','knutarild1978\r欧标\rHSNO019'),(11867,568399869003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','zaider1985','okuyama.toru@gmail.com','Toru Okuyama','Honcho<br>3-14-13','Nakano-ku','Tokyo','JAPAN','164-0012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 13:28:41',0,NULL,3,1,3,1,'RA184580432CN\r ','zaider1985\rHSPL010'),(11868,766305870011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','linscha','christian.weg@googlemail.com','Weg Christian','Grießweg 8','Jettingen','','GERMANY','71131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 13:29:19',0,NULL,3,1,2,1,'\\  ','linscha'),(11869,850081582012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','epopav','popov.windsurf@gmail.com','Aleksandr Popov','korpus 1132, kvartira 423','Moskow','','RUSSIAN FEDERATION','124460','+7(903)7856655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 13:33:00',0,NULL,5,0,18,0,' ','epopav\r客户要求撤单 款已经退'),(11870,708123612008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','kidd3500','rdybty@hotmail.com','David Kilgore','10 Cimarron Dr','Hattiesburg','MS','UNITED STATES','39402-8141','(601) 818-3207','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 13:39:04',0,NULL,3,1,1,1,'\\  ','kidd3500'),(11871,708124575008,180699002928,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','epipos','epicenter@mac.com','Anggra S','255 Compassvale Road<br>#05-692','default','','SINGAPORE','540255','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 13:43:48',0,NULL,3,1,11,1,'\\ ','epipos'),(11872,850104822012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',39.9,'eastar4','plee9135','ptrylee@hotmail.com','Peter Lee','8 Shamrock Ct','Millbrae','CA','UNITED STATES','94030-1740','(650) 307-0501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 14:13:32',0,NULL,3,1,1,1,'\\ ','plee9135'),(11873,624251680013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','mark_8900','mark_8900@hotmail.com','Mark Ibraheem','6 Chandela Loop, Currambine','Perth','Western Australia','AUSTRALIA','6028','610406758144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 14:37:02',0,NULL,3,1,3,1,'RA184566435CN\r ','mark_8900\rMOSA005'),(11874,624255969013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','kir667','kir@exe.su','Kirill Isupov','B. Pochtovaya, 1/33, 46','Moscow','Moscow','RUSSIAN FEDERATION','105082','+7(916)1734352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 14:44:46',0,NULL,3,1,2,1,'\\  ','kir667'),(11875,850130184012,220681620511,'New SAMSUNG WMN1000B ULTRA SLIM WALLMOUNT LED TV 40-50\'',1,'MOSA002',43.98,'eastar4uk','stimpooooo','dean.stimpson@gmail.com','Chantelle Harris','90 Neckinger Estate','London','London','UNITED KINGDOM','SE16 3QJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 14:55:12',0,NULL,3,1,3,1,'RA184580295CN\r ','stimpooooo\rMOSA002'),(11876,850137485012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','ezie3256','ewaziegler@bellsouth.net','ewa ziegler','1032 Springdale Cir','palm springs','FL','UNITED STATES','33461-6358','(561) 352-8214','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 15:05:39',0,NULL,3,1,1,1,'\\  ','ezie3256\r24K 多色伞'),(11877,766361427011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','dyann10123','dyann10123@free.fr','Yannick DUVEAU','Le Parc de la Moutonne 2<br>85 impasse de la Ciboulette','LA CRAU','Provence-Alpes-Côte d\'Azur','FRANCE','83260','09.50.39.75.65','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 15:16:58',0,NULL,3,1,3,1,'RA184580888CN\r ','dyann10123\rGLSG001*2'),(11878,850180723012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','deiferdog','bronzac9@aol.com','gareth john','10 oakridge acers','tenby','pembrokshire','UNITED KINGDOM','sa70 8db','01834842560','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 16:05:53',0,NULL,3,1,3,1,'RA184580450CN\r ','deiferdog\rHSJA010\r英标'),(11879,568464443003,130554588383,'NEW Logitech battery 890 880 950mA',1,'BALO001',11.9,'cnfaner','phyre2k','phyre@rogers.com','Michael Krieger','45 Vogell Road<br>Suite 300','Richmond Hill','ON','CANADA','L4B 3P6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 16:09:40',0,NULL,3,1,3,1,'RA184580361CN\r ','phyre2k\rBALO001'),(11880,766409110011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','pawnman0071','pawnwiley@gmail.com','Glenn Wiley','2034 Tryon Courthouse Rd','Bessemer City','NC','UNITED STATES','28016','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 16:16:28',0,NULL,3,1,1,1,'\\  ','pawnman0071'),(11881,850191879012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','sandrail02','kbarstow34@msn.com','David  Barstow','16180 Siskiyou Ct','Apple Valley','CA','UNITED STATES','92307-1447','(760) 946-1468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 16:38:56',0,NULL,3,1,1,1,'\\  ','sandrail02'),(11882,624335795013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','burentogunter','bulentguner@hotmail.com','Bulent Guner','Resit Galip Cd.\nGolgeli Sk. 18','ANKARA','TR','TURKEY','06700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 17:19:01',0,NULL,3,1,2,1,'\\  ','burentogunter'),(11883,568539931003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.9,'cnfaner','wirxestonia','laptopid@laptopid.ee','Virgo Rikk','Kivimurru 34<br>Laptopid.ee, 3 korrus, uksekood 7, tel +372 5292750','Tallinn','Harjumaa','ESTONIA','11411','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 18:15:26',0,NULL,3,1,3,1,'RA184580287CN ','wirxestonia\rMOLO006'),(11884,766542092011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',11,'CASS003',93.39,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Holzhofallee 21','Darmstadt','','GERMANY','64295','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 18:46:25',0,NULL,3,1,4,1,'YW866011776CN','cisco-campus-eu\rCASS003\r一共买了21条CAB-6060\r12条NEW CAB-2660\r包在一起'),(11885,850309861012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',31.49,'eastar4','vallejofan','former_redhead@yahoo.com','Tonya Shoemaker','1913 Lincolnshire Blvd','Ridgeland','MS','UNITED STATES','39157-1217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 18:21:25',0,NULL,3,0,1,1,'\\  ','vallejofan'),(11886,766539743011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',12,'CASS002',99.48,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Holzhofallee 21','Darmstadt','','GERMANY','64295','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 18:42:04',0,NULL,8,1,17,0,' ','cisco-campus-eu\rCASS002\r'),(11887,766540827011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','beni8080','brigita.koc@gmail.com','Benjamin Kocevar','dragovanja vas 11','Dragatuš','Dragatuš','SLOVENIA','8343','073057420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 18:48:15',0,NULL,3,1,2,1,'\\  ','beni8080'),(11888,568592651003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','irene12111','mvb@onetoonerealty.com','Michael Von Bank-','3844 Bexley Sq','Reno','NV','UNITED STATES','89503-1819','(775) 287-4027','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-18 19:44:36',0,NULL,3,1,1,1,'\\  ','irene12111'),(11889,574054472004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','zammke','zammke@maltanet.net','Kevin Zammit','55 CORNER COURT<br>FLAT 4, TRIQ L-IMSELL','BUGIBBA','ST PAUL\'S BAY','MALTA','SPB2447','+356 79286173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 19:56:47',0,NULL,3,1,3,1,'RA184580260CN\r ','zammke\r欧标\rHSPL015'),(11890,766617978011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','mooseboy000','brian.stefurak@bell.net','Brian Stefurak','90 Robarts Drive','Milton','ON','CANADA','L9T5P4','(416) 691-5321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 20:17:46',0,NULL,3,1,2,1,'\\  ','mooseboy000'),(11891,850431027012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.24,'eastar4','alexeiganin','aaganin@rambler.ru','Aleksey Ganin','Andreeva st. bl.9','Nizhny Novgorod','Nizhegorodskaya oblast','RUSSIAN FEDERATION','603051','+7(920)2537520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 20:42:31',0,NULL,3,1,2,1,'\\  ','alexeiganin\r白色的'),(11892,850425207012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','hhk0n','hhkonijn@tele2.nl','Harold Konijnenberg','Archimedesstraat 95','Den Haag','','NETHERLANDS','2517 RS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 20:55:15',0,NULL,3,1,2,1,'\\  ','hhk0n'),(11893,766644299011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','redaviator15','martywings@blueyonder.co.uk','martin jeffery','15 bodiam close, pitsea','basildon','Essex','UNITED KINGDOM','SS133RA','01268459253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 21:02:31',0,NULL,3,1,3,1,'RA184580724CN\r ','redaviator15\rGLOT001*2\r兼容型3D眼镜 通用型'),(11894,624477692013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',52.64,'eastar4','yotsuya0f30','angers.claude@gmail.com','Claude Angers','1239 chemin Ste-Claire','Riviere-Beaudette','QC','CANADA','j0p1r0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 21:34:28',0,NULL,3,1,3,1,'RA184580962CN\r ','yotsuya0f30\rMOLO009+BALO007\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000\r'),(11895,850463386012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.9,'eastar4','top-france','nicolas@wavelet.fr','Nicolas Wavelet','76B CHEMIN ETANG LONG','PIA','Languedoc-Roussillon','FRANCE','66380','06.73.05.38.59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 21:40:18',0,NULL,3,1,2,1,'\\  ','top-france\racer 5pin1.25 6cm'),(11896,624484216013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','karelklatovsky007','karel.klatovsky@live.com','Karel Klatovsky','Spartakiadni 14','Usti nad Labem','Ustecky','CZECH REPUBLIC','40010','+420775082265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 21:51:07',0,NULL,3,1,3,1,'RA184566475CN\r ','karelklatovsky007\rMOSA005'),(11897,846230407012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','andyl1977','andrewloucas@hotmail.com','Andrew Loucas','33 Windella Quadrant, Doncaster','Melbourne','Victoria','AUSTRALIA','3108','0398916446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 22:47:24',0,NULL,3,1,3,1,'RA184580809CN\r ','andyl1977\rGLOT001*2\r兼容型3D眼镜 通用型'),(11898,850492074012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',108.99,'eastar4uk','pkholmes51985','phillipkh2003@hotmail.com','Phillip Holmes','8 Grange Grove<br>Moorends','Doncaster','South Yorkshire','UNITED KINGDOM','DN84LU','07906823357','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 22:50:41',0,NULL,3,1,3,1,'RA184566413CN\r ','pkholmes51985\rOTSO004*3'),(11899,766193334011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','tonedef_pony','my_white_pony@hotmail.com','carmelo grasso','27 clarendon st. thornbury','melbourne','Victoria','AUSTRALIA','3071','0433196004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 21:52:49',0,NULL,3,1,2,1,'\\  ','tonedef_pony'),(11900,766681705011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','crackblind','dhcohen67@gmail.com','David Cohen','345 8th Ave<br>Apt 8F','New York','NY','UNITED STATES','10001','(212) 243-2260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 22:28:41',0,NULL,3,1,1,1,'\\  ','crackblind'),(11901,725982667001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19.99,'buysia','allonsgagnon2222','allonsgagnon@live.fr','sebastien gagnon','112 leclerc','princeville','QC','CANADA','g6l4r3','(819) 505-3271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 23:40:00',0,NULL,3,1,3,1,'RA184580429CN\r ','allonsgagnon2222\rBR3D007'),(11902,766712013011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','snickers30','christianshink@hotmail.com','christian shink','10 rue de cassiopee','gatineau','QC','CANADA','j9j 3w3','(819) 918-2029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 23:58:39',0,NULL,3,1,2,1,'\\  ','snickers30'),(11903,624495317013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','maggie1sarah','hay.saz@gmail.com','Sarah Hay','43A West Tamaki Rd<br>St Heliers','Auckland','Auckland','NEW ZEALAND','1071','0212034964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 23:51:04',0,NULL,3,1,2,1,'\\  ','maggie1sarah'),(11904,568675801003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',53.9,'cnfaner','wrkn-hard-plyn-harder','wrkn.hard.plyn.harder@gmail.com','Catherine Murphy','87 Alta Ave','Yonkers','NY','UNITED STATES','10705-1402','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 00:16:29',0,NULL,3,1,1,1,'\\  ','wrkn-hard-plyn-harder'),(11905,574137452004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','eware.2007','bfridman@saucedfinepreserves.com','ben Fridman','60 Filbert st','Melbourne','Victoria','AUSTRALIA','3162','0395282442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 00:38:31',0,NULL,3,1,3,1,'RA184580477CN\r ','eware.2007\rWLAP008'),(11906,850542079012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','alexprim_2009','alexprym@mail.ru','Alexander Potapov','Vatutina st.<br>4-50','Vladivostok-109','Primorye territory','RUSSIAN FEDERATION','690109','+7 914 705 06 20','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 02:17:17',0,NULL,3,1,3,1,'RA184580582CN\r ','alexprim_2009\rGLOT001\r兼容型3D眼镜 通用型'),(11907,568706487003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',27.98,'cnfaner','buckles356','farm_chick34@hotmail.com','Kelleen Nolan','36 Morris Place','Airdrie','AB','CANADA','t4a2b6','(403) 613-8184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 02:28:19',0,NULL,3,1,3,1,'RA184580928CN\r ','buckles356\rHSMO018'),(11908,8881316400099308,111,'Grohe hose',1,'OTGR002',0,'eastar4','shmuelyaniv23','shmuelyaniv@gmail.com','Yaniv Shmuel','Shraga refaeli 12/44','Petach tikva','Israel','ISRAEL','49064','972-50-9060224',NULL,NULL,NULL,'2011-09-19 02:41:39',0,NULL,3,1,2,1,'\\  ','补发的 '),(11909,766773931011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','strikor','len.smith@runtimeconsulting.com','Leonard Smith','900 Stagecoach Dr<br>Unit 18','Kamloops','BC','CANADA','V2B 0B7','(778) 470-1414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 03:02:27',0,NULL,3,1,2,1,'\\  ','strikor'),(11910,8881316401755228,111,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',0,'eastar4','ihsaan7','iamotara@gmail.com','Ihsaan Motara','Suite 302, Al Durrah Office Towers<br>Buhairah Corniche, Al Intifidah Road,','Sharjah','SHARJAH','UNITED ARAB EMIRATES','AL KHAN','+971 55 335 3781',NULL,NULL,NULL,'2011-09-19 03:09:15',0,NULL,3,1,3,1,'RA184580993CN\r ','补发的 '),(11911,766777273011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.4,'eastar4','gtxclonebg','mat_meilleur@hotmail.com','Mathieu Meilleur','72 Falconio-Mathé','Val-des-Monts','QC','CANADA','J8N 2T1','(819) 457-4236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 03:15:12',0,NULL,3,1,2,1,'\\  ','gtxclonebg\rHP 8pin 1.25 25cm '),(11912,568718632003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','seinfeldfan1','jerryzkid@yahoo.com','Lesley Petrone','1400 Brookside Dr','Norman','OK','UNITED STATES','73072-6347','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 03:37:37',0,NULL,3,1,1,1,'\\  ','seinfeldfan1'),(11913,766804356011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','merverine','merv_sy@hotmail.com','Mervin Sy','2 Hiram Johnson Road','Stouffville','ON','CANADA','L4A 0H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 05:31:59',0,NULL,3,1,2,1,'\\  ','merverine'),(11914,8881316412737357,111,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',0,'eastar4','dianafabbro','dfabbro2000@hotmail.com','Diana  Fabbro','C/ Cap Ponent Nº 11 Edif. Garbi bajo 22B Buzon 5','Roses','Cataluña','SPAIN','17480','687958747',NULL,NULL,NULL,'2011-09-19 06:12:17',0,NULL,3,1,3,1,'RA184580931CN\r ',' '),(11915,8881316413113238,111,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',0,'eastar4','1087j','mbh41@hotmail.co.uk','Malcolm Guest','44 Woodford','Gateshead','Tyne and Wear','UNITED KINGDOM','NE9 6QG','',NULL,NULL,NULL,'2011-09-19 06:18:33',0,NULL,3,1,2,1,'\\  ','补发的  只补发耳机 '),(11916,850633503012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',99.99,'eastar4','lucasghaz','lucasbradstreet@gmail.com','Lucas Bradstreet','20 Anson Road #12-03<br>C/O Iss Group Asia','SG','','SINGAPORE','079912','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 06:47:52',0,NULL,3,1,3,1,'RA184580980CN\r ','lucasghaz\rOTKE001'),(11917,766804826011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','swong007','swong@wongway.com','Sam Wong','191 Portico LN','Tracy','CA','UNITED STATES','95377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 07:13:17',0,NULL,3,1,1,1,'\\  ','swong007'),(11918,766828045011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','tyurinvlad','tyurinv@gmail.com','Владислав Тюрин','ул. Димитрова д.15/1 кв. 47','Санкт-Петербург','Северо-западный регион','RUSSIAN FEDERATION','192284','(921) 8635963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 07:36:40',0,NULL,3,1,2,1,'\\  ','tyurinvlad'),(11919,766835371011,320753598425,'NIB Genuine Samsung 3D glasses+2010 FIFA world cup disc',1,'GLSG001*2',112.99,'eastar4','zazou8178','zazou8@yahoo.com','MYRON MYLONAS','Evripidou 24','Glyfada','','GREECE','16674','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:07:13',0,NULL,3,1,3,1,'RA184582036CN\r ','zazou8178\rGLSG001*2'),(11920,850652050012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','sleeson73','home@leeson50.fsnet.co.uk','mrs m leeson','5<br>jasmine drive','tibshelf alfreton','Derbyshire','UNITED KINGDOM','de555lj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 08:09:28',0,NULL,3,1,3,1,'RA184582040CN\r ','sleeson73\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(11921,624614995013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','gear_junkie21','ajtruloff@yahoo.com.au','Andrew Truloff','8 Vivian Hancock Drive','North Booval','Queensland','AUSTRALIA','4304','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:10:28',0,NULL,3,1,2,1,'] ','gear_junkie21'),(11922,850656068012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','alexeav','ermolaev_av@rambler.ru','Алексей Ермолаев','Банк Москвы<br>Лиговский пр. д. 108А','Санкт-Петербург','','RUSSIAN FEDERATION','191119','(812) 320-90-54','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:23:29',0,NULL,3,1,2,1,'] ','alexeav'),(11923,850656843012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'KEOT001',31.49,'eastar4','igorili','igor_ulanovsky@yahoo.com','Igor Ulanovsky','Sarah Imenu 47/21','Modiin','IL','ISRAEL','71727','(972) 8-9759898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:26:29',0,NULL,3,0,3,1,'RA184582053CN\r ','igorili\r'),(11924,624619933013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','vlad43smeloff','smeloff@inbox.ru','Smeloff Vladislav','Festivalnaya str. 12-24<br>---','Murygino','Kirov oblast\' PFO','RUSSIAN FEDERATION','613641','+79229239901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:29:54',0,NULL,3,1,2,1,']','vlad43smeloff'),(11925,766843222011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','superfast.payment','i.goodluck.i@gmail.com','ASHTHMKER ILAN YOSEF','HARAV BEN MEIR ISEAEL 3/17','NETANYA','','ISRAEL','42361','972-05-2248225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:41:30',0,NULL,3,1,2,1,'\\  ','superfast.payment'),(11926,766541358011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',10,'CASS003',84.9,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Holzhofallee 21','Darmstadt','','GERMANY','64295','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:46:50',0,NULL,8,1,17,0,NULL,'cisco-campus-eu'),(11927,850664584012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','inglem424','inglem-ebay@pobox.com','Michael Ingle','424 Tuolumne Ave<br>Apt 204','Thousand Oaks','CA','UNITED STATES','91360','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 08:54:58',0,NULL,3,1,1,1,'\\  ','inglem424\r客户要只发耳机\r并且给两美金的折扣\r\r'),(11928,850668881012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','davemadeley','dave.madeley@talktalk.net','David   Madeley','49 Admiral Parker Drive','Shenstone','Staffordshire','UNITED KINGDOM','WS140NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 09:11:18',0,NULL,3,1,3,1,'RA184582022CN\r ','davemadeley\rOTCN003'),(11929,8881316423629113,111,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',0,'eastar4uk','tomg5754','bixbox@btinternet.com','Tom Graham','174 Meadowgate Avenue','Sheffield','South Yorkshire','UNITED KINGDOM','s20 2rr','01142513546',NULL,NULL,NULL,'2011-09-19 09:13:49',0,NULL,3,1,3,1,'RA184582019CN ','补发的\rRELO002 '),(11930,850675712012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','mibis22','mibis20@yahoo.com','Mindaugas Barzinskas','Bielskio 57g','Siauliai','LT','LITHUANIA','76157','+37061672916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 09:35:35',0,NULL,3,1,2,1,'\\ ','mibis22'),(11931,850692077012,220853842587,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'KEOT001',31.49,'eastar4','0424blue','rmsallan@yahoo.com.au','allan ramos','16 rawson street','lidcombe','New South Wales','AUSTRALIA','2141','0449204088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 10:39:51',0,NULL,3,0,3,1,'RA184582138CN\r ','0424blue\r'),(11932,766877611011,320721866934,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',15.95,'eastar4','pascaletim','timsteward@ozemail.com.au','TIMOTHY STEWARD','PO Box 565<br>Paddington','Brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 10:46:05',0,NULL,3,1,2,1,'\\  ','pascaletim\r地图伞 '),(11933,766877681011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','phat_bargains','ph4tc4ts@yahoo.co.uk','Qasim Rasul','19 Seven Kings Road','Ilford','Essex','UNITED KINGDOM','IG3 8DQ','07946385526','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 10:47:12',0,NULL,3,1,3,1,'RA184582362CN\r ','phat_bargains\rHSPL010\r英标'),(11934,766883611011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dhlbrown','dhlbrown@gmail.com','Doug Brown','32 Hodford Road','London','London','UNITED KINGDOM','NW11 8NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 11:08:48',0,NULL,3,1,3,1,'RA184582169CN ','dhlbrown\rMOAP001'),(11935,623699303013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',9.9,'eastar4','rpfister','rpfister@tampabay.rr.com','R. Pfister','2629 Sunridge Cir.','Palm Harbor','FL','UNITED STATES','34684','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 11:44:13',0,NULL,3,1,1,1,'\\  ','rpfister'),(11936,766887833011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',3,'TRMX002',22.71,'eastar4','n.kipnis','calabr@gmail.com','Nikolay Kipnis','default','default','','UKRAINE','03142','380504692627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 11:46:33',0,NULL,3,0,2,1,'、 ','n.kipnis\r已入库\r新地址\rNikolay Kipnis\rDobrohotova 17 app 91, \rKiev, 03142 \rUkraine\r380504692627\r\r'),(11937,766895747011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',20,'TRMX001',151.4,'eastar4','fati_zee','actualtestking747@hotmail.com','ZSM Inc.','502 Shaw Rd<br>Ste 105','Sterling','VA','UNITED STATES','20166-9435','(440) 840-3343','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 11:47:18',0,NULL,3,1,4,1,'YW865546744CN ','fati_zee\r已入库\r'),(11938,766900416011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',36.99,'eastar4uk','vigobit','tviggo@gmail.com','Trond Viggo  Bjerke','Dampsagveien 82c','Lillehammer','','NORWAY','2609','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 12:02:45',0,NULL,3,1,3,1,'RA184566890CN ','vigobit\rOTSO004'),(11939,850727617012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',67.99,'eastar4uk','unclemonty1970','mark@ency.co.uk','Mark Osborne','Ency Associates<br>Printware Court','Cumberland Business Centre','Portsmouth','UNITED KINGDOM','PO5 1DS','02392812871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 12:19:59',0,NULL,3,1,3,1,'RA184582098CN\r ','unclemonty1970\rGLSG001*2'),(11940,624670329013,230649308833,'New Vivienne  Red w/lace Boetie Sun Rain Stick umbrella',1,'UM00027',24.99,'eastar4','malenesis','malene.sandoe@hotmail.com','malene sandø','arthur nordlies vei 3A','Oslo','','NORWAY','0956','004791822437','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-19 12:30:55',0,NULL,3,1,2,1,'\\  ','malenesis\r蕾丝蝴蝶结长柄伞  '),(11941,850730590012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',5,'OTCN004*10',83.7,'eastar4','k3n-k3n','kenkenwebid@yahoo.com','Herken -','Jln. Maesa 6 No. 135<br>Ranomut Lingkungan I','Manado','North Sulawesi','INDONESIA','95128','+624313300995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 12:49:43',0,NULL,3,1,3,1,'RA184582190CN ','k3n-k3n\rOTCN004*10'),(11942,766916672011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','dolly.0406','julie.949@hotmail.com','Julie Nguyen','90 Railway Street<br>Yennora','Sydney','New South Wales','AUSTRALIA','2161','0406815967','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 12:49:55',0,NULL,3,1,2,1,'\\  ','dolly.0406\r红边优联'),(11943,850744860012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','wishi2','thegreatwishi@yahoo.es','Josep Ferrer Cazalla','Rambla Francesc Macià, 61 3º2ª','Terrassa - Barcelona','Cataluña','SPAIN','08226','600512693','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 13:08:11',0,NULL,3,1,3,1,'RA184582257CN ','wishi2\rGLOT005'),(11944,624681545013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','gwaraich','gswaraich@gmail.com','Gurvie Waraich','469 Acumen Court','Mississauga','ON','CANADA','L5W0E2','(647) 892-1390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 13:16:09',0,NULL,3,1,3,1,'RA184566872CN ','gwaraich\rMOSA005'),(11945,766925604011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.9,'eastar4','vik-v2006','vik-v2006@yandex.ru','Vitaliy Vorobev','Ligovsciy pr. 215/56','St.-Petersburg','','RUSSIAN FEDERATION','192007','79052080984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 13:16:30',0,NULL,3,1,2,1,'\\  ','vik-v2006\racer 4pin1.25 15cm '),(11946,624681409013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',8.29,'eastar4','bethlehem_distributors','anton_atallah@hotmail.com','Anton Atallah','34 johnston rd<br>bass hill','sydney','New South Wales','AUSTRALIA','2197','0297557807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 13:17:13',0,NULL,3,1,2,1,'\\  ','bethlehem_distributors\rCAB-SS-2626'),(11947,850760491012,220448695662,'Acer TravelMate 5210 5510 Bluetooth Module EDR2.0+cable',1,'BTAC2021',9.9,'eastar4','d.pasotti','icetuner@hotmail.com','Διαμαντής-Μιχαήλ Παζόττι','Ακτή Θεμιστοκλέους 342','Πειραιάς','Αττική','GREECE','18539','2104513859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 13:50:05',0,NULL,3,1,3,1,'RA184582305CN ','d.pasotti\racer 8pin1.00 8cm'),(11948,766940220011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.96,'eastar4','1corman1','sirenkon@gmail.com','Nikolay Sirenko','Belomorskaya street 10/3, app.18','Moscow','Moscow','RUSSIAN FEDERATION','125195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 13:59:50',0,NULL,3,1,2,1,'\\  ','1corman1'),(11949,624692025013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',2,'RELO003',23.96,'eastar4','luckycoincoluckycoin','renee@luckycoin.net','Renee\' Schober','1525 Airline Drive<br>c/o AMA Distributors','Metairie','LA','UNITED STATES','70001','(504) 309-1200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 14:06:22',0,NULL,3,1,1,1,'\\  ','luckycoincoluckycoin\r红边优联'),(11950,766949751011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','jennyr4','ebay@ramshaw.net','Jenny Ramshaw','112 Ryrie Ave<br>Como','Perth','Western Australia','AUSTRALIA','6152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:23:29',0,NULL,3,1,2,1,'\\  ','jennyr4'),(11951,574290318004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',26.18,'cnfaner','601rmagee8','rmagee8@hotmail.com','Rod Magee','721 Liberty Road','Flowood','MS','UNITED STATES','39232','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 14:24:14',0,NULL,3,1,1,1,'\\  ','601rmagee8'),(11952,850773205012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',108.99,'eastar4uk','sailorbill57','bill.phillips1@tiscali.co.uk','WILLIAM PHILLIPS','61 GOLBORNE ROAD, ASHTON IN MAKERFIELD','WIGAN','Lancashire','UNITED KINGDOM','WN48XA','01942714399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 14:24:32',0,NULL,3,1,3,1,'RA184566943CN ','sailorbill57\rOTSO004*3'),(11953,624698712013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','shimoda2010','amshimoda@msn.com','Anderson Massaru Shimoda','Estrada turistica do jaragua n*30 bloco B  apt104<br>Vila Jaragua','Sao Paulo','São Paulo','BRAZIL','05161000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:26:22',0,NULL,3,1,2,1,'\\  ','shimoda2010'),(11954,565967135003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','johnny10s2ghz','johnny10s@aol.com','Johnny Wayne Hartley','20 Gowham Ct','Irmo','SC','UNITED STATES','29063-8217','(803) 467-7611','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 14:34:30',0,NULL,3,1,1,1,'\\  ','johnny10s2ghz'),(11955,850779527012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','dimkkxx','d-volkovsky@yandex.ru','Dmitry Volkovsky','Beketova 11-1','Nizhniy Novgorod','','RUSSIAN FEDERATION','603057','+7 904 052 0894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:39:53',0,NULL,3,1,2,1,'\\  ','dimkkxx'),(11956,568824935003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','reeldeal1','the1reeldeal@aol.com','Richard Harris','545 Hidden Blvd','Mount Pleasant','SC','UNITED STATES','29464','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 14:51:04',0,NULL,3,1,1,1,'\\  ','reeldeal1'),(11957,624707655013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','fagear001','fagear@mail.ru','Maxim Kryukov','4th Vyatskiy Lane., 22B, Apt. 31','Moscow','RU','RUSSIAN FEDERATION','127287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:58:41',0,NULL,3,1,2,1,'\\  ','fagear001'),(11958,850789119012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','rau020202','wsrau02@mail.ru','Sandra Rau','Am Dorfplatz 43','Halen','','GERMANY','49685','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 15:04:31',0,NULL,3,1,2,1,'\\  ','rau020202\r欧标'),(11959,850795680012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','kh4tri123','manojckhatri@btinternet.com','Manoj Khatri','63 The Fairway','Northolt','Middlesex','UNITED KINGDOM','UB54SN','07944284524','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 15:17:41',0,NULL,3,1,3,1,'RA184582230CN ','kh4tri123\rGLOT005'),(11960,850797040012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',77.99,'eastar4','sg1_grendel','yoonsteve@hotmail.com','hooyoun yoon','656 Luna Park Dr','San Jose','CA','UNITED STATES','95112-4854','(408) 286-3766','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 15:20:57',0,NULL,3,1,1,1,'、 ','sg1_grendel'),(11961,766911761011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','michael.14gogo','michael.14@hotmail.ca','sabrina morin','3795 sicotte app 25','quebec','QC','CANADA','g2b3x3','(418) 847-8673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 15:25:17',0,NULL,3,1,2,1,'\\  ','michael.14gogo'),(11962,764744525011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','msnguyen','vnguyen@optonline.net','Vuong V. Nguyen','21 Richmond Pl<br>Apt 13','Stamford','CT','UNITED STATES','06902-5691','(203) 570-7546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 15:33:50',0,NULL,3,1,1,1,'、 ','msnguyen'),(11963,850809496012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','remix-shoes','emirzunic@hotmail.com','emir zunic','crkvice48','zenica','','BOSNIA AND HERZEGOVINA','72000','0038761974449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 15:48:58',0,NULL,3,1,2,1,'\\  ','remix-shoes'),(11964,766986719011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','nicholasmay','nicholasmay1959@talktalk.net','nicholas may','agincourt alltami road','alltami near mold','flintshire','UNITED KINGDOM','ch76rw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 15:54:43',0,NULL,3,1,3,1,'RA184582067CN\r ','nicholasmay\rGLOT001*2\r兼容型3D眼镜 通用型'),(11965,0,110743204593,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.01,'buysia','olesgal0_1','dmyren@rocketmail.com','donna myren','33236 Friar Tuck St','Lake Elsinore','CA','UNITED STATES','92530-5410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 17:05:06',0,NULL,3,1,1,1,'\\  ','olesgal0_1'),(11966,850850172012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','geddasalus','geddas@hotmail.com','Gediminas Budrys','171 Kingfisher Meadow','Maidstone','Kent','UNITED KINGDOM','ME16 8RD','07835948359','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 17:11:12',0,NULL,3,1,3,1,'RA184582243CN ','geddasalus\rGLOT005'),(11967,624735685013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','sichoff74','sichoff@mail.ru','Илья Сычёв','Хабаровская 6-1-101','Москва','','RUSSIAN FEDERATION','107589','(916) 7546365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 17:11:51',0,NULL,3,1,2,1,'\\  ','sichoff74'),(11968,766995726011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','juliekane007','julie.a.kane@gmail.com','Julie Kane','1100 N Dearborn St<br>Apt 2012','Chicago','IL','UNITED STATES','60610-5031','(248) 840-8386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 17:13:27',0,NULL,3,1,1,1,'\\  ','juliekane007'),(11969,624753146013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',10,'WLAT001',139.9,'eastar4','ubiquitainc','ebay@ubiquita.com','Leith Martin','6971 Monte Rosa Ave','Las Vegas','NV','UNITED STATES','89120-3018','(702) 446-0901','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 17:19:50',0,NULL,3,1,1,1,'\\  ','ubiquitainc'),(11970,850858981012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',57.99,'eastar4','unfairlane500','cougargt@wideopenwest.com','Thomas Tomasic','2803 Grindley Park St','Dearborn','MI','UNITED STATES','48124-4521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 17:28:00',0,NULL,3,1,1,1,'\\  ','unfairlane500'),(11971,850868881012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',2,'HSSE003',45.8,'eastar4','laurinan','dr.andrej.jereb@siol.net','Andrej Jereb','Kosovelova 25a','Vipava','Slovenija','SLOVENIA','5271','3687217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 17:44:21',0,NULL,3,1,3,1,'RA184582172CN ','laurinan\r欧标\rHSSE003'),(11972,767066107011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',2,'',17.98,'eastar4','liranhe11','liranhe@gmail.com','liran hefetz','bar nisan 48/10','beer sheva','','ISRAEL','84633','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 18:31:29',0,NULL,3,0,2,1,'\\  ','liranhe11'),(11973,850920763012,220816334369,'New Clear Transparent Dome Rain Sun Umbrella with trim',1,'UMTR001',15.95,'eastar4','akhvah','gadji-73@mail.ru','Gadzhimurad Gitinov','prospekt Akushinskogo Nauchniy gorodok dom 6b kv 38','Makhachkala','Republic Dagestan','RUSSIAN FEDERATION','367014','+79604111573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 19:12:41',0,NULL,3,0,2,1,'\\','akhvah\r\r已入库  '),(11974,850925877012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','supersaiyanzero','perfectdark.ci@ntlworld.com','Shiraz Adam','28 Cecil Road','Leicester','Leicestershire','UNITED KINGDOM','LE2 0AD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 19:14:06',0,NULL,3,1,3,1,'RA184582115CN ','supersaiyanzero\rMOMI001\r英标'),(11975,850932748012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','swamp2781','graham@gpmills.com','Graham Mills','163 Trysull Road<br>Merry Hill','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 7JP','01902336074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 19:25:42',0,NULL,3,1,3,1,'RA184582155CN\r ','swamp2781\rOTCN004*10'),(11976,767099623011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','lavblue1','rflavender@sbcglobal.net','FRAN LAVENDER','5401 Mormon Trl','FORT WORTH','TX','UNITED STATES','76137','(817) 514-9909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 19:31:30',0,NULL,3,1,1,1,'\\  ','lavblue1'),(11977,850951603012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.8,'eastar4uk','k1k2k3kkk','camilo_verin@hotmail.com','Camilo Javier Nuñez Gonzalez','C/ Canella Cega nº 25 3ºB','Verin (Orense)','Galicia','SPAIN','32600','670908830','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 19:58:20',0,NULL,3,1,3,1,'RA184582209CN ','k1k2k3kkk\rWLAP002'),(11978,624818781013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','gomigo1','gomigneault@hotmail.com','Daniel Migneault','791 Vercheres','Longueuil','QC','CANADA','j4k2y8','(450) 670-9293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 20:02:51',0,NULL,3,1,3,1,'RA184566869CN ','gomigo1\rMOSA005'),(11979,624836513013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','arvid.svasand','arvid.svaasand@gmail.com','Arvid Svåsand','Ragdevegen 27','Odda','Hordaland','NORWAY','5750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 21:04:06',0,NULL,3,1,6,1,'EE495359976CN ','arvid.svasand'),(11980,767172255011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',9.99,'eastar4','vanessamm7969','vdog13@yahoo.com','vanessa medina','1702 clay st se','roanoke','VA','UNITED STATES','24013-2105','(813) 313-6528','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 21:58:41',0,NULL,3,1,1,1,'\\  ','vanessamm7969'),(11981,767173981011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','christownsley89','chris_townsley89@hotmail.com','mr c townsley','flat 6/2 145 george street','glasgow','Glasgow (City of)','UNITED KINGDOM','g1 1rd','07870193593','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 22:07:12',0,NULL,3,1,3,1,'RA184582124CN ','christownsley89\rGLSG001'),(11982,624862822013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','blueopaline','cagouilles@club-internet.fr','Florence & Thierry LECERF','1 rue de la Comedie','Noisy le Grand','Seine St Denis','FRANCE','93160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 22:09:19',0,NULL,3,1,3,1,'RA184566815CN ','blueopaline\rMOSA005'),(11983,851025417012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',205.99,'eastar4','cicc86','bciccarelli86@zoominternet.net','William Ciccarelli','5430 Lou Ida Blvd','Youngstown','OH','UNITED STATES','44515-1121','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 22:43:05',0,NULL,3,1,6,1,'EE495359959CN ','cicc86'),(11984,851025552012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',1,'CASS001',5.99,'eastar4uk','vimukthilk','vimukthilk@gmail.com','Vimukthi S M W T Mudiyanselage','8 Belgrave Gardens','Stanmore','Middlesex','UNITED KINGDOM','HA7 4PH','02089547498','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 22:44:56',0,NULL,3,1,3,1,'RA184582084CN ','vimukthilk\rCASS001'),(11985,0,110743204680,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','valdirmagalhaes1','valdirmagalhaes@ig.com.br','FRANCISCO VALDIR ALVES MAGALHAES','RUA ALVARO MENDES, 1313 SEXTO ANDAR','TERESINA','PIAUI','BRAZIL','64000-915','8688026200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 22:48:50',0,NULL,3,1,3,1,'RA184582075CN ','valdirmagalhaes1\rBR3D008'),(11986,574449856004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','wholesale_2004','wholesale_2004@hotmail.com','William Spranger','1400 W Pershing St','Appleton','WI','UNITED STATES','54914-2020','(920) 850-2475','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 22:56:56',0,NULL,3,1,1,1,'\\  ','wholesale_2004'),(11987,568989767003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',16.99,'cnfaner','kenbro59','kfarrier@q.com','Kenneth L. Farrier','48453 E 1st St','Oakridge','OR','UNITED STATES','97463-9614','(541) 782-4667','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 23:18:42',0,NULL,3,1,1,1,'\\  ','kenbro59'),(11988,767209925011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',27.99,'eastar4uk','joshthejuggler','joshthejuggler@hotmail.com','Josh Chalmers','Box 311','Eston','SK','CANADA','S0L 1A0','(306) 962-3362','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 00:06:44',0,NULL,3,1,3,1,'RA184582141CN ','joshthejuggler\rOTPL001'),(11989,851055384012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','rudie_t','tboger@hotmail.com','Thomas Boger','5 meadowcroft ct','Montgomery Village','MD','UNITED STATES','20886-1340','(240) 426-4296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 00:17:23',0,NULL,3,1,1,1,'\\  ','rudie_t'),(11990,848584313012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',118.99,'eastar4','ecergina','exzor_ergina@msn.com','Exzor Ergina','3/27 Moore Road','Reynella','South Australia','AUSTRALIA','5161','61430407961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 00:26:52',0,NULL,3,1,3,1,'RA184566886CN ','ecergina\rOTSO004*2'),(11991,767216187011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',55.98,'eastar4','thunderkat88','gerald.triplett@ms.ngb.army.mil','Gerald Triplett','406 Metts St','Louisville','MS','UNITED STATES','39339-2210','(662) 803-8889','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 00:30:42',0,NULL,3,1,1,1,'\\  ','thunderkat88'),(11992,568241841003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'cnfaner','soltek2010','sales@soltekonline.net','Haydee Melendez','10030 Marconi Dr<br>STE F','San Diego','CA','UNITED STATES','92154-7292','(619) 758-3808','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 00:31:07',0,NULL,3,1,1,1,'\\  ','soltek2010'),(11993,767220708011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','natron_r1','rsalomon@comcast.net','Ronald Salomon','200 Mount Pleasant Ave<br>Apt. F6','West Orange','NJ','UNITED STATES','07052-4036','(973) 736-5235','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 00:46:04',0,NULL,3,0,1,1,'\\  ','natron_r1\r已入库'),(11994,767222679011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','lunau456','lmbasque@telus.net','Larry Basque','5611 54st','Taber','AB','CANADA','T1G1L5','(403) 223-4123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 00:52:57',0,NULL,3,1,2,1,'\\  ','lunau456'),(11995,767231297011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','clarkj5300','clarkj5300@hotmail.com','Jonathan Clark','290 Wentworth Dr','Canton','GA','UNITED STATES','30114','(678) 880-8540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 01:23:50',0,NULL,3,1,1,1,'、 ','clarkj5300'),(11996,767237476011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','awat6423','anthony.watkins@iri-roto.com','Anthony Watkins','1401 E Bowman st','South Bend','IN','UNITED STATES','46613-3303','(574) 386-5717','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 01:47:34',0,NULL,3,1,1,1,'\\  ','awat6423'),(11997,624910338013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','lxlflylxl','christian.r.petersen@gmail.com','christian petersen','931 Orchid Dr','brentwood','CA','UNITED STATES','94513-6130','(925) 550-4752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 01:48:26',0,NULL,3,1,1,1,'\\  ','lxlflylxl'),(11998,574483914004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','blueckir294','rallenl@verizon.net','Richard A. Lewis','10711 Sherman Grove Ave<br>Spc 22','Sunland','CA','UNITED STATES','91040-2353','(818) 352-0327','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 02:03:34',0,NULL,3,1,1,1,'\\  ','blueckir294'),(11999,767241900011,320738961239,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo Y460',1,'BTLE3002',19.99,'eastar4','dj-udi','udithadj@netzero.net','Uditha Neelapriyantha','2020 ingalls ave','Linden','NJ','UNITED STATES','07036','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 02:04:06',0,NULL,3,1,1,1,'\\  ','dj-udi'),(12000,851089137012,220594073986,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10e S9 M10',1,'BTLE2101',12.4,'eastar4','jedwelts','joshua.felts@gmail.com','Joshua Felts','65 Mattingly Ave','Indian Head','MD','UNITED STATES','20640-1731','(217) 649-9364','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 02:09:28',0,NULL,3,1,1,1,'\\  ','jedwelts'),(12001,767244516011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.9,'eastar4','eudesneto','eudes.neto@bol.com.br','Eudes Neto','RUA ANTONIO GERBASE, 58<br>PITANGUINHA','Maceio','Alagoas','BRAZIL','57052-160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 02:13:52',0,NULL,3,1,2,1,'\\  ','eudesneto\racer 5pin 1.25 3cm'),(12002,569022524003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','1stang67','jrj@foxinternet.net','Jim R. Jensen','15446 SE 275th St','Kent','WA','UNITED STATES','98042-4333','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 02:14:27',0,NULL,3,1,1,1,'\\  ','1stang67'),(12003,624924306013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.9,'eastar4','kste6064','karlsteier@gmail.com','Karl Steier','14263 SW 16th CT','Davie','FL','UNITED STATES','33325','(954) 370-9775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 02:53:37',0,NULL,3,1,1,1,'\\  ','kste6064'),(12004,851101401012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',2,'HSNO022',20.8,'eastar4uk','estevaojrr1','estevaojrr@ig.com.br','Carlos Allan de Lima Rosendo','Cond. Vert Paradiso Quadra J Lote 12','Maceió','Alagoas','BRAZIL','57048375','33283890','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 02:55:43',0,NULL,3,1,3,1,'RA184582393CN ','estevaojrr1\rHSNO022'),(12005,624932823013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','bouldrmnkey44558','bouldrmnkey44558@yahoo.com','Dean Valentini','44 Allagash Trl','Narragansett','RI','UNITED STATES','02882-1722','(518) 528-4872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 03:42:15',0,NULL,3,1,1,1,'、 ','bouldrmnkey44558'),(12006,851111401012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',57.98,'eastar4','kartofellagerhaus','mikejcarey@mac.com','Michael Carey','4206 W Muledeer Dr<br>Apt F','U S A F Academy','CO','UNITED STATES','80840-1148','(618) 610-7996','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 03:44:11',0,NULL,3,1,1,1,'、 ','kartofellagerhaus'),(12007,624933544013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jamesmcaskill','jamesmcaskill@hotmail.com','James McAskill','c/o O\'Connor MacLeod Hanna LLP<br>700 Kerr Street','Oakville','ON','CANADA','L6K 3W5','(905) 615-8803 ext.: 3304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 03:48:07',0,NULL,3,1,3,1,'RA184582291CN ','jamesmcaskill\rMOSA005'),(12008,574505820004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.09,'cnfaner','pggysu57','pggysu@wi.rr.com','Peggy Braddock','23227 81st St','Salem','WI','UNITED STATES','53168-9418','(847) 668-5711','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 04:12:21',0,NULL,3,1,1,1,'、 ','pggysu57'),(12009,851121657012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','fmstocco','fms@wwbits.com','Fabio Marcelo Stocco','Rua Jose Rodrigues P Carvalho, 417<br>JD IV Centenario','Campinas','SP','BRAZIL','13070195','1991379390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 04:19:24',0,NULL,3,1,3,1,'RA184582331CN ','fmstocco\rGLOT001\r兼容型3D眼镜 通用型'),(12010,569045287003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',38.79,'cnfaner','sirejohnny','johnnyal@msn.com','johnny Løvhøj','Ådalsparkvej 13 1th','Hørsholm','','DENMARK','2970','+45 45571639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 04:58:53',0,NULL,3,1,3,1,'RA184582328CN ','sirejohnny\r欧标\rHSNO019'),(12011,8881316498333515,111,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',0,'eastar4','devildoll_texas','jace.barbin@att.com','L Jace Barbin','9121 E Lost Hill Dr','Lone Tree','Co','UNITED STATES','80124-6747','(214) 704-4000',NULL,NULL,NULL,'2011-09-20 05:58:53',0,NULL,3,1,3,1,'RA184582359CN ','HBPH002\r发之前好好测试一下 '),(12012,851143910012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','jordany1382','jordond@sasktel.net','Jordon Danylyshen','428 Dalhousie Cr','Saskatoon','SK','CANADA','S7H 3S4','(306) 220-1382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 06:13:57',0,NULL,3,1,2,1,'、 ','jordany1382'),(12013,767296140011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','ferlanie_dajao238','ferlanie_dajao@yahoo.com','FERLANIE DAJAO','4023-F FOREST HILLS BANAWA','CEBU CITY','CEBU','PHILIPPINES','6000','32-2386257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 06:30:49',0,NULL,3,1,3,1,'RA184582288CN ','ferlanie_dajao238\rOTSO004\r一共买了两副'),(12014,767296713011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','ferlanie_dajao238','ferlanie_dajao@yahoo.com','FERLANIE DAJAO','4023-F FOREST HILLS BANAWA','CEBU CITY','CEBU','PHILIPPINES','6000','32-2386257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 06:32:37',0,NULL,8,1,17,0,NULL,'ferlanie_dajao238'),(12015,574521495004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','papostolos','apostolospap@gmail.com','Apostolos Papafragkakis','18 Dimokratias Street','Zografou','Attiki','GREECE','157 72','(+30)6974077732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 06:35:06',0,NULL,3,1,3,1,'RA184582345CN ','papostolos\rWLDE002'),(12016,851151618012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','designer_eng','mrtharin@gmail.com','E.N.G. Company Limited.','675/146 Charansanitwong Rd.<br>Arunamarin, Bangkoknoi','Bangkok','Bangkok','THAILAND','10700','(662)882-4945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 06:54:08',0,NULL,3,1,3,1,'RA184582402CN ','designer_eng\rHSPL009'),(12017,767302471011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','rukeerox','ruchira.mirinda@yahoo.com','Ruchira Mirinda','No-25,Muruthawala,Pasyala','Pasyala','Western','SRI LANKA','11890','0773215461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 07:01:27',0,NULL,3,1,2,1,'、 ','rukeerox'),(12018,622101401013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',25.99,'eastar4','remonde01','remonde.rense@hotmail.com','Remonde Rense','Leliestraat<br>13','Alkmaar','','NETHERLANDS','1815xs','0715115706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 07:26:51',0,NULL,3,1,2,1,'、 ','remonde01'),(12019,0,120776685268,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',11.5,'buysia','visage84','anpanag5@otenet.gr','THEOFANIS ANAGNOSTOU','AMPELAKION<br>24','ALIMOS','','GREECE','17455','2109836012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 07:33:23',0,NULL,3,1,3,1,'RA184582265CN ','visage84\rBR3D005'),(12020,767310017011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','etc_films','studioetc@gmail.com','C K Chu','15 Winslow Kinglake Street','London','London','UNITED KINGDOM','SE17 2RT','07934946722','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 07:35:53',0,NULL,3,1,3,1,'RA184582274CN ','etc_films\rCACN004'),(12021,850845138012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',22.71,'eastar4','azuluse','eusebio_mayol@inicia.es','AGIE CHARMILLES, S.A.','Riera de Fonollar, 41-A<br>Polígono industrial de Fonollar','Sant Boi de Llobregat','Cataluña','SPAIN','08830','600404136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 08:10:53',0,NULL,3,1,2,1,'\\ ','azuluse\r\r'),(12022,624975646013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',296.98,'eastar4','dealmeinbaby','kitchin@quicknet.com.au','A Kitchin','Level 13, Quay Central, 95 North Quay','BRISBANE','Queensland','AUSTRALIA','4000','0732102999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 08:38:15',0,NULL,3,1,6,1,'EE495359931CN ','dealmeinbaby\r一共买了五副'),(12023,851181989012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','dancinzw','bjdancinzw@yahoo.co.uk','Brenda Hartley','4 Bellflower Close','Lincoln','Lincolnshire','UNITED KINGDOM','LN2 4UD','01522807495','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 08:58:11',0,NULL,3,1,3,1,'RA184560177CN\r ','dancinzw\rHSJA010\r英标'),(12024,8881316509849014,111,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',10,'SCLO001',0,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 SnowdoniaCove','Bee Cave','TX','UNITED STATES','78738','',NULL,NULL,NULL,'2011-09-20 09:10:49',0,NULL,3,1,1,1,'\\ ','LK032708382CN\r补发的 '),(12025,851187334012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',11.99,'eastar4','blase49','blase49@yahoo.fr','philippe georges','Chemin du Moulin Cassé','LA REMAUDIERE','Pays de la Loire','FRANCE','44430','0688394293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 09:17:42',0,NULL,3,1,2,1,'\\ ','blase49'),(12026,707234321008,180699061588,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.99,'au-buy','maddog220473','rayrobbo2@yahoo.com.au','Raymond Robinson','15 Floyd st','Coonamble','New South Wales','AUSTRALIA','2829','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 10:13:10',0,NULL,3,1,3,1,'RA184560251CN\r ','maddog220473\r澳标\rHSJA001'),(12027,767353340011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','yarontamir','yaron.tamir@gmail.com','Yaron Tamir','Morad Hazamir 2/4','Haifa','','ISRAEL','34364','971543339615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:33:12',0,NULL,3,1,2,1,'\\  ','yarontamir'),(12028,767354977011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',1,'CASS001',8.29,'eastar4','kabdullin','kabdullin81@gmail.com','Kamil Abdullin','Orbita-1, house 22, flat 17','Almaty','Almaty District','KAZAKHSTAN','050043','+77272291347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:37:04',0,NULL,3,1,2,1,'\\  ','kabdullin\r一共买了两条'),(12029,767355567011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',1,'CASS001',8.29,'eastar4','kabdullin','kabdullin81@gmail.com','Kamil Abdullin','Orbita-1, house 22, flat 17','Almaty','Almaty District','KAZAKHSTAN','050043','+77272291347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:38:54',0,NULL,3,1,17,0,' ','kabdullin'),(12030,767357049011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','locky1275','lockwah@gmail.com','Wes Lock','8 Pesaro Place','Point Cook','Victoria','AUSTRALIA','3030','0393958796','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 10:44:12',0,NULL,3,1,2,1,'\\  ','locky1275'),(12031,851214414012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','lambros73','labrouss@gmail.com','Kostas  Labroussis','15 Kordeliou str.','Byronas / Athens','Attica','GREECE','16231','+302107608159','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:59:27',0,NULL,3,1,2,1,'\\  ','lambros73'),(12032,851239289012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','juniorarg','arildejunior@yahoo.com.br','Arilde Junior','Rua Barão de Macaúbas n° 34 Ed. Argus ap. 22<br>Barbalho','Salvador','Bahia','BRAZIL','40302-000','55 71 9971 7560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 12:12:56',0,NULL,3,1,3,1,'RA184560375CN\r ','juniorarg\rGLOT001\r兼容型3D眼镜 通用型'),(12033,726620087001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','deanjaxdean','deanjax@hotmail.com','Dean Jackson','C/- CadCut 65 Inspiration dve<br>Wangara','Perth','Western Australia','AUSTRALIA','6065','0893024520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 12:35:16',0,NULL,3,1,3,1,'RA184560129CN ','deanjaxdean\rBR3D005'),(12034,625024023013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',8.29,'eastar4','michaell9979','mrlkmw@optusnet.com.au','Michael Launder','6 Bambra Court','Seaford','Victoria','AUSTRALIA','3198','0416155698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 12:37:45',0,NULL,3,1,2,1,'\\  ','michaell9979\rCAB-SS-2626'),(12035,851272091012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',11.99,'eastar4uk','mat_fenwick','mat.fenwick@yahoo.co.uk','Mat Fenwick','Ty Isaf<br>Frongoch','Bala','Gwynedd','UNITED KINGDOM','LL23 7NU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 13:40:24',0,NULL,3,1,3,1,'RA184560194CN\r ','mat_fenwick\rHSMO019\r英标'),(12036,767427238011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','robertkawon','rapson@op.pl','Robert Nowak','3 TANGYE ROAD<br>Pool','REDRUTH','Cornwall','UNITED KINGDOM','TR153PA','004860348298','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 14:31:29',0,NULL,3,1,3,1,'RA184560265CN\r ','robertkawon\r红边优联\rRELO003'),(12037,851292106012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','irene_ven','irpavena@cc.jyu.fi','Irene Venäläinen','Mattilankatu 17','Jyväskylä','Länsi-Suomi','FINLAND','40600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 14:34:45',0,NULL,3,1,2,1,'\\ ','irene_ven\r蕾丝蝴蝶结伞 \r黑色带红蝴蝶结的'),(12038,767434594011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','pjmedina1981','pjmedina@lycos.es','Jose A. Medina Molina','Doctor Sanchez Quero, 6','Berja (Almería)','Andalucía Ceuta y Melilla','SPAIN','04760','645681619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 14:37:11',0,NULL,3,1,3,1,'RA184560384CN\r ','pjmedina1981\rGLSG001*2'),(12039,709163112008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','carrondo','pedrocarrondo@netcabo.pt','Pedro Carrondo','Rua das Abóbodas 15-1ºF','Queijas','Queijas','PORTUGAL','2790-506','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 14:42:05',0,NULL,3,1,3,1,'RA184560322CN\r ','carrondo\rSCLO001'),(12040,851296501012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',67.99,'eastar4uk','niv10010','daveniven2008@gmail.com','David Niven','21 Bennett Street','Buxton','Derbyshire','UNITED KINGDOM','SK17 6NA','0129825352','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 14:42:42',0,NULL,3,1,3,1,'RA184560441CN\r ','niv10010\rGLSG001*2'),(12041,625059727013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','rrreric','michel.strogoff@free.fr','Eric Robert','8-10, avenue Victor Hugo','Vanves','Île-de-France','FRANCE','92170','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184560115CN ','rrreric\rWLIN014+WLIN006+ANTY001+MOCN001\r再发一个\rNew Intel IBM 512ANX Card+antenna\r和一个Bracket of half intel 5300 6250 '),(12042,569153246003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',14.99,'cnfaner','yurist','yu84ra@gmail.com','Yuriy Levin','Ben Atar 5/16','Ashqelon','','ISRAEL','78309','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 15:05:30',0,NULL,3,1,3,1,'RA184560340CN\r ','yurist\rHSPL005'),(12043,851308417012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','dimattt','dimatttt@gmail.com','Dima Paulvchenko','Mansions in the park, 26/9 (Apartment 7B)<br>Soi Prasert Issalam, Sammaku Rd., Pakret','default','NO','THAILAND','11120','0897645537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 15:11:19',0,NULL,3,1,2,1,'\\  ','dimattt'),(12044,767457276011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','renatoditzel','renato_ditzel@hotmail.com','Renato Ditzel','Rua da Glória, 414<br>Centro Cívico','Curitiba','Paraná','BRAZIL','80030-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 15:35:26',0,NULL,3,0,2,1,'\\  ','renatoditzel'),(12045,767461432011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','nonick13','gernot.kuester@gmx.de','Gernot Kuester','Renold House<br>Styal Road','Wythenshawe','Greater Manchester','UNITED KINGDOM','M225WB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 15:49:08',0,NULL,3,1,3,1,'RA184560353CN\r ','nonick13\rRELO003\r红边优联'),(12046,625075789013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',64.47,'eastar4','raon255','slpjimmy@gmail.com','junho moon','Naun Dong Daewoo Apt. 102/602','Gunsan Si','','KOREA,REPUBLIC OF','573-760','+821054904725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 15:52:36',0,NULL,3,1,3,1,'RA184560398CN\r ','raon255\rWLIN014+CASS003\r再发一个CAB-6060'),(12047,625079382013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','vtuc5626','tuckervj@ccrsb.ca','Valerie Tucker','Chignecto-Central Reg Sch Brd<br>60 Lorne Street','Truro','NS','CANADA','B2N3K3','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-09-20 16:02:53',0,NULL,3,1,3,1,'RA184560234CN\r ','vtuc5626\rHSNO019\r一共买了五个  没有信息'),(12048,625081327013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',4,'HSNO019',151.96,'eastar4','vtuc5626','tuckervj@ccrsb.ca','Valerie Tucker','Chignecto-Central Reg Sch Brd<br>60 Lorne Street','Truro','NS','CANADA','B2N3K3','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-09-20 16:06:27',0,NULL,3,1,17,0,NULL,'vtuc5626'),(12049,767472371011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',36.99,'eastar4uk','fourdotone','mart.stevens@tiscali.co.uk','Martin R Stevens','2 Dundas Gardens, West Molesey, KT8 1RX','West Molesey','Surrey','UNITED KINGDOM','KT8 1RX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 16:13:11',0,NULL,3,1,3,1,'RA184560367CN\r ','fourdotone\rOTSO004'),(12050,851349436012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','mot112','breling@t-online.de','Thomas Breling','Droste-Hülshoffstr.21','Dorsten','','GERMANY','46282','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 16:40:22',0,NULL,3,1,2,1,'\\  ','mot112\r欧标'),(12051,625101079013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','tngu5490','tientran0102@gmail.com','TONY NGUYEN','4175 BOUNTIFUL BLVD','BOUNTIFUL','UT','UNITED STATES','84010','(801) 425-7301','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 17:03:45',0,NULL,3,1,1,1,'\\  ','tngu5490'),(12052,726718225001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','abouda-otaibi','ama_997@hotmail.com','abdullah','3401 Fair Park Blvd<br>Apt E208','little rock','AR','UNITED STATES','72204-8914','(501) 410-4254','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 17:05:31',0,NULL,3,1,1,1,'\\  ','abouda-otaibi'),(12053,851365493012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','recycle-scrap','wayne@texas-metals.com','Texas Metals','2989 Pine St.','Abilene','TX','UNITED STATES','79601','(325) 672-8585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 17:12:05',0,NULL,3,1,1,1,'\\  ','recycle-scrap'),(12054,766954583011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.99,'eastar4','bvw11','britt1988@hotmail.com','Britt van Waveren','Spreeuwenpark 38A','AMSTERDAM','','NETHERLANDS','1021GX','0031613843954','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'bvw11'),(12055,851293600012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','silverstone-sue','sue@gentryward.freeserve.co.uk','Sue Ward','Chequers House 50 West End','Silverstone','Northamptonshire','UNITED KINGDOM','NN12 8UY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 17:27:34',0,NULL,3,1,3,1,'RA184560319CN\r ','silverstone-sue\rHBPH003'),(12056,851361684012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','danbit','beithm@gmail.com','dani bittan','Beit Keshet 32','Bat Hefer','','ISRAEL','42842','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 17:33:07',0,NULL,3,1,3,1,'RA184560132CN ','danbit\rKEOT001'),(12057,851378156012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.9,'eastar4uk','thane0_1','tmans207@aol.com','chad badore','27 harriman cove rd','bucksport','ME','UNITED STATES','04416-4213','(207) 217-2881','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 17:35:35',0,NULL,3,1,1,1,'\\  ','thane0_1'),(12058,851382550012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','aquarix','exotic_nut@hotmail.com','Supachoke Pongquan','99/147 Sirichai Village, Soi Maiyalap, Ramindra Rd.<br>Tharang, Bangkhen, Bangkok 10230','default','BA','THAILAND','10230','66832966262','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 17:43:54',0,NULL,3,1,2,1,'\\  ','aquarix'),(12059,767515698011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','masolutions1','marcus@geek-experts.com','Marcus Aponte','121 Algonquin St','Brockton','MA','UNITED STATES','02302-2452','(508) 510-4990','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 17:44:27',0,NULL,3,1,1,1,'\\  ','masolutions1\r红边优联'),(12060,851392998012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','vallikos','levis46@mail.ru','Лев Пономарёв','Булгаковой 4 ,кв.50','Печора','коми','RUSSIAN FEDERATION','169600','+79041047658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:02:35',0,NULL,3,1,3,1,'RA184560455CN\r ','vallikos\rKEOT001'),(12061,851399632012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',28.99,'eastar4','onlinebuyer1955','n.kau@web.de','Nikolaus Kau','52 Ashgrove Road','Aberdeen','Aberdeen City','UNITED KINGDOM','AB25 3AD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:13:54',0,NULL,3,1,2,1,'\\  ','onlinebuyer1955'),(12062,726750033001,110701383504,'NIB CBS High Pressure Portable Car Washer wash',1,'CAWA001',69.9,'buysia','rogeriomoreno','roberval.moreno@yahoo.com.br','rogerio moreno','R. dos Atuns, n°19, apt 11<br>Pq. Res. Aquarius','Sao Jose dos Campos','São Paulo','BRAZIL','12246-320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:15:22',0,NULL,3,1,3,1,'RA184582685CN\r ','rogeriomoreno\rCAWA001'),(12063,851406707012,220763389170,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',27.9,'eastar4uk','argi1974','tsamakos@gmail.com','Argirios Tsamakos','WIZZIT SA<br>Vasileiou Mela 35','Cholargos','Athens','GREECE','15562','+306936549852','NoPaymentFailure','CheckoutIncomplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184560305CN\r ','argi1974\rWWSI004+ANCN001+WWSI005\r再发一个NEW Sierra WWAN MC8781 '),(12064,625131674013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','andreemichele','andresouza.rio@hotmail.com','Andre Luiz de Souza Pinto','Rua Grao Mogol, 341 - Fundos<br>Realengo','Rio de Janeiro','Rio de Janeiro - RJ','BRAZIL','21760210','552198032296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:24:48',0,NULL,3,1,3,1,'RA184560336CN\r ','andreemichele\rHSNO019'),(12065,851412237012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','dwynne4854','david@agbag.co.uk','D Wynne','Glenrue<br>Bow','Crediton','Devon','UNITED KINGDOM','EX17 6EN','0136382677','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 18:33:52',0,NULL,3,1,3,1,'RA184560225CN\r ','dwynne4854\rHSJA010\r英标'),(12066,574681988004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',2,'HSPL002',25.96,'cnfaner','tampa6045','rowell6045@aol.com','george parkes','5 Waldorf Pl','poughkeepsie','NY','UNITED STATES','12601-1268','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 18:33:55',0,NULL,3,1,1,1,'\\  ','tampa6045'),(12067,767542720011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jason.murray','jmurray@disillusion.ca','Jason Murray','624 Amaretto Avenue','Pickering','ON','CANADA','L1X2V2','(905) 831-4016','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:34:19',0,NULL,3,1,2,1,'\\  ','jason.murray'),(12068,767553756011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','brochuj306','brochuj@gmail.com','JEFF BROCHU','12176 Battle Springs Drive<br>Box 1501','Battleford','SK','CANADA','S0M 0E0','(306) 441-3859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:53:10',0,NULL,3,1,2,1,'\\  ','brochuj306'),(12069,767553828011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.7,'eastar4','asfdf','madog82@mail.ru','Andrey Gubenko','60 let SSSR pr. d. 31, kv. 10','Lipetsk','RU','RUSSIAN FEDERATION','398046','89513043860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:53:39',0,NULL,3,1,2,1,'\\  ','asfdf'),(12070,767554417011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','313877607','malchin.natalia@gmail.com','Natalia Malchin','Iftah 16/7','Tel aviv','none','ISRAEL','67314','52-8373-546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 18:54:37',0,NULL,3,1,2,1,'\\  ','313877607'),(12071,623422009013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',236.99,'eastar4','flpmttr','flpmtt@gmail.com','Felipe Motta','Rua Estancia, N: 15 AP02','São Paulo','São Paulo','BRAZIL','05786-090','+55 11 58420163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 19:01:15',0,NULL,3,1,6,1,'EE495359928CN ','flpmttr'),(12072,767565521011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','gsixpd','ozz17@walla.co.il','Oz Elisyan','Golomb 8/6','Nahariya','','ISRAEL','22403','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 19:17:19',0,NULL,3,1,2,1,'\\  ','gsixpd'),(12073,851440568012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','dalos_t_123','dalos_t@freemail.hu','Tibor Dalos','Dózsa György út 84/b.','Budapest','Pest','HUNGARY','1068','+3612358904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 19:18:43',0,NULL,3,1,3,1,'RA184560217CN\r ','dalos_t_123\rGLOT005'),(12074,851459972012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*3',78.99,'eastar4uk','mattheww5313','thevillageplumber@msn.com','matthew woods','22 church road<br>Murston','sittingbourne','Kent','UNITED KINGDOM','me10 3ru','01795423361','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 19:49:53',0,NULL,3,1,3,1,'RA184560407CN\r ','mattheww5313\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(12075,625177521013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','macprouser1.1','kirgintsev@inbox.ru','Oleg Kirgintsev','Bratislavskaya st. 14, 299','Moscow','','RUSSIAN FEDERATION','109451','+7(925)5051765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 20:15:46',0,NULL,3,1,2,1,'\\  ','macprouser1.1'),(12076,767601457011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.99,'eastar4','cwipes','cwipes@netscape.net','Michael Tjoa','1 Tamarack Lane','Pomona','NY','UNITED STATES','10970','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 20:15:46',0,NULL,3,1,1,1,'\\  ','cwipes'),(12077,767622574011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','rbumr','rbumr@aol.com','robert Bumgardner','1630 Stanwood Ave SE','Atlanta','GA','UNITED STATES','30317-1912','(404) 377-9554','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 20:55:51',0,NULL,3,1,1,1,'\\  ','rbumr'),(12078,851496576012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',28.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Tracy Murphy','3966 S Pacific Hwy<br>Spc 8','Medford','OR','UNITED STATES','97501-9015','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 20:55:28',0,NULL,3,1,1,1,'\\  ','321expressllc'),(12079,851507072012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','sontin0','sandoraizer@gmail.com','Aleksandre Lasareishvili','Palachovo Namesti 2, AT&T','Brno','Moravia','CZECH REPUBLIC','625 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 21:13:51',0,NULL,3,1,2,1,'\\  ','sontin0'),(12080,851508470012,220815929490,'New Atheros AR9287 BGN 300M Half PCI-E card+ANTENNA',1,'WLAT007+ANTY001',10.7,'eastar4uk','margariux','irmantas.mockevicius@gmail.com','Irmantas Mockevicius','Kovo 11-osios, 65-56','Kaunas','Kaunas district','LITHUANIA','49434','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 21:16:31',0,NULL,3,1,2,1,'\\  ','margariux'),(12081,851512663012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','brc1951','brian.coombs@gmail.com','Brian Coombs','18 Walmer Road','Seaford','East Sussex','UNITED KINGDOM','BN25 3TH','01323890071','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 21:25:35',0,NULL,3,1,3,1,'RA184560248CN\r ','brc1951\rHSMO018\r英标'),(12082,767637261011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','krzysiek26','reksiu1@vp.pl','KRZYSZTOF','MAJEWSKI<br>48 FIELDFARE CLOSE','CORBY','Northamptonshire','UNITED KINGDOM','NN188FF','07511095562','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 21:33:43',0,NULL,3,1,3,1,'RA184582376CN\r ','krzysiek26\r英标\rHSPL010'),(12083,850763601012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',15,'OTIN002',525,'eastar4','lantech_eugene','ebay@lantech.ru','Oleg Zharikov','1015 Honeysuckle Dr','Wheeling','IL','UNITED STATES','60090-5774','(847) 867-9711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 21:40:10',0,NULL,3,1,1,1,'\\  ','lantech_eugene'),(12084,851523255012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','bumbuh','graff@ntlworld.com','lionel lewis','64 Angelica<br>Amington','Tamworth','Staffs','UNITED KINGDOM','B77 3JY','07779599043','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 21:51:36',0,NULL,3,1,3,1,'RA184560163CN\r ','bumbuh\rGLOT004\r兼容型3D眼镜  samsung 专用'),(12085,767650347011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','simon_greenwood','simon_greenwood@msn.com','Simon Greenwood','10 Morley St','Leek','Staffordshire','UNITED KINGDOM','st138be','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 22:02:52',0,NULL,3,1,3,1,'RA184560282CN\r ','simon_greenwood\rRELO003\r红边优联'),(12086,851543178012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','eyebuyneatstuff','garyleewright@gmail.com','Gary   Wright','506 E Edgewood St','Springfield','MO','UNITED STATES','65807-3635','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 22:54:15',0,NULL,3,1,1,1,'\\  ','eyebuyneatstuff\rKEOT001'),(12087,851555636012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.9,'eastar4','pvhuniv','pvhuniv@hotmail.com','Hemanth Porumamilla','9555 Las Lomas Ave','Atascadero','CA','UNITED STATES','93422','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 23:23:42',0,NULL,3,1,1,1,'\\  ','pvhuniv\racer 4pin1.25 8cm '),(12088,726880870001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','alsrsry2010','azizamer1@hotmail.com','abdulaziz a alsuig','5170 Hudson Dr<br># 62021806 Ste I','Hudson','OH','UNITED STATES','44236-3797','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 23:23:50',0,NULL,3,1,1,1,'\\  ','alsrsry2010'),(12089,767676806011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.99,'eastar4','kkot6493','kkotadia@gmail.com','ketan kotadia','3500 cheney hwy','titusville','FL','UNITED STATES','32780','(321) 607-1710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-20 23:29:37',0,NULL,3,1,1,1,'\\  ','kkot6493'),(12090,851554950012,220844147216,'New Philips Sonicare toothbrush Handle HX6930+charger',1,'HBPH002+HBPH003',79.99,'eastar4','chrislewis9388','clpltd@xtra.co.nz','Elaine Vreeling','26 Edinburgh Drive<br>Queenstown Hill','Queenstown','','NEW ZEALAND','9300','+64 3 4424254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 23:35:29',0,NULL,3,1,3,1,'RA184560279CN\r ','chrislewis9388\rHBPH002+HBPH003'),(12091,574779756004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','dcswinehart','dan.swinehart@acm.org','Daniel C. Swinehart','371 Ferne Ave','Palo Alto','CA','UNITED STATES','94306-4606','(650) 906-0813','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 23:53:10',0,NULL,3,1,1,1,'\\  ','dcswinehart'),(12092,574784001004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','ked2869','ked1969@comcast.net','Keith Dalton','1223 Eagle Ridge RD','Oak Harbor','WA','UNITED STATES','98277-8646','(360) 632-6049','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 00:13:41',0,NULL,3,1,1,1,'\\  ','ked2869'),(12093,851567822012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'eastar4','philipb','accounts@digimead.com','Philip Brandes','1048 Irvine Ave. # 400','Newport Beach','CA','UNITED STATES','92660','(949) 642-3455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 00:19:25',0,NULL,3,1,1,1,'\\  ','philipb'),(12094,767707357011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','israelaviv','avivisr@mail.com','aviv israel','hashfela 5','kfar saba','','ISRAEL','44400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 01:18:18',0,NULL,3,1,3,1,'RA184560185CN\r ','israelaviv\rRCLO008'),(12095,625272567013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','thecarusory','carusory@gmail.com','Ryan Caruso','500 Queens Quay<br>unit 708 West','Toronto','ON','CANADA','M5V3K8','(519) 933-8099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 02:24:04',0,NULL,3,1,2,1,'\\  ','thecarusory\r红边优联'),(12096,569338575003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',14.99,'cnfaner','felippegm','felippe.moreira@terra.com.br','Luis Moreira','Al. Paradiso, nº75, Apto 2002<br>Pituba','Salvador','Bahia','BRAZIL','41830-620','+55 71 33517460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 02:24:29',0,NULL,3,1,3,1,'RA184560296CN\r ','felippegm\rHSPL005'),(12097,851615136012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','gygrpcsk','pcsk99@gmail.com','Seet Koh Tan','135 Mei Hwan Drive','default','','SINGAPORE','568424','62879218','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 02:27:08',0,NULL,3,1,3,1,'RA184560203CN ','gygrpcsk\rHSPL009'),(12098,569340840003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',4,'HSPL010',107.8,'cnfaner','jwseaux','wadeseaux@gmail.com','jonathan seaux','po box 761','iota','LA','UNITED STATES','70543-0761','(337) 313-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 02:39:23',0,NULL,3,1,1,1,'\\ ','jwseaux'),(12099,625282906013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','ocampo118','alessandraocampo118@hotmail.com','Jimmy Gurm','17 / 2 North Shore Avenue','Varsity Lakes','Queensland','AUSTRALIA','4227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 03:20:43',0,NULL,3,1,2,1,'\\  ','ocampo118\r红边优联'),(12100,851640543012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','sylo*2010','lo_franco@yahoo.com','Su Young Lo','c/o Renaissance Shanghai Yangtze Hotel, Attn: Franco Lo<br>2099 YanAn Xi Road','Shanghai','上海','CHINA','200336','+86-21-62750000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 04:05:02',0,NULL,3,1,15,1,'韵达1900047065907\r','sylo*2010\r\rSu Young Lo\r中国 上海  200336\r扬子江万丽大酒店上海延安西路2099号\r+86-21-62750000\rTel：15921608786'),(12101,767760413011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','theharpoongill','harpoon@gmail.com','paul s gill','5078 223 st','langley','BC','CANADA','v2y 2v4','(778) 237-4277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 04:54:08',0,NULL,3,1,2,1,'\\ ','theharpoongill\r新地址\rpaul s gill\r5011 223 st\rlangley BC v2y 2v4\rCANADA\r(778) 237-4277'),(12102,851652659012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','acsol','elai72@aol.com','Edmond Lai','50 Bayard St<br>Apt 5C','New York','NY','UNITED STATES','10013-4912','(917) 822-2277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 04:56:43',0,NULL,3,1,1,1,'\\  ','acsol'),(12103,767760482011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','apinzo','apinzon@elp.rr.com','Adrian Pinzon','7950 E. Via Bonita','Scottsdale','AZ','UNITED STATES','85258','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 04:57:51',0,NULL,3,1,1,1,'\\  ','apinzo'),(12104,851669057012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','thebearcub','kamikazecub@gmail.com','Anthony T. Yamada','11727 Mesa Verde Dr','Valley Center','CA','UNITED STATES','92082','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 06:16:54',0,NULL,3,1,1,1,'\\  ','thebearcub'),(12105,625309747013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','beegrons','brett@paintmypicture.com','Brett','Suite 2, 150 Chestnut Street','Richmond','Victoria','AUSTRALIA','3121','0401794935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 06:19:43',0,NULL,3,1,2,1,'\\  ','beegrons'),(12106,767789228011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.9,'eastar4','zakalupi','rovo34@hotmail.com','roberto volkwein','karl-max-alle 102','Berlin','','GERMANY','10243','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 07:25:13',0,NULL,3,1,2,1,'\\  ','zakalupi\racer 4pin1.25 15cm '),(12107,8881316590514291,111,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',0,'eastar4','nguyenvinhhao','vinhhao77@yahoo.com','NGUYEN VINH HAO','Truong Dai Hoc Bach Khoa TP.HCM<br>Khoa Dien Dien Tu','268 Ly Thuong Kiet, Quan 10,','TP Ho Chi Minh','VIET NAM','7000','(84)1217486149',NULL,NULL,NULL,'2011-09-21 07:35:14',0,NULL,3,1,3,1,'RA184582447CN ','补发的\rWWSI004 '),(12108,623104102013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*4',473.98,'eastar4','necatanen','dimakobzov@gmail.com','Dmitriy Kobzov','SANDRIGAYLO 94-65','Rudny','QOSTANAY','KAZAKHSTAN','111500','+77771440636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 07:57:41',0,NULL,3,1,3,1,' RA184582433CN\rRA184582420CN\r','necatanen\r分两票发'),(12109,767797323011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','mihailvalevko','miha.blja@inbox.lv','Mihail Valevko','Vecmilgravja 1linija 37-15','Riga','Riga Vecmilgravis','LATVIA','lv 1015','+37129888928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:06:26',0,NULL,3,1,3,1,' RA184582455CN','mihailvalevko\rGLOT001\r兼容型3D眼镜 通用型'),(12110,625325735013,230641641998,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',15.95,'eastar4','smailhan','admin@ercin.com.tr','İsmail ilhan','Kocaeli Ticaret Odası<br>Cumhuriyet Caddesi No:106 P.K: 247 41040','Kocaeli / İzmit','Kocaeli','TURKEY','247 41040','5065649194','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 08:08:56',0,NULL,5,1,2,1,NULL,'smailhan\r向日葵长柄伞  \r\r没发货，等客户问的时候退款吧。'),(12111,625327229013,230655991704,'New Bride White pure lace Wedding Marriage Sun Umbrella',1,'UM00032',21.99,'eastar4','love_farzad','love_myfarzad_4ever@hotmail.com','Ramzia Karimzadeh','1A brewer crescent','south wentworthville','New South Wales','AUSTRALIA','2145','0479097648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:14:06',0,NULL,3,1,2,1,'\\  ','love_farzad\r白色蕾丝新娘伞 '),(12112,767807395011,320741897705,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',56.99,'eastar4uk','joshuappg','padeakin@gmail.com','Paul Deakin','29 The rose walk','newhaven','East Sussex','UNITED KINGDOM','BN99NJ','01273516011','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 08:47:54',0,NULL,3,1,3,1,'RA184582481CN\r ','joshuappg\rGPS0002'),(12113,569393698003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','ingrid358','kinkkuli@jippii.fi','Ingrid Müller','Kauriintie 1 c 5<br>01480','Vantaa','Oletus','FINLAND','01480','+358407592366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:59:53',0,NULL,3,1,3,1,'RA184582645CN\r ','ingrid358\rOMHJ001'),(12114,851694734012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.99,'eastar4','alexandrfrolov','drturbo2004@yandex.ru','Alexandr Frolov','Kourovskaya, 28, 33','Yekaterinburg','Sverdlovsk Region','RUSSIAN FEDERATION','620090','8-922-22-14694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 09:19:34',0,NULL,3,1,3,1,'RA184582597CN\r ','alexandrfrolov\rWWOT003'),(12115,851716051012,220807272247,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',2,'UM00008',49.98,'eastar4','min2709','mindy.alker@bigpond.com','Mindy Alker','72 Eastern Avenue','Kingsford','New South Wales','AUSTRALIA','2032','0296622228','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 09:31:30',0,NULL,3,1,3,1,'RA184582739CN ','min2709\r24K 多色伞\rUM00008'),(12116,727019796001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'HDGE001',24.99,'buysia','klasser2009','klasser@bk.ru','Iljinych Pavel','Veteranu 8-13','Visaginas','','LITHUANIA','31134','+37062628244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 09:34:26',0,NULL,3,1,3,1,'RA184582610CN\r ','klasser2009\rHDGE001'),(12117,625350800013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','maxzealand','max.paulousky@gmail.com','Aliaksandr Bukhtseyeu','Starynauskaya 2-45','Minsk','','BELARUS','220141','+375 29 125-0585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 10:32:51',0,NULL,3,1,3,1,'RA184582504CN ','maxzealand\rMOSA005'),(12118,851735266012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','kulix_2009','g_kula@epf.pl','Grzegorz Kula','Al. Jana Pawla II 39a','Krakow','małopolskie','POLAND','31-864','697 348975','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 10:37:56',0,NULL,3,1,3,1,'RA184582464CN ','kulix_2009\rGLOT005'),(12119,767838242011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','eerryk','kyrree@kdata.no','Kyrre Eide','Brekke','JONDAL','','NORWAY','NO-5627','00 47 48153630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 10:41:18',0,NULL,3,1,2,1,'\\  ','eerryk\r红边优联'),(12120,8881316602705676,111,'CAB-6060',1,'CASS003',0,'eastar4','the.q.family','qfamily@hotmail.co.uk','Jamal Qureashi','28 Victoria Road','Mitcham','Surrey','UNITED KINGDOM','CR4 3JA','',NULL,NULL,NULL,'2011-09-21 10:58:25',0,NULL,3,1,3,1,'RA184582570CN\r ','补发的\rCASS003 '),(12121,625359095013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','lgra7908','letricia.kelly@wellsfargo.com','letricia gray','3240 coosa county road 71','Kellyton','AL','UNITED STATES','35089','(256) 794-5529','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 11:09:49',0,NULL,3,1,1,1,'\\ ','lgra7908\r黑色的'),(12122,0,120776685320,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',18.02,'buysia','joseguz28','jguzman2@yahoo.com','jose guzman','74 Melville Ln','willingboro','NJ','UNITED STATES','08046-2911','(609) 325-8870','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 11:10:13',0,NULL,3,1,1,1,'\\  ','joseguz28'),(12123,767850167011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','classicmash','lyndonwilliams4@hotmail.com','Lyndon Williams','4 Orrong Court','Mornington','Victoria','AUSTRALIA','3931','0359751847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 11:22:00',0,NULL,3,1,2,1,'\\  ','classicmash'),(12124,574894954004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','rototiili','jari@juutit.fi','Jari Juuti','Rauhalanpuisto 6-8 C 20','ESPOO','','FINLAND','FI-02230','358443549630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 11:28:02',0,NULL,3,1,3,1,'RA184582583CN\r ','rototiili\rBALO007\r新地址\rJari Juuti\rSaku Vainio Eestintaival 3 C 19 \rEspoo FI-02280  Finland \r358443549630'),(12125,851750332012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','city450','fxstc69@hotmail.com','Claude Tellier','267 rue du Chanoine-Pepin','Beloeil','QC','CANADA','J3G3A6','(514) 928-7525','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 11:31:52',0,NULL,3,1,2,1,'\\  ','city450'),(12126,767864153011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kwentinm','quentinm@orcon.net.nz','Quentin Morgan','6B Coates Street<br>Linden','Wellington','Wellington','NEW ZEALAND','5028','+64 4 232 7918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 12:08:18',0,NULL,3,1,2,1,'\\  ','kwentinm'),(12127,625380439013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','drbrain_2k6','datorbutik@drbrain.se','Fredrik Nilsson','Hofverbergsgatan 7A','Helsingborg','','SWEDEN','25443','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 12:47:35',0,NULL,3,1,2,1,'\\  ','drbrain_2k6'),(12128,851765911012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','karen23smile09','karen23smile@hotmail.com','Karen Lim','Blk 119 Teck Whye lane<br>#05-778','default','','SINGAPORE','680119','+6591779523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 12:12:46',0,NULL,3,1,3,1,'RA184582535CN\r ','karen23smile09\rKEOT001'),(12129,767886402011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.99,'eastar4','kingstratos2004','stratosss@hotmail.com','EFSTRATIOS THEODORELIS','ANTHOUPOLEOS 47','PATRAS','GREECE/PATRAS','GREECE','26443','(0030) 2610435897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 13:15:17',0,NULL,3,1,2,1,'\\ ','kingstratos2004\rHP 5pin1.0 20cm'),(12130,767889264011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',3,'GLOT004',134.67,'eastar4','stevef18020','stevef@fast.net','G. Stephen Fogt','3640 Manor Rd','Bethlehem','PA','UNITED STATES','18020-8607','(610) 882-1835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 13:28:49',0,NULL,3,1,1,1,'\\ ','stevef18020\r兼容型3D眼镜  samsung 专用'),(12131,851804462012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',4,'WLAP004',19.8,'eastar4','muemmelchen111','regina.lenz111@yahoo.de','Regina Lenz','In der Grobe 16','Wilgersdorf','','GERMANY','57234','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 13:57:31',0,NULL,3,1,2,1,'\\ ','muemmelchen111'),(12132,851816021012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','mickeww','micke08@gmail.com','Mikael Wiegand','Kärrtorpsvägen 7<br>121 55 Johanneshov','Stockholm','Stockholm','SWEDEN','12155','+46704164505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 14:29:37',0,NULL,3,1,2,1,'\\  ','mickeww'),(12133,851833879012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',26.99,'eastar4uk','fgaud','starbasec4@yahoo.fr','GAUD Francis','98 route de jousson','MAGNE','Poitou-Charentes','FRANCE','79460','0688697713','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 15:12:47',0,NULL,3,1,3,1,'RA184582668CN\r ','fgaud\rGLOT004\r兼容型3D眼镜  samsung 专用'),(12134,574946963004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.09,'cnfaner','rodasturbo','joelrodasturbo@hotmail.com','Joel Ramos','Rua Ferreira de Castro nº 69','Valbom','Gondomar','PORTUGAL','4420-451','+351918435152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 15:16:24',0,NULL,3,1,3,1,'RA184583561CN\r ','rodasturbo\r欧标\rHSNO005'),(12135,767938772011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.89,'eastar4','rafajl','rafajl@ono.com','Rafael Jiménez López','Sa Riera, 18','Puigpunyent','Islas Baleares','SPAIN','07194','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 15:44:04',0,NULL,3,1,3,1,'RA184582756CN\r ','rafajl\rGLOT004\r兼容型3D眼镜  samsung 专用'),(12136,851863987012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','arkadir255','arkadiraider@gmail.com','Arkadi Raider','Amnon 34','Beer-Sheva','nahal-ashan','ISRAEL','84511','0545276068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 16:21:57',0,NULL,3,1,3,1,'RA184582521CN ','arkadir255\rKEOT001'),(12137,624477581013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','virusandy','diplocoder@gmail.com','Alexander Sergeevich Kargapolov','d. 11/1, kv. 44<br>ul. Russkaya','Novosibirsk','NOVOSIBIRSKAYA OBL','RUSSIAN FEDERATION','630058','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 16:22:17',0,NULL,3,1,2,1,'\\  ','virusandy'),(12138,574976075004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','stf8549','sl2@libertysurf.fr','Stéphane LASNE','4, rue Pasteur','La Tessoualle','Pays de la Loire','FRANCE','49280','06.16.47.05.62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 17:02:15',0,NULL,3,1,3,1,'RA184582518CN\r ','stf8549\rWWOT003+ANCN001'),(12139,851886466012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','beaubarre','np@newtale.com','Nguyen Phi','48 boulevard Murat','Paris','Île-de-France','FRANCE','75016','06.76.16.19.99','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 17:08:16',0,NULL,3,1,2,1,'\\  ','beaubarre'),(12140,851889055012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',2,'SCLO002',10.78,'eastar4','marcis55','marcis1972@yahoo.de','Wiegand Marc','Schwarzer Weg 55','Moers','','GERMANY','47447','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 17:12:33',0,NULL,3,1,3,1,'RA184582708CN\r ','marcis55\rSCLO002+SCLO003+SCLO004\r再发两个New Logitech Performance MX Mouse M950 Mat 3M material\r两个New Logitech MX Revolution Mouse Mat 3M material'),(12141,851888119012,220815931195,'New Logitech/Asus Limit MX518 MX 518 Gaming mouse USB',2,'MOLO004',53,'eastar4uk','tatpole99','andrew.tatarek@c2mdesign.co.uk','Andrew Tatarek','Gower House<br>Croft Road','Aldershot','Hampshire','UNITED KINGDOM','GU11 3HR','01252332007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 17:13:34',0,NULL,3,1,3,1,'RA184583632CN\r ','tatpole99\rMOLO004\r华硕限量版'),(12142,851890287012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',7.8,'eastar4','marcis55','marcis1972@yahoo.de','Wiegand Marc','Schwarzer Weg 55','Moers','','GERMANY','47447','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 17:14:48',0,NULL,3,1,17,0,NULL,'marcis55'),(12143,625455268013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',11.9,'eastar4','marcis55','marcis1972@yahoo.de','Wiegand Marc','Schwarzer Weg 55','Moers','','GERMANY','47447','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 17:18:38',0,NULL,3,1,17,0,NULL,'marcis55'),(12144,851892223012,220858454297,'New original Apple AirPort Extreme WiFi Card 54M',1,'WLAP003',14.9,'eastar4uk','pmgarfield','peter.pmgarfield@gmail.com','Peteris Mikelsons','56 Howrcoft Crescent','London','London','UNITED KINGDOM','N3 1PB','07553508652','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 17:19:18',0,NULL,3,1,3,1,'RA184582623CN\r ','pmgarfield\rWLAP003\r二代卡新的'),(12145,767986028011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','divingsatrebla','vladelis@yahoo.com','VLADAS STANKEVICIUS','507 W RAVINE AVE','WILLOW SPRINGS','IL','UNITED STATES','60480','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 17:32:17',0,NULL,3,1,1,1,'\\ ','divingsatrebla'),(12146,574987477004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','gastonmike','mbirrell@verizon.net','Michael E Birrell','4814 Washington Blvd','Arlington','VA','UNITED STATES','22205-2543','(703) 243-2125','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 17:37:13',0,NULL,3,1,1,1,'\\  ','gastonmike'),(12147,767995032011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','avi.fedida','avi.fedida@gmail.com','Avi Fedida','Koresh 14, entrance D, apartment 11','Jerusalem,','Jerusalem','ISRAEL','94144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 17:55:42',0,NULL,3,1,2,1,'\\  ','avi.fedida'),(12148,768001351011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','dharkins55','nb10r@yahoo.com','Diana Harkins','38 Calle Cabrillo','Foothill Ranch','CA','UNITED STATES','92610','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 18:00:32',0,NULL,3,1,1,1,'\\ ','dharkins55'),(12149,768001988011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','smilesallaround333','candice.reggi@hotmail.com','Candice Reggi','2058 <br>Oxford Ave.','Oakville','ON','CANADA','L6H 4K7','(905) 467-1683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 18:01:17',0,NULL,3,1,2,1,'\\  ','smilesallaround333'),(12150,851897874012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',9.9,'eastar4','gorva84','gramirez084@gmail.com','Gustavo Ramirez','33 Newark Ave','Bloomfield','NJ','UNITED STATES','07003-6022','(862) 703-0949','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 18:10:35',0,NULL,3,1,1,1,'\\  ','gorva84\racer 8pin1.00 6cm '),(12151,625485305013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',3,'HSNO019',113.97,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-09-21 18:37:53',0,NULL,3,1,3,1,'RA184582566CN ','jape324\r欧标\rHSNO019'),(12152,851936906012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','7uin4cj9','giedrius.preisegolavicius@sky.com','giedrius preisegolavicius','Unit 4 Newtons Court<br>Crossways Business Park','Dartford','Kent','UNITED KINGDOM','DA2 6QL','07877967793','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 18:38:36',0,NULL,3,1,3,1,'RA184582725CN\r ','7uin4cj9\rGLOT001*2\r兼容型3D眼镜 通用型'),(12153,768040172011,320730481767,'New Japan Gentleman business Stripe Rain Stick Umbrella',1,'UM00026',26.99,'eastar4','luacaz','acaz2005@yahoo.com.br','ADRIANO ANDRE SILVA','SHIS QL 26 CONJ 07 CASA 09<br>LAGO SUL','BRASILIA','DISTRITO FEDERAL','BRAZIL','71665175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 19:11:10',0,NULL,3,1,2,1,'\\ ','luacaz\r日本外贸经典条纹长柄伞 '),(12154,569549028003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.9,'cnfaner','alexander_burtsev','alexander.burtsev@gmail.com','Alexander Burtsev','Prospekt Mira, building 114B, appt. 74','Moscow','','RUSSIAN FEDERATION','129626','+79168054705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 19:31:31',0,NULL,3,1,3,1,'RA184582637CN\r ','alexander_burtsev\rWLAT007'),(12155,625521042013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','craig_lee10','craig_lee10@yahoo.co.uk','Craig Thomas','16 Penhale Drive<br>Hucknall','Nottingham','Nottinghamshire','UNITED KINGDOM','NG15 6FH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 20:08:19',0,NULL,3,1,2,1,'\\  ','craig_lee10\rCAB-6060'),(12156,727265389001,110694687287,'New Genuine AKG Q460 On-Ear Headphone for Iphone',1,'HSAK002',96,'buysia','noga123','nogajacobi@gmail.com','donna hordes','854 W 181st St','new york','NY','UNITED STATES','10033-4444','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 20:44:10',0,NULL,5,0,18,1,NULL,'noga123\r已经退款'),(12157,852033637012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','gmcctech76','gmcctech@gmail.com','Gary McCormack','OPW, M&E Section<br>Jonathon Swift Street','Trim','Meath','IRELAND','046','012993411','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 21:40:23',0,NULL,3,1,3,1,'RA184582654CN\r ','gmcctech76\rHBPH003'),(12158,768114184011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','bimbat','saltu@yahoo.com','Sam Tucci','2566 Provence','Saint-Lazare','QC','CANADA','J7T2C1','(450) 424-3742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 21:43:05',0,NULL,3,1,2,1,'\\  ','bimbat'),(12159,852043111012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','suziesmith37','suziesmith37@googlemail.com','Su Robertson','10 Highland Park','Redruth','Cornwall','UNITED KINGDOM','TR15 2EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 21:57:20',0,NULL,3,1,3,1,'RA184582699CN\r ','suziesmith37\rMOLO009\r旧的'),(12160,575074983004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','esedona','ebay@esedona.net','Jeff Dissinger','1785 W State Route 89A<br>Ste 1D','Sedona','AZ','UNITED STATES','86336-5559','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 22:05:36',0,NULL,3,1,1,1,'\\  ','esedona'),(12161,575075392004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','dtrt1970','doubleb@sannet.ne.jp','Hiromitsu Takase','nisiwaki450','ninsiwaki','Hyogo','JAPAN','677-0015','0795-25-2500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 22:07:30',0,NULL,3,1,3,1,'RA184582606CN\r ','dtrt1970\rWLAP008'),(12162,622600733013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','aadvincol','vincentblans@ziggo.nl','Vincent Blans','Loosduinse Hoofdstraat 1152','\'S-GRAVENHAGE','','NETHERLANDS','2552AT','+31644902490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 22:15:06',0,NULL,3,1,3,1,'RA184582711CN\r ','aadvincol\rGLOT001*3\r兼容型3D眼镜 通用型'),(12163,569597964003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','jameswang200910','jameswang@sinocare.ca','Yuan (James) Wang','112 Northview Ave.','Dollard des ormeaux','QC','CANADA','H9B 3J6','(514) 816-0892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 22:24:33',0,NULL,3,1,3,1,'RA184582549CN\r ','jameswang200910\rHSPL009'),(12164,768134216011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',119.98,'eastar4','ctav4092','tavares.carlos.9@gmail.com','Carlos Tavares','5403 Crowchild Trail NW','Calgary`','AB','CANADA','T3B 4Z1','(587) 899-3103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 22:44:16',0,NULL,3,1,3,1,'RA184582416CN ','ctav4092\rOTSO004\r新地址\rcarlos tavares\rc/o chili club Thai house\r5403 crowchild trail nw\rCalgary ab\rt3b 4z1 Canada\r587 899 3103\r\r'),(12165,768135513011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','mani005','lakhbir.shergill@gmail.com','Manvir Shergill','3 Premier Ave<br>South Morang','Melbourne','Victoria','AUSTRALIA','3752','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 22:49:58',0,NULL,3,1,2,1,'\\  ','mani005'),(12166,768143202011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','coolingcoil','gliu1978@hotmail.com','zhang, qian ','2048 Crab Apple Cir','WEST RICHLAND','WA','UNITED STATES','99353-5090','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 23:18:32',0,NULL,3,1,1,1,'\\  ','coolingcoil'),(12167,625348804013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','ns00h','nathan@awh.com.au','Nathan Simpson','AWH Pty Ltd<br>250 Forest Road','Lara','Victoria','AUSTRALIA','3212','0417317411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 23:44:20',0,NULL,3,1,3,1,'RA184582552CN\r ','ns00h\rOTRA003'),(12168,852079678012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','aliriyaz-2008','aliriyaz@aliriyaz.ws','ali riyaz','M. Goldenbones<br>Javaahiru magu','male\'','male\'','MALDIVES','20-02','00960 7900385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 23:58:16',0,NULL,3,1,3,1,'RA184582495CN ','aliriyaz-2008\rOTGR001+OTGR002'),(12169,849931498012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','alexandranorton','alexnorton88@gmail.com','Alexandra Norton','21 Sandpiper Place<br>Kenthurst','Sydney','New South Wales','AUSTRALIA','2156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 00:14:31',0,NULL,3,1,3,1,'RA184582800CN\r ','alexandranorton\rUM00013+UM00006\r蕾丝蝴蝶结伞 \r黑色的\r再发一把草莓伞 '),(12170,624128929013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','alexandranorton','alexnorton88@gmail.com','Alexandra Norton','21 Sandpiper Place<br>Kenthurst','Sydney','New South Wales','AUSTRALIA','2156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 00:17:17',0,NULL,3,1,17,0,NULL,'alexandranorton'),(12171,852105986012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','456193','jonas_erbs@hotmail.com','Jonas Erbs Piazza','Bairro Souza Cruz<br>Rua José Erbs \"28\"','Brusque','Santa Catarina','BRAZIL','88354-473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 01:44:09',0,NULL,3,1,2,1,'\\ ','456193'),(12172,852114826012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',28.89,'eastar4','veroskut','jamie_howlett@hotmail.com','James Howlett','3 Gisele Drive','Hamilton','ON','CANADA','L9B 2M5','(905) 977-4858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 02:04:00',0,NULL,3,1,2,1,'\\ ','veroskut\r再发一个New Logitech Harmony Rechargeable battery 890 880 950mA\r'),(12173,768186630011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',44.89,'eastar4','zoltec_qc','zoltec.qc@gmail.com','Ricky Gamache','14E rue<br>87 (App. 1)','Rouyn-Noranda','QC','CANADA','j9x2h9','(819) 948-2854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 02:16:03',0,NULL,3,1,3,1,'RA184582742CN ','zoltec_qc\rGLOT004\r兼容型3D眼镜  samsung 专用'),(12174,852150937012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','wg4711','wg4711@arcor.de','Wolfgang Garske','Helene-Engelbrecht-Str. 85','Braunschweig','','GERMANY','38124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 04:43:09',0,NULL,3,1,2,1,'\\ ','wg4711'),(12175,768216649011,320756093124,'New Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','coklat2010','nyomansukarna55@yahoo.com','nyoman sukarna','jln pratama gang nusa 11 c','nusa dua','bali','INDONESIA','80363','081805469737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 04:43:15',0,NULL,3,1,3,1,'RA184582844CN','coklat2010\r银色的\rMOLO008'),(12176,569665039003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','houssam65','houssamh@eim.ae','Houssam Halimeh','Al Cournich<br>ADGAS - Projects Div.','Abu Dhabi','Abu Dhabi','UNITED ARAB EMIRATES','3500','00971505311956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 05:28:54',0,NULL,3,1,3,1,'RA184582858CN\r ','houssam65\rHSNO004'),(12177,625650290013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','karinenok','baeva.elena@mail.ru','Sergey Bayev','R.Luxemburg st. 77-144','Kirov','RU','RUSSIAN FEDERATION','610005','+79128204785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 06:53:41',0,NULL,3,1,3,1,'RA184582795CN\r ','karinenok\rOTRA003'),(12178,768244986011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',59.99,'eastar4','bcc142','juwnay@yahoo.com','Son Damrongkittiwej','37/75 serivillage2 srinakarinroad nongbone pravaj Bangkok 10250','Bangkok','Thailand','THAILAND','10250','0814499958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 07:14:15',0,NULL,3,1,3,1,'RA184582760CN\r ','bcc142\rOTSO004'),(12179,852178012012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','kai1000baby','dennyo1@fsmail.net','denny oloughlin','1 railway square','brentwood','Essex','UNITED KINGDOM','cm14 4ln','07515436950','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 06:58:16',0,NULL,3,1,3,1,'RA184582773CN\r ','kai1000baby\rGLOT005*2'),(12180,625492259013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',15.95,'eastar4','mete_1907','skiptomylou08@gmail.com','Mete Kaymak','SSK Bloklari 3.Blok , No:4<br>Lalegul','ANKARA','Yenimahalle','TURKEY','06200','05364178334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 07:16:18',0,NULL,3,1,3,1,'RA184582787CN\r ','mete_1907\rCACN004\r客户打了3美金挂号'),(12181,573114542004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',13,'cnfaner','dda_walker','np.walker@hotmail.com','Nick Walker','21 Glenside St','Avondale Heights','Victoria','AUSTRALIA','3034','0412769303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 08:18:23',0,NULL,3,1,3,1,'RA184582835CN ','dda_walker\rCACN004'),(12182,768277991011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',21.58,'eastar4','unlykneother714','unlykneother1@gmail.com','vance mesa','14122 Denise Dr','westminster','CA','UNITED STATES','92683-3713','(714) 460-3410','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 09:38:53',0,NULL,3,1,1,1,'\\  ','unlykneother714'),(12183,847557909012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.39,'eastar4','netalbernwern','steffenbieber@freenet.de','Bieber, Steffen','Ober der Kirch 6','Sinn','','GERMANY','35764','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 09:51:28',0,NULL,3,1,2,1,'\\  ','netalbernwern\r欧标'),(12184,727453153001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',16,'buysia','nzcanucks','imb4u1@hotmail.com','Jayesh Solanki','9 Hogarth Rise<br>West Harbour','Auckland','','NEW ZEALAND','0618','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 10:15:10',0,NULL,3,1,3,1,'RA184583045CN ','nzcanucks\rBR3D008'),(12185,768309569011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.5,'eastar4uk','pedgaard','povl@odgaard.be','Jonas Hougaard','Skovtoften 42','Ryomgaard','.','DENMARK','8550','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 11:39:44',0,NULL,3,1,2,1,'\\  ','pedgaard\r微软的'),(12186,852262607012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.8,'eastar4uk','wei803','weiwei803@hotmail.com','Ng Kan Wei','114, Jalan 19,<br>Kampung Sri Indah A,','Sungai Buloh','Selangor','MALAYSIA','47000','0126979362','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 12:15:00',0,NULL,3,1,3,1,'RA184582861CN\r ','wei803\rWLAP002'),(12187,768322973011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.99,'eastar4uk','alfa156silver','dkny_flyguy@hotmail.com','Darren Knowles','3 Rossington Drive<br>Littleover','Derby','Derbyshire','UNITED KINGDOM','DE23 3UP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 12:22:49',0,NULL,3,1,3,1,'RA184583005CN\r ','alfa156silver\rHBPH002'),(12188,852266378012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','viniciushideki','vhideki@hotmail.com','hideki otsuki','Rua antonio guilherme do nascimento<br>n180 apt201 blc D Jardim Camburi','vitoria','Espirito Santo','BRAZIL','29090570','(5527) 3337 8426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:27:19',0,NULL,3,1,2,1,'\\  ','viniciushideki'),(12189,768333227011,320730083567,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',9.99,'eastar4uk','farkyeah','briannewton@westnet.com.au','Brian M Newton','72 15th street','Home Hill','Queensland','AUSTRALIA','4806','0408822857','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 12:56:28',0,NULL,3,1,2,1,'\\  ','farkyeah'),(12190,852293035012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','hmgodinho','henrique.godinho@gmail.com','Henrique Godinho','Rua 612<br>Quadra 570 Lote 01 Nº 449 Setor Aeroviário','Goiânia','Goiás','BRAZIL','74435290','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 13:41:59',0,NULL,3,1,3,1,'RA184583028CN\r ','hmgodinho\rRCLO006'),(12191,625727295013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','graphitexp','huadex@gmail.com','Bob Goh','M+W Singapore Pte. Ltd<br>16 International Business Park','default','','SINGAPORE','609929','6596667241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 13:47:23',0,NULL,3,1,3,1,'RA184582963CN\r ','graphitexp\rCASS003'),(12192,575230815004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','cutts378','cuttsjohn@yahoo.co.uk','John Cutts','AFTC Rafo Seeb<br>P.O.Box 732','muscat','','OMAN','111','0096824488462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 13:53:03',0,NULL,3,1,3,1,'RA184582950CN\r ','cutts378\rBALO007'),(12193,852316743012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','mac-bonsai','kekax@hotmail.com','Tomaz Matevljic','Neubergerjeva 25','Ljubljana','','SLOVENIA','1000','00386 51421701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 14:48:36',0,NULL,3,1,2,1,'\\  ','mac-bonsai'),(12194,569764494003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',31.98,'cnfaner','rezapd1001','rezapd@yahoo.com','Reza Pourassad','Sandhamnsg 10 2tr','Stockhom','','SWEDEN','115 40','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 15:09:58',0,NULL,3,1,3,1,'RA184582994CN ','rezapd1001\rHSMO019\r欧标'),(12195,768388329011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',60.49,'eastar4','valdimar72','vshkuratov@gmail.com','Vladimir Shkuratov','ul. Melnikayte d.103 kv.17','Tyumen','Tyumen region','RUSSIAN FEDERATION','625026','+79519889380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 15:36:37',0,NULL,3,1,3,1,'RA184583014CN\r ','valdimar72\rWWSI006+ANCN001'),(12196,625760836013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','0965751413','grebenyukkostya@gmail.com','Konstantin Grebenyuk','Natalii Uzhviy 82/72','Kharkiv','Kharkiv region','UKRAINE','61195','0936779112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 15:52:50',0,NULL,3,1,3,1,'RA184582901CN\r ','0965751413\rOTRA003'),(12197,768406686011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','bob151264','boabfraser@hotmail.com','robert fraser','8 balmossie brae<br>broughty ferry','dundee','Dundee (City of)','UNITED KINGDOM','dd5 3ga','01382739939','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 16:22:54',0,NULL,3,1,3,1,'RA184582827CN\r ','bob151264\rGLOT001\r兼容型3D眼镜 通用型'),(12198,622482129013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','skydima','dima39@yahoo.com','Dmytro Moshchynskyy','Chernyshevskogo<br>11a/24','Dnepropetrovsk','','UKRAINE','49005','0964814058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 16:24:32',0,NULL,3,1,2,1,'\\  ','skydima'),(12199,852358817012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','herve418','renaud.veilleux@sg.cgocable.ca','Renaud Veilleux','920-143ième rue est','ST-GEORGES  Bce','QC','CANADA','G5Y2K8','(418) 228-5987','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 16:31:06',0,NULL,3,1,3,1,'RA184583059CN\r ','herve418\rRCLO006'),(12200,625773011013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','maximnovikov1982','maxim.novikov@inbox.ru','Максим Новиков','Московская область Подольский район с. Ознобишино д. 91','Подольский район с. Ознобишино','','RUSSIAN FEDERATION','142144','+79197775575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 16:39:58',0,NULL,3,1,3,1,'RA184582946CN\r ','maximnovikov1982\rWWOT001+ANCN001'),(12201,569789353003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.9,'cnfaner','mariogonram','sh.mario@teleline.es','Enrique Polo Gómez','C/Ocaña, 20, 6ºD','Madrid','Madrid','SPAIN','28047','609202707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 16:46:40',0,NULL,3,1,3,1,'RA184582932CN ','mariogonram\rWWOT003'),(12202,575278114004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23.26,'cnfaner','pcell65','pcell65@msn.com','Jeff Eddins','4141 Wagon Trail Ave','Las Vegas','NV','UNITED STATES','89118-4426','(702) 528-3467','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-22 17:05:40',0,NULL,3,1,1,1,'\\  ','pcell65'),(12203,852375884012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','belov.sergey','belov.sergeiy@gmail.com','Sergey Belov','Karl  Marx Street  32, 50','Severodvinsk','Arkhangelsk region','RUSSIAN FEDERATION','164500','7-911-870-9225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 17:10:35',0,NULL,3,1,2,1,'\\  ','belov.sergey'),(12204,768442380011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.9,'eastar4','kajmann','ntrinschek@web.de','Norbert Trinschek','Beverfördering 7','Hamm','','GERMANY','59071','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 17:44:01',0,NULL,3,1,2,1,'\\  ','kajmann\racer 4pin1.25 15cm '),(12205,768443772011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',3,'CASS002',24.87,'eastar4','klingor.cisco','klingor@btinternet.com','Colin Gorrie','18 The Paddock<br>Balcarres Road','Musselburgh','East Lothian','UNITED KINGDOM','EH21 7SP','01316655669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 17:47:52',0,NULL,3,1,2,1,'\\  ','klingor.cisco\r'),(12206,569692526003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.9,'cnfaner','paveld09','n.dreadlock@gmail.com','Pavel Dotsulenko','Bazarnaya 91, 9','Odessa','Odesskaya','UKRAINE','65020','+380503920797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 18:17:50',0,NULL,3,1,3,1,'RA184582915CN\r ','paveld09\rWWSI002+ANCN001'),(12207,852418049012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','vigilante1976','supervilain@hotmail.com','Victor-Anthony Masson','9030 Emile-Legault','Montreal','QC','CANADA','H1K4Y5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 18:26:31',0,NULL,3,1,2,1,'\\  ','vigilante1976'),(12208,768472943011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','ladieskingme20','drubaine@gmail.com','Dusty Rubaine','1305 Amsterdam Ave<br>Apt 6I','New York','NY','UNITED STATES','10027-4234','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 18:44:00',0,NULL,3,1,1,1,'\\  ','ladieskingme20'),(12209,569833842003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','larryb661','larryb1767@bellsouth.net','Larry Brown','661 Campbell Rd','Fort Pierce','FL','UNITED STATES','34945-2106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-22 19:04:57',0,NULL,3,1,1,1,'、 ','larryb661'),(12210,575316854004,140583345997,'GENUINE Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','dimonbuk','dimabuk@yandex.ru','DZMITRY BUKATSICH','Zareche, Yubileynaya street, 6','Smolevichi, Belarus','','RUSSIAN FEDERATION','222220','375292566082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 19:10:47',0,NULL,3,1,3,1,'RA184582875CN\r ','dimonbuk\rHSPL011\r欧标'),(12211,852444870012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.9,'eastar4','gourby22','djzed@orange.fr','Khafi Isabelle','21, kermouchard','treglamus','Bretagne','FRANCE','22540','0629886443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 19:11:50',0,NULL,3,1,2,1,'\\  ','gourby22\racer 4pin1.25 8cm'),(12212,768490995011,320441567780,'2.1 Acer Aspire 5720 5720G  Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','dxtune','fredrick.wtf@gmail.com','Fredrick Myrvoll','Breidablikk 30','Bergen','Hauglandshella','NORWAY','5310','41575400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 19:18:28',0,NULL,3,1,2,1,'\\  ','dxtune\racer 8pin1.00 15cm'),(12213,852448681012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',37.85,'eastar4','snick401','max.pcrepair@gmail.com','Max Bopp','100 Marlborough st','East Greenwich','RI','UNITED STATES','02818-3783','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 19:18:48',0,NULL,3,0,1,1,'\\  ','snick401'),(12214,727654328001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','singhengineer','gobinder@gmail.com','Gobinder S Waraich','9135 Judicial Dr<br>Apt 3107','San Diego','CA','UNITED STATES','92122-4654','(603) 864-9400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 19:35:07',0,NULL,3,1,1,1,'\\  ','singhengineer'),(12215,852459899012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','theleadbasher','leadsheetspecialist-ebay@yahoo.co.uk','Adrian Trevitt','100 Turning Lane<br>Scarisbrick','Southport','Merseyside','UNITED KINGDOM','PR8 5HZ','01704535164','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 19:35:33',0,NULL,3,1,3,1,'RA184582892CN\r ','theleadbasher\rOTCN003'),(12216,625846824013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',16.99,'eastar4','sleepylechat','marc.vanbelle@skynet.be','marc vanbelle','rue des tulipes n°24','enghien','','BELGIUM','7850','32474862305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 19:56:28',0,NULL,3,1,2,1,'\\  ','sleepylechat'),(12217,569860504003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','richardjp1945','richardjp@comcast.net','RICHARD J. PULLEY','14838 38th Ave S','TUKWILA','WA','UNITED STATES','98168-4306','(206) 248-6005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-22 20:23:38',0,NULL,3,1,1,1,'\\ ','richardjp1945'),(12218,852488552012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','darksmagician','darksmagician@hotmail.com','Jing Qiang Wu','120 Elizabeth St Apt 4A','New York','NY','UNITED STATES','10013-4284','(646) 255-6570','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 20:29:39',0,NULL,3,1,1,1,'\\  ','darksmagician'),(12219,768528638011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','rask0lnik0v','danieltonkin@hotmail.com','mieke linssen','47 Plum Lane','Plumstead','London','UNITED KINGDOM','SE18 3AG','07838116523','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 20:31:53',0,NULL,3,1,3,1,'RA184582889CN ','rask0lnik0v\rHSUE001'),(12220,852510803012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','ujdmar','marin.ujdur@gmail.com','Marin Ujdur','Pilarova 11','Zagreb','Zagreb','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 21:14:21',0,NULL,3,1,2,1,'\\  ','ujdmar'),(12221,768550478011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','mtbzone.com','info@mtbzone.com','Mike Albright','19590 Tokatee Lake Ct','Bend','OR','UNITED STATES','97702-9157','(541) 317-5638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 21:19:55',0,NULL,3,1,1,1,'\\  ','mtbzone.com'),(12222,852519779012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','mike500uk','mike500uk@tiscali.co.uk','michael nash','7 creighton road','southampton','Hampshire','UNITED KINGDOM','so15 4jf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 21:36:05',0,NULL,3,1,3,1,'RA184582813CN\r ','mike500uk\rHSJA010\r英标'),(12223,710205558008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','tonydoolz','q1221886@mail.connect.usq.edu.au','Anthony Dooley','Super Cheap Auto Support Office<br>751 Gympie Road','Lawnton','Queensland','AUSTRALIA','4501','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-22 21:55:29',0,NULL,3,1,3,1,'RA184582929CN\r ','tonydoolz\rRELO002'),(12224,763774200011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','robash02','edwintorres4@aol.com','Anabel Castro','PO Box 3434','Arecibo','PR','PUERTO RICO','00613-3434','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 21:51:07',0,NULL,3,1,1,1,'\\  ','robash02'),(12225,569887475003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','hazmo77','rgroceman@haz-matresponse.com','Rex Groceman','3720 S Emery St','Independence','MO','UNITED STATES','64055-3448','(816) 836-5834','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-22 22:10:04',0,NULL,3,1,1,1,'、 ','hazmo77'),(12226,625358233013,230393140134,'2.1 Acer Aspire 5735 5735Z Bluetooth Module EDR +cable',1,'BTAC2105',12.4,'eastar4','jonrile','j.dear@exemail.com.au','Jon Dear','1 the crest cove','valentine','New South Wales','AUSTRALIA','2280','0249659564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 22:48:11',0,NULL,3,1,2,1,'\\  ','jonrile\racer 4pin1.25 8cm'),(12227,852547957012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','chrishobbsz','hobbsz@hotmail.co.uk','Chris Hobbs','57 Derham Park','Yatton','Bristol','UNITED KINGDOM','BS49 4EA','01934832940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 23:00:28',0,NULL,3,1,3,1,'RA184582977CN\r ','chrishobbsz\rWLAP008'),(12228,727733110001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','justinslayne','justinslayne@cox.net','Tyre Davis','7815 S 48th Ln','Laveen','AZ','UNITED STATES','85339-7338','(602) 535-5181','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-22 23:13:47',0,NULL,3,1,1,1,'\\  ','justinslayne'),(12229,768586684011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','afransis','afransis@gmail.com','Amir Fransis','Hagefen 16','Pardesiya','Pardesiya , box 345','ISRAEL','42815','+972 98945355 , +972 525688833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 23:15:49',0,NULL,3,1,2,1,'\\  ','afransis'),(12230,569907821003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','parafun1234','parafun@triad.rr.com','Mark Bouldin','4155 Lambeth Mill Rd','Siler City','NC','UNITED STATES','27344-8414','(336) 879-1791','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-22 23:55:34',0,NULL,3,1,1,1,'\\  ','parafun1234'),(12231,575398347004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','e-usimage','usaimage@yahoo.com','Ivan Radic','300 California Ave<br>Apt 32','Santa Monica','CA','UNITED STATES','90403-5022','(310) 590-5170','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 00:29:03',0,NULL,3,1,1,1,'\\ ','e-usimage'),(12232,768607126011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',6,'CASS001',49.74,'eastar4','tracidtrax','konstantin@internode.on.net','Konstantin Miklos','37 Hennessy Way','Dandenong North','Victoria','AUSTRALIA','3175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 00:37:00',0,NULL,3,1,3,1,'RA184582985CN\r ','tracidtrax\rCASS001'),(12233,575403783004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','schnellbahn','druark@pobox.com','Dylan Ruark','21329 SW Sandra Ln','Aloha','OR','UNITED STATES','97006-6800','(503) 395-8681','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 00:59:47',0,NULL,3,1,1,1,'\\  ','schnellbahn'),(12234,0,120782239457,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.5,'buysia','marceloalejandro8','chelomd_p@hotmail.com','marcelo alejandro  parejo','lopez de vaga 4 bloq 6 portal b puerta o6<br>(urb el jable)','morro jable','Canarias','SPAIN','35625','630253207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 01:20:53',0,NULL,3,1,3,1,'RA184583031CN\r ','marceloalejandro8\rBR3D007'),(12235,768619923011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','jpb613','jpbialke@yahoo.com','Joseph P Bialke','4236 E 119th Pl<br>Apt B','Thornton','CO','UNITED STATES','80233-6312','(303) 941-6504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 01:24:45',0,NULL,3,1,1,1,'\\  ','jpb613'),(12236,569924643003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',15.4,'cnfaner','8007philip','logginireland@msn.com','philip ireland','994 fruitdale dr','grants pass','OR','UNITED STATES','97527','(541) 476-8327','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 01:33:31',0,NULL,3,1,1,1,'\\  ','8007philip'),(12237,625936763013,230658777210,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',89.99,'eastar4','nan1don2','nanzak45@msn.com','Donald Kasprzak','4955 Helmo Ave N','Oakdale','MN','UNITED STATES','55128-2207','(651) 770-3649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 02:16:10',0,NULL,3,1,1,1,'\\ ','nan1don2'),(12238,768633143011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',3,'TRMX002',22.71,'eastar4','phallicobject','fvheiser@comcast.net','Frank Heiser','3 Wilmarth St','Attleboro','MA','UNITED STATES','02703','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 02:25:35',0,NULL,3,0,1,1,'\\  ','phallicobject\r已入库'),(12239,569946262003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','sframe2007','sharon_frame@telstra.com','Sharon Frame','4R Jandra Rd<br>P.O. Box 2947','Dubbo','New South Wales','AUSTRALIA','2830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 03:56:12',0,NULL,3,1,3,1,'RA184583102CN ','sframe2007\rOMHJ001'),(12240,727796065001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','gladiator88','edwardy88@yahoo.com','Edward Yip','10 Sunny Glenway Apt 1104','Toronto','ON','CANADA','M3C 2Z3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 04:03:57',0,NULL,3,1,3,1,'RA184583093CN\r ','gladiator88\rBR3D005'),(12241,768628541011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.99,'eastar4','nikyb','callfas1@telus.net','Derek Callfas','308 - 7600 Cottonwood Drive','Osoyoos','BC','CANADA','V0H1V3','(250) 495-0410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 04:33:58',0,NULL,3,1,2,1,'\\','nikyb'),(12242,575437433004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',19.9,'cnfaner','7zark7-sys64738','poke53281sys64738@gmail.com','Ken Kwasnicki','2829 Stephens Street','Vancouver','BC','CANADA','V6K 3X4','(604) 880-4821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 04:41:12',0,NULL,3,1,3,1,'RA184583080CN\r ','7zark7-sys64738\rOTGR001'),(12243,8881316754215164,111,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'',0,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334',NULL,NULL,NULL,'2011-09-23 05:03:35',0,NULL,3,1,2,1,'\\ ','补发的\r注意 只补发一个欧标转换头  不发耳机 '),(12244,575442095004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','469victor','leatherneck1754@hotmail.com','victor ramirez','1624 Boyd St','Dallas','TX','UNITED STATES','75224-1390','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 05:45:20',0,NULL,3,1,1,1,'、 ','469victor'),(12245,575305654004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',52.9,'cnfaner','anton516','ivanow@gmail.com','Sergei Komarov','5th Sokolinaya gora 20 bild. 2 ap. 39','Moscow','','RUSSIAN FEDERATION','105275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 05:53:58',0,NULL,3,1,3,1,'RA184583062CN ','anton516'),(12246,852650480012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','leefields51','lee.fields51@gmail.com','LISA SATTERFIELD','1774B Wells Rd','NORTONVILLE','KY','UNITED STATES','42442-9474','(270) 584-3312','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 06:01:07',0,NULL,3,1,1,1,'、 ','leefields51'),(12247,852655719012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','sirhumphrey','update@i-t-support.com','Winsock Network Services','5/37-39 Marshall Road','DUNDAS','New South Wales','AUSTRALIA','2117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 06:25:48',0,NULL,3,0,3,1,'RA184560937CN ','sirhumphrey  挑外包装有划痕的出'),(12248,625979510013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','albo_man','alvi.hirvela@gmail.com','Alvi Hirvelä','Lasinpuhaltajantie 7','Helsinki','','FINLAND','00750','358504876779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 07:14:27',0,NULL,3,1,3,1,'RA184583076CN ','albo_man'),(12249,768694151011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','cka3o4nuk666','ph@bk.ru','Pavel Strelnikov','Grajdanskiy st. 130-1-359','Saint-Petersburg','RU','RUSSIAN FEDERATION','195267','+79043334940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 07:46:36',0,NULL,3,1,2,1,'\\ ','cka3o4nuk666'),(12250,852673001012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','infomoviles','informaticaymoviles@gmail.com','DAVID GARCIA RODRIGUEZ','C  Seneca nº3, 1ºB','LOJA ( GRANADA )','Andalucía Ceuta y Melilla','SPAIN','18300','634447145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 07:47:06',0,NULL,3,1,2,1,'\\ ','infomoviles'),(12251,852680176012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',8.99,'eastar4uk','babsi.kl','babsi.kl@gmx.at','Barbara Kleiner','Alfred-Cossmanngasse 19','Graz','','AUSTRIA','8054','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 08:15:54',0,NULL,3,1,2,1,'\\ ','babsi.kl'),(12252,8881316766130799,111,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','captainmemphis','pullyoudown@gmail.com ','Mikhail Basamykin','Borisovskie Prudy st. 14/3 kv. 160','Moscow','','RUSSIA','115211','',NULL,NULL,NULL,'2011-09-23 08:22:10',0,NULL,3,1,3,1,'RA184560945CN ',' '),(12253,8881316768559237,111,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kasongene','stubbart@cox.net','Evan Stubbart','2925 E Warbler Rd','Gilbert ','AZ','UNITED STATES',' 85297-8147','',NULL,NULL,NULL,'2011-09-23 09:02:39',0,NULL,3,1,1,1,'、 ',' 系统漏单  自己录入的'),(12254,8881316769654780,111,'TDG-BR250',15,'OTSO004',888,'eastar4','yo.patel','yogesh.patel@y7mail.com','Yogesh Patel','P.O.Box 1276<br>Surrey Hills North LPO','Mont Albert','Victoria','AUSTRALIA','3127','0414490101',NULL,NULL,NULL,'2011-09-23 09:20:54',0,NULL,3,1,6,1,'EE495359857CN ','\r'),(12255,852697543012,220806848943,'Transparent Dome Rain Sun Umbrella with purple trim',1,'UMTR001',19.99,'eastar4','vitalich-nv','vboichuk@mail.ru','VITALIY BOYCHUK','Permyakova st., 82/1, room 36','Tyumen','Tyumenskay oblast\'','RUSSIAN FEDERATION','625016','79026220124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 09:23:10',0,NULL,3,1,2,1,'\\ ','vitalich-nv  紫色边的'),(12256,626001583013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',11.9,'eastar4','recellking','jperry583@hotmail.com','Jerry Perry','902 Silver Chase Dr','Choctaw','OK','UNITED STATES','73020-7176','(405) 306-2603','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 09:36:25',0,NULL,3,1,1,1,'\\ ','recellking 注意客户买了两个'),(12257,852705394012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',28.99,'eastar4','zlyuk','horbachevskyy@gmail.com','Iurii Gorbachevskyi','O. Davydova blvd., 14, ap. 34','Kyiv','','UKRAINE','02147','0974944099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 10:22:50',0,NULL,3,1,2,1,' \\','zlyuk'),(12258,768737189011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','mult85','mult-vova@mail.ru','Vladimir Fedotov','ul. Parkovaja 16-ja d.49/1 kv.9','Moscow','Moscow','RUSSIAN FEDERATION','105425','8-926-888-03-46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 10:44:25',0,NULL,3,0,3,1,'RA184583544CN\r ','mult85 KBNO001'),(12259,626022168013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','shai_mic','shai_mic@walla.com','shai michael','9/18 zichron yaakov st.','petach tikva','israel','ISRAEL','49723','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 11:17:59',0,NULL,3,1,2,1,'、 ','shai_mic'),(12260,626024978013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','mctoee','sdemk1@yandex.ru','Svetlana Demkina','Entuziastov<br>5-99','Dubna','Moscow region','RUSSIAN FEDERATION','141980','+7 (925) 801-14-64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 11:30:22',0,NULL,3,1,2,1,'、 ','mctoee'),(12261,768748607011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','avivm9','aviv69@gmail.com','Zohar itach','Ha\'shaked 6','Kiryat Ekron','','ISRAEL','76920','0542595989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 11:30:25',0,NULL,3,1,2,1,'\\ ','avivm9'),(12262,626028025013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','byerevgeniya','kz.dim@mail.ru','YEVGENIYA LEZHANINA','ulica Gorkogo, dom 15/A, kvartira 70','Kokshetau','KZ','KAZAKHSTAN','020006','77162313141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 11:45:21',0,NULL,3,1,2,1,'、 ','byerevgeniya  \r\r'),(12263,768758478011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','conveytm','conveyt@yahoo.com','Thomas Convey','295 Reist St','Amherst','NY','UNITED STATES','14221-5341','(716) 631-8162','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 11:58:15',0,NULL,3,1,1,1,'\\ ','conveytm'),(12264,768765391011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','tribb2010','tribb07@hotmail.co.uk','Grace Carpenter','21 May Terrace<br>St Judes','Plymouth','Devon','UNITED KINGDOM','PL4 8PP','01159630328','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-23 12:20:46',0,NULL,3,1,3,1,'RA184583147CN\r ','tribb2010\rRELO003'),(12265,575515543004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',26.99,'cnfaner','esalesconsignment','monagarland@gmail.com','eSales Consignment LLC','2780 Achillea Way SW','Marietta','GA','UNITED STATES','30064-2598','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 13:01:44',0,NULL,3,1,1,1,'\\ ','esalesconsignment'),(12266,852764479012,220783475162,'New genuine Grohe Shower head holder made in Germany',1,'OTGR003',21.99,'eastar4','min_isis','md_tr@msn.com','cuneyt ozcan','Turan Cetin TUP bebek merkezi 100. yil mh. 85017 sk No: 9/A','Adana','Cukurova','TURKEY','01360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:03:14',0,NULL,3,1,2,1,'\\ ','min_isis'),(12267,626047309013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.99,'eastar4','seymour777','cvm77@juno.com','Vicky Moore','4215 S Forest Meadow Dr','Spokane Valley','WA','UNITED STATES','99206-9643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 13:11:48',0,NULL,3,1,1,1,'\\ ','seymour777'),(12268,848392884012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','j_amend','j.amend@gmail.com','Jonathan Amend','4220 Rue Brebeuf Apt. 15','Montreal','QC','CANADA','H2J3K7','(514) 708-8433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:25:07',0,NULL,3,1,2,1,'、 ','j_amend'),(12269,626053823013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','acasha_81','supersaio@hotmail.com','saioa lekue garcia','c/ resamano, nº14 1ºB','Castro Urdiales','Cantabria','SPAIN','39700','655708519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:39:21',0,NULL,3,1,2,1,'、 ','acasha_81  cat 图案'),(12270,626051124013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',15.6,'eastar4','zanechua','zain.chua@gmail.com','Zane Jocelyn Chua','Block 726 Jurong West Avenue 5<br>Floor 6 Unit Number 242','default','','SINGAPORE','640726','+65 8182 4533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:26:51',0,NULL,3,1,11,1,'、 ','zanechua\rWLAT008'),(12271,768788148011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','pilcallaclip','allan4817@mac.com','Allan Pilcher','47 Eaton Circle<br>Kirwan','Townsville','Queensland','AUSTRALIA','4817','070408002721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:47:44',0,NULL,3,1,2,1,'、 ','pilcallaclip'),(12272,575526393004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'cnfaner','hallswpl','biwb@op.pl','Witold Blaszczyk','Okoniowa 20 m6','Lodz','łódzkie','POLAND','91-498','42 2985433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:57:26',0,NULL,3,1,3,1,'RA184583867CN\r ','hallswpl\rRELO003'),(12273,768805549011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','graphitexp','huadex@gmail.com','Bob Goh','M+W Singapore Pte. Ltd<br>16 International Business Park','default','','SINGAPORE','609929','6596667241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 14:22:07',0,NULL,3,1,11,1,'、 ','graphitexp\rCASS002'),(12274,852795862012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','geofrancis2001','o.o.o.o@hotmail.co.uk','George Muirhead','10 newtonhead<br>girdle toll','irvine','North Ayrshire','UNITED KINGDOM','ka111pb','07882741198','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-23 14:34:54',0,NULL,3,1,3,1,'RA184583955CN\r ','geofrancis2001\rWLAP008'),(12275,852801012012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','liveonlocation','liveonlocation@gmail.com','Jason Denkers','8705 100 Ave','Fort Saskatchewan','AB','CANADA','T8L2Y6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 14:42:48',0,NULL,3,1,3,1,'RA184583663CN\r ','CRLO001+POLO001  liveonlocation 加两个兰电池 新的'),(12276,768812299011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','liveonlocation','liveonlocation@gmail.com','Jason Denkers','8705 100 Ave','Fort Saskatchewan','AB','CANADA','T8L2Y6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 14:43:29',0,NULL,8,1,17,0,NULL,'liveonlocation'),(12277,768820283011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','aviviani','arviviani@gmail.com','Anthony Viviani','4 Mingbool ave','St. Marys','South Australia','AUSTRALIA','5042','0421462048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 15:04:16',0,NULL,3,1,2,1,'\\ ','aviviani '),(12278,768843981011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','jerome.nichols','hickorydickables@gmail.com','Jerome Nichols','969 Washtenaw Rd<br>Apt 2 (Back Door)','Ypsilanti','MI','UNITED STATES','48197','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 16:07:08',0,NULL,3,1,1,1,'\\ ','jerome.nichols'),(12279,852845041012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','region140100','johnmerkov@gmail.com','Кучеренко Сергей','ул. Чугунова д.38 кв.52','Раменское','Московская область','RUSSIAN FEDERATION','140105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 16:46:54',0,NULL,3,1,2,1,'、 ','region140100'),(12280,852854410012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','birdyisme','ebay@stephaneguth.fr','guth stephane','53 rue marechal foch','Sarreguemines','Lorraine','FRANCE','57200','0671582395','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 16:50:27',0,NULL,3,1,3,1,'RA184583748CN\r ','birdyisme GLOT005'),(12281,626107903013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.99,'eastar4','mikegruben','mike.gruben27@gmail.com','michael gruben','3702 Parker Rd<br>Wylie, Texas 75098-7884','Wylie','TX','UNITED STATES','75098-7884','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 16:56:37',0,NULL,3,1,1,1,'\\ ','mikegruben'),(12282,852883479012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',63.98,'eastar4uk','myszy667','mattt667@o2.pl','Bogumila Myszka','Ivington<br>Ivingtonbury','Leominster','Herefordshire','UNITED KINGDOM','HR6 0JH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-23 17:50:31',0,NULL,3,1,3,1,'RA184583751CN\r ','myszy667 GLOT005'),(12283,626125251013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','smaugie','jbascom@mac.com','Jeremy Bascom','2363 Iroquois Ave<br>Unit A','Placentia','CA','UNITED STATES','92870-1655','(714) 606-1521','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 17:50:34',0,NULL,3,1,1,1,'\\ ','smaugie'),(12284,575492278004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','mes123sey','seymourme@comcast.net','marshall seymour','2003 Montezuma Dr','Colorado Springs','CO','UNITED STATES','80910-1515','(719) 579-8711','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 18:15:42',0,NULL,3,1,1,1,'\\ ','mes123sey'),(12285,626138139013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','alporus1','leo.rus@gmail.com','Alexey Popov','Proizvodstvennaya str, 4, 272','Moscow','RU','RUSSIAN FEDERATION','119619','+79154707924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 18:30:29',0,NULL,3,1,2,1,'、 ','alporus1'),(12286,852905157012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',1,'HSMO010',8.99,'eastar4uk','dobby5662','denise562cooper@btinternet.com','MRS D COOPER','12 FOLJAMBE STREET<br>THORNES','WAKEFIELD','WEST YORKSHIRE','UNITED KINGDOM','WF2 7QZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-23 18:32:28',0,NULL,3,1,3,1,'RA184583924CN\r ','HSMO010 dobby5662  英标头'),(12287,626151388013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.95,'eastar4','oopeteroo88','peterthedragon@hotmail.com','Peter Tran','Mårtensgatan 3','Mjölby','östergötland','SWEDEN','595 32','0736466892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 19:05:36',0,NULL,3,0,2,1,'、 ','oopeteroo88'),(12288,852928480012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','kathysmarshall','kathysmarshall@aol.com','Kathy Marshall','5570 N. Nithsdale Dr','Salisbury','MD','UNITED STATES','21801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 19:17:00',0,NULL,3,1,1,1,'\\ ','kathysmarshall'),(12289,570138482003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','nightwatch818','chavez.joshua@gmail.com','Joshua Chavez','13709 Algranti Ave','Sylmar','CA','UNITED STATES','91342-2606','(818) 581-9074','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 19:53:43',0,NULL,3,1,1,1,'\\ ','nightwatch818'),(12290,626182835013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','jjvahatiitto2009','jjvahatiitto@hotmail.com','Jari Vähätiitto','Metsätähdentie 2<br>60510 HYLLYKALLIO','SEINÄJOKI','FL','FINLAND','60510','+358407748500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 20:38:19',0,NULL,3,1,3,1,' RA184561138CN','jjvahatiitto2009\rGLOT001*2'),(12291,768982568011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','copierking','dlachn@comcast.net','Douglas Lachniet','20121 Camp Ganzer Ct','Chippewa Lake','MI','UNITED STATES','49320','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 21:07:44',0,NULL,3,1,1,1,'\\ ','copierking'),(12292,852995822012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','pmj1964','philip@pjc.eclipse.co.uk','Philip Joseph','The Carriage House<br>Castle Hill','Crowborough','East Sussex','UNITED KINGDOM','TN6 3RR','01892853086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 21:38:57',0,NULL,3,1,2,1,'、 ','pmj1964'),(12293,570173426003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','hlweissman','hweissman@juno.com','Herbert Weissman','2963 Autumnwood Trail','Apopka','FL','UNITED STATES','32703-4945','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 22:01:10',0,NULL,3,1,1,1,'\\ ','hlweissman'),(12294,769007202011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','parnivick','reidky@gmail.com','Kyle Reid','200 Waterfront Dr.','Winnipeg','MB','CANADA','R3B 3P1','(204) 294-0308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 22:25:42',0,NULL,3,1,2,1,'、 ','parnivick'),(12295,853035263012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','ramapo','ramapo2010@optonline.net','John Wrobel','35 Cherokee Trl','Oakland','NJ','UNITED STATES','07436-3011','(201) 337-6830','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 23:46:42',0,NULL,3,1,1,1,'、 ','ramapo'),(12296,769031689011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',92.99,'eastar4uk','enemixen','samir@namer.se','Samir Namer','Våglängdsgatan 67','Borås','Västra Götaland','SWEDEN','50741','+46 707 241164','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 23:57:14',0,NULL,3,1,3,1,'RA184583155CN ','enemixen GLOT005*3'),(12297,626234425013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','123milev','techo91@mail.bg','Stefan Milev','Verge De La Salut 12<br>fl. 1, ap. 4','Sant Feliu de Llobregat','Cataluña','SPAIN','08980','672662683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 00:28:13',0,NULL,3,1,2,1,'、 ','123milev'),(12298,570200582003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','onek10f7','bponek@gmail.com','Bruce P Onek','13611 Columbine Ave','Wellington','FL','UNITED STATES','33414','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-24 00:44:04',0,NULL,3,1,1,1,'\\ ','onek10f7'),(12299,769055012011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','pmgardin','poem.turner@gmail.com','Lynn Gardiner','8000 Merrimac Dr','Apex','NC','UNITED STATES','27539-7675','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 01:34:28',0,NULL,3,1,1,1,'\\ ','pmgardin'),(12300,769058327011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','rsm494','reddog27@cogeco.ca','Ronald MacDonald','58 Janlyn Crescent','Belleville','ON','CANADA','K8N 1L2','(613) 966-4630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 01:48:02',0,NULL,3,1,2,1,'、 ','rsm494'),(12301,853067314012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','bluebearsw','bluebearsw@yahoo.com','Leona Chang','1663 Bath Ave','Brooklyn','NY','UNITED STATES','11214-4509','(718) 256-4699','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 01:54:19',0,NULL,3,1,1,1,'\\ ','bluebearsw'),(12302,570212798003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','southbeachbody','buttman32@aol.com','Derrell Hutton','5048 Alencia Ct','delray beach','FL','UNITED STATES','33484','(561) 499-5566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-24 02:39:23',0,NULL,3,1,1,1,'\\ ','southbeachbody'),(12303,769071127011,320721807693,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','hjrker','heike216@hotmail.com','H. Ramsbottom','PO Box 43269','Casuarina','Northern Territory','AUSTRALIA','0811','0416062159','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 02:47:45',0,NULL,3,1,2,1,'、 ','hjrker  pink 粉红边'),(12304,769076032011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','prgv10','prgv@earthlink.net','Percy Garcia','6027 Amherst Ave','Springfield','VA','UNITED STATES','22150-3228','(407) 435-8461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 03:27:02',0,NULL,3,1,1,1,'\r\\ ','prgv10'),(12305,769082708011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','pjtmobiles','paul.thresh@gmail.com','Paul Thresh','421 Leeds Road','DEWSBURY','West Yorkshire','UNITED KINGDOM','WF12 7HL','07733229311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 03:46:27',0,NULL,3,1,2,1,'、 ','pjtmobiles'),(12306,769093108011,320441946476,'2.1 HP DV9500  Bluetooth Module  EDR+cable',1,'BTHP2111',12.4,'eastar4','smoothsurfer','emailbob53@yahoo.com','robert somma','1190 High Falls Rd','catskill','NY','UNITED STATES','12414-5675','(518) 678-3267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 04:46:57',0,NULL,3,1,1,1,'\\ ','smoothsurfer  \rHP 8pin 1.25 25cm '),(12307,575726803004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'cnfaner','07_riles','raypatriles@ozemail.com.au','Frederick Riles','15 Sovereign Mile<br>Sovereign Islands','Paradise Point','Queensland','AUSTRALIA','4216','0755296145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 05:03:42',0,NULL,3,1,3,1,'RA184583969CN ','07_riles OTGR001+OTGR002'),(12308,769110539011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','petrowiq','aserty789@gmail.com','Alexandr Perepelitsyn','Moskowskoe shosse, 36-42','Tosno','Leningradskaya obl RU','RUSSIAN FEDERATION','187000','79119758223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 06:34:24',0,NULL,3,1,2,1,'、 ','petrowiq'),(12309,853131095012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','yo4riv2010','yo4riv@yahoo.com','Dumitrascu George Teodor','Macedona nr.9 Bl.A10 ap.39 Micro16','Galati','Galati','ROMANIA','800449','+40722294683','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 07:07:18',0,NULL,3,1,2,1,'、 ','yo4riv2010 大遥控'),(12310,570248761003,130553147069,'New Jabra BT135 Bluetooth Wireless Headset BT 135',2,'HSJA007',29.6,'cnfaner','eyalshilon','shilon@bezeqint.net','Eyal Shilon','Shilon Zuckerstein<br>Azrieli Center 1, Round Tower, 19th Floor','Tel Aviv','Israel','ISRAEL','67021','+972-54-6138282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 07:08:23',0,NULL,3,1,2,1,'、 ','eyalshilon'),(12311,769122588011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.99,'eastar4','pauloneill1066','paulssatsumas@hotmail.co.uk','paul o\'neill','212 royle building<br>31 wenlock road','london','London','UNITED KINGDOM','n17sh','02076841107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 07:36:46',0,NULL,3,1,2,1,'、 ','pauloneill1066'),(12312,853143447012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','leeside0','a_m_a@btopenworld.com','Alex Marner','Leeside Tool Shop,<br>Burndell Road, Yapton','Nr. Arundel','West Sussex','UNITED KINGDOM','BN180HP','01243554056','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 07:56:00',0,NULL,3,1,3,1,'RA184583589CN\r ','OTCN004*10 leeside0'),(12313,8881316852428356,111,'New HP MCE Media Center Remote Control big',1,'',0,'eastar4uk','rhezzy','ri.heslop@btinternet.com','Richard Heslop','34 Grey Court','Wakefield','West Yorkshire','UNITED KINGDOM','WF1 3HL','01924825246',NULL,NULL,NULL,'2011-09-24 08:20:28',0,NULL,3,0,3,1,'RA184583938CN ','大遥控  补发 '),(12314,626309289013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','erikpoperik','ralf.rose@o2online.de','Ralf Rose','Gutenbergstraße 1','Göttingen','','GERMANY','37075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 08:42:46',0,NULL,3,1,2,1,'、 ','erikpoperik'),(12315,853158785012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'eastar4','pwner','donchan411@msn.com','Billy D. Clark III','616 91st Pl SW','Everett','WA','UNITED STATES','98204-2689','(425) 737-1500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 08:50:16',0,NULL,3,1,1,1,'\\ ','pwner'),(12316,853160992012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','jaxfiu','jansku@sonemar.fi','Janne Kollanus','Putkistonniementie 17','Lempäälä','','FINLAND','37500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 09:00:52',0,NULL,3,1,2,1,'、 ','jaxfiu'),(12317,728250210001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','pokiemonkarl','karlhunter@xtra.co.nz','Karl Hunter','884 Pataua South Road<br>RD1','Onerahi','Whangarei','NEW ZEALAND','0192','0274705018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 09:08:18',0,NULL,3,1,3,1,'RA184583725CN\r ','pokiemonkarl\rBR3D005'),(12318,853172494012,220747230858,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',14.95,'eastar4uk','bobsid1965','squires@squires65.wanadoo.co.uk','Bob Squires','1 Manor Farm Close<br>Bishopstoke','Eastleigh','Hampshire','UNITED KINGDOM','SO50 6LG','02380650538','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 09:36:49',0,NULL,3,1,3,1,'RA184583915CN\r ','bobsid1965  英标头\rHSMO016'),(12319,575775986004,140583345997,'GENUINE Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',65.98,'cnfaner','nailstudiosky','ronitbuskila@gmail.com','Yoram Buskila','Arnon 32','Kiryat Shmona','Israel','ISRAEL','11631','+972-54-6114488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 10:27:52',0,NULL,3,1,3,1,'RA184583703CN\r ','nailstudiosky\rHSPL011'),(12320,769190737011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','rich3310512','mybooks1@aol.com','ABSRIchard Romash','19 Fair St','Carmel','NY','UNITED STATES','10512-1325','(845) 228-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 11:35:38',0,NULL,3,1,1,1,'\\ ','rich3310512'),(12428,728621517001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',2,'HSJB001',21.98,'buysia','kevindavidson44','kevindavidson2011@yahoo.com','Kevin Davidson','1736 93 Avenue','Dawson Creek','BC','CANADA','V1G 1E6','(250) 719-6860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 03:38:22',0,NULL,3,1,3,1,'RA184583513CN ','kevindavidson44  黑色的\rHSJB001'),(12321,8881316865057130,111,'apple mouse',1,'MOAP001',0,'eastar4','anabel7777777','anabel7777777@hotmail.com','Anabel Debelak','67 Bungan head road','Newport  SYDNEY','NEW SOUTH WALES','AUSTRALIA','2106','',NULL,NULL,NULL,'2011-09-24 11:50:57',0,NULL,3,1,2,1,'、',' 补货 '),(12322,769215821011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','ckirouac','clermontkirouac@videotron.ca','Clermont Kirouac','6925 des Sittelles','Laval','QC','CANADA','H7L 4Y3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 12:50:48',0,NULL,3,1,3,1,'RA184583782CN\r ','ckirouac\rRCLO006'),(12323,626364007013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','eyalgro','eyal.grobak@gmail.com','Eyal Grobac','Kfar Gibton 2','Rehovot','Israel','ISRAEL','76910','972544803652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 12:57:25',0,NULL,3,1,3,1,'A184583677CN\r ','eyalgro\rMOSA005'),(12324,853253746012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',2,'HSMO017',17.98,'eastar4uk','jontycohn','jonathan.cohn@optusnet.com.au','Jonathan Cohn','14 seaflower Cres<br>Craigie','Perth','Western Australia','AUSTRALIA','6025','0403557951','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 13:33:38',0,NULL,3,1,3,1,'RA184583884CN ','jontycohn  澳标头\rHSMO017'),(12325,626379612013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','illetram','nandrem@msn.com','Nicholas Martelli','1609 Palm St','Reading','PA','UNITED STATES','19604-1731','(610) 374-0777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 13:57:38',0,NULL,3,1,1,1,'\\ ','illetram'),(12326,853267450012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*3',78.99,'eastar4uk','happyas_larry','larry.pearlman@btinternet.com','Larry Pearlman','15 Summerfield','Ashtead','Surrey','UNITED KINGDOM','KT21 2LF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 14:08:50',0,NULL,3,1,3,1,'RA184583765CN ','happyas_larry\rGLOT004*3'),(12327,769244952011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','alr243611','alr24362@gmail.com','alfredo morales','7212 1/2 S Broadway','los angeles','CA','UNITED STATES','90003-2030','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 14:12:33',0,NULL,3,1,1,1,'\\ ','alr243611'),(12328,769208542011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','luckymathilde','carolynfranco@comcast.net','carolyn franco','3600 Connecticut Ave NW<br>Apt 301','Washington','DC','UNITED STATES','20008-2432','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 14:18:08',0,NULL,3,1,1,1,'\\ ','luckymathilde'),(12329,769253841011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','h3h3548','hani3li@gmail.com','Hani Ali Hassan','House:1291 Road:1538 Block::815','Isa Town','','BAHRAIN','1291','97339084472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 14:31:47',0,NULL,3,1,2,1,'、 ','h3h3548'),(12330,853281556012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','yv1074','yv1227@gmail.com','Michele Anselmetti','7060 NW 52nd St<br>null','Miami','FL','UNITED STATES','33166-4845','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 14:42:45',0,NULL,3,1,1,1,'\\ ','yv1074'),(12331,728353751001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','timr1956','timrogers1956@yahoo.com','tim rogers','4842 cannon st','bakersfield','CA','UNITED STATES','93314-8603','(661) 565-5143','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 14:51:01',0,NULL,5,1,18,1,NULL,'timr1956'),(12332,728366761001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','anantha_kk','anantha_kk@yahoo.com','Anantha Krishna Karkala','60 Hamilton ave<br>Apt 4C','Staten Island','NY','UNITED STATES','10301-1851','(718) 207-4626','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 15:27:08',0,NULL,3,1,1,1,'\\ ','anantha_kk'),(12333,626406592013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','46ford','dpscurti@earthlink.net','Don Scurti','1323 S Golden Vista Dr','West Covina','CA','UNITED STATES','91791-3727','(626) 919-8120','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 15:30:54',0,NULL,3,1,1,1,'\\ ','46ford 草莓伞'),(12334,626406607013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','cassa9004','ck@newshop.no','Casper Knudsen','Sore Titlestad 47<br>Fana','Bergen','Hordaland','NORWAY','N-5243','0047 90048855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 15:31:23',0,NULL,3,1,2,1,'、 ','cassa9004'),(12335,853291481012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','sqgl','ebay_junk@jo.koan.net','Joe Stojsic','5 Oak St Ashfield','Sydney','New South Wales','AUSTRALIA','2131','61297992192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 15:33:58',0,NULL,3,1,2,1,'、 ','sqgl'),(12336,728380512001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',23.99,'buysia','jorwig280211zk','jorwig2802@aol.com','James F. Orwig','131 Eldred St','Williamsport','PA','UNITED STATES','17701-3433','(570) 244-7150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 15:59:49',0,NULL,3,1,1,1,'\\ ','jorwig280211zk'),(12337,769290102011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kgavand','kgavand@charter.net','Kimberly Gavin-Anderson','3 Lafayette Trl','Newtown','CT','UNITED STATES','06470','(203) 364-1820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 16:00:13',0,NULL,3,1,1,1,'\\ ','kgavand'),(12338,626416914013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','rottoddles','smith.partners@btconnect.com','todd smith','Flemings Farm<br>Flemings Farm Road','Eastwood','Essex','UNITED KINGDOM','ss9 5qt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 16:03:17',0,NULL,3,1,2,1,'、 ','rottoddles'),(12339,728386565001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','edj000','janecek@usa.com','Edward D Janecek','11201 Woodlake Dr','Kirtland','OH','UNITED STATES','44094','(440) 256-2509','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 16:14:23',0,NULL,3,1,1,1,'\\ ','edj000'),(12340,626097165013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',52.74,'eastar4','serpent_23','wsdicke@gmail.com','Vadim Dikke','apt. 103, bdg. 109/4, Chernykh St.','Tomsk','Tomsk area','RUSSIAN FEDERATION','634062','79016130778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 16:18:21',0,NULL,3,1,3,1,'RA184583734CN\r ','serpent_23\rCASS001'),(12341,567507731003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','bighairalicious101','bighairalicious@yahoo.com','Tracy Geniviva','1013 sunset blvd','Ellwood City','PA','UNITED STATES','16117-1461','(724) 630-6696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-24 16:21:25',0,NULL,3,1,1,1,'\\ ','bighairalicious101'),(12342,853341479012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','dicky1230_3','richardgreensmith@hotmail.co.uk','Richard Greensmith','County Supplies, Rolleston Drive<br>Arnold','Nottingham','Nottinghamshire','UNITED KINGDOM','NG5 7JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 16:47:37',0,NULL,3,1,3,1,'RA184583972CN ','dicky1230_3\rGLOT005*2'),(12343,853345687012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','motosucks','mail@stephen-walton.me.uk','STEPHEN WALTON','52 Edwin Street','Houghton-le-Spring','Tyne and Wear','UNITED KINGDOM','DH5 8AP','01915840199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 16:56:24',0,NULL,3,1,3,1,'RA184584006CN ','motosucks\rWLIN013'),(12344,769358195011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','garm1984','fmuebay@web.de','Frank Müller','Vogt-Dufner-Str. 28','Furtwangen','','GERMANY','78120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 18:22:44',0,NULL,3,1,2,1,'、 ','garm1984'),(12345,853394484012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',67.99,'eastar4uk','batcave84','batcave.rogers@gmail.com','David Rogers','24 thornbridge square','falkirk','Falkirk','UNITED KINGDOM','Fk2 9BA','01324623315','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 18:26:58',0,NULL,3,1,3,1,'RA184583535CN ','batcave84\rGLSG001*2'),(12346,575910215004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',2,'RELO003',23.96,'cnfaner','kaross88','eddix@inbox.lv','Edgars Kaross','Nicgales 64-108','Riga','','LATVIA','LV-1035','+37126265465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 18:50:52',0,NULL,3,1,3,1,'RA184583120CN\r ','kaross88\rRELO003'),(12347,626499994013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','aslansa','aslans@list.ru','Abdulkhanov','Verhnyaya Pervomayskaya str. 39-1','Moscow','Moscow','RUSSIAN FEDERATION','105264','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 19:58:59',0,NULL,3,1,2,1,'、 ','aslansa'),(12348,626519550013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','350-lt1','slammedlt1@shaw.ca','Mike DiGasparro','9238 99 Ave','Grande Prairie','AB','CANADA','T8V3X5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 21:01:09',0,NULL,3,1,2,1,'、 ','350-lt1'),(12349,853484070012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','neil.roehrborn','neil.roehrborn@gmail.com','Neil Roehrborn','1010 Waube Ln','Green Bay','WI','UNITED STATES','54304-5524','(920) 338-3442 ext.: 111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 21:24:27',0,NULL,3,1,1,1,'\\ ','neil.roehrborn'),(12350,853493150012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','robbybayrobby','robbypay@gmail.com','Beaumont Pierre - Robby','Rue du Moulin, 61','Mouchin','Picardie','FRANCE','59310','32474649748','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 21:46:13',0,NULL,3,1,2,1,'、 ','robbybayrobby'),(12351,626534182013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','inx22','inox202@hotmail.com','Damir Pehar','Kruzna 3','Zagreb','','CROATIA','10110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 21:55:40',0,NULL,3,1,2,1,'\\ ','inx22'),(12352,626546165013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','palinka101','ssugarman@shaw.ca','shelley sugarman','1760 east 2nd avenue','vancouver','BC','CANADA','v5n 1e2','(604) 671-0050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 22:48:07',0,NULL,3,1,2,1,'、 ','palinka101'),(12353,575975889004,140583345997,'GENUINE Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','m-lapointe-819','dancing_mimi@hotmail.com','Mireille Lapointe','698 rue saint-matthieu','sherbrooke','QC','CANADA','J1R 0T4','(819) 575-0902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 22:50:39',0,NULL,3,1,2,1,'、 ','m-lapointe-819'),(12354,626554178013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','ibsengomes','ibsenperdigao@gmail.com','Ibsen Perdigao','Rua Aldo Bonadei 265<br>Ap 301','Rio de Janeiro','Rio de Janeiro','BRAZIL','22621-160','(552) 124-9496 ext.: 39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 23:25:30',0,NULL,3,1,3,1,NULL,'ibsengomes\rMOSA004'),(12355,575986987004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',26.99,'cnfaner','cdevl','cdevlcdevl@verizon.net','Stanley Oygenblik','62 Congress Ct','Freehold','NJ','UNITED STATES','07728-1352','(732) 252-5869','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-24 23:52:11',0,NULL,3,1,1,1,'\\ ','cdevl'),(12356,728562506001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','jshivak','grimlock16@hotmail.com','joseph r shivak','43650 PECK WADSWORTH RD','WELLINGTON','OH','UNITED STATES','44090-9451','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 23:57:01',0,NULL,3,1,1,1,'\\ ','jshivak'),(12357,769492898011,320679575591,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',27.99,'eastar4uk','fishsoupisgood','ebay@madingley.org','James McKenzie','Citrix R<br>101 Science Park','CAMBRIDGE','Cambridgeshire','UNITED KINGDOM','CB4 0FY','01223225900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 00:01:16',0,NULL,3,1,3,1,'RA184583116CN\r ','WWOT001+ANCN001 fishsoupisgood  再发一个Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card ×1'),(12358,769497220011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.99,'eastar4','anhdalam2002','richienguyent@yahoo.com','RICHIE NGUYEN','8038 Garden Grove Blvd<br># A','GARDEN GROVE','CA','UNITED STATES','92844-1005','(714) 799-7760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 00:19:59',0,NULL,3,1,1,1,'\\ ','anhdalam2002'),(12359,728569970001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','rosswilbal','thebeloved1@msn.com','Thomas G Rose','7052 N Greenview Ave<br>Apt 2','Chicago','IL','UNITED STATES','60626-2832','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 00:28:55',0,NULL,3,1,1,1,']\\ ','rosswilbal'),(12360,769505202011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','goldenboy57','garylepp@shaw.ca','Gary Lepp','27013 26 Ave','Aldergrove','BC','CANADA','V4W3N6','(604) 607-0736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 00:52:20',0,NULL,3,1,2,1,'、 ','goldenboy57'),(12361,625707570013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','safsofi81','safsofi81@yahoo.com','mohamed hassan','204 endicott ave<br>apt 1','revere','MA','UNITED STATES','02151','(781) 854-7744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 01:12:55',0,NULL,3,1,1,1,'\\ ','safsofi81'),(12362,728585713001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','feltondevries','felton.martin@earthlink.net','Felton Martin','3630 Beatrice Cv','Geneva','FL','UNITED STATES','32732-9647','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 01:38:45',0,NULL,3,1,1,1,'\\ ','feltondevries'),(12363,728598262001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','blocksavitz','blocksavitz@verizon.net','SHARON R SAVITZ','5 Cobbler Ct','MARLTON','NJ','UNITED STATES','08053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 03:01:25',0,NULL,3,1,1,1,'\\ ','blocksavitz'),(12364,853581779012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','tennessee_tom_12','thomasliddell@aol.com','Tom  Liddell','150 Cedar Creek Dr','Franklin','TN','UNITED STATES','37067-4078','(615) 794-1188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 03:01:41',0,NULL,3,1,1,1,'\\ ','tennessee_tom_12'),(12365,626604225013,230649308783,'New Japan Gentleman business Stripe Sun Rain Umbrella',1,'UM00026',26.99,'eastar4','cinemalink','gregory@clink.com.au','Cinema Link','216 Victoria St','Beaconsfield','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 03:39:57',0,NULL,3,1,2,1,'、 ','cinemalink'),(12366,0,110747104886,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',32.25,'buysia','trekerdan','danfastwave@cox.net','daniel n moser','1440 S Citrus Ave','Escondido','CA','UNITED STATES','92027-4953','(760) 739-9878','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 04:36:18',0,NULL,3,1,1,1,'\\ ','trekerdan'),(12367,570536895003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','streetgill','streetgill.broncos@hotmail.com','jagmandip gill','7 Hybrid Court<br>Craigieburn','Melbourne','Victoria','AUSTRALIA','3064','0393081045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 04:39:22',0,NULL,3,1,3,1,'RA184583694CN\r ','streetgill  澳标头\rHSMO019'),(12368,853611643012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','afsharfarhad','afsharfarhad@hotmail.com','farhad afshar','714 Woodrow St<br>Apt 3','houston','TX','UNITED STATES','77006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 05:33:53',0,NULL,3,1,1,1,'\\ ','afsharfarhad'),(12369,626628223013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','scliva75','scliva@gmail.com','Исаков Вячеслав','Перекопская д.17 кор.2 кв.55','Москва','Москва','RUSSIAN FEDERATION','117209','89162634566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 06:31:37',0,NULL,3,1,2,1,'、 ','scliva75'),(12370,769594200011,320735056905,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',14.99,'eastar4uk','zoltantheking','erzsi1938@yahoo.com','ZSUZSA TARNAI','VAN LEIJENBERGHLAAN<br>28','AMSTERDAM','','NETHERLANDS','1082GM','31 207754576','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 07:49:24',0,NULL,3,1,2,1,'、 ','zoltantheking'),(12371,626652977013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','8774jrme','jerome.billotet@numericable.fr','Jérôme Billotet','27 A Rue Morel Ladeuil','Clermont-Ferrand','Auvergne','FRANCE','63000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 08:30:19',0,NULL,3,1,3,1,'RA184583907CN ','8774jrme\rMOSA005'),(12372,769606355011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',31,'eastar4uk','josteini20000','einsteini2003@hotmail.com','Patrick Steinberg','Huygensstr. 22','Leipzig','','GERMANY','04159','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 08:31:14',0,NULL,3,1,3,1,'RA184583629CN\r ','josteini20000\rWWOT003'),(12373,853667790012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','78kb90','catherinebrown99@hotmail.com','Catherine Brown','29 De Tany Court','St Albans','Hertfordshire','UNITED KINGDOM','AL1 1TU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 08:49:00',0,NULL,3,1,3,1,'RA184583819CN\r ','78kb90\rHBPH003'),(12374,769623296011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','d.franz84','d.franz@gmx.net','Dominik Franz','Abt-Führer-Str. 25','Fürstenfeldbruck','','GERMANY','82256','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 09:11:23',0,NULL,3,1,2,1,'、 ','d.franz84'),(12375,769629355011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',31,'eastar4uk','fishsoupisgood','ebay@madingley.org','James McKenzie','Citrix R<br>101 Science Park','CAMBRIDGE','Cambridgeshire','UNITED KINGDOM','CB4 0FY','01223225900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 09:25:22',0,NULL,3,1,17,0,NULL,'fishsoupisgood'),(12376,570590658003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','mywitness','adelizaga@yahoo.com','Adlai T Elizaga','Central Caltex Station<br>Velez-Makahambus St.','Cagayan de Oro City','','PHILIPPINES','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 09:41:06',0,NULL,3,1,3,1,'RA184583805CN\r ','mywitness\rHSNO004'),(12377,853694755012,220807272265,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','yulin07','ytl_lee@yahoo.com.au','Lucy Lee','22 Leonie Place Doolandella','Brisbane','Queensland','AUSTRALIA','4077','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 09:55:23',0,NULL,3,1,2,1,'、 ','yulin07   ivory白色'),(12378,770914743002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',239.98,'buysia','ladybenji12','benjamincotton100@btinternet.com','philip Cotton','31 Rothesay Close','Runcorn','Cheshire','UNITED KINGDOM','wa7 2sj','01928589654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:03:45',0,NULL,3,1,4,1,'YW866011953CN ','ladybenji12 配一个英标头  \rphilip Cotton\r15 keepers walk castlfield runcorn \rcheshire wa72jh  \rEngland \rUnited Kingdom\rTel：01928 581280 \rmobile：07928 960546   \r\r退款119.99'),(12379,769647160011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',117.99,'eastar4','arog3009','ajrbuck@bigpond.com','Andrew Rogers','8 Griffith Court','Forest Lake','Queensland','AUSTRALIA','4078','0417764247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:08:44',0,NULL,8,1,17,0,NULL,'arog3009'),(12380,626682708013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',239.99,'eastar4','arog3009','ajrbuck@bigpond.com','Andrew Rogers','8 Griffith Court','Forest Lake','Queensland','AUSTRALIA','4078','0417764247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:17:24',0,NULL,3,1,6,1,'EE495359843CN ','arog3009  再加2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses ×1'),(12381,769666372011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','suadict','sunaddict@mail.ru','Konstantin Ivanov','pr. Kosmonavtov, 20/35, 138','Korolev','Moscow Region','RUSSIAN FEDERATION','141080','8(926)7231034','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 10:57:46',0,NULL,3,1,2,1,'、 ','suadict 深蓝色'),(12382,626712269013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','fronike','fronik@gmail.com','Georgy Sofronov','Latviyskaya 37-293','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620007','+7-912-670-00-17','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 11:55:57',0,NULL,3,1,2,1,'、 ','fronike'),(12383,769355970011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','nja022','nja022@yahoo.com','Norma Atkinson','64 Manadnock Drive','Westford','MA','UNITED STATES','01886','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 12:51:17',0,NULL,3,1,1,1,'\\ ','nja022'),(12384,853778336012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',2,'OTSO002',151.98,'eastar4','poularas1965','ppe3@otenet.gr','Panagiotis Poularas','Vathi - Aeginis','Aegina','Attiki','GREECE','18010','+302297054135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 12:55:45',0,NULL,3,1,3,1,'RA184583822CN\r ','poularas1965\rOTSO002'),(12385,626758801013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','otaser','pjintes@gmail.com','Philip Jintes','Hoppad 8','Roden','','NETHERLANDS','9301PH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 14:12:37',0,NULL,3,1,3,1,'RA184583898CN ','otaser\rGLOT001*3'),(12386,626229544013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','alex_eri','oddghost@mail.ru','Aleksandr Stepanov','TEC-3<br>h.1, p.49','Ivanovo','Ivanovskaya','RUSSIAN FEDERATION','153042','+79158327039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 14:40:40',0,NULL,3,1,3,1,'RA184583133CN\r ','alex_eri\rWWSI005'),(12387,626773061013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','sagitarios22','sagitarios22@conlared.com','Diego Guerrero Ulecia','República Artentina 21 ( bar Gil )','Logroño','La Rioja','SPAIN','26002','679193588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 14:49:49',0,NULL,3,1,3,1,'RA184583796CN ','sagitarios22\rMOSA005'),(12388,853871856012,220815929156,'New in box Iqua bluetooth Smart Badge BHS-608 BHS 608',1,'HSIQ001',29.99,'eastar4uk','toloelan','tore.loeland@online.no','Tore Løland','Heddekroken 5','Stavanger','','NORWAY','4034','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 15:33:38',0,NULL,3,1,3,1,'RA184583875CN\r ','toloelan\rHSIQ001'),(12389,853891659012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','mrc084084','schembrimarco@yahoo.com','Marco Schembri','Flat1, Binja Hamrija, triq il-Hamrija,','Naxxar','','MALTA','NXR3480','0035679792810','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 16:01:36',0,NULL,3,1,2,1,'、 ','mrc084084'),(12390,769833707011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',83.98,'eastar4uk','aqua0','scuba-diving@bigfoot.com','adrian hardy','64 Marina Avenue<br>Fulwell','Sunderland','Tyne and Wear','UNITED KINGDOM','SR6 9AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 16:19:03',0,NULL,3,1,3,1,'RA184583779CN\r ','aqua0  注明是sample \rHBPH002'),(12391,853918474012,220820889853,'New Germany Grohe Crystal Anion Spa Shower Head +hose',1,'OTGR004+OTGR002',26.99,'eastar4uk','lorealkid','lorealkid@hotmail.co.uk','Gavin Dunnett','25 Banyard Close<br>Kesgrave','Ipswich','Suffolk','UNITED KINGDOM','ip5 2fr','01473334883','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 16:35:03',0,NULL,3,1,3,1,'RA184583941CN ','lorealkid\rOTGR004+OTGR002'),(12392,853968013012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',12,'eastar4uk','greg-snell','me@gregsnell.co.uk','Gregory Snell','34 First Avenue','Teignmouth','Devon','UNITED KINGDOM','TQ14 9DJ','01626773115','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 17:31:20',0,NULL,3,1,3,1,'RA184583986CN\r ','greg-snell\rWLHP002'),(12393,769909656011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.99,'eastar4','crob1309','chrisrobeflash@yahoo.com','chris roberson','10626 liberty bell dr','tampa','FL','UNITED STATES','33647','(510) 932-7108','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 17:41:00',0,NULL,3,1,1,1,'\\ ','crob1309'),(12394,769945337011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.4,'eastar4','stoechio','auchan@altern.org','Ravalitera Ray','24 boulevard du Canada','BETHUNE','Nord-Pas-de-Calais','FRANCE','62400','0610498213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 18:17:08',0,NULL,3,1,2,1,'、 ','stoechio'),(12395,769948352011,320730088723,'NIB GENUINE NOKIA BH-207 BLUETOOTH HEADSET',1,'HSNO010',14.99,'eastar4uk','tauricio07','afonso_costa@hotmail.com','Afonso Costa','Rua Lopes nº88 2ºDto','Lisboa','','PORTUGAL','1900-301','+351912337626','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 18:17:27',0,NULL,3,1,2,1,'\\ ','tauricio07'),(12396,626939483013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','fredrsb93','frede.nat@free.fr','frederic dal','fort de rosny 9 allée de sébastopol batE n°205','rosny sous bois','Île-de-France','FRANCE','93110','01.48.55.90.06','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 19:21:15',0,NULL,3,1,3,1,'RA184583717CN ','fredrsb93\rM0SA005'),(12397,854098269012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','wimbledontennisshop','d4m077@gmail.com','damian neiras','174 clonmore street','southfields','London','UNITED KINGDOM','sw18 5hb','02082655508','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 19:29:35',0,NULL,3,1,3,1,'RA184583615CN\r ','wimbledontennisshop\rGLOT005'),(12398,626944965013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.99,'eastar4','jcsmkz09','jcapp855@comcast.net','John Capp','855 6th Ave<br>Apt A','Coraopolis','PA','UNITED STATES','15108-1508','(724) 650-6512','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 19:32:12',0,NULL,3,1,1,1,'\\ ','jcsmkz09'),(12399,854103023012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','mmed2096','webmaster@sciro.ca','Miguel Medieors','632 Browning Ave.','Ottawa','ON','CANADA','K1G 0T9','(613) 898-7579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 19:33:35',0,NULL,3,1,2,1,'、 ','mmed2096'),(12400,626952876013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','lalass77','seide923@hotmail.com','ALEX SEIDE','80 URSULA PL','STAMFORD','CT','UNITED STATES','06902-4243','(407) 733-6470','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 19:43:44',0,NULL,3,1,1,1,'\\ ','lalass77'),(12401,854132862012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','rdidier75','rmandel@free.fr','Raphael MANDEL','11 BIS rue Guilloteaux Vatel','Le Chesnay','Ile-de-France','FRANCE','78150','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 20:11:18',0,NULL,3,1,2,1,'、 ','rdidier75'),(12402,570871708003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.9,'cnfaner','albrevange','aevangelista@rogers.com','Alberto Evangelista','459 Scarborough Golf Club Rd.','Scarborough','ON','CANADA','M1G 1G9','(416) 439-2149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 20:31:15',0,NULL,3,1,3,1,'RA184583685CN\r ','albrevange\rWLDE001'),(12403,626979705013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','philippe8847','philipperos@free.fr','Philippe Ros','18 rue des Paquerettes','MONTPELLIER','Languedoc-Roussillon','FRANCE','34000','0661309300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 20:36:04',0,NULL,3,1,3,1,'RA184583853CN ','philippe8847\rMOSA005'),(12404,854155570012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','guido68_de','guido_koch@online.de','Guido Koch','Osterfeldstr.19','Bad Nenndorf','other','GERMANY','31542','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 20:42:18',0,NULL,3,1,3,1,'RA184583990CN\r ','guido68_de\rGLOT005'),(12405,854149147012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',67.99,'eastar4uk','claudia-307','bzb4831@gmail.com','Cristina Ruiz Carrión','Calle Doctor Esquerdo, 6 Local Arte9','Madrid','Madrid','SPAIN','28028','914029608','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 20:45:06',0,NULL,3,1,3,1,'RA184583601CN ','claudia-307\rGLSG001*2'),(12406,769617319011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','prophet_60091','p60091@gmail.com','Vinh Huynh','8842 Bralorne Way','San Diego','CA','UNITED STATES','92126-1439','(408) 431-2716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 21:19:30',0,NULL,3,1,1,1,'\\ ','prophet_60091'),(12407,626998078013,230641258112,'New lady lace trim sun/rain stick Umbrella pink',1,'UM00011',24.99,'eastar4','obelixx11','stianknudsen@yahoo.no','Ina Cecilie Knudsen','Postboks 91','ANKENESSTRAND','Nordland','NORWAY','8513','90687560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 21:20:56',0,NULL,3,0,2,1,NULL,'obelixx11 粉色的 实际没发货，等客户问就退款'),(12408,854192909012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','phd_house','gkordares@hotmail.com','George J. Kordares','578 Anderson Rd NW','Marietta','GA','UNITED STATES','30064-1304','(770) 428-7551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 21:49:47',0,NULL,3,1,1,1,'\\ ','phd_house  \r发210TS'),(12409,770109418011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',16.58,'eastar4','michael4ngelo','aj001b9399@blueyonder.co.uk','Michael Jacques','51 Poplar Grove, Prescot','Liverpool','Merseyside','UNITED KINGDOM','L35 5AY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 21:56:00',0,NULL,3,1,2,1,'、 ','michael4ngelo'),(12410,770112028011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','940101_norway62','bibo_norway@yahoo.com','Bjorn Bommen','Liveien 255','Boe i Telemark','Telemark','NORWAY','3800','+47 90133830','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 22:03:09',0,NULL,3,1,2,1,'、 ','940101_norway62'),(12411,770116203011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','henkgroenendijk','henk.groenendijk@casema.nl','henk groenendijk','C. van Maasdijkstraat 44','UTRECHT','','NETHERLANDS','3555VP','06-53354514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 22:16:37',0,NULL,3,1,3,1,'RA184583558CN\r ','henkgroenendijk\rKBNO001'),(12412,854225448012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','nadz450','nadz_450@hotmail.com','Patrick Nadeau','5101 Buchan, suite 510','Montreal','QC','CANADA','H4P 2R9','(514) 745-2143 ext.: 250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 23:13:05',0,NULL,3,1,2,1,'、 ','nadz450'),(12413,770149209011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','davidblvd','davidblvd@hotmail.com','David Brittain','105 Elk Mountain Rd','Asheville','NC','UNITED STATES','28804-2011','(828) 260-0757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 23:51:24',0,NULL,3,1,1,1,'\\ ','davidblvd'),(12414,627039931013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','nikrad.k','nknikrad@gmail.com','Nikrad Kashanian','44392 Oakmont Manor Sq.','Ashburn','VA','UNITED STATES','20147','(703) 347-1530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 23:55:02',0,NULL,3,1,1,1,'、 ','nikrad.k'),(12415,771371362002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','gmaxraw79','griffin@theeyecarecompany.com.au','Griffin Ngo','139 Ryde Rd','Hunters Hill','New South Wales','AUSTRALIA','2110','0404046190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 00:07:35',0,NULL,3,0,4,1,'YW866011964CN ','gmaxraw79'),(12416,570933570003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','gliveston','gl61@hotmail.com','Gerri Liveston','9 Park Rdg','Lisbon','NH','UNITED STATES','03585-6510','(603) 838-2580','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 00:10:57',0,NULL,3,1,1,1,'\\ ','gliveston'),(12417,627058284013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.99,'eastar4','bims58','vshtibin@mn.rr.com','Vladimir Shtibin','12805 Sheffield Curv','Minnetonka','MN','UNITED STATES','55305-2750','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 00:59:19',0,NULL,3,1,1,1,'\\ ','bims58'),(12418,627058443013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','jaekwon.park','insainty21@gmail.com','jaekwon.park','634-10 yundang Building 3F rockPLACE Co. LTD<br>gang-nam gu shin-sa dong','seoul','','KOREA,REPUBLIC OF','135-895','01086132486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 01:02:10',0,NULL,3,1,2,1,'、 ','jaekwon.park'),(12419,854274370012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','mcortez6','cortez9337@att.net','Michael Cortez','12252 Casa Grande Dr','Dallas','TX','UNITED STATES','75253-3038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 01:24:43',0,NULL,3,1,1,1,'\\ ','mcortez6  \r发210TS'),(12420,576044852004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','ifoneuser','ifone727@gmail.com','Chonburi Am','9280 52nd st n','Pinellas park','FL','UNITED STATES','33782-5258','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 01:36:45',0,NULL,3,1,1,1,'\\ ','ifoneuser'),(12421,576452657004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.98,'cnfaner','tourpro68','e.staton@insightbb.com','Eric Staton','2414 Lake Park Rd<br>Apt 1107','Lexington','KY','UNITED STATES','40502','(859) 327-2720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 01:45:56',0,NULL,3,1,1,1,'\\ ','tourpro68'),(12422,570960156003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.98,'cnfaner','emmytrip699704','emmytrip@hotmail.com','emily evans','4635 stonesthrow dr','denver','NC','UNITED STATES','28037-8439','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 02:16:28',0,NULL,3,1,1,1,'\\ ','emmytrip699704'),(12423,770208648011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',2,'WLIN015',37.98,'eastar4','bearplay','gregmoreland@exemail.com.au','Greg Moreland','15 B Potato Point Rd','BODALLA','New South Wales','AUSTRALIA','2545','0414078206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 02:52:09',0,NULL,3,1,2,1,'、 ','bearplay'),(12424,627095087013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.5,'eastar4','ashleyshine','bguy13@aol.com','Chester S Riley','90 Finchley Blvd','Lakewood','NJ','UNITED STATES','08701-5522','(732) 905-0551','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-26 03:25:57',0,NULL,3,1,1,1,'\\ ','ashleyshine\r银色的'),(12425,770218219011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'eastar4','inland46','inland46a@aol.com','Warden Fong','7314 Camino Del Rey St','Sacramento','CA','UNITED STATES','95831','(916) 421-1214','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 03:28:02',0,NULL,3,1,1,1,'\\ ','inland46'),(12426,576474241004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'cnfaner','davidhsjr','davidsoto@aol.com','David Soto','1705 Shane Ln','Beaumont','CA','UNITED STATES','92223','(951) 830-5435','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 03:28:55',0,NULL,3,1,1,1,'\\ ','davidhsjr'),(12427,570976958003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'cnfaner','hmazen','haitham@maznet.ca','Haitham Mazen','1305 Cobbler Lane','Oakville','ON','CANADA','L6M2X4','(905) 901-9431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 03:33:53',0,NULL,3,1,3,1,'RA184583575CN\r ','hmazen\rSCLO001'),(12429,8881317008596304,111,'plantronics 510',1,'HSPL010',0,'cnfaner','littlemarty1','js.petree@verizon.net','Sandra Petree','1550 E. Los Flores Dr','San Bernardino','CA','UNITED STATES','92404-2059','',NULL,NULL,NULL,'2011-09-26 03:43:16',0,NULL,3,1,3,1,'RA184583527CN ',' 补发耳机\rHSPL010'),(12430,854335830012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','jakefaride','willrpm@hotmail.com','William Restrepo','84-16 F Astoria Blvd.','East Elmhurst','NY','UNITED STATES','11370','(347) 574-1542','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 04:56:54',0,NULL,3,1,1,1,'\\ ','jakefaride'),(12431,576486750004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',26.99,'cnfaner','shamgate','orders@shamgate.com','Sham Gate Inc','6817 3RD AVE','BROOKLYN','NY','UNITED STATES','11220','(347) 741-8888','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 05:01:17',0,NULL,3,1,1,1,'\\ ','shamgate'),(12432,854336800012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',77.99,'eastar4','badspeeddotcom_2','2011@badspeed.com','Alexander Petrovic','1402 Bay Rd','Miami Beach','FL','UNITED STATES','33139-3703','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 05:02:33',0,NULL,3,1,1,1,'\\ ','badspeeddotcom_2'),(12433,627113304013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',10,'CASS001',82.9,'eastar4','azdok','boosdok@gmail.com','Denis Okolokulak','B.Nuriyev 5, app. 12','Baku','','AZERBAIJAN','Az1119','+994557023925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 05:22:42',0,NULL,3,1,3,1,'RA184583650CN\r ','azdok\rCASS001'),(12434,770245271011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','minhvu1','minhvu.01@gmail.com','Minh Vu','13251 Safford St','Garden Grove','CA','UNITED STATES','92843','(714) 423-2296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 05:53:10',0,NULL,3,1,1,1,'\\ ','minhvu1'),(12435,854361812012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','gud24','ronny@eidahl.com','Ronny Strand Eidahl','Kjennveien 93','Lørenskog','Lørenskog','NORWAY','1470','4790818080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 07:10:03',0,NULL,3,1,2,1,'、 ','gud24'),(12436,854368337012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',28.99,'eastar4','bamiry2011','bamirymeri@gmail.com','Bamir Ymeri','Dardania 1<br>Rr.1 Nr.21','Gjilan','Kosovo','ALBANIA','60000','+38649700578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 07:35:05',0,NULL,3,1,2,1,NULL,'bamiry2011'),(12439,0,110747104937,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',15.1,'buysia','danmetro','danmetro@btinternet.com','Daniel Taylor','Unit 2 LaGare Building<br>Surrey Row','London','London','UNITED KINGDOM','SE1 0BZ','07973305004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 09:13:34',0,NULL,3,1,3,1,'RA184583411CN\r ','danmetro  客户新地址： \rDaniel Taylor\rLaGare Studios\r49 Surrey Row\rLondon SE10BY\rUnited Kingdom\r\r'),(12437,770269112011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.8,'eastar4','mic21_fr','mikosax@yahoo.fr','Michel MICONNET','35 rue Jean-Philippe-Rameau','MARSANNAY LA COTE','-','FRANCE','21160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 07:51:00',0,NULL,3,1,2,1,'\\ ','mic21_fr'),(12438,571014783003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',3,'HSJA004',59.97,'cnfaner','itsfiya007','itsfiya@aol.com','James C. Jones','507 Pecan Wood Cir','Fairburn','GA','UNITED STATES','30213-6405','(404) 513-8477','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 08:24:27',0,NULL,3,1,1,1,'\\ ','itsfiya007'),(12440,770293396011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',92.99,'eastar4uk','suleyman7038','dolfijnen_11@hotmail.com','suleyman sonmezcan','Jonge Schutskooilaan 56','TIEL','','NETHERLANDS','4001SC','0344-707234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 09:34:58',0,NULL,3,1,3,1,'RA184583592CN\r ','suleyman7038\rGLOT005*3'),(12441,8881317029902985,111,'MC8781',5,'WWSI005',0,'eastar4','update_marcelo','marcelo@upbrasil.com.br','Marcelo S. Machado','Rua Rodrigues Caldas, 726/1002','Belo Horizonte','Minas Gerais','BRAZIL','30190-120','',NULL,NULL,NULL,'2011-09-26 09:38:22',0,NULL,5,0,18,1,NULL,'\rWWSI005\r已退过钱了'),(12442,767494861011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',15.65,'eastar4uk','krzysiek26','reksiu1@vp.pl','KRZYSZTOF','MAJEWSKI<br>48 FIELDFARE CLOSE','CORBY','Northamptonshire','UNITED KINGDOM','NN188FF','07511095562','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 10:04:38',0,NULL,3,1,3,1,'RA184583195CN\r ','krzysiek26 英标头\rHSPL010'),(12443,576529442004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',6,'WLAT008',93,'cnfaner','alosyev','cdal@012.net.il','Alex Computers (2002) Ltd','58 Moriah ave','Haifa','Israel','ISRAEL','34401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 10:14:08',0,NULL,3,1,3,1,'RA184583204CN\r ','alosyev\rWLAP008'),(12444,854412456012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','jupi3','fj.schulz@yahoo.de','Franz-Josef Schulz','Klemensstr.39','Duisburg','','GERMANY','47059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 10:22:55',0,NULL,3,1,2,1,'、 ','jupi3 发210TS'),(12445,770306846011,320721819844,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','vedran1512','vedrankoren@gmail.com','Blazenka Koren','Bednjanska 26','Osijek','Osijek','CROATIA','31000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 10:24:42',0,NULL,3,1,2,1,'、 ','vedran1512'),(12446,627172136013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',17.89,'eastar4','victorpimchenko','victornavolsky@yandex.ru','Victor Pimchenko','Traktorostroiteley ave.<br>h.152 f.54','Kharkiv','','UKRAINE','61121','(067)701-6613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 11:14:01',0,NULL,3,1,2,1,'\\ ','victorpimchenko 欧标头'),(12447,854427285012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','mmacario','alimohammed@sapo.pt','Marco Cláudio Torres Macário','Estrada Nacional 329','Penalva do Castelo','Penalva do Castelo','PORTUGAL','3550-163','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 11:17:16',0,NULL,3,1,2,1,'\\ ','mmacario'),(12448,627175997013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','maasdonkervelden','pietvandervelden@home.nl','P.M. van der Velden','Hoogstraat 7','Nuland','','NETHERLANDS','5391 BX','073-5323294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 11:33:52',0,NULL,3,1,2,1,'\\ ','maasdonkervelden'),(12449,770326630011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',79.98,'eastar4uk','nedw1282','njebrain@hotmail.com','Nigel Edwards','C/o Melinhomes Ltd<br>Ty\'r Efail, Lower Mill Field','Pontypool','Torfaen','UNITED KINGDOM','NP4 0XJ','07813766173','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 11:34:05',0,NULL,3,1,3,1,'RA184583337CN ','nedw1282\rOTSO004'),(12450,770330698011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.9,'eastar4','eddie0_2','behand@web.de','Brendan Edward    Hand','Im Brückfeld 28','Wiesbaden / Medenbach','','GERMANY','65207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 11:49:47',0,NULL,3,1,2,1,'\\ ','eddie0_2'),(12451,770335235011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','dumbasses21','dumbasses21@hotmail.com','bradyn cook','8 munday court','skye','Victoria','AUSTRALIA','3977','0397826524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 11:59:46',0,NULL,3,1,2,1,'\\ ','dumbasses21'),(12452,854444430012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','matejs78','srebernjak@gmail.com','Matej Srebernjak','Kotna pot 4<br>Voglje','Sencur','','SLOVENIA','4208','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 12:02:25',0,NULL,3,1,3,1,'RA184583442CN ','matejs78\rGLOT005'),(12453,854444702012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','1st.class.computers','kris30@gmail.com','Kris300 Nietzold','17 Queenswood Rd, Forest Hill','London','London','UNITED KINGDOM','SE232QR','02086901423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:03:48',0,NULL,3,1,2,1,'\\ ','1st.class.computers'),(12454,627183967013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','bismo84','runardalsveen@gmail.com','Runar Dalsveen','Møllefaret 14 A','Oslo','','NORWAY','0750','+4799406248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:12:08',0,NULL,3,1,2,1,'\\ ','bismo84'),(12455,854451049012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','spike69r','johnq83@gmail.com','john quach','2/14 Federal Highway','Watson','Australian Capital Territory','AUSTRALIA','2602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:23:07',0,NULL,3,1,2,1,'\\ ','spike69r'),(12456,770350027011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.99,'eastar4','harufinho','pierre.becher@t-online.de','Pierre Becher','6 Capensia Way<br>Authorised to leave at door','Canning Vale','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:46:52',0,NULL,3,1,3,1,'RA184583500CN ','harufinho\rHBPH002'),(12457,570586009003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','donorosz','kisorosz7@gmail.com','Gabor Orosz','Jaszai Mari 5','Dunakeszi','Pest','HUNGARY','2120','+36-30/481-8575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:52:46',0,NULL,3,1,3,1,'RA184583385CN\r ','donorosz  OEM的\rMOOE002'),(12458,627202343013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','salzgitter','ernst.grimm@gmail.com','Ernst Grimm','Redoute 53 B','Prangins','','SWITZERLAND','1197','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 13:26:14',0,NULL,3,1,2,1,'\\ ','salzgitter'),(12459,627205583013,230657633130,'KODAK Wi-Fi Card 4 EasyShare Camera printer dock',2,'WLKO001',51.98,'eastar4','goldberg43','goldberg_43@web.de','Thomas Brunner','Hecknerstr 6','Freising','','GERMANY','85356','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 13:39:13',0,NULL,3,1,3,1,'RA184583371CN\r ','goldberg43\rWLKO001'),(12460,854489954012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','murabnoob','rafaeltsb@gmail.com','Rafael Brites','Rua Campos Salles,2063<br>Bairro dos Alemães','Piracicaba','Sao Paulo','BRAZIL','13416-310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 14:11:54',0,NULL,3,1,2,1,'\\ ','murabnoob'),(12461,854494438012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','flognerfoz01','flognerfoz@hotmail.com','Eder Flogner','Rua Euzébio de Queiroz, 418<br>Ap. 1004','Joinville','Santa Catarina','BRAZIL','89203-100 ','554799786675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 14:26:52',0,NULL,3,1,3,1,'RA184583399CN ','flognerfoz01\rGLOT001*2'),(12462,627220362013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',16.99,'eastar4','eyalhl','eyalhl@gmail.com','Dror Hilel','5510 Sepulveda Blvd<br>Apt 315','Sherman Oaks','CA','UNITED STATES','91411-4508','(818) 660-7820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 14:38:35',0,NULL,3,1,1,1,'\\ ','eyalhl'),(12463,854515266012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','atkaice85','atkaice@freemail.hu','Attila Pénzes','Tábor u. 6.','Györ','Györ-Moson-Sopron','HUNGARY','9026','+36202569986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 15:14:22',0,NULL,3,0,2,1,'\\ ','atkaice85 欧标头'),(12464,769746862011,320730086052,'New brand Logitech Digital IO Writing Pen',1,'NTLO002',18.99,'eastar4uk','caz1.2009','caroline.caz.williams@gmail.com','caroline williams','19 stapletonhall road<br>haringey','london','London','UNITED KINGDOM','n4 3qe','02072725978','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 15:31:51',0,NULL,3,1,3,1,'RA184583456CN\r ','caz1.2009\rNTLO002'),(12465,571101675003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',19.95,'cnfaner','ld22611','ldevos@epo.org','Luc De Vos','Gertrud-Kückelmann-Weg 15','München','','GERMANY','81739','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 15:34:13',0,NULL,3,1,2,1,'\\ ','ld22611'),(12466,770407508011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','fasg','art.burla4enko@yandex.ru','Artem Burlachenko','Stolbovaya<br>81/1','Odessa','Odessa','UKRAINE','65098','+380636719837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 15:39:09',0,NULL,3,1,3,1,'RA184584037CN ','fasg\rHSLO001 挑一个成色好点的'),(12467,627248928013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',11.99,'eastar4','brian198503','peterturk85@gmail.com','Turk Peter','Balassi street 32','Nyekladhaza','Borsod Abauj Zemplen','HUNGARY','3433','+36702417567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 16:16:49',0,NULL,3,1,2,1,'\\ ','brian198503'),(12468,770431991011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','samantha.bryan','samo.bryan@gmail.com','Samantha Bryan','153 Winnett Ave','Toronto','ON','CANADA','M6C3L7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 16:54:32',0,NULL,3,1,2,1,'\\ ','samantha.bryan'),(12469,768977002011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','ales791','dr_elmir@yahoo.co.uk','Elmir Alasgarov','Natavan dongasi 2/6','Baku','Sabail Rayonu','AZERBAIJAN','AZ1005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 16:56:49',0,NULL,3,1,2,1,'\\ ','ales791'),(12470,770441671011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','elivshen','daytodayny@gmail.com','Olya Petrovich','464 W 146th St<br>Apt 4','New York','NY','UNITED STATES','10031-4725','(646) 641-1417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 17:17:41',0,NULL,3,1,1,1,'\\ ','elivshen'),(12471,854590723012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','wallykuz','wallykuz@hotmail.com','Wally Kuzmicz','302-2555 St. Joseph Blvd.','Orleans','ON','CANADA','K1C1S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 17:49:01',0,NULL,3,1,2,1,'\\ ','wallykuz'),(12472,576642383004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','wallykuz','wallykuz@hotmail.com','Wally Kuzmicz','302-2555 St. Joseph Blvd.','Orleans','ON','CANADA','K1C1S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 17:53:59',0,NULL,3,1,3,1,'RA184564699CN ','wallykuz\rWLDE002'),(12473,571156157003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','d-creator','daniel.sky.eyes@gmail.com','Daniel Kachaev','Yosef #6','Haifa','','ISRAEL','33144','0547655945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 18:39:40',0,NULL,3,1,3,1,'RA184583283CN ','d-creator\rHSPL009'),(12474,770499928011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','c2000m','cml@tinet.cat','Carles Mateu Lopez','Avda Catalunya 31C, 4, 2','Tarragona','Tarragona','SPAIN','43002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 18:41:07',0,NULL,3,1,2,1,'\\ ','c2000m'),(12475,627304253013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','er1559','elruizj@sbcglobal.net','ERNEST RUIZ JR.','3605 W Cutler Ave','VISALIA','CA','UNITED STATES','93277-4113','(559) 739-1239','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 18:41:54',0,NULL,3,1,1,1,'\\ ','er1559'),(12476,854626930012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT004*3',132.99,'eastar4','ah4des2010','ah4des@windowslive.com','Abdullah Almushayqih','6035 Pebblebrook LN<br>APT 111','Kent','OH','UNITED STATES','44240-7160','202 355 4119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 18:46:14',0,NULL,3,1,1,1,'\\ ','ah4des2010'),(12477,770504408011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',23.99,'eastar4','dawgemmafoley','emmaf@uga.edu','Emma Foley','106 Gayle Ct','Winterville','GA','UNITED STATES','30683-1602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 18:49:54',0,NULL,3,1,1,1,'\\ ','dawgemmafoley'),(12478,729496555001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','debbydoo_2','debby@debsmail.com','Debby Ranieri','1437 Crowfoot Ln','Minooka','IL','UNITED STATES','60447-8219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 18:54:19',0,NULL,3,1,1,1,'\\ ','debbydoo_2'),(12479,770507489011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','howlmarkl','basquet-hero@hotmail.com','Fermin Aviles Sandoval','Bruckner Ave 247','Staten Island','NY','UNITED STATES','10303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 18:54:23',0,NULL,3,1,3,1,'RA184561623CN ','howlmarkl 新地址：\rIsrael Aviles Garrido\rCalle 5 # 76 Colonia Estado de Mexico\rC.P. 57210\rCiudad: \rNezahualcoyotl\rEstado: Estado de Mexico\rPais: Mexico\r\r'),(12480,770545353011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','sazismail','my_ebay_seller_account@yahoo.com','Saz Ismail','210 Gresleywood Road','Swadlincote','Derbyshire','UNITED KINGDOM','DE11 9QR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 19:56:57',0,NULL,3,1,3,1,'RA184583408CN\r ','sazismail\rGLOT001*2'),(12481,854676225012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','calpass','calpass@online.de','Pascal Aubron','Bienenstr. 8','Kaiserslautern','RHEINLANDPFALAZ','GERMANY','67655','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:02:57',0,NULL,3,1,2,1,'\\ ','calpass'),(12482,770549280011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.89,'eastar4','cinnoke','rossmiller1@bigpond.com','Ross Miller','2 The Rampart<br>Orchard Beach','Redland Bay','Queensland','AUSTRALIA','4165','0732068587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:05:18',0,NULL,3,1,3,1,'RA184583345CN ','cinnoke\rGLOT004'),(12483,854678998012,220815928236,'GENUINE Plantronics Voyager 851/855 Bluetooth headset',1,'HSPL017',21.99,'eastar4uk','jimpheonix19','jimpheonix1@msn.com','James Thomson','19 Fraser Avenue','HAWICK','Borders','UNITED KINGDOM','TD9 8DG','01450379308','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 20:09:27',0,NULL,3,1,3,1,'RA184583270CN ','jimpheonix19\rHSPL017'),(12484,770556862011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','akinias','fer@fer.nu','Fernando Benito (ACK STORM)','C/Catalunya 72 Local','Viladecans','Cataluña','SPAIN','08840','902888345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:22:22',0,NULL,3,1,2,1,'\\ ','akinias'),(12485,770566662011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','d331088','drago.stz@gmail.com','Dragan Nedyalkov','44 General Gurko Str., fl.1, app.1','Stara Zagora','Stara Zagora','BULGARIA','6000','359887637139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:39:25',0,NULL,3,1,2,1,'\\ ','d331088'),(12486,770569980011,320741901009,'Original Yamaha AV Remote control RAV255 WE45880 EU',1,'RCYA001',26.99,'eastar4uk','puelli03','puelli1007@t-online.de','Michael Puelsinger','Wienerplatz 13','Mainz-Kostheim','','GERMANY','55246','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 20:46:30',0,NULL,3,1,3,1,'RA184583368CN ','puelli03\rRCYA001'),(12487,627356373013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','zahaynyygedz','gedz_z@ukr.net','Oleksandr Zahaynyy','Manuilskogo<br>23/24','Kyiv','Kyiv','UKRAINE','04050','(091)310-2878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 21:01:37',0,NULL,3,1,2,1,'\\ ','zahaynyygedz'),(12488,770577450011,320687835296,'New Lenovo/IBM Thinkpad Series 3 4337 MINI DOCK T410',1,'EXLO001',147.99,'eastar4','gerlac2','dr.dieter.g@gmx.net','Dr. Dieter Gerlach','Schützenstr. 21A','Diekholzen','','GERMANY','31199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 21:02:36',0,NULL,3,1,3,1,'RA184583323CN\r ','gerlac2\rEXLO001'),(12489,854624047012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','me.wantee','me.wantee.ebay@gmail.com','Dimitri P. / m.w.','847 Mango Ave<br>Igor','Sunnyvale','CA','UNITED STATES','94087-1653','(408) 254-1267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 21:03:42',0,NULL,3,1,1,1,'、 ','me.wantee'),(12490,576716872004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',26.99,'cnfaner','franciscanen','scalero@gmail.com','Sergio Calero','Avda. Pintor Xavier Soler nº5 Oficina E','Alicante','Comunidad Valenciana','SPAIN','03015','647232408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 21:13:43',0,NULL,3,0,3,1,'RA184583495CN\r ','franciscanen 欧标头\rHSJA010'),(12491,770597476011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','7300mark','lukewarm@autografix.com','Mark Nesbitt','Greencroft<br>Harton Cross','Hartland','Bideford','UNITED KINGDOM','EX39 6AE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 21:51:21',0,NULL,3,1,3,1,'RA184583487CN\r ','7300mark\rMOAP001'),(12492,854734309012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','vincentceriale4420','vinmaniac@yahoo.com','Vincent Ceriale','PO Box 154','Cornwall','NY','UNITED STATES','12518-0154','(914) 420-7235','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 22:02:02',0,NULL,3,1,1,1,'\\ ','vincentceriale4420'),(12493,770607624011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','propluskk','nhily.liu@gmail.com','Ly  Liu','36 Dickens Road','Ipswich','Suffolk','UNITED KINGDOM','ip2 0JW','01473217791','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 22:20:45',0,NULL,3,1,2,1,'\\ ','propluskk'),(12494,627386941013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','renatogalera','renatoguilhermini@hotmail.com','Renato Guilhermini','Rua Luciano Freire, 97<br>Mandaqui','Sao Paulo','São Paulo','BRAZIL','02420-060','55 11 60777740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 22:42:06',0,NULL,3,1,2,1,'\\ ','renatogalera'),(12495,854758163012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','landirover','orlandopassfield@gmail.com','orlando passfield','hope cottage, crown lane south<br>ardleigh','colchester','Essex','UNITED KINGDOM','co77pl','01206231018','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 23:12:41',0,NULL,3,1,3,1,'RA184583460CN ','landirover\rWLAP002'),(12496,770623049011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','masterp123','jgellingson@gmail.com','John Ellingson','Box 26089','Red Deer','AB','CANADA','T4N6X7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 23:19:40',0,NULL,3,1,2,1,'\\ ','masterp123'),(12497,770629699011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','m7amadb','m7amad@topmail-files.de','Mohamad Bakir','Fritz-Reuter-Allee 146','Berlin','','GERMANY','12359','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 23:38:18',0,NULL,3,1,2,1,'\\ ','m7amadb'),(12498,770640957011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mrhotguy696987','hotguy696987@hotmail.com','tyler kwast','3243 274 street','aldergrove','BC','CANADA','v4w3j1','(604) 807-1745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 00:18:58',0,NULL,3,1,2,1,'\\ ','mrhotguy696987'),(12499,770647137011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','dmsr739','dmsr739@yahoo.com','Samuel Still','4055 Sapling Way','Triangle','VA','UNITED STATES','22172-2052','(703) 878-5951','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 00:42:28',0,NULL,3,1,1,1,'\\ ','dmsr739'),(12500,854802115012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','*wookie*','castlerock@comcast.net','Brian F. Ort','3121 Tennyson St NW','Washington','DC','UNITED STATES','20015-2317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 01:35:56',0,NULL,3,1,1,1,'\\ ','*wookie*'),(12501,854804014012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',177.88,'eastar4','glet1','glet@telus.net','Garry Letwin','8945-92 avenue','Fort Saskatchewan','AB','CANADA','T8L 1A3','(780) 446-1224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 01:53:07',0,NULL,3,1,6,1,'EE495359812CN ','glet1  再加三幅，一共4副'),(12502,0,120782239445,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.5,'buysia','smartack','wilson2.rick@gmail.com','Cindy Wilson','4791 Upper River Rd','Grants Pass','OR','UNITED STATES','97526-7272','(541) 479-4791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 02:14:59',0,NULL,3,1,1,1,'\\\r ','smartack'),(12503,576781680004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','luckyfish4873','strike.eagle.three@gmail.com','Edward Hupe','3708-8 Ave. S.W.','Calgary','AB','CANADA','T3C0G2','(403) 612-4443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 02:37:28',0,NULL,3,1,3,1,'RA184583425CN ','luckyfish4873\rHSJA002'),(12504,626312819013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','larko12000','larko1@hotmail.com','Anthony Larken','38/178   Sukomwit Road<br>Soi Nuernplubwan Nongpure','Banglamung','chonburi','THAILAND','20150','08 35480208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 02:46:25',0,NULL,3,1,3,1,'RA184583310CN ','larko12000\rMOSA005'),(12505,770687956011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',3,'HBPH002',190.5,'eastar4','benski123','bpon@platinum.ca','Bernard Pon','Suite 268, 16 Midlake Blvd SE','Calgary','AB','CANADA','T2X2X7','(403) 966-5060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 03:18:16',0,NULL,3,1,3,1,'RA184583473CN ','benski123\rHBPH002'),(12506,0,120782239417,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.49,'buysia','barajasdealer','barajasdealer@verizon.net','RICARDO ALBA','1316 S Meadow Ln<br>Apt 291','COLTON','CA','UNITED STATES','92324','(909) 838-7313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 03:50:11',0,NULL,3,1,1,1,'\\ ','barajasdealer'),(12507,854844561012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','cannonballseven','enk3@sympatico.ca','Eric Knibbe','RR#4 766 Simcoe Rd.','Bradford','ON','CANADA','L3Z 2A6','(905) 775-4517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 04:17:02',0,NULL,3,1,2,1,'\\ ','cannonballseven'),(12508,571305793003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',38.79,'cnfaner','denis.kuzin','kuzin.d@mail.ru','Denis Vladimir','Azerbaijan F. Ibrahimbeyov str 12<br>mehelle 458, 1-ci mertebe ADT Comp, 012 480-23-46','Baku','','AZERBAIJAN','1065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 05:38:19',0,NULL,3,1,3,1,'RA184583439CN ','denis.kuzin  欧标头\rHSNO019'),(12509,770719440011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','natepnguyen','natepnguyen@yahoo.com','Sally Ugly Women Pham','2448 mills ave','Port arthur','TX','UNITED STATES','77642-0527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 06:12:05',0,NULL,3,1,1,1,'\\ ','natepnguyen'),(12510,626551374013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',16.99,'eastar4','atomix_82','atomix@o2.pl','Tomasz Baluszek','ul. Konopnickiej 13a/6','Zagan','lubuskie','POLAND','68-100','503 099910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 06:26:49',0,NULL,3,1,2,1,'\\ ','atomix_82'),(12511,770723826011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','grow4302','gayler@castlepersonnel.com.au','Gayle Rowney','242 Maitland Road','Mayfield','New South Wales','AUSTRALIA','2304','0240142222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 06:28:03',0,NULL,3,1,2,1,'\\ ','grow4302'),(12512,729689100001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',3,'HSJB001',37.97,'buysia','liboretto','scazano@gmail.com','Oleksandr Kutchenko','Sribnokilska str., bldg. 1, apt. 283','Kyiv','Kyiv city','UKRAINE','02140','+380504107290','NoPaymentFailure','CheckoutComplete','NotSelected','2011-09-27 06:46:20',0,NULL,3,1,3,1,'RA184583266CN ','liboretto\rHSJB001'),(12513,770732172011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','jyac2240','slrey@yahoo.com','Jacquelyne Yacubic','434 Latta Brook Road','Horseheads','NY','UNITED STATES','14845-9010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 07:12:28',0,NULL,3,1,1,1,'\\ ','jyac2240'),(12514,854887931012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','drukltd','disres@hotmail.com','David Collinson','2 Buckingham Close<br>Whitburn','Sunderland','Tyne and Wear','UNITED KINGDOM','SR6 7AX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 07:47:29',0,NULL,3,1,3,1,'RA184583181CN ','drukltd\rMOMI001 '),(12515,854893056012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','c843861','c843861@gmail.com','Mr Paul F. Matthews','8 Koppe Court<br>Middle Ridge','Toowoomba','Queensland','AUSTRALIA','4350','0407771677','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 08:08:43',0,NULL,3,1,2,1,'\\ ','c843861 澳标'),(12516,729723982001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','smsechler','suemholt58@yahoo.com','SUE SECHLER','16 Trutt Rd','WINFIELD','PA','UNITED STATES','17889-9301','(570) 524-6234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 08:49:40',0,NULL,3,1,1,1,'\\ ','smsechler'),(12517,0,120782239490,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','valdirmagalhaes1','valdirmagalhaes@ig.com.br','FRANCISCO VALDIR ALVES MAGALHAES','RUA ALVARO MENDES, 1313 SEXTO ANDAR','TERESINA','PIAUI','BRAZIL','64000-915','8688026200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 09:01:19',0,NULL,3,1,3,1,'RA184583178CN ','valdirmagalhaes1\rBR3D008'),(12518,729736148001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',23.99,'buysia','mvigs','mark@visuals.co.uk','mark vigna','Unit 3-4 Teddington Business Park<br>Station Road','Teddington','Middlesex','UNITED KINGDOM','TW11 9BQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 09:41:51',0,NULL,3,1,3,1,'RA184584964CN\r ','mvigs\rBR3D007'),(12519,770769847011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','luisifun','luisfuness@gmail.com','Luis Alberto Gonzalez Funes','Coniferas,3 2º D','Madrid','Madrid','SPAIN','28041','627435458','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 09:54:10',0,NULL,3,1,2,1,'\\ ','luisifun'),(12520,571342871003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','kamsanita1630','kamsanita@singnet.com.sg','Kamsani Yakob','Block 385 Bukit Batok West Avenue 5<br>#02-342','default','','SINGAPORE','650385','+6593830897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 09:57:31',0,NULL,3,1,3,1,'RA184584995CN\r ','kamsanita1630\rHSNO004'),(12521,729742735001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','rafap80','rafael90260@msn.com','Jose Perdomo','17213 Grevillea ave','Lawndale','CA','UNITED STATES','90260-3456','(310) 793-8588','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 10:08:41',0,NULL,3,1,1,1,'\\ ','rafap80'),(12522,627511462013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','tealcsg','kmioc@inet.hr','Krasomir Mioč','Vijenac Petrove gore 15','Osijek','Osječko-baranjska','CROATIA','31000','+38598386407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 10:18:55',0,NULL,3,1,3,1,'RA184584893CN\r ','tealcsg\rHSNO019'),(12523,854939490012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','bloodog97','bloodog@bamba.lt','Olegas Kurasovas','Karaliauciaus 6-200','Vilnius','LT','LITHUANIA','06201','+370-5-2798020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 11:00:04',0,NULL,3,1,3,1,'RA184584981CN\r ','bloodog97\rGLOT001*2'),(12524,0,110747104961,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',12.8,'buysia','tower03tomcat98','swiftek98@aol.com','Fatihe Ennajihi','167 paterson ave','lodi','NJ','UNITED STATES','07644-3122','(516) 790-6960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 11:24:55',0,NULL,3,1,1,1,'\\ ','tower03tomcat98'),(12525,627525093013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','xetrow','muratedizaksoy@gmail.com','ediz aksoy','Servier Ilac ve Arastirma A.S Beybi Giz Kule <br>Meydan Sk. No.28 Kat:22 Maslak','Istanbul','','TURKEY','34398','00905326467398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 11:31:51',0,NULL,3,1,3,1,'RA184583249CN\r ','xetrow\rMOSA005'),(12526,854949885012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','protacio440e','matt.protacio@gmail.com','Matthew Protacio','5656 Kungle Rd','Barberton','OH','UNITED STATES','44203-7837','(330) 825-8292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 11:44:22',0,NULL,3,1,1,1,'\\ ','protacio440e'),(12527,576863039004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'cnfaner','rhondalwilson','drummerboy_48@hotmail.com','rhonda wilson','Po Box 1122','Armidale','New South Wales','AUSTRALIA','2350','0267713637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 11:45:06',0,NULL,3,1,3,1,'RA184584920CN\r ','rhondalwilson\rRELO003'),(12528,854971549012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','rae3890','rae.oldham@btinternet.com','Rae Oldham','57 Swannington Street<br>Outwoods','Burton on Trent','Staffordshire','UNITED KINGDOM','DE13 0RT','01283564929','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 12:40:42',0,NULL,3,1,3,1,'RA184583164CN\r ','rae3890 英标头\rHSJA010'),(12529,571371588003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','der-schlaue-det','eimertenbrink@web.de','Detlef Eimertenbrink','Kirschbaumer Str. 88','Solingen','','GERMANY','42655','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 12:40:55',0,NULL,3,1,3,1,'RA184584978CN\r ','der-schlaue-det\rBAZA001  投递不成功退回'),(12530,770821041011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','wolboy','wayne.lidbetter@hotmail.co.uk','wayne lidbetter','16 orlando gardens, epsom','london','surrey','UNITED KINGDOM','kt199et','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 12:52:04',0,NULL,3,1,3,1,'RA184584880CN\r ','wolboy\rRCLO008'),(12531,770828243011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','bonard113','bonard2.0@gmail.com','Eric Poulin','1721 albertine app.9','St-Romuald (Lévis)','QC','CANADA','G6W2P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 13:15:16',0,NULL,3,1,2,1,'\\ ','bonard113'),(12532,627547870013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','klmvalex','klmvlksndr@rambler.ru','Aleksandr Klimov','ul. Shkuljova, d.3, kv.26','Moskva','','RUSSIAN FEDERATION','109390','+79264906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 13:16:43',0,NULL,3,1,3,1,'RA184583218CN\r ','klmvalex\rWLIN014'),(12533,627552031013,230656011331,'2.4GHz 18dBi RP-SMA Yagi 802.11b/g Antenna N-Female',1,'ANYA002',15.99,'eastar4','yeohbingjie0303','yeohbingjie@hotmail.com','Yeoh Bing Jie','#06-15<br>12, Lorong 14 Geylang','default','','SINGAPORE','398924','6583543136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 13:35:20',0,NULL,3,1,11,1,'\\ ','yeohbingjie0303\rANYA002'),(12534,770843737011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',29.99,'eastar4uk','biljanaandrejevic','andrejevic.sinisa@gmail.com','Andrejevic Sinisa','Kumodraska br.87','Belgrade','Serbia','SERBIA','11000','+381641429520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 14:03:03',0,NULL,3,1,3,1,'RA184584955CN\r ','biljanaandrejevic\rGLOT001 申报5美金'),(12535,770844883011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',3,'BTHP2010',29.7,'eastar4','leo2006mo','susmohns@googlemail.com','Susanne Mohns','Max-von-Laue-Straße 26','Remscheid','','GERMANY','42897','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 14:05:05',0,NULL,3,1,3,1,'RA184584876CN\r ','leo2006mo  \rHP 8pin 1.25 18cm\rBTHP2010'),(12536,770845790011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',117.99,'eastar4','spookyroos','spooky1@zonnet.nl','Nico Roos','Westkade 51','HELLEVOETSLUIS','','NETHERLANDS','3221AV','0181317854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 14:07:50',0,NULL,3,1,3,1,'RA184584045CN ','spookyroos\rOTSO005*2'),(12537,770860269011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','3yy02ad9','sdi02ad9@yahoo.co.jp','YASUYUKI ABE','EAST 1-2-2<br>NISHINOSATO','KITAHIROSHIMASHI','Hokkaido','JAPAN','0611105','090-1304-5093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 14:50:55',0,NULL,3,1,2,1,'\\ ','3yy02ad9'),(12538,571401648003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','skystar1','miroslav.makara@gmail.com','Miroslav Makara','Plynarenska<br>7/C  ,9p accenture','Bratislava','Slovakia','SLOVAK REPUBLIC','82109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 14:51:58',0,NULL,3,1,3,1,'RA184584916CN\r ','skystar1\rBALO007'),(12539,855027667012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','m-tinchen0_3','martinahanser@web.de','Martina Hanser','Schönbergstrasse 20','Schallstadt','','GERMANY','79227','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 15:15:52',0,NULL,3,1,2,1,'\\ ','m-tinchen0_3 欧标'),(12540,627577988013,230393146954,'2.1 Acer Aspire 8920 8920G 8930 Bluetooth Module+cable',1,'BTAC2121',12.4,'eastar4','johan-vrinssen','johan.vrinssen@upcmail.nl','Johan Vrinssen','Hoge Notte 31','Nederweert','','NETHERLANDS','6031HW','0495842595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 15:18:51',0,NULL,3,1,2,1,'\\ ','johan-vrinssen\racer 8pin1.00 6cm （AS 8920 8920G 8930 ) 线序不同'),(12541,855036371012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','haszczak75','piotr.madera@gmail.com','Piotr Madera','Mojmirovo Namesti 22c','Brno','','CZECH REPUBLIC','61200','+420 774 536 984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 15:44:37',0,NULL,8,1,17,0,NULL,'haszczak75'),(12542,770885651011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',16.98,'eastar4','haszczak75','piotr.madera@gmail.com','Piotr Madera','Mojmirovo Namesti 22c','Brno','','CZECH REPUBLIC','61200','+420 774 536 984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 15:59:08',0,NULL,3,1,3,1,'RA184583235CN\r ','haszczak75  再发两个CAB-2660\rCASS003'),(12543,855050749012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','kaffeetrinken_88','kaffeetrinken88@googlemail.com','Tobias Wölk','Focko-Ukena-Str. 27','Wilhelmshaven','','GERMANY','26386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 16:14:07',0,NULL,3,1,3,1,'RA184584933CN\r ','kaffeetrinken_88\rGLOT005'),(12544,855055391012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','sbcraig','cbcorders@craigbusinessconsulting.com','Sean B. Craig','2852 Grimes Ranch Rd','Austin','TX','UNITED STATES','78732','(512) 266-9020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 16:24:26',0,NULL,3,1,1,1,'\\ ','sbcraig'),(12545,627600052013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','alexp2181','alexandrpach@yahoo.com','Alex Pach','2915 Old Court RD','Baltimore','MD','UNITED STATES','21208-3312','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 16:34:45',0,NULL,3,1,1,1,'\\ ','alexp2181'),(12546,576956705004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','nmye5663','naomidesiree@yahoo.com','Naomi Myers','6669 Cortez Cir','Ocean Springs','MS','UNITED STATES','39564-2334','(228) 282-5586','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-27 18:02:41',0,NULL,3,1,1,1,'\\ ','nmye5663'),(12547,571460426003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',4,'HSJA001',95.6,'cnfaner','txcubcadet','txpalladin@yahoo.com','14paul scarnato','562 S Highway 123 Byp<br># 197','seguin','TX','UNITED STATES','78155','(210) 241-4567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-27 18:24:41',0,NULL,3,1,1,1,'\\ ','txcubcadet'),(12548,770959109011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','krtule','netone@seznam.cz','Jaroslav Hamal','Albrechticka 14','Krnov','moravskoslezsky','CZECH REPUBLIC','79401','+420724692823','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 18:39:30',0,NULL,3,1,3,1,'RA184584947CN\r ','krtule\rGLOT001'),(12549,571468247003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','bo-hassan','hassan3003@gmail.com','Saad Aljuaidan','Ashaqeeq<br>P.O.Box # 30715','Alhasa','','SAUDI ARABIA','31982','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 18:42:57',0,NULL,3,1,3,1,'RA184583306CN\r\r ','bo-hassan\rHSNO004'),(12550,627649878013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',30,'WLAP008',536.4,'eastar4','maclike','paypal@vintagecomp.com','Hideki Muto','2909 Oregon Ct<br>Ste C8','Torrance','CA','UNITED STATES','90503-2681','(310) 320-4907','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 18:52:31',0,NULL,3,1,4,1,'YW866012023CN ','maclike'),(12551,627650927013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','scumeplul','ggombos@gmail.com','George Gombos','Bd Alexandru cel Bun 30, bl H3, ap 5','Iasi','Iasi','ROMANIA','700571','0040721566565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 18:55:47',0,NULL,3,1,3,1,'RA184583297CN\r ','scumeplul\rMOSA005'),(12552,855142752012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',29.98,'eastar4','whiteelefant','theozuhause2005@web.de','Theodor Sauerwein','Laengenfeldweg 8','Murnau','','GERMANY','82418','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 19:04:41',0,NULL,3,1,2,1,'\\ ','whiteelefant'),(12553,770982756011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','glowes2','lundell3@comcast.net','Glenn Lundell','7217 Hannah Brook Rd','Knoxville','TN','UNITED STATES','37918-0915','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 19:17:37',0,NULL,3,1,1,1,'\\ ','glowes2'),(12554,855164454012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','swamp2781','graham@gpmills.com','Graham Mills','163 Trysull Road<br>Merry Hill','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 7JP','01902336074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 19:40:21',0,NULL,3,1,3,1,'RA184583221CN\r ','swamp2781\rOTCN004*10'),(12555,627670451013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',16.99,'eastar4','elman78','elmansabre@gmail.com','Elman Suleymanov','Vitebskaya 3/1/655','Moscow','RU','RUSSIAN FEDERATION','121354','+7 916 509-8000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 19:44:40',0,NULL,3,1,2,1,'\\ ','elman78'),(12556,855156711012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','djamel682011','dja682000@gmail.com','jamel elarbaji','18221 150th Ave<br>JED 12115','Springfield Gardens','NY','UNITED STATES','11413-4010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 19:47:45',0,NULL,3,1,1,1,'\\ ','djamel682011'),(12557,855159031012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','glllom','gleb.omarov@gmail.com','Gleb Omarov','Aharon Zisling<br>20/8','Beer Sheva','Negev','ISRAEL','84486','0524241382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 19:33:32',0,NULL,3,1,2,1,'\\ ','glllom'),(12558,855175181012,220747230960,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',9.5,'eastar4uk','vgps1479','gandham_phani_srinivasan@yahoo.com','phani srinivasan gandham','stenbocksvägen 8','ronneby','blekinge','SWEDEN','37237','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 19:58:54',0,NULL,3,1,2,1,'\\ ','vgps1479'),(12559,771000635011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'eastar4','doublthreat','jordansearejones@gmail.com','Jordan Jones','1450 S West Temple<br>Apt H304','Salt Lake City','UT','UNITED STATES','84115-5495','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 20:02:32',0,NULL,3,1,1,1,'\\ ','doublthreat'),(12560,627679140013,230656397777,'New 3.0 Bluetooth BCM92070 Module+cable Asus UL50 UL80',1,'BTAS3002',19.99,'eastar4','telmo_sil','telmosil@gmail.com','Telmo Silva','Lavoura, nº92','Paços de Brandão','Aveiro','PORTUGAL','4535-288','964352280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 20:06:30',0,NULL,3,1,2,1,'\\ ','telmo_sil'),(12561,712463306008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',2,'HBPH007',97.98,'au-buy','spectrumau','mark.weinberger@me.com','Mark Weinberger','Level 6, 350 George Street','Sydney','New South Wales','AUSTRALIA','2000','0282564911','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 20:35:43',0,NULL,3,1,3,1,'RA184584142CN\r','spectrumau\rHBPH007'),(12562,627697573013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','jonanddanica','dajoloehr@hotmail.com','Danica Cuthbert','640 Princess rd','Kelowna','BC','CANADA','v1x2z1','(250) 491-3156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 20:58:20',0,NULL,3,1,2,1,'\\ ','jonanddanica'),(12563,855227779012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',79,'eastar4','aeldridgevoip','aeldridge@cinci.rr.com','Alex Eldridge','105 Lakefield Dr','Milford','OH','UNITED STATES','45150','(513) 633-6612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 21:41:35',0,NULL,3,1,1,1,'\\ ','aeldridgevoip'),(12564,627715722013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','glaucia_aguiar','glaucia_ponte@yahoo.com.br','Gláucia Aguiar Ponte Silva','Condominio Residencial das Palmeiras DF 475 Km 01 Rua 07 Casa 07<br>Ponte Alta Norte','Gama','DF','BRAZIL','72.457-995','(61) 34040905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 22:03:40',0,NULL,3,1,3,1,'RA184583252CN\r ','glaucia_aguiar\rMOSA004'),(12565,855238811012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','francois22011','francois.limoges@videotron.ca','francois limoges','2421 des oiseaux','laval','QC','CANADA','h7l 4x6','(450) 628-7739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 22:14:20',0,NULL,3,1,3,1,'RA184584862CN\r ','francois22011\rGLOT001'),(12566,627728567013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',69.9,'eastar4','rargilag','dakiteman@hotmail.com','raul argilagos','818 Bayview Dr','ruskin','FL','UNITED STATES','33570-2805','(813) 786-2041','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 23:00:12',0,NULL,3,1,1,1,'\\ ','rargilag'),(12567,627729819013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','chaconmonica','chaconmon1986@yahoo.com','monica chacon','302 Mill Stream Ln','houston','TX','UNITED STATES','77060-4117','(832) 768-8994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 23:05:54',0,NULL,3,1,1,1,'\\ ','chaconmonica'),(12568,771101101011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','matrudenko','mrudenko@gmail.com','Matthew Rudenko','109 Estate Garden Drive','Richmond Hill','ON','CANADA','L4E 3V6','(416) 277-5771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 00:25:38',0,NULL,3,1,2,1,'\\ ','matrudenko'),(12569,771103744011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','klg1948','k.l.g@blueyonder.co.uk','Ken Grey','17 Grindon Close<br>Monkseaton','Whitley Bay','Tyne and Wear','UNITED KINGDOM','NE25 9EB','01912525252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 00:44:28',0,NULL,3,1,2,1,'\\ ','klg1948'),(12570,771107378011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kancheta','kerry@kancheta.com','Kerry Ancheta','85 Leonard St<br>Apt 2','New York','NY','UNITED STATES','10013-3997','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 00:49:33',0,NULL,3,1,1,1,'\\ ','kancheta'),(12571,627754788013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','steveno68','stevensonnoreen@gmail.com','Noreen Stevenson','122 MacGregor Cres','Waterloo','ON','CANADA','N2J 3W9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 01:01:49',0,NULL,3,1,2,1,'\\ ','steveno68 \rSHOES pattern.'),(12572,855297674012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.99,'eastar4','ming7197','lamkylecnn@yahoo.com','LAM TRAN','5208 Fernbrook Dr','CENTREVILLE','VA','UNITED STATES','20120-1795','(703) 968-7661','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 01:23:57',0,NULL,3,1,1,1,'\\ ','ming7197'),(12573,8881317174868861,111,'apple 8GB disk',5,'UDAP001',192,'eastar4','carlosinternational','sixtysiete@gmail.com ','Carlos Velasco','Esqueira<br>C/Eladia Baylina 38 1-C','Ponferrada','Leon','SPAIN','24400 ','',NULL,NULL,NULL,'2011-09-28 01:54:28',0,NULL,3,1,3,1,'RA184585001CN ','UDAP001\r'),(12574,627769054013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',16.99,'eastar4','chathu92722','chathumina@hotmail.com','chathumina wijewantha','viveka pinikahan kahaduwa<br>elpitiya','Galle','Southern','SRI LANKA','80460','940776542777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 02:11:13',0,NULL,3,1,2,1,'\\ ','chathu92722'),(12575,771150540011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','teldoc','davidlfriedman@aol.com','David Friedman','1344 Amherst Terrace Way','Chesterfield','MO','UNITED STATES','63017-6010','(314) 952-4224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 03:35:01',0,NULL,3,1,1,1,'\\ ','teldoc'),(12576,577120981004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.99,'cnfaner','mohandev','mohanmendis@gmail.com','Mohan Mendis','C/o Senaratne Associates Ltd<br>Suite 408 4th Floor, Liberty Plaza','Colombo 3','','SRI LANKA','003','+94777315470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 06:23:29',0,NULL,3,1,3,1,'RA184584139CN\r ','mohandev\rOTTP001'),(12577,855224065012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','m4ttr4llye','matthew_jemmett2@hotmail.com','matthew jemmett','25 grosvenor road<br>swinton','manchester','Greater Manchester','UNITED KINGDOM','m27 5eg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 06:43:44',0,NULL,3,1,3,1,'RA184584902CN\r ','m4ttr4llye\rHBPH003'),(12578,855375984012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','makroli','bazaads@hotmail.com','Priyanka Singh','7 Opal Court','Kelso','New South Wales','AUSTRALIA','2795','0263323936','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 06:56:06',0,NULL,3,1,2,1,'\\ ','makroli'),(12579,771192826011,320731011543,'New DELL D630 D830 BCM4321 300Mbp PCI-E Card+antenna',1,'WLDE001+ANTY001',10.5,'eastar4uk','conq29','lrenaux6@gmail.com','RENAUX.LUCIEN','8 rue jos bolloré','concarneau','Bretagne','FRANCE','29900','06 07 61 51 92','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 07:15:24',0,NULL,3,1,2,1,'\\ ','conq29'),(12580,855386106012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','grigoriyroshka','nemora@inbox.ru','Roshka Grigoriy Alekseevich','St.-Petersburg,Yaroslava Gasheka street,house 4/3,flat147','St.-Petersburg','','RUSSIAN FEDERATION','192281','8127761388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 07:35:39',0,NULL,3,1,2,1,'\\ ','grigoriyroshka'),(12581,771197686011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','vlado.bg.85','vladimir_jj@abv.bg','Vladimir Yordanov','11 Izmail St; 5th ent; 2nd floor','Ruse','Ruse','BULGARIA','7013','++359878880848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 07:37:33',0,NULL,3,1,2,1,'\\ ','vlado.bg.85'),(12582,730130820001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',12.99,'buysia','joe_california','safari_joe@hotmail.com','Joe Baker','207 Arroyo Seco','Santa Cruz','CA','UNITED STATES','95060','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 07:47:00',0,NULL,3,1,1,1,'\\ ','joe_california'),(12583,771213035011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','gisellechao2011','gisellefchao@gmail.com','Giselle Fonseca Chao','Rua Edgar Falcão, 130 apto 402 Bloco D<br>Bairro Presidente Kennedy','Fortaleza','Ceara','BRAZIL','60356-090','+558532375651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 08:44:48',0,NULL,3,1,2,1,'\\ ','gisellechao2011'),(12584,771226945011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','robotronas','kaskamko@gmail.com','JP Architektura Lukas Narutis','Jasinskio 16','Vilnius','','LITHUANIA','LT-01112','0037061127207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 09:39:47',0,NULL,3,0,2,1,'\\ ','robotronas'),(12585,771228379011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','peted76','peted76@gmail.com','P Davies','21 St Fremund Way','Leamington Spa','Warwickshire','UNITED KINGDOM','cv31 1ab','07738424947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 09:45:19',0,NULL,3,1,3,1,'RA184584828CN\r ','peted76\rRELO003'),(12586,627842585013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',20,'UDAP003',339.8,'eastar4','rs8258','info@n-standard.jp','Ryo Shimada','2-1-213 Udagawa','Shibuya-ku','Tokyo','JAPAN','1500042','+81 90 21424956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 09:49:12',0,NULL,3,1,3,1,'RA184584434CN ','rs8258\rUDAP003'),(12587,771230629011,320402075801,'HP DV9500  Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.9,'eastar4','jackvdh','idioot28@hotmail.com','Jack Bloem','Prins Bernhardlaan 111','Leidschendam','','NETHERLANDS','2264CC','0642-398381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 09:54:45',0,NULL,3,1,2,1,'\\ ','jackvdh'),(12588,855430283012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','andypalmerusa','aerobatics@clear.net.nz','Andrew Palmer','797 Ellesmere Road<br>RD 2','Christchurch','','NEW ZEALAND','7672','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 10:23:08',0,NULL,3,1,2,1,'\\ ','andypalmerusa'),(12589,627856134013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','samanthac0789','correia.samantha@hotmail.com','Samantha Correia','30<br>Lothair Street','Pascoe Vale South','Victoria','AUSTRALIA','3044','614022604155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 10:59:14',0,NULL,3,1,3,1,'RA184584068CN\r ','samanthac0789\rMOSA005'),(12590,627882259013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','patreid75','preid@iworks.com.au','Patrick Reid','5 Lakeside Ave','Broadbeach Waters','Queensland','AUSTRALIA','4218','0756301143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 13:02:20',0,NULL,3,1,2,1,'\\ ','patreid75'),(12591,855481729012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','owlscohk','everay2003@yahoo.com','KWAN CHUN LEUNG','F14-C, Block 5, Hibiscus Court, World-wide Gardens<br>7 Lung Pak Street, Tai Wai, Shatin, N.T.,','default','','HONG KONG','default','(852) 91919841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 13:08:09',0,NULL,3,1,2,1,'\\ ','owlscohk'),(12592,627887450013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','drbillhafner','billh66@ucla.edu','Bill Hafner','5377 Godbey Dr','La Canada','CA','UNITED STATES','91011-1872','(818) 952-1534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 13:25:31',0,NULL,3,0,1,1,'\\ ','drbillhafner'),(12593,571691505003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','sollord','sollord@gmail.com','William Schweder','31435 Kelly Rd','Fraser','MI','UNITED STATES','48026-2489','(586) 294-0271','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 13:59:25',0,NULL,3,1,1,1,'\\ ','sollord'),(12594,855505581012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','fred23021988','fred88@bk.ru','Vladimir Sergeev','c/o Eastbiz Corp. 4310 W. 190th St. Suite # 57835','Torrance','CA','UNITED STATES','90504','926 172 0070','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 14:08:56',0,NULL,3,1,1,1,'\\ ','fred23021988'),(12595,771307098011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','stefan2kvaliant','dragon-12@hotmail.co.uk','Stefan Valiantis','39 Carpenter Way','Potters Bar','Hertfordshire','UNITED KINGDOM','EN6 5PZ','07974286118','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 14:15:24',0,NULL,3,1,3,1,'RA184584831CN\r ','stefan2kvaliant\rRELO003'),(12596,771313780011,320737064070,'New Samsung SSG-2200AR Rechargeable Adult 3D glasses',3,'GLSG005',176.97,'eastar4','selectgametienda','gusmlg86@hotmail.com','Agustín Manuel Almagro Rojas','C/de Aragonito 7-A','puerto de la torre (Málaga)','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 14:30:40',0,NULL,3,1,3,1,'RA184584085CN\r ','selectgametienda 申报10美金  注意是2200AR  库里只有三个\rGLSG005'),(12597,855518791012,220816384245,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',78.99,'eastar4uk','daki9851','daki985@hotmail.com','Dalibor Malenovic','Docentgatan 2b','Malmö','Skåne','SWEDEN','21552','0762749050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 14:41:06',0,NULL,3,1,3,1,'RA184584156CN\r ','daki9851\rGLOT001*3'),(12598,627912020013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',9.9,'eastar4','true2u1','rgarland@pinnacledesigns.tv','Richard Garland','9101 Midway Dr','Woodway','TX','UNITED STATES','76712','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 15:00:55',0,NULL,3,1,1,1,'\\ ','true2u1'),(12599,855535180012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','frmichaud','frmichaud@yahoo.com','Francois MICHAUD-HERBST','2680 Chatham Street','LONGUEUIL','QC','CANADA','J4L 2E6','(450) 651-8230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 15:21:21',0,NULL,3,1,2,1,'\\ ','frmichaud'),(12600,771335594011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','karloworld','karlosworld@yahoo.com','Karlo Gomez','11860 Boylan Ave','Baton Rouge','LA','UNITED STATES','70809-5166','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 15:25:29',0,NULL,3,1,1,1,'\\ ','karloworld'),(12601,855544009012,220723590911,'New Genuine Motorola H700 Bluetooth Wireless Headset',1,'HSMO011',53.88,'eastar4uk','j.adel','e.adel@arcor.de','JALCO Autoteile','Dahlien Str. 4 a<br>(Gewerbegebiet Rosenstrasse)','Bad Segeberg','','GERMANY','23795','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 15:43:51',0,NULL,3,1,3,1,'RA184584023CN\r ','j.adel  再发两个motorola 710耳机 送欧标头\rHSMO011'),(12602,571723160003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',12.99,'cnfaner','spirosks','spiroskod@tellas.gr','SPIROS KONTOPOULOS','KORINIS 24<br>GALATSI','ATHENS','GREECE','GREECE','11146','2102221820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 16:12:39',0,NULL,3,1,3,1,'RA184584814CN\r ','spirosks 欧标头\rHSNO004'),(12603,855558627012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',57.98,'eastar4','mchar60','marc-etienne.charron@polymtl.ca','Marc-Etienne Charron','3541 Dorion','Montreal','QC','CANADA','H2K4B7','(514) 660-3704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 16:17:10',0,NULL,3,1,3,1,'RA184584859CN\r ','mchar60\rMOAP001'),(12604,771364271011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','david1569','david15@centurylink.net','David West','442 Tyndallwood Dr','Stedman','NC','UNITED STATES','28391-9621','(910) 630-2118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 16:38:34',0,NULL,3,1,1,1,'\\ ','david1569'),(12605,771367639011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','methos-de','frank@f-meissner.eu','Frank Meißner','Am Redinger Bach 26','Neuhaus','','GERMANY','94152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 16:45:36',0,NULL,3,1,2,1,'\\ ','methos-de'),(12606,855572958012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','scoobydooenterprises','stevemay@hotmail.co.uk','Mr Steve May','Flat 2A<br>72 Portmore Park Road','Weybridge','Surrey','UNITED KINGDOM','KT13 8HH','07888898871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 16:47:48',0,NULL,3,1,3,1,'RA184584845CN\r ','scoobydooenterprises\rOTCN004*10'),(12607,627943649013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP003',19.99,'eastar4','kevinlao','kevinlao123@livemail.tw','Guanzhao Lao','751 Santa Clara Ave','Alameda','CA','UNITED STATES','94501-3317','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 16:52:10',0,NULL,3,1,1,1,'\\ ','kevinlao'),(12608,771372200011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','fillionster','david.fillion@cogeco.ca','David Fillion','2115 Mount Royal Ave','Burlington','ON','CANADA','L7P 1R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 16:56:11',0,NULL,3,1,2,1,'\\ ','fillionster'),(12609,771374050011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','olsen94','olsen94@gmail.com','Garrett Olsen','13312 Beall Creek Ct','Potomac','MD','UNITED STATES','20854-1117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 17:00:04',0,NULL,3,1,1,1,'\\ ','olsen94'),(12610,771394990011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','doumat','yyz01@rogers.com','Doug Brown','31 Anvil Millway','Toronto','ON','CANADA','M2L1P9','(416) 277-7584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 17:43:18',0,NULL,3,1,2,1,'\\ ','doumat'),(12611,577260727004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','alvidy','alekss1375@mail.ru','Aleksey Dydykin','ul. Michurina, dom 1, kv168','Saransk','','RUSSIAN FEDERATION','430027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 17:49:14',0,NULL,3,1,2,1,'\\ ','alvidy 欧标头'),(12612,771408572011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','tyron_mitchell','aktion.jackson@gmx.de','Razvan Badicescu','Grazer Str. 49','Duisburg','','GERMANY','47249','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:13:00',0,NULL,3,1,2,1,'\\ ','tyron_mitchell'),(12613,855617826012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','antonius2463','bmw325i@gmx.net','Luaces Antonio','Offenburgerstrasse 55','Basel','','SWITZERLAND','4057','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 18:14:37',0,NULL,3,1,2,1,'\\ ','antonius2463'),(12614,771416236011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.99,'eastar4','kenjin67','kty034@hotmail.com','oktay pöhrenk','Maltepe Mah.Gumussuyu cad.Birtas San.Sit. no:61/4 Bayrampasa','Istanbul','','TURKEY','34010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:23:07',0,NULL,3,1,2,1,'\\ ','kenjin67  欧标头'),(12615,627982002013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','svekk09','svekk@online.no','Svein Bekken','Sykehusvegen 14','Skarnes','Hedmark','NORWAY','2100','+4791610138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:34:54',0,NULL,3,0,3,1,'RA184584108CN\r ','svekk09  欧标头\rHSNO019'),(12616,771438342011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','janne.kovanen','janne.kovanen@gmail.com','Janne Kovanen','Pohjanniementie 3 B 13','Jyväskylä','','FINLAND','40250','050-3700375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 19:00:54',0,NULL,3,1,2,1,'\\ ','janne.kovanen'),(12617,571801896003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'cnfaner','gene10000','gene_lesage@yahoo.com','Gene LeSage','207 Highland Ridge Ter','Johnson City','TN','UNITED STATES','37615','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 20:14:50',0,NULL,3,1,1,1,'\\ ','gene10000'),(12618,771494069011,320738499561,'New Portable Funny Wine Bottle Folding Sun Umbrella',1,'UM00030',7.95,'eastar4','sharpeaw','allen.w.sharpe@gmail.com','Allen Sharpe','17 Pennsylvania Ave','Lockport','NY','UNITED STATES','14094-5725','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 20:42:17',0,NULL,5,0,18,1,NULL,'sharpeaw'),(12619,771483455011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','211016349','tcprijatel@adelphia.net','TOM PRIJATEL','6684 BREEZEWOOD DR','CONCORD twp','OH','UNITED STATES','44077','(440) 354-6532','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 20:36:25',0,NULL,3,1,1,1,'\\ ','211016349'),(12620,628037078013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','huboy403','wi11hu@hotmail.com','Will Hu','Suite 900, 707-7 Ave SW','Calgary','AB','CANADA','T2P3H6','(403) 714-5675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 21:03:15',0,NULL,3,1,2,1,'\\ ','huboy403'),(12621,855718545012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','fabiomelettirj','meletti@msn.com','Fabio Meletti de Oliveira Barros','Rua Pierre Laplace, 135<br>Anil','Rio de Janeiro','RJ','BRAZIL','22755270','+55-21-9321-9109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 21:06:14',0,NULL,3,1,3,1,'RA184584099CN\r ','fabiomelettirj\rGLOT001'),(12622,771505708011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',105.99,'eastar4','durbin918','durbinf@aol.com','Eugene','1033 Windsor St.','Flint','MI','UNITED STATES','48507','(810) 223-1063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 21:12:14',0,NULL,3,1,1,1,'\\ ','durbin918'),(12623,855733066012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','brentmille','brentmil@earthlink.net','Brent Miller','8445 Harvard Park Dr','Sandy','UT','UNITED STATES','84094-1204','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 21:35:29',0,NULL,3,1,6,1,'EE495359790CN ','brentmille'),(12624,628048611013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','valeriy500','cosmos2009@mail.com','Valeriy Sidorov','Basseynaya street 71-93, Russia 196211<br>Russia 196211','Sankt-Peterburg','Russia','RUSSIAN FEDERATION','196211','911-823-1943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 21:41:07',0,NULL,3,1,3,1,'RA184584765CN\r ','valeriy500\rWLIN014'),(12625,771519840011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','mbridea','mbridea@hotmail.com','Adrian Bridea','1250 Limeridge Rd. East, Unit #41','hamilton','ON','CANADA','l8w 1p1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 21:43:27',0,NULL,3,1,2,1,'\\ ','mbridea'),(12626,771526015011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','t90n','t9a12@yahoo.com','Tung Nguyen Hoang','18012 Hiawatha St<br>Apt 183B','Northridge','CA','UNITED STATES','91326-4204','(310) 404-4632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 21:59:38',0,NULL,3,1,1,1,'\\ ','t90n'),(12627,855743885012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','vrozkovec','vit.rozkovec@gmail.com','Vit Rozkovec','Blanická 17','Praha','Czech Republic','CZECH REPUBLIC','12000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 22:01:55',0,NULL,3,1,2,1,'\\ ','vrozkovec'),(12628,855747397012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','gilbertadam','adg34@cam.ac.uk','Mr Adam Gilbert','28, Ralph Court<br>Queensway','London','London','UNITED KINGDOM','W25HT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 22:13:05',0,NULL,3,1,3,1,'RA184584774CN\r ','gilbertadam\rHBPH003'),(12629,766954583011,320621692447,'Apple Airmac/Airport Wireless WiFi Card iMac iBook eMac',1,'WLAP001',12.99,'eastar4','bvw11','britt1988@hotmail.com','Britt van Waveren','Spreeuwenpark 38A','AMSTERDAM','','NETHERLANDS','1021GX','0031613843954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 22:18:07',0,NULL,3,1,2,1,'\\ ','bvw11'),(12630,628067740013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','cintiadelfino','cintiadelmach@hotmail.com','Cíntia Machado','Rua Bélgica','Canoas ','Rio Grande do Sul','BRAZIL','92022075','05134758515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 22:59:49',0,NULL,3,1,2,1,'\\ ','cintiadelfino'),(12631,855766650012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.4,'eastar4','dainsmail-1','dainsmail-ebay@yahoo.com','David Ainsburg','9500 Jollyville Rd<br>APT 125','Austin','TX','UNITED STATES','78759-7271','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 23:18:42',0,NULL,3,1,1,1,'\\ ','dainsmail-1'),(12632,628075969013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','albimmer','alam225@yahoo.com','ALBERT LAM','3927 International Blvd','oakland','CA','UNITED STATES','94601-4011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 23:38:29',0,NULL,3,1,1,1,'\\ ','albimmer'),(12633,628079394013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',16.89,'eastar4','rygyryan','x.ray.cat@gmail.com','Ryan Munday','212-1414 17 ST SE','Calgary','AB','CANADA','T2G5S6','(403) 998-0233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 00:01:50',0,NULL,3,1,2,1,'\\ ','rygyryan  再加一个电源'),(12634,855793203012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',2,'HSPL011',27.7,'eastar4uk','sjaddict!!!!','missmonroeproductions@yahoo.com','Laura Fresso','13114 Delaware St','Crown Point','IN','UNITED STATES','46307-9131','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 00:44:49',0,NULL,3,1,1,1,'\\ ','sjaddict!!!!'),(12635,855800607012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',14.95,'eastar4','mullinrs','rsmullins@comcast.net','Robert Mullins','11 Deer Run Rd','Manakin Sabot','VA','UNITED STATES','23103','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 01:08:37',0,NULL,3,1,1,1,'\\ ','mullinrs'),(12636,855809353012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',2,'MOMI002',27.58,'eastar4','murabnoob','rafaeltsb@gmail.com','Rafael Brites','Rua Campos Salles,2063<br>Bairro dos Alemães','Piracicaba','Sao Paulo','BRAZIL','13416-310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 01:38:37',0,NULL,3,1,3,1,'RA184584071CN\r','murabnoob\rMOMI002'),(12637,771588382011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',7.57,'eastar4','clricee','clricee12345@yahoo.com','charlie riley','654 crabapple place','macon','GA','UNITED STATES','31217','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 01:40:49',0,NULL,3,1,1,1,'\\ ','clricee'),(12638,628102925013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','terrydavidphoto','terry@terrypeckham.com','Terry Peckham','PO Box 3059','Robina Town Centre','Queensland','AUSTRALIA','4230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 01:53:37',0,NULL,3,1,2,1,'\\ ','terrydavidphoto'),(12639,771594548011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jorgengmj','jorgeng@arc.losrios.edu','Greg Jorgensen','PO Box 241<br>6891 Marshall Road','Coloma','CA','UNITED STATES','95613','(530) 295-4982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 02:03:14',0,NULL,3,1,1,1,'\\ ','jorgengmj'),(12640,855821762012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','bobros','bobros@ptd.net','Robert rosendale','137 Daniel Boone Rd','Birdsboro','PA','UNITED STATES','19508-8729','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 02:19:31',0,NULL,3,1,1,1,'\\ ','bobros'),(12641,628121225013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','bugsly68','info@photoprintproducts.com','Brendan Hill','22 Philip Street','Redbank Plains','Queensland','AUSTRALIA','4301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 03:15:17',0,NULL,3,1,2,1,'\\ ','bugsly68'),(12642,855840702012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',13.19,'eastar4','sandiebeach111','sandiebeach@hughes.net','andrea mckinney','135 Rockfort Rd<br>Apt 136','pikeville','TN','UNITED STATES','37367-5251','(423) 718-8185','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 03:34:56',0,NULL,3,1,1,1,'\\ ','sandiebeach111'),(12643,571892535003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'cnfaner','pataklysm1969','pataklysm@hotmail.com','Patrick Renfro','8685 Summer Pointe Dr','Elk Grove','CA','UNITED STATES','95624-3427','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-29 03:49:43',0,NULL,3,1,1,1,'\\ ','pataklysm1969'),(12644,628128689013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.95,'eastar4','adenaden','lilybeel@yahoo.com','Aden Ayesha','101, 1745<br>bloor street','Mississauga','ON','CANADA','l4x 1s6','(289) 232-4017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 04:01:34',0,NULL,3,1,2,1,'\\ ','adenaden'),(12645,769053739011,320741897705,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',56.99,'eastar4uk','are_gone21','hasrul.hashim@dbschenker.com','Hasrul Hashim','no.6-1<br>Bandar Bukit Tinggi 2,','KLANG','SELANGOR','MALAYSIA','41200','0193035031','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 04:50:52',0,NULL,3,1,3,1,'RA184584010CN\r ','are_gone21\rGPS0002'),(12646,628136540013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jimautoman0','jcole100@hotmail.com','jim cole','13130 Carriage Rd<br>Apt 3','poway','CA','UNITED STATES','92064','(858) 848-4204','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jimautoman0\recheck'),(12647,855872194012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',9.99,'eastar4uk','asm4849','asm4849@gmail.com','Asmawie Ab Jalil','F-5-4 Pangsapuri Mawar Sari, Jln 17/56 Ampang Ulu Kelang,<br>AU3, 54200 Kuala Lumpur','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','54200','017-6454921','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 06:06:09',0,NULL,3,1,2,1,'\\ ','asm4849'),(12648,771647942011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','techguru_pal','kuteosj@gmail.com','Binh Le','255 Shoreline Dr<br>Coraid Inc Ste 650','Redwood City','CA','UNITED STATES','94065-1431','(650) 730-5128','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 06:20:25',0,NULL,3,1,1,1,'\\ ','techguru_pal'),(12649,855875937012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','juanjo3535','juanjo3535@hotmail.com','Juan José Martínez Fernández','Doctor cuatrecasas, nº34<br>Urb. La Solana','Vallirana','Cataluña','SPAIN','08759','629637969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 06:21:58',0,NULL,3,1,2,1,'\\ ','juanjo3535'),(12650,571911352003,130490602003,'HP Broadcom BCM94322 bcm4322 half mini PCI-E card+2 an',1,'WLHP002+ANTY001',19.45,'cnfaner','digital_weenie','dan.rothwell@ii.net','Dan Rothwell','Unit D<br>53 Troy Tce','Jolimont','Western Australia','AUSTRALIA','6014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 06:24:40',0,NULL,3,1,2,1,'\\ ','digital_weenie'),(12651,855876450012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',28.99,'eastar4','bulanbek','bulantulakpayev@gmail.com','Bulatbek Tulakpayev','ul. Yubileynaya, d.3, kv.3','Karaganda','Karagandinskaya obl','KAZAKHSTAN','100000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 06:27:50',0,NULL,3,1,2,1,'\\ ','bulanbek'),(12652,855896006012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',24.99,'eastar4uk','marko_ven','marko.venalainen@nic.fi','Marko Venäläinen','Kolsarintie 8','KANTVIK','Finland','FINLAND','02460','+358503324116','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 07:51:50',0,NULL,3,1,3,1,'RA184584125CN ','marko_ven\rHSNO019'),(12653,855903542012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','fridgeman01','iccaminada@yahoo.com','Ivo Caminada','Sir Winston Churchilllaan 125','Rijswijk ZH','','NETHERLANDS','2282JN','0707552000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 08:22:58',0,NULL,3,1,2,1,'\\ ','fridgeman01'),(12654,628174141013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','petert5237','trapp_p@internode.on.net','Peter Trapp','23 English Street','HAHNDORF','South Australia','AUSTRALIA','5245','0883887615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 09:12:56',0,NULL,3,1,2,1,'\\ ','petert5237'),(12655,571935859003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',64.99,'cnfaner','nikhil3175','veenanz@yahoo.co.nz','Praveen Lata Singh','5a Johnston Road<br>Mt Wellington','Auckland','','NEW ZEALAND','1060','(09) 580 -2170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 09:25:21',0,NULL,3,1,3,1,'RA184584173CN ','nikhil3175\rMOSA003'),(12656,855920904012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','swamp2781','graham@gpmills.com','Graham Mills','163 Trysull Road<br>Merry Hill','WOLVERHAMPTON','West Midlands','UNITED KINGDOM','WV3 7JP','01902336074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 09:32:12',0,NULL,3,1,3,1,'RA184584235CN','swamp2781\rOTCN004*10'),(12657,855925651012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','muhammodalee','susiealan@bigpond.com','ALAN LEE','9 PICASSO PLACE<br>NEWNHAM','LAUNCESTON','Tasmania','AUSTRALIA','7248','0363265568','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 09:50:05',0,NULL,3,1,2,1,'\\ ','muhammodalee'),(12658,628180186013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','moreau2157','antony.moreau@free.fr','Anthony Moreau','5 rue de la Brasserie','Nantes','Pays de la Loire','FRANCE','44100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 10:01:59',0,NULL,3,1,2,1,'\\ ','moreau2157'),(12659,855931595012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',4,'HSMO010',35.96,'eastar4uk','lmsqldpty','lmsqld@iprimus.com.au','LARRY SPENCER','20 WEIR STREET','MOOROOKA','Queensland','AUSTRALIA','4105','0738488206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 10:12:31',0,NULL,3,1,3,1,'RA184584394CN ','lmsqldpty  澳标头\rHSMO010'),(12660,771700774011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','fordfan5859','steve@mascotmont.com.au','Steve Canard','17 Lakeview drive','Nth Bundaberg','Queensland','AUSTRALIA','4670','0741544544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 10:17:18',0,NULL,3,1,3,1,'RA184584377CN ','fordfan5859\rGLOT001*3'),(12661,855936431012,220815928644,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',13.5,'eastar4uk','hakantezcan','htezcan@hotmail.com','HAKAN TEZCAN','Rauf Denktas Cad., Patara Sitesi<br>No:21/2, Mersin 10 Turkey','KKTC / Girne','ICEL','TURKEY','33030','00905338616881','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 10:33:17',0,NULL,8,1,17,0,NULL,'hakantezcan'),(12662,851505393012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','jaurdonjo','collis-smithp@orange.net','Paul Collis-Smith','9 Lolwand Avenue<br>Leicester Forest East','Leicester','Lecestershire','UNITED KINGDOM','LE3 3PA','07817547826','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 10:45:00',0,NULL,3,1,3,1,'RA184584227CN ','jaurdonjo\rOTCN004*10'),(12663,771709917011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','hakantezcan','htezcan@hotmail.com','HAKAN TEZCAN','Rauf Denktas Cad., Patara Sitesi<br>No:21/2, Mersin 10 Turkey','KKTC / Girne','ICEL','TURKEY','33030','00905338616881','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 10:51:53',0,NULL,3,1,3,1,'RA184584346CN ','hakantezcan WLIN010+ANTY 002 再发一个\rIntel 5300 AGN MIMO Wireless Network Mini PCI-E Card'),(12664,855948376012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','okashii_kitsune','ksufkaxd@gmail.com','Kseniya Zateeva','Hudoznikov prospect, 31-2-11','Saint-Petersburg','','RUSSIAN FEDERATION','194295','+7-904-645-96-06','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 11:14:55',0,NULL,3,1,2,1,'、 ','okashii_kitsune  \r咖啡色  \r'),(12665,571102218003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',20,'WWSI005+ANCN001',818,'cnfaner','bumark','compras@bct.com.ar','BCT BUMARK / Gaston','7923 NW 21st St','Doral','FL','UNITED STATES','33122-1616','(305) 592-9203 ext.: 1111','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-29 11:48:28',0,NULL,3,1,4,1,'YW866012185CN ','新地址\rBCT BUMARK - Andrew \r7923NW 21ST Miami Florida 33122 \rUnited states \r(305) 592-9203 ext.: 1111'),(12666,855960509012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','blackvish','swamifeatshanky@hotmail.com','Shashank Chauhan','7 Ryde grove<br>Acocks Green','birmingham','West Midlands','UNITED KINGDOM','B27 7SW','07525448815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 11:53:32',0,NULL,3,1,2,1,'\\ ','blackvish'),(12667,628203956013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','vershinin_dmitry','vershinin_72@mail.ru','Dmitriy Vershinin','Gagarina 81 fl 39','Krasnodar','','RUSSIAN FEDERATION','350062','9183334660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 11:56:25',0,NULL,3,1,2,1,'\\ ','vershinin_dmitry'),(12668,0,120782239476,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',19,'buysia','wongkamfai51','wongkamf@hotmail.com','kam wong','1974 W 5th St','brooklyn','NY','UNITED STATES','11223-2650','(917) 582-6689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 11:57:43',0,NULL,3,1,1,1,'\\ ','wongkamfai51'),(12669,855970862012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',3,'WLIN013',32.97,'eastar4uk','asterixnl','cinto@vveen.demon.nl','Cinto van Veen','Grote Bickersstraat 74','Amsterdam','','NETHERLANDS','1013 KS','020-5225858','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 12:36:18',0,NULL,3,1,3,1,'RA184584332CN ','asterixnl\rWLIN013'),(12670,628214481013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','amysgrammy','sjbehling@suddenlink.net','John   Behling','117 Fineza Way','Hot Springs Village','AR','UNITED STATES','71909','(501) 915-0972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 12:46:36',0,NULL,3,1,1,1,'\\ ','amysgrammy'),(12671,855984927012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',6,'HSSA002',65.94,'eastar4uk','marios290178','m_georgiou@hotmail.com','Marios Georgiou','104 road Parodos A No 4<br>Pano Polemidia','Limassol','Cyprus','CYPRUS','4130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 13:08:00',0,NULL,3,1,3,1,'RA184584111CN','marios290178 欧标头\rHSSA002'),(12672,771755609011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','karajak159','jakub.karasek.cze@gmail.com','Jakub Karásek','Na Pískovně<br>651','Liberec [Liberec]','58','CZECH REPUBLIC','46014','0604371344','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 13:28:56',0,NULL,3,1,2,1,'\\ ','karajak159'),(12673,571982801003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','blue1163','chris@therowats.info','Chris  Rowat','#2200, 101 - 6 Ave S.W. ','Calgary','AB','CANADA','T2P3P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 13:41:47',0,NULL,3,0,3,1,'RA184584289CN ','blue1163\rBALO007'),(12674,628237459013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','digippal','digitpall@gmail.com','Vaganov Vasiliy','3 Schorsa str. 8-66','Minsk','','BELARUS','220089','(375) 291-6403 ext.: 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 14:27:40',0,NULL,3,1,3,1,'RA184584363CN ','digippal\rGLOT001*2'),(12675,628237661013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','sviswan','shyam.vishi@gmail.com','Shyam Viswanath','9127 Falling Waters Dr E','burr ridge','IL','UNITED STATES','60527-0716','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 14:28:18',0,NULL,3,1,1,1,'\\ ','sviswan \r新地址：\rShyam Viswanath\r 3310 Louisiana street, \r apt 2112,\r Houston, Tx, 77006\rUnited States'),(12676,628240883013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',57.99,'eastar4','deng2010996','2010996@gmail.com','guoyi deng','8 danilack court','toronto','ON','CANADA','m1y4l7','(416) 275-9640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 14:41:23',0,NULL,3,1,3,1,'RA184584213CN','deng2010996\rBAZA001'),(12677,856024154012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',3,'HSMO017',26.97,'eastar4uk','blackbeltjonest','turul_umit@hotmail.com','Turul Umit','IMS London Limited<br>1st Floor, Dean House, 193 High Street','Ponders End','Middlesex','UNITED KINGDOM','EN3 4DZ','07961345237','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 14:57:40',0,NULL,3,1,3,1,'RA184584195CN ','blackbeltjonest\rHSMO017'),(12678,771784136011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.4,'eastar4','3-2-1-futsch','ingo.fischer@arcormail.de','Ingo Fischer','Holunderweg 2','Altenberge','','GERMANY','48341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:00:31',0,NULL,5,0,18,0,'','3-2-1-futsch'),(12679,856025383012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',17.5,'eastar4','rana_iftikhar_ahmad','fresh.noun@yahoo.com','RANA-IFTIKHAR AHMAD','19<br>STEPHENSON WHARF','HEMEL HEMPSTEAD','Hertfordshire','UNITED KINGDOM','HP3 9WZ','07950390209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:00:51',0,NULL,3,1,3,1,'RA184584403CN ','rana_iftikhar_ahmad\rANCN002'),(12680,628253738013,230667063783,'New Apple 4GB USB PEN KEY FLASH DRIVE U disk',4,'UDAP003',79.96,'eastar4','veritydawn','veritydawn.contact@yahoo.ca','Verity Hill','33 Holly St.<br>Apt. 311','Toronto','ON','CANADA','M4S 2G8','(647) 774-7405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:32:07',0,NULL,3,1,3,1,'RA184589533CN\r ','veritydawn\rUDAP003\r由于缺货  客户回复同意要三个  退一个的钱'),(12681,628253972013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','humphries5902','l_humphries@bellsouth.net','Linda Humphries','8116 Rhanbuoy Rd','SPRING HILL','FL','UNITED STATES','34606','(352) 592-2511','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 15:33:29',0,NULL,3,1,1,1,'\\ ','humphries5902'),(12682,628053240013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','fernynunezcasas','fernunezcasas@hotmail.com','Fernando Nunez','9660 Joe Rodriguez<br>Suite 1','El Paso','TX','UNITED STATES','79927-2142','(915) 859-9557 ext.: 2012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 15:42:27',0,NULL,3,1,1,1,'\\ ','fernynunezcasas'),(12683,856042567012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','wallyworld136','wesreynolds@hotmail.com','Wesley W Reynolds','16240 San Pedro Ave<br>Lot 212','San Antonio','TX','UNITED STATES','78232-3006','(210) 385-3804','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 15:45:18',0,NULL,3,1,1,1,'\\ ','wallyworld136'),(12684,856046221012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','lvenok1968','tolchev_n@list.ru','Kuznetsov Alexey','Toganas Batira street , dom 6','Kizilorda','','KAZAKHSTAN','120009','(7242)224662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:56:31',0,NULL,3,0,2,1,'\\ ','lvenok1968  \r已入库'),(12685,577536578004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','abegil','abegil4@bezeqint.net','Abraham Gilboa','6, Golomb str','Ramat Hasharon','Israel','ISRAEL','47414','+97235492011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 16:10:15',0,NULL,3,1,3,1,'RA184584200CN ','abegil\rHSPL015'),(12686,771818311011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.99,'eastar4','nelke4570','g.wenzl@gmx.net','Wenzl Gerhard','Griesgasse 20/<br>1/9','Graz','','AUSTRIA','8020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 16:31:03',0,NULL,3,1,3,1,'RA184584301CN ','nelke4570  欧标头\rHSNO019'),(12687,856062707012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','riowhite','showsyergoose@yahoo.co.uk','Gary White','187 clement rise<br>dedridge','livingston','West Lothian','UNITED KINGDOM','eh546lp','07986435895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 16:32:26',0,NULL,3,1,3,1,'RA184584451CN ','riowhite\rGLOT001'),(12688,856061868012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',99.9,'eastar4uk','don-bx11','hae_tho_don@gmx.de','Thomas Häckl','Geschwister-Scholl-str.38','Donauwörth','','GERMANY','86609','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 16:34:40',0,NULL,3,1,3,1,'RA184584275CN ','don-bx11\rWLAP008'),(12689,713193728008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',63.98,'au-buy','vearrier2','tvearrier@yahoo.com','T.  Vearrier','508 Sunrise Creek Rd','SUPERIOR','MT','UNITED STATES','59872-9486','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 16:41:53',0,NULL,3,1,1,1,'\\ ','vearrier2\rHSPL010'),(12690,771828956011,320721866865,'New lady lace trim sun/rain stick Umbrella 6 colors',1,'UM00011',15.95,'eastar4','73wickedbelladonna','wickedbelladonna73@yahoo.com','Shellee White','635 Argonaut St','Manteca','CA','UNITED STATES','95336-3616','(209) 406-3212','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 16:58:30',0,NULL,8,1,17,0,NULL,'73wickedbelladonna    '),(12691,856073577012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',49.98,'eastar4','73wickedbelladonna','wickedbelladonna73@yahoo.com','Shellee White','635 Argonaut St','Manteca','CA','UNITED STATES','95336-3616','(209) 406-3212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 16:59:33',0,NULL,3,1,3,1,'RA184584385CN ','  UM00010  一共三把伞   白色的钢琴伞   再发一个New lady lace trim sun/rain stick Umbrella 褐色的\r\rNEW Auto folding parasol sun umbrella w/lace black+red\r\r'),(12692,771830006011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',27.99,'eastar4uk','jerovillar','jvalonso54@yahoo.es','Jeronimo Villar Alonso','Avd. Galicia,38 - 1º D','Zamora','Castilla y León','SPAIN','49024','659154500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 17:11:19',0,NULL,3,1,3,1,'RA184584315CN ','jerovillar\rOTPL001'),(12693,771838517011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','j8s8n','m888w@ymail.com','Kam Wah Wong','Flat 3<br>18 Alfred Street','Bath','Somerset','UNITED KINGDOM','BA1 2QU','01225319970','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 17:21:58',0,NULL,3,1,3,1,'RA184584258CN ','j8s8n 带盒子的\rWLAT011'),(12694,771842677011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','313877607','malchin.natalia@gmail.com','Natalia Malchin','Iftah 16/7','Tel aviv','none','ISRAEL','67314','52-8373-546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 17:30:48',0,NULL,3,1,2,1,'\\ ','313877607'),(12695,771853233011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','housed84','housed84@windstream.net','Don House','624 S. Magnolia St','Mooresville','NC','UNITED STATES','28115','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-29 17:52:37',0,NULL,3,1,1,1,'\\ ','housed84'),(12696,572046224003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','universe4goods','master_ebay888@yahoo.com','Chaleam Sriwantana','Department of Civil Aviation<br>71 Soi NgamDoPree King Rama4 Rd. ThunMaHaMeak','Sathon','Bangkok','THAILAND','10120','668-9421-2689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 17:57:00',0,NULL,3,1,3,1,'RA184584261CN ','universe4goods\rHSMO020'),(12697,572053755003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','cosmo515','jon@levincpa.com','Jon Levin','1251 S Cedar Crest Blvd<br>Suite 209','Allentown','PA','UNITED STATES','18103-6205','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-29 18:20:09',0,NULL,3,1,1,1,'\\ ','cosmo515'),(12698,572055054003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',21.95,'cnfaner','lunatishe','krimop@list.ru','Gutorov Evgenij','Kirovskij rajon<br>Gagarina 14/70','Otradnoe','','RUSSIAN FEDERATION','187330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 18:24:39',0,NULL,3,1,3,1,'RA184584329CN ','lunatishe\rHSUE003'),(12699,771871115011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','cbeakley','charlotte@whimsywishes.com','Charlotte Beakley','1515 Cannon Pkwy<br>Apt 1721','Roanoke','TX','UNITED STATES','76262-6480','(480) 747-5067','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 18:27:55',0,NULL,3,1,1,1,'\\ ','cbeakley'),(12700,771873698011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','anoe9397','amanda.jean@hotmail.com','Amanda Noel','The Colorado College, Worner box 1691<br>902 N. Cascade Avenue','Colorado Springs','CO','UNITED STATES','80122','(303) 503-5821','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 18:31:46',0,NULL,3,1,1,1,'\\ ','anoe9397'),(12701,856162488012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','flying_kat','family@raybrowne.co.uk','Raymond A Browne','Farthingstone Barn','Little Urswick. Ulverston','Cumbria','UNITED KINGDOM','LA12 0PN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 19:38:22',0,NULL,3,1,2,1,'、 ','flying_kat'),(12702,771909750011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3002',19.99,'eastar4','scuro2','scuro@speleo.ch','Martin Schneider','Mühlemattstrasse 41','Bern','','SWITZERLAND','3007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 19:41:37',0,NULL,3,1,2,1,'\\ ','scuro2'),(12703,628346292013,230545855042,'Acer TM 3000 3020 /AS5760 Bluetooth Module2.0+cable',1,'BTAC2024',9.9,'eastar4','budapestconnection','varga.lukacs@gmail.com','Unisys Mo. Kft / Varga Lukacs Peter','Westend Office Center A Torony<br>Vaci ut 1-3','Budapest','','HUNGARY','1062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 20:04:13',0,NULL,3,1,2,1,'\\ ','budapestconnection'),(12704,856187154012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',19.98,'eastar4uk','spspaschal','sppaschal@gmail.com','Stavros Paschalidis','Papanika 36','Acharne','προεπιλογή','GREECE','13671','+306977149393','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 20:22:45',0,NULL,3,1,3,1,'RA184584350CN ','spspaschal\rWLAP008'),(12705,628360277013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',5.96,'eastar4','valdimar72','vshkuratov@gmail.com','Vladimir Shkuratov','ul. Melnikayte d.103 kv.17','Tyumen','Tyumen region','RUSSIAN FEDERATION','625026','+79519889380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 20:42:34',0,NULL,3,1,2,1,'\\ ','valdimar72'),(12706,628362644013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','ieskela84','ieskela@gmail.com','Aleksey Sheshulin','Churupi 13-65','Moscow','Moscow','RUSSIAN FEDERATION','117418','+79265532627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 20:51:34',0,NULL,3,1,2,1,'\\ ','ieskela84'),(12707,856209669012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','jdbabinec','jandjbabinec@att.net','john Babinec','115 WHEATSBURY DR','CARY','NC','UNITED STATES','27513-9412','(919) 481-0847','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 21:06:01',0,NULL,3,1,1,1,'\\ ','jdbabinec'),(12708,856212693012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.9,'eastar4','kabi060182','kabi82@gmail.com','Anastasios Kampisioulis','Kleonon 1<br>Ano Patissia','Athens','Attiki','GREECE','11142','00306979590130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 21:12:33',0,NULL,3,1,2,1,'\\ ','kabi060182'),(12709,771958198011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','rafy170','raense@hotmail.com','Rafael Serrano','1454 Walton Ave<br>Apt 6A','Bronx','NY','UNITED STATES','10452-6537','(718) 360-7776','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 21:26:01',0,NULL,3,1,1,1,'\\ ','rafy170'),(12710,856222385012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.9,'eastar4','jedrcd27','jedr@grandecom.net','James Rant','505 Gladiola Ln','San Antonio','TX','UNITED STATES','78213-2511','(210) 344-7082','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 21:37:30',0,NULL,3,1,1,1,'\\ ','jedrcd27'),(12711,628396559013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.4,'eastar4','lordkokkei','sdzhang210@gmail.com','steven Zhang','6418-Sandin Crescent NW','Edmonton','AB','CANADA','T6R 0E9','(780) 436-8910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 23:01:51',0,NULL,3,1,2,1,'\\ ','lordkokkei'),(12712,856267345012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','dgwright99','ebay@davidandmartha.com','David G Wright','16069 Cayenne Creek Rd','San Diego','CA','UNITED STATES','92127-3704','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 23:51:27',0,NULL,3,1,1,1,'\\ ','dgwright99'),(12713,628411248013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','boyinnorway','renebrox@yahoo.no','René Brox','Ebbells gate 3','oslo','oslo','NORWAY','0183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 00:14:15',0,NULL,3,1,3,1,'RA184584187CN ','boyinnorway\rMOSA005'),(12714,730871372001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','chickywmn19','andreathomas@mchsi.com','chickywmn19','2170 SE 60th St','Pleasant Hill','IA','UNITED STATES','50327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 00:43:32',0,NULL,3,1,1,1,'\\ ','chickywmn19'),(12715,856288644012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','mikeslizs','esinger505@yahoo.com','Michael B. Singer','11 Mohegan Dr','Chappaqua','NY','UNITED STATES','10514','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 01:04:27',0,NULL,3,1,1,1,'、 ','mikeslizs'),(12716,772029406011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','altpernikolaus','nwegmann@princeton.edu','Nikolaus Wegmann','16 Hawthorne Ave','Princeton','NJ','UNITED STATES','08540-3804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 01:29:47',0,NULL,3,1,1,1,'\\ ','altpernikolaus'),(12717,577690637004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23.26,'cnfaner','hamburgercancer','wentichou@gmail.com','Wen-Ti CHOU','142 Wick Rd','North Ryde','New South Wales','AUSTRALIA','2113','0403421208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 02:08:51',0,NULL,3,1,3,1,'RA184584292CN ','hamburgercancer\rBALO007'),(12718,856309262012,220815930312,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',16.95,'eastar4uk','bazza6t9barry','barrystonehouse@sky.com','barry stonehouse','11 white house close','basingstoke','Hampshire','UNITED KINGDOM','rg226hd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 02:14:29',0,NULL,3,1,3,1,'RA184584160CN ','bazza6t9barry\rHSMO021'),(12719,772045877011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','spelk1','kspelay@sasktel.net','Kevin J Spelay','915 Broad Street North','Regina','SK','CANADA','S4R 5V6','(306) 525-2715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 02:32:28',0,NULL,3,1,2,1,'\\ ','spelk1'),(12720,772046833011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','sellomatrixx','barneseri@gmail.com','Eric Barnes','3672 Durham Way','Boise','ID','UNITED STATES','83716-8706','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 02:39:37',0,NULL,3,1,1,1,'\\ ','sellomatrixx'),(12721,8881317352156839,111,'jabra JX10',1,'HSJA004',0,'eastar4','almentis1mbc','almentis@aol.com','Ann Mentis','PO Box 2881','Gulf Shores','AL','UNITED STATES','36547-2881','(251) 967-4706',NULL,NULL,NULL,'2011-09-30 03:09:16',0,NULL,3,1,3,1,'RA184584448CN ',' 只发耳机 不给电源\rHSJA004'),(12722,730906411001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','cedar710','cedar710@yahoo.com','Brian Lewis','1208 N Tower Ave','Centralia','WA','UNITED STATES','98531-5046','(360) 508-5836','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 03:10:11',0,NULL,3,1,1,1,'\\ ','cedar710'),(12723,856288432012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','kingsandsultans','hoteyce@gmail.com','Stephen Adams','7979 NW 21st St<br>POS 3576','Doral','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 03:33:55',0,NULL,3,0,1,1,'\\ ','kingsandsultans'),(12724,572194003003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','moraed','morales.ejr@sbcglobal.net','EDGAR MORALES','37236 Oak St<br>APARMENT # C','NEWARK','CA','UNITED STATES','94560','(510) 974-3364','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 05:13:30',0,NULL,3,1,1,1,'\\ ','moraed  OEM的'),(12725,772080707011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','1974corey','corey_f@bigpond.net.au','Corey Forcucci','20  Cokas  Ave','Meikleville Hill','Queensland','AUSTRALIA','4703','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 05:29:46',0,NULL,3,1,2,1,'\\ ','1974corey'),(12726,856354106012,220705174904,'New Genuine Motorola H555 Bluetooth Wireless Headset',1,'HSMO008',8.99,'eastar4uk','angelrockboy','angelrockboy@msn.com','Fidel Alcaide','3208 83rd St','East Elmhurst','NY','UNITED STATES','11370','(347) 813-2596','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 05:38:06',0,NULL,3,1,1,1,'\\ ','angelrockboy'),(12727,730934766001,110731214793,'New in box AKG K 450 Premium Foldable Headphone',1,'HSAK003',58.9,'buysia','bartekss','bartosz.lewandowski@rocketmail.com','Bartosz Lewandowski','2701 Boardwalk','Wildwood','NJ','UNITED STATES','08260-5460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 05:58:31',0,NULL,3,1,1,1,'\\ ','bartekss'),(12728,572205191003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','glanver','gladisverdiales@hotmail.com','Gladis Herrera','PO Box 1066','Lafayette','OR','UNITED STATES','97127-1066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 06:46:03',0,NULL,3,1,1,1,'\\ ','glanver'),(12729,628478564013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','sycee20112011','sycee2011@hotmail.com','Dan Parker','18210 ne 112th way<br>apt 3090','REDMOND','WA','UNITED STATES','98052-7405','(253) 376-9702 ext.: 2533769702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 06:52:10',0,NULL,3,1,1,1,'\\ ','sycee20112011'),(12730,772100186011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','tha_max','promax@zonnet.nl','Max Hattem','Waalsteen 14','Houten','','NETHERLANDS','3991 ZH','0306314845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 07:09:04',0,NULL,3,1,2,1,'\\ ','tha_max'),(12731,628493213013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','rkplk1','rkplk@comcast.net','randy petty','2009 N Ellory Rd','peoria','IL','UNITED STATES','61604','(309) 673-5345','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 08:19:01',0,NULL,3,1,1,1,' \\ ','rkplk1'),(12732,628503862013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','makada','damaka@gmail.com','Dalius Makackas','A.Mickeviciaus 39-213','Kaunas','LT','LITHUANIA','44244','+37065253695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 09:24:00',0,NULL,3,1,2,1,'\\ ','makada'),(12733,772132985011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',10,'NTLO001',89.9,'eastar4uk','adriekr','a.kraaij@oldheroes.com','Adrie Kraaij','Laan van Vlaanderen 315','Amsterdam','','NETHERLANDS','1066 WB','06-38891865','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 09:33:35',0,NULL,3,1,3,1,'RA184586205CN ','adriekr'),(12734,856418241012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','nethobby4fun','anc.cruz@sapo.pt','Antonio Cruz','R. das Almas, Lote 7<br>Póvoa do Paço','Cacia','Aveiro','PORTUGAL','3800-552','(351) 234315358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 10:16:26',0,NULL,3,1,2,1,'\\ ','nethobby4fun'),(12735,772147388011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','hardrain0703','sandymanson@hotmail.com','Alexander Manson','105 Octavia Terrace','Greenock','Inverclyde','UNITED KINGDOM','PA167PY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 10:32:44',0,NULL,3,0,3,1,'RA184589785CN\r ','hardrain0703'),(12736,628516396013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',63.5,'eastar4','ericc222','couling60@o2.co.uk','Eric couling','4 Beech Gardens, Clayton-Le-Woods','Chorley','Lancashire','UNITED KINGDOM','pr67un','01772321288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 10:36:29',0,NULL,3,0,3,1,'RA184589771CN\r ','ericc222'),(12737,770185970011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','mjn2096','matthewjneill@hotmail.com','matthew neill','10491 106th Pl N','maple grove','MN','UNITED STATES','55369','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 10:42:13',0,NULL,3,1,1,1,' \\ ','mjn2096'),(12738,628470254013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.99,'eastar4','inonggomez','inong.gomez@gmail.com','Moch. Tedzar Ardisas','RSUD CIANJUR<br>Jalan Rumah sakit N0. 1','Cianjur','jawabarat','INDONESIA','43216','+622635309880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 10:53:18',0,NULL,3,1,3,1,'RA184584638CN\r ','inonggomez'),(12739,572244400003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.9,'cnfaner','1958wes','kahli43@yahoo.com','Wesley D Moody','20333 kimzy carr rd','Athens','AL','UNITED STATES','35614-6823','(256) 497-2408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 11:00:40',0,NULL,3,1,1,1,' \\ ','1958wes'),(12740,628522257013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','1jourjrey','1jourjrey@wanadoo.fr','antoine maunoury','13, rue st antonin','st aquilin de pacy','Haute-Normandie','FRANCE','27120','0232264750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:07:16',0,NULL,3,1,2,1,'\\ ','1jourjrey'),(12741,772161020011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',42.9,'eastar4uk','mujdatsevik','centerland@msn.com','mujdat sevik','Fyrreparken 144. 3 TV','Odense','','DENMARK','5240','+4527115769','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 11:30:06',0,NULL,3,1,3,1,'RA184584686CN\r ','mujdatsevik'),(12742,856443811012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','thing2397','siewthing2397@hotmail.com','soh siew thing','10E, Jalan Muar','Segamat','Johor','MALAYSIA','85000','0167172566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:44:54',0,NULL,3,1,2,1,'\\ ','thing2397'),(12743,628532253013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','joelhuntx','joelhunt@gmail.com','Joel Hunt','145 Fairlane Avenue','Winnipeg','MB','CANADA','R2Y 0B2','(204) 885-4483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:59:43',0,NULL,3,1,2,1,'\\ ','joelhuntx'),(12744,572256446003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',2,'OMHJ001',27.8,'cnfaner','premier-vehicle-products','premier.vehicle.products@googlemail.com','M.D.EVENDEN','THE BRIAR<br>CROWHURST ROAD','ST.LEONARDS-ON-SEA','East Sussex','UNITED KINGDOM','TN388EE','01424830727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 12:11:19',0,NULL,3,1,3,1,'RA184589856CN\r ','premier-vehicle-products'),(12745,772192683011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','krismith4','krisplus4@aol.com','Kristine Lavoie','110 Maple St','east Brookfield','MA','UNITED STATES','01515-1608','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 13:14:31',0,NULL,3,1,1,1,'、 ','krismith4'),(12746,772195418011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',92.99,'eastar4uk','didier8679','diodiergb@free.fr','didier goeytes-bedat','19 chemin de labaste','labatut','Aquitaine','FRANCE','40300','05.58.98.17.42','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 13:23:13',0,NULL,3,1,3,1,'RA184584519CN\r ','didier8679'),(12747,0,140612086331,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',3.44,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 eagle heights','Madison','WI','UNITED STATES','53705','(608) 334-4816','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:15',0,NULL,5,0,18,0,NULL,'wicanc'),(12748,0,130581485977,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',86.84,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:20',0,NULL,5,0,18,0,NULL,'wicanc'),(12749,0,130581491467,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',13.25,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 eagle heights','Madison','WI','UNITED STATES','53705','(608) 334-4816','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:26',0,NULL,5,0,18,0,NULL,'wicanc'),(12750,0,140612085037,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',18.3,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:34',0,NULL,5,0,18,0,NULL,'wicanc'),(12751,0,130581492673,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',60.52,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:42',0,NULL,5,0,18,0,NULL,'wicanc'),(12752,0,130581490348,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',25.81,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:49',0,NULL,5,0,18,0,NULL,'wicanc'),(12753,0,140612083959,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',29.33,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:41:57',0,NULL,5,0,18,0,NULL,'wicanc'),(12754,856485833012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','telmaz1','michael@telmaz.co.uk','Michael Radford','7 Redman Gardens','Biggleswade','Bedfordshire','UNITED KINGDOM','SG18 0DF','07748534034','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 13:51:51',0,NULL,3,1,2,1,'\\ ','telmaz1'),(12755,628575440013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.7,'eastar4','dakks_152','trust_no1@europemail.com','Daniel Johannes Knob Kerekgyarto','Fornhöjdsvägen 8','Södertälje','Stockholms Län','SWEDEN','15258','0704861331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 15:10:45',0,NULL,3,1,2,1,'\\ ','dakks_152'),(12756,856499814012,220815930479,'New GENUINE NOKIA BH-700 BLUETOOTH HEADSET',1,'HSNO028',13.39,'eastar4uk','zubr09','zubr@mail.ru','Andrey Zubriy','Geroyev Oborony 3/25','Kiev','','UKRAINE','03127','(050) 3553648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 15:14:00',0,NULL,3,1,2,1,'\\ ','zubr09'),(12757,731072824001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','ileabalagbagba','ademipo@ccpshipping.com','Ajeyemisi Adegboyega','1253 River St','Hyde Park','MA','UNITED STATES','02136','(857) 236-2406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 15:28:02',0,NULL,3,1,1,1,'、 ','ileabalagbagba'),(12758,856528035012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','tankmaker57','alicrawford11@hotmail.com','alastair crawford','11,hurcott court<br>hurcott road','kidderminster','Worcestershire','UNITED KINGDOM','dy10 2qt','07968122504','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 15:47:10',0,NULL,3,1,3,1,'RA184589737CN\r ','tankmaker57'),(12759,572305432003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','crazybrit','bloomis@cox.net','BARBRA LOOMIS','357 E Thomas Rd<br>Unit A104','PHOENIX','AZ','UNITED STATES','85012-3210','(602) 234-3181','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 15:59:06',0,NULL,3,1,1,1,' \\ ','crazybrit'),(12760,856548669012,220594073947,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10 S10e S9',1,'BTLE2101',12.4,'eastar4','mechanicaldmitry','mechanicalhand01@gmail.com','Dmitry Petrenko','339 Strelkovoy divizii st. 17/3 kv131','Rostov-on-Don','Rostovskaia Oblast','RUSSIAN FEDERATION','344015','79094323656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 16:38:49',0,NULL,3,1,2,1,'\\ ','mechanicaldmitry'),(12761,731098949001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',23.99,'buysia','g-dog-bmw','mikelycka@hotmail.com','mike lycka','3433 12st NE','Calgary','AB','CANADA','T2E 6S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 16:45:28',0,NULL,3,1,3,1,'RA184584575CN\r ','g-dog-bmw'),(12762,572325359003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',3,'HSPL010',95.97,'cnfaner','wabbits1','wabbithole@comcast.net','Leslie Brooks C/O Analog Audio','11496 Pierson Rd<br>Ste C5','Wellington','FL','UNITED STATES','33414-8708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 17:19:03',0,NULL,3,1,1,1,' \\ ','wabbits1'),(12763,628614607013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','goglooz','gogloo@emirates.net.ae','Fahad  Yousuf','Flat 303,Mohd Sharif Building,Murshid Bazar<br>Deira','Dubai','Dubai','UNITED ARAB EMIRATES','25745','00971508702557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:34:56',0,NULL,3,1,3,1,'RA184584788CN\r ','goglooz   眼镜退回了了 没发到 2.12.1.17'),(12764,772290118011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',3.6,'eastar4uk','absorbentsponge','aslan07708495454@hotmail.co.uk','Henry Hutchings','2 Old Chapel Road<br>Skellingthorpe','Lincoln','Lincolnshire','UNITED KINGDOM','LN65UB','01522871012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 17:44:47',0,NULL,3,1,3,1,'RA184589670CN\r ','absorbentsponge'),(12765,856579515012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001',89.78,'eastar4','macbhoy0','amac18882003@yahoo.co.uk','ALAN MACKIE','31 CARDROSS AV','PORT GLASGOW','Inverclyde','UNITED KINGDOM','PA145SG','01475795579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:46:52',0,NULL,3,1,3,1,'RA184584712CN\r ','macbhoy0'),(12766,628620814013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','bxkaos120','bxboriqua20@hotmail.com','Kevin Pena','984 Bronx Park S<br>Apt 208','Bronx','NY','UNITED STATES','10460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 17:53:39',0,NULL,3,1,1,1,' \\ ','bxkaos120'),(12767,628630452013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','uvatha38','sylvainbevilacqua@sfr.fr','BEVILACQUA Sylvain','57 rue des eaux claires<br>none','GRENOBLE','Rhône-Alpes','FRANCE','38100','0674082698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 18:24:04',0,NULL,3,1,3,1,'RA184584641CN\r ','uvatha38'),(12768,772326464011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','sbfintheusa','steve@francis.com','Sir Stephen Barry Francis','152 Wetherbrooke Ln','Smyrna','GA','UNITED STATES','30082-4866','(404) 918-9275','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 19:17:13',0,NULL,3,1,1,1,'、 ','sbfintheusa'),(12769,772338867011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','pvalopess','pvalopes@yahoo.com.br','Paulo Vinicius Alves Lopes','Rua Mexico, n. 305<br>Jardim Nautilus','Cabo Frio','Rio de Janeiro','BRAZIL','28909180','55 22 26484627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 19:31:21',0,NULL,3,1,2,1,'\\ ','pvalopess'),(12770,856634905012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',10.99,'eastar4uk','davkoszanski','amd-ko@wp.pl','Dawid Koszanski','68 Totnes road','Paignton','Devon','UNITED KINGDOM','Tq45LD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 19:37:07',0,NULL,3,1,3,1,'RA184589860CN\r ','davkoszanski'),(12771,628658260013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','n0ure','johnwclark@frii.com','John Clark','2702 S Quitman St','Denver','CO','UNITED STATES','80236-2205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 19:47:30',0,NULL,3,1,1,1,' \\','n0ure'),(12772,856652199012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','sadyfarah','sadyfarah@yahoo.com.br','Sady Farah Junior','Av. Alexandre Ferreira, 353 ap.101<br>Lagoa','Rio de Janeiro','Rio de Janeiro','BRAZIL','22470-220','21 - 25277425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 20:14:38',0,NULL,3,1,3,1,'RA184589895CN\r ','sadyfarah'),(12773,772358788011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',15.14,'eastar4','jmoreta2011','jgmoreta@gmail.com','Julio Moreta','24 Merrifield St','Worcester','MA','UNITED STATES','01605-3019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 20:21:56',0,NULL,3,1,1,1,'、 ','jmoreta2011'),(12774,856672743012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','matthew_smith9119','matthew.kieran.smith@hotmail.co.uk','Matthew Smith','32 George Road','Stokenchurch','Buckinghamshire','UNITED KINGDOM','HP143RN','07938010001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 20:57:01',0,NULL,3,1,2,1,'\\ ','matthew_smith9119'),(12775,628684406013,230655993632,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4','yt65','warmark414@aol.com','G Denmark','708 Poplar Springs Ln','Lexington','KY','UNITED STATES','40515-6085','(312) 678-1439','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 21:13:45',0,NULL,3,1,1,1,' \\','yt65   粉色的'),(12776,856686722012,220816847682,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',14.99,'eastar4uk','thoskyt','ebay@sofagang.dk','Thomas Jessen','28 Grangepans','Bo\'Ness','West Lothian','UNITED KINGDOM','EH51 9PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 21:41:32',0,NULL,3,1,3,1,'RA184584505CN\r ','thoskyt'),(12777,628700819013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','vsok_2007','vsok@mail.ru','Владимир Долгополов','Январского восстания. д.12. кв.26','Киев','','UKRAINE','01010','+380672091146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 22:17:56',0,NULL,3,1,3,1,'RA184589900CN\r ','vsok_2007\rWWOT002+ANCN001   注意改发IBM版的，客户补差价了\r'),(12778,772405830011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','raht1966','raht76@hotmail.com','rahat mirza','TITAN TRUCK PARK<br>STONENESS ROAD','WEST THURROCK','Essex','UNITED KINGDOM','RM20 3AG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 22:18:27',0,NULL,3,1,3,1,'RA184589710CN\r ','raht1966'),(12779,572410766003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','ubysoft82','dadouby@gmail.com','Fam.Uberti Badino Penone Davide','Via S. Albano Stura<br>2/E','Morozzo','CN','ITALY','12040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 22:40:48',0,NULL,5,1,3,1,'RA184589683CN\r ','ubysoft82  欧标头\r'),(12780,628720488013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','riktoffen','rickeunice@hotmail.com','Rick Gullion','65 Grand Lake Point','Enfield','NS','CANADA','B2T 1H9','(902) 883-7347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 00:03:22',0,NULL,3,1,2,1,'\\ ','riktoffen'),(12781,713770933008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','pedantique','ebay@darrenchallis.com','Darren Challis, DH International Pty Ltd','Level 31, Aurora Place<br>88 Phillip Street','Sydney','New South Wales','AUSTRALIA','2000','0282110577','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 01:30:11',0,NULL,3,1,3,1,'RA184584598CN\r ','pedantique'),(12782,772454201011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',33.16,'eastar4','bweb97','bertow@gmail.com','Berto Wong','29 Capella Street','Balwyn North','Victoria','AUSTRALIA','3104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 01:43:33',0,NULL,3,1,3,1,'RA184589768CN\r ','bweb97  再发三个NEW CAB-SS-2626 '),(12783,772458853011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','xaedox','docko@docko.sk','Andrej Docolomansky','podjavorinskej 3','Bratislava','','SLOVAK REPUBLIC','81103','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 02:00:37',0,NULL,3,1,2,1,'\\ ','xaedox'),(12784,572447309003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','coreyluther','lesliebell09@gmail.com','Leslie Bell','12204 Wileman Way','Oklahoma city','OK','UNITED STATES','73162-1837','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 02:37:01',0,NULL,3,1,1,1,' \\ ','coreyluther'),(12785,772467553011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','sail0r4life','tcerkman@gmail.com','Todd Erkman','19 Bradbury St','Wiscasset','ME','UNITED STATES','04578-4112','(443) 995-8478','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 02:39:47',0,NULL,3,1,1,1,'、 ','sail0r4life'),(12786,856771732012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','scotthemme','scott.a.hemme@gmail.com','Scott Hemme','501 SW 10th Street','Concordia','MO','UNITED STATES','64020','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-01 02:47:36',0,NULL,3,1,1,1,' \\ ','scotthemme'),(12787,856784805012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','rsbulldog','pjboyer@vodafone.co.nz','Paul Boyer','12 Ngawhatu rd<br>Stoke','NELSON','','NEW ZEALAND','7011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 03:52:56',0,NULL,3,1,2,1,'\\ ','rsbulldog'),(12788,628765937013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',6.88,'eastar4','alaska773477','elleped@hotmail.com','Michael  Pedersen','18 Ottelia Drive','Elanora','Queensland','AUSTRALIA','4221','0422877463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 04:32:39',0,NULL,3,1,2,1,'\\ ','alaska773477'),(12789,856793577012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',3,'WLAT009',29.94,'eastar4','george_rutkay','twinflame@rogers.com','George Rutkay','122 Amaranth St. East<br>PO Box 617','Grand Valley','ON','CANADA','L0N 1G0','(519) 928-2850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 04:39:36',0,NULL,3,1,3,1,'RA184589958CN\r ','george_rutkay'),(12790,772502372011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','nurshasha','nanurnanur@yahoo.com.sg','Mohd Hisham','Block 316, Sembawang Vista, #06-191, Singapore 750316','default','','SINGAPORE','750316','91005009','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 06:02:05',0,NULL,3,1,11,1,'\\ ','nurshasha\rOTHP005'),(12791,628780905013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','samsamshayin','seancsy998@gmail.com','Shan Yong Chung','30-1, Persiaran 65C, Pekeliling Business Centre<br>Off Jalan Pahang Barat','Kuala Lumpur','WP','MALAYSIA','53000','03-40241399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:35:59',0,NULL,3,1,3,1,'RA184589935CN\r ','samsamshayin'),(12792,572474982003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','amguin','amamam@gmail.com','Akarawat Arthimokyothin','1291/1 Shinawatra Tower2(14) Phaholyothin Rd.,','phayathai','Bangkok','THAILAND','10400','+66813727733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:41:03',0,NULL,3,1,3,1,'RA184584615CN\r ','amguin   OEM'),(12793,628782347013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','aljo_kupuj','branka.vujanovic@triera.net','branka vujanovic','kacova 4','maribor','slovenia','SLOVENIA','2000','+38622523275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:47:48',0,NULL,3,1,2,1,'\\ ','aljo_kupuj'),(12794,628783097013,230676837702,'New Philips Sonicare Essence Toothbrush Handle HX5500',1,'HBPH006',26.99,'eastar4','arthurmcwizard','mcwizard@mac.com','John A McQuade','5F, No. 123 Xuecheng Rd.','Sanxia, Taipei County','','TAIWAN','237','(02) 8672-5408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:51:03',0,NULL,3,1,14,1,'301208196268 ','arthurmcwizard'),(12795,856830923012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',26.38,'eastar4','olisa111','gatoyem@aol.com','olisa oluyemi','15 inwood house,<br>quorn road','london','London','UNITED KINGDOM','SE228BT','02077387325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 07:51:16',0,NULL,3,1,3,1,'RA184584540CN\r ','olisa111'),(12796,731338902001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','the-brown-bunch','carl@thebrownbunch.com','George Brown','43067 Corte Calanda','Temecula','CA','UNITED STATES','92592-3600','(951) 719-5395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 08:21:13',0,NULL,3,1,1,1,' \\ ','the-brown-bunch'),(12797,628802779013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','jackiesiow','siowjackie@gmail.com','SIOW TECK HUAT','APT BLK 504 ANG MO KIO AVENUE 8<br>#08-2664 SINGAPORE','default','','SINGAPORE','560504','96550636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 09:01:33',0,NULL,3,1,11,1,'RA184584757CN\r ','jackiesiow\rWLAP008'),(12798,572504535003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','iv_i_vi','yoichiro@gmail.com','Yoichiro Takahashi','6-21-28 Oizumigakuencho','Nerimaku','Tokyo','JAPAN','1780061','03-5387-7621','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 09:53:09',0,NULL,3,1,3,1,'RA184590001CN\r ','iv_i_vi'),(12799,856872243012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','kdre6063','drewkg@hotmail.com','Keith Drew','51 Bagshot Green','Bagshot','Surrey','UNITED KINGDOM','GU19 5JR','07710088779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 10:27:24',0,NULL,3,1,2,1,'\\ ','kdre6063'),(12800,856882382012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','rawpowerd','rawpowerdaddy@gmail.com','Black Salt Press','1730 S Federal Hwy<br># 319','Delray Beach','FL','UNITED STATES','33483','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 11:15:45',0,NULL,3,1,1,1,' \\ ','rawpowerd'),(12801,628828817013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','whyebee','octolink@hotmail.com','Lian Tan','No. 90, Jalan UP3/2<br>Ukay Perdana','Ampang','Selangor','MALAYSIA','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 11:22:20',0,NULL,3,1,2,1,'\\ ','whyebee'),(12802,856894702012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',19.98,'eastar4uk','jad200','jdenny@sky.com','John A Denny','19 Carpenters Way','Hailsham','East Sussex','UNITED KINGDOM','BN27 3XD','01323849372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 11:46:05',0,NULL,3,1,3,1,'RA184584536CN\r ','jad200'),(12803,856896268012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','megan6178','spanglepants@hotmail.com','Megan Matson','57 Hicks St<br>Red Hill','Canberra','Australian Capital Territory','AUSTRALIA','2603','0417686254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 11:51:53',0,NULL,3,1,3,1,'RA184562345CN\r ','megan6178'),(12804,578057804004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23.26,'cnfaner','liddel_laju','apache6@freenet.de','Antje Körner','Demmeringstr.163','Leipzig','','GERMANY','04179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 12:28:05',0,NULL,3,1,3,1,'RA184589723CN\r ','liddel_laju'),(12805,856916362012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','selku19','spkvdo@yahoo.co.uk','Suban purushothmakumar','147,turner road<br>edgware','harrow','Middlesex','UNITED KINGDOM','ha8 6as','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 12:54:46',0,NULL,3,1,3,1,'RA184584482CN\r ','selku19'),(12806,856920356012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',7.98,'eastar4uk','azz435','azzopardi435@hotmail.com','George Azzopardi','31 Lord Byron St\'','Hamrun','','MALTA','HMR 1091','79784489','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 13:07:07',0,NULL,3,1,2,1,'\\ ','azz435'),(12807,856928149012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','happ1shopaz','jekite101@yahoo.co.uk','Jacob Kite','6 Winchester Court<br>North Hykeham','Lincoln','Lincolnshire','UNITED KINGDOM','LN6 9HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 13:29:32',0,NULL,3,1,3,1,'RA184584479CN\r ','happ1shopaz'),(12808,571660956003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','lanselot_mag','lanselot.a@gmail.com','Alexey Marchenko','46, 3/2, M-n Mirniy','Noviy Urengoy','Yamalo-Nenetskiy Autonomniy Okrug','RUSSIAN FEDERATION','629303','+79129158520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 13:58:40',0,NULL,3,1,3,1,'RA184584553CN\r ','lanselot_mag'),(12809,578084598004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','kidamemaxchan','jgmontpetit@videotron.ca','jean-guy montpetit','109 therrien','ste-anne des plaines','QC','CANADA','j0n1h0','(450) 838-8570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 14:35:33',0,NULL,3,1,3,1,'RA184589989CN\r ','kidamemaxchan'),(12810,772636272011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.98,'eastar4','abd030','zaragheat@hotmail.com','Abdullah Bursalıoğlu','Cumhuriyet Mah.Hüseyin Bayık Cad.Yeter Sitesi.A Blok.Kat:3','Afyonkarahisar','Merkez','TURKEY','03200','05374802828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 14:38:03',0,NULL,3,1,2,1,'\\ ','abd030'),(12811,576955534004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',21.5,'cnfaner','naomidsherman','nmyers@cwr.ms','Michael Sherman','6669 Cortez Cir','Ocean Springs','MS','UNITED STATES','39564-2334','(228) 760-0299','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 15:12:38',0,NULL,3,1,1,1,' \\ ','naomidsherman'),(12812,628882114013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','choonhahwang','memoryallocator@gmail.com','Choonha Hwang','Haneulmaeul 6Danji Apt. 605-1104<br>Jungsan-Dong, Ilsandong-gu','Goyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','410756','(031) 923-1668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 15:14:54',0,NULL,3,1,2,1,'\\ ','choonhahwang'),(12813,856976361012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','ictchem','ictchem@mail.ru','Alexey Dubovskiy','Shevchenko 144A','Taganrog','RUSSIAN FEDERATION','RUSSIAN FEDERATION','347900','(960)462-7777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 15:41:35',0,NULL,3,1,2,1,'\\ ','ictchem'),(12814,628891274013,230622403729,'New Philips SHB6102 Bluetooth Stereo Headset  ',1,'HSPH001',74.9,'eastar4','pat00057','patrick.deleus@skynet.be','Patrick De Leus','Ave Franz Guillaume, 31/11','Bruxelles','','BELGIUM','1140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 15:48:24',0,NULL,3,1,3,1,'RA184584726CN\r ','pat00057'),(12815,578105429004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.8,'cnfaner','trikom1979','trikom@list.ru','Vladimir Nayakshin','str.Engels,5-39','Volzhsky','Volgogradsky','RUSSIAN FEDERATION','404111','89275004999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 16:02:07',0,NULL,3,1,3,1,'RA184589666CN\r ','trikom1979'),(12816,856986023012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','07932frosty2008','luciano777@live.co.uk','crescenzo feliciello','228 osmondthorpe lane','leeds','West Yorkshire','UNITED KINGDOM','ls90jw','07932305602','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'07932frosty2008'),(12817,572591256003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',31.98,'cnfaner','00peck','jpeckford2@cogeco.ca','James Peckford','337 Nelson st,','Sarnia','ON','CANADA','N7T5J6','(519) 344-7991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 16:44:04',0,NULL,3,1,3,1,'RA184589745CN\r ','00peck'),(12818,628908867013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','jeff_simmons','jeff.a.simmons@blueyonder.co.uk','Jeff Simmons','19 Plough Lane Close','Wallington','Surrey','UNITED KINGDOM','SM6 8JN','02084012002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 16:51:25',0,NULL,3,1,3,1,'RA184589808CN\r ','jeff_simmons'),(12819,628915699013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',239.99,'eastar4','pbbforlife','pbbforlife@gmail.com','Mladen Topic','Pavlovac bb','Banja Luka','Bosnia And Herzegovina','BOSNIA AND HERZEGOVINA','78000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 17:12:39',0,NULL,3,1,3,1,'RA184584607CN\r ','pbbforlife'),(12820,772716589011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',13.99,'eastar4','liskoff123','liskoff@gmail.com','Mykola Liskov','230 Strelkovoy Divizii, 38-A, 82','Donetsk','','UKRAINE','83092','+380672423443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 17:58:37',0,NULL,3,1,2,1,'\\ ','liskoff123'),(12821,857061060012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','hsm_dk','hsm@tjnet.dk','Henrik Mathiesen','Rensdyrvej 9','Esbjerg N','','DENMARK','6715','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 18:45:22',0,NULL,3,0,2,1,'\\ ','hsm_dk'),(12822,857059168012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','theinterneter','warwick.wan@gmail.com','Warwick Wan','1508-3939 Duke of York Blvd','Mississauga','ON','CANADA','L5B4N2','(416) 473-9730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 18:46:38',0,NULL,3,1,2,1,'\\ ','theinterneter'),(12823,629003779013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','squeezle1','squeezle@comcast.net','Gregory A Myers','181 Easy Rd','Carlisle','PA','UNITED STATES','17013-9594','(717) 385-7789','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 21:58:23',0,NULL,3,1,1,1,'、 ','squeezle1'),(12824,572645037003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','pattywack_az','pattywack@npgcable.com','Pat Nelson','PO Box 2093','Payson','AZ','UNITED STATES','85547','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 22:03:36',0,NULL,3,1,1,1,' \\ ','pattywack_az'),(12825,857155531012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','debbieandpeter','debbie.a.howell@gmail.com','Deborah Howell','42 McOwan Crescent','Yarra Junction','Victoria','AUSTRALIA','3797','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 22:20:49',0,NULL,3,1,3,1,'RA184589754CN\r ','debbieandpeter  澳标头'),(12826,772846243011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','shabds','shabnm@yahoo.com','Shirin Bilimoria','31 Colonia Rd','Parsippany','NJ','UNITED STATES','07054-3003','(973) 727-4025','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 23:36:11',0,NULL,3,1,1,1,' \\ ','shabds'),(12827,629029258013,230649308783,'New Japan Gentleman business Stripe Sun Rain Umbrella',1,'UM00026',26.99,'eastar4','bikashthedon','roshan_2s@hotmail.com','Roshan','4/27-29 john street','Granville','New South Wales','AUSTRALIA','2142','0296373134','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 00:00:52',0,NULL,3,1,2,1,'\\ ','bikashthedon'),(12828,578229247004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','injuhneer','glendalehalls@hotmail.com','steve hall','229 S Beech St','Glendale','KY','UNITED STATES','42740','(270) 723-7325','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 00:03:21',0,NULL,3,1,1,1,' \\ ','injuhneer'),(12829,772868166011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','pocketjammer','pocketrocket2001@hotmail.com','Paul Metcalfe','2/24 Crescent Road','Hamilton','Queensland','AUSTRALIA','4007','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 01:05:15',0,NULL,3,1,2,1,'\\ ','pocketjammer 黑色的'),(12830,857203886012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','zetzzzz','izzufarhanfajri@yahoo.com','Izzu Farhan Fajri','Jl. Batu Pancawarna no. 29<br>RT 002 RW 011 Kayuputih','Jakarta','Jakarta','INDONESIA','13210','+6281317776110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 01:12:25',0,NULL,3,1,3,1,'RA184584791CN\r ','zetzzzz'),(12831,714162248008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.95,'au-buy','rabinov123','jemzac@optusnet.com.au','Joanne Rabinov','2/37 Almond Street','South Caulfield','Victoria','AUSTRALIA','3162','0395027620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 01:45:29',0,NULL,3,1,3,1,'RA184589887CN\r ','rabinov123'),(12832,857214657012,220455488862,'HP Pavilion DV5 HDX X16 Bluetooth Module 2.0 EDR+cable',1,'BTHP2013',9.9,'eastar4','compustarus1','compustarusa@yahoo.com','Omar Saeed','918 S Magnolia Ave<br>Ste G','Anaheim','CA','UNITED STATES','92804-4076','(714) 274-5444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 01:53:41',0,NULL,3,1,1,1,'、 ','compustarus1'),(12833,772899351011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','skydive12345','skydive__@hotmail.com','Bradley Barrett','56 chishlom drive','caroline springs','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 03:23:55',0,NULL,3,1,3,1,'RA184584743CN\r ','skydive12345'),(12834,629064305013,230658777210,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',89.99,'eastar4','cookie1954richard','rickcook_2011@yahoo.com','Richard Cook','1338 22nd St W<br>null','Hastings','MN','UNITED STATES','55033-3219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 03:32:39',0,NULL,3,1,1,1,'、 ','cookie1954richard'),(12835,629068369013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','gyver5201','en_gage_qd@hotmail.com','adam ibrahim','lucky star (2-A)<br>izzudheen magu','maafannu','male\'','MALDIVES','20310','+9607773262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 03:36:44',0,NULL,3,1,2,1,'\\ ','gyver5201'),(12836,629086354013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',2,'WLAT001',27.98,'eastar4','ljm9','lmerrillm3@gmail.com','lawrence merrill','3080 Glenwood Ct','meadow vista','CA','UNITED STATES','95722-9402','(530) 878-2472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 05:48:13',0,NULL,3,1,1,1,' \\ ','ljm9'),(12837,857266652012,220759427766,'New SAMSUNG WMN1000C ULTRA SLIM WALLMOUNT LED TV  60-65',1,'MOSA003',39.99,'eastar4uk','phantomescort','florin.ilies@bigpond.com','Florin Ilies','43 Greenway Drive','West Hoxton','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 06:09:13',0,NULL,3,0,3,1,'RA184584624CN\r ','phantomescort'),(12838,731711266001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','mingostar7','mingoruben@hotmail.com','Ruben Mingo','9472 England Ave','Westminster','CA','UNITED STATES','92683-6523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 06:21:10',0,NULL,3,1,1,1,'、 ','mingostar7'),(12839,572759700003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.95,'cnfaner','ckar1646','nswck@yahoo.com.au','CAROLINE KARL','OAKLEIGH<br>320 NEW OLIVERS ROAD','RUNNING STREAM','New South Wales','AUSTRALIA','2850','0263588209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 06:46:42',0,NULL,3,1,3,1,'RA184589873CN\r ','ckar1646'),(12840,578295376004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',19.9,'cnfaner','vancouverjoseph','josephtanmail@gmail.com','Denise Lambert','1186 Danville Blvd','Alamo','CA','UNITED STATES','94507-2141','(925) 964-0987','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 07:52:09',0,NULL,3,1,1,1,' \\ ','vancouverjoseph'),(12841,629105997013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','glenn_dickson','glennodickson@gmail.com','Glenn Dickson','17 Harrow Pl<br>Kewdale','Perth','Western Australia','AUSTRALIA','6105','610415534883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 07:52:33',0,NULL,3,1,2,1,'\\ ','glenn_dickson'),(12842,772962351011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','1csasoftware','icsa.ebay@icsasoftware.com','Ben Harding','ICSA Software<br>340a Shirley Road','Southampton','Hampshire','UNITED KINGDOM','SO15 3HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 08:41:32',0,NULL,3,1,3,1,'RA184589799CN\r ','1csasoftware'),(12843,857349523012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','lingetll','lingetll@yahoo.com.sg','Ruth','Blk 65 Circuit Road<br>#05-375','default','','SINGAPORE','370065','65-83681538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 10:29:11',0,NULL,3,1,11,1,'、 ','lingetll\rOTCN003\r'),(12844,773005901011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','pajo11988','pajo15@orange.pl','Paweł Maciaszczyk','Ogrodowa 107','Ujazd/ Poczta Zabierzów','małopolskie','POLAND','32-080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 10:35:43',0,NULL,3,1,2,1,'\\ ','pajo11988'),(12845,773017852011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.5,'eastar4','pfar3388','fearghail@live.ca','Peter Farrell','4784 Ridge Road<br>R.R. 1','Fournier','ON','CANADA','K0B 1G0','(613) 524-2495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 11:07:33',0,NULL,3,1,2,1,'\\ ','pfar3388\r再发一个\r罗技遥控电池 蓝色 新 950mah\rBALO001'),(12846,857365285012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','pfar3388','fearghail@live.ca','Peter Farrell','4784 Ridge Road<br>R.R. 1','Fournier','ON','CANADA','K0B 1G0','(613) 524-2495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 11:09:19',0,NULL,8,1,17,0,NULL,'pfar3388'),(12847,857368608012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','nikita7781','merkuriy_83@inbox.ru','Nikita Merkushov','Paromnaya str. 7-3-424','Moscow','','RUSSIAN FEDERATION','115408','3420863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 11:18:22',0,NULL,3,1,2,1,'\\ ','nikita7781'),(12848,857375960012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','lennon_walrus','conrad@gladesvillejoinery.com.au','Gladesville Joinery  (conrad galanos)','29 buffalo rd<br>gladesville','sydney','New South Wales','AUSTRALIA','2111','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 11:37:27',0,NULL,3,1,3,1,'RA184589839CN\r ','lennon_walrus'),(12849,572820780003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','2011bobsbobs','voronin_boris@mail.ru','Boris Voronin','Prospect Hudozhnikov, 31/1. app. 242','St.-Peterburg','','RUSSIAN FEDERATION','194295','921-182-7777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 11:38:48',0,NULL,3,1,3,1,'RA184589975CN\r ','2011bobsbobs   OEM的'),(12850,773033599011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','freestylii','pdessis@hotmail.com','Pascal Dessis','1 Avenue du Maréchal de Lattre de Tassigny','ORNANS','Franche-Comté','FRANCE','25290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 11:59:16',0,NULL,3,1,2,1,'\\ ','freestylii'),(12851,0,110750126096,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','kimsubarry','barry.s.decker@gmail.com','Barry Decker','10 Dillworth Ct','Simpsonville','SC','UNITED STATES','29681-3688','(561) 222-1864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 12:20:02',0,NULL,3,1,1,1,'、 ','kimsubarry'),(12852,773059314011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','nibbins0653','nibbins53@hotmail.co.uk','maureen reynolds','281 perrysfield road','cheshunt','Hertfordshire','UNITED KINGDOM','en80tp','07719832739','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 12:56:28',0,NULL,3,1,3,1,'RA184584669CN\r ','nibbins0653'),(12853,857417718012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','struwe','irinastruwe@hotmail.com','Irina Struwe','Bjorkvagen 6B','Strangnas','','SWEDEN','645 40','45-152-15402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 13:17:43',0,NULL,3,1,2,1,'\\ ','struwe'),(12854,629189299013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','2978perreault','guiric86@msn.com','richard perreault','1332 des rosiers','l\'assomptions','QC','CANADA','j5w 5w9','(450) 589-9330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 13:23:38',0,NULL,3,1,3,1,'RA184589961CN\r ','2978perreault\r兼容型3D眼镜 通用型\rGLOT001*3'),(12855,857420582012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','seyfulislam','seyful55@gmail.com','Seyfülislam Özdemir','Bilkent Universitesi Dogu Kampusu 92. YurtOda No 121 CANKAYA','ANKARA','CANKAYA','TURKEY','06800','(505) 781 - 0553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 13:26:55',0,NULL,3,1,2,1,'\\ ','seyfulislam'),(12856,572856849003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','mynsxt6','ldublin@nc.rr.com','larry dublin','3009 riverbrooke dr','raleigh','NC','UNITED STATES','27610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 13:55:54',0,NULL,3,1,1,1,'、 ','mynsxt6'),(12857,773101012011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','alehousesinger','jhsnr@hotmail.com','CATHERINE HEWISH','ROSE COTTAGE','BELFORD','Northumberland','UNITED KINGDOM','NE707NG','01668213924','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 14:35:39',0,NULL,3,1,3,1,'RA184589706CN\r ','alehousesinger'),(12858,773110987011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',3,'CASS003',25.47,'eastar4','d_long_00','david_long2@cable.comcast.com','Dave P Long','3 Fletcher Blvd','Sicklerville','NJ','UNITED STATES','08081-9362','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-02 14:57:08',0,NULL,3,1,1,1,'、 ','d_long_00'),(12859,0,110750125720,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',10.49,'buysia','globalworlds','nguyennancy2010@hotmail.com','Dung Tran','902 Cooper Ct SE','Vienna','VA','UNITED STATES','22180-5966','(703) 938-0539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 15:01:13',0,NULL,3,1,1,1,' \\ ','globalworlds'),(12860,857469867012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',11.99,'eastar4','bobblehoot','bobblehoot@gmail.com','Joseph E DeLaCruz','1719 E Post Oak Rd','Norman','OK','UNITED STATES','73072','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 15:06:30',0,NULL,3,1,1,1,'、 ','bobblehoot'),(12861,572881285003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.89,'cnfaner','jtombrak57','jtombrak@verizon.net','John Tombrakos','11050 71st Rd<br>Apt E Ph E','Forest Hills','NY','UNITED STATES','11375-4971','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 15:14:46',0,NULL,3,1,1,1,' \\ ','jtombrak57'),(12862,857475861012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','menadzer13','menadzer13@onet.eu','DAMIAN LUDWICZAK','61 STATION ROAD','TEYNHAM','Kent','UNITED KINGDOM','ME9 9TJ','07783919114','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 15:16:41',0,NULL,3,1,3,1,'RA184584425CN\r ','menadzer13 英标头'),(12863,629227433013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.95,'eastar4','biggul2','aleksei.gul@gmail.com','Aleksei Gul','Kopli 96B-22','Tallinn','Harjumaa','ESTONIA','10416','+37255626370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:18:50',0,NULL,3,1,2,1,'\\ ','biggul2\r欧标'),(12864,773128067011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',1,'BTHP2010',9.9,'eastar4','ravage8ravage8','helix8@mail.ru','Yuriy Zhyvytsya','60 apt, 16/3 Fontanskaya doroga','Odessa','','UKRAINE','65049','380677135067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:30:18',0,NULL,3,1,2,1,'\\ ','ravage8ravage8\rHP 8pin 1.25 18cm '),(12865,857498155012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','leatherm0nkey','a.ahlsten@gmail.com','anton ahlsten','Tilkankatu 39 b 53','Helsinki','Helsinki','FINLAND','00300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:55:16',0,NULL,3,1,2,1,'\\ ','leatherm0nkey'),(12866,857504314012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',7,'REPL001',76.93,'eastar4','erhorseman','darren@dneilson.com','Darren W Neilson','Box 2 Site 104','Stony Plain','AB','CANADA','T7Z 1X1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 16:03:55',0,NULL,3,1,3,1,'RA184589992CN\r ','erhorseman\rREPL001'),(12867,857512092012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',10.99,'eastar4uk','dhanikk12','dhanikk12@hotmail.com','Dhanikk Patel','61 Oak Road','West Bromwich','West Midlands','UNITED KINGDOM','B70 8HR','07965601194','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 16:14:08',0,NULL,3,1,3,1,'RA184589927CN\r ','dhanikk12'),(12868,572907678003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','cyberklp','cyberklp@hotmail.com','Kurt Pryor','1918 Rawlins Ave','Woodbine','IA','UNITED STATES','51579','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 16:23:04',0,NULL,3,1,1,1,' \\ ','cyberklp'),(12869,773179782011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','plp427','priyal.patel.27@gmail.com','Priyal Patel','2127 State Route 31','Glen Gardner','NJ','UNITED STATES','08826-6415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 16:55:04',0,NULL,3,1,1,1,'、 ','plp427'),(12870,773181031011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','simethedime99','simethedime@hotmail.com','simon umlandt','highclere farm<br>uppersoldridge','medstead','Hampshire','UNITED KINGDOM','gu345qg','01420563056','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 16:57:20',0,NULL,3,1,3,1,'RA184589913CN\r ','simethedime99'),(12871,731952456001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','picolith','glouisr@hotmail.com','Gary Rashman','2321 Carlmont Dr<br>Apt 301','Belmont','CA','UNITED STATES','94002-3303','(650) 814-5049','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 17:05:26',0,NULL,3,1,1,1,'、 ','picolith'),(12872,773193850011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','roncricket','ron@rh42.fsnet.co.uk','Ron Haworth','15 Cricket Path, Birkdale','Southport','Merseyside','UNITED KINGDOM','PR8 2HJ','01704550458','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 17:14:03',0,NULL,3,1,3,1,'RA184584690CN\r ','roncricket'),(12873,629314244013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','james.schenk','jds081468@gmail.com','jim schenk','0222 SW California St','portland','OR','UNITED STATES','97219-2330','(503) 502-0298','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 18:12:59',0,NULL,3,1,1,1,' \\ ','james.schenk'),(12874,857615961012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','llam4392','lamanna.louise@sympatico.ca','Louis Charles La Manna Harvey','198 du châtelet<br>app 1','Gatineau','QC','CANADA','j8m1x4','(819) 961-4099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 18:21:05',0,NULL,3,1,3,1,'RA184584709CN\r ','llam4392\rOTSO004*2'),(12875,773277702011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','kurtbcop','kurtborg@onvol.net','Kurt Borg','Marjeliez<br>E.Giordano Street','Gzira','','MALTA','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 18:52:28',0,NULL,3,1,2,1,'\\ ','kurtbcop\r向日葵三折叠伞 '),(12876,773299915011,320730088383,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',55.99,'eastar4uk','j_sta83','j_stamnes@yahoo.com','Jørgen Stamnes','Bertrand Narvesns vei 49','Oslo','','NORWAY','0661','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 19:19:46',0,NULL,3,1,3,1,'RA184584522CN\r\r\r','j_sta83   \r\r\r'),(12877,629359649013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.59,'eastar4','47argus','sorgmunter@epost.no','Arne Gustav Sorgmunter','c/o E. Rasmussen','Ildskog','Lakselv','NORWAY','9700','(+47)92402853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 19:33:14',0,NULL,3,1,3,1,'RA184584730CN\r ','47argus\r黑色或着银色的'),(12878,773316931011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',2,'OTSO005*2',235.98,'eastar4','sto95','b-esp-st@online.no','Bjørn Espen Storre','Barnålstien 15','Hunndalen','Norway','NORWAY','2827','41658895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 19:42:47',0,NULL,3,1,6,1,'EE495359724CN ','sto95'),(12879,628642147013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','patmtp35','faupatrick@msn.com','Patrick Fau','57 Rue Des Cigales','Juvignac','Languedoc-Roussillon','FRANCE','34990','+33616965915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 20:05:52',0,NULL,3,1,2,1,'\\ ','patmtp35'),(12880,629386923013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','w_maclaurin','wayne@maclaurin.ca','Wayne MacLaurin','8374 ForestGreen Cres','Metcalfe','ON','CANADA','K0A 2P0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 20:30:01',0,NULL,3,1,2,1,'\\ ','w_maclaurin'),(12881,573048081003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',8.89,'cnfaner','538kjg','kgillissie@sbcglobal.net','Ken Gillissie','4460 Hialeah Dr','Parma','OH','UNITED STATES','44134-6212','(440) 886-1459','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-02 21:12:10',0,NULL,3,1,1,1,' \\ ','538kjg'),(12882,573059583003,130554633280,'New Grohe Crystal Anion Spa Shower Head save water',1,'OTGR004',22.9,'cnfaner','diablilla2','laura_022@msn.com','Laura Marín Afonso','Dona Perfecta nº 140','Las Palmas','Las Palmas','SPAIN','35012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 21:57:27',0,NULL,3,1,3,1,'RA184584417CN\r ','diablilla2'),(12883,629420557013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ccc519','cookcj25@rogers.com','Craig Cook','78 Centre Crescent','London','ON','CANADA','N6J2Z6','(519) 432-1911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 22:07:10',0,NULL,3,1,2,1,'\\ ','ccc519'),(12884,857781927012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','jakun2002','jakun@web.de','Jacek Kunat','Quellhofstr. 45','Kassel','','GERMANY','34127','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 22:24:12',0,NULL,3,1,3,1,'RA184584496CN\r ','jakun2002'),(12885,857795337012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','lanarties','alphatobeta@me.com','Jared Hicks','2701 Lincoln Dr E','Ambler','PA','UNITED STATES','19002-3864','(856) 279-3212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 22:57:41',0,NULL,3,1,1,1,'、 ','lanarties\r兼容型3D眼镜 通用型\r\r'),(12886,857800444012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4','davidacampbell','david@pastornet.net.au','David Campbell','19 Gregory St','ACACIA RIDGE','Queensland','AUSTRALIA','4110','0403070773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 23:12:20',0,NULL,3,1,2,1,'\\ ','davidacampbell'),(12887,857805144012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','lkunitz','louisekunitz@rogers.com','Louise Kunitz','58 Birkendale Drive','Kanata','ON','CANADA','K2K2X5','(613) 592-7655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 23:24:11',0,NULL,3,1,2,1,'\\ ','lkunitz'),(12888,857809643012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','davdav112','feblesdavid@gmail.com','David Febles','Adalavagen. 3','Lerum','','SWEDEN','44331','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 23:36:53',0,NULL,3,1,2,1,'\\ ','davdav112  欧标头'),(12889,857811592012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','jon_wilner','jonwilner@hotmail.com','Jonathan Wilner','6421 130th St SE','Snohomish','WA','UNITED STATES','98296','(425) 879-2526','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jon_wilner'),(12890,857820165012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','imran678','akumajin@bellsouth.net','Imran Khan','3733 Memphis Dr','Suwanee','GA','UNITED STATES','30024-6795','(770) 365-4126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 00:07:52',0,NULL,3,1,1,1,' \\ ','imran678'),(12891,629455520013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','gj4040','gj4040422@gmail.com','Gary Johnston','195 Speers Rd','Kingston','TN','UNITED STATES','37763-4024','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 00:21:35',0,NULL,3,1,1,1,'、 ','gj4040'),(12892,773457751011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',29.99,'eastar4','staceyconz630','mrsconz@me.com','stacey connelly','5N164 Deer Pond Dr','St Charles','IL','UNITED STATES','60175-7963','(630) 587-4078','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 01:12:00',0,NULL,3,1,1,1,'、 ','staceyconz630'),(12893,857851785012,220716106718,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',55.9,'eastar4','tngu3000','trangkentucky@yahoo.com','trang nguyen','3615 W San Luis Street','tampa','FL','UNITED STATES','33629','(813) 374-5670','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 01:24:05',0,NULL,3,1,1,1,'、 ','tngu3000'),(12894,573112430003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'cnfaner','prince321974','thekewlcat@hotmail.com','Brandon Hunt','44 Hogan Cres','Bowmnanville','ON','CANADA','l1c4x9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 01:37:26',0,NULL,3,1,3,1,'RA184589811CN\r ','prince321974'),(12895,857858588012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','mashulya','yashapro@gmail.com','Maria Shchelkova','68 Laurel Rd','Princeton','NJ','UNITED STATES','08540-2708','(609) 720-1999','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 01:41:51',0,NULL,3,1,1,1,'、 ','mashulya\r兼容型3D眼镜 通用型'),(12896,773470064011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'eastar4','loki842','asindher@gmail.com','Alok Sindher','1601 3rd Ave<br>Apt 22C','New York','NY','UNITED STATES','10128-0028','(650) 346-4818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 01:49:18',0,NULL,3,1,1,1,' \\ ','loki842'),(12897,857864706012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',3,'GLOT001',134.67,'eastar4','chrisdearing13','dearingchris@hotmail.com','chris dearing','6 Gail st','Kallangur','Queensland','AUSTRALIA','4503','0435007504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 01:59:32',0,NULL,3,1,3,1,'RA184589842CN\r ','chrisdearing13\rGLOT001\r兼容型3D眼镜 通用型'),(12898,629495526013,230641224717,'Transparent Dome Rain Sun Umbrella with yellow trim',1,'UMTR001',19.99,'eastar4','puppylover500','natalia1@nycap.rr.com','Natalia Murdock','718 Riverview Rd','Rexford','NY','UNITED STATES','12148-1316','(518) 399-8408','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 02:44:40',0,NULL,3,0,1,1,' \\ ','puppylover500\r黄色的 \r已入库'),(12899,8881317610573306,111,'罗技 单头 雷管',4,'',6,'eastar4','cbar5225','christophertbarrow@yahoo.com','CHRISTOPHER BARROW','7945 Cherrywood Ct','CINCINNati','OH','UNITED STATES','45224-1113','(513) 886-4400',NULL,NULL,NULL,'2011-10-03 02:56:13',0,NULL,3,1,1,1,'、 ',' 补发  E邮宝改一个\rLK003664636CN'),(12900,8881317610773591,111,'intel 5300 全高卡',1,'WLIN010',0,'eastar4','mishikoff','xmishik@gmail.com','Michael Zbarsky','Aharon Lublin 10/31','Lod','','ISRAEL','71471','',NULL,NULL,NULL,'2011-10-03 02:59:33',0,NULL,5,0,18,0,NULL,NULL),(12901,8881317610836207,111,'intel 5300 全高卡',1,'WLIN010',0,'eastar4','mishikoff','xmishik@gmail.com','Michael Zbarsky','Aharon Lublin 10/31','Lod','','ISRAEL','71471','',NULL,NULL,NULL,'2011-10-03 02:59:33',0,NULL,5,0,18,0,NULL,NULL),(12902,629499836013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','ksinghal','singhal.nj@gmail.com','Kunal Singhal','1610 McConnor Pkwy','SCHAUMBURG','IL','UNITED STATES','60173-6800','(732) 444-4833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 03:03:57',0,NULL,8,1,17,0,NULL,'ksinghal'),(12903,629500306013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',3,'ANCN001',8.94,'eastar4','ksinghal','singhal.nj@gmail.com','Kunal Singhal','1610 McConnor Pkwy','SCHAUMBURG','IL','UNITED STATES','60173-6800','(732) 444-4833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 03:05:40',0,NULL,3,1,1,1,' \\ ','ksinghal\r一共买了四个'),(12904,8881317611253344,111,'intel 5300 全高卡',1,'WLIN010',0,'eastar4','mishikoff','xmishik@gmail.com','Michael Zbarsky','Aharon Lublin 10/31','Lod','','ISRAEL','71471','',NULL,NULL,NULL,'2011-10-03 02:59:33',0,NULL,3,1,3,1,'RA184589825CN\r ','WLIN010 \r补发的\r发货了，由于改不了状态'),(12905,8881317612616264,111,'New Logitech Rechargeable battery L-LB2 1700mAh',1,'BALO007',0,'eastar4','yotsuya0f30','angers.claude@gmail.com','Claude Angers','1239 chemin Ste-Claire','Riviere-Beaudette','QC','CANADA','j0p1r0','',NULL,NULL,NULL,'2011-10-03 03:30:16',0,NULL,3,1,3,1,'RA184584465CN\r ','补发的\rBALO007 \r发货了，由于改不了状态'),(12906,8881317614802751,111,'MC8781',1,'WWSI005',36,'eastar4','Facundo N Vivado Loria','npviv@yahoo.com.ar','Facundo N Vivado Loria','Chascomús 4668<br>Capital Federal','Buenos Aires Ciudad de Buenos Aires','','ARGENTINA','1407 ','',NULL,NULL,NULL,'2011-10-03 04:06:42',0,NULL,3,1,3,1,'RA184589697CN\r ','WWSI005 \r发货了，由于改不了状态'),(12907,773511842011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',84.95,'eastar4uk','ipad','phil@macbank.co.uk','AMY GOLDSMITH -SCRUMPYMACS LTD','UNIT 2A RIVERSIDE INDUSTRIAL PARK<br>RAPIER STREET','IPSWICH','Suffolk','UNITED KINGDOM','IP2 8JX','01473680100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-03 04:37:11',0,NULL,3,1,3,1,'RA184584672CN\r ','ipad\rMOAP001'),(12908,773514083011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','sketchthat_com','kimpton@gmail.com','Michael Kimpton','96 - 98 Market Street','South Melbourne','Victoria','AUSTRALIA','3205','0390956245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 04:49:38',0,NULL,3,1,2,1,'\\ ','sketchthat_com'),(12909,773517515011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','jillcb10','jblakely4@bigpond.com','Jill Blakely','932 Boston Rd<br>Chandler','Brisbane','Queensland','AUSTRALIA','4155','0733903505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 05:13:58',0,NULL,3,1,2,1,'\\ ','jillcb10\r澳标'),(12910,732265745001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','geoff.03','bazzle1@optusnet.com.au','GEOFF ENNOR','1 GRESHAM COURT','GOLDEN SQARE','Victoria','AUSTRALIA','3555','0354478860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 05:35:31',0,NULL,3,1,3,1,'RA184584655CN\r ','geoff.03\rBR3D005'),(12911,573077234003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','kei_23','keinotez_23@msn.com','Karl H Goodman','3727 w 130th st','cleveland','OH','UNITED STATES','44111-3315','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-03 05:41:08',0,NULL,3,1,1,1,NULL,'kei_23\r发OEM的'),(12912,578685418004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',19.9,'cnfaner','razuvay1','bimdim@gmail.com','DMITRY RAZUVAY','DOM 31, KVARTIRA 92<br>BARVIHA, ','MOSCOW','','RUSSIAN FEDERATION','143083','+7(905)5957898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 05:56:07',0,NULL,3,1,3,1,'RA184584805CN\r ','razuvay1\rOTGR001'),(12913,857925028012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','colinng','colinng@ngland.net','Colin Ng','6116 Lanark Street','Vancouver','BC','CANADA','V5P2Y8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 06:11:27',0,NULL,3,1,2,1,'\\ ','colinng'),(12914,857928340012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.19,'eastar4','gcp1119','gcars@iinet.net.au','Russell Gilder','P.O.Box 1197<br>Eagle Farm','Brisbane','Queensland','AUSTRALIA','4009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 06:28:53',0,NULL,3,1,2,1,'\\ ','gcp1119\r澳标'),(12915,857933257012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','rabebe','bert.behrendt@gmx.de','Bert Behrendt','Gilgenburger Straße 27','Berlin','','GERMANY','12587','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 06:51:25',0,NULL,3,1,3,1,'RA184584584CN\r ','rabebe\r欧标\rHSPL009'),(12916,714772127008,180699060430,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.99,'au-buy','thof77','mparejanieto@gmail.com','Mario Pareja Nieto','Circunvalacion 84 4o 2a','Badalona','Barcelona','SPAIN','08914','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 07:24:46',0,NULL,3,1,3,1,'RA184584567CN\r ','thof77\rGLOT004\r兼容型3D眼镜  samsung 专用'),(12917,629542221013,230655993632,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4','igelstellung','gernsback@gmail.com','Roman Llorente-Casas','Nikulinskaya, 11, 209','Moscow','Moscow','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 07:50:16',0,NULL,3,1,2,1,'\\ ','igelstellung\r红色的\rLED发光伞'),(12918,773550920011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','alphaest2','alphaest@gmail.com','Toomas Tomson','Kloostri 6-1','Tartu','','ESTONIA','51007','+37253986779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 08:06:29',0,NULL,3,1,3,1,'RA184589520CN\r ','alphaest2\r欧标'),(12919,773554687011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','slv1972','slav.vs@gmail.com','Vyacheslav Strekozov','Nagatinskaya nab. 40/1, apt. 305','Moscow','','RUSSIAN FEDERATION','115470','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 08:20:52',0,NULL,3,1,2,1,'\\ ','slv1972'),(12920,857977791012,220747230841,'New Motorola H670 Bluetooth Wireless Headset H 670',4,'HSMO010',35.96,'eastar4uk','mergs06','mergs@hotmail.com','Troy Murgatroyd','The Groves<br>Unit 111, 11 West Dianne Street','Lawnton','Queensland','AUSTRALIA','4501','0408474422','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 09:35:18',0,NULL,3,1,3,1,'RA184589652CN\r ','mergs06\r澳标\rHSMO010\r客户同意就发两个   然后退另外两个的钱'),(12921,857893542012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.9,'eastar4','daveedmunds','mdedmunds1@eastlink.ca','Dave P Edmunds','1129 andringa Drive','Cambridge','NS','CANADA','B0P 1G0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 10:00:39',0,NULL,3,1,2,1,'\\ ','daveedmunds\racer 4pin1.25 8cm '),(12922,573197079003,130522150221,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER iPHONE IPAD IPOD',1,'BAZA001',57.9,'cnfaner','garveybiz','chrisgarveybiz@gmail.com','Robert Garvey','28 Bradley Street','Dayboro','Queensland','AUSTRALIA','4521','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 10:14:48',0,NULL,3,1,3,1,'RA184589621CN\r ','garveybiz\rBAZA001'),(12923,857368219012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.95,'eastar4','tradeufa','ufatrade@inbox.ru','Kuptsov Kirill','Parkovaja street 6/2 - 36','Ufa','Republic Bashkortostan','RUSSIAN FEDERATION','450083','347-272-56-61','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 10:18:57',0,NULL,3,1,2,1,'\\ ','tradeufa'),(12924,773601666011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',27.99,'eastar4uk','nimnim2001','nimnim2001@hotmail.com','Nimrod Csasznik','25 Betsal\'el st.<br>appt. # 10','Tel - Aviv','','ISRAEL','64683','972-52-2238670','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 11:02:02',0,NULL,3,1,3,1,'RA184589578CN\r ','nimnim2001\rOTPL001'),(12925,629585744013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',20,'WLAP008',357.6,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+7 (905) 7183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 11:21:18',0,NULL,3,1,3,1,'RA184589604CN\r ','michel_egorov\rWLAP008'),(12926,857365728012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','7lollies','briansmith5@optusnet.com.au','Carly Smith','25 Decastella Drive','Horsham','Victoria','AUSTRALIA','3400','0353825014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 11:24:39',0,NULL,3,1,3,1,'RA184589462CN\r ','7lollies\rOTSO004*2'),(12927,773616228011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','horsehoney09','ellis@crownwood.co.uk','Att:  MRS DEBRA ELLIS','LEMONGRASS KITCHENS LTD<br>UNIT 12 RADFORD CRESCENT','BILLERICAY','Essex','UNITED KINGDOM','CM12 0DG','01277634343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 11:48:45',0,NULL,3,1,2,1,'\\ ','horsehoney09\r英标'),(12928,573219162003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','syl47den','tva-47@hotmail.com','sylvain denis','2021 marcel','st jerome','QC','CANADA','j5l1z2','(450) 432-7901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:04:27',0,NULL,3,1,3,1,'RA184589516CN\r ','syl47den\rHSPL010'),(12929,857376518012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',32.57,'eastar4','valeriy1332','valeriy133@rambler.ru','Valery Goloulin','Pravdy 18/1 -36','Ufa','Bashkortostan','RUSSIAN FEDERATION','450024','(927)232-2234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:10:16',0,NULL,3,1,3,1,'RA184589581CN\r ','valeriy1332\rWLIN012+ANTY002\r再发一个Triple Tyco Universal Wireless Laptop Antenna Mini PCI\r'),(12930,857922498012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',10,'OTIN001',219.9,'eastar4','gan1970','nag@abbeylane.biz','Abbey Lane, Inc','715 Discovery Blvd<br>Ste 502','Cedar Park','TX','UNITED STATES','78613-2293','(512) 250-0502','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 12:20:20',0,NULL,3,1,4,1,'YW866012432CN ','gan1970'),(12931,773622908011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','ihaxaleksander','sandi.kopcic@gmail.com','Aleksander Kopcic','Zeleznikova 22','Maribor','Maribor','SLOVENIA','2000','0038624710784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:24:08',0,NULL,3,1,2,1,'\\ ','ihaxaleksander'),(12932,773630476011,320730530069,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','min4a','root@shopaz.net','Emil Yahyayev','Shirvahi str 2A app.8','Baku','Baku','AZERBAIJAN','AZ1142','994-50-3439588','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 12:33:29',0,NULL,3,1,2,1,'、 ','min4a\r24K超轻碳纤骨长柄伞\r蓝色的'),(12933,773632930011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',69.9,'eastar4','fdamata','fabianodamata@yahoo.com.br','Fabiano da Mata Almeida','Rua Prof. José Americano, 126<br>APTO 104 - Fonte Grande','Contagem','MG','BRAZIL','32013-520','+55 31 86343417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:41:03',0,NULL,3,1,3,1,'RA184589547CN\r ','fdamata\rMOSA005'),(12934,856909107012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',205.99,'eastar4','kkmspm1','amasavetas@ath.forthnet.gr','Massavetas Thanassis','sokratous 37 peristeri','athens','','GREECE','12134','+306947994081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 13:13:35',0,NULL,3,1,6,1,'EE495359715CN ','kkmspm1'),(12935,858066427012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','sottah_eshop','sylvesterottah@yahoo.co.uk','Sylvester Ottah','9 Clydach Road','Enfield','Middlesex','UNITED KINGDOM','EN1 3SL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-03 13:53:19',0,NULL,3,1,3,1,'RA184589555CN\r ','sottah_eshop\rGLOT001*2\r兼容型3D眼镜 通用型'),(12936,732406383001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','knicksbg','bennygon@aol.com','Ben Gonzalez','54 Ray St','Freeport','NY','UNITED STATES','11520-5125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 14:29:56',0,NULL,3,1,1,1,'\\ ','knicksbg'),(12937,858083937012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','fer_nan_do_pi','fer_nan_do@hotmail.com','Fernando Pichardo Dominguez','Platillos Nº7 3ªB','Madrid','Madrid','SPAIN','28054','913347124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 14:38:02',0,NULL,3,1,2,1,'\\ ','fer_nan_do_pi'),(12938,773682605011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','wonderbargirl','sohui_lee@hotmail.com','James Chan','2736 Delaware Ave','Redwood City','CA','UNITED STATES','94061-3219','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 15:08:12',0,NULL,3,1,1,1,'\\ ','wonderbargirl'),(12939,732421144001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','sergesvs','svetlo@vitalway.com','Serge Shirshov','47 W Evergreen Dr','Kalispell','MT','UNITED STATES','59901-2859','(406) 752-6551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 15:11:27',0,NULL,3,1,1,1,'\\ ','sergesvs'),(12940,714916388008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','djmad_mike','michael.nelson@guidant.com','Mike T. Nelson','1261 Birch Ct','White Bear Lake','MN','UNITED STATES','55110','(651) 582-5389','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 15:28:59',0,NULL,3,1,1,1,'\\ ','djmad_mike'),(12941,773693811011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.96,'eastar4','cbroverman','cbroverman@rcn.com','Carol Broverman','51 Cotter Rd','Waban','MA','UNITED STATES','02468-1000','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 15:29:59',0,NULL,3,1,1,1,'\\ ','cbroverman'),(12942,773707074011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','costingusu','blackchristall@yahoo.com','Gusu Constantin','Emanuel Street<br>No. 38','Portsmouth','Hampshire','UNITED KINGDOM','PO2 7BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-03 16:01:29',0,NULL,3,1,3,1,'RA184589480CN\r ','costingusu\rGLOT001*2\r兼容型3D眼镜 通用型'),(12943,858133047012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.98,'eastar4','sccutler','scutler@cutler-smith.com','Sewall C. Cutler, Jr.','12750 Merit Drive Suite 1450','Dallas','TX','UNITED STATES','75251','(214) 914-9951','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 16:28:43',0,NULL,3,1,1,1,'\\ ','sccutler'),(12944,629666946013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.88,'eastar4','cthom123','chuck@rockontexas.com','Charles Thomas','6101 W Plano Pkwy','Plano','TX','UNITED STATES','75093-8201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 16:29:43',0,NULL,3,1,1,1,'\\ ','cthom123'),(12945,858130495012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','monoacero','eleonm@gmail.com','Epigmenio Leon','República de Brasil 37<br>Centro Historico','Mexico','Mexico','MEXICO','06020','+52 5532211879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 16:34:53',0,NULL,3,1,2,1,'\\ ','monoacero\racer 6pin1.25 23cm'),(12946,629712771013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','chemist27','d_dobler@yahoo.com','Darin Dobler','1625 Piccard Drive, #403','Rockville','MD','UNITED STATES','20850','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 18:23:12',0,NULL,3,1,1,1,'\\ ','chemist27'),(12947,858206680012,220759896680,'New HP BCM970012 BroadCom BCM70010 HD Decoder',1,'OTHP001',28.99,'eastar4','tosikkos','marko.sarkijarvi@gmail.com','Marko Särkijärvi','iilikentie 14 as 8','Halikko','Halikko','FINLAND','24800','0400340070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 18:29:29',0,NULL,3,1,2,1,'\\ ','tosikkos'),(12948,858233515012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','cngolfaz','cwnaas@cox.net','Craig Naas','11950 E Forty Niner Dr','Tucson','AZ','UNITED STATES','85749-9277','(520) 760-4541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 19:09:25',0,NULL,3,1,1,1,'\\ ','cngolfaz'),(12949,629734458013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','oyvindisdahl99','oyvindisdahl@gmail.com','Hege Sagberg','Hemneveien','Fannrem','Sør-Trøndelag','NORWAY','7320','004799462262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 19:12:19',0,NULL,3,1,2,1,'\\ ','oyvindisdahl99'),(12950,629735850013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','europa.xii','dbozu@hotmail.com','Drazen Bozunovich','4513 Emerald Way','Culver City','CA','UNITED STATES','90230-4218','(310) 384-0971','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 19:15:43',0,NULL,3,1,1,1,'\\ ','europa.xii'),(12951,773821652011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','antony39v8','tonybloodworth@hotmail.co.uk','antony bloodworth','2 seathwaite road','king\'s lynn','Norfolk','UNITED KINGDOM','pe303uw','01553679017','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-03 19:26:01',0,NULL,3,1,3,1,'RA184589476CN\r ','antony39v8\rGLOT001*2\r兼容型3D眼镜 通用型'),(12952,773823086011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4','m00b00','spamcrap@home.nl','D. de Haan','Verlengde Meeuwerderweg 199','GRONINGEN','','NETHERLANDS','9723 ZN','0505890269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 19:30:12',0,NULL,3,1,2,1,'\\ ','m00b00'),(12953,858249593012,220815929490,'New Atheros AR9287 BGN 300M Half PCI-E card+ANTENNA',1,'WLAT007+ANTY001',10.7,'eastar4uk','xazer007','anton@doronin.co.uk','Anton Doronin, c/o Eastbiz Corp.','4310 W. 190th St., Suite # 76055','Torrance','CA','UNITED STATES','90504','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 19:34:17',0,NULL,3,1,1,1,'\\ ','xazer007'),(12954,573350883003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',3,'HSPL010',95.97,'cnfaner','rodneyistheman','rmoffat@belley.net','A R Belley Inc','1035 rue Panneton','Sherbrooke','QC','CANADA','J1K 2B3','(819) 823-1843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 20:04:58',0,NULL,3,1,3,1,'RA184589635CN\r ','rodneyistheman\rHSPL010'),(12955,858269900012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','bountzoukas','bountzoukas@yahoo.gr','Giannis Mpountzoukas','Gergeris 4 Dileina','Heraclion Crete','','GREECE','71304','+306947741499','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 20:07:00',0,NULL,3,1,3,1,'RA184589649CN\r ','bountzoukas\rMOMI001'),(12956,568965996003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',26.95,'cnfaner','kristam.2012','kristamcneal@yahoo.com','Krista McNeal','7704 Alexanders Ridge Cv','Olive Branch','MS','UNITED STATES','38654-4150','(662) 890-4505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-03 20:38:29',0,NULL,3,1,1,1,'\\ ','kristam.2012'),(12957,629756945013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.4,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 21:38:56',0,NULL,3,1,1,1,'\\ ','revikom\rHP 8pin 1.25 18cm '),(12958,573397318003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',3,'HSMO019',47.97,'cnfaner','icewulfwhitetigers','polarbear69x@hotmail.com','Sean McCabe','3203 S Spring Creek Ln','Spokane','WA','UNITED STATES','99224-9628','(360) 463-0672','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-03 22:00:48',0,NULL,3,1,1,1,'、 ','icewulfwhitetigers'),(12959,858326302012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.9,'eastar4','ses_cz','jursaj@centrum.cz','Jiri Jursa','Mrenkova 58','Ivancice','Czech Republic','CZECH REPUBLIC','66491','+420608000408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 22:06:48',0,NULL,3,1,2,1,'\\ ','ses_cz\racer 8pin1.00 8cm '),(12960,730254516001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','georgeofl','ggato069@concast.net','Gregory Gatto','238 old willets path','smithtown','NY','UNITED STATES','11787-4125','(516) 810-6199','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 23:09:58',0,NULL,3,1,1,1,'\\ ','georgeofl'),(12961,858363148012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',26.99,'eastar4uk','hmgodinho','henrique.godinho@gmail.com','Henrique Godinho','Rua 612<br>Quadra 570 Lote 01 Nº 449 Setor Aeroviário','Goiânia','Goiás','BRAZIL','74435290','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 23:56:16',0,NULL,3,1,3,1,'RA184589595CN\r ','hmgodinho\rRCLO006\r新的'),(12962,858377695012,220815856735,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.99,'eastar4','dmonte123','dmonte123@comcast.net','dennis c monte','32 maplewood dr','brick','NJ','UNITED STATES','08723','(732) 277-1145','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 00:43:00',0,NULL,3,1,1,1,'\\ ','dmonte123'),(12963,629833446013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','kisauren1','kisauren@gmail.com','Lisa Christiansen','1 Ambrose Dr','Horseheads','NY','UNITED STATES','14845-1300','(607) 398-2352','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 00:58:50',0,NULL,3,1,1,1,'\\ ','kisauren1'),(12964,773949263011,320661086344,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',22.9,'eastar4','hako86','hakobdloren@hotmail.com','Lorenzo Solomon','88 Brisdale rd.','Brampton','ON','CANADA','L7A2G8','(905) 846-4196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 01:03:41',0,NULL,3,1,2,1,'\\ ','hako86'),(12965,773949800011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','babooska17','kylie_campbell@yahoo.com','Kylie Campbell','117 Augusta Rd','Lenah Valley','Tasmania','AUSTRALIA','7008','61400172829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 01:05:59',0,NULL,3,1,2,1,'\\ ','babooska17'),(12966,773952962011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.9,'eastar4','edreis2011','edreis@ymail.com','Ed Reis','Calle Santa Margarita 340<br>Riberas del Pilar','Chapala','Jalisco','MEXICO','45915','(376) 765-7249','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 01:21:12',0,NULL,3,1,3,1,'RA184589618CN\r','edreis2011\rHSLO001'),(12967,573444015003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','creid46438','reid@christophermusic.com','Chris Reid','464 Stanton Dr','Springboro','OH','UNITED STATES','45066','(937) 241-5311','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 01:52:23',0,NULL,3,1,1,1,'\\ ','creid46438'),(12968,773966980011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','borjalj','borjalopez@hotmail.com','Borja Lopez','1585 Five Forks Rd','Bedford','VA','UNITED STATES','24523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 02:09:41',0,NULL,3,1,1,1,'\\ ','borjalj'),(12969,8881317694468430,111,'IBM版 6250 622ANXHMW',1,'WLIN002',0,'eastar4','allmaz1','bullterrier@live.ru','Alla Mazur','Chebrikova st. 40/523','Sochi','','RUSSIAN FEDERATION','354057','(7) 9183048883',NULL,NULL,NULL,'2011-10-04 02:14:28',0,NULL,3,1,3,1,'RA184589564CN\r ','补发的 \rWLIN002\r'),(12970,629850792013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','natoe1','n.albrighton@gmail.com','nathan Albrighton','PO Box 7094','Greenway','Australian Capital Territory','AUSTRALIA','2900','0439366437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 02:16:45',0,NULL,3,1,2,1,'\\ ','natoe1'),(12971,8881317695837715,111,'花洒底部的塑料圈 再加两个橡胶圈',1,'',0,'eastar4','woodlandplace','deecee3@sky.com','Mr D Griffiths','36 Heol Dylan<br>North Cornelly','Bridgend','Bridgend','UNITED KINGDOM','CF33 4LE','01656740809',NULL,NULL,NULL,'2011-10-04 02:37:17',0,NULL,3,0,2,1,'\\ ','那就补发一个花洒吧 \r已发，由于不能改系统 '),(12972,858411348012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','pearldave','pnd@guam.net','Pearl A. CHAPMAN','PO Box 3538','Hagatna','GU','UNITED STATES','96932-3538','(671) 777-5505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 02:47:15',0,NULL,3,1,1,1,'\\ ','pearldave'),(12973,8881317697527519,111,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',0,'eastar4','patt022010','patanasit02@gmail.com','Patanasithi Khemngern','1279 Border Patrol Police, Phahonyotin Road,<br>Samsennai,','Phayathai','Bangkok','THAILAND','10400','6622788000',NULL,NULL,NULL,'2011-10-04 03:05:27',0,NULL,3,1,3,1,'RA184589105CN\r ',' 补货\rOTCN004*10\r已发，由于不能改系统 '),(12974,8881317697682296,111,'jabra BT250V',1,'HSJA001',0,'eastar4','montecarlosusan','srbarton3@msn.com','Susan Barton','PO Box 99<br>6265 Mangrove st','Scottsmoor','FL','UNITED STATES','32775-0099','(321) 268-5324',NULL,NULL,NULL,'2011-10-04 03:08:02',0,NULL,3,1,1,1,'\\ ',' 补全套 E邮宝 改一个\rLK045429744CN\r已发，由于不能改系统 '),(12975,715184178008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',71,'au-buy','colhoun78','colhoun@iinet.net.au','Chris Colhoun','Hood Sweeney Technology, 11-16 South Terrace','Adelaide','South Australia','AUSTRALIA','5000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 03:21:55',0,NULL,3,1,3,1,'RA184589082CN\r ','colhoun78\rGLOT005'),(12976,858440618012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',153.99,'eastar4','ukbeatz','nnorman_bates@hotmail.com','Christopher Lestus','7227 Essex Way','Sherwood Park','AB','CANADA','T8H 0L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 04:40:40',0,NULL,3,1,3,1,'RA184589096CN\r ','ukbeatz\rGLSG001*3'),(12977,573471382003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','biddn4stuff','chadh0@yahoo.com','chad hancock','33872 el encanto ave','dana point','CA','UNITED STATES','92629-2244','(310) 386-4157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 04:45:42',0,NULL,3,1,1,1,'\\ ','biddn4stuff'),(12978,732716214001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','fatjoejr2001','da1truemaster@aol.com','Marlon Irizarry','97 Ocean Pkwy','Brooklyn','NY','UNITED STATES','11218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 05:18:07',0,NULL,3,1,1,1,'\\ ','fatjoejr2001'),(12979,858449716012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*3',78.99,'eastar4uk','adrian_kabakchiev','poco_loco@abv.bg','Adrian','Llacuna de Sanabria Bl-8 bajos B','Palma','Baleares','SPAIN','07013','666772229','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 05:24:42',0,NULL,3,1,3,1,'RA184589079CN\r ','adrian_kabakchiev\rGLOT004*3\r兼容型3D眼镜  samsung 专用'),(12980,579016364004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.9,'cnfaner','rickattheauction','rickattheauction@comcast.net','Rick DeSlover','7213 Hall Rd','Greenbrier','TN','UNITED STATES','37073-4853','(615) 516-1261','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 05:50:51',0,NULL,3,1,1,1,'\\ ','rickattheauction\r银色的 '),(12981,858457542012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','emica333','ema333ema@hotmail.com','VANJA DOBRIC , NAKIT ONA - MERCATOR','LJUBLJANSKA 36<br>id: si98994824','SLOVENSKA BISTRICA','','SLOVENIA','2310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 06:06:17',0,NULL,3,1,2,1,NULL,'emica333'),(12982,8881317710475824,111,'补发一个欧标转换头',1,'',0,'eastar4','maor_a18','maor0247@gmail.com','Maor Avraham','Hatothanim 8/4','Kiryat-Gat','','ISRAEL','82201','0546574449',NULL,NULL,NULL,'2011-10-04 06:41:15',0,NULL,3,0,2,1,'\\ ','已发，由于不能改系统 '),(12983,858467655012,220705197723,'New Genuine Motorola RAZR H3 Bluetooth Wireless Headset',2,'HSMO003',13.8,'eastar4uk','uzs58d','olaf_roemmelt@web.de','Olaf Roemmelt','Am Hoefgen 15','Haan','','GERMANY','42781','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 07:01:34',0,NULL,3,1,2,1,'\\ ','uzs58d\r欧标'),(12984,573490857003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','juanc2323','juan@juanortega.com','juan ortega','2809 Santa Laura','mission','TX','UNITED STATES','78572-7652','(956) 580-3584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 07:30:49',0,NULL,3,1,1,1,'\\ ','juanc2323'),(12985,573492415003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',12,'HSPL010',383.88,'cnfaner','findscheaper','mark_furman@hotmail.com','rami esses','1316 Avenue M<br>Ste 2','brooklyn','NY','UNITED STATES','11230-5206','(718) 676-0368','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 08:02:04',0,NULL,3,1,4,1,'YW866012443CN ','findscheaper'),(12986,629907131013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.9,'eastar4','dennisrawet','dennis.rawet@gmail.com','Dennis Rawet','Hättingsgatan 71B','Norrköping','','SWEDEN','60361','+46707522588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 08:20:54',0,NULL,3,1,2,1,'\\ ','dennisrawet'),(12987,629911097013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','kamijyo_japan','kamijyo@gmail.com','Shintaro Kamijyo','Sekido 3-14-8<br>chez-moi sakuragaoka 405','Tama-shi','Tokyo','JAPAN','206-0011','042-400-0567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 08:47:07',0,NULL,3,1,2,1,'\\ ','kamijyo_japan'),(12988,573504929003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',22.8,'cnfaner','kocsis_ibolya_hu','ibolya@deltaline.hu','Kocsis Julianna','Bocskai u. 43.','Budapest','Budapest','HUNGARY','1193','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:08:29',0,NULL,3,1,3,1,'RA184589017CN\r ','kocsis_ibolya_hu\rHSSE004\r欧标\r'),(12989,774054881011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','barzino','yves.barzin@mobistar.be','Barzin Yves','Rue des Monts  19','Pondrome','','BELGIUM','5574','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:21:42',0,NULL,3,1,2,1,'\\ ','barzino'),(12990,774054840011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','amarguli1','alex.margulis@marvell.com','Alex Margulis','Shevet Dan 10/22','Ashdod','','ISRAEL','77677','972-54-2509441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:23:03',0,NULL,3,1,2,1,'\\ ','amarguli1'),(12991,715252595008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','beach_dweller','nick_lambropoulos@fastmail.fm','Nick lambropoulos','67 Veda St<br>Hamilton','Newcastle','New South Wales','AUSTRALIA','2303','0419319964','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 09:33:26',0,NULL,3,1,3,1,'RA184589330CN ','beach_dweller\r澳标\rHSPL001'),(12992,774067005011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','vmanhoney','vincentvarney@hotmail.com','Vincent Varney','3 Clissold Street','Katoomba','New South Wales','AUSTRALIA','2780','0247825868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 10:16:00',0,NULL,3,1,2,1,'\\ ','vmanhoney'),(12993,774073526011,320730088383,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',55.99,'eastar4uk','tozza23','danieltozza@gmail.com','Daniel Tosevic','26 Webster cres, Watsonia','melbourne','Victoria','AUSTRALIA','3087','0394329234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 10:37:39',0,NULL,3,1,3,1,'RA184589065CN ','tozza23\rMOSA006'),(12994,715273210008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',63.98,'au-buy','peterjanetzki','peter@peterj.com.au','Peter Janetzki','PO Box 3099','BIRKDALE','Queensland','AUSTRALIA','4159','0738228336','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 11:03:36',0,NULL,3,1,3,1,'RA184589365CN ','peterjanetzki\rHSPL010\r澳标'),(12995,774083301011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','dc.lo.fi','dcluck@gmail.com','David Cluck','539 Classen Dr','Dallas','TX','UNITED STATES','75218-1727','(214) 701-8526','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 11:14:50',0,NULL,3,1,1,1,'、 ','dc.lo.fi'),(12996,573534149003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',22.8,'cnfaner','verwolf125','verwolf25@mail.ru','Александр Тюкавкин','Первая Рабочая, 74, 59','Артем','Приморский край','RUSSIAN FEDERATION','692771','+79242503093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 11:56:49',0,NULL,3,1,3,1,'RA184589326CN ','verwolf125\r欧标\rHSSE004'),(12997,629945535013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','crysanddave','cboot@optusnet.com.au','David Boothby','10 Oswin St','Crib Point','Victoria','AUSTRALIA','3919','0359839156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 11:57:26',0,NULL,3,1,2,1,'\\ ','crysanddave\rCAB-6060'),(12998,858547822012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','ollen1410','neansh11@yahoo.com.au','neil sheahan','4 A. Doveton st','castlemaine','Victoria','AUSTRALIA','3450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:11:23',0,NULL,3,1,2,1,'\\ ','ollen1410'),(12999,858553037012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',2,'MOMI002',27.58,'eastar4','murabnoob','rafaeltsb@gmail.com','Rafael Brites','Rua Campos Salles,2063<br>Bairro dos Alemães','Piracicaba','Sao Paulo','BRAZIL','13416-310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:28:10',0,NULL,3,1,2,1,'\\ ','murabnoob'),(13000,858556116012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',4,'MOMI002',55.16,'eastar4','marcelosan86','marcelo_san_@hotmail.com','MARCELO A.  ALBURQUERQUE','Rua Marechal Deodoro 888 Apt 101<br>Zona 07','Maringá','Paraná','BRAZIL','87030-020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:37:40',0,NULL,3,1,3,1,'RA184589215CN ','marcelosan86\rMOMI002'),(13001,774107509011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','atho7149','amy_leigh_thompson@hotmail.co.uk','Amy Thompson','39 Dove Close<br>Killingworth','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE12 6TG','01912560109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:38:39',0,NULL,3,1,2,1,'\\ ','atho7149'),(13002,774110374011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','terry_brans','terry.bransbury@ntlworld.com','Theresa Bransbury','53 Erlanger Road','New Cross','London','UNITED KINGDOM','se14 5tf','02076392410','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-04 12:47:14',0,NULL,3,1,2,1,'\\ ','terry_brans\r向日葵三折叠伞 '),(13003,858561766012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','marcie_wagner','marcielynnae@comcast.net','Marcie L Wagner','4136 Zenith Ave N','Minneapolis','MN','UNITED STATES','55422','(763) 913-1264','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 12:56:04',0,NULL,3,1,1,1,'、 ','marcie_wagner'),(13004,774135047011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',3,'RELO002',38.94,'eastar4','valeri_ab','valeri_ab@abv.bg','Valeri Belitchenov','15-17 Tintiava Str.<br>Reset Computers Ltd.','Sofia','','BULGARIA','1113','00359 888517172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 14:07:37',0,NULL,3,1,3,1,'RA184586191CN ','valeri_ab\rRELO002'),(13005,774135379011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.88,'eastar4','walrus121','walrus@bellsouth.net','William Quarles','265 N Main St<br>Apt 3','HARRISONBURG','VA','UNITED STATES','22802-3830','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 14:08:02',0,NULL,3,1,1,1,'、 ','walrus121'),(13006,579101232004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','cros3775','rosenbergs@gmail.com','Cheryl Rosenberg','268 Booth AVe','Englewood','NJ','UNITED STATES','07631','(201) 567-6008','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 14:15:53',0,NULL,3,1,1,1,'、 ','cros3775'),(13007,774143506011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'eastar4','swoosh5082003','jstheise@gmail.com','Jeff S Theise','10 MacDonald Ln','Framingham','MA','UNITED STATES','01702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 14:33:06',0,NULL,3,1,1,1,'、 ','swoosh5082003'),(13008,858599521012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','jkbuha','julian.buhagiar@gmail.com','Julian K Buhagiar','205 Latymer Court<br>Hammersmith Road','London','London','UNITED KINGDOM','W6 7JY','07834265126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 14:39:28',0,NULL,3,1,2,1,'\\ ','jkbuha'),(13009,858599793012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',57.98,'eastar4','rcgort','rcg.mjg@comcast.net','Richard C. Gortowski','1051 Freedom Cir S','Crown Point','IN','UNITED STATES','46307','(219) 226-3175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 14:41:13',0,NULL,3,1,1,1,'、 ','rcgort'),(13010,774148996011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','ipodamou','arnaud-b@optionplus.com','Option + Arnaud Bordalis','107 avenue Georges Clemenceau','Nanterre','Île-de-France','FRANCE','92000','336 1434 2998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 14:48:45',0,NULL,3,1,3,1,'RA184589286CN ','ipodamou\rTRTS001*10'),(13011,774154448011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','bobrasenski','bobrasenski@msn.com','frédérick aubert','23 lot le coteau des hochettes','espeluche','Rhône-Alpes','FRANCE','26780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 15:03:46',0,NULL,3,1,3,1,'RA184589388CN ','bobrasenski\rRCLO008'),(13012,715354692008,180699062479,'2 pairs genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',99.99,'au-buy','naladchik2011','sergey_uliy@mail.ru','siarhey dashkoyski','pobediteley 77-56','Minsk','','BELARUS','220020','375296263348','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 15:37:19',0,NULL,3,1,3,1,'RA184589140CN ','naladchik2011\rGLSG001*2'),(13013,858630550012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','boyxzj','vinssion@gmail.com','Zijian Xu','501 W 133rd St<br>Apt 20','New York','NY','UNITED STATES','10027-7329','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 16:05:41',0,NULL,3,1,1,1,'、 ','boyxzj'),(13014,774163934011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','xandisland','xander-france@hotmail.com','Alexander France','3020 Persimmon Place','Nanaimo','BC','CANADA','v9t 4p2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 15:49:41',0,NULL,3,1,2,1,'\\ ','xandisland'),(13015,0,120785211026,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',9.99,'buysia','minh3221','minh3221@yahoo.com','Minh Nguyen','4103 Clear vista path','round rock','TX','UNITED STATES','78665-1207','(512) 287-1148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 16:11:25',0,NULL,3,1,1,1,'、 ','minh3221'),(13016,774180140011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',10,'HSJA011',299.9,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 16:11:55',0,NULL,3,1,4,1,'YW866011986CN ','gogo-buyers'),(13017,858653869012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','thomashouston10','thomas.houston@rocketmail.com','thomas houston','36/4 magdalene drive','edinburgh','Midlothian','UNITED KINGDOM','eh15 3ed','01316200230','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 16:51:06',0,NULL,3,1,3,1,'RA184589255CN ','thomashouston10\rHSPL011\r英标'),(13018,573605372003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',28.9,'cnfaner','aleksman','alejandro.j_m@hotmail.com','Alejandro Martinez','122 Trestle Tree','San Marcos','TX','UNITED STATES','78666-4262','(210) 505-3093','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 16:58:34',0,NULL,3,1,1,1,'、 ','aleksman'),(13019,858677146012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','shem1010','frotka233@yahoo.com','TERESA SUROWKA','5/4 WEST PILTON DRIVE','Edinburgh','Midlothian','UNITED KINGDOM','EH 4 4HR','07742631066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 17:36:05',0,NULL,3,1,2,1,'\\ ','shem1010'),(13020,579160356004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.7,'cnfaner','fredrik.ahl','fredrik@fredrikahl.se','Fredrik Åhl','Granbacken 6','Bromma','Stockholm','SWEDEN','16869','+ 46855119686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 18:01:31',0,NULL,3,1,3,1,'RA184586157CN ','fredrik.ahl\rWWOT001'),(13021,628136540013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','jimautoman0','jcole100@hotmail.com','jim cole','13130 Carriage Rd<br>Apt 3','poway','CA','UNITED STATES','92064','(858) 848-4204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 19:15:35',0,NULL,3,1,1,1,'、 ','jimautoman0'),(13022,858740114012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','cinemascope','peterhaas@cruzio.com','Peter Haas','234 Miramar Dr','Santa Cruz','CA','UNITED STATES','95060-5230','(831) 426-5482','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 19:21:30',0,NULL,3,1,1,1,'、 ','cinemascope'),(13023,858743834012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',24.99,'eastar4uk','shamalkirkuki','kurikirkuk@yahoo.co.uk','shamal hussein','65<br>bucknall new raod ','stoke on trent','Staffordshire','UNITED KINGDOM','st1 2ba','07833572870','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 19:29:49',0,NULL,3,1,3,1,'RA184589374CN ','shamalkirkuki\r英标\rHSNO019'),(13024,630082608013,230657622422,'Genuine DENON RC-970 Remote Control RC 970',1,'RCDE002',79.99,'eastar4','sleep_walker','bowman@alpenjodel.de','Andreas Möhrke','Mareschstr.8','Berlin','','GERMANY','12055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 19:37:39',0,NULL,3,1,3,1,'RA184589184CN ','sleep_walker\rRCDE002'),(13025,858750208012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','neil221177','neil_001@hotmail.co.uk','Neil Martin','5 south road<br>Horsell','woking','Surrey','UNITED KINGDOM','gu214ju','07773307567','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 19:50:19',0,NULL,5,0,18,1,NULL,'neil221177\rGLOT001*2\r兼容型3D眼镜 通用型\r已经退款  撤单'),(13026,858768928012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',193.99,'eastar4','dpee9110','wantitall.dp@gmail.com','Danarrah Peeples','7167 Grassy Trail','San Antonio','TX','UNITED STATES','78244','(210) 725-8094','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 20:11:32',0,NULL,3,1,6,1,'EE495359684CN ','dpee9110'),(13027,573674185003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','moto_good','werser@rambler.ru','Ilya Mikheev','Zelenodolskay dom 7  korpus 7 kv 11','Moscow','','RUSSIAN FEDERATION','109377','(916)956-1382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:16:19',0,NULL,3,1,3,1,'RA184589309CN ','moto_good\rOMHJ001'),(13028,774304719011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.9,'eastar4','trueffelnase','trueffelnase@googlemail.com','Mathias Kolb','Oberdorf 1','Dürrwangen','','GERMANY','91602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:21:24',0,NULL,3,1,2,1,'\\ ','trueffelnase\racer 4pin1.25 15cm '),(13029,579218528004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','maxman353','kapetanakisbasilis@hotmail.com','vasilis kapetanakis','apostolou pavlou 14, rodos, rodos<br>rodos','rodos','','GREECE','85100','030 22410 63169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:38:33',0,NULL,3,1,3,1,'RA184589312CN ','maxman353\rHSPL002'),(13030,858737970012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT004',53.98,'eastar4uk','14bowman7','bowman_7@hotmail.co.uk','alan bowman','13 wilsgait street<br>cleland','motherwell','North Lanarkshire','UNITED KINGDOM','ml1 5pe','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 20:46:28',0,NULL,3,1,3,1,'RA184586090CN ','14bowman7\rGLOT004\r兼容型3D眼镜  samsung 专用\r可以用'),(13031,630114285013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','dcbens','dcbens@web.de','Daniel Bens','Trianel GmbH, Lombardenstr. 28','Aachen','OPTIONAL','GERMANY','52070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 21:06:43',0,NULL,3,1,2,1,'\\ ','dcbens'),(13032,858808542012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','scott.bonnar','scott.b_94@hotmail.com','Scott Bonnar','28 kareela road<br>baulkham hills','Sydney','New South Wales','AUSTRALIA','2153','0296393958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 21:33:42',0,NULL,3,1,2,1,'\\ ','scott.bonnar'),(13033,630126610013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','eusebio.monreal','control2dance@gmail.com','eusebio jose monreal ortiz','c eras nº 60 1º c','alcantarilla','Murcia','SPAIN','30820','617312709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 21:47:40',0,NULL,3,1,2,1,'\\ ','eusebio.monreal'),(13034,715519487008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',71,'au-buy','dave.b600','daveb600@gmail.com','Dave Bower','Unit 7<br>58 Bluebell Street.','O\'Connor','Australian Capital Territory','AUSTRALIA','2602','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 21:48:05',0,NULL,3,1,3,1,'RA184586188CN ','dave.b600\rGLOT005\r白色的'),(13035,579248797004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','antoniowaker','pedromarrero@marrero-henning.com','Pedro Marrero','C/San Miguel 68A, 8º,','Palma de Mallorca','Baleares','SPAIN','07002','699476493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 22:32:33',0,NULL,3,1,3,1,'RA184589343CN ','antoniowaker\rHSPL015\r欧标'),(13036,855308042012,220501842033,'2.1 Acer Aspire 6920 6920G Bluetooth Module  EDR+cable',2,'BTAC2117',24.8,'eastar4','alexandrenonakabr','alexandrenonaka@gmail.com','Alexandre Nonaka dos Santos','rua luis lourenco simione, 252<br>jardim patricia','Uberlandia','Minas Gerais','BRAZIL','38414166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 22:43:10',0,NULL,3,1,2,1,'\\ ','alexandrenonakabr\racer 8pin0.8 16cm'),(13037,630145320013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.98,'eastar4','minhla703','kevinla703@gmail.com','Minh la','2820 SPRIG DR','MARRERO','LA','UNITED STATES','70072-5878','(703) 992-3053','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 23:14:49',0,NULL,3,1,1,1,'、 ','minhla703'),(13038,858845467012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','twinengine55','mshasha@tiscali.co.uk','Meir Shasha','39 Tudor Way<br>Hillingdon','Uxbridge','Middlesex','UNITED KINGDOM','UB10 9AA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 23:20:45',0,NULL,3,1,3,1,'RA184586015CN ','twinengine55\rWLAP002'),(13039,858873525012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',13.99,'eastar4','tamaddon123','jmtamaddon@yahoo.com','Jennifer  Tamaddon','5110 Lafitte Dr','Oak Park','CA','UNITED STATES','91377-4722','(818) 865-0398','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 01:13:15',0,NULL,3,1,1,1,'、 ','tamaddon123'),(13040,630174455013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','tdollar57','tdollar57@yahoo.com','Teresea Dollar','13329 Anchor Ln','Temple','TX','UNITED STATES','76502-6854','(512) 755-7775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 01:23:33',0,NULL,3,1,1,1,'、 ','tdollar57\r黑色的'),(13041,858887338012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','oli_oof','olislade@hotmail.com','Oliver Slade','55 Jacaranda Grove','Elrington','New South Wales','AUSTRALIA','2325','0249912452','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 01:43:20',0,NULL,3,1,2,1,'、 ','oli_oof'),(13042,858882800012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','loumattsdad','johnsonhouse1@optusnet.com.au','Terrence Johnson','21 Medway Road','Craigieburn','Victoria','AUSTRALIA','3064','0393082788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 01:27:24',0,NULL,5,0,18,1,' ','loumattsdad\rGLOT001*2\r兼容型3D眼镜 通用型\r已退款'),(13043,858892793012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','worlditem','johnnyfcastro@gmail.com','Johnny Castro','144 bergen ave','bergenfield','NJ','UNITED STATES','07621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 02:01:15',0,NULL,3,1,1,1,'、 ','worlditem'),(13044,573752821003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','emitch19','emitch19@aol.com','ERIC V MITCHEL','1106 DELAWARE DR','MANSFIELD','TX','UNITED STATES','76063-6364','(817) 690-1218','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 02:10:22',0,NULL,3,1,1,1,'、 ','emitch19'),(13045,573753674003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','n112kc','n112kc@aol.com','Russ Widman','149 Tiffany Ln','Willingboro','NJ','UNITED STATES','08046-3845','(609) 790-4326','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 02:16:08',0,NULL,3,1,1,1,'、 ','n112kc'),(13046,573756616003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','mssmims','mssmims@aol.com','Sheila Mims','7505 Wendell Dr','Jacksonville','FL','UNITED STATES','32210','(904) 226-9861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 02:30:51',0,NULL,3,1,1,1,'、 ','mssmims'),(13047,858914036012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','highmark_1049','highmark_800@hotmail.com','Jordan Heisler','Box 54','Mildred','SK','CANADA','S0J1V0','(306) 883-7953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 03:22:46',0,NULL,3,1,3,1,'RA184586086CN ','highmark_1049\rOTSO004*2'),(13048,733131525001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','canaweedpr','rjimenez3766@live.com','RAMON JIMENEZ','10611 ABERCORN ST<br>APT 55','SAVANNAH','GA','UNITED STATES','31419-1457','(912) 507-3078','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 04:41:56',0,NULL,3,1,1,1,'、 ','canaweedpr'),(13049,630214148013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','rachel3895','rjkitchener@bigpond.com','Rachel Kitchener','49 Eaton Circle, Greenwood Estate','Kirwan','Queensland','AUSTRALIA','4817','0747238554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 05:06:09',0,NULL,3,1,2,1,'\\ ','rachel3895'),(13050,774454122011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','codey1010','cjames893@gmail.com','Codey James','39 princess st','cannon hill','Queensland','AUSTRALIA','4170','0420978746','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 05:10:41',0,NULL,3,1,3,1,'RA184589241CN\r','codey1010\rGLOT001*3\r兼容型3D眼镜 通用型\r客户不回复  \r发吧'),(13051,573782846003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',2,'MOOE002',85.98,'cnfaner','arena2030','itasony@naver.com','kim hyoung un','226 veneto','Irvine','CA','UNITED STATES','92614-5950','949 533 5764','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 05:47:36',0,NULL,3,1,1,1,'、 ','arena2030\rOEM的'),(13052,774467997011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','supajason','jasonstuart85@gmail.com','Jason Stuart','Unit 8<br>88  Cleveland  St','Greenslopes','Queensland','AUSTRALIA','4120','0414197913','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 06:30:21',0,NULL,3,1,2,1,'\\ ','supajason'),(13053,858956557012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','michaelaburris','mburris505@gmail.com','micheal burris','1108 Vista grande','albuquerque','NM','UNITED STATES','87105','(505) 730-6926','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 06:45:50',0,NULL,5,0,18,1,'未发','michaelaburris\r兼容型3D眼镜 通用型\r客户回复了电视型号但不兼容\r已退款'),(13054,858484267012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',5,'REPL001',54.95,'eastar4','kneilson','kneilson@kneilson.com','Kevin Neilson','RR4 Station Main<br>50351 Range Road 225','Sherwood Park','AB','CANADA','T8A3K4','(780) 416-4296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 06:47:34',0,NULL,3,1,3,1,'RA184589405CN ','kneilson\rREPL001'),(13055,774474957011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','jotyler65','jotyler65@aol.com','John Tyler','1750 Grevelia St<br>Apt 8','South Pasadena','CA','UNITED STATES','91030-2758','(626) 799-1524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 07:05:07',0,NULL,3,1,1,1,'、 ','jotyler65'),(13056,774478582011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.99,'eastar4','mikomanus','mikoman@pobox.sk','Michal Bizik','Saratovska 19','Bratislava','','SLOVAK REPUBLIC','84102','+421905612142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 07:21:28',0,NULL,3,1,3,1,'RA184589167CN ','mikomanus\rRCLO007+POLO001+RCLO008*4'),(13057,573797721003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.9,'cnfaner','manjinitin','manjinitin@hotmail.com','Nitin Patel','U2/130 Forrester Rd','St Marys','New South Wales','AUSTRALIA','2760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 07:35:16',0,NULL,3,1,3,1,'RA184589290CN ','manjinitin\rHSJA006\r澳标'),(13058,858966227012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',29.37,'eastar4','vlad-boss','vbedenko@hotmail.com','Bedenko Vladimir','43 rue Anatole de Monzie<br>bat. 7, esc. 24, 5 etage, apt. 458','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06300','0699195950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 07:40:28',0,NULL,3,1,2,1,'\\ ','vlad-boss\r再发一个优联\r不是红边的  '),(13059,858970896012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','ewetwins','ewengrahamslaw@hotmail.com','Ewen Grahamslaw','2 Bisham Close, Maidenbower','Crawley','West Sussex','UNITED KINGDOM','RH107QP','01293884837','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-05 07:46:53',0,NULL,3,1,3,1,'RA184586069CN ','ewetwins\rOTCN003'),(13060,858977294012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',4,'WLIN001',87.96,'eastar4','buyondream','jihwan.is@gmail.com','Ji-Hwan Lee','RM4405, Mechanical Eng. Bldg, KAIST, 335 Kwahak-ro, Yuseong-gu','Daejeon','Daejeon','KOREA,REPUBLIC OF','305-701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 08:27:24',0,NULL,3,1,3,1,'RA184586126CN ','buyondream\rWLIN001'),(13061,774496966011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','sabanbaba','pinar_nurcan@hotmail.com','Mustafa girgin','inönü bulvari no:103','fethiye','mugla','TURKEY','48300','2526142039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 08:49:19',0,NULL,3,1,3,1,'RA184586038CN ','sabanbaba\rGLSG001'),(13062,630253322013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',79.9,'eastar4','touyakun','keisan@gmail.com','Michael Bui','AC3 Suite 7003, Bay 8<br>2 Locomotive St Australian Technology Park','Eveleigh','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 09:25:45',0,NULL,3,1,3,1,'RA184589136CN ','touyakun\rMOSA006'),(13063,859006966012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',6.8,'eastar4uk','alatus1982','jakob.mursak@triera.net','Jakob Murschak','Ulica heroja Lacka 81','Lenart v Slovenskih goricah','','SLOVENIA','2230','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 10:07:05',0,NULL,3,1,2,1,'\\ ','alatus1982'),(13064,630265238013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','frostythe2nd','sharonandfrosty@yahoo.com.au','michael frost','39 sladden rd yarrawarrah','sydney','New South Wales','AUSTRALIA','2233','0285216197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 10:32:13',0,NULL,3,1,3,1,'RA184586041CN ','frostythe2nd\rMOSA003'),(13065,774525670011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'eastar4','tsuibearbear','wongthings@gmail.com','Ricky Wong','3c Kwong Hing Bldg 543 Canton RD<br>Kowloon','default','','HONG KONG','default','92613867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 10:41:09',0,NULL,3,1,14,1,'301208196277\r ','tsuibearbear'),(13066,573830668003,130554587884,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',28.85,'cnfaner','boyden09','boyden@mail.ru','Denis Logvinov','Novikov 13-357','Severodonetsk','Luganskaya','UKRAINE','93414','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 10:57:52',0,NULL,3,1,3,1,'RA184589445CN ','boyden09\rOTCR001'),(13067,859023536012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','harris_f_sarris','h.sarris@gmail.com','CHARALAMPOS SARRIS','8, PHILIPPOU LITSA STR.<br>Motion Hellas Ltd.','HALANDRI','προεπιλογή','GREECE','15234','(30) 2106858455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 11:02:34',0,NULL,3,1,3,1,'RA184586143CN ','harris_f_sarris\rWWOT001'),(13068,852154334012,220855431129,'100% Original 2.4G Wireless Rii Mini PC Keyboard with Touchpad Laser Point!!',1,'KEOT001',31.49,'eastar4','greeksantojack','iakovoskarnavas@hotmail.com','Iakovos Karnavas','Agiras 12','Trikala','','GREECE','42100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 11:04:06',0,NULL,3,1,3,1,'RA184589272CN ','greeksantojack\rKEOT001'),(13069,573829688003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.9,'cnfaner','ercanskose01','ercanskose@gmail.com','ERCAN SARIKÖSE','MUHITTIN USTUNDAG CD. NO:23 KOSUYOLU<br>RESPITEK SAGLIK URUNLERI','ISTANBUL','KADIKOY','TURKEY','34718','5432230101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 11:09:17',0,NULL,3,1,3,1,'RA184589431CN ','ercanskose01\r欧标\rHSJA001'),(13070,630282725013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','punsakky','pwanagosit@yahoo.com','Pansak Wanagosit','15 Ford Ln','Berlin','NJ','UNITED STATES','08009-9475','(609) 352-2398','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-05 11:54:44',0,NULL,3,1,1,1,'、 ','punsakky'),(13071,774557969011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',3,'RELO002',38.94,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 12:31:52',0,NULL,3,1,3,1,'RA184589269CN ','masteroll2010\rRELO002'),(13072,630297293013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','vance3d','vance3d@telstra.com','Carl Vance','4 Fraser Drive','Greenmount','Western Australia','AUSTRALIA','6056','0892943768','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 13:09:00',0,NULL,3,1,2,1,'\\ ','vance3d\r红边优联'),(13073,573859733003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',63.98,'cnfaner','milosmilos','pyrat77@gmail.com','Milos Milos','1785 S Park Rd','Benton Harbor','MI','UNITED STATES','49022-9626','(505) 228-3158','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 13:33:21',0,NULL,3,1,1,1,'\\','milosmilos'),(13074,859078715012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','johnascherl','john@ascherlfs.com','John Ascherl','1618 S Riverside Dr','New Smyrna Beach','FL','UNITED STATES','32168-7756','(386) 689-5646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 13:46:30',0,NULL,3,1,1,1,'、 ','johnascherl'),(13075,859080506012,220711639863,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',18.99,'eastar4','cashattack','patt@caseyconstruction.net','Patt R. Karr','2090 Hendry St','Fort Myers','FL','UNITED STATES','33901','(239) 461-5333','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 13:51:48',0,NULL,3,1,1,1,'、 ','cashattack'),(13076,573871315003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',31.98,'cnfaner','pawankhehra','ranja_1210@yahoo.com','amandeep singh','10618 grand prairie dr','bakersfield','CA','UNITED STATES','93311-9139','(661) 303-4363','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 14:18:09',0,NULL,3,1,1,1,'、 ','pawankhehra'),(13077,573876382003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','bulgarb','bdickens5@yahoo.com','Brandon S Dickens','5485 Calle Vista Linda','Yorba Linda','CA','UNITED STATES','92887-2404','(714) 915-7678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 14:39:42',0,NULL,3,1,1,1,'\\','bulgarb'),(13078,774609119011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',2,'UDAP001',63.98,'eastar4uk','davimark2831','rockdriving@gibtelecom.net','Mark Galia','26 Plymouth Court<br>Harbour Views','Gibraltar','Gibraltar','GIBRALTAR','','00300 54729000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 15:05:12',0,NULL,3,1,3,1,'RA184565086CN ','davimark2831\rUDAP001'),(13079,859110144012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','tt-rn','tbarnello@hotmail.com','Tricia Barnello','102 West Way','Camillus','NY','UNITED STATES','13031-1215','(315) 218-5121','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'tt-rn'),(13080,630331083013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','wiwalthers','wiwalthers@wi.rr.com','Leslie Walther','W246N5826 Partridge Ct','Sussex','WI','UNITED STATES','53089-5035','(262) 246-5960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 15:17:35',0,NULL,5,0,18,0,' ','wiwalthers\r兼容型3D眼镜 通用型\r\r已经退款    撤单'),(13081,630336645013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','alpcrimea','alpcrimea@gmail.com','Alexey Pisarenko','Kievskaya str. 132 fl. 62','Simferopol','Crimea','UKRAINE','95043','+380505724290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 15:36:50',0,NULL,3,1,2,1,'\\ ','alpcrimea'),(13082,859123757012,220699045781,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',16.39,'eastar4','ftwsiegel','ftwsiegel@aol.com','Andrew Siegel - HH Prop Department','10202 Washington Blvd<br>Rooney Bldg. 2nd Floor','Culver City','CA','UNITED STATES','90232-3119','(818) 652-3970','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 15:44:37',0,NULL,3,1,1,1,'、 ','ftwsiegel'),(13083,859149014012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.74,'eastar4','cucuson','dchinaman@yahoo.com','Thien Tran','10214 Bayou Trail LN','Houston','TX','UNITED STATES','77064-5120','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 16:39:30',0,NULL,3,1,1,1,'、 ','cucuson'),(13084,774654718011,320701906241,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.5,'eastar4','matt_in-a-hat','final_fantasy3333@hotmail.com','matthew paniccia','1947 swan street','innisfil','ON','CANADA','L9S 0B3','(705) 294-1947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 16:59:20',0,NULL,3,1,2,1,'\\ ','matt_in-a-hat'),(13085,774656360011,320730548431,'NIB 3D Active Shutter TV Glasses with IR emitter',1,'GLOT002+GLOT003',48.99,'eastar4uk','7220wendy','lawton_w@sky.com','wendy lawton','277 stafford road','cannock','Staffordshire','UNITED KINGDOM','ws11 4at','01543467650','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-05 17:03:04',0,NULL,3,1,3,1,'RA184589459CN ','7220wendy\rGLOT002+GLOT003'),(13086,857811592012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','jon_wilner','jonwilner@hotmail.com','Jonathan Wilner','6421 130th St SE','Snohomish','WA','UNITED STATES','98296','(425) 879-2526','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 17:28:46',0,NULL,3,1,1,1,'、 ','jon_wilner'),(13087,859174594012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','navjot_sarowa','navjot_sarowa@yahoo.ca','Navjot Sarowa','392 Phipps Crescent','Kelowna','BC','CANADA','V1X7N9','(250) 215-9763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 17:40:37',0,NULL,3,1,3,1,'RA184589122CN ','OTSO004*2\r'),(13088,774681365011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',69.9,'eastar4','brin1983','rhauptmanns@arcor.de','Rene Hauptmanns','Brohltalstrasse 120a','Niederzissen','','GERMANY','56651','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 17:54:36',0,NULL,3,1,3,1,'RA184589153CN ','brin1983\rMOSA005'),(13089,573935718003,130553128709,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'cnfaner','presidario','ehynne@hotmail.com','Espen Hynne','Skomakerhaugen','Gjesaasen','Hedmark','NORWAY','2280','+4740013469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 18:08:27',0,NULL,3,1,3,1,'RA184586109CN','presidario\rHSPL010\r欧标'),(13090,774691156011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','alofrisco','anthjunk@lofrisco.com','Anthony LoFrisco, Jr','51 Marion Rd','Westport','CT','UNITED STATES','06880','(203) 226-7760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 18:13:13',0,NULL,3,1,1,1,'、 ','alofrisco'),(13091,774690014011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',31.99,'eastar4uk','luuj77','tj@email.dk','Tonni Juul','Bilstrupvej 37','Skive','','DENMARK','7800','+4521667576','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 18:14:30',0,NULL,3,1,3,1,'RA184586024CN ','luuj77\rGLSG001'),(13092,774698530011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','frank384404','fblcph@t-online.de','Frank Hagenlüke','Van-Oldeneel-Weg 7 A','Herzebrock-Clarholz','','GERMANY','33442','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 18:26:29',0,NULL,3,1,2,1,'\\ ','frank384404'),(13093,774705568011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','parkys76','masspark@gmail.com','YOUNG SOO PARK','2700 S Grand Ave<br># KM9229','Los Angeles','CA','UNITED STATES','90007-3301','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 18:57:04',0,NULL,3,1,1,1,'、 ','parkys76'),(13094,774730275011,320679575680,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',22.9,'eastar4uk','pahappo','pahappo@gmail.com','Paavo Happonen','Tampellan esplanadi 5 A60','tampere','','FINLAND','33100','0456721816','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 19:23:01',0,NULL,3,1,3,1,'RA184586072CN ','pahappo\rWWSI005'),(13095,859242576012,220844128244,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',26.98,'eastar4','s_mikke','svkluge@online.no','Svein Kluge','Bjørkeveien 30','Kirkenes','','NORWAY','9900','91768479','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 19:25:41',0,NULL,3,0,2,1,'\\ ','s_mikke\r再发一个Replacement LCD Touch Screen Glass Digitizer iPhone 3GS'),(13096,857632079012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','sandrine_hazan','hazanshuki@gmail.com','sandrine hazan','atoren 5 td 67','chave stion','','ISRAEL','22806','0528777745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 19:25:56',0,NULL,3,1,2,1,'\\ ','sandrine_hazan\r钢琴美女伞 '),(13097,859273853012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',50.94,'eastar4','hermodf','hermod@finjord.net','Hermod Finjord','Stakkevollvegen 98D','Tromsø','Troms','NORWAY','9010','+4790023580','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184589357CN ','hermodf\rCASS002+CASS003\rCAB-6060\r再发四条NEW CAB-2660 '),(13098,859321596012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','hoosa','cdegar01@yahoo.com','Christopher de Garay','250 Iven Ave<br>Apt 3C','St Davids','PA','UNITED STATES','19087-4924','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 21:57:28',0,NULL,3,1,1,1,'、 ','hoosa'),(13099,774804879011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',13.99,'eastar4','mc-guiver','hans-schmucker@mankei.de','Hans Schmucker','Flensburger Str. 18','München','','GERMANY','81929','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 22:06:56',0,NULL,3,1,2,1,'\\ ','mc-guiver'),(13100,859324981012,220826598356,'100% Brand New Original HP Wireless mobile 2.4G mouse ',1,'MOHP001',19.9,'eastar4','shime_0903','ivan.simic.shime@gmail.com','Ivan Šimić','Sjenjak 41','Osijek','','CROATIA','31000','031571922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 22:07:45',0,NULL,3,1,2,1,'\\ ','shime_0903'),(13101,859324977012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','cali-tech','thetran209@gmail.com','Meuy Saeteurn','8987 Terracorvo Cir','Stockton','CA','UNITED STATES','95212-3831','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 22:07:48',0,NULL,3,1,1,1,'、 ','cali-tech'),(13102,859332694012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','raul.mex','raul.mexico@gmail.com','RAUL CERDA','5201 Memorial Dr<br>Bayou On The Bend Unit 409','HOUSTON','TX','UNITED STATES','77007-8385','(832) 230-9225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 22:36:01',0,NULL,5,0,18,1,'未发','raul.mex\r兼容型3D眼镜 通用型\r已经退款  撤单'),(13103,859341982012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.4,'eastar4','tfmaia','t_fmaia@yahoo.com.br','Fábio Maia','Martim Afonso de Souza, 210','Santo André','Vila Pires','BRAZIL','09195-230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 22:57:42',0,NULL,3,1,2,1,'\\ ','tfmaia\rAcer 5pin1.25 3cm'),(13104,774825487011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',2,'MOCN001',7.96,'eastar4','jimari5','jimari@pacbell.net','Jim Johnson','1403 Carleton St<br>Apt F','Berkeley','CA','UNITED STATES','94702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 23:19:06',0,NULL,3,1,1,1,'、 ','jimari5'),(13105,774832808011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','felixmargadant','hixebay@margadant.ch','Dr. Felix Margadant','RCE in Mechanobiology T-Lab<br>5A, Engineering Drive 1','default','','SINGAPORE','117411','93215360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 23:47:30',0,NULL,3,1,11,1,'、 ','felixmargadant\rRELO002'),(13106,630494231013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','jessel9179','jesseluna1979@hotmail.com','jesse lu','239 pimpala rd<br>woodcroft','adelaide','South Australia','AUSTRALIA','5162','0883817489','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 23:54:39',0,NULL,3,1,3,1,'RA184586055CN ','jessel9179\rMOSA003'),(13107,579579991004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','nicotangara','nicorahardian@gmail.com','Nico Rahardian Tangara','2 Jalan Mutiara #10-02','default','','SINGAPORE','249183','83337945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 00:12:53',0,NULL,3,1,3,1,'RA184589391CN ','nicotangara\rWLDE002'),(13108,859366354012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',9.9,'eastar4','janet_rodriguez2010','janet_rodriguez84@yahoo.com','Janet Rodriguez','262 E Union St','Allentown','PA','UNITED STATES','18109-2750','(610) 351-3430','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 00:23:15',0,NULL,3,1,1,1,'、 ','janet_rodriguez2010\racer 8pin1.0 3cm '),(13109,774843391011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.99,'eastar4','aarzed','royzan@bigpond.net.au','Roy Zanetti','85 Auburn Street','WOLLONGONG','New South Wales','AUSTRALIA','2500','0417890098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 00:28:52',0,NULL,3,1,2,1,'\\ ','aarzed'),(13110,629216806013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.99,'eastar4','paul_baroni','paul_baroni@scotiacapital.com','Paul Baroni','9 Bethesda Crt','Toronto','ON','CANADA','M3B3S4','(416) 225-1640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 01:36:26',0,NULL,3,1,2,1,'\\ ','paul_baroni'),(13111,716008201008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',48.99,'au-buy','jlaye414','jlaye79@msn.com','Jason Laye','6711 Ardmore Dr SW<br>Apt 1','Lakewood','WA','UNITED STATES','98499-2185','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 01:53:51',0,NULL,3,1,1,1,'、 ','jlaye414'),(13112,775866813002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','musicconcertchick','slycunha@aol.com','Sylvia Cunha','157 Pleasant St','Lowell','MA','UNITED STATES','01852-3628','(978) 275-9521','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 02:35:55',0,NULL,3,1,1,1,'、 ','musicconcertchick'),(13113,574072555003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',31.98,'cnfaner','arts2010','aj0945@telus.net','Art Stevenson','6505 50A ave','Camrose','AB','CANADA','t4v3e7','(780) 608-9551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 03:45:15',0,NULL,3,1,3,1,'RA184589175CN ','arts2010\rHSMO019'),(13114,774891628011,320721404615,'Transparent Dome Rain Sun Umbrella with pink trim',1,'UMTR001',19.99,'eastar4','rosita0987','rrodrig474@student.glendale.edu','Rosa Rodriguez','1300 Waterloo St','Los Angeles','CA','UNITED STATES','90026-2340','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 03:54:40',0,NULL,3,0,1,1,'\\ ','rosita0987\r粉色的\r已入库'),(13115,716037563008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','bm3csl','andrewcoldham@hotmail.com','Andrew Coldham','20 Verdichio Avenue','Mermaid Waters','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 04:14:57',0,NULL,3,1,3,1,'RA184567612CN\r','bm3csl\rHSPL010'),(13116,574076259003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.8,'cnfaner','gr8fulace','hasty1@hastyelectric.com','Dennis Hasty','2622 Groveton St','Alexandria','VA','UNITED STATES','22306-1730','(703) 839-5721','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-06 04:16:01',0,NULL,3,1,1,1,'\\ ','gr8fulace'),(13117,859441493012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','plaidhatter','ebay@plaidcentral.com','Dan S. Perry','473 E 8th Ave','New Westminster','BC','CANADA','V3L 4L3','(604) 357-3730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 05:25:56',0,NULL,3,1,3,1,'RA184589207CN ','plaidhatter\rUM00009+UM00008\r再发一把黑底七色边彩虹伞 '),(13118,630555499013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','plaidhatter','ebay@plaidcentral.com','Dan S. Perry','473 E 8th Ave','New Westminster','BC','CANADA','V3L 4L3','(604) 357-3730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 05:27:41',0,NULL,8,1,17,0,NULL,'plaidhatter'),(13119,859447608012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',138,'eastar4','hooper1timothy','timmy_boone@yahoo.com','Timothy Boone','15230 Oak Terrace Dr','Houston','TX','UNITED STATES','77082-4027','(281) 556-5839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 05:58:21',0,NULL,3,1,1,1,'\\ ','hooper1timothy'),(13120,774913793011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','tamas.patai','tamas.patai@freemail.hu','Tamas Patai','FELINA<br>Kinizsi 2/1','Szeghalom','','HUNGARY','5520','+36309634390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 05:49:57',0,NULL,3,1,2,1,'\\ ','tamas.patai'),(13121,859455972012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','timpo-tech','driehlax@hotmail.com','Tim Porter','365 goslin st','sawyers valley','Western Australia','AUSTRALIA','6074','0892952463','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 06:38:34',0,NULL,3,1,3,1,'RA184586112CN ','timpo-tech\rMOMI001\r澳标'),(13122,574093498003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','rasul1971','amanov_rasul@rambler.ru','Rasul Amanov','Bolshaya Cheremushkinskaya<br>3 k1 kv16','Moscow','','RUSSIAN FEDERATION','117447','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 06:39:13',0,NULL,3,1,3,1,'RA184589119CN ','rasul1971\rOEM的\rMOOE002'),(13123,859461274012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','snipez999','snipez999-ebay@yahoo.co.uk','Robin Vidler','3 Fulmards Close<br>Wilmslow Park','Wilmslow','Cheshire','UNITED KINGDOM','SK92EB','07855109876','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 07:02:09',0,NULL,3,1,3,1,'RA184589198CN ','snipez999\r英标\rMOMI001'),(13124,8881317888165847,111,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',0,'eastar4uk','itzik88','itzik@r-tco.com','itzik kedem','nof sadot 303','olesh','asharon','ISRAEL','42855','972-52-8742502',NULL,NULL,NULL,'2011-10-06 08:02:45',0,NULL,3,1,2,1,'\\ ','补发的 \r只补发耳机\r发之前测试一下是否能工作\r已发货，由于系统改不了'),(13125,774957058011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',29.99,'eastar4','ian7770_2','i.white8@sky.com','ian white','22 leahall lane','rugeley','staffs','UNITED KINGDOM','ws151hx','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 09:15:24',0,NULL,3,1,2,1,'\\ ','ian7770_2\r英标'),(13126,859503689012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','vasspiou','vaspiou@gmail.com','VASSILIS BERTOS','STEFANOU KOUMANOUDI 27','ATHENS','ATHENS','GREECE','11474','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 09:56:13',0,NULL,3,1,2,1,'\\ ','vasspiou\rCAB-6060'),(13127,630597426013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',2.98,'eastar4','pc-mastor','zabounis@hotmail.com','Theodore Kalogiannis','4 Andrea Papandreou STR','Athens','Melissia','GREECE','15127','00302116875007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 09:59:52',0,NULL,3,1,2,1,'\\ ','pc-mastor'),(13128,630602826013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',50.94,'eastar4','phobes2000','webmaster@phobes.de','Richard Friedrich','Tölzerstr.46a','Taufkirchen','','GERMANY','82024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 10:36:44',0,NULL,3,1,3,1,'RA184586381CN\r ','phobes2000\rCASS003\rCAB-6060\r'),(13129,774981496011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','5373joseph','greenhatch1@bigpond.com','Joseph Greenhatch','24 Tranquility Drive','Rothwell','Queensland','AUSTRALIA','4022','0428732200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 10:54:51',0,NULL,3,1,2,1,'\\ ','5373joseph'),(13130,859523483012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','crysanddave','cboot@optusnet.com.au','David Boothby','10 Oswin St','Crib Point','Victoria','AUSTRALIA','3919','0359839156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:02:26',0,NULL,3,1,2,1,'\\ ','crysanddave'),(13131,630610162013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','sh00reg','shooreg@gmail.com','Alexander Golenshin','Pushkin<br>Shishkova 14 - 112','Saint Petersburg','Saint Petersburg','RUSSIAN FEDERATION','196605','+7 921 981-9871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:09:36',0,NULL,3,1,2,1,'\\ ','sh00reg\r欧标'),(13132,858407871012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',77.99,'eastar4','mustang19_123','jasonlane_16@yahoo.com','Jason Lane','3980 Morrice rd','Webberville','MI','UNITED STATES','48892-9749','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 11:16:27',0,NULL,3,1,1,1,'\\ ','mustang19_123'),(13133,774996843011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.98,'eastar4','top-queues','info@netsektor.de','Dragisa Grujovic','Ridlerstr. 29b','München','','GERMANY','80339','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:44:54',0,NULL,3,1,3,1,'RA184586452CN\r ','top-queues\rWWSI002+ANCN001'),(13134,774997024011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.4,'eastar4','stalindim','d.bozec@gmail.com','David BOZEC','26 place du commerce','PLOUZANE','Bretagne','FRANCE','29280','0650184121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:45:46',0,NULL,3,1,2,1,'\\ ','stalindim'),(13135,775007019011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.65,'eastar4','freewall_czech','freewall2@gmail.com','Jiri Egermaier - KODE servis','Sykorice','Sykorice 243','Czech republic','CZECH REPUBLIC','270 24','00420605158635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 12:18:43',0,NULL,3,1,2,1,'\\ ','freewall_czech'),(13136,775013189011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','wings_m84','wings_m84@hotmail.com','Daniel Cheong Chee Weng','BLK 230H TAMPINES ST21 #02-681','default','','SINGAPORE','522230','94574113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 12:39:46',0,NULL,3,1,11,1,'RA184586378CN\r ','wings_m84\rHSUE004'),(13137,775017123011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','xpolgr','xpolgr@hotmail.com','Polivios Xanthakis','Nikou Xilouri 17','Heraklion','Crete','GREECE','71307','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 12:52:29',0,NULL,3,1,2,1,'\\ ','xpolgr'),(13138,775022846011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','charliezena7','bill07adamski@gmail.com','William Adamski','273 Quaker Meeting House Rd','Catawissa','PA','UNITED STATES','17820','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 13:09:45',0,NULL,3,1,1,1,'\\ ','charliezena7'),(13139,630642431013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','kevyoung312010','kevyoung31@yahoo.com','Kevin Young','122 Rogers Ln','Des Allemands','LA','UNITED STATES','70030-4337','(985) 306-0073','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 13:38:02',0,NULL,3,1,1,1,'\\ ','kevyoung312010'),(13140,859581464012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','nicholas.mossad02','nicholas.mossad@msn.com','Nicholas Mossad','2a kalora cresent<br>Charlestown','Newcastle','New South Wales','AUSTRALIA','2290','0249421630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 13:57:36',0,NULL,3,1,2,1,'\\ ','nicholas.mossad02'),(13141,574174202003,130554587745,'New DELL BCM4321 300Mbp WiFi Mini PCI-E Card+ANTENNA*2',1,'WLDE001+ANTY001',16.9,'cnfaner','vladsen_k','svk@apollo.lv','Vladislav Senkans','Ozolciema 56/6-71','Riga','Riga','LATVIA','LV-1058','+37129208051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 14:15:18',0,NULL,3,1,3,1,'RA184586395CN\r ','vladsen_k\rWLDE001+ANTY001'),(13142,574068928003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',3,'HSNO005+CCNO001',44.97,'cnfaner','donatebloodtoday','mcarfano@tampabay.rr.com','mark carfano','2654 Midland Ct','PALM HARBOR','FL','UNITED STATES','34684-4531','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-06 14:17:38',0,NULL,3,1,1,1,'\\ ','donatebloodtoday'),(13143,859596098012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',16.95,'eastar4','newcomws','crodriguez@newcom.ws','NewCom','12515 Orange Dr<br>Ste 802','Davie','FL','UNITED STATES','33330-4309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 14:38:36',0,NULL,3,1,1,1,'\\ ','newcomws'),(13144,579729534004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','dwight3380','d_collins80@yahoo.com','Dwight Collins Jr','519 American Blvd','Warner Robins','GA','UNITED STATES','31093-2345','(478) 918-0652','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-06 14:54:50',0,NULL,3,1,1,1,'\\ ','dwight3380'),(13145,775066281011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.99,'eastar4','violamalshy','viola.m24_2@hotmail.com','Violet Malshy','Lohame Hagetaot 49','Haifa','Haifa','ISRAEL','35664','0777512015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 15:20:04',0,NULL,3,1,3,1,'RA184586355CN\r ','violamalshy\rOTGR001+OTGR002+OTGR003'),(13146,630677873013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','khan_sam','gali82@hotmail.com','SHAHID KHAN','AKACIASTIGEN 4 APT/LGH# 24<br>54242 MARIESTAD','MARIESTAD','SKARABORG','SWEDEN','54242','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 16:00:14',0,NULL,3,1,3,1,'RA184586364CN\r ','khan_sam\rHSNO019\r欧标'),(13147,859642317012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','good4u_good4me','cmdematos@gmail.com','Martie Matos','16 Landstone Ct','Greer','SC','UNITED STATES','29650-3687','(864) 335-9031','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 16:31:54',0,NULL,3,1,1,1,'\\ ','good4u_good4me'),(13148,733740513001,110728899326,'NIB Samsung SSG-3100GB 3D Active Glasses for PC monitor',1,'GLSG007',79.99,'buysia','6418jonathan','jonny4.g@googlemail.com','Jonathan Gentles','9 Parkgate<br>Windsor Lane','Burnham','Berkshire','UNITED KINGDOM','SL1 7HP','07850375363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 16:33:49',0,NULL,3,1,3,1,'RA184586537CN\r\r ','6418jonathan\rGLSG007'),(13149,630690994013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.59,'eastar4','helenader','prirodae@hotmail.com','Derbandiker Helena','POBox 31208','Jerusalem','','ISRAEL','91311','(972) 258-5508 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 16:38:54',0,NULL,3,1,3,1,'RA184586421CN\r ','helenader\rMOLO008'),(13150,630691721013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','syd_03','jason_scala@hotmail.com','Jason Scala','40/192 Vimiera Road','Marsfield','New South Wales','AUSTRALIA','2122','61402357622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 16:46:54',0,NULL,3,1,2,1,'\\ ','syd_03'),(13151,574219553003,130553375553,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',10.99,'cnfaner','kit0007','ntmsajith@gmail.com','sajith NTM','169,Haja Road, sainthamaruthu-10','sainthamaruthu','Kalmunai','SRI LANKA','0094','+94777596056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 17:13:31',0,NULL,3,1,3,1,'RA184586449CN\r ','kit0007\rHSNO030'),(13152,859681583012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','safenath82','nathan.walsh82@gmail.com','Nathan Walsh','6 Saxby Road','Billingham','Cleveland','UNITED KINGDOM','TS20 2TH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 17:51:02',0,NULL,3,1,2,1,'\\ ','safenath82'),(13153,859689302012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',10.99,'eastar4uk','chrismb1986','lagerlover@hotmail.com','Christopher Blower','16 Charnwood Rd <br>Whitchurch','Bristol','Bristol','UNITED KINGDOM','BS14 0JR','01275541317','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 18:05:55',0,NULL,3,1,3,1,'RA184586245CN\r ','chrismb1986\rMOMI002'),(13154,574247998003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','fiesty3594','fiestyforever@yahoo.com','Erica Williams','PO Box 1360<br>55 Flynt Street','Metter','GA','UNITED STATES','30439-4563','(912) 687-3661','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'fiesty3594'),(13155,775149289011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','cwrea','chris@dynasphere.ca','Chris W. Rea','2266 Yorktown Circle','Mississauga','ON','CANADA','L5M 5Y1','(905) 814-8785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 18:48:12',0,NULL,3,1,2,1,'\\ ','cwrea'),(13156,630739892013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','zdenekzelva','zdenek@comcast.net','Zdenek Zverina','8500 Commons Dr<br>Apt 9','Hickory Hills','IL','UNITED STATES','60457-7823','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 18:54:29',0,NULL,3,1,1,1,'\\ ','zdenekzelva'),(13157,859749375012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.99,'eastar4uk','gerbilistic','kevin.dickson@btinternet.com','Kevin Dickson','20 Firshill close Thornton,Cleveleys','Cleveleys','Lancashire','UNITED KINGDOM','FY5 5HA','01253850933','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 19:46:30',0,NULL,3,1,3,1,'RA184586293CN\r ','gerbilistic\rOTHP004'),(13158,859754730012,220619422274,'Apple Airport Wireless WiFi Card iMac iBook eMac+adapte',1,'WLAP001+WLAP004',11.99,'eastar4','macdive89','macdive@cegetel.net','Yves Comet','19 rue des Coteaux','Saumur','Pays de la Loire','FRANCE','49400','0954948949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 19:57:05',0,NULL,3,1,2,1,'\\ ','macdive89'),(13159,775220106011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.5,'eastar4','cgus7431','cgusman@lexcominc.net','Carl Gusman','301 Pope St','Lexington','NC','UNITED STATES','27292-2859','(336) 238-6158','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 20:41:59',0,NULL,3,1,1,1,'\\ ','cgus7431\r微软的'),(13160,859780609012,220844128244,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',17.99,'eastar4','marlonmla','mla@marlon.dk','Martin Ladegaard','Lervejdal 10','Brædstrup','standard','DENMARK','8740','0045 40784302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 20:43:53',0,NULL,3,0,2,1,'\\ ','marlonmla'),(13161,775224013011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.99,'eastar4','fastasp2dqq','fastasp@aol.com','Hayes Hutchins','13541 Sharpes Lake Rd','Northport','AL','UNITED STATES','35473','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 20:56:00',0,NULL,3,1,1,1,'\\ ','fastasp2dqq'),(13162,859783833012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',13.19,'eastar4','16texas16','yavuz-akbaba@web.de','YavuzSelim Akbaba','Gerberstraße 15','duisburg','','GERMANY','47249','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 20:56:53',0,NULL,3,1,2,1,'\\ ','16texas16\r欧标'),(13163,630806002013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','timmka79','timmka@mail.ru','Timur Chaban','Auv-Dag 11','Simferopol','Crimea','UKRAINE','95044','+380506373693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 22:08:43',0,NULL,3,1,2,1,'\\ ','timmka79'),(13164,859819808012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','loth_10','cesar.a.chavez@gmail.com','Cesar Chavez','2220 Bassett Ave<br>Ste 50-1936','El Paso','TX','UNITED STATES','79901-2020','(432) 362-2323','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 22:21:06',0,NULL,3,1,1,1,'\\ ','loth_10'),(13165,775265414011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','leihc','cheil97@yahoo.com','charles heil','204 Kramer Way','pittsburgh','PA','UNITED STATES','15211-2006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 22:49:04',0,NULL,3,1,1,1,'\\ ','leihc'),(13166,859834250012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','kaban978','osorokin978@gmail.com','Oleg Sorokin','5272 Pandora Str','Burnaby','BC','CANADA','V5B 1L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 23:03:13',0,NULL,3,1,3,1,'RA184586466CN\r ','kaban978\rOTIN005'),(13167,775301287011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','alexbyko','alexbyko88@gmail.com','Alexander Bykovec','90 - 94 Cranbourne Rd','Frankston','Victoria','AUSTRALIA','3199','0387900141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 01:04:09',0,NULL,3,1,2,1,'\\ ','alexbyko'),(13168,733949422001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','nickdurig','nickdurig@yahoo.com','Nicholas Durig','1230 Jackson Park Pl<br>Apt E','Seymour','IN','UNITED STATES','47274','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 02:12:26',0,NULL,3,1,1,1,'\\ ','nickdurig'),(13169,733950484001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','alexandre5422','xxando@uol.com.br','Alexandre Maluf F.','R. Sampaio Vidal 372','São Paulo','São Paulo','BRAZIL','01443000','0055.11.30327711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 02:18:38',0,NULL,3,1,3,1,'RA184586276CN\r ','alexandre5422\rBR3D008'),(13170,630860464013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','skygok','gokhan_orak@yahoo.co.uk','Gokhan Orak','Yeni Levent Postanesi<br>Posta Kutusu 23','Istanbul','Besiktas','TURKEY','34330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 02:24:00',0,NULL,3,1,2,1,'\\ ','skygok'),(13171,775326495011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','clubedasmoedas','sales@coinsclub.net','Adosinda Maria Cerqueira Andrade','Rua do Sol, 221','Lourosa','Lourosa','PORTUGAL','4535-076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 02:42:45',0,NULL,3,1,2,1,'\\ ','clubedasmoedas'),(13172,859905789012,220806892229,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','circatrish','willjphoto@gmail.com','Will Jivcoff','84 Simeon Street','Kitchener','ON','CANADA','N2H 1S5','(519) 743-5388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 03:17:20',0,NULL,3,1,2,1,'\\','circatrish\r向日葵长柄伞  \r\r由于缺货 客户同意改发向日葵三折叠伞 UM00004 \r\r并需要退差价\r'),(13173,859917248012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','hinder8love','hinder8love@yahoo.com','Abdul Sajid','339 Flanders Rd<br>Apt 205','East Lyme','CT','UNITED STATES','06333-1732','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 04:11:03',0,NULL,3,1,1,1,'\\ ','hinder8love'),(13174,775350846011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','justin.koonin','jkoonin@iinet.net.au','Justin Koonin','Unit 5, 43-57 Mallett St','Camperdown','New South Wales','AUSTRALIA','2050','0290297922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 04:42:31',0,NULL,3,1,2,1,'\\ ','justin.koonin'),(13175,775352462011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','hi20961','sala0167@metnet.edu','Kayla Salazar','5214 Greatview Ave','Brooklyn Center','MN','UNITED STATES','55429-3346','(763) 438-2575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 04:58:20',0,NULL,3,1,1,1,'\\ ','hi20961'),(13176,716466618008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','ltpone79','ltpone@hotmail.com','Stephen Thomas','873 Fifteenth Street','Mildura','Victoria','AUSTRALIA','3500','0350211480','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 05:04:33',0,NULL,3,1,3,1,'RA184567705CN\r','ltpone79\r澳标\rHSPL010'),(13177,859932546012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4','bushido_aus','bruceisnot@gmail.com','Bruce Bentley','2A Neriba Cresent','Whalan','New South Wales','AUSTRALIA','2770','0406907637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 05:29:54',0,NULL,3,1,2,1,'、 ','bushido_aus'),(13178,716472606008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','shalders*2009','laurenshalders@hotmail.com','Lauren Shalders','6 Gill Place<br>Mooroolbark','Melbourne','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 05:38:56',0,NULL,3,1,3,1,'RA184586262CN\r ','shalders*2009\rHSPL005\r澳标'),(13179,859940497012,220448658655,'Acer Travelmate 4720 4320 Bluetooth Module 2.0 cable',1,'BTAC2004',9.9,'eastar4','mgreer53','mgreer3g@msn.com','MICHAEL L GREER','8012 Vista Tijeras ln sw','Albuquerque','NM','UNITED STATES','87121','(505) 228-7961','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 06:09:30',0,NULL,3,1,1,1,'\\ ','mgreer53\racer 4pin1.25 6cm'),(13180,630899247013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','fors2008','fors99@inbox.lv','Dmitry Gribkov','Slokas 29/12','Jurmala','','LATVIA','2015','26124026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 06:45:23',0,NULL,3,1,2,1,'\\ ','fors2008'),(13181,859952626012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',2,'HSPL011',27.7,'eastar4uk','jason2007','bigwelshtrucker@yahoo.co.uk','Ms Nikki Hunt','9 Ascot Court<br>White Horse Business Park','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 0XA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 07:06:25',0,NULL,3,1,3,1,'RA184586231CN\r ','jason2007\rHSPL011\r英标'),(13182,774937756011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','otezelsin','tezel.orcun@gmail.com','Tezel Orcun','33A West Coast Park<br>#02-41','Singapore','','SINGAPORE','127727','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 07:19:03',0,NULL,3,1,3,1,'RA184586608CN\r ','otezelsin\rGLSG001'),(13183,574410122003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','disciplerf','rf19@bk.ru','Bobeika Alexandr','Malinovskogo, 3A, kv 168','Kiev','','UKRAINE','04212','+380937867880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 08:09:56',0,NULL,3,1,3,1,'RA184586228CN\r ','disciplerf\rHSPL009\r欧标'),(13184,716504203008,180699060430,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',44.99,'au-buy','xthadx78','xthadx@gmail.com','Thad Franklin','5057 Glen Lily Rd','Bowling Green','KY','UNITED STATES','42101-9405','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 08:24:21',0,NULL,3,1,1,1,'\\ ','xthadx78\r兼容型3D眼镜  samsung 专用\r\r客户没回复   发吧'),(13185,775396522011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.29,'eastar4uk','neilratty','neil@prdsoftware.co.uk','BeeBlu','5 Kingstone Hall Barns<br>Church Lane','Kingstone, Uttoxetter','Staffordshire','UNITED KINGDOM','ST148QJ','01889500297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 08:35:16',0,NULL,3,1,3,1,'RA184586165CN\r ','neilratty\rCACN004'),(13186,859977235012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','dave.r.carson','dave.carson@telus.net','Dave Carson','4818 Soucie Ave.','Terrace','BC','CANADA','V8G4R8','(250) 635-4404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 08:48:05',0,NULL,3,1,2,1,'\\ ','dave.r.carson'),(13187,775400575011,320679568138,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',13.9,'eastar4uk','lucinenecka','jirkaalucka@volny.cz','Boleslav Molin','Kubinova 1198','Pribor','Novy Jicin','CZECH REPUBLIC','74258','07580812508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 08:50:37',0,NULL,3,1,2,1,'\\ ','lucinenecka'),(13188,774990492011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','ichaus','thomas.woischnig@ichaus.de','Thomas Helmdach','Am Kuemmerling 18','Bodenheim','','GERMANY','55294','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 09:08:52',0,NULL,3,1,3,1,'RA184586470CN\r ','ichaus\rTRTS001*10'),(13189,859987539012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','georgetsg','georgeallan259@hotmail.com','george allan','9 burns close','south wonston','Hampshire','UNITED KINGDOM','so21 3hg','01962886919','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 09:26:41',0,NULL,3,1,3,1,'RA184586302CN\r ','georgetsg\rHBPH003'),(13190,8881317979602640,111,'3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005',0,'eastar4uk','kai1000baby','dennyo1@fsmail.net','denny oloughlin','1 railway square','brentwood','Essex','UNITED KINGDOM','cm14 4ln','07515436950',NULL,NULL,NULL,'2011-10-07 09:26:42',0,NULL,3,1,3,1,'RA184586554CN\r ','GLOT005\r补发一副 \r已发货，由于改不了系统'),(13191,859996386012,220814220259,'NIB Sony TDG-BR50/L Youth Size 3D Active Glasses  Blue',1,'OTSO005',59.99,'eastar4','kassydemma','markdemarchi@hotmail.com','Mark DeMarchi','P/O Box 298','Tindal RAAF','Northern Territory','AUSTRALIA','0853','0889717343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 10:04:29',0,NULL,3,1,3,1,'RA184586599CN\r ','kassydemma\rOTSO005'),(13192,775422317011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','fatihozcan06','fatihzcan06@gmail.com','fatih özcan','selçuk university<br>ileri teknoloji araştırma geliştirme merkezi (yadam yanı) no:G09','konya','','TURKEY','42079','+905326156679','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 10:18:20',0,NULL,3,1,2,1,'\\ ','fatihozcan06'),(13193,579976930004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',2,'OTGR001',39.8,'cnfaner','craig2410','c-mwurtz@iimetro.com.au','Craig Wurtz','PO BOX 1308','CANBERRA','Australian Capital Territory','AUSTRALIA','2601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 10:18:58',0,NULL,3,1,3,1,'RA184586259CN\r ','craig2410\rOTGR001'),(13194,630037803013,230416889272,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',2,'ANCN001',5.96,'eastar4','grizmakus','grizmak@gmail.com','Piotr Hawrylik','Kartonowa 34','Warszawa','mazowieckie','POLAND','04-781','503 195654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 10:37:52',0,NULL,3,1,2,1,'\\ ','grizmakus'),(13195,574436284003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.9,'cnfaner','btinova10467-1','btinova10467@gmail.com','Elena Batinova','850 E 17th St<br>Apt 1C','Brooklyn','NY','UNITED STATES','11230-3118','(718) 798-8057','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-07 10:45:46',0,NULL,3,1,1,1,'\\ ','btinova10467-1'),(13196,860009942012,220759427766,'New SAMSUNG WMN1000C ULTRA SLIM WALLMOUNT LED TV  60-65',1,'MOSA003',39.99,'eastar4uk','trckme1','trckme@yahoo.com.au','george cunha','33 denison rd','lewisham','New South Wales','AUSTRALIA','2049','0408350429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 10:50:32',0,NULL,3,1,3,1,'RA184586497CN\r ','trckme1\rMOSA003'),(13197,775445717011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','remix-shoes','emirzunic@hotmail.com','emir zunic','crkvice48','zenica','','BOSNIA AND HERZEGOVINA','72000','0038761974449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 11:42:11',0,NULL,3,1,2,1,'\\ ','remix-shoes'),(13198,860033625012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',2,'BALO007',21.9,'eastar4uk','danlii','danlii@frozenbanana.net','Daniel Liikamaa','Jagaregatan 140','Lund','','SWEDEN','S-22653','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 12:03:46',0,NULL,3,1,3,1,'RA184586404CN\r ','danlii\rBALO007'),(13199,775452902011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','lambostyler69','jara.ormoz@siol.net','Boris ZADRAVEC','Javna razvojna agencija Ormož<br>Vrazova ulica 9','Ormož','','SLOVENIA','2270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 12:07:53',0,NULL,3,1,2,1,'\\ ','lambostyler69'),(13200,630957594013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','fabio_vw','fabiodelamarta@gmail.com','Fabio Dela Marta','Rua Amelia Zanini Bombonatti, 402<br>Centro','Barrinha','Sao Paulo','BRAZIL','14860000','(551) 691-7644 ext.: 03','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 12:14:53',0,NULL,3,1,3,1,'RA184586523CN\r ','fabio_vw\rMOSA005'),(13201,775464034011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','flourpowerpunk','slj.spurs@talk21.com','Simon James','Kenilworth<br>15 Marine Road','Barmouth','Gwynedd','UNITED KINGDOM','LL42 1NW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 12:42:09',0,NULL,3,1,3,1,'RA184586483CN\r ','flourpowerpunk\rOTHP005'),(13202,630967779013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','chicagoskis','srs@ellijay.com','Sharon R. Stevens','133 Jump St','Talking Rock','GA','UNITED STATES','30175-1656','(706) 636-4377','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 12:59:52',0,NULL,3,1,1,1,'\\ ','chicagoskis'),(13203,775475290011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','ammarkzaman','asdiqa@gmail.com','Ammar Kamarulzaman','5622, Lorong DB 4, Jln Cempaka Biru<br>Kg Dato Abu Bakar Baginda','Kajang','Selangor','MALAYSIA','43000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 13:16:23',0,NULL,3,1,2,1,'\\ ','ammarkzaman'),(13204,580011776004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'cnfaner','mkck77','mkcgroupmatt@yahoo.com','WinnResidential Attn: Charles Riddle','942 Main St<br>Ste 301','hartford','CT','UNITED STATES','06103-1223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-07 13:17:04',0,NULL,3,1,1,1,'\\ ','mkck77\r红边优联'),(13205,579727145004,140583323292,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',46.9,'cnfaner','andreidenisov','luter1982@yahoo.com','Andrey Denisov','Frunze 22-16','Buzuluk','Orenburgskaya oblast','RUSSIAN FEDERATION','461040','+79225341504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 13:21:35',0,NULL,3,1,3,1,'RA184586418CN\r ','andreidenisov\rWWSI004+ANCN001'),(13206,856986023012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',62.99,'eastar4uk','07932frosty2008','luciano777@live.co.uk','crescenzo feliciello','228 osmondthorpe lane','leeds','West Yorkshire','UNITED KINGDOM','ls90jw','07932305602','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 13:43:45',0,NULL,3,1,3,1,'RA184586510CN\r ','07932frosty2008\rGLOT005*2'),(13207,574481622003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',14.99,'cnfaner','juan_garrido','juan_enrique_21@hotmail.com','juan garrido','psje nicolas guzman bustamante 4220','la serena','cuarta región','CHILE','56','92907941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 14:20:11',0,NULL,3,1,3,1,'RA184586333CN\r ','juan_garrido\rHSNO005+CCNO001'),(13208,631004389013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','vgershenzon','vgershenzon@yahoo.com','PricewaterhouseCoopers LLP, attn: Vladislav Gershenzon','Desk # 27330.7<br>300 Madison Avenue','New York','NY','UNITED STATES','10017-6232','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 15:18:52',0,NULL,3,1,1,1,'\\ ','vgershenzon'),(13209,631011429013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','judi4037','lentsj@gmail.com','Judith Lents','2957 Oceans Trce','Daytona Beach Shores','FL','UNITED STATES','32118-5937','(386) 761-6948','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-07 15:43:47',0,NULL,3,1,1,1,'\\ ','judi4037'),(13210,860119414012,220745030903,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',1,'OTIN001',27.99,'eastar4','alsteve95','alsteve@yandex.ru','Alexandr Sudarikov','L. Tolstogo, 45, 36','Stavropol','Stavropolskiy Region','RUSSIAN FEDERATION','355041','962-448-0546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 15:50:59',0,NULL,3,1,2,1,'\\ ','alsteve95'),(13211,860133734012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','liedownbrian','liedownbrian@yahoo.com','brian wilson','1369 US Hwy 12','chehalis','WA','UNITED STATES','98532','(360) 304-1734','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 16:20:19',0,NULL,3,1,1,1,'\\ ','liedownbrian\racer 6pin1.25 23cm'),(13212,775551719011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','sergeylanz10','sergeylanz@gmail.com','sergey lanzman','avraah bashari 2','rehovot','merkaz','ISRAEL','76531','972-546214290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 16:39:10',0,NULL,3,1,2,1,'\\ ','sergeylanz10'),(13213,574514877003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','zuoyeheye','zuoyehe@nifty.com','kazuya sano','2-10-11<br>sena chuoh','shizuoka city','Shizuoka','JAPAN','420-0916','(054)261-2832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 16:40:29',0,NULL,3,1,3,1,'RA184586316CN\r ','zuoyeheye\rHSPL009'),(13214,775555488011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',18.65,'eastar4uk','bodor0276','bodor02.76@freemail.hu','Attila Bódor','Fehérvári út 153/b','Gy&#337;r','','HUNGARY','9028','+36205564096','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 16:49:17',0,NULL,3,1,2,1,'\\','bodor0276\r欧标'),(13215,574524509003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.63,'cnfaner','madbutcher76','cornelius@ukrpost.net','Kornel Kontros','Yarockaya str. 7','Uzhgorod','Transcarpathia','UKRAINE','88000','+380502254186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 17:07:32',0,NULL,3,1,3,1,'RA184586320CN\r ','madbutcher76\rBALO007'),(13216,860155732012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','g6018','bertoenjanine@hetnet.nl','Berto Berkhof','westeinde 303','Vriezenveen','','NETHERLANDS','7671es','0031651865760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 17:08:07',0,NULL,3,1,2,1,'\\ ','g6018'),(13217,860194957012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','cherebere','schereji@yahoo.com','stefan chereji','3580 sirois','saint hubert','QC','CANADA','j3y 6l4','(450) 671-9058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 18:25:20',0,NULL,3,1,2,1,'\\ ','cherebere'),(13218,631069498013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','janis150988','astichs@gmail.com','Janis Astics','Hāpsalas iela 15-60','Riga','Latvia','LATVIA','LV-1005','(371) 28313827','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-10-07 18:41:08',0,NULL,3,1,3,1,'RA184586347CN\r ','janis150988\rHSNO019\r欧标'),(13219,860219641012,220501830523,'2.1 Acer Aspire 5570 5570Z Bluetooth Module EDR+cable',1,'BTAC2116',12.4,'eastar4','rdelgatto','rdelgatt@optonline.net','Robert Del Gatto','89 Terrace Dr','East Northport','NY','UNITED STATES','11731','(631) 774-7814','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 19:12:42',0,NULL,3,1,1,1,'\\ ','rdelgatto\racer 6pin1.25 23cm'),(13220,775644275011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',18.99,'eastar4','thibault45','moimaime@lavache.com','Thibault SUSINI/St Worthington DSS Ltd','Flat 1/B, 37 Lansdowne Road','Worthing','West Sussex','UNITED KINGDOM','BN11 4NF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 19:58:08',0,NULL,3,1,2,1,'\\ ','thibault45'),(13221,631101928013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.88,'eastar4','nomaded885','nomade885@gmail.com','muller camille','31 rue du duc','la rochelle','Poitou-Charentes','FRANCE','17000','0682279795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 20:13:33',0,NULL,3,1,2,1,'\\ ','nomaded885'),(13222,734262006001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','leafsbuffalo','byarndley@hotmail.com','Bill Yarndley','9 Eastgate Circle','Whitby','ON','CANADA','L1M 2N3','(905) 425-0923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 20:25:30',0,NULL,3,1,3,1,'RA184586435CN\r ','leafsbuffalo\rBR3D008'),(13223,775671848011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','007garmendia','mr-garmendia@hotmail.com','Lucas Garmendia','Av. Getulio Vargas 888 apt 402','Porto Alegre','Rio Grande do Sul','BRAZIL','90150-002','555130193546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 21:00:30',0,NULL,3,1,2,1,'\\ ','007garmendia'),(13224,775673061011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','raysooner','ray@vela-law.com','Ray L. Vela','ABV Law<br>8111 Lyndon B Johnson Fwy Ste 480','Dallas','TX','UNITED STATES','75251-1395','(214) 276-1545','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-07 21:02:41',0,NULL,3,1,1,1,'\\ ','raysooner'),(13225,631117336013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','norriekid71','lisap01@bigpond.com.au','Lisa Pacini','3 Third Avenue','Cheltenham','South Australia','AUSTRALIA','5014','0882441416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 21:03:11',0,NULL,3,1,3,1,'RA184586585CN\r ','norriekid71\rMOSA005'),(13226,775681009011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','mike_l_76','michael_lech@hotmail.com','Michael Lech','19 Petersilka Street','Gungahlin','Australian Capital Territory','AUSTRALIA','2912','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 21:23:25',0,NULL,3,1,2,1,'\\ ','mike_l_76'),(13227,775693781011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.98,'eastar4','bennomaaate','yodabat@optusnet.com.au','Ben Vertigan','121 Franklin Street','Eltham','Victoria','AUSTRALIA','3095','0390179633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 21:59:22',0,NULL,3,1,2,1,'\\ ','bennomaaate\r澳标\r银色的'),(13228,860304686012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','dorinelll','dbunea@yahoo.com','Dorinel Bunea','43 THE GREENSTEAD','BASILDON','Essex','UNITED KINGDOM','SS14 1TA','01268557396','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 22:16:54',0,NULL,3,1,3,1,'RA184586280CN\r ','dorinelll\r英标\rHSJA010'),(13229,574625767003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.9,'cnfaner','unix_core','themadlion2002@yahoo.com','Christopher Witthaus -  HCRC','2625 Michigan Ave','Saint Louis','MO','UNITED STATES','63118-1213','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-07 23:04:49',0,NULL,3,1,1,1,'\\ ','unix_core'),(13230,773076046011,320394892477,'Acer Aspire 5235 5335 5535 Bluetooth Module 2.0 +cable',1,'BTAC2005',9.9,'eastar4','bumpin_sounds','bumpin_sounds@hotmail.com','Rick Kral','9437 S 86th Ct<br>Apt GE','Hickory Hills','IL','UNITED STATES','60457-1759','(773) 505-8637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 00:27:45',0,NULL,3,1,1,1,'\\ ','bumpin_sounds\racer 4pin1.25 8cm '),(13231,775748827011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','18729','joshchee@gmail.com','Joshua Chee','77 Canterfield Close','Markham','ON','CANADA','L3P 7S4','(905) 479-7577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 01:38:47',0,NULL,3,1,2,1,'\\ ','18729'),(13232,631181904013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.95,'eastar4','boblemoche514','luckyluke014@gmail.com','Mike Siméon','170 roger-pilon','Dollard-des-ormeaux','QC','CANADA','h9b2b6','(514) 683-8519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 02:26:25',0,NULL,3,1,2,1,'\\ ','boblemoche514'),(13233,775761359011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',92.99,'eastar4uk','crazyshopdude','ebaycrazyshopdude@gmail.com','Abbas Reza','16 Sharpave Avenue','The Ponds','New South Wales','AUSTRALIA','2769','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 02:33:09',0,NULL,3,1,3,1,'RA184586506CN\r ','crazyshopdude\rGLOT005*3'),(13234,631187399013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',48.5,'eastar4','scientiam7','alblanco48@gmail.com','Al Blanco','1082 Tilley Cir','Concord','CA','UNITED STATES','94518-1829','(510) 849-0567','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 02:50:12',0,NULL,3,1,1,1,'\\ ','scientiam7'),(13235,8881318045107277,111,' New Logitech Unifying USB Receiver For Performance MX  ',1,'RELO002',0,'eastar4','theharpoongill','harpoon@gmail.com','paul s gill','5011 223 st','langley','BC','CANADA','v2y 2v4','(778) 237-4277',NULL,NULL,NULL,'2011-10-08 03:38:27',0,NULL,3,1,2,1,'\\ ','补发的 \r已发货，由于系统改不了'),(13236,775770691011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','meedoemad','emad.saad@mail.mcgill.ca','Emad Saad','4 Vendome','Kirkland','QC','CANADA','H9J 3W3','(514) 232-7223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 03:48:51',0,NULL,3,1,2,1,'\\ ','meedoemad'),(13237,775777413011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.9,'eastar4','easypcrepair','easy.pc.repair@hotmail.com','Igor Petronijevic','2015 N Ginger Creek Dr','Palatine','IL','UNITED STATES','60074-1316','(224) 353-0072','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 03:56:45',0,NULL,3,1,1,1,'\\ ','easypcrepair\rHP 8pin 1.25 25cm '),(13238,775781646011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.4,'eastar4','harbisonautoparts','harbisonautoparts@hotmail.com','Harbison Auto Parts - Arthur Crosby','4434 Kiln Ct<br>Bldg A','Louisville','KY','UNITED STATES','40218-3042','(502) 458-0326','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 04:19:19',0,NULL,3,1,1,1,'\\ ','harbisonautoparts\racer 6pin1.25 23cm'),(13239,775763502011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','jl93sundance','logrecohockey@yahoo.com','Jimmy LoGreco','808 Graham St','Belle Vernon','PA','UNITED STATES','15012-1673','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 04:29:20',0,NULL,3,1,1,1,'\\ ','jl93sundance'),(13240,775785192011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','eddy504','emira10915@aol.com','Ed Miranda','1010 Grand Cerritos Ave','Las Vegas','NV','UNITED STATES','89183-4658','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 04:42:56',0,NULL,3,1,1,1,'\\ ','eddy504'),(13241,734382296001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','3bg2011','jttt@xtra.co.nz','Tracey Taylor','19A Elstree Avenue<br>Glen Innes','Auckland','','NEW ZEALAND','1072','095286139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 04:53:09',0,NULL,3,1,3,1,'RA184586174CN\r ','3bg2011\rBR3D005'),(13242,775797955011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',27.99,'eastar4uk','09jaryn','jaryngillick@gmail.com','Jaryn Gillick','4/35 Sherwood Road','Ivanhoe','Victoria','AUSTRALIA','3079','0394971759','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 06:01:06',0,NULL,3,1,3,1,'RA184586214CN\r ','09jaryn\rOTPL001\r'),(13243,860427678012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.9,'eastar4','yves862','yves.saumier@free.fr','yves saumier','les romarins 1<br>camp militaire de carpiagne','carnoux en provence','Provence-Alpes-Côte d\'Azur','FRANCE','13470','0675695283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 07:08:26',0,NULL,3,1,2,1,'\\ ','yves862\racer 8pin1.00 15cm\r已发，改不了系统'),(13244,8881318060563208,111,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D007',0,'buysia','trekerdan','danfastwave@cox.net','daniel n moser','1440 S Citrus Ave','Escondido','CA','UNITED STATES','92027-4953','(760) 739-9878',NULL,NULL,NULL,'2011-10-08 07:56:03',0,NULL,5,0,3,1,'RA184567056CN\r ','BR3D005\r补发的    \r已发，由于系统改不了状态'),(13245,775837620011,320679568138,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',3,'HSSE003',41.7,'eastar4uk','gmccomiskie','gmccomiskie@hotmail.com','Gordon McComiskie','PO Box 575','Lakemba','New South Wales','AUSTRALIA','2195','0421020633','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 08:54:11',0,NULL,3,1,3,1,'RA184564854CN\r ','gmccomiskie\rHSSE003\r澳标'),(13246,8881318064229355,111,' 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001',0,'eastar4','philippe-mouse','philippe.claesens@telenet.be','philippe claesens','moerstraat 9','nevele','','BELGIUM','9850','+3293718771',NULL,NULL,NULL,'2011-10-08 08:57:09',0,NULL,3,1,3,1,'RA184567025CN ','补发的一副\rGLOT001 '),(13247,631244663013,230657622422,'Genuine DENON RC-970 Remote Control RC 970',1,'RCDE002',79.99,'eastar4','stephane28','s_chapel@club-internet.fr','CHAPELLE stephane','9 rue poupinet','VIGNEUX SUR SEINE','Île-de-France','FRANCE','91270','0675488432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:09:42',0,NULL,3,1,3,1,'RA184567039CN\r ','stephane28\rRCDE002'),(13248,860460177012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','aginu','iroxxorjoo@hotmail.com','Bogdan Albu','BSMT-1505 Dent Ave.','Burnaby','BC','CANADA','V5C 5B9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:12:32',0,NULL,3,1,2,1,'\\ ','aginu'),(13249,631247318013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','izotop67','bykov@012.net.il','Sergey Bykov','Brosh str. 33/1','Nazareth Illite','','ISRAEL','17511','+97246578287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:22:31',0,NULL,3,1,2,1,'\\ ','izotop67'),(13250,580260952004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',2,'HSPL002',25.96,'cnfaner','hardeepchohan11','hc_11@live.com.au','Hardeep Chohan','63 Aleppo Street<br>Quakers Hill','Sydney','New South Wales','AUSTRALIA','2763','0298378948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:26:27',0,NULL,3,1,3,1,'RA184567042CN\r ','hardeepchohan11\rHSPL002'),(13251,775847736011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',6.88,'eastar4','xpolgr','xpolgr@hotmail.com','Polivios Xanthakis','Nikou Xilouri 17','Heraklion','Crete','GREECE','71307','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:28:37',0,NULL,3,1,2,1,'\\ ','xpolgr'),(13252,630561274013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','pinsara','prageeth.polgampola@gmail.com','Prageeth Polgampola','408<br>Bollatha','Ganemulla','','SRI LANKA','11024','+94 775524829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:40:39',0,NULL,3,1,2,1,'\\ ','pinsara'),(13253,631251121013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','renee887','renee.b@virserum.com','RENEE BRINTER','KÄLLGATAN 1','VIRSERUM','','SWEDEN','57080','0495-30026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 09:41:50',0,NULL,3,1,2,1,'\\ ','renee887'),(13254,775871854011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','customs151','customs151@hotmail.com','matt douglas','14 North Road','Bideford','Devon','UNITED KINGDOM','ex392nw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 10:47:38',0,NULL,3,1,3,1,'RA184567246CN ','customs151\r兼容型3D眼镜 通用型\rGLOT001*2\r可以用'),(13255,716946737008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','othiking','othi.k@live.com','Othniel Kienle','Derech Avshalom 1','Zickhron Ya\'akov','','ISRAEL','30951','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 10:50:22',0,NULL,3,1,3,1,'RA184567688CN\r','othiking\rHSPL010'),(13256,775873677011,320730088774,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT011',17.99,'eastar4uk','twipsy1','twipsy1@gmx.net','Joerg Borchert','Auf der Allmende 22','Hannover','','GERMANY','30657','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 10:55:39',0,NULL,5,1,18,1,' ','twipsy1  已经退款 撤单'),(13257,860448758012,220692197062,'IBM Ericsson F3507G 3G WWAN card+antenna FRU43Y6513',1,'WWOT002+ANCN001',53.9,'eastar4','iab_sib','iab@sibnet.ru','ANDREY ILCHUK','ul. Gaydara, dom 18, кв.134','Prokopievsk','Kemerovskay obl','RUSSIAN FEDERATION','653047','+79236206588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 10:56:25',0,NULL,3,1,3,1,'RA184586625CN\r ','iab_sib\rWWOT002+ANCN001'),(13258,631278329013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','kvtgs','kvtgs@optusnet.com.au','Graham Scott','29 Rylandes Dr','Gladstone Park','Victoria','AUSTRALIA','3043','0393382126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 11:51:22',0,NULL,3,1,2,1,' \\ ','kvtgs'),(13259,580030225004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.7,'cnfaner','eltongermano','elton.germano@gmail.com','Elton Rodrigo Germano','Travessa Doutor Freitas, 64<br>Centro','Caçapava','SP','BRAZIL','12281550','+55(12)88015012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 12:04:52',0,NULL,3,1,3,1,'RA184586687CN\r ','eltongermano\rWWOT001'),(13260,860536387012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','kakpoo','lizteasdale@yahoo.com','john p donlon','13 Oak Lane','kerridge','Cheshire','UNITED KINGDOM','SK10 5BD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 12:49:22',0,NULL,3,1,2,1,' \\ ','kakpoo'),(13261,860543146012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','sunnytam4','kingfisher505@gmail.com','John Shorthouse','33 Merivale St, North Lambton','Newcastle','New South Wales','AUSTRALIA','2299','0421839220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:06:41',0,NULL,3,1,2,1,' \\ ','sunnytam4'),(13262,574764688003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','32050la','lyudmil@primus.ca','Lyudmil Stoyanov','305-500 Glenelm Crescent','Waterloo','ON','CANADA','N2L 5C8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:06:51',0,NULL,3,1,3,1,'RA184586656CN\r ','32050la\rWLIN016'),(13263,631303882013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',43.9,'eastar4','hotride_dude89','hotride_dude@list.ru','Dmitry Marchenko','Bistrova 82-39','Volgograd','RU','RUSSIAN FEDERATION','400067','89023832662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:26:55',0,NULL,3,1,3,1,'RA184586639CN\r ','hotride_dude89\rMOLO004\r华硕限量版'),(13264,631305060013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','nata-koenig','nata_koenig@km.ru','Natalya Pronina','Kommunisticheskaya 37v-15','Kaliningrad','Kaliningrad region','RUSSIAN FEDERATION','236005','+74012682395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:32:30',0,NULL,3,1,2,1,' \\','nata-koenig\r韩版透明伞\r带心型的'),(13265,860553984012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',8.99,'eastar4uk','homelands2011','malcsleep@btinternet.com','malcolm sleep','hillside','launceston','Cornwall','UNITED KINGDOM','pl159ph','07855831317','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 13:34:35',0,NULL,3,1,3,1,'RA184586642CN\r ','homelands2011\rHSMO017\r英标'),(13266,631308597013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',2,'MOSA005',139.8,'eastar4','baoule75','baoule@gmail.com','Jeugnet Frédéric','5, allée de l\'Europe','CHANTILLY','Picardie','FRANCE','60500','+33663397557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:44:41',0,NULL,3,1,3,1,'RA184586744CN\rRA184586792CN\r\r ','baoule75\rMOSA005\r分开发'),(13267,775935276011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mc08608','gonzalez.alberto@yahoo.com','Alberto A Gonzalez','1601 Cuyler Ave','Berwyn','IL','UNITED STATES','60402','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 13:52:11',0,NULL,3,1,1,1,' \\ ','mc08608'),(13268,860565685012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','lee.buying.stuff','lee@allemandfamily.info','Lee Allemand','PO BOX 614','Beerwah','Queensland','AUSTRALIA','4519','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 14:15:51',0,NULL,3,1,2,1,' \\ ','lee.buying.stuff'),(13269,775949691011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','terina75','teri.orengo@sky.com','Teri Orengo','19 Millhouse crescent','Glasgow','Glasgow (City of)','UNITED KINGDOM','G20 0UD','01415793820','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-08 14:38:23',0,NULL,3,1,2,1,' \\ ','terina75\r向日葵三折叠伞 '),(13270,775965984011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.98,'eastar4','abstinatus','iovsec@gmail.com','Igor OVSEC','133 rte de St Victor de Cessieu','SAINTE-BLANDINE','Rhône-Alpes','FRANCE','38110','0607999474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 15:04:13',0,NULL,3,1,2,1,' \\ ','abstinatus'),(13271,775980393011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',2,'HSNO003',47.98,'eastar4','clegg_67','clegg1967@gmail.com','Sergei Podbolotov','Shlisselburgsky pr. 34-4-58','Saint-Petersburg','','RUSSIAN FEDERATION','192076','+79219580968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 15:39:44',0,NULL,3,1,3,1,'RA184586568CN\r ','clegg_67\r欧标\rHSNO003'),(13272,860615995012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.9,'eastar4','pootchi65','schwarz-irina@web.de','irina schwarz','friedrichsgrüner str.5a','höchstädt','','GERMANY','89420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 15:48:33',0,NULL,3,1,2,1,' \\ ','pootchi65\r4pin 1.25 '),(13273,860616887012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.99,'eastar4','customstiks','theubermensche@gmail.com','Matt Robertson','4615 Lindell Blvd<br>Apt 602','Saint Louis','MO','UNITED STATES','63108-3719','(417) 661-0220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 15:52:18',0,NULL,3,1,1,1,' \\ ','customstiks'),(13274,773754778011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','sutherland.jay','sutherland.jay@gmail.com','Jessica Westbrook','1040 division st<br>unit 10','cobourg','ON','CANADA','k9a5y5','(905) 377-0264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:03:54',0,NULL,3,1,2,1,' \\ ','sutherland.jay'),(13275,776000520011,320730549023,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',78.99,'eastar4uk','dina10041983','dzheina19@inbox.lv','Dina Rogosa','371<br>Elgar road south','Reading','Berkshire','UNITED KINGDOM','RG2 0DP','7599623078','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 16:19:43',0,NULL,3,1,3,1,'RA184567250CN ','dina10041983\rGLOT001*3\r兼容型3D眼镜 通用型\r可以用'),(13276,860635491012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',31.99,'eastar4uk','danieletx','danieletx@hotmail.com','Daniel Badia Jobal','C/ Torre del Pardals N.22  / Piso :  4o  2a','barcelona','barcelona','SPAIN','08041','655905139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 16:27:11',0,NULL,3,1,3,1,'RA184586758CN\r ','danieletx\rGLOT005'),(13277,631367728013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',76.78,'eastar4','florian2505','flotrek@gmail.com','Florian CAPOLUNGHI','66, rue Desnouettes','PARIS','Île-de-France','FRANCE','75015','0145310527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:54:02',0,NULL,3,1,3,1,'RA184586735CN\r ','florian2505\rMOSA005\r再发一个Griffin Dual USB Car Charger for iPhone ipad iPad2\r'),(13278,776020600011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','emanuelrod','emany1262@aol.com','EMMANUEL RODRIGUEZ','159 Van Buren St','PASSAIC','NJ','UNITED STATES','07055-8432','(551) 265-7879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 17:01:02',0,NULL,3,1,1,1,' \\ ','emanuelrod'),(13279,860678854012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.9,'eastar4uk','bigkev35','kevin.nicoll@ntlworld.com','kevin   nicoll','36 lanfine rd','paisley','Renfrewshire','UNITED KINGDOM','PA13NL','01415810091','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 17:44:57',0,NULL,3,1,3,1,'RA184586695CN\r ','bigkev35\rWLAP002'),(13280,860694336012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',14.9,'eastar4uk','davidb5480','davebriers@hotmail.com','David Briers','80 Chesterfield Road','Lichfield','Staffordshire','UNITED KINGDOM','WS13 6QW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 18:14:30',0,NULL,3,1,3,1,'RA184586700CN\r ','davidb5480\rHBPH003'),(13281,631400910013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','jackson*engr','bjackson@intersite.com','Brian C. Jackson','11 E 25th St','Tulsa','OK','UNITED STATES','74114-2409','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 18:16:10',0,NULL,3,1,1,1,' \\ ','jackson*engr\r红边优联'),(13282,717130466008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','josesoft66','joselato35@hotmail.com','Jose Latorre','La Almendra 21','Estadilla(Huesca)','Aragón','SPAIN','22423','974305241','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 18:29:33',0,NULL,3,1,3,1,'RA184567691CN\r','josesoft66\rHSPL010'),(13283,860721223012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',21.99,'eastar4','valeriy1332','valeriy133@rambler.ru','Valery Goloulin','Pravdy 18/1 -36','Ufa','Bashkortostan','RUSSIAN FEDERATION','450024','(927)232-2234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 18:59:18',0,NULL,3,1,2,1,' \\ ','valeriy1332'),(13284,734666109001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',19.99,'buysia','bamarebel51','crowmelvis69@hotmail.com','malvin crowson','4900 bow st','Anniston','AL','UNITED STATES','36206-1519','(256) 820-6373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 19:21:14',0,NULL,3,1,1,1,' \\ ','bamarebel51'),(13285,860734163012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','guy1372','gmcphee@sky.com','Guy McPhee','77 Park road New Carron','Falkirk','Falkirk','UNITED KINGDOM','FK27PU','07905364654','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 19:22:08',0,NULL,3,1,3,1,'RA184586673CN\r ','guy1372\rGLSG001*2'),(13286,580435449004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'cnfaner','kapacbhifi','hifi7@yandex.ru','Andrey Karasev','Baryshiha 21/1-97','Moscow','','RUSSIAN FEDERATION','125368','+79030065555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 19:54:41',0,NULL,3,1,3,1,'RA184586660CN\r ','kapacbhifi\rOTGR005'),(13287,776112064011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','lemay0123','lemay98@hotmail.com','Lemay Matos','2840 NW 151st Ter','miami gardens','FL','UNITED STATES','33054-2637','(305) 778-7133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 19:57:17',0,NULL,3,1,1,1,'\\ ','lemay0123\r兼容型3D眼镜 通用型\r客户不回复电视型号\r发吧'),(13288,776138130011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','jbathehut','jschmall@gmail.com','Jared Schmall','1101 Gettysburg Ave<br>Apt 1228','Clovis','CA','UNITED STATES','93612-3974','(530) 227-6845','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 20:54:34',0,NULL,3,1,1,1,' \\ ','jbathehut'),(13289,860680331012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','gopyak','rgopyak@yahoo.com','Roman Gopyak','Kulparkivska<br>93, ofice 308','Lviv','','UKRAINE','79021','0038-050-6740405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 21:51:53',0,NULL,3,1,2,1,' \\ ','gopyak'),(13290,580469253004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','mcghee.r','mcghee.r@insightbb.com','ronald mcghee','7333 egypt ln','louisville','KY','UNITED STATES','40219-2745','(502) 548-5848','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-08 21:52:00',0,NULL,3,1,1,1,' \\ ','mcghee.r'),(13291,776163263011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','kaczor47','kaczor47@gmail.com','Pawel Dmochowski','5A Ravi Street','Khandallah','Wellington','NEW ZEALAND','6035','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 21:56:22',0,NULL,3,1,2,1,' \\ ','kaczor47'),(13292,776169351011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','fhalemang','fhag@hotmail.com','Felix Horacio Aleman Jr','116 E Coma Ave<br>Apt 179','Hidalgo','TX','UNITED STATES','78557-2501','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 22:14:16',0,NULL,3,1,1,1,' \\ ','fhalemang\r红边优联'),(13293,631479926013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.99,'eastar4','exmpsfc','sdaddabbo@gmail.com','Steve Daddabbo','135 Macedonia Woods Dr','Newnan','GA','UNITED STATES','30263-6133','(770) 820-3831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 22:21:12',0,NULL,3,1,1,1,' \\ ','exmpsfc'),(13294,776174655011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',31.99,'eastar4uk','summer1230_9','s-thodges@talktalk.net','Mr Tim Hodges','9 Kingfishers<br>Orton Wistow','Peterborough','Cambridgeshire','UNITED KINGDOM','PE2 6YH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 22:30:10',0,NULL,3,1,3,1,'RA184586727CN\r ','summer1230_9\rGLSG001'),(13295,860826533012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',4,'TRMX003',30.28,'eastar4','snowboard31','res70ebs@frontier.com','Gordon Matthews','PO Box 1198<br>406 Maple ave','La Conner','WA','UNITED STATES','98257-1198','(360) 466-5152','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 22:46:38',0,NULL,3,1,1,1,' \\ ','snowboard31'),(13296,776184278011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','achi2393','cowyafat@hotmail.com','Alex Chicas','498 Queen Victoria Drive','Hamilton','ON','CANADA','L8W 1G9','(905) 869-5180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 23:01:49',0,NULL,3,1,2,1,' \\ ','achi2393'),(13297,860834101012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',25.9,'eastar4uk','ballardc69','ballardc69@yahoo.co.uk','Christopher Ballard','17<br>Elibank Road','Eltham','London','UNITED KINGDOM','SE91QQ','02082657244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 23:11:03',0,NULL,3,1,3,1,'RA184586571CN\r ','ballardc69\rOTGR001+OTGR002'),(13298,631499093013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','terzilermehmet','mehmetterziler@yahoo.com','Mehmet Terziler','1775/6 no:8 d:3 çağlar apt. Karşiyaka','İzmir','İzmir','TURKEY','35530','+905069315552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 23:54:03',0,NULL,3,1,2,1,' \\ ','terzilermehmet'),(13299,860855645012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',28.99,'eastar4','arice3','eluniuck@gmail.com','elaine olson','4405 114th Ave E','edgewood','WA','UNITED STATES','98372-2312','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 00:27:22',0,NULL,3,1,1,1,' \\ ','arice3'),(13300,860856898012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.9,'eastar4','bspcs1','antoniomorin@yahoo.com','Jose Antonio Morin Romero','1227 Cheshire st','Groveland','FL','UNITED STATES','34736-9515','(352) 897-6421','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 00:31:22',0,NULL,3,1,1,1,' \\ ','bspcs1\racer 6pin1.25 23cm'),(13301,776232647011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3002',19.99,'eastar4','moboot39','maro@tarumi-kikaku.com','Shintaro Sakurai','1-2-30-804 Fukiage<br>Chikusa-ku','Nagoya','Aichi','JAPAN','464-0856','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 02:12:55',0,NULL,3,1,2,1,' \\ ','moboot39\rHP 6pin1.0 3cm'),(13302,631531593013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','bradpas','bthompson@pacific.net.au','Brad Thompson','16 Peterson Place<br>Bridgeman Downs','Brisbane','Queensland','AUSTRALIA','4035','0733534335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 02:54:13',0,NULL,3,1,2,1,' \\ ','bradpas\r红边优联'),(13303,776247615011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','morethanyouexpect','jaymiscl123@hotmail.com','Donna Hodges','HC 89 Box 445<br>(Drop Box)','Winona','MO','UNITED STATES','65588-9538','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 03:20:14',0,NULL,3,1,1,1,' \\ ','morethanyouexpect'),(13304,631546910013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',34.99,'eastar4','riperdaniilsan','daniil_sanarov@mail.ru','Daniil Sanarov','5th Parkovaya st., 32 - 9','Moscow','Moscow','RUSSIAN FEDERATION','105043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 04:11:55',0,NULL,3,1,3,1,'RA184586611CN\r ','riperdaniilsan\rWLIN002   ebay注销帐号 paypal可能有问题'),(13305,631551434013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.95,'eastar4','sonixd8','lmromena@gmail.com','Lester Michael Romena','05-4985 Blk 645<br>Ang Mo Kio Avenue 6 Singapore 560645','default','','SINGAPORE','560645','91268997','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 04:42:44',0,NULL,3,1,11,1,NULL,'sonixd8'),(13306,631551216013,230658777210,'Original lowrance ifinder EXPLORER GPS',1,'GPS0002',89.9,'eastar4','mattomgo','sgohman@hotmail.com','SCOTT GOHMAN','775 ANDERSON AVE<br>GRAINGER','SAINT CLOUD','MN','UNITED STATES','56303-2048','(320) 255-5422','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 04:59:45',0,NULL,3,1,1,1,'\\ ','mattomgo\r新地址\rGrainger \r3900 Roosevelt Road, Ste 104\rSaint Cloud, MN 56301\rUNITED STATES\r(320) 255-5422\r由于缺货换发成\rLowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver彩色\r\r\r\r'),(13307,860926440012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','ivanvista','everest16@hotmail.com','jivan','7/25-27 robertson st','kogarah','new south wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 05:20:39',0,NULL,3,1,3,1,'RA184586775CN\r ','ivanvista\rOTIN005'),(13308,631557017013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','nagne99','kkr099@hotmail.com','Kenneth Row','4839 S Torrey Pines Dr<br>Unit 104','Las Vegas','NV','UNITED STATES','89103-4440','(702) 335-1128','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-09 05:25:16',0,NULL,3,1,1,1,' \\ ','nagne99'),(13309,776280750011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',3,'HSJA011',85.5,'eastar4','bauwornrat','fredfredericks@cox.net','Fred  Fredericks','11218 Del Rio Rd','Spring Valley','CA','UNITED STATES','91978-1224','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 06:15:53',0,NULL,3,1,1,1,' \\ ','bauwornrat'),(13310,776281481011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','edwardrus','kievman2003@hotmail.com','Gnidets Vladimir','645 W 1st Ave','Roselle','NJ','UNITED STATES','07203-1049','908 241 2190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 06:19:56',0,NULL,3,1,1,1,' \\ ','edwardrus'),(13311,776284231011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.98,'eastar4','jimiology','hahajim2003@yahoo.com.hk','Jim Liu','17B 101 Boardway street<br>Mei Foo Sun Chuen Kowloon Hong Kong','default','','HONG KONG','default','85267785881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 06:35:47',0,NULL,3,1,2,1,'、 ','jimiology'),(13312,776180429011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','lillyjy','3ly@qlink.queensu.ca','Lilly Yonadam','1463 Indian Grove','Mississauga','ON','CANADA','L5H 2S5','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'lillyjy'),(13313,860947427012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','karategal21','jagap1@hotmail.com','Melanie Agapiou','17 Glendye Court<br>corio','Geelong','Victoria','AUSTRALIA','3214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 07:03:37',0,NULL,3,1,3,1,'RA184586789CN\r ','karategal21\rOTSO004*2'),(13314,776290766011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','itay.kalo','itayk777@gmail.com','Itay Kalo','Chruv St. 18','Haifa','IL','ISRAEL','34326','0523411669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 07:07:30',0,NULL,3,1,2,1,' \\ ','itay.kalo'),(13315,8881318145733173,111,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',0,'buysia','dolomb12bx','dolomb@aol.com','Dolores E. Biggett','6312 Colonial View','Fairburn','GA ','UNITED STATES','30213','(239) 949-1158',NULL,NULL,NULL,'2011-10-09 07:35:33',0,NULL,3,1,3,1,'RA184586713CN\r ','BR3D007\r补发的 '),(13316,860957907012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',9.99,'eastar4uk','123-kamaljit','kamaljit_bagha@hotmail.com','Sanjeet BAGHA','27 ash grove<br>ASH GROVE','SOUTHALL','London','UNITED KINGDOM','UB1 2UN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 07:41:06',0,NULL,3,1,3,1,'RA184586801CN\r ','123-kamaljit\rOTCN004*10'),(13317,776302972011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',32.99,'eastar4uk','dawnst65','dawn.trivess@midkent.ac.uk','Dawn Trivess','21 Hero Walk','Rochester','Kent','UNITED KINGDOM','ME1 2UZ','01622625820','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 07:56:15',0,NULL,3,1,3,1,'RA184586761CN\r ','dawnst65\r英标\rHSPL015'),(13318,631588637013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.4,'eastar4','doka2233','zdravko.dokuzovic@sb.t-com.hr','Zdravko Dokuzovic','Aleja Miroslava Krleze 65.','Slavonski Brod','','CROATIA','35000','+38535255220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 08:31:40',0,NULL,3,1,2,1,'、 ','doka2233\racer 5pin1.25 6cm '),(13319,861004779012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','ringtailmonkeypuzzle','rampling@supanet.com','Stephen Rampling','44 New Road<br>Great Baddow','Chelmsford','Essex','UNITED KINGDOM','CM2 7QT','01245475130','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 09:45:04',0,NULL,3,1,3,1,'RA184567396CN ','ringtailmonkeypuzzle\r英标\rHSJA010'),(13320,776345142011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','bert8468','b1huygen@xs4all.nl','Bas Huygen','Kortfoortstraat 24','Oss','','NETHERLANDS','5342AE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 09:48:20',0,NULL,3,1,2,1,'\\  ','bert8468'),(13321,861017374012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',9.5,'eastar4uk','gerrymc5-2008','gerrymc5@hotmail.com','Gerry McLaughlin','29 Milner St <br>Swinton','Manchester','Greater Manchester','UNITED KINGDOM','M27 4AS','07966198599','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 10:11:53',0,NULL,3,1,3,1,'RA184567453CN ','gerrymc5-2008\rHSPL002'),(13322,776373564011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','chensta','william@websitemart.com.au','WIlliam Chen','Level 2, 181 Riley street<br>Department: First Rate','Darlinghurst','New South Wales','AUSTRALIA','2010','020433674099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:56:17',0,NULL,3,1,2,1,' ','chensta'),(13323,631629952013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','thstee84','thstee84@gmail.com','Terence Tee','Northbridge Pharmacy<br>Shop 2/115 Sailors Bay Road','Northbridge','New South Wales','AUSTRALIA','2063','0405356652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:58:44',0,NULL,3,1,3,1,'RA184567507CN ','thstee84\rMOSA004'),(13324,861038683012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','stuppri*6','udoudelhoven@gmx.de','Udo Udelhoven','Gleiwitzer Str. 7','Köln','','GERMANY','51065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:58:57',0,NULL,3,1,2,1,'\\  ','stuppri*6'),(13325,717420373008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','pc-activeuk','pc-active@mail.com','PC Active','46 Long Street','Wigston','Leicestershire','UNITED KINGDOM','LE182AH','01162883055','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 11:12:04',0,NULL,5,0,18,0,NULL,'pc-activeuk\r已经退款'),(13326,631645077013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',65.9,'eastar4','hiddevanheusden','hiddevanheusden@gmail.com','Hidde van Heusden','Spelt-Oord 30','HOUTEN','','NETHERLANDS','3991XH','0306378143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 11:47:31',0,NULL,3,1,3,1,'RA184567498CN ','hiddevanheusden\rMOSA005'),(13327,776407565011,320590826661,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',119,'eastar4','buran.0338','santoy@voxnet.ru','ALEXANDER ZIBOROV','Universitetsky ave. 6/3/104','Moscow','RU','RUSSIAN FEDERATION','119333','74957230338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 12:19:04',0,NULL,3,1,3,1,'RA184586829CN ','buran.0338\rRCMA001'),(13328,631658684013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','rocambol333','da.al.con@hotmail.com','maria victoria Sanchez Blazquez','Las pedrizas, nº3(junto a SEDIACO)','Aldeanueva del Camino','Extremadura','SPAIN','10740','927479031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 12:32:49',0,NULL,3,1,2,1,'\\  ','rocambol333'),(13329,631660767013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','iamporkie','trunksthesin@hotmail.com','Nancy Lim','10 Seraya Lane Seraya Court #01-02','default','','SINGAPORE','437277','63465992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 12:36:13',0,NULL,3,1,3,1,'RA184567365CN ','iamporkie\rBAZA001'),(13330,631663224013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',357.98,'eastar4','vador1971','dossantosjp@aol.com','JEAN-PIERRE DOS SANTOS','28 RUE PORTE DE LA VILLE','MAUREGARD','Île-de-France','FRANCE','77990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 12:51:24',0,NULL,3,1,6,1,'EE491015808CN ','vador1971\r再发两副2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses\r'),(13331,776424218011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.39,'eastar4','zonnea','amz@onsbrabantnet.nl','Ad Zonnevijlle','Koekelberg 34','Veldhoven','','NETHERLANDS','5508 GB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 12:51:44',0,NULL,3,1,2,1,' \\ ','zonnea\racer 4pin1.25 8cm'),(13332,861106809012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','steveglassock64','sglassock@btinternet.com','S Glassock','2Wood Heath Way<br>Eastham','Wirral','Merseyside','UNITED KINGDOM','CH61 0BQ','07976840326','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 13:22:37',0,NULL,3,1,3,1,'RA184567379CN ','steveglassock6\rHSSE005\r英标'),(13333,774897484011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',2,'RELO002',25.96,'eastar4','chongyeeong','chongyee@hotmail.com','Chong-Yee Ong','13 Farrell Place<br>Noranda','Perth','Western Australia','AUSTRALIA','6062','0415354788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 13:36:01',0,NULL,3,1,2,1,'\\  ','chongyeeong'),(13334,861122512012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',29.99,'eastar4uk','boris2721','danaya@mail.bg','Danaya Ltd/  Boris Sotirov','34 Turgovska','Samokov','Sofia oblast','BULGARIA','2000','+359 88 820 85 95','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 13:54:02',0,NULL,3,1,3,1,'RA184567538CN ','boris2721\r欧标\rMOMI001'),(13335,717498361008,180699062016,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',34.49,'au-buy','franck_flynn','franck.flynn@free.fr','OLIVIER SEBAG','32 RUE MANIN','PARIS','Ile-de-France','FRANCE','75019','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 14:06:39',0,NULL,3,1,3,1,'RA184567609CN ','franck_flynn\rUDAP001'),(13336,776481546011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','co2_85','edvine@gmail.com','Edvin Eminovic','Persikogatan 2','Hässelby','','SWEDEN','16563','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 14:46:01',0,NULL,3,1,2,1,'\\  ','co2_85'),(13337,776488515011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.39,'eastar4','toxhawk','rheyne@hotmail.com','Ryan Heyne','12659 337th Ave','Hosmer','SD','UNITED STATES','57448-5216','(605) 216-0634','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 14:58:03',0,NULL,3,1,1,1,'\\  ','toxhawk\racer 6pin1.25 23cm'),(13338,580689967004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','xxxkotxxx','shay_dd@walla.com','Vladimir doroshenko','adar 7/5','Ashkelon','','ISRAEL','78724','(972)546771482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 15:06:08',0,NULL,3,1,3,1,'RA184567382CN ','xxxkotxxx\rHSPL002'),(13339,631741851013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','squabi','arborider@yahoo.com','fabio apolito','4320 SE 48th ave','portland','OR','UNITED STATES','97206-4064','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 16:00:22',0,NULL,3,1,1,1,'\\  ','squabi'),(13340,631743669013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','coxwen691','hoffmanncedric@hotmail.fr','cedric hoffmann','Residence jules vernes 10-12 boulevard d\'erkrath appart a005','Cergy le haut','ile de france','FRANCE','95800','0630012660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 16:04:19',0,NULL,3,1,2,1,'\\  ','coxwen691'),(13341,631743935013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',65.9,'eastar4','selimspider','isasentrab@hotmail.com','Sengun','Saint Maur n°1 appartement 2','Bavay','Nord-Pas-de-Calais','FRANCE','59570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 16:10:48',0,NULL,3,1,3,1,'RA184569556CN\r ','selimspider\rMOSA005\r新地址\rSengun\r11 rue Roger Salengro \r59680 \rFeriere La Grande\rFrance\r'),(13342,580721672004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'cnfaner','cb0305','clbuono@hotmail.com','claudio buono','59 bedell ave','staten island','NY','UNITED STATES','10307','(718) 288-0305','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-09 16:15:45',0,NULL,3,1,1,1,'\\  ','cb0305'),(13343,861237130012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','merlin_neo','merlin2002@ntlworld.com','Robert Bryant','5 Habershon Drive<br>Frimley','Camberley','Surrey','UNITED KINGDOM','GU16 9TN','07969408769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 16:37:04',0,NULL,3,1,2,1,'、 ','merlin_neo\racer 6pin1.25 23cm '),(13344,776563125011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',42.9,'eastar4uk','chameleon_158','paypal@corporatechameleon.co.uk','Michael Hesketh','7 The Birches','Camberley','Surrey','UNITED KINGDOM','GU170EB','01252678089','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 16:46:01',0,NULL,3,1,3,1,'RA184586903CN ','chameleon_158\rHDGE001\r英标\r'),(13345,776566631011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',15.14,'eastar4','ck_goa','chandra_kiran@hotmail.com','Chandra Kiran','8M Reading Rd','Edison','NJ','UNITED STATES','08817-2106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 16:58:07',0,NULL,3,0,1,1,'\\  ','ck_goa\r已入库'),(13346,776577964011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','zanthius2002','andrew.casey@zanthius.com.au','Andrew Casey','U1/67 Nelson St','Kilburn','South Australia','AUSTRALIA','5084','0871220821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:03:15',0,NULL,3,1,2,1,'\\  ','zanthius2002'),(13347,575205878003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','arieka51','dune2000@013.net','Yaniv Kahana','Shay Agnon 24<br>Apartment 8','Raanana','','ISRAEL','43380','97297460212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:09:23',0,NULL,3,1,3,1,'RA184567436CN ','arieka51\rOMHJ001'),(13348,631794986013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','catalink_ce','catalink_ce@yahoo.com','Catalin Costache','4921-107 street','Edmonton','AB','CANADA','T6H 2W8','(780) 935-9055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:29:25',0,NULL,3,1,2,1,'\\  ','catalink_ce'),(13349,861306236012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',29.9,'eastar4','*sternlein','martinschoebel@gmail.com','Martin Schöbel','Barer Straße 35','München','','GERMANY','80799','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:48:47',0,NULL,3,1,2,1,'\\  ','*sternlein'),(13350,580784832004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','flotteuse','nicos1@feignoux.ch','feignoux nicolas','bauma 17','yvonand','','SWITZERLAND','1462','0764342178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:59:58',0,NULL,3,1,3,1,'RA184567440CN ','flotteuse\rHSPL002'),(13351,776634105011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','svenscatman','lange.sven@gmail.com','Sven Lange','Mõisavahe 42-57','Tartu','Tartumaa','ESTONIA','50708','3725541860','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 18:02:10',0,NULL,3,1,2,1,'\\  ','svenscatman'),(13352,861343250012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','member33223','cpinkerton@shaw.ca','Cam Pinkerton','480 Chester Rd','Qualicum Beach','BC','CANADA','V9K 1C1','(250) 720-1045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 18:18:38',0,NULL,3,1,3,1,'RA184567524CN ','member33223\rOTSO004*2'),(13353,861372026012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','sokadik','lapa@lapanet.hu','lapanet LTD.','Alsóerdösor Str. 23.','Alsónémedi','Ungarn','HUNGARY','2351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 18:50:57',0,NULL,3,1,2,1,'\\  ','sokadik'),(13354,776689482011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','igortarasenko1972','igortarasenko@gmail.com','Igor Tarasenko','Borohov 12 ap.8','Petah-Tiqwa','','ISRAEL','49632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 18:59:37',0,NULL,3,1,2,1,'\\  ','igortarasenko1972'),(13355,861381727012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','holaju6','juke_holappa_69@hotmail.com','Jukka-Pekka Holappa','Vartiokatu 14-16 B9<br>96100','Rovaniemi','Rovaniemi','FINLAND','96100','+358405160239','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 19:03:30',0,NULL,3,1,3,1,'RA184586850CN ','holaju6\rHSNO019+CCNO001'),(13356,735219551001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',21.99,'buysia','ramianky27','rabbigleaguer@hotmail.com','Rafael A Barradas B','16 de septiembre #60<br>Col.Pescadores Centro','Boca del Rio','Veracruz','MEXICO','94290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:04:56',0,NULL,3,1,3,1,'RA184567422CN ','ramianky27\rBR3D006'),(13357,861392034012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','natalie37373','natalya@freenet.de','Natalya Ruge','Händelstr. 12','Sarstedt','','GERMANY','31157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:05:37',0,NULL,3,1,2,1,'\\  ','natalie37373\r欧标\r'),(13358,631864485013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','11sammel','sammel@mail.ru','Dmitry Samodin','Mihalkovskaya 5 - 50','Moscow','Moscow','RUSSIAN FEDERATION','125008','915-363-0655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:17:09',0,NULL,3,1,2,1,'\\  ','11sammel'),(13359,776714153011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',93.99,'eastar4uk','chegue74','chegue1974@yahoo.it','marco usai','Flat 4, 18, Crescent road','worthing','West Sussex','UNITED KINGDOM','bn111rl','07789204556','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 19:22:12',0,NULL,3,1,3,1,'RA184567515CN ','chegue74\rGLSG001*3'),(13360,776722040011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','scott32records','shopkin@sbcglobal.net','scott hopkin','32481 Spyglass ct','San Juan Capistrano','CA','UNITED STATES','92675-4017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 19:32:43',0,NULL,3,1,1,1,'\\  ','scott32records'),(13361,776710818011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'eastar4','ullevi85','metteandersen1@gmail.com','Mette Andersen','Langegade 65','Kerteminde','','DENMARK','5300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:18:11',0,NULL,3,1,2,1,'\\  ','ullevi85'),(13362,861436439012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',34,'eastar4uk','mvannas','marttivannas@mac.com','Martti Vannas','Oikokatu 2 B','Hanko','','FINLAND','10900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 19:53:04',0,NULL,3,1,3,1,'RA184586894CN ','mvannas\rHSPL009\r欧标'),(13363,631892864013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','djsp_fr','denis-josse@wanadoo.fr','JOSSE Deniss','21 rue Georges Brassens','LEUVILLE SUR ORGE','Ile-de-France','FRANCE','91310','0620326717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:55:08',0,NULL,3,1,3,1,'RA184567419CN ','djsp_fr\rMOSA004'),(13364,631894793013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','ironhyd','ozfinger@hotmail.com','Rob Osborne','126 Colborne St','Bradford','ON','CANADA','l3z1c5','(905) 895-2288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:59:42',0,NULL,3,1,2,1,'\\  ','ironhyd'),(13365,631895879013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','vonafrent','cybertonas@gmail.com','Antonio Rodrigues','Estrada José Justino dos Anjos Nº 126<br>(Casal Santo António)','Trajouce','S Domingos de Rana','PORTUGAL','2785-660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 20:01:17',0,NULL,3,1,3,1,'RA184567484CN ','vonafrent\rMOSA006'),(13366,631895982013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','kman1001','ahk288@gmail.com','Alexander Katzman','135 E 83rd St<br>Apt 8B','New York','NY','UNITED STATES','10028-2414','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 20:02:21',0,NULL,3,1,1,1,'\\  ','kman1001'),(13367,776752252011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','scoroopster','scoroop@gmail.com','Paweł Skorupa','Dąbrowskiego 21/13','Wrocław','dolnośląskie','POLAND','50-457','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 20:15:16',0,NULL,3,1,2,1,'\\  ','scoroopster'),(13368,575323793003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',39.99,'cnfaner','rockwithgrv007','rockwithgrv@gmail.com','Gaurav suvarna','Shop no.4, building no.5, matruchhaya chs ltd, j.k karmalkar marg,<br>opp. amchi shala, tilak nagar, chembur[W]','Mumbai','Maharashtra','INDIA','400089','919967942362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 20:20:52',0,NULL,5,0,18,1,'RA184586832CN ','rockwithgrv007\rHSNO019+CCNO001\r已经退款 客户要撤单'),(13369,580878456004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',16.4,'cnfaner','kontikonrad','konrad863@btinternet.com','Konrad Bialoskorka','18 Buckthorn Road','Peterborough','Cambridgeshire','UNITED KINGDOM','PE7 8EE','01733344239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 20:45:56',0,NULL,3,1,3,1,'RA184567643CN ','kontikonrad\rHSNO009\r英标'),(13370,735287776001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','cforkner','cforkner@hotmail.com','cindy forkner','2377 Liverpool Ct','Columbus','OH','UNITED STATES','43229-1571','(614) 214-7781','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 20:46:00',0,NULL,3,1,1,1,'\\  ','cforkner'),(13371,776778890011,320738499440,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',12.85,'eastar4','wekkika','jrvd3@hotmail.com','Jessica Dimech','44, John Paul 2, Triq id Dielja','Malta','','MALTA','ATD 2680','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 20:54:55',0,NULL,3,1,2,1,'\\  ','wekkika\r韩版透明伞 '),(13372,776789690011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','ynontal','yinon.tal@gmail.com','Yinon Tal','P.O.BOX 2053<br>4 Hacharoshet street','Kfar Saba','','ISRAEL','44640','00972545428423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 21:19:06',0,NULL,3,1,2,1,'\\  ','ynontal'),(13373,631933914013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','brewman777','brewman777@hotmail.com','Bret Tanner','568 Armington Rd','Belt','MT','UNITED STATES','59412-8303','(406) 277-3232','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 21:34:28',0,NULL,3,1,1,1,'\\  ','brewman777\r兼容型3D眼镜 通用型'),(13374,776801884011,320678793994,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',8.99,'eastar4uk','gabundu','dropdesaintcom@hotmail.com','Daniela Catania','64,walnat domenico cachia str birkirkara','birkirkara','malta','MALTA','1016','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 21:40:11',0,NULL,3,1,2,1,'\\  ','gabundu\r粉红色的\r欧标'),(13375,631941397013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.99,'eastar4','chucknsheila651','getzin@charter.net','chuck getzin','780 Wilkinson St','red wing','MN','UNITED STATES','55066-2818','(651) 385-7576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 21:55:30',0,NULL,3,1,1,1,'\\  ','chucknsheila651'),(13376,631910196013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','blazer210prov','carter234@netzero.com','nicole carter','PO Box 352','centerville','LA','UNITED STATES','70522-0352','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 21:58:44',0,NULL,3,1,1,1,'\\ ','blazer210prov'),(13377,861523757012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.96,'eastar4','djcot','djcottle@msn.com','Dennis J. Cottle','7000 NE Dolphin Dr','Bainbridge Island','WA','UNITED STATES','98110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 22:29:10',0,NULL,3,1,1,1,'\\ ','djcot'),(13378,861525239012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','biepoo','ebay@mfrick.de','Michael Frick','Qatar First Investment Bank, 6th Floor, QFIB Bldg.<br>Suhaim Bin Hamad Street, P.O Box 28028','Al Sadd, Doha','','QATAR','28028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 22:30:46',0,NULL,3,1,3,1,'RA184586885CN ','biepoo\rHBPH001  退款了'),(13379,776826335011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','guantanameraa','jmisangyi@gmail.com','Jennifer Misangyi','25 First Street','Waterdown','ON','CANADA','L0R 2H3','(289) 208-6357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 22:41:46',0,NULL,3,1,2,1,'\\  ','guantanameraa'),(13380,631134505013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','kdonavan','kdonavan@todaystmj4.com','Keith Donavan, TODAY\'S TMJ4','720 E Capitol Dr','Milwaukee','WI','UNITED STATES','53212-1308','(414) 736-3813','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 23:04:15',0,NULL,3,1,1,1,'\\  ','kdonavan'),(13381,735351185001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','josepepeoliva','josemigueloliva@yahoo.com','JOSE OLIVA','19933 nw 78 ave','HIALEAH','FL','UNITED STATES','33015','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 23:30:32',0,NULL,3,1,1,1,'\\  ','josepepeoliva'),(13382,631968318013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','rpjones6','rnb.jones@frontier.com','Randy P Jones','3748 FAWN DR','Marion','IL','UNITED STATES','62959','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 23:35:55',0,NULL,3,1,1,1,'\\  ','rpjones6'),(13383,631966109013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','starduck_de','bjoern.berz@gmx.net','Bjoern Berz','Am Atzelberg 5','Gross-Gerau','','GERMANY','64521','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 23:39:36',0,NULL,3,1,2,1,'\\  ','starduck_de'),(13384,861553490012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','chuckus2','cahj1968@gmail.com','Charles Hiller','47 Kiel Ave','Butler','NJ','UNITED STATES','07405-1304','(973) 492-3229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 23:46:36',0,NULL,3,1,1,1,'\\  ','chuckus2\racer 6pin1.25 23cm '),(13385,631976619013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','jsn1217','jonathan@nabersstone.com','jonathan Naber','21301 Vanowen St<br>Ste C','Canoga Park','CA','UNITED STATES','91303-2863','(818) 989-0303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 00:09:06',0,NULL,3,1,1,1,'\\  ','jsn1217'),(13386,776611664011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',65.9,'eastar4','diogosimons','diogo@mastermidiacomunicacao.com.br','Diogo Simons','Rua dos Juritis, 10, apto 601<br>RENASCENCA II','SAO LUIS','MA','BRAZIL','65075240','+559884140411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 00:46:12',0,NULL,3,1,3,1,'RA184569468CN\r','diogosimons\rMOSA005'),(13387,776872046011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',65.9,'eastar4','hymenwong','leons@qq.com','zhi jun huang','68 corporate drive. unit 3627','scarborough','ON','CANADA','m1h 3h3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 00:56:43',0,NULL,3,1,3,1,'RA184563037CN\r ','hymenwong\rMOSA005'),(13388,631996121013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','valkdan','danlf99@comcast.net','Dan Fleming%Neva Slike Beauty Salon','149 Madison St','Clarion','PA','UNITED STATES','16214','(814) 226-4716','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 01:18:04',0,NULL,3,1,1,1,'\\  ','valkdan'),(13389,575409568003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',14.99,'cnfaner','gut-d','gutodantas22@hotmail.com','Gutemberg Dantas do Nascimento Dantas do Nascimento','R Bernado coutinho,Denaza, 3guarita, N10351,lt60, araras','Petropolis','Rio de janeiro','BRAZIL','25725022','2492318125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 01:28:55',0,NULL,3,1,3,1,'RA184586815CN ','gut-d\rHSNO005+CCNO001'),(13390,861601476012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','trug2002','trug2002@yahoo.com','Thomas Ruggieri','576 stevens st','lowell','MA','UNITED STATES','01851-4501','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 01:49:03',0,NULL,3,1,1,1,'\\ ','trug2002\racer 5pin1.25 6cm  '),(13391,735406210001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','burpngrl38','donnadb037@aol.com','Donna Brown','6 Buckshot Cv','Pine Bluff','AR','UNITED STATES','71603','(870) 534-7889','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 02:21:05',0,NULL,3,1,1,1,'\\  ','burpngrl38'),(13392,717905703008,180699062113,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',1,'GLOT001',44.99,'au-buy','douglee31206','magicman3755@yahoo.com','douglas huston','1948 Winston Dr','macon','GA','UNITED STATES','31206-3246','(478) 808-6511','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 02:24:35',0,NULL,3,1,1,1,'\\  ','douglee31206\r兼容型3D眼镜 通用型'),(13393,575424110003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','tengrand2','tengrand2@adelphia.net','PHILIP CARUSO','PO Box 645','New Hartford','NY','UNITED STATES','13413-0645','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-10 02:32:24',0,NULL,3,1,1,1,'\\  ','tengrand2'),(13394,776890251011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','bbc5754','rlsp_bc@yahoo.com','Bossman BC','4625 Portofino Way<br>Bldg 27 Apt 301','West Palm Beach','FL','UNITED STATES','33409-8148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 02:44:54',0,NULL,3,1,1,1,'\\  ','bbc5754'),(13395,776917549011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',5,'CASS001',41.45,'eastar4','khorsoo','khorsoo@yahoo.com','Khor Hee Soo','Global  Knowledge<br>190 Middle Road, #20-02 Fortune Centre','default','','SINGAPORE','188979','63322330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 03:17:44',0,NULL,3,1,3,1,'RA184567586CN ','khorsoo\rCASS001'),(13396,861633717012,220844128244,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',17.99,'eastar4','erikhamre','e_hamre@hotmail.com','Erik Hamre','Haugesunds gata 15','Stavanger','','NORWAY','4014','+4795783850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 03:25:57',0,NULL,3,0,2,1,'、 ','erikhamre'),(13397,776928764011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',10.86,'eastar4','francom','basement4000@yahoo.com','Erin Francom','3169 Kingfisher Ct','Fort Collins','CO','UNITED STATES','80528-9455','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 04:05:33',0,NULL,3,1,1,1,'\\ ','francom\r再发一个8V AC Adapter Charger Power Supply Logitech Harmony 880\r\r新地址\rLINDA FRANCOM\r824 VERBENIA AVE\rSANDY UT\rUNITED STATES 84094\r'),(13398,575442332003,130458358024,'New Motorola HS810 Bluetooth Wireless Headset track#',1,'HSMO017',16.99,'cnfaner','altj080mj','marlene.echols@gmail.com','Marlene Echols','25730 Shiawassee Rd<br>Apt 169','Southfield','MI','UNITED STATES','48033-3740','(313) 778-5442','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-10 04:29:39',0,NULL,3,1,1,1,'、 ','altj080mj'),(13399,861646550012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','iishka22','prue.s@hotmail.com','Prue Smith','116 Moola Street','Ballarat','VICTORIA','AUSTRALIA','3350','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'iishka22'),(13400,632039898013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','shahnawazmansuri','shahnawazmansuri@hotmail.com','shahnawaz mansuri','2477<br>100 ave','laval','QC','CANADA','h7t0c3','(450) 681-4367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 04:40:38',0,NULL,3,1,2,1,'、 ','shahnawazmansuri\r黑色的'),(13401,717936666008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.99,'au-buy','radiodan-w7rf','rfpower@radiodan.com','Daniel Magro','6493 Thompson Dr','Fort Collins','CO','UNITED STATES','80526','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 04:43:58',0,NULL,3,1,1,1,'\\','radiodan-w7rf'),(13402,632041769013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',2,'GPS0004',219.98,'eastar4','gmjmcmwm101','motomccain@gmail.com','Gary McCain','7861 Jemez Trl','Yucca Valley','CA','UNITED STATES','92284-3425','(760) 832-5009','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 04:53:31',0,NULL,3,1,1,1,'\\ ','gmjmcmwm101'),(13403,861679486012,220713846457,'New GENUINE NOKIA HS 3W BLUETOOTH HEADSET',1,'HSNO021',7.99,'eastar4uk','execdetailing','info@execdetailing.co.uk','Ricky Field','Unit 35 Mahatma Gandhi Ind Est<br>Milkwood Road','Herne Hill','London','UNITED KINGDOM','SE24 0JF','08452240024','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 06:55:24',0,NULL,3,1,3,1,'RA184567630CN ','execdetailing\r英标\rHSNO021'),(13404,776983627011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','wteaweawe','waiteaweawe@yahoo.com.au','Waitokorau Karauria','130 Amess street','Carlton North','Victoria/ Australia','NEW ZEALAND','3054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 08:37:46',0,NULL,3,1,2,1,'\\  ','wteaweawe\r新地址\rWaitokorau Karauria\r130 Amess street Carlton North Victoria/ Australia 3054\rAUSTRALIA'),(13405,776990075011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','everydaycamel','rock_on_camel@hotmail.com','Ashley Eccleston','2 Congella Road,Ellacombe','Torquay','Devon','UNITED KINGDOM','TQ11JU','01803404904','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 08:55:33',0,NULL,3,1,3,1,'RA184567626CN ','everydaycamel\rGLOT001*2\r兼容型3D眼镜 通用型'),(13406,776990469011,320679568138,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',13.9,'eastar4uk','solveigkr','kenneth-62@hotmail.no','Solveig Kristoffersen','steinseide, 5310 Hauglandshella<br>5310 Hauglandshella','bergen','','NORWAY','5310','98498586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 08:57:27',0,NULL,3,1,2,1,'\\','solveigkr\r欧标'),(13407,861723012012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','pysia822justyna','pysia822@onet.pl','justyna bartosik','295 leagrave high st','luton','Bedfordshire','UNITED KINGDOM','lu4 0nb','07854005163','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 09:36:31',0,NULL,3,1,3,1,'RA184568003CN\r ','pysia822justyna\r英标\rHSJA010'),(13408,632093709013,230641642037,'New lady Painting Rain Sun Parasol Stick Umbrella',1,'UM00014',15.95,'eastar4','axx12','lindamgalloway@yahoo.co.uk','Linda  M Galloway','Pennyroyal.  2A  High Street<br>Earith','Huntingdon','Cambridgeshire','UNITED KINGDOM','PE28 3PP','01487840527','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-10 10:09:05',0,NULL,3,1,2,1,'\\ ','axx12\r美女涂鸦伞 '),(13409,632105603013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','mmadle','tumi782@centrum.cz','Michal Madle','Tyrsovo namesti 2219','Roztoky','Stredocesky kraj','CZECH REPUBLIC','25263','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 11:03:42',0,NULL,3,1,3,1,'RA184567952CN\r ','mmadle\rMOSA004'),(13410,632106069013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','3bit.ru','ebay.3bit.ru@gmail.com','Anatoliy Bychkovskikh','Krasnyh Komandirov, 21-32','Ekaterinburg','Sverdlovskaya oblast','RUSSIAN FEDERATION','620135','+79501990755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 11:06:49',0,NULL,3,1,2,1,'\\  ','3bit.ru'),(13411,777032523011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',16.58,'eastar4','ide_1234','iejielat@gmail.com','Iyad Ejielat','Level1 367 Collins St','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 11:17:07',0,NULL,3,1,2,1,'\\  ','ide_1234'),(13412,861770532012,220815928079,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',6,'OTIN002',119.94,'eastar4uk','ide_1234','iejielat@gmail.com','Iyad Ejielat','7/183 Napier St','Essendon','Victoria','AUSTRALIA','3040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 12:00:42',0,NULL,3,1,3,1,'RA184565072CN ','ide_1234\rOTIN002'),(13413,777046561011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','*phiffie','e_panagiotopoulou@yahoo.com','Michael Miller','Propontidos 7<br>Lofos Skouze','Athens','Attica','GREECE','10444','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 12:02:58',0,NULL,3,1,2,1,'\\  ','*phiffie\r红边优联'),(13414,774585709011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.55,'eastar4uk','robertoooo92','robertyousif@live.se','Robert Yousif','Vinstavägen 70A','Vällingby','','SWEDEN','16270','+46707729208','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 12:27:10',0,NULL,3,1,2,1,'\\ ','robertoooo92'),(13415,718052106008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','windymiller00','mail@ianpmiller.co.uk','Ian Miller','44 Loxwood<br>Earley','Reading','Berkshire','UNITED KINGDOM','RG6 5QZ','01189860056','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 12:37:27',0,NULL,3,1,3,1,'RA184567997CN\r ','windymiller00\rSCLO001'),(13416,773757899011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','a.ha1der','ali.h@gmx.com','Ali Haider','4542 Dora Cres.','Ottawa','ON','CANADA','k1j8s4','(613) 301-2544','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'a.ha1der'),(13417,776955123011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','xxpovgg','stavross25@mail.ru','Mikhail Cetvertakov','45-Parallel, 22/8, 67','Stavropol','Stavropolsky','RUSSIAN FEDERATION','355042','+79187513323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 13:04:42',0,NULL,3,1,2,1,'\\ ','xxpovgg'),(13418,777073667011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','ckwashey','ckwashey@blueyonder.co.uk','Christine Washbrook','118 Foxhole Road','Paignton','Devon','UNITED KINGDOM','TQ3 3ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 13:17:21',0,NULL,3,1,3,1,'RA184565041CN\r ','ckwashey\rGLOT001*2\r兼容型3D眼镜 通用型'),(13419,777081582011,320730086228,'NEW CAB-2660-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 1T',1,'CASS002',5.99,'eastar4uk','phil-s-d','philsd@btconnect.com','Phil Stuart-Douek','23 Evesham Road','Cheadle','Cheshire','UNITED KINGDOM','SK82LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 13:38:14',0,NULL,3,1,3,1,'RA184567921CN\r ','phil-s-d\rCASS002'),(13420,777099554011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','seacowboys','seacowboys@msn.com','darrell wallace','2880 Belle Air Blvd.','Theodore','AL','UNITED STATES','36582','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 14:25:54',0,NULL,3,1,1,1,'\\ ','seacowboys'),(13421,777097087011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kenspiel','kenspiel@yahoo.com','Kenneth Spielman','9 Cedar Ridge Ln','Randolph','NJ','UNITED STATES','07869-4704','(973) 895-3467','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 14:34:35',0,NULL,3,1,1,1,'\\  ','kenspiel'),(13422,632169322013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',17.98,'eastar4','freak-monk','darcksider@gmail.com','Sergey Savchuk','Rybalko 13/166','Novograd-Volynskiy','ZT','UKRAINE','11709','+380938634442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 15:10:23',0,NULL,3,1,2,1,'\\  ','freak-monk'),(13423,861850793012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.88,'eastar4','glavota20','glavota@gmail.com','Stanislav Glavota','Grge Novaka 27','Split','Dalmatia','CROATIA','21000','0912004969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 15:19:18',0,NULL,3,1,2,1,'\\  ','glavota20\racer 8pin1.00 18cm'),(13424,861871114012,220664024415,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.55,'eastar4','romario.k','kukharenko_roman@mail.ru','Roman Kukharenko','Tastak 2    33-92<br>Almaty','Almaty','Asia','KAZAKHSTAN','050005','+7705 1846901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 16:01:36',0,NULL,3,1,2,1,'\\  ','romario.k'),(13425,861875671012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','ricky7252','rickypepperuk@yahoo.co.uk','ricky pepper','2 dene walk ramsgate road','margate','Kent','UNITED KINGDOM','ct94ds','01843232149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 16:10:08',0,NULL,3,1,3,1,' RA184567935CN\r','ricky7252\rGLOT005'),(13426,777152325011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','yiyipum','yiyipum@yahoo.es','Moujahed Akel Injerini','C/ marques de la Valdavia, 151  4ºA','Alcobendas','Madrid','SPAIN','28100','626969697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 16:27:48',0,NULL,3,1,2,1,'\\  ','yiyipum'),(13427,861885340012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',22.71,'eastar4','hunker5','midence1@mac.com','Harold Midence','25452 2nd Street','Lake Forest','CA','UNITED STATES','92630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 16:28:05',0,NULL,3,1,1,1,'\\ ','hunker5'),(13428,777156274011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',9.99,'eastar4uk','ww768','wim.westenberg@versatel.nl','Wim Westenberg','Venkel 34','Dronten','Flevoland','NETHERLANDS','8252 CH','31-321-310026','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 16:34:20',0,NULL,3,1,2,1,'\\  ','ww768'),(13429,575601001003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','dcmurphy7','dcmurphy7@charter.net','Doug Murphy','21 Michelle Ln','Mansfield Center','CT','UNITED STATES','06250-1652','(860) 306-6370','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-10 17:03:30',0,NULL,3,1,1,1,'\\  ','dcmurphy7'),(13430,632221233013,230679976738,'NIB LCD/DLP Projector Ceiling Mount Braket Universal',1,'OTNB001',33.99,'eastar4','hankosky','hankosky.ebay@gmail.com','matthew Hankosky','2413 Waterford Dr','Crest Hill','IL','UNITED STATES','60403-0818','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 17:35:38',0,NULL,3,1,3,1,'RA184565024CN ','hankosky\rOTNB001'),(13431,575616458003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','jahpedro','pedro.vazquez.r@gmail.com','pedro-j, Vasquez Rodriguez','Pi y Margal, 12, 3-der','Las Palmas','','SPAIN','35006','630649156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 17:44:25',0,NULL,5,0,18,1,' ','jahpedro\r发OEM的\rMOOE002\r已经退款 撤单\r'),(13432,632234397013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',39.99,'eastar4','racemedic01','racemedic@gmail.com','Roman  Simon','614 N. Tenth','Garden City','KS','UNITED STATES','67846','(620) 271-2973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 18:07:17',0,NULL,3,1,1,1,'\\  ','racemedic01'),(13433,575625865003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',39.99,'cnfaner','tomasroda67','tomasroda@interia.pl','Tomasz Popiel','8 David Road','Rugby','Northamptonshire','UNITED KINGDOM','cv227px','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 18:16:47',0,NULL,3,1,3,1,'RA184567970CN\r ','tomasroda67\rHSNO019+CCNO001'),(13434,861946424012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',11.99,'eastar4uk','agent3170504','poongo231@yahoo.com','Premlal Maradappan','PricewaterhouseCoopers,<br>H. Thandiraiymaage, Level 3','Roashanee Magu','Male\'','MALDIVES','20031','+9609775498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 18:20:15',0,NULL,3,1,2,1,'\\ ','agent3170504'),(13435,861957269012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','jmplantey','jmdebiganos@live.fr','Jean-Michel Plantey','28 Rue Georges Clemenceau','Biganos','Aquitaine','FRANCE','33380','06.49.41.54.35','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 18:23:43',0,NULL,3,1,3,1,'RA184567949CN\r ','jmplantey\rWWOT003'),(13436,777220275011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','zainey420','ne14zainey@hotmail.com','Mason Zainey','5937 Copeland Mills Dr','Indianapolis','IN','UNITED STATES','46221-4533','(317) 821-3583','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 18:31:04',0,NULL,3,1,1,1,'\\ ','zainey420'),(13437,777247311011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',14.97,'eastar4','eduardorq','ebay@eduardorq.es','Eduardo Romero Quintero','c/ Francisco Hernandez Guerra 6, 10A','Las Palmas de Gran Canaria','Canarias','SPAIN','35014','670645272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 19:19:03',0,NULL,3,1,2,1,'\\  ','eduardorq'),(13438,777255152011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','macksway33','macksway@hotmail.com','Ryan','19 Lorraine Dr','Cambridge','ON','CANADA','N1R 6N9','(519) 222-5995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 19:23:43',0,NULL,3,1,2,1,'\\ ','macksway33'),(13439,862027273012,220806861411,'New lady lotus leaves sun/rain stick Umbrella maroon',1,'UM00002',24.99,'eastar4','masteroll2010','abirman@mts.com.ua','Alexandr Birman','K.Libkneht, 1/3/29','Dnepropetrovsk','','UKRAINE','49030','+380503200088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 20:07:43',0,NULL,3,1,2,1,'\\ ','masteroll2010\r荷叶边伞 \r褐红色'),(13440,777297866011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.49,'eastar4uk','carlin2k','scarlin83@gmail.com','Stuart Carlin','92 Whifflet Street','Coatbridge','Lanarkshire','UNITED KINGDOM','ML5 4EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 20:32:38',0,NULL,3,1,3,1,'RA184567983CN\r ','carlin2k\rOTHP006\r微软的'),(13441,862046939012,220747230858,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',14.9,'eastar4uk','bigleslie5810','lsheridan145@gmail.com','Leslie J. Sheridan','159 Ashley Ln','Enterprise','AL','UNITED STATES','36330-9701','(334) 393-4551','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 20:40:29',0,NULL,3,1,1,1,'\\ ','bigleslie5810'),(13442,575697631003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','itzikitzik2010','itzikmishali@gmail.com','itzik mishali','rambam 47/3','petah tikva','IL','ISRAEL','49542','052-4222055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 21:07:44',0,NULL,3,1,3,1,'RA184567966CN\r ','itzikitzik2010\rHSMO018'),(13443,632323688013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','torokjanos','torokjanos@tanos2000.com','Török János Tamás','Réti út 87 II/4','Tatabánya','Tatabánya','HUNGARY','2800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 21:40:38',0,NULL,3,1,3,1,'RA184567864CN\r ','torokjanos\rMOSA004'),(13444,632328439013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','bmartin1219','basteon@comcast.net','brandon martin','1219 quakers way','quakertown','PA','UNITED STATES','18951-2783','(215) 536-8355','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 21:56:37',0,NULL,3,1,1,1,'\\ ','bmartin1219'),(13445,575710636003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',31.98,'cnfaner','lharvell73','live2pay@hotmail.com','LaSchon Harvell','4400 Birchtree Ln','Temple Hills','MD','UNITED STATES','20748-5733','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-10 21:56:50',0,NULL,3,1,1,1,'\\','lharvell73'),(13446,632335236013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','pumpkin_batman','dk_batman@yahoo.com','Jason Johns','C/-Aitken Partners<br>Level 1, 114 William Street','Melbourne','Victoria','AUSTRALIA','3000','0386006009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 22:22:08',0,NULL,3,1,3,1,'RA184565055CN\r ','pumpkin_batman\rOTES001'),(13447,575719283003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',64.99,'cnfaner','martin_fiset','teneighty_1080@hotmail.com','Martin Fiset','2211 St-Andrews way','Courtenay','BC','CANADA','V9N 9X9','(250) 792-1232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 22:31:21',0,NULL,3,1,3,1,'RA184567918CN\r ','martin_fiset\rMOSA003'),(13448,632351602013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','ed1957519','arcanoid8@hotmail.com','Edward Piecko','446 C  Shelley Dr','Kitchener','ON','CANADA','N2C 1N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 23:34:07',0,NULL,3,1,2,1,'\\  ','ed1957519'),(13449,777364973011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','wo1f1ing','wolfling@gmail.com','R.J. van der Heide','Elisabeth Wolffstraat 76 iii','Amsterdam','','NETHERLANDS','1053TW','(020)6897696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 23:48:47',0,NULL,3,1,2,1,'\\  ','wo1f1ing'),(13450,862131329012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','millermv','mickle75@gmail.com','Michael Miller','4555 N Channel Ave<br>Ste 160','Portland','OR','UNITED STATES','97217-7649','(360) 831-4939','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 00:14:18',0,NULL,3,1,1,1,'\\ ','millermv'),(13451,575741001003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','bgkerr','bgkerr@aol.com','brian kerr','10924 SW 27th Ave','Gainesville','FL','UNITED STATES','32608','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-11 00:21:11',0,NULL,3,1,1,1,'\\  ','bgkerr'),(13452,777384107011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',62.5,'eastar4','elaine913golf','putteron@aol.com','Elaine Newbold','16722 Canby Way','Broomfield','CO','UNITED STATES','80023-4643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 00:34:47',0,NULL,3,1,1,1,'\\  ','elaine913golf'),(13453,862145936012,220828314408,'GPS USB receiver w/SIRF3 chip sets +antenna',1,'GPS0001',45.99,'eastar4','tommegunne','dkkranch@earthlink.net','david  kranch','1038 briar ln','pottstown','PA','UNITED STATES','19464-2902','(610) 326-8971','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 01:01:08',0,NULL,3,1,1,1,'\\ ','tommegunne'),(13454,632389957013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','ves56','ves56@hotmail.com','Vincent E Schrader','26898 Startzman Rd','Arcadia','IN','UNITED STATES','46030-9528','(317) 219-3267','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-11 02:30:58',0,NULL,3,1,1,1,'\\  ','ves56'),(13455,629404069013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','dusttink','dusttink2@yahoo.com','Deborah Petersen','17519 Heaton Ct','Magnolia','TX','UNITED STATES','77355','(281) 356-2136','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 02:33:15',0,NULL,3,1,1,1,'\\ ','dusttink'),(13456,777419953011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','cooljage','jage32@gmail.com','Earl Bielinski','PO Box 26091','Wauwatosa','WI','UNITED STATES','53226-0091','(312) 213-8707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 02:44:04',0,NULL,3,1,1,1,'\\  ','cooljage'),(13457,777427240011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',96.99,'eastar4uk','888design','vpo@hotmail.co.uk','Mr Thomas schobesberger','352/202-203 M.12 Pratumnak Road<br>Nongprue','Banglamung','Chonburi','THAILAND','20150','0382501201','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 03:11:40',0,NULL,3,1,3,1,'RA184563085CN\r ','888design\rGLOT005*3 \r新地址\rMR THOMAS SCHOBESBERGER\r523-523,M.12 PRATUMNAK RD\rNONGPURE, BANGLAMUNG\rCHONBURI, THAILAND\r20150\r'),(13458,775448008002,120762768837,'2pair Samsung SSG-3100GB 3D Active Glasses 4 PC monitor',1,'GLSG007*2',156.99,'buysia','hawk0586431763','keiferhawk@yahoo.com','Yu Sakamoto','4-16-26,Tokugyo.505','Kofu','Yamanashi','JAPAN','400-0047','08065621435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 03:18:03',0,NULL,3,1,3,1,'RA184565038CN ','hawk0586431763\rGLSG007*2'),(13459,777431367011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','a.reible','areible@gmail.com','Amelia Reible','38 Colonial Hills Dr','Lillington','NC','UNITED STATES','27546-6203','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 03:29:04',0,NULL,3,1,1,1,'\\ ','a.reible'),(13460,777433271011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','bigmercier','mercier@doctornetwork.com','Chris Mercier','11115 Industriplex Blvd<br>Ste 800','Baton Rouge','LA','UNITED STATES','70809','(225) 802-2033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 03:39:07',0,NULL,3,1,1,1,'\\ ','bigmercier'),(13461,777433895011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','xsocietydwellerx','codog180@gmail.com','Cody Siegel','1451 Quail St<br>Ste 100','Newport Beach','CA','UNITED STATES','92660-2747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 03:40:50',0,NULL,3,1,1,1,'\\  ','xsocietydwellerx'),(13462,632407883013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','zocciasmom','sfvmoss@cox.net','Chris Campbell','11025 Vista Sorrento Pkwy<br>Homewood Suites/ Engineering Dept','San Diego','CA','UNITED STATES','92130-8202','(619) 977-3195','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 03:53:46',0,NULL,3,1,1,1,'\\ ','zocciasmom'),(13463,575783360003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','willywaygood','will@ozifresh.com.au','Will Waygood','PO Box 2001<br>Mansfield','Brisbane','Queensland','AUSTRALIA','4122','0412322230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 04:13:48',0,NULL,3,1,3,1,'RA184569967CN\r ','willywaygood\rMOOE002\r发OEM的'),(13464,657485703010,200658853016,'Samsung 3D Glasses SSG-3700CR  Active 2011 new  for samsung 3d led tv ',4,'',380,'dcsamsungmall','buysia','ebay@buysia.com','Bo Fang','Rm.104, Building 124,Nanhuxiyuan, Wangjing','BEI JING','北京','CHINA','100102','+86 13911173424','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 04:15:00',0,NULL,5,0,18,0,NULL,'buysia'),(13465,777461503011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','thelukester45','topnotchguy@gmail.com','Luke mahoney','4128 Alabama St<br>Apt 3','San Diego','CA','UNITED STATES','92104-7022','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 06:10:48',0,NULL,3,1,1,1,'\\  ','thelukester45'),(13466,777465033011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 06:39:27',0,NULL,3,1,2,1,'\\  ','germanskynet'),(13467,777468729011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','alexpkh','alexpkhmail@gmail.com','Aliaksandr Kharytonenka','Suhogo street, 3-134','Gomel, Belarus','','RUSSIAN FEDERATION','246035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 06:47:20',0,NULL,3,1,2,1,'\\ ','alexpkh\racer 4pin1.25 15cm '),(13468,862232931012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','squarc85','geradaniloff@mail.ru','Osetrov J.V.','B.Vasilyeva 4-3','Tambov','RUSSIAN FEDERATION','RUSSIAN FEDERATION','392000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 07:02:16',0,NULL,3,1,2,1,'\\ ','squarc85'),(13469,777477797011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',7.56,'eastar4','bookie284','pjgrant4@bigpond.com.au','Tim Grant','351 Coal Point Road','Coal Point','New South Wales','AUSTRALIA','2283','0249595161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 07:30:32',0,NULL,3,1,2,1,'\\ ','bookie284\r再发一Triple Tyco Universal Wireless Laptop Antenna Mini PCI\rANTY002\r'),(13470,632439154013,230611245572,'New Logitech Asus MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO004',43.89,'eastar4','compy_386','tomichp@msoe.edu','Peter Tomich','28596 W. Valley Rd.','Ingleside','IL','UNITED STATES','60041','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 07:33:37',0,NULL,3,1,1,1,'\\ ','compy_386\r华硕限量版'),(13471,862244438012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',35,'eastar4uk','247sara','sarafaulkner247@hotmail.com','will price','3 HADLEY COURT<br>COLERIDGE CRESCENT COLNBROOK','SLOUGH','-','UNITED KINGDOM','SL30PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 07:50:39',0,NULL,3,1,3,1,'RA184565015CN\r ','247sara\rBAZA001'),(13472,632443186013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',9.98,'eastar4','davidkiogho2011','amy_tiu@yahoo.com','David Ho','12F Crystal Bay Garden, Metropolitan Park Ave. Pasay City Philippines<br>12F Crystal Bay Garden, Metropolitan Park Ave. Pasay City Philippines','Pasay','NCR','PHILIPPINES','1300','+632556227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 08:04:12',0,NULL,3,1,2,1,'\\ ','davidkiogho2011'),(13473,862257536012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','matthewmckenzie1983','matthewmckenzie1983@hotmail.com','Matthew Mckenzie','39 Hampton Gardens','Pointe-Claire','QC','CANADA','H9s5b8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 08:42:51',0,NULL,3,1,2,1,'\\ ','matthewmckenzie1983'),(13474,8881318322647699,111,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',0,'eastar4uk','myszy667','mattt667@o2.pl','Bogumila Myszka','Ivington<br>Ivingtonbury','Leominster','Herefordshire','UNITED KINGDOM','HR6 0JH','',NULL,NULL,NULL,'2011-10-11 08:44:07',0,NULL,3,1,3,1,'RA184563054CN\r ','补发 一副 \rGLOT005'),(13475,777498360011,320721404615,'Transparent Dome Rain Sun Umbrella with pink trim',1,'UMTR001',19.99,'eastar4','vanditavalsan','vandita_valsan@yahoo.com','Vandita Valsan','2090 Southwest Expy<br>Apt 84','San Jose','CA','UNITED STATES','95126-4673','(408) 912-3306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 09:02:03',0,NULL,3,0,1,1,'\\ ','vanditavalsan\r粉红色的\r已入库'),(13476,859084279012,220826598356,'100% Brand New Original HP Wireless mobile 2.4G mouse ',1,'MOHP001',19.9,'eastar4','ravit_gal','ravit_gal@hotmail.com','ravit gal','93 nordau','Tel-Aviv','','ISRAEL','62496','972523353337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 09:08:41',0,NULL,3,1,2,1,'. ','ravit_gal'),(13477,632456578013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mlvidal05','chazyvidal@gmail.com','Marcelo Vidal','Rua Ana Silva, 100 - bl.01 - ap505','Rio de Janeiro','Rio de Janeiro','BRAZIL','22740300','55-21-33925460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 09:12:22',0,NULL,3,1,2,1,'. ','mlvidal05'),(13478,632461202013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','timmyf11','s12009@bigpond.com','tim','218 tucker rd','mckinnon','victoria','AUSTRALIA','3204','0412377072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 09:35:28',0,NULL,3,1,3,1,'RA184565302CN ','timmyf11\rGPS0004'),(13479,862283024012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','RANDY FISHMAN','OAK RIDGE NATIONAL LABORATORY<br>1 BETHEL VALLEY RD; BLDG. 4100; A369','Oak Ridge','TN','UNITED STATES','37831','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 10:14:25',0,NULL,3,1,1,1,'\\  ','321expressllc'),(13480,8881318328700712,111,'3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005',0,'eastar4uk','duluxmont21','duluxmont@msn.com','MYRIAM DUMONT','3 ROUTE DE DIJON','NUITS SAINT GEORGES','Bourgogne','FRANCE','21700','0380269891',NULL,NULL,NULL,'2011-10-11 10:25:00',0,NULL,3,1,3,1,'RA184563045CN\r ','补发的  一副\rGLOT005 '),(13481,862290293012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','daemoon_ua','daemoon@mail.ru','Nikolay Suvorov','Pirogovskaya st. 16 ap.9','Yalta','Crimea','UKRAINE','98604','+38-050-593-81-68','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:37:01',0,NULL,3,1,3,1,'RA184565245CN ','daemoon_ua\rWWOT003'),(13482,632474812013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','offchops37','offy_00@hotmail.com','Chris Booth','PO Box 26','Rosebery','Tasmania','AUSTRALIA','7470','0404491549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:43:24',0,NULL,3,1,3,1,'RA184565143CN ','offchops37\rMOSA004'),(13483,575851462003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',13.9,'cnfaner','lukyanov_alex','alexsat77@gmail.com','Alexander Lukyanov','ul. Vojkova, dom 25, kv. 103','Naro-Fominsk','Moscow region','RUSSIAN FEDERATION','143300','79099399099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 11:28:44',0,NULL,3,1,3,1,'RA184565231CN ','lukyanov_alex\rOMHJ001'),(13484,777545460011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',21.9,'eastar4uk','steph.bbmw','stephanbetzler@gmx.de','Daniela Unschuld','Stephanusstraße 23','Lehmen','','GERMANY','56332','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 11:45:49',0,NULL,3,1,2,1,'\\  ','steph.bbmw'),(13485,862319630012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','2011taxibob173','taxibob173@yahoo.com','robert dixon','17 streamside close','coventry','West Midlands','UNITED KINGDOM','cv59ff','02476633708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 12:08:46',0,NULL,3,1,3,1,'RA184565130CN\r ','2011taxibob173\rHSJA010\r英标'),(13486,777560304011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','dtaz666','taz666@live.fr','michel braz','763 av. Maréchal Alphonse Juin','SIX FOURS LES PLAGES','Provence-Alpes-Côte d\'Azur','FRANCE','83140','06.64.35.51.60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 12:31:34',0,NULL,3,1,2,1,'\\  ','dtaz666'),(13487,777561105011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','e2ks','edmundas.bruzas@gmail.com','Edmundas Bruzas','Kaminkelio g. 19 - 5','Vilnius','','LITHUANIA','LT-02192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 12:33:54',0,NULL,3,1,3,1,'RA184565214CN\r ','e2ks\rOTSA001'),(13488,777566404011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','artbear1','colleencrochet.davis@gmail.com','Colleen Davis','300 E 4th Ave','Truth Or Consequences','NM','UNITED STATES','87901','(575) 894-9375','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 12:50:33',0,NULL,3,1,1,1,'\\  ','artbear1'),(13489,777441649011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','dadget','dadget@gmail.com','Leonard Kenney','208 Foundation Ave','Laurel','MT','UNITED STATES','59044','(406) 628-0666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 13:24:07',0,NULL,3,1,1,1,'\\  ','dadget'),(13490,859110144012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','tt-rn','tbarnello@hotmail.com','Tricia Barnello','102 West Way','Camillus','NY','UNITED STATES','13031-1215','(315) 218-5121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 13:42:46',0,NULL,3,1,1,1,'\\  ','tt-rn'),(13491,777587005011,320737041206,'4 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*4',127.99,'eastar4uk','nicomelane45','carlinicolas@hotmail.fr','Carli Nicolas','2 Rue Vivaldi<br>Logement 31','Villemandeur','Centre','FRANCE','45700','0671088394','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 13:54:26',0,NULL,3,1,6,1,'EE491015825CN ','nicomelane45'),(13492,862338283012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',29.9,'eastar4','rewinhanrahan10','rewinhanrahan@yahoo.com','Rewin Hanrahan','Jalan Kelapa Sawit X, Blok BG 04/03<br>Sektor 1B, Gading Serpong','Tangerang','Banten','INDONESIA','15326','(6221) 542-03956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 14:20:10',0,NULL,3,1,2,1,'\\  ','rewinhanrahan10'),(13493,777600443011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','bpickle24','pickleninehundred@yahoo.ca','Bryan Pickle','47 Douglas AVE','Hamilton','ON','CANADA','l8l 5r1','(519) 839-5371 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 14:28:56',0,NULL,3,1,2,1,'\\ ','bpickle24'),(13494,777606292011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','bubakystorsky','romashka21@bellsouth.net','JOHN NOONAN','309 Battery Cres','SAVANNAH','GA','UNITED STATES','31410-1252','(912) 308-9112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 14:48:59',0,NULL,3,1,1,1,'\\  ','bubakystorsky'),(13495,581446345004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.9,'cnfaner','ceez_it','superceez@tiscalinet.it','PANATRONICS','Via Bruno Maderna, 8','Milano','MI','ITALY','20138','333-5690359','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 14:49:16',0,NULL,3,1,3,1,'RA184565174CN\r ','ceez_it\rWLDE002'),(13496,718555193008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','dxcup828','dexter.rillera@gmail.com','Dexter Rillera','Rm 5, 850 Pacific HWY','Chatswood','New South Wales','AUSTRALIA','2067','0425180005','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 14:52:06',0,NULL,3,1,3,1,'RA184565259CN\r ','dxcup828\rHSPL015\r澳标'),(13497,777616651011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','ramatyishai','robsacks25@gmail.com','Robert Sacks','25 Windsor Road','London','London','UNITED KINGDOM','N3 3SN','02083460533','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 15:14:00',0,NULL,3,1,3,1,'RA184565126CN ','ramatyishai\rHBPH002'),(13498,632389338013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','hind74','boughima_hind@yahoo.com','Hind Washington','3422 Cline St','Houston','TX','UNITED STATES','77020','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 15:15:36',0,NULL,3,1,1,1,'\\  ','hind74'),(13499,632544769013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','luckyc0w','luckycow@gmail.com','Tan Peng Seng','Block 310A<br>Anchorvale Road, #16-25','default','','SINGAPORE','541310','98559852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 15:28:06',0,NULL,3,1,3,1,'RA184565157CN ','luckyc0w\rMOSA004'),(13500,736074483001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','andreluiz','sicario_slackware@yahoo.com.br','André Luiz da Silva','Marquês de Caxias, 28<br>Apto. 201','Niterói','Rio de Janeiro','BRAZIL','24030050','55 (21) 2621-0676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 15:33:04',0,NULL,3,1,3,1,'RA184563125CN ','andreluiz\rBR3D005'),(13501,862402602012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','navagoshi','faichow7@hotmail.com','Fai Chow','Kragsbjergvej 71 , 3.tv.','Odense','','DENMARK','5000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 15:44:15',0,NULL,3,1,2,1,'\\  ','navagoshi'),(13502,777638121011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',3,'WLIN011+ANTY002',56.97,'eastar4','ro12009','ralf_ott@ich.ms','Ralf Ott','Thüngbacher Weg 13','Schlüsselfeld','','GERMANY','96132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 16:04:09',0,NULL,3,1,3,1,'RA184565191CN ','ro12009\rWLIN011+ANTY002'),(13503,632561416013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',33.16,'eastar4','eespi_703','eespi_703@t-online.de','Edmund Espiritu','Arndstr. 62a','Krefeld','','GERMANY','47829','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 16:24:11',0,NULL,3,1,2,1,'\\  ','eespi_703'),(13504,777649942011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','rlpmg','rr@cooley.com','Ricardo Rodriguez','1594 Wessex Ave','Los Altos','CA','UNITED STATES','94024-5716','(650) 938-7756','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 16:30:45',0,NULL,3,1,1,1,'\\  ','rlpmg'),(13505,862454748012,220455488077,'HP TX2500 TX2500z TX2z Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',9.88,'eastar4','taylormb74','mod187@gmail.com','Matthew B Taylor','18647 Pamwood Dr','Foley','AL','UNITED STATES','36535','(251) 747-5469','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 17:27:39',0,NULL,3,1,1,1,'\\  ','taylormb74\rHP 8pin 0.8 3cm'),(13506,777678700011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','rahucha','rahucha@hotmail.com','Rafael Ahucha','Villas del Este C/Playa de la Ballena 34','Cadiz','Andalucia/Cadiz/Jerez Frontera','SPAIN','11406','630420141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 17:30:53',0,NULL,3,1,2,1,'\\  ','rahucha'),(13507,736132672001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','stephen3869','marentette7@yahoo.com','Stephen Marentette','219 Joan Flood Dr.','Essex','ON','CANADA','N8M0A2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 17:49:24',0,NULL,3,1,3,1,'RA184565112CN ','stephen3869\rBR3D005'),(13508,777690726011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','adalberto9599','alto7819@msn.com','ADALBERTO VAZQUEZ','244 N QUEEN ST<br>SABVI','LANCASTER','PA','UNITED STATES','17603-3512','(717) 823-3879','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 17:53:30',0,NULL,3,1,1,1,'\\  ','adalberto9599\r红边优联'),(13509,717058921008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','wardelder','ward@eldersoft.ca','Ward Elder','Creswin Properties Ltd.<br>590 - 201 Portage Ave','Winnipeg','MB','CANADA','R3B3K6','(204) 791-7754','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 17:58:41',0,NULL,3,1,3,1,'RA184565188CN ','wardelder\rSCLO001'),(13510,777709367011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','nil_nilich','nill@inbox.lv','Kirills Galikins','Klaipedas 106-1','Liepaja','Kurzeme','LATVIA','LV-3416','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 18:25:03',0,NULL,3,1,2,1,'\\  ','nil_nilich\r欧标'),(13511,718653945008,180699062113,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',1,'GLOT001',44.99,'au-buy','jorgep777','jorgeperez_777@hotmail.com','jorge perez','GENERAL HORNOS 950','capital federal','buenos aires','ARGENTINA','1772','(011)1558841339','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 18:27:49',0,NULL,3,1,3,1,'RA184565228CN ','jorgep777\rGLOT001\r兼容型3D眼镜 通用型'),(13512,777731968011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','vanbatenburg','gvbatenburg@belgacom.net','Geert van Batenburg','Schransweg 46','Wommelgem','','BELGIUM','2160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 19:06:46',0,NULL,3,1,2,1,'\\  ','vanbatenburg'),(13513,632636651013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','ikrammer0407','ikrammer@013net.net','itzhak krammer','hanita 12<br>neve-sheanan','haifa','israel','ISRAEL','32440','0523076161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 19:33:56',0,NULL,3,1,2,1,'\\  ','ikrammer0407'),(13514,632638197013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','vovadnepr2011','vovadnepr@gmail.com','Volodymyr Gadiatskyi','Huli Koroliovoi str<br>13/72','Dnipropetrovsk','Dnipropetrovsk','UKRAINE','49051','380632495316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 19:43:20',0,NULL,3,1,2,1,'\\  ','vovadnepr2011'),(13515,632648384013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.39,'eastar4','1380dave','dave.ching@tema.toyota.com','Dave Ching','14221 Cedarwood St','Westminster','CA','UNITED STATES','92683-4448','(310) 787-5632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 20:04:06',0,NULL,3,1,1,1,'\\ ','1380dave\racer 4pin1.25 15cm '),(13516,777773431011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','adnexa','enagoski@gmail.com','Emily Nagoski','81 Bridge St','Northampton','MA','UNITED STATES','01060-2414','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 20:15:43',0,NULL,3,1,1,1,'\\  ','adnexa'),(13517,862562783012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','admiller21','amiller21@btinternet.com','Andrew Miller','28 Pantain Road','Loughborough','Leicestershire','UNITED KINGDOM','LE113NA','01509210060','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 20:20:49',0,NULL,3,1,3,1,'RA184565205CN ','admiller21\rOTGR001'),(13518,862565162012,220692197076,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',29.9,'eastar4','wgalus2010','wieslaw25@gmail.com','EUTHERM Sp. z o.o. Wiesław Galus','Poznanska 129/133','Ozarow Mazowiecki','mazowieckie','POLAND','05-850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 20:26:33',0,NULL,5,1,18,1,NULL,'wgalus2010 \r 已退款'),(13519,736232448001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','onno7616','ononator@gmail.com','onno van Gurp','Burgemeester van Haarenlaan 788','Schiedam','','NETHERLANDS','3119GV','010 4709376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 21:03:54',0,NULL,3,1,3,1,'RA184565165CN\r ','onno7616\rBR3D008'),(13520,777810178011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','david_aguillard','davidaguillard@hotmail.com','David Aguillard','1111 S Washington St','Lafayette','LA','UNITED STATES','70501-6719','(337) 303-5050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 21:29:48',0,NULL,3,1,1,1,'\\  ','david_aguillard'),(13521,777816089011,320737041206,'4 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*4',127.99,'eastar4uk','jnns89','astrom89@hotmail.com','Jens Åström','Frejgatan 1','Boden','Norrbotten','SWEDEN','96133','+46702937768','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 21:44:35',0,NULL,3,1,6,1,'EE491015839CN ','jnns89'),(13522,777823148011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',4,'TRMX001',30.28,'eastar4','allan.olsson','olsson@denver.navy.mil','Allan Olsson','2119 N 600 W','Pleasant Grove','UT','UNITED STATES','84062-9251','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 22:02:37',0,NULL,3,0,1,1,'\\  ','allan.olsson\r已入库'),(13523,777840606011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','fisky7000','n.fisk@pgrad.unimelb.edu.au','Nick Fisk','c/o Rizzacasa Group, Bio21 Institute<br>30 Flemington Road','Parkville','Victoria','AUSTRALIA','3052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 22:58:08',0,NULL,3,1,2,1,'\\  ','fisky7000'),(13524,777854603011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','prockey111','j.e.hamer@web.de','Bettina Kimpfbeck','Westerwaldstr. 19 A','Ehringshausen-Greifenthal','','GERMANY','35630','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 23:46:48',0,NULL,3,1,2,1,'\\  ','prockey111\r欧标'),(13525,632722650013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','fourgirlsmom','mksmitty@aol.com','Mary Smith','130 Winchester Drive','Savannah','GA','UNITED STATES','31410','(912) 897-3468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 00:35:17',0,NULL,3,1,1,1,'\\  ','fourgirlsmom'),(13526,777902863011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','mattlessins','mlessins@gmail.com','Matthew Lessins','4565 Middleton Dr','West Bloomfield','MI','UNITED STATES','48323-3640','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 02:42:25',0,NULL,3,1,1,1,'\\  ','mattlessins'),(13527,581642442004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',2,'HSPL002',25.96,'cnfaner','brightjosh10','rockstarbabybrightx2@gmail.com','Albright Abronomah','154 Barnsfield Ct','Gaithersburg','MD','UNITED STATES','20878-2720','(301) 355-5705','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 02:52:43',0,NULL,3,1,1,1,'\\  ','brightjosh10'),(13528,0,220871183811,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',20.5,'eastar4','mikestack2248','mjtm25@earthlink.net','Michael Stack','7800 W Higgins Rd<br>Apt A','CHICAGO','IL','UNITED STATES','60631-3347','(773) 718-5624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 02:55:41',0,NULL,3,1,1,1,'\\  ','mikestack2248'),(13529,0,130585830555,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',9.99,'cnfaner','pardeep.balyan82','pardeep.balyan@gmail.com','pardeep kumar','3/290 wood st<br>preston,vic-3072','melbourne','Victoria','AUSTRALIA','3072','0433030782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 03:04:23',0,NULL,3,1,3,1,'RA184565280CN ','pardeep.balyan82\rHSPL001'),(13530,0,220871184695,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','hidayatkassim','dayat710@hotmail.com','Hidayat Kassim','Lot 6052 Spg 91-22 Jln Setia Pahlawan','Kuala Belait','','BRUNEI DARUSSALAM','KA 1931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 03:06:47',0,NULL,3,1,2,1,'\\  ','hidayatkassim'),(13531,632759329013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','shoppingandbuying2011','shoppekonto@gmail.com','Stig Hertaas','krokstien 4b','oslo','','NORWAY','0672','+47 47887979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 03:25:43',0,NULL,3,1,2,1,'\\  ','shoppingandbuying2011'),(13532,0,320772362002,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',6.99,'eastar4','luedkejd','matthew.luedke@gmail.com','Matthew Luedke','545 W Katelyn Ln','Spokane','WA','UNITED STATES','99224-8452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 03:25:46',0,NULL,3,1,1,1,'\\  ','luedkejd'),(13533,777914109011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','pga-west','trpga@aol.com','Terry Rennhack','80248 Via Tesoro','La Quinta','CA','UNITED STATES','92253-9062','(760) 619-3810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 03:29:23',0,NULL,3,1,1,1,'\\  ','pga-west\r新地址\rTerry Rennhack\r21613 10th Ct SE\rBothell, Wa 98021\rUNITED STATES\r(760) 619-3810\r'),(13534,632762505013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','kyle81107','kyle.reist@gmail.com','Kyle Reist','2682 Orchid Dr','Richardson','TX','UNITED STATES','75082-4246','(903) 742-1797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 03:43:53',0,NULL,3,1,1,1,'\\  ','kyle81107'),(13535,576102934003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.99,'cnfaner','ju-vines','ju_vines4@yahoo.com','Julius Vines','2324 Mcilwraith st','Muskegon Heights','MI','UNITED STATES','49444-1629','(231) 578-9949','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 04:09:35',0,NULL,3,1,1,1,'\\  ','ju-vines'),(13536,736357415001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','nitronest24','m6marshall1@wmich.edu','mike marshall','813 W Lovell St<br>Apt 110B','kalamazoo','MI','UNITED STATES','49007-4554','(616) 292-1935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 05:21:28',0,NULL,3,1,1,1,'\\  ','nitronest24'),(13537,576114149003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.99,'cnfaner','wcs6000','wcs6000@aol.com','West Coast Security Service','336 Cambridge Street','San Francisco','CA','UNITED STATES','94134','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 05:32:09',0,NULL,3,1,1,1,'\\  ','wcs6000'),(13538,0,230684151352,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',4,'eastar4','drontus11','drontus@gmail.com','Andrey Vorobev','pr.Vernadskogo d.127 kv.98','Moscow','Moscow','RUSSIAN FEDERATION','119571','79261114499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 05:38:11',0,NULL,3,1,2,1,'\\  ','drontus11'),(13539,8881318401116315,111,'NEW Ralink RT2870F Wi-Fi USB Adapter chip WIS09ABGN',2,'OTRA003',71.98,'eastar4','calpvera','capvera@gmail.com','Albano Perdiguero','Av. Escalada 4215 8? H','Buenos Aires','','ARGENTINA','1439','005491164999474',NULL,NULL,NULL,'2011-10-12 06:31:56',0,NULL,3,1,3,1,'RA184565523CN\r ','OTRA003 '),(13540,777945055011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',93.99,'eastar4uk','tiluka86','atesz-86@hotmail.com','Attila Nagy','18 Tünde<br>str.','Nyíregyháza','Szabolcs-Szatmár-Bereg megye','HUNGARY','4405','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 06:40:14',0,NULL,3,1,3,1,'RA184565510CN\r ','tiluka86\rGLSG001*3'),(13541,581676450004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',13.09,'cnfaner','ugur4066','ugulcu@yahoo.com','emniyet amirligi','ilce emniyet amirligi<br>kargi','corum','','TURKEY','19900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 06:59:52',0,NULL,3,1,3,1,'RA184565537CN\r ','ugur4066\r欧标\rHSNO006'),(13542,777955584011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','1kokoman','eokojie@ymail.com','Emanuel Okojie','6454 Van Nuys Blvd<br>Ste 150','Van Nuys','CA','UNITED STATES','91401-1407','(818) 299-6816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 07:09:37',0,NULL,3,1,1,1,'\\  ','1kokoman'),(13543,8881318403969433,111,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.9,'cnfaner','moupin','godwinz@gmail.com','Phutphornxai LUANGLATH','094/1 Sisavath Kang VillagePO BOX 961','Chanthabuly Vientiane','Capital','LAOS','10000 ','',NULL,NULL,NULL,'2011-10-12 07:19:29',0,NULL,3,1,3,1,'RA184563108CN ',' 这票没有下来\rWLDE001'),(13544,0,230684147419,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',8.49,'eastar4','wrickout','sk3tch@lgc.hu','Ákos Emericzy','Nagymező utca 21.','Budapest','Budapest','HUNGARY','1065','+36209823733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 07:22:18',0,NULL,3,1,2,1,'\\  ','wrickout'),(13545,777960766011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','seanxs2','obryan@bigpond.net.au','Sean O\'Bryan','241/4 Bechert Road','Chiswick','New South Wales','AUSTRALIA','2046','0297123623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 07:34:40',0,NULL,3,1,2,1,'\\  ','seanxs2'),(13546,632803477013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',16.58,'eastar4','genkos3','drienkop@gmail.com','Peter Drienko','Janskeho 29/24','Ziar nad Hronom','','SLOVAK REPUBLIC','965 01','+421907818948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 08:26:43',0,NULL,3,1,2,1,'\\  ','genkos3'),(13547,632793240013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',13,'CASS001',107.77,'eastar4','ifthikarraheem1','ifthikarraheem@yahoo.com','Ifthikar Raheem','562/15B<br>Lower Bagathalle Road','Colombo 03','Western','SRI LANKA','00300','+94777322893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 08:30:45',0,NULL,3,1,3,1,'RA184565608CN\r ','ifthikarraheem1\rCASS001'),(13548,777992053011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','benjaminvandenberg','benjamin_vandenberg@hotmail.com','benjamin van den berg','burg. visserweg 34','ijsselmuiden','OV','NETHERLANDS','8271 CP','038-3317419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 09:36:05',0,NULL,3,1,2,1,' \\ ','benjaminvandenberg'),(13549,777998793011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','mr.daweed','david6670@gmail.com','David Gyimesi','21 Torvenyhaz st.','Eger','Heves','HUNGARY','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 10:01:25',0,NULL,3,1,2,1,' \\ ','mr.daweed'),(13550,862807426012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','deuterium','trevor.ostrander@gmail.com','Trevor Ostrander','B102-5212 48th Street<br>Suite 232','Red Deer','AB','CANADA','T4N 7C3','(403) 307-8787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 10:12:34',0,NULL,3,1,2,1,' \\ ','deuterium');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (13551,736423820001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',15.99,'buysia','t4et1c','dannysbhoys67@aol.com','danny mahoney','290 wimborne road<br>oakdale','poole','dorset','UNITED KINGDOM','bh15 3ef','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 10:29:15',0,NULL,3,1,3,1,'RA184563139CN\r ','t4et1c\rBR3D005'),(13552,778011592011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','japaneze_pl','japaneze@tlen.pl','Marek Malik','Laska 12','Pabianice','','POLAND','95-200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 10:55:31',0,NULL,3,1,2,1,' \\ ','japaneze_pl\r旧的\r黑色的  欧标'),(13553,0,220871181728,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.04,'eastar4','arpy222','arpad.boros@gmail.com','Boros Arpad','Irinyi Jozsef u. 42.','Budapest','','HUNGARY','1117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 11:12:38',0,NULL,3,1,2,1,' \\ ','arpy222'),(13554,778020292011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','alexchikoff','alex.chikoff@gmail.com','ALEXEY CHIKOV','Fontanka river 139 31','St. Petersburg','','RUSSIAN FEDERATION','190068','+79213435815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 11:15:01',0,NULL,3,1,2,1,'\\  ','alexchikoff\r欧标'),(13555,778026486011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','hupfrey1974','konsto@tele2.at','Konrad Stogart','Theodor-Körner-Gasse 12/4','Wien','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 11:33:50',0,NULL,3,1,2,1,'\\  ','hupfrey1974'),(13556,862836097012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','sismanidis','book@otenet.gr','DIMITRIS SISMANIDIS','N.XILI MAKRIS 20<br>ALEXANDROUPOLIS','ALEXANDROUPOLIS','ALEXANDROUPOLIS','GREECE','68100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 11:41:34',0,NULL,3,1,2,1,' \\ ','sismanidis\r欧标'),(13557,576185902003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','kristianfryd','kristianfrydstad3@gmail.com','kristian frydstad','seljeholtet 16<br>9912 hesseng','kirkenes','WY','NORWAY','9912','+4793829725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 12:31:58',0,NULL,3,1,3,1,'RA184569922CN\r ','kristianfryd\rMOOE002\r发OEM的'),(13558,778045254011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','lnozdrin','izmaylovo5@yandex.ru','Leonid Nozdrin','Privolnaya, 5/3 - 600','Moscow','','RUSSIAN FEDERATION','109145','926-587-4540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 12:32:21',0,NULL,3,1,2,1,' \\ ','lnozdrin'),(13559,862857523012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','mywebsrus','mywebsru@yandex.ru','Mihail  Danilkevich','Mojayskoye shosse, 31, 198','Moscow','Moscow','RUSSIAN FEDERATION','121471','(903) 973-6774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 12:45:18',0,NULL,3,1,2,1,' \\ ','mywebsrus'),(13560,778053192011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','dunc623b','dunc@lemonia.org','Duncan Lockwood','19 Wallace Road','Loughborough','Leicestershire','UNITED KINGDOM','LE11 3NU','07875027939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 12:57:46',0,NULL,3,1,3,1,'RA184565925CN\r ','dunc623b\rTRTS001*10'),(13561,862865447012,220785819830,'NIB 3D Active Shutter TV Glasses 4 Mitsubishi Japan TV',1,'GLOT001',44.89,'eastar4','davidtrevor21','d.a.reinke77@hotmail.com','david reinke','33729 crystal springs rd','Grand Rapids','MN','UNITED STATES','55744-4944','(218) 326-7943','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 13:03:35',0,NULL,3,1,1,1,'、 ','davidtrevor21\r兼容型3D眼镜 通用型'),(13562,632861029013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','mic007tan','mic007tan@gmail.com','michael Tan','P.O.BOX 67','SERIA','SERIA','BRUNEI DARUSSALAM','KB1190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:12:22',0,NULL,3,1,3,1,'RA184565758CN\r ','mic007tan\rBAZA001'),(13563,581745318004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','yusuke345','you-ko1002@hotmail.co.jp','yusuke kondo','nishiarai<br>6-12-7-107','adachi-ku','Tokyo','JAPAN','123-0841','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:15:24',0,NULL,3,1,3,1,'RA184565744CN\r ','yusuke345\rHSPL015'),(13564,862881050012,220815931195,'New Logitech/Asus Limit MX518 MX 518 Gaming mouse USB',1,'MOLO004',26.5,'eastar4uk','cater903','jamiecater@hotmail.co.uk','Jamie Cater','29 Marlfield road<br>Hale barns','Manchester','Cheshire','UNITED KINGDOM','WA15 0SB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-12 13:45:32',0,NULL,3,1,3,1,'RA184565775CN\r ','cater903\rMOLO004\r华硕限量版'),(13565,862883646012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','vinch22','vincentgbzh@accessmastercard.fr','Vincent GUILLEMIN','Résidence La Haute Rive - Bat B<br>Bat B - Appt 106','22300','Bretagne','FRANCE','LANNION','0687441550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 13:51:31',0,NULL,3,1,3,1,'RA184565850CN\r ','vinch22\rGLOT004\r兼容型3D眼镜  samsung 专用'),(13566,778073284011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',9.88,'eastar4','carbobby549','santech@netzero.net','arvind singh','1604 chapala way','modesto','CA','UNITED STATES','95355','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 13:52:36',0,NULL,3,1,1,1,' \\ ','carbobby549\racer 4pin1.25 6cm'),(13567,574247998003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','fiesty3594','fiestyforever@yahoo.com','Erica Williams','PO Box 1360<br>55 Flynt Street','Metter','GA','UNITED STATES','30439-4563','(912) 687-3661','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 14:16:28',0,NULL,3,1,1,1,' \\ ','fiesty3594'),(13568,862894168012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dumkatfun','katllyn@yahoo.com','diana llewellyn','8033 Ridgeview Dr','des moines','IA','UNITED STATES','50320-6850','(917) 701-3478','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 14:19:26',0,NULL,3,1,1,1,' \\ ','dumkatfun'),(13569,778111673011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','wthstr','nekam76@gmail.com','Daniel Wojtas','4243 w Diversey ave','Chicago','IL','UNITED STATES','60639-2002','(312) 404-0701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 15:31:55',0,NULL,3,1,1,1,' \\ ','wthstr'),(13570,778122171011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','keks281','keksy05@hotmail.com','sebastian kuspisz','202  Collins  St','Thornbury','Victoria','AUSTRALIA','3071','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 15:59:03',0,NULL,3,1,2,1,' \\ ','keks281'),(13571,632908637013,230653156192,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',46.99,'eastar4','wksoo1','wksoo2@gmail.com','soo weng keong','50-17-5 taman yew lean,<br>jalan slim.','georgetown','penang','MALAYSIA','11600','0124800172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 15:59:08',0,NULL,3,1,3,1,'RA184565982CN\r ','wksoo1\rHSIT001'),(13572,778133330011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','chrismumof6','chrisyates6@hotmail.co.uk','Chris Yates','8 Usk Road<br>Llanishen','Cardiff','The Vale of Glamorgan','UNITED KINGDOM','CF14 0NN','7967313119','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-12 16:21:18',0,NULL,3,1,2,1,' \\ ','chrismumof6\r向日葵三折叠伞 '),(13573,576253547003,130583982411,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',14.9,'cnfaner','awesome_g','mastergprod@aol.com','Gerald  Glass','19323 Ohio St','Detroit','MI','UNITED STATES','48221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 16:56:38',0,NULL,3,1,1,1,' \\ ','awesome_g'),(13574,778155894011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','oliv5568','o.austin@lectra.com','Sté LECTRA - M. Olivier AUSTIN','16-18, rue Chalgrin','PARIS','Ile-de-France','FRANCE','75016','06 80 74 71 45','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:09:19',0,NULL,3,1,2,1,' \\ ','oliv5568'),(13575,862976064012,220826626639,'New Genuine DENON RC-1050 Remote Control RC 1050',1,'RCDE003',19.99,'eastar4uk','voncheechandchong','alibensoul@gmx.de','Galip Alemdag','Habichtweg 4','Elmsorn','','GERMANY','25337','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 17:12:13',0,NULL,3,1,2,1,' \\ ','voncheechandchong'),(13576,576259468003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',48.9,'cnfaner','anona10','andrew_1@live.com','A A','FLAT 2<br>88 ST. GEORGE\'S WAY','LONDON','London','UNITED KINGDOM','SE15 6QT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:14:29',0,NULL,5,0,18,0,NULL,'anona10\r撤单  已退款'),(13577,576271928003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',21.9,'cnfaner','j_l_p','juergen.schneider@auge.de','Jürgen Schneider','untere Bärenbergstraße 13','Bartholomä','','GERMANY','73566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:49:25',0,NULL,3,1,3,1,'RA184565789CN\r ','j_l_p\rWLIN016'),(13578,632947834013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',9.98,'eastar4','vavashop','virginia.rawls@yahoo.com','Virginia Rawls','3918 Pulley Ct','VIRGINIA BEACH','VA','UNITED STATES','23452-2374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 17:56:17',0,NULL,3,1,1,1,' \\ ','vavashop'),(13579,632924242013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','amkan','lvegasdesert@gmail.com','amit kantaria','10788 fairfield ave','las vegas','NV','UNITED STATES','89183','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 18:15:05',0,NULL,3,1,1,1,'、 ','amkan\r黑色的'),(13580,632960243013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','rengeniuss','rengenius@gmail.com','Dmitriy Donich','Vishnyakovskiy per. 27-1','Moscow','MSK','RUSSIAN FEDERATION','119017','79104852422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 18:16:49',0,NULL,3,1,2,1,' \\ ','rengeniuss'),(13581,778195119011,320756093124,'New Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','zac34p','info@astrofegia.com','Zacharias C.  Papadopoulos','Dimokratias 66<br>Ayia Marina Polis Chrysochous','Paphos','','CYPRUS','8881','+357-2681 2706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 18:20:29',0,NULL,3,1,3,1,'RA184565761CN\r ','zac34p\rMOLO008\r红色的'),(13582,778202149011,320730086487,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',3.99,'eastar4uk','omg_wtf_pete','pethanger1@hotmail.com','Peter S Hansen','8 Brenzi Court Spearwood','Perth','Western Australia','AUSTRALIA','6163','0894349891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 18:30:48',0,NULL,3,1,2,1,' \\ ','omg_wtf_pete'),(13583,863042521012,220815928236,'GENUINE Plantronics Voyager 851/855 Bluetooth headset',1,'HSPL017',21.99,'eastar4uk','furyest','fury8@abv.bg','tihomir fartunov','prespa10 et7 ap54','Plovdiv','','BULGARIA','4006','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 18:58:40',0,NULL,5,0,18,0,NULL,'furyest\r客户要求撤单\r已退款\r'),(13584,719135616008,180727201562,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',19.99,'au-buy','atari001','atari0001.ebay@ntlworld.com','M J Clatworthy','120 Burton Old Road East','Lichfield','Staffordshire','UNITED KINGDOM','WS14 9HU','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 19:15:32',0,NULL,3,1,3,1,'RA184565660CN\r ','atari001\rSCLO001'),(13585,632984816013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',3,'UM00033',59.97,'eastar4','f0luche','fduche@gmail.com','Alexey Khvatov','n. r. Fontanki 77 kv. 44','Saint-Petersburg','Russia','RUSSIAN FEDERATION','191023','+7 911 711-3028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 19:18:59',0,NULL,3,1,3,1,'RA184565846CN\r ','f0luche\rUM00033\r韩版透明伞\r一把彩点  的   一把可爱猫的  一把红心的'),(13586,630492844013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','foozool23','foozool23@yahoo.com','Novaj Javidzad','2834 Colorado Ave<br>Ste 56','Santa Monica','CA','UNITED STATES','90404-3660','(310) 720-1619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 19:29:49',0,NULL,3,1,1,1,'、 ','foozool23\r黑色的'),(13587,778217702011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'eastar4','angwolf_79','angwolf@mail.ru','Vitaly Goryaynov','Angliyskiy prospekt<br>58-36','Sankt-Petersburg','','RUSSIAN FEDERATION','190008','981-761-9848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 18:57:53',0,NULL,3,1,2,1,' \\ ','angwolf_79\r欧标'),(13588,778236129011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','tommieboylaughlin','carterthomasl@q.com','Thomas Carter','849 E 1000 S','Orem','UT','UNITED STATES','84097-6626','(801) 225-5842','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 19:35:12',0,NULL,3,1,1,1,' \\ ','tommieboylaughlin'),(13589,863073286012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','chipperiszbest','stephaneraynaud@yahoo.com','Stephane Raynaud','330 Metcalfe St, #405','ottawa','ON','CANADA','k2p1s4','(613) 598-0148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 19:45:17',0,NULL,3,1,3,1,'RA184563156CN\r ','chipperiszbest\rGLOT005*2'),(13590,778252099011,320730087674,'New Logitech Digital IO Writing Pen +IO notebook',1,'NTLO001+NTLO002',23.99,'eastar4uk','kutnarova','horice@centrum.cz','Renata Bejstova','Dukelskych hrdinu 288','Velky Osek','Velky Osek','CZECH REPUBLIC','28151','00420608156383','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 19:54:29',0,NULL,3,1,2,1,' \\','kutnarova'),(13591,863084332012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',15.95,'eastar4','ii343hbka','iie4ehbka@live.ru','Denis Batishchev','2 Shalandina street, app. 54','Belgorod','BELGOROD REGION','RUSSIAN FEDERATION','308034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 20:05:05',0,NULL,3,1,2,1,' \\ ','ii343hbka'),(13592,779084509002,120791889572,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','qwimble','ajax_fan1991@hotmail.com','Arend Steenbeek','De Hoep 6','HOMMERTS','','NETHERLANDS','8622XL','0515443024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 20:34:51',0,NULL,3,1,3,1,'RA184565979CN\r ','qwimble\rHSBS002'),(13593,860295158012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','mkal4776','yasin_78@hotmail.co.uk','mohammed kalu','47 princes street','nuneaton','Warwickshire','UNITED KINGDOM','cv11 5nw','07863218220','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-12 20:36:10',0,NULL,3,1,3,1,'RA184565735CN\r ','mkal4776\r英标\rHSPL011'),(13594,581890319004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'cnfaner','nemrak0918','nemrak918@gmail.com','Karmen Tso','21 Knowlman Avenue<br>Pymble','Sydney','New South Wales','AUSTRALIA','2073','0294400152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 20:49:01',0,NULL,3,1,3,1,'RA184565801CN\r ','nemrak0918\rHBPH003'),(13595,778289580011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','andiase23','andiase@videotron.ca','Diane Cyr','889 rue des Cormiers','St-Jean-Chrysostome','QC','CANADA','G6Z 3B1','(418) 834-2581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 21:08:49',0,NULL,3,1,3,1,'RA184565713CN\r ','andiase23\rOTSA001'),(13596,863128659012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','ruijed','ruijede@hotmail.com','Rui David','Rua de Matarraque, Nº458, 2ºFt.','Zambujal','S Domingos de Rana','PORTUGAL','2785-696','351967769744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 21:24:49',0,NULL,3,1,3,1,'RA184563434CN  ','ruijed\rGLOT001\r兼容型3D眼镜 通用型'),(13597,575358956003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',42.99,'cnfaner','kawazmiles','breizhcelt@hotmail.fr','COINTEMENT ANTHONY','9 BIS RUE SAINT ANTOINE<br>CHICHY','HAUTERIVE (CHICHY)','Bourgogne','FRANCE','89250','0642330057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 21:29:34',0,NULL,3,1,3,1,'RA184569936CN\r ','kawazmiles\rMOOE002\r发OEM的'),(13598,863131804012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','erider99','gbs999@gmail.com','Greg Sahlberg','1917 E Evergreen Blvd','Vancouver','WA','UNITED STATES','98661-4236','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 21:31:15',0,NULL,3,1,1,1,' \\ ','erider99'),(13599,633041202013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','joe40*11','reidjoseph95@yahoo.com','JOSEPH REID','2511 NW 56th Ave<br>Apt 102','LAUDERHILL','FL','UNITED STATES','33313-2446','(954) 625-0662','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 21:46:47',0,NULL,3,1,1,1,' \\ ','joe40*11'),(13600,576358315003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',38.79,'cnfaner','plea8234','greeneyes3669@gmail.com','Peggy Leadbetter','2053 University Commons','Massillon','OH','UNITED STATES','44646','(330) 904-7494','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 21:53:57',0,NULL,3,1,1,1,' \\ ','plea8234'),(13601,633049053013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 22:16:49',0,NULL,3,1,2,1,' \\ ','germanskynet\r华硕 8pin 1.0 6cm '),(13602,576358784003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','stanleyms521','stanleyms521@yahoo.com','Stanley Schubert','4021 Gifford Ave','Cleveland','OH','UNITED STATES','44109-3945','(216) 401-5985','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-12 21:59:13',0,NULL,3,1,1,1,' \\ ','stanleyms521'),(13603,778347847011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','rpai2458','roykenneth@netzero.net','Roy Painter','57386 Quail Run Blvd','New Haven','MI','UNITED STATES','48048-2955','(586) 265-7155','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 00:05:36',0,NULL,3,1,1,1,' \\ ','rpai2458'),(13604,778360125011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','goodiesmart','hapyface07@yahoo.com','Certifit/Bruce Nguyen','4609 Van Epps Rd','Brooklyn Heights','OH','UNITED STATES','44131-1042','(216) 739-5000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 00:43:32',0,NULL,3,1,1,1,' \\ ','goodiesmart'),(13605,778362051011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','meatball0_5','gmasioli@vianet.on.ca','Greg Mascioli','659 Tamrack Street','Timmins','ON','CANADA','P4N6S2','(705) 267-6885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 00:51:49',0,NULL,3,1,2,1,' \\ ','meatball0_5'),(13606,778365883011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ykim85','ykim514@yahoo.com','Young Kim','411 Eve Cir','Placentia','CA','UNITED STATES','92870-4703','(949) 331-3948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 01:05:00',0,NULL,3,1,1,1,' \\ ','ykim85'),(13607,581947343004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','bridget48','bridget48@msn.com','Bridget  Day','13 Arrow Head Ln','Somerset','NJ','UNITED STATES','08873-4646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 01:12:47',0,NULL,3,1,1,1,' \\ ','bridget48'),(13608,633091295013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','rbfenton01','gartonone@optusnet.com.au','Bruce Fenton','7 Hudson St','HAMPTON','Victoria','AUSTRALIA','3188','0395020095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 01:33:23',0,NULL,3,1,3,1,'RA184569940CN\r ','rbfenton01\rGPS0004'),(13609,778375445011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','123gwh','kopfamily@comcast.net','ALBERT KOPESKY','9014 Ensemble Ct','HOUSTON','TX','UNITED STATES','77040-2478','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 01:41:11',0,NULL,3,1,1,1,' \\ ','123gwh'),(13610,778384116011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',24.99,'eastar4','artsyhas','havvas@rogers.com','Havva Seydali','75 Northampton Street','Brampton','ON','CANADA','l6s 3z7','(905) 453-0009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 02:09:38',0,NULL,3,1,2,1,' \\ ','artsyhas'),(13611,778390410011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',115.99,'eastar4','richard7889wife','ralvey@comcast.net','Richard Alvey','976 Voboril Ave','Yuba City','CA','UNITED STATES','95991-5759','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 02:34:17',0,NULL,3,1,1,1,' \\ ','richard7889wife'),(13612,778390764011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','ronzues','ronzues@comcast.net','Ron Anderson','1204 Beautiful Valley Ct','Nashville','TN','UNITED STATES','37221-6582','(615) 673-2691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 02:35:42',0,NULL,3,1,1,1,' \\ ','ronzues'),(13613,863246339012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.39,'eastar4uk','stuartw253','stu_wallace4@hotmail.com','stuart wallace','4 Ryedale','Guisborough','Cleveland','UNITED KINGDOM','TS148JE','01287203919','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 03:31:58',0,NULL,3,1,3,1,'RA184565792CN\r ','stuartw253\rCALO001'),(13614,778405045011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','whopr','nrheeman@yahoo.com','Nicholas Rheeman','804 Terra Bella','Irvine','CA','UNITED STATES','92602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 03:37:38',0,NULL,3,1,1,1,' \\ ','whopr'),(13615,8881318481069705,111,'2.4GHz 2.4G Wireless Rii Mini PC Keyboard with Touchpad',1,'',0,'eastar4','zik-kislota','zik2004@hotmail.com','Dmitri Ponomarjov','Ehitajate-tee<br>45-68','Tallinn','','ESTONIA','12613','+37258382911',NULL,NULL,NULL,'2011-10-13 04:44:29',0,NULL,3,0,2,1,' \\ ','只补发一个USB线 '),(13616,778426465011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',184.99,'eastar4','joshcha06','ashley@chadwickmerch.com.au','ashley mrocki','27 fiveways boulevard<br>keysborough','melbourne','Victoria','AUSTRALIA','3173','0410421496','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 05:37:24',0,NULL,3,1,3,1,'RA184566002CN\r ','joshcha06\rOTSO004*3'),(13617,778430814011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','bay_v_korsar','v_korsar@mail.ru','Viktor Kleymenov','3 Parkovaya d.30 kv.39','Moscow','Москва','RUSSIAN FEDERATION','105264','+7-916-9049079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 06:06:18',0,NULL,3,1,3,1,'RA184565727CN\r ','bay_v_korsar\rOTSA001'),(13618,8881318487767216,111,'WMN1000B',2,'',0,'eastar4','oliver_sonntag ','oliver_sonntag@arcor.de','Oliver Sonntag','Dellwiger Stra? 23','Dortmund','','GERMANY ','44379 ','',NULL,NULL,NULL,'2011-10-13 06:36:07',0,NULL,3,0,6,1,'EE491016091CN ','补发的  OEM的\r已入库   货已经退回 11.30\rMOSA002\r Oliver Sonntag\rDellwiger Straße 23\rDortmund  44379 \rGERMANY'),(13619,863290308012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','helenpost13','helen.postle@sky.com','helen postle','30 talbot road','immingham','Lincolnshire','UNITED KINGDOM','dn40 1ex','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 07:09:20',0,NULL,3,1,3,1,'RA184565917CN\r ','helenpost13\r英标\rHSMO007'),(13620,863305261012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',4,'HSMO017',39.6,'eastar4uk','blackbeltjonest','turul_umit@hotmail.com','Turul Umit','IMS London Limited<br>1st Floor, Dean House, 193 High Street','Ponders End','Middlesex','UNITED KINGDOM','EN3 4DZ','07961345237','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 08:08:56',0,NULL,3,1,3,1,' RA184565885CN','blackbeltjonest\rHSMO017\r英标'),(13621,633160351013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',132.99,'eastar4','muzza-3447','seadogsnr@yahoo.com.au','MURRAY TILKA','p/o box 5055<br>CABLE BEACH','BROOME','Western Australia','AUSTRALIA','6726','0891923447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 08:43:49',0,NULL,3,1,3,1,'RA184563451CN ','muzza-3447\rGLOT001*3\r兼容型3D眼镜 通用型'),(13622,778467487011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',63.99,'eastar4','komineni27','vjlkp_36@yahoo.com','Kommineni Venkata Krishna Prasad','Mirbat Street(POBOX:1758)','Salalah','Dhofar','OMAN','211','0096823290385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 08:54:23',0,NULL,3,1,3,1,'RA184565877CN ','komineni27\rOTSO004'),(13623,860102026012,220816847682,'Genuine Cisco PVDM-256K-4 VoiceFax DSP Module PVDM-256',10,'OTIN001',149.9,'eastar4uk','vaa666','ebay@venelin.com','EONETIX Information Technology HandelsgmbH','Meidlinger Hauptstrasse 63/5','Vienna','','AUSTRIA','1120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 09:22:19',0,NULL,3,1,3,1,'RA184569984CN\r ','vaa666\rOTIN001\r可以发了\r发七个   退三个的钱'),(13624,778477012011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',3,'GLOT001*2',158.97,'eastar4uk','imtiaz4555','imtiaz001@blueyonder.co.uk','Imtiaz Hussain','10 Fossdyke Close','Hayes','Middlesex','UNITED KINGDOM','ub4 9st','07979521905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 09:32:03',0,NULL,3,1,6,1,'EE491015842CN ','imtiaz4555\r兼容型3D眼镜 通用型'),(13625,778479573011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','1414645','res0bayg@verizon.net','JOHN RICHARDSON','12009 Tigrina Ave','WHITTIER','CA','UNITED STATES','90604-4019','(562) 947-8795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 09:41:38',0,NULL,3,1,1,1,'、 ','1414645'),(13626,863335805012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','0153639','steve.linda@ntlworld.com','Stephen Napier','12<br>Romney Road','Corby','Northamptonshire','UNITED KINGDOM','NN18 0SH','01536395444','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 10:02:37',0,NULL,3,1,3,1,'RA184563292CN\r ','0153639\rOTCN003'),(13627,633176086013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','jeangell','jeangell@gmail.com','Jan Erik  Angell','Vesterålsgata 130','Sortland','Nordland','NORWAY','8400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 10:12:52',0,NULL,3,1,2,1,'\\  ','jeangell'),(13628,778490717011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','claus-winberg','claus.winberg@gmail.com','Claus Winberg - Christina Rolste','Blommegrenen 53, 1. th.','Odense SO','','DENMARK','5220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 10:24:49',0,NULL,3,1,2,1,'\\  ','claus-winberg'),(13629,633178655013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','noevidenz','k_murphy@tpg.com.au','Kyle Murphy','Level 1/116-122 Chapel Street<br>(Entry via Duke Street)','Windsor','Victoria','AUSTRALIA','3181','0434957040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 10:34:50',0,NULL,3,1,3,1,'RA184563346CN\r ','noevidenz\rWWOT001+ANCN001'),(13630,778489836011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',63.99,'eastar4','alikon777','aliko@bk.ru','Albert Mingazov','Moskowskaya st. 38A/77','Astana','Akmolinsk state','KAZAKHSTAN','010000','+77015449181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 10:41:20',0,NULL,3,1,3,1,'RA184563071CN\r ','alikon777\rOTSO004'),(13631,736349715001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','clementimestash','gowdas@live.com','Anil Gowda','#325/1 14th main 5th Cross RMV Extn<br>Sadshivanagar','Bangalore','KA','INDIA','560080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 11:01:38',0,NULL,3,1,3,1,'RA184563010CN ','clementimestash\rOTSB001'),(13632,778494670011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','mixanoid_rus','mixanoid@mail.ru','Mihail Morosov','Ivanteevskaya, 13-102','Moscow','','RUSSIAN FEDERATION','107150','+74997483032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 11:06:03',0,NULL,3,1,2,1,'\\  ','mixanoid_rus'),(13633,863366390012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','vainiya','vainiya@hotmail.com','Francisco José Sánchez Sánchez','C/ Gavilanes, 4, 2º B','MÉRIDA','Extremadura','SPAIN','06800','655624520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 11:48:45',0,NULL,3,1,2,1,'\\  ','vainiya'),(13634,778235778011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','soia1202','pjoz00@wp.pl','Paweł Jóźwik','Palacza<br>29/24','Poznań','wielkopolskie','POLAND','60242','61 2217073','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 12:06:25',0,NULL,3,1,2,1,'\\  ','soia1202'),(13635,633209927013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','nazar_ko','nazar.pelenjo@gmail.com','Nazar Pelenjo','27, Zboischa str.','Lviv','','UKRAINE','79037','+380503706413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 12:52:51',0,NULL,3,1,2,1,'\\  ','nazar_ko\r华硕 8pin 1.0 6cm '),(13636,863392703012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','dph16','dhoffer@mba1996.hbs.edu','David Hoffer','16 Virginia Ridge Rd','Sudbury','MA','UNITED STATES','01776-1053','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 13:11:02',0,NULL,3,1,1,1,'、','dph16'),(13637,863402339012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','kvocha80','v.kvachevskiy@yandex.ru','Vladimir Kvachevskiy','Musa Djalilya st., 26-1-183','Moscow','','RUSSIAN FEDERATION','115573','+79175004444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 13:29:22',0,NULL,3,1,2,1,'\\  ','kvocha80'),(13638,633225084013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','qqqcs','elekestimi@freemail.hu','Kovacs Tamas','Kapisztrán út 80','Szeged','','HUNGARY','6710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 13:57:42',0,NULL,3,1,3,1,'RA184563023CN ','qqqcs\rGLOT005'),(13639,863419252012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','vint1701','vint.kirov@gmail.com','Vitaly Chertov','Lenina 45-30','Kirov','Kirovskaya obl','RUSSIAN FEDERATION','610004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 14:22:22',0,NULL,3,1,2,1,'、 ','vint1701\r'),(13640,778566692011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','barrowmedic1','christmastime073@aol.com','mrs march','22 chester street','barrow in furness','Cumbria','UNITED KINGDOM','la144al','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 14:29:57',0,NULL,3,1,3,1,'RA184563289CN ','barrowmedic1\rMOAP001'),(13641,863429016012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','galeczka3335','lukas90-1990@tlen.pl','Łukasz Gałkowski','Flat 19 Grosvenor court<br>hale lane','mill hill','London','UNITED KINGDOM','NW73RY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 14:39:59',0,NULL,3,1,3,1,'RA184563213CN\r ','galeczka3335\rHSMO007\r英标'),(13642,633240017013,230576481551,'10 pcs AUI Ethernet 10Base-T RJ45 Transceiver track#',1,'TRMX003*10',75,'eastar4','networkindia','networkstore2011@gmail.com','VINIT JAIN','18221 150th Ave<br>BOM 292','Springfield Gardens','NY','UNITED STATES','11413-4010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 15:05:23',0,NULL,3,1,1,1,'、 ','networkindia\rAUI Transceiver  MX20T\r'),(13643,777919975011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','hzuercher9','hzuercher9@aol.com','Hannes Zuercher','1220-87F Tasman Dr<br>Geoseis','Sunnyvale','CA','UNITED STATES','94089-2446','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 15:38:17',0,NULL,3,1,1,1,'、 ','hzuercher9'),(13644,778589628011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','agamemnon0000','agamemnon000@yahoo.com','Egemen Ferah','Universiteler Mahallesi Bilkent 1 Camlik Sitesi E-6 Blok Daire:4<br>Bilkent/Cankaya/ANKARA 06800','Ankara','Ankara','TURKEY','06800','00905055924373','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 15:38:36',0,NULL,3,1,3,1,'RA184563301CN ','agamemnon0000\rOTSO002'),(13645,778592921011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',39.99,'eastar4','bmw_shcrott','zap4asti_kz@mail.ru','Anatoliy Lissin','8 Microdistrict<br>house 19, apartment 7','Almaty','','KAZAKHSTAN','050035','+7 701 739 78 92','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 15:46:27',0,NULL,3,1,2,1,'\\  ','bmw_shcrott'),(13646,736978815001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','g-dog-bmw','mikelycka@hotmail.com','mike lycka','3433 12st NE','Calgary','AB','CANADA','T2E 6S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 16:06:32',0,NULL,3,1,3,1,'RA184563350CN\r ','g-dog-bmw\rBR3D008'),(13647,863474365012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','erklat','damatic18@gmail.com','Davor Maticevic','Grada Chicaga 28 (kod Stanic)','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 16:26:11',0,NULL,3,1,2,1,'\\  ','erklat'),(13648,778612322011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','compwiz123vl','vwl2103@columbia.edu','Vincent Lee','500 W 120th St<br>Room 1300/MC 4712','New York','NY','UNITED STATES','10027-6623','(732) 266-3038','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 16:30:26',0,NULL,3,1,1,1,'、 ','compwiz123vl'),(13649,863484450012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','cedogros','cedomil.gros@zg.t-com.hr','CEDOMIL GROS','JAKICEVA 3','ZAGREB','HR','CROATIA','10000','+38512321021','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 16:46:50',0,NULL,3,1,2,1,'\\  ','cedogros'),(13650,778623123011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','benjaminaam','vip_benjamin@hotmail.com','Benjamin Y.Aam','Vinjevollvegen 51','Ørsta','Møre og Romsdal','NORWAY','6150','+4797525789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 16:56:46',0,NULL,3,1,2,1,'\\  ','benjaminaam'),(13651,778636122011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','morgessa','boerner.michael@gmail.com','Michael Boerner','Flat 2, The Allens<br>67 Surrey Road','Poole','Dorset','UNITED KINGDOM','BH12 1HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 17:23:02',0,NULL,3,1,3,1,'RA184563261CN\r ','morgessa\rOTHP005'),(13652,863504129012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','angoram1','angoram@aol.com','A Bell','PO Box 1390','Texas City','TX','UNITED STATES','77592-1390','(409) 944-0065','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'angoram1'),(13653,631122796013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',69.9,'eastar4','selimspider','isasentrab@hotmail.com','Sengun','11, rue Roger Salengro','Ferrière La Grande','Nord-Pas-de-Calais','FRANCE','59680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 17:28:06',0,NULL,3,1,3,1,'RA184563068CN ','selimspider\rMOSA005'),(13654,778643624011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','xtrimal','xtrimal@gmail.com','Sergey Aliferovich','Kamskaya st. 10 , 19','Sankt-Peterburg','Sankt-Peterburg','RUSSIAN FEDERATION','199178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 17:38:50',0,NULL,3,1,2,1,'\\  ','xtrimal'),(13655,633294840013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',73.98,'eastar4','jmcastroj','jcastroj@yahoo.com','Carolina James','1672 E THISTLE DR','READING','PA','UNITED STATES','19610','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-13 17:50:06',0,NULL,3,1,1,1,'、 ','jmcastroj\r '),(13656,582136496004,140490658280,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',73.8,'cnfaner','jmcastroj','jcastroj@yahoo.com','Ivette Mc.Mullen','3615 S Lake Dr','Boynton Beach','FL','UNITED STATES','33435','(305) 517-7779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 17:52:27',0,NULL,3,1,1,1,'、 ','jmcastroj\r '),(13657,633298768013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','d-mon.sobaka','dveselkin@mail.ru','Dmitry Veselkin','Verkhniye Polya str.,bld. 7-1,  apt. 32','Moscow','Moscow','RUSSIAN FEDERATION','109382','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 18:01:43',0,NULL,3,1,2,1,'\\  ','d-mon.sobaka'),(13658,863527413012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','harrymendigo','renatocf7@gmail.com','Renato César Faria','Rua Oscar de Souza Geribello, 676<br>Apt 41','São Carlos','São Paulo','BRAZIL','13564-031','551631167039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 18:04:28',0,NULL,3,1,2,1,'、 ','harrymendigo\r24K 多色伞 '),(13659,863530981012,220816334369,'New Clear Transparent Dome Rain Sun Umbrella with trim',1,'UMTR001',15.95,'eastar4','frambwase114','framb.114@hotmail.com','Geneviève Bergeron','6820, rue Garnier','Montréal','QC','CANADA','H2G 3A4','(438) 322-8776','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 18:10:33',0,NULL,3,0,2,1,'、 ','frambwase114\r已入库'),(13660,778671031011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','kimbcunn','kwest@thecmigroup.com','Kimberly Westfall','4928 Watson Dr','The Colony','TX','UNITED STATES','75056-1011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 18:25:01',0,NULL,3,1,1,1,'、 ','kimbcunn'),(13661,778682441011,320679555888,'Genuine OMRON HJ-112 Digital Pedometer Walking style',1,'OMHJ001',9.99,'eastar4uk','ozgurozden','oozden@iit.edu','ozgur ozden','koc ozel lisesi kurtkoy pendik','istanbul','kurtkoy','TURKEY','34941','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 18:45:11',0,NULL,3,1,2,1,'\\  ','ozgurozden'),(13662,0,130585830992,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',20.75,'cnfaner','zhylik2010','zhylik@yahoo.com','Andrei Stepchuk','3410 180th PL SW','Lynnwood','WA','UNITED STATES','98037-7707','(425) 773-5350','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 18:46:55',0,NULL,3,1,1,1,'\\  ','zhylik2010'),(13663,863555942012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','oliv5568','o.austin@lectra.com','Sté LECTRA - M. Olivier AUSTIN','16-18, rue Chalgrin','PARIS','Ile-de-France','FRANCE','75016','06 80 74 71 45','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 18:51:11',0,NULL,3,1,2,1,'\\  ','oliv5568'),(13664,863560297012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','eiris19680905','eiris999@gmail.com','RIMAS EIDUKONIS','VILEISIO 10-5','VILNIUS','','LITHUANIA','10307','37068531622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 19:00:57',0,NULL,3,1,2,1,'\\  ','eiris19680905'),(13665,576620647003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',12.99,'cnfaner','diesel70','usmcesu6@me.com','Irving Marrero','40 Bay Ridge Ave<br>Apt 1C','Brooklyn','NY','UNITED STATES','11220-5070','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 19:19:56',0,NULL,3,1,1,1,'、 ','diesel70'),(13666,633344332013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','mega-lo-maniack','motormaster@rambler.ru','Illya Kuzmuk','35a Vidinskaya St.,Apt. 32','Rivne','Rivnenska','UKRAINE','33018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 19:51:48',0,NULL,3,1,2,1,'\\ ','mega-lo-maniack'),(13667,778734679011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','meridiem99','meridiem00@gmail.com','Jaehoon Kim','#1102-256 Doris Avenue','Toronto','ON','CANADA','M2N 6X8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 20:20:47',0,NULL,3,1,2,1,'\\  ','meridiem99'),(13668,778736444011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','bgfoto_net','admin@bgfoto.net','Slavko Todorov','ul. Pop Hariton bl.129 et.5 ap.47','Varna','','BULGARIA','9009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 20:21:30',0,NULL,3,1,2,1,'\\  ','bgfoto_net'),(13669,863612020012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','ballardc69','ballardc69@yahoo.co.uk','Christopher Ballard','17<br>Elibank Road','Eltham','London','UNITED KINGDOM','SE91QQ','02082657244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 20:21:59',0,NULL,3,1,3,1,'RA184563315CN ','ballardc69\rOTGR001'),(13670,863612907012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','bravado78','mrk_ren@yahoo.co.uk','Marek Dubicki','12 Westmorland Court<br>Lovelace Road','Surbiton','Surrey','UNITED KINGDOM','KT6 6PE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 20:24:54',0,NULL,3,1,2,1,'\\  ','bravado78\rAUI Transceiver  MX20T'),(13671,633366386013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','bisnao','paulormalmeida@gmail.com','Paulo Almeida','av.de belverde nº51 - B','Marisol','Corroios','PORTUGAL','2855-156','00351919797956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 20:48:45',0,NULL,3,1,2,1,'\\  ','bisnao'),(13672,863625793012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',4,'WLIN001',91.96,'eastar4','gaiver','gaiver@gmail.com','Anatoly Vasiljev','Smolenskay square 3,<br>Regus business center, floor 9, app.921','Moscow','RF','RUSSIAN FEDERATION','121099','(791) 632-3303 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 21:08:57',0,NULL,3,1,3,1,'RA184563332CN\r ','gaiver\rWLIN001'),(13673,863643887012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 21:27:03',0,NULL,3,1,3,1,'RA184570695CN ','lochearn1234\rWLAP002\r标记为AIRPORT  EXTREMER'),(13674,778772322011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','snotface90','hannah.simms90@hotmail.co.uk','Hannah Simms','5 Wimpole Road<br>Fairfield','Stockton-On-Tees','Cleveland','UNITED KINGDOM','TS19 7LP','07792274331','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 21:40:17',0,NULL,3,1,3,1,'RA184563329CN\r ','snotface90\rMOAP001'),(13675,778766342011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','ckoc1398','kcman46@hotmail.com','Craig Kochen','2200 Schrader Lane','North Aurora','IL','UNITED STATES','60542','(630) 907-9887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 21:23:04',0,NULL,3,1,1,1,'\\ ','ckoc1398'),(13676,778794805011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','vas_o_line','vkirovski@gmail.com','Vasko Kirovski','Reddam House<br>70 Edgecliff Road','Woollahra','New South Wales','AUSTRALIA','2025','0293694096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 22:44:30',0,NULL,3,1,2,1,'\\  ','vas_o_line'),(13677,778799017011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT004*2',88.99,'eastar4','stephen5199','acgwarren@aol.com','Stephen Warren','5819 Palo Pinto Ave','Dallas','TX','UNITED STATES','75206-6829','(214) 870-4244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 22:59:42',0,NULL,3,1,1,1,'\\ ','stephen5199\r兼容型3D眼镜  samsung 专用'),(13678,861646550012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','iishka22','prue.s@hotmail.com','Prue Smith','116 Moola Street','Ballarat','VICTORIA','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 23:09:34',0,NULL,3,1,3,1,'RA184563142CN\r ','iishka22\rOTSO004*2'),(13679,778811876011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','wiggo53','wigo53@bigpond.com','R Wiggins','48 Vista Ave','BATEMANS BAY','New South Wales','AUSTRALIA','2536','0244729024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 23:52:18',0,NULL,3,1,2,1,'\\  ','wiggo53'),(13680,778610408011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 00:01:58',0,NULL,3,1,6,1,'EE491015860CN ','latiendadelsotano\r兼容型3D眼镜 通用型'),(13681,863698372012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','andre28461','andrehuynh1974@yahoo.com','Hien Huynh','1450 Fifty Lakes Dr.<br>Suite E','Southport','NC','UNITED STATES','28461','(910) 845-2707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 00:03:26',0,NULL,3,1,1,1,'\\ ','andre28461'),(13682,779608844002,120791889572,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','amimac89','amimac89_04@yahoo.com','Mohd Helmi Mohd Samathani','No 6, Dorndern House, Dorndern Park<br>Bellevue Avenue, Booterstown, Blackrock','Dublin','Dublin','IRELAND','0','0857237076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 00:12:06',0,NULL,3,1,3,1,'RA184569998CN\r ','amimac89\rHSBS002'),(13683,863711280012,220816317730,'New Vivienne Red w/lace Boetie Sun Rain Stick unbrella',1,'UM00027',24.99,'eastar4','pcolantu2011','paula864@verizon.net','Paula Colantuoni','57 Sagamore Ave','Medford','MA','UNITED STATES','02155-2156','(617) 519-0406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 00:44:24',0,NULL,3,1,1,1,'\\ ','pcolantu2011\r蕾丝蝴蝶结长柄伞   '),(13684,778839748011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',35.99,'eastar4uk','eagleflight.nadav','nadav_ts@walla.co.il','Nadav Tsabari','Naham 35','Naham','','ISRAEL','99801','0544854011','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 01:34:02',0,NULL,3,1,3,1,'RA184563403CN\r ','eagleflight.nadav\rHSPL015'),(13685,778844005011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','scobarbr','pablo.marani@gmail.com','Fabiano Trambaioli','Rua Vigario Albernaz 785  - apt 12<br>- Vila Gumercindo','Sao Paulo','SP','BRAZIL','04134021','551182685280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 01:51:00',0,NULL,3,1,2,1,' ','scobarbr'),(13686,719706077008,180699062113,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',2,'GLOT001',89.98,'au-buy','bazil1908','d.wheeler@ronchiwheeler.com.au','David Wheeler','201 York Street','Sale','Victoria','AUSTRALIA','3850','0418342575','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 01:51:18',0,NULL,3,1,3,1,'RA184563448CN  ','bazil1908\rGLOT001\r兼容型3D眼镜 通用型'),(13687,576717545003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.69,'cnfaner','peklost','peklost@yahoo.com','PETR KLOUCEK','3035 35th St<br>ASTORIA','Astoria','NY','UNITED STATES','11103-4733','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 02:13:12',0,NULL,3,1,1,1,'\\ ','peklost'),(13688,633446427013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',47.9,'eastar4','saltwaterdon','ikozak@q.com','Isabel Kozak','19407 N 36th Pl','Phoenix','AZ','UNITED STATES','85050-3901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 02:25:34',0,NULL,3,1,1,1,'\\ ','saltwaterdon'),(13689,633450868013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','ankit_au','ankit.gupta.au@gmail.com','Mahavir Gupta','5 Allnutt Crescent','Forde','Australian Capital Territory','AUSTRALIA','2914','0408077574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 02:47:46',0,NULL,3,1,3,1,'RA184563099CN\r ','ankit_au\rMOSA006'),(13690,0,320772362457,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',10.5,'eastar4','asinclair197510','asinclair1975@gmail.com','Andrew Sinclair','705 Green Pastures Dr','Cedar Hill','TX','UNITED STATES','75104-2125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 02:50:34',0,NULL,3,1,1,1,'\\ ','asinclair197510\r再发一个New Jabra BT250 BT 250 wireless Bluetooth Headset'),(13691,0,320772363072,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',16.49,'eastar4','asinclair197510','asinclair1975@gmail.com','Andrew Sinclair','705 Green Pastures Dr','Cedar Hill','TX','UNITED STATES','75104-2125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 02:54:57',0,NULL,3,1,17,0,'\\ ','asinclair197510'),(13692,778860814011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','acacio23','romualdoacacio@sbcglobal.net','Romualdo F Acacio','13525 Kit Ln<br>Apt 210','dallas','TX','UNITED STATES','75240-8953','(214) 578-6954','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 02:59:46',0,NULL,3,1,1,1,'\\  ','acacio23'),(13693,863754347012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','ducktoad','ducktoad@hotmail.com','Jody Weiand','1207 Canal St','Custer','SD','UNITED STATES','57730-2109','(605) 673-2321','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 03:13:13',0,NULL,3,1,1,1,'\\ ','ducktoad'),(13694,778869577011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','flirt843','flirt843@aol.com','Samantha Fahndrich','15 Fox Trail','Lincolnshire','IL','UNITED STATES','60069','(847) 477-4341','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'flirt843'),(13695,0,220871184711,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.35,'eastar4','hidayatkassim','dayat710@hotmail.com','Hidayat Kassim','Lot 6052 Spg 91-22 Jln Setia Pahlawan','Kuala Belait','','BRUNEI DARUSSALAM','KA 1931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 03:46:02',0,NULL,3,1,2,1,'、 ','hidayatkassim'),(13696,863766289012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',257,'eastar4','schwedib','style@ysconsulting.com.au','Justin Gibson','16 Tallong Pl Turramurra','Sydney','New South Wales','AUSTRALIA','2074','0299830302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 04:15:57',0,NULL,3,1,3,1,'RA184563363CN ','schwedib\rHSJA009\r澳标'),(13697,582287999004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','kubalek','kimberly@kubalek.com','Kimberly Kubalek','po box 1337','zephyr Cove','NV','UNITED STATES','89448-1337','(775) 298-1119','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 04:21:15',0,NULL,3,1,1,1,'\\  ','kubalek'),(13698,576736896003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA004',37.96,'cnfaner','filmworks1','andy@cameraspeed.com','Andrew Schefter','8250 NE 12th Ave','Miami','FL','UNITED STATES','33138-4148','(305) 704-7139','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 04:24:51',0,NULL,3,1,1,1,'\\  ','filmworks1'),(13699,576540134003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',39.99,'cnfaner','rockwithgrv007','rockwithgrv@gmail.com','Gaurav suvarna','Shop no.4, building no.5, matruchhaya chs ltd, j.k karmalkar marg,<br>opp. amchi shala, tilak nagar, chembur[W]','Mumbai','Maharashtra','INDIA','400089','919967942362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 04:51:49',0,NULL,3,1,3,1,'RA184563385CN  ','rockwithgrv007\rHSNO019+CCNO001'),(13700,576740956003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','mxfile','cpittman@seiu99.net','C. Pittman','1063 Browning Blvd','Los Angeles','CA','UNITED STATES','90037-1603','(323) 373-9533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 04:55:57',0,NULL,3,1,1,1,'\\  ','mxfile'),(13701,0,230684147439,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',5.99,'eastar4','gekl20030321','gekl2003@pandora.be','heirman geert','quinten Matsijsstraat  47/2','schoten','','BELGIUM','2900','032130948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 05:27:30',0,NULL,3,1,2,1,'、 ','gekl20030321'),(13702,0,220871181740,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',3.75,'eastar4','3wide3','raycaemm@aol.com','Robert Caemmerer','PO Box 696','Bronxville','NY','UNITED STATES','10708-0696','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 05:47:33',0,NULL,3,1,1,1,'\\ ','3wide3'),(13703,0,320772361988,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',5.99,'eastar4','rictube','vengwah@gmail.com','Eng Wah Chan','18 KEPPEL BAY DRIVE<br>#05-24 CARIBBEAN','SINGAPORE','','SINGAPORE','098644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 05:51:12',0,NULL,3,1,11,1,'RA184563377CN  ','rictube'),(13704,863796775012,220815931796,'New Sony Ericsson HBH-DS970 Bluetooth headset',2,'HSNO008',79.8,'eastar4uk','laiffatus','petri.rajama@gmail.com','Petri Rajama','Kilterinkaari 2 C 59','Vantaa','Uusimaa','FINLAND','01600','+358409030171','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 06:34:12',0,NULL,3,1,3,1,'RA184563465CN  ','laiffatus\r欧标\rHSSE010'),(13705,863798558012,220501842033,'2.1 Acer Aspire 6920 6920G Bluetooth Module  EDR+cable',1,'BTAC2117',12.39,'eastar4','companyauctionitems','deldrago@gmail.com','Joseph Sumin','11251 N Twin Spur Ct','Oro Valley','AZ','UNITED STATES','85737-7238','(520) 531-0005','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 06:42:01',0,NULL,3,1,1,1,'\\ ','companyauctionitems\racer 8pin0.8 16cm  '),(13706,576758893003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','jfle3141','jeri.fletcher@gmail.com','Jeri Fletcher','6023 W St Moritz Ln','Glendale','AZ','UNITED STATES','85306','(602) 262-6928','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 07:16:57',0,NULL,3,1,1,1,'\\ ','jfle3141'),(13707,8881318579683031,111,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',0,'cnfaner','liddel_laju','apache6@freenet.de','Antje Körner','Demmeringstr.163','Leipzig','','GERMANY','04179','',NULL,NULL,NULL,'2011-10-14 08:08:03',0,NULL,3,1,3,1,'RA184563479CN  ','BALO007\r补发的 \r充完电测试一下'),(13708,863821831012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',7.8,'eastar4','rsrank','popo666@kefoweb.sk','Roman Šrank','Námestie Matice slovenskej<br>10/8','Žiar nad Hronom','Slovakia','SLOVAK REPUBLIC','96501','+421 908 818 499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 08:22:59',0,NULL,3,1,2,1,'、 ','rsrank'),(13709,778935508011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','kengee99','ken.gee@ntlworld.com','Ken Gee','69 Hummersknott Ave','Darlington','Durham','UNITED KINGDOM','DL3 8LE','07740190729','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 09:02:07',0,NULL,3,1,6,1,'EE491016065 ','kengee99\r兼容型3D眼镜 通用型'),(13710,0,220871182181,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',35.99,'eastar4','aloniba5000','aloniba@walla.co.il','barak aloni','remez 20','kfar saba','israel','ISRAEL','44321','052-4485838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 09:07:47',0,NULL,3,1,2,1,'\\ ','aloniba5000'),(13711,778943156011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',184.99,'eastar4','tom9898tom','tom@settem.no','Tom Settem','Skollerudveien 135','Lommedalen','','NORWAY','1350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 09:31:26',0,NULL,3,1,3,1,'RA184569423CN\r ','tom9898tom\rOTSO004*3'),(13712,576786540003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','stanleyms521','stanleyms521@yahoo.com','Stanley Schubert','4021 Gifford Ave','Cleveland','OH','UNITED STATES','44109-3945','(216) 401-5985','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 10:09:57',0,NULL,3,1,1,1,'\\ ','stanleyms521'),(13713,778961215011,320730084621,'Griffin Dual USB Car Charger for iPhone ipad iPad2',2,'CCGR001',7.5,'eastar4uk','mikeburns2','mike.burns2@btopenworld.com','Mike Burns','1, Carn Mor<br>Culbokie','Dingwall','Highland','UNITED KINGDOM','IV7 8NA','01349887103','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 10:39:00',0,NULL,3,1,3,1,'RA184569114CN\r ','mikeburns2\rCCGR001'),(13714,778962937011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','22ptitsa11','22ptitsa@gmail.com','Andrii Gorobets','Kudryashova  7, kv 104','Kyiv','','UKRAINE','03035','+380672739494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 10:46:03',0,NULL,3,1,2,1,'\\  ','22ptitsa11'),(13715,778963548011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',16.98,'eastar4','audrius4117','audrius.kucinskas@gmail.com','Audrius Kucinskas','19 Lincoln Road','Guildford','Surrey','UNITED KINGDOM','GU2 9TJ','07979411113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 10:48:02',0,NULL,3,1,2,1,'\\  ','audrius4117'),(13716,863872211012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','tcandfriends2','enormoushangover@hotmail.com','Jarred Edwards','9771 W Daffodil Ln','Miramar','FL','UNITED STATES','33025-2375','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 11:21:10',0,NULL,3,1,1,1,'\\ ','tcandfriends2'),(13717,863878267012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','kiki-jaune','bidoche054@hotmail.fr','Verrelle Damien','4 rue de verdun','Baccarat','lorraine','FRANCE','54120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 11:39:38',0,NULL,3,1,2,1,'\\  ','kiki-jaune'),(13718,863886440012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Rachel Abroms','1200 MEADOWBROOK AVE','Los Angeles','CA','UNITED STATES','90019-2869','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 12:06:22',0,NULL,3,1,1,1,'\\ ','bigtimepimp'),(13719,863890624012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Cornerstone Christian Academy','355 N Cross St','Sycamore','IL','UNITED STATES','60178-1231','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 12:17:47',0,NULL,3,1,1,1,'\\ ','321expressllc'),(13720,863895720012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','David Birdwell','535 WAYLAND AVE<br>APT D','Kenilworth','IL','UNITED STATES','60043-1084','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 12:32:16',0,NULL,3,1,1,1,'\\ ','321expressllc'),(13721,0,220871184421,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',1.85,'eastar4','e-noose','enoose@gmail.com','ahmet adas','101-1026 Glendor ave.','Burlington','ON','CANADA','l7r 4m7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 12:53:10',0,NULL,3,1,2,1,'\\  ','e-noose'),(13722,863911649012,220815932431,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',13.98,'eastar4uk','pjero63','griljp@gmail.com','Peter Grilj','Erjavčeva 1','Nova Gorica','Slovenia','SLOVENIA','5000','+38431841058','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 13:15:44',0,NULL,3,1,2,1,'\\  ','pjero63'),(13723,779017187011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','irmgardroberta','anna.fendt@vitus-fendt.de','Vitus Fendt Erdbewegungen u. Transporte','GmbH & Co. KG<br>Dieselstr. 12','Gersthofen','','GERMANY','86368','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 13:40:13',0,NULL,3,1,2,1,'\\  ','irmgardroberta\r欧标'),(13724,633570418013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','arkalis1968','arkalis.e@gmail.com','Evangelos Arkalis','89-91, Lefkon Oreon Str','Chalandri','Athens','GREECE','15234','6977837693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 13:50:44',0,NULL,3,1,2,1,'\\  ','arkalis1968'),(13725,779008262011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','shanesgiraffesale','shanebennettconnell@hotmail.com','Shane Connell','40 Pinedale Street<br>East Victoria Park','Perth','Western Australia','AUSTRALIA','6101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 13:13:27',0,NULL,3,1,2,1,'\\  ','shanesgiraffesale'),(13726,863935782012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','owlscohk','everay2003@yahoo.com','KWAN CHUN LEUNG','F14-C, Block 5, Hibiscus Court, World-wide Gardens<br>7 Lung Pak Street, Tai Wai, Shatin, N.T.,','default','','HONG KONG','default','(852) 91919841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 14:22:39',0,NULL,3,1,2,1,'\\  ','owlscohk'),(13727,863936367012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.88,'eastar4','gallego250887','david__tuky@hotmail.com','David Gallego Puertas','C/Gerona,27,1º','Les Franqueses del Vallès','Cataluña','SPAIN','08521','667463079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 14:22:44',0,NULL,3,1,2,1,'\\  ','gallego250887\r华硕10pin 0.8 6cm '),(13728,653314321005,150675012128,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','abcdan','daniel.robidoux@videotron.ca','Daniel Robidoux','244 Sherbrooke est App 311','Montreal','QC','CANADA','H2X 1E1','(514) 961-5303','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 14:24:40',0,NULL,3,0,3,1,'RA184569247CN\r ','abcdan'),(13729,0,130585830348,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',10.99,'cnfaner','renatodonascimento','renato.do.nascimento@gmail.com','Renato Nascimento','Rua Jardim Castro Alves, 42, fundos<br>Caminho de Areia','Salvador','BA','BRAZIL','40440520','71 88049334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 14:27:33',0,NULL,3,1,3,1,'RA184563964CN\r ','renatodonascimento\rHSMO008'),(13730,863944507012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','zataoa','sraynham@googlemail.com','Steven Raynham','32 Barnaby Rudge','Chelmsford','Essex','UNITED KINGDOM','CM1 4YG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 14:43:59',0,NULL,3,1,3,1,'RA184563981CN\r ','zataoa\rWLHP002'),(13731,633589418013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','alx_chel','alxchel@yandex.ru','Alexey Chelmodeev','kv. 83<br>ul. Lenina dom 25','Klimovsk','Moskovskaya obl','RUSSIAN FEDERATION','142180','+79175811150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:00:49',0,NULL,3,1,2,1,'\\  ','alx_chel'),(13732,633589862013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','renatd72','renatd72@gmail.com','TYMUR Dashkevych','Kameneva 4a','Kiev','','UKRAINE','01014','+380672099707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:04:43',0,NULL,3,1,3,1,'RA184563978CN\r ','renatd72\rWWOT001+ANCN001'),(13733,863954441012,220825062314,'New 3.0 Bluetooth BCM92070 Module+cable Asus N43 N73',1,'BTAS3001',19.98,'eastar4','germanskynet','german-skynet@bk.ru','German Shramov','9/22, Gogol str.','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:08:24',0,NULL,3,1,2,1,'\\  ','germanskynet\r3.0 ASUS 6pin 6CM '),(13734,633587151013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.39,'eastar4','fernandogahyva','fernandogahyva85@gmail.com','Fernando Gahyva','Rua 10 Numero 118 Boa Esperança','Cuiabá','Mato Grosso','BRAZIL','78068727','6584682696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:00:38',0,NULL,3,1,2,1,'\\  ','fernandogahyva\racer 8pin1.00 10cm '),(13735,863954702012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','torrot_mustang','manrike5@hotmail.com','Eloy Facorro Caamaño','Esteiro, Muros<br>C/ Areal nº 17','A Coruña','Galicia','SPAIN','15240','650476563','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 15:22:43',0,NULL,3,1,3,1,'RA184569508CN\r ','torrot_mustang\rGLOT005'),(13736,633607246013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','claa8888','cdvergil@yahoo.ca','Craig Laatz','Apartment 21, 1950 Bloor street West','Toronto','ON','CANADA','M6P 3K9','(416) 890-1296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 16:01:21',0,NULL,3,1,2,1,'\\  ','claa8888'),(13737,863990147012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','polysonsvaldor','discoberard@cablevision.qc.ca','Marcel Berard','127 Elizabeth','Val-d\'Or','QC','CANADA','J9P 0C3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 16:28:29',0,NULL,3,1,3,1,' RA184569383CN\r','polysonsvaldor\rOTSO004*2'),(13738,633623671013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',2,'BTDE2002',19.76,'eastar4','traduzca','nrands@nickrands.com','Nick Rands','Brunel<br>South Dock Marina','Rope Street','London','UNITED KINGDOM','SE16 7SZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 16:55:08',0,NULL,3,1,2,1,'\\  ','traduzca'),(13739,779101669011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','kcoudron49hw','kcoudron@aol.com','Alice Coudron','2417 143rd ST NW','Monticello','MN','UNITED STATES','55362-6214','(612) 878-2235','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 17:13:23',0,NULL,3,1,1,1,'\\ ','kcoudron49hw'),(13740,864017621012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',9.88,'eastar4','dsecomp','drinaldo@dse-computers.com','Datastream Electronics','6410 N Monroe St','Spokane','WA','UNITED STATES','99208-7063','(509) 701-4142','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 17:27:51',0,NULL,3,1,1,1,'\\ ','dsecomp\racer 8pin1.00 6cm '),(13741,737458153001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','239.lee','lpthamonster@yahoo.com','Levander Pugh','5332 18th ct sw','naples','FL','UNITED STATES','34116-5626','(239) 465-8096','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 17:52:57',0,NULL,3,1,1,1,'\\ ','239.lee'),(13742,864037103012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','kbaberska','karola260@op.pl','Karolina Baberska','13 Brooklawn','New Ross','Wexford','IRELAND','','0868589100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 18:01:03',0,NULL,3,1,2,1,'\\  ','kbaberska'),(13743,864016137012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',139.95,'eastar4','peonypage','hcpage@gmail.com','Heidi Page','21707 NE 161st St','Woodinville','WA','UNITED STATES','98077-7460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 18:03:50',0,NULL,3,1,1,1,'\\ ','peonypage'),(13744,779148932011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','snillman','snillboy@yahoo.com','Hadi Akbari','Fjæreveien 55','Grimstad','Grimstad','NORWAY','4885','99855275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 18:48:03',0,NULL,3,1,2,1,'\\  ','snillman'),(13745,633674739013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','dwayne_222000','derwyn2@rogers.com','keron smith','7 Distleman Way','Ajax','ON','CANADA','L1T4X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 19:15:01',0,NULL,3,1,2,1,'\\  ','dwayne_222000'),(13746,864080053012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','szelestamas','szelest@tvnetwork.hu','Széles Tamás','Vérhalom u. 42.','Budapest','','HUNGARY','1025','(3620) 2643635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 19:15:08',0,NULL,3,1,2,1,'\\  ','szelestamas'),(13747,864106119012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','2010andreapanescu','andreapanescu@yahoo.com','andrea maria ursu','C.A.Vlaicu,Bl.A8,et 3 ap 27','ARAD','OH','ROMANIA','31031','0729938711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 20:02:48',0,NULL,3,1,2,1,'\\  ','2010andreapanescu'),(13748,864107410012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','pdurrant','paul@durrant.co.uk','Paul M P Durrant','82 Earlham Road','Norwich','other','UNITED KINGDOM','NR2 3HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 20:04:42',0,NULL,3,1,3,1,'RA184570687CN ','pdurrant\rWLAP002'),(13749,778984226011,320745265525,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',15.95,'eastar4','milly79_liverbird','cv79@live.no','Camilla Viken','Johan Hirsch vei 1','Oslo','Oslo','NORWAY','N-0678','45066233','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 20:06:12',0,NULL,3,1,2,1,'\\  ','milly79_liverbird\r蓝天白云长柄伞 '),(13750,779201914011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','christosmarcou','christos_marcou@hotmail.com','Christos Marcou','34 Kyriakou Matsi Avenue,','Nicosia','','CYPRUS','1082','0035722316356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 20:31:06',0,NULL,3,1,3,1,'RA184569953CN\r ','christosmarcou\rGLSG001*2'),(13751,864120881012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick Welsh','6 Langford Pl<br>Renfrewshire','Glasgow','Renfrewshire','UNITED KINGDOM','g53 7hz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 20:32:30',0,NULL,3,1,3,1,'RA184571033CN\r ','lochearn1234\rWLAP002\r发AirPort的'),(13752,864122459012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','alanisone','ebayuser@theingram.co.uk','alan ingram','8 micklehill drive','solihull','West Midlands','UNITED KINGDOM','B902PU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 20:34:59',0,NULL,3,1,3,1,'RA184569216CN\r ','alanisone\rRCLO006'),(13753,576954545003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','bbyblu_82','bbyblu_82@yahoo.com','Troy J Jardot','501 W Poplar Ave','Enid','OK','UNITED STATES','73701-1674','(580) 233-2261','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 20:41:30',0,NULL,3,1,1,1,'\\ ','bbyblu_82'),(13754,864126095012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','miomaiy','mio_maiy@yahoo.com','Анастасия Рыбалкина','Калинина, 37, 16<br>Стр.','Сочи','Краснодарский край','RUSSIAN FEDERATION','354348','89180507178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 20:42:19',0,NULL,3,1,2,1,'\\  ','miomaiy'),(13755,864126215012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','lucien.girard','lucien_girard@hotmail.com','lucien girard','797 basile-routhier','repentigny','QC','CANADA','j6a7v2','(514) 502-0502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 20:46:41',0,NULL,3,1,3,1,'RA184569220CN\r ','lucien.girard\rHSJA001'),(13756,653465204005,150675012128,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','yourkjdj','djhost@comcast.net','Murray Coleman','31709 125th Pl SE','Auburn','Wa','UNITED STATES','98092-3658','(253) 804-5475','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-14 20:50:29',0,NULL,3,0,1,1,'\\ ','yourkjdj\rLK011375463CN'),(13757,576957423003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',13.98,'cnfaner','tommarthat','tommarthat@aol.com','Henry Taylor','7426 Marlbrook Dr','Charlotte','NC','UNITED STATES','28212-4766','(704) 408-8669','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 20:52:09',0,NULL,3,1,1,1,'\\ ','tommarthat'),(13758,779228179011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','ranbenderli','ranb34@nana.co.il','ran benderli','hacharov 7','kefar yona','','ISRAEL','40300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 21:34:04',0,NULL,3,1,2,1,'\\  ','ranbenderli'),(13759,864151958012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','pat8','pblanfor@bellsouth.net','Pat Blanford','3137 Yorkshire Dr','Bardstown','KY','UNITED STATES','40004-9431','(502) 507-3484','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 21:43:01',0,NULL,3,1,1,1,'\\ ','pat8'),(13760,580482980004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'cnfaner','sbenjaminrudnick','ben.rudnick@gmail.com','Stanford Rudnick','311 E 38th St<br>Apt 8A','New York','NY','UNITED STATES','10016-2774','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 22:02:28',0,NULL,3,1,1,1,'\\ ','sbenjaminrudnick'),(13761,779240707011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','ud080','jonathan.rozenberg@gmail.com','Jonathan Rosenberg','Shaham 3/5','Haifa','','ISRAEL','34792','(972)4-8328874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 22:09:42',0,NULL,3,1,2,1,'\\  ','ud080'),(13762,576979740003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',2,'HSJA006',27.1,'cnfaner','granofgosie','gosiesgran@aol.com','Susan Widmann','552 Eastgate Dr','Waterloo','IA','UNITED STATES','50703','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 22:23:17',0,NULL,3,1,1,1,'\\ ','granofgosie'),(13763,779236021011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','hristodoulou','hristodoulou@hotmail.com','John Hristodoulou','201 Glenlyon Road','Brunswick','Victoria','AUSTRALIA','3057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 21:56:05',0,NULL,3,1,2,1,'\\  ','hristodoulou'),(13764,779252838011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','ser.nadie1905','ser.nadie@gmail.com','Oscar Alfredo Martinez Martinez','San Miguel de Cruces #418<br>La Forestal','Durango','Durango','MEXICO','34217','6181004248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 22:49:14',0,NULL,3,1,2,1,'\\  ','ser.nadie1905'),(13765,779253090011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','olexua','olexdj@gmail.com','Olexiy Sakovsky','Kostyantynivska, 122, kv. 12','Priluki','Chernigiv region','UKRAINE','17500','+380937444422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 22:57:53',0,NULL,3,1,2,1,'\\  ','olexua'),(13766,633746526013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',12,'CASS003',101.88,'eastar4','nhat-trang','nhat.tran@ingrealestate.com','Nhat tran','8 lackey st fairfield','Fairfield','New South Wales','AUSTRALIA','2165','0297233908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 23:29:56',0,NULL,3,1,4,1,'YW868053256CN ','nhat-trang\rCASS003'),(13767,633755624013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',62.5,'eastar4','seladewig','sladewig81@yahoo.com','Shannon Ladewig','4 Wollundry Place','The Gap','Queensland','AUSTRALIA','4061','0419477782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 00:18:12',0,NULL,3,1,3,1,'RA184569233CN\r ','seladewig\rHBPH002\r一共买了两个'),(13768,633753024013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',62.5,'eastar4','seladewig','sladewig81@yahoo.com','Shannon Ladewig','4 Wollundry Place','The Gap','Queensland','AUSTRALIA','4061','0419477782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 00:20:04',0,NULL,3,1,17,0,NULL,'seladewig'),(13769,779282728011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','fhu013','hhfcareer@hotmail.com','Frank Huang','Level 26, 201 Elizabeth Street<br>Maersk Australia Pty Ltd','Sydney','New South Wales','AUSTRALIA','2000','0289175404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 00:49:39',0,NULL,3,1,2,1,'\\  ','fhu013'),(13770,577006874003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','carol_pompom','my2poms@hotmail.com','Carol Torres','8778 Larkin Ct','Riverside','CA','UNITED STATES','92503-4054','(909) 214-8494','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 00:58:41',0,NULL,3,1,1,1,'\\ ','carol_pompom'),(13771,653539451005,150675012128,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','stephenk5975','swkrebsjr@yahoo.com','STEPHEN KREBS','1114 Del Norte Cir','PASCAGOULA','MS','UNITED STATES','39581-2052','(228) 762-1569','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-15 01:39:04',0,NULL,3,0,1,1,'\\ ','stephenk5975\rLK035421352CN'),(13772,720127088008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',32.99,'au-buy','teremanrique','tere_manrique@hotmail.com','Teresa Manrique','144 Haasville Rd','Anthony','NM','UNITED STATES','88021-8560','(505) 882-3929','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 01:57:56',0,NULL,3,1,1,1,'\\ ','teremanrique'),(13773,779301224011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','rawon_87','rawon87@gmail.com','Riki Wong','4 Merrimu St','Melbourne','Victoria','AUSTRALIA','3163','0430082609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 02:04:22',0,NULL,3,1,2,1,'\\  ','rawon_87'),(13774,653544896005,150675012128,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','gmoney574','gregory.tropea@yahoo.com','Gregory Tropea','130 Burdick Dr','Cranston','RI','UNITED STATES','02920-1537','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-15 02:10:41',0,NULL,3,0,1,1,'\\ ','gmoney574\rLK047850535CN'),(13775,779305041011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','wallytuten','wgtuten@gmail.com','Wallace G Tuten','605 Oak Crest Lane','Georgetown','TX','UNITED STATES','78628','(512) 563-2453','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 02:20:26',0,NULL,3,1,1,1,'\\ ','wallytuten'),(13776,779319119011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','j_jsales0','jjjdevinney@frontier.com','joe devinney','707 Aurora Knoll Ln','fort wayne','IN','UNITED STATES','46825','(260) 515-7497','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 03:24:43',0,NULL,8,1,17,0,NULL,'j_jsales0'),(13777,779320229011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','mani005','lakhbir.shergill@gmail.com','Lochana Dharmatilake','22 Ambrose Treacy Drive<br>Bundoora','Melbourne','Victoria','AUSTRALIA','3083','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 03:31:56',0,NULL,3,1,2,1,'\\  ','mani005'),(13778,779323783011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','jwalker126','jwalker@mainet.com','John   Walker','3065 Blackthorn Dr','Reno','NV','UNITED STATES','89523-2142','(775) 747-1517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 03:50:38',0,NULL,3,1,1,1,'\\ ','jwalker126'),(13779,633784728013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',9,'CASS003',134.44,'eastar4','mossyrj','rohan05@tpg.com.au','Rohan Moss','16 Stein Pl','Glenmore Park','New South Wales','AUSTRALIA','2745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 04:16:43',0,NULL,3,1,4,1,'YW868053260CN ','mossyrj\rCASS003\r一共买了九条CAB-6060\r五条CAB-2626\r两条CAB-2660\r'),(13780,779339813011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','bc_inc','ewan@thereids.com.au','Ewan','3 Young Street<br>Kings Langley','Sydney','New South Wales','AUSTRALIA','2147','0409181440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 05:25:00',0,NULL,3,1,2,1,'\\  ','bc_inc'),(13781,779344276011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','sssharksss','bigfootsam62@hotmail.com','Sami Ali (Bah 9983)','18221 150th Ave','Springfield Gardens','NY','UNITED STATES','11413-4010','718 553 8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 06:13:02',0,NULL,3,1,1,1,'\\ ','sssharksss'),(13782,633820675013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','hoatieu_au','hoatieu_au@yahoo.com','Hoa Tieu','19 Yarrie St','Corinda','Queensland','AUSTRALIA','4075','0732776088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 07:26:54',0,NULL,3,1,2,1,'\\  ','hoatieu_au\r钢琴美女伞 \r客户同意要紫色的'),(13783,582612757004,140516860294,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.9,'cnfaner','evanxinos','evan_xinos@msn.com','Evan xinos','14 chablis','Kirkland','QC','CANADA','h9h5a9','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-15 07:46:22',0,NULL,3,1,3,1,'RA184569304CN\r ','evanxinos\rWLAT008'),(13784,779370986011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','2010simonlimingti','simonlimingti@hotmail.com','Morris Li','1405<br>north road','Oakleigh east','Victoria','AUSTRALIA','3166','0398989766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 08:03:26',0,NULL,3,1,2,1,'\\  ','2010simonlimingti'),(13785,779379610011,320407696984,'Acer Travelmate 5520 5530 Bluetooth Module 2.0+cable',1,'BTAC2009',9.88,'eastar4','goneil48','gboneil@hotmail.com','Geoffrey O\'Neil','51 Hillsea Ave','Clearview','South Australia','AUSTRALIA','5085','0411808462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 08:34:19',0,NULL,3,1,2,1,'\\  ','goneil48\racer 4pin1.25 20cm'),(13786,864320470012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','henni2668','uwehennrichs@web.de','Uwe Hennrichs','Wersbach 4','Leichlingen-Witzhelden','','GERMANY','42799','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 08:59:49',0,NULL,3,1,2,1,'\\  ','henni2668'),(13787,577075610003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','sigfever','sigfever@gmail.com','James A Ray','8705 Martinique Bay Ln','Las Vegas','NV','UNITED STATES','89147-6517','(702) 290-1867','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 09:07:33',0,NULL,3,1,1,1,'\\  ','sigfever'),(13788,633838470013,230545855042,'Acer TM 3000 3020 /AS5760 Bluetooth Module2.0+cable',1,'BTAC2024',9.88,'eastar4','satbitsuk','s_fakley@yahoo.com','S Fakley','3 Elmstone Close','Maidstone','Kent','UNITED KINGDOM','ME16 8DQ','01622721114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 09:04:11',0,NULL,3,1,2,1,'\\  ','satbitsuk\racer 8pin1.25 10cm'),(13789,779397251011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','davies46','phil.m.davies@gmail.com','Phil M Davies','1 Ravenswood Gardens','Southsea','Hampshire','UNITED KINGDOM','PO5 2LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 09:36:29',0,NULL,3,1,3,1,'RA184569587CN\r ','davies46\rGLOT001\r兼容型3D眼镜 通用型'),(13790,864347494012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',2,'UMTR001',39.98,'eastar4','123wendan','wwe62020@bigpond.net.au','Wendy Webster','15 Barsby Street','Ayr','Queensland','AUSTRALIA','4807','0746623942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 10:29:24',0,NULL,3,0,2,1,'\\  ','123wendan\r已入库\r一个粉红色一个紫色的'),(13791,776941644011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',2,'WLAP003',49.98,'eastar4','lipigod','akutus@akutus.net','Ari Kivelä','Huhmarinrinne 1','Tampere','FI','FINLAND','33560','+358405549651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 10:31:49',0,NULL,3,1,3,1,'RA184570673CN ','lipigod\rWLAP003'),(13792,779415960011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','lookingzone','peejayhercules@optusnet.com.au','Mr David Walker','Level 9, 10 Queens Road','Melbourne','Victoria','AUSTRALIA','3004','61398646606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 10:39:40',0,NULL,3,1,3,1,'RA184569471CN\r ','lookingzone\rGLOT001\r兼容型3D眼镜 通用型'),(13793,779425174011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','sim.0n','simon.kneringer@gmail.com','Simon Kneringer','Prof.-Franz-Spath-Ring 3/10','Graz','','AUSTRIA','8042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 11:09:57',0,NULL,3,1,2,1,'\\  ','sim.0n'),(13794,633860255013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','zhestyr','t.rafibeyli@gmail.com','Turan Rafibeyli','M.Qasqay 24<br>apt 133','Baku','Nasimi','AZERBAIJAN','AZ1010','994504342278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 11:10:07',0,NULL,3,1,3,1,'RA184569445CN\r ','zhestyr\rOTES001'),(13795,864374445012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','pwsharpau','pwsharp@gmail.com','Peter Sharp','7 Carmichael Court','Sebastopol','Victoria','AUSTRALIA','3356','0413276282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 11:48:01',0,NULL,3,1,2,1,'\\  ','pwsharpau'),(13796,779441184011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','antetapi','duje@euromarine.hr','Duje Kragic','Zagrebacka 11','Split','Croatia','CROATIA','21000','00385992101594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 12:01:25',0,NULL,3,1,2,1,'\\  ','antetapi'),(13797,779445033011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','sebkama','sebastiansuslik@ymail.com','Kamilla Suslik','68 St. Andrews Close','Canterbury','Kent','UNITED KINGDOM','CT1 2RT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 12:15:32',0,NULL,3,1,3,1,'RA184570007CN\r ','sebkama\rGLSG001'),(13798,633881450013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',39.99,'eastar4','jjtiang','franky_tiang@yahoo.com','franky tiang','21 Jalan Indah 1/6,<br>Taman Universiti Indah,','Seri Kembangan','Selangor','MALAYSIA','43300','0126137446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 12:25:14',0,NULL,3,1,2,1,'\\  ','jjtiang'),(13799,864399013012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','galeczka3335','lukas90-1990@tlen.pl','Łukasz Gałkowski','Flat 19 Grosvenor court<br>hale lane','mill hill','London','UNITED KINGDOM','NW73RY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 12:54:28',0,NULL,3,1,3,1,'RA184569352CN\r ','galeczka3335\rHSMO007\r英标'),(13800,633895902013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.45,'eastar4','rylezee','ian.ryles@ntlworld.com','Ian Ryles','29 Paris Avenue,The Westlands','NEWCASTLE','Staffordshire','UNITED KINGDOM','ST52RQ','01782610958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 13:21:44',0,NULL,3,1,2,1,'\\  ','rylezee\r英标'),(13801,864419382012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Andy Friedman','122 Trowbridge St<br>Apt 1R','Cambridge','MA','UNITED STATES','02138-3114','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 13:48:10',0,NULL,3,1,1,1,'\\ ','321expressllc'),(13802,779483829011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',2,'WLAT006',18.98,'eastar4','yrepillez','yrepillez57@yahoo.fr','YANNICK REPILLEZ','8 Hameau de Belmach','APACH','Lorraine','FRANCE','57480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 14:02:52',0,NULL,3,1,2,1,'\\  ','yrepillez'),(13803,582693466004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','ladyirona','ladylynda43@att.net','Lynda Walker','2196 Worrall Hill Dr','Duluth','GA','UNITED STATES','30096-1264','(678) 417-9182','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 14:26:39',0,NULL,3,1,1,1,'\\ ','ladyirona'),(13804,779495398011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','noodles2k5','nicknoodles69@hotmail.com','nicholas woods','THE WILLOWS<br>SECOND DRIFT, WOTHORPE','STAMFORD','Lincolnshire','UNITED KINGDOM','PE93JQ','01780752474','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 14:31:26',0,NULL,3,1,3,1,'RA184569295CN\r ','noodles2k5\r英标\rHSJA011'),(13805,633919974013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','lb3088','loic3088@bluewin.ch','Loïc Barben','Petit-chasseur 92','Sion','Valais','SWITZERLAND','1950','0041797636077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 14:48:06',0,NULL,3,1,2,1,'\\  ','lb3088'),(13806,577153002003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',2,'POLO001',13.78,'cnfaner','hotincoeb','hotincoeb@trophyshop.net','Darren Lange','6285 Baum ST','Frederick','CO','UNITED STATES','80530-4860','(303) 833-5907','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 14:55:02',0,NULL,3,1,1,1,'\\ ','hotincoeb'),(13807,779509002011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.5,'eastar4uk','olivier92170','olivier.lev@gmail.com','Olivier Leveque','12 avenue de Verdun','Vanves','Île-de-France','FRANCE','92170','0146486255','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 15:05:49',0,NULL,3,1,2,1,'\\  ','olivier92170\r红边优联'),(13808,577165985003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','evoyzracer','jasonkraft1@msn.com','Jason Kraft','305 S Camp Meade Rd','Linthicum','MD','UNITED STATES','21090-2510','(410) 370-1136','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 15:37:50',0,NULL,3,1,1,1,'\\ ','evoyzracer'),(13809,864478731012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','quveyt','tito.73@mail.ru','Aleksei Erastov','Nekrasova<br>6-45','Balashikha','Moskow','RUSSIAN FEDERATION','143900','+79267048882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 15:58:54',0,NULL,3,1,2,1,'\\  ','quveyt'),(13810,633948046013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','jmorinno','jmorinno@hotmail.com','Jose Manuel Morin Cabrera','C/ El Cine 28 <br>Las Canteras','La Laguna - Santa Cruz de Tenerife','Canarias','SPAIN','38293','655496312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 16:14:49',0,NULL,3,0,3,1,'RA184569600CN\r ','jmorinno\rGLOT001*2'),(13811,633950121013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','rekrap250','parketre250@gmail.com','Trent Parker','1005 Hildreth St','Charles City','IA','UNITED STATES','50616-3636','(641) 330-9490','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 16:20:38',0,NULL,3,1,1,1,'\\ ','rekrap250'),(13812,737849653001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','allonsgagnon2222','allonsgagnon@live.fr','sebastien gagnon','112 leclerc','princeville','QC','CANADA','g6l4r3','(819) 505-3271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 16:24:27',0,NULL,3,1,3,1,'RA184569193CN\r ','allonsgagnon2222\rBR3D006'),(13813,577194868003,130553128921,'Genuine Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL017',35.9,'cnfaner','mte_marketing','wingnutonabike@gmail.com','Michael Marks','13900 NE 64th Cir','Vancouver','WA','UNITED STATES','98682-5951','(503) 839-5471','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 17:07:03',0,NULL,3,1,1,1,'\\ ','mte_marketing'),(13814,779614977011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','pen.0174','kenneth@bradleykenneth.orangehome.co.uk','PENNY BRADLEY','CRAFTY FOX COTTAGE, OCCUPATION LANE<br>CHELMARSH','BRIDGNORTH','Shropshire','UNITED KINGDOM','WV16 6BE','01746862337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 18:39:23',0,NULL,3,1,2,1,'\\  ','pen.0174\r英标'),(13815,864574044012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','squidmonke!','squid_up@yahoo.co.uk','peter seymour','41 howe st','Derby','Derbyshire','UNITED KINGDOM','DE223ES','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 18:43:26',0,NULL,3,1,3,1,'RA184569454CN\r ','squidmonke!\rGLOT005'),(13816,737929915001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','schmerbear10','schmerbear@gmail.com','Erin Hannan','1220 Greenvalley Dr<br>Apt 12','Pittsburgh','PA','UNITED STATES','15220-1835','(412) 609-3707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 19:09:42',0,NULL,3,1,1,1,'\\ ','schmerbear10'),(13817,864597497012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',3,'HSSA002',32.97,'eastar4uk','conduitfittings','conduitfitting@bigpond.com','Tony Sfameni','4 Sinns ave','Werribee','Victoria','AUSTRALIA','3030','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 19:21:31',0,NULL,3,1,3,1,'RA184569499CN\r ','conduitfittings\rHSSA002\r澳标\r黑色的'),(13818,779637631011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',115.99,'eastar4','timrobocop','timrobocop1@yahoo.com','Tim Morgan','14255 Preston RD<br>APT 534','Dallas','TX','UNITED STATES','75254-8534','(972) 715-6598','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 19:22:59',0,NULL,3,1,1,1,'、 ','timrobocop'),(13819,864634529012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.39,'eastar4','shark-357','shark35777@gmail.com','Dejan Matičič','Sejmiška 25','Domžale','','SLOVENIA','1230','0038651339557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 20:29:49',0,NULL,3,1,2,1,'\\  ','shark-357\rAcer 5pin1.25 3cm'),(13820,779675122011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','teeeeneey','jonathan.brough@lineone.net','Mr J Brough','72 Grange View<br>Harworth','Doncaster','South Yorkshire','UNITED KINGDOM','DN11 8QN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 20:37:46',0,NULL,3,1,2,1,'\\  ','teeeeneey'),(13821,779679284011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.9,'eastar4','neil.a.henry','mark.henry@ismg.com.au','Mark Henry','3 Brendale Avenue','Blackburn North','Victoria','AUSTRALIA','3130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 20:46:59',0,NULL,3,1,2,1,'\\  ','neil.a.henry'),(13822,779689578011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','j_jsales0','jjjdevinney@frontier.com','joe devinney','707 Aurora Knoll Ln','fort wayne','IN','UNITED STATES','46825','(260) 515-7497','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 21:08:51',0,NULL,3,1,1,1,'\\ ','j_jsales0\r一共买了两个'),(13823,634069416013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','cookiem_nl','cookiem_nl@hotmail.com','Tze-Choi Chan','Siciliano 72','Nieuw-Vennep','','NETHERLANDS','2152 TS','06-14989552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 21:53:49',0,NULL,3,1,2,1,'\\  ','cookiem_nl'),(13824,779705853011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','carlitto74uk','erk14_v@yahoo.com','Julian M Gozar','Office 228<br>61 Victoria Road','Surbiton','Surrey','UNITED KINGDOM','KT6 4JX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 22:04:44',0,NULL,3,1,3,1,'RA184569278CN\r ','carlitto74uk\rBR3D001'),(13825,779716375011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','svarthol1024','47mikael@gmail.com','Mikael Hreidarsson','Sorlaskjol 84','Reykjavik','IS','ICELAND','107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 22:21:07',0,NULL,3,1,2,1,'\\  ','svarthol1024'),(13826,864683643012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',16.99,'eastar4','emptyvee','epereg1@gmail.com','Edwin F Peregrina','12290 Green Meadow Dr<br>Apt 611','Columbia','MD','UNITED STATES','21044-4851','(443) 610-8946','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-15 22:21:06',0,NULL,3,1,1,1,'\\ ','emptyvee\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000\r'),(13827,577296463003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','krsbunnies','karenreneesmail@yahoo.com','karen hixson','11131 ragan way','grass valley','CA','UNITED STATES','95949','(530) 273-8348','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 22:22:49',0,NULL,3,1,1,1,'\\ ','krsbunnies'),(13828,864699909012,220872406392,'4 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT001*4',175.99,'eastar4','sonatacall','dazuidema@gmail.com','David Zuidema','3/61 Mount View Parade','Croydon','Victoria','AUSTRALIA','3136','0399053649','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 23:10:44',0,NULL,3,1,6,1,'EE491016074CN ','sonatacall\r兼容型3D眼镜 通用型'),(13829,634089987013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','abedaziz_idais','abedaziz_i@hotmail.com','Fadi Thayabeh','8 raya street','abu nasser','amman','JORDAN','','(079) 631-6048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 23:23:29',0,NULL,3,1,2,1,'\\  ','abedaziz_idais'),(13830,864708073012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','bie888','gabrielalmeida85@hotmail.com','gabriel almeida','avenida capitão silva pereira nº102 3ºdrt','viseu','viseu','PORTUGAL','3500-205','+351 964186003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 00:04:02',0,NULL,3,1,3,1,'RA184569539CN\r ','bie888\rGLOT001*2\r兼容型3D眼镜 通用型'),(13831,634106494013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','obviousmistake','hsienchiwu@gmail.com','Hsien Chi  Wu','1201-50 Capulet Lane Buzzcode 5125','London','ON','CANADA','N6H0B1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 00:38:50',0,NULL,3,1,2,1,'\\  ','obviousmistake'),(13832,738043149001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','docvauxhall','l-tech-electronics@tesco.net','Stephen Lane','49 East Donington Street','Darvel','East Ayrshire','UNITED KINGDOM','KA17 0JN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 00:42:48',0,NULL,3,1,3,1,'RA184570568CN\r ','docvauxhall\rOTSB001'),(13833,633816046013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','vhmejia','vhmejia2000@yahoo.com','Victor Mejia','Jerercuaro 630<br>Col. Ricardo Flores Magon','Morelia','Michoacan','MEXICO','58147','(524) 432-7485 ext.: 48','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 01:38:43',0,NULL,3,1,2,1,'\\  ','vhmejia'),(13834,779771508011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','sven4uk','mihael.markevich@gmail.com','Michael Markevich','Technion City 109/2','Haifa','Haifa','ISRAEL','32000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 01:42:45',0,NULL,3,1,2,1,'\\  ','sven4uk\racer 4pin1.25 15cm '),(13835,779777600011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','ramakrishna_pnvs','ramakrishna_panuganti@yahoo.co.in','Ramakrishna Panuganti','Unit 8<br>115 Hartington Street','Rooty Hill','New South Wales','AUSTRALIA','2766','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 02:06:10',0,NULL,3,1,2,1,'\\  ','ramakrishna_pnvs'),(13836,779780052011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',184.99,'eastar4','rpchito','monjuco@bigpond.net.au','Ramon Juco','16 Sabre Street<br>Netley','Adelaide','South Australia','AUSTRALIA','5037','0883514920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 02:18:37',0,NULL,3,1,3,1,'RA184569370CN\r ','rpchito\rOTSO004*3'),(13837,738016088001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','julyhigh','wfcobbs@uhs.com','willie cobbs','843 Antler Post','san antonio','TX','UNITED STATES','78245-1478','(817) 825-6861','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 02:22:32',0,NULL,3,1,1,1,'\\ ','julyhigh'),(13838,0,230684147544,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',37,'eastar4','warp10too','warp10to6@rogers.com','FRANK THOM','39 FLORA DRIVE','INNISFIL','ON','CANADA','L9S 1R1','(705) 794-3863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 02:49:57',0,NULL,3,1,2,1,'\\  ','warp10too'),(13839,582893870004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',2,'HSPL011',65.98,'cnfaner','mnsherry','sherrycarmichael@yahoo.com','Sherry  Carmichael','604 S Wall ST','Montfort','WI','UNITED STATES','53569-9795','(608) 354-7450','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-16 03:20:44',0,NULL,3,1,1,1,'\\ ','mnsherry'),(13840,864776977012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','n6175308','n61753@gmail.com','Stephen Holas','Unit 1/6 Rae Street','Chadstone','Victoria','AUSTRALIA','3148','0408359374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 03:56:06',0,NULL,3,1,2,1,'\\  ','n6175308\r\r'),(13841,634143137013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','kaminiwa','toyo8833@yahoo.co.jp','Toyohisa Kaminiwa','255 W 94th St<br>Apt 21D','New York','NY','UNITED STATES','10025-9653','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 03:59:37',0,NULL,3,1,1,1,'\\ ','kaminiwa'),(13842,862891572012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','ira2791','iradarustambekova@list.ru','L.A.Eventus Ltd. c/o PX BAK  Irada','12 North End Parade','London','London','UNITED KINGDOM','W14 0SJ','44207603388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 04:07:02',0,NULL,3,1,2,1,'\\  ','ira2791\r美女涂鸦伞'),(13843,634146949013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','zanechua','zain.chua@gmail.com','Zane Jocelyn Chua','Block 726 Jurong West Avenue 5<br>Floor 6 Unit Number 242','default','','SINGAPORE','640726','+65 8182 4533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 04:22:52',0,NULL,3,1,11,1,NULL,'zanechua\rWLAT008'),(13844,720602415008,180699062138,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',45,'au-buy','drivatruk','mondeo08@bigpond.com','Steve Mather','66 Lawless Drive','Cranbourne North','Victoria','AUSTRALIA','3977','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 04:35:35',0,NULL,3,1,3,1,'RA184569202CN\r ','drivatruk\rOTPL001'),(13845,577362783003,130554590478,'NIB IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT011',14.8,'cnfaner','lazibayer','firexl@hotmail.com','Lu Xie','5726 Beacon St<br>Apt E2','Pittsburgh','PA','UNITED STATES','15217-2092','(412) 587-3981','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-16 05:22:23',0,NULL,3,1,1,1,'、 ','lazibayer\r发成不带盒子的'),(13846,779817968011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','plllls','psouthwood@sbcglobal.net','Paul Southwood','1213 Wedglea Dr','Bedford','TX','UNITED STATES','76021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 05:25:04',0,NULL,3,1,1,1,'\\ ','plllls'),(13847,634161469013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','merlionxx','merlion@attglobal.net','TAKUYA FURUYA','NOMURA INTERNATIONAL PLC, DIFC, BUILDING 6, LEVEL 6<br>P.O.BOX 506535','DUBAI','','UNITED ARAB EMIRATES','--','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 06:10:56',0,NULL,3,1,2,1,'\\  ','merlionxx'),(13848,0,130585830968,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',17.5,'cnfaner','chriszervos','chriszervos1@yahoo.gr','CHRISTOS ZERVOS','AMALIADOS 26<br>A.ILIOUPOLI','ATHENS','','GREECE','163 42','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 06:58:37',0,NULL,3,1,3,1,'RA184569349CN\r ','chriszervos\rMOLO006'),(13849,779861285011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','christian_dorgelo','christian_dorgelo@yahoo.com','christian dorgelo','5 Heussler Tce<br>Milton','Brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 08:27:57',0,NULL,3,1,2,1,'\\  ','christian_dorgelo'),(13850,738145488001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','carhay05','hminred@aol.com','HAYMEE MORENO','1913 SW 107th Ave<br>Apt 1109','MIAMI','FL','UNITED STATES','33165','(786) 262-2705','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 08:46:57',0,NULL,3,1,1,1,'\\ ','carhay05'),(13851,779873816011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',4,'CASS002',33.16,'eastar4','thomas-graf','thomas@graf3.net','Thomas Graf','Stationsstrasse 23','Regensdorf','','SWITZERLAND','8105','41787249255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 09:00:07',0,NULL,3,1,3,1,'RA184569180CN\r ','thomas-graf\r再发两条CAB-6060\rCASS002+CASS003'),(13852,634197656013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','thomas-graf','thomas@graf3.net','Thomas Graf','Stationsstrasse 23','Regensdorf','','SWITZERLAND','8105','41787249255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 09:02:58',0,NULL,3,1,17,0,' ','thomas-graf'),(13853,634197794013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','opth30','chayapat.ruk@gmail.com','Chayapat Rukpanichmanee','95/228-229 Tiwannon Rd.','Parket','Nontaburi','THAILAND','11120','668-9-513-1000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 09:03:57',0,NULL,3,1,2,1,'\\  ','opth30'),(13854,8881318758368938,111,'HP BCM94322MC',1,'WLHP002',0,'eastar4','cinemascope','peterhaas@cruzio.com','Peter Haas','234 Miramar Dr','Santa Cruz','CA','UNITED STATES','95060-5230','(831) 426-5482',NULL,NULL,NULL,'2011-10-16 09:46:08',0,NULL,3,1,1,1,'\\ ',' 注意产品要新进的那批  E邮宝改一个\rLK062947222CN'),(13855,8881318758606467,111,'Griffin PowerJolt Dual USB Car Charger',1,'CCGR001',0,'eastar4','gsixpd','ozz17@walla.co.il','Oz Elisyan','Golomb 8/6','Nahariya','','ISRAEL','22403','',NULL,NULL,NULL,'2011-10-16 09:50:06',0,NULL,3,1,2,1,'\\ ',NULL),(13856,0,220871181708,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',3.75,'eastar4','chanceux_fr','serial_as@hotmail.com','ambroise samuel','18 rue du docteur lepan','lomme','Nord-Pas-de-Calais','FRANCE','59160','0950292273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 09:53:32',0,NULL,3,1,2,1,'\\  ','chanceux_fr'),(13857,779900090011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.99,'eastar4','sgsgsg2712','dwalmsley1@optusnet.com.au','David Walmsley','10 Josquin Way','Claremont Meadows','New South Wales','AUSTRALIA','2747','0298332185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 10:01:20',0,NULL,3,1,2,1,'\\  ','sgsgsg2712'),(13858,779905375011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','tipubhai2010','m_sraza@hotmail.com','Muhammad Shahid Raza','36<br>hardy road','Ashfield Perth','Western Australia','AUSTRALIA','6054','0402456010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 10:15:09',0,NULL,3,1,2,1,' \\ ','tipubhai2010\r澳标'),(13859,864909909012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','nsubugag','godwin@wiredvisio.com','Godwin Nsubuga','Unit 2022, Bianconi Avenue<br>Citywest Business Park','Dublin 24','Dublin','IRELAND','24','0879020377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 11:01:11',0,NULL,3,1,2,1,'\\  ','nsubugag\r再发一条CAB-6060\rCASS003'),(13860,634236377013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','nsubugag','godwin@wiredvisio.com','Godwin Nsubuga','Unit 2022, Bianconi Avenue<br>Citywest Business Park','Dublin 24','Dublin','IRELAND','24','0879020377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 11:09:11',0,NULL,3,1,17,0,' ','nsubugag'),(13861,634267185013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','terenc3','terenc3le3@gmail.com','Terence Lee','3 Woodlands Drive 72,<br>#09-05 Woodsvale Condominium','default','','SINGAPORE','738090','94779465','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 12:40:24',0,NULL,3,1,11,1,NULL,'terenc3\rWLDE001'),(13862,779490489011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',41.69,'eastar4uk','marcosroberto1982','marcosmrp@yahoo.com.br','Marcos Roberto Pereira','Rua Des. Clotario Portugal, 835 Ap. 301A','Apucarana / PR','Brasil','BRAZIL','86.800-020','(43) 9977 4582','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 12:54:21',0,NULL,3,1,3,1,'RA184569437CN\r ','marcosroberto1982\rHDGE001'),(13863,634272822013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','jasonjanex2','jas_cr250f@hotmail.com','jason mcdougall','55 swan ave millbridge','bunbury','Western Australia','AUSTRALIA','6232','6145850403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 12:58:19',0,NULL,3,1,3,1,'RA184569542CN\r ','jasonjanex2\rGLOT001*3\r兼容型3D眼镜 通用型'),(13864,634279726013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',132.99,'eastar4','dinok88','dinok88@hotmail.com','konstandinos konstandinou','712 13th Ave','prospect park','PA','UNITED STATES','19076-1203','(610) 586-9927','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 13:16:33',0,NULL,3,1,1,1,'\\ ','dinok88\r兼容型3D眼镜 通用型'),(13865,780001883011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','gmanb00','gbellevue@gmail.com','Gregory Bellevue','458 E Walnut ln','philadelphia','PA','UNITED STATES','19144-1054','(215) 204-3835','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'gmanb00'),(13866,780017842011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','cmuellernd','casey@muellernd.com','Casey Mueller','2218 S 3rd St','Bismarck','ND','UNITED STATES','58504-7405','(701) 391-2850','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 14:09:00',0,NULL,3,1,1,1,'\\ ','cmuellernd'),(13867,634302615013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sergey.gorshkov','irq@list.ru','Sergey Gorshkov','Komunny 40-91','Saint Petersburg','','RUSSIAN FEDERATION','195030','905-203-3022','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'\\  ','sergey.gorshk\rov\r再发一个Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS'),(13868,779739382011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',35.99,'eastar4uk','dars.aeros','darshan_4u_zakash@yahoo.com','Barkat Ali Cheema','2 Rue D\'Oberhuasbergen','Wolfisheim','Alsace','FRANCE','67202','0033641673856','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 14:30:06',0,NULL,3,1,3,1,'RA184569406CN\r ','dars.aeros\r欧标\rHSPL015'),(13869,778282666011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',127.98,'eastar4','idanash007','amit471@gmail.com','idan ash','iris<br>2','matan','matan','ISRAEL','0547244916','0547244913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 15:03:10',0,NULL,3,1,3,1,'RA184569525CN\r ','idanash007\rOTSO004'),(13870,865061363012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','pangul6024','okramis@bluewin.ch','Otmar Kramis','Gibraltarstrasse 19','Luzern','','SWITZERLAND','6003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 15:30:13',0,NULL,3,1,2,1,'\\  ','pangul6024'),(13871,0,320772363981,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','bio_noise','admin.biohazard@gmail.com','Alexey Osipov','Shukshina st. 26/124','Barnaul','RU','RUSSIAN FEDERATION','656060','79609374632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 15:40:12',0,NULL,3,1,2,1,'\\  ','bio_noise'),(13872,865082157012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','allsortsknits','tuppence52@gmail.com','Linda J Flack','104 Beckenham Park<br>Otterham Quay Lane','Rainham','Kent','UNITED KINGDOM','ME8 7XF','01634230620','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-16 15:56:04',0,NULL,3,1,2,1,'\\  ','allsortsknits'),(13873,865086592012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',2,'WLAP004',9.9,'eastar4','paulspit','peter.eis@t-online.de','PETER EIS','AM KANAL(OHNE HAUSNUMMER)','GÖTTIN','','GERMANY','21514','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:02:43',0,NULL,3,1,2,1,'\\  ','paulspit'),(13874,780097549011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','ydel6426','yoann.delienne@devoteam.com','Yoann Delienne','41 rue Berthie Albrecht','Saint-Gratien','Ile-de-France','FRANCE','95210','0953261003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:06:27',0,NULL,3,1,3,1,'RA184569511CN\r ','ydel6426\rGLSG001'),(13875,738356457001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','dmteeter641','davidateeter@gmail.com','David Teeter','1119 4th St SE<br>Apt 6','Mason City','IA','UNITED STATES','50401-4345','(641) 530-0130','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 16:11:22',0,NULL,3,1,1,1,'\\ ','dmteeter641'),(13876,0,140617596564,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',9.99,'cnfaner','afzaal2010afzaal','afzaal81@yahoo.com','AFZAAL RANA','200 Woodydell ave','winnipeg','MB','CANADA','R2M2V1','(120) 496-0826 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:15:15',0,NULL,3,1,3,1,'RA184569281CN\r ','afzaal2010afzaal\rHSMO008\r一共买了两个'),(13877,634361258013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','stradibary','stradibary@gmail.com','Kyungbum Park','Gumidong<br>Bundang Posville 551','SungNamSi BunDangKu','KYUNGGIDO','KOREA,REPUBLIC OF','463-861','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:19:01',0,NULL,3,1,2,1,'\\  ','stradibary'),(13878,865121834012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',6.96,'eastar4','hh807','mail.box.807@xs4all.nl','J.R. van den akker','voorthuizenstraat 80','Den Haag','','NETHERLANDS','2573AL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:42:53',0,NULL,3,1,2,1,'\\  ','hh807\r再发一个New 44 Pin Female to Female Mini IDE Cable for PC 30cm'),(13879,577577631003,130583982440,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',12.39,'cnfaner','afzaal2010afzaal','afzaal81@yahoo.com','AFZAAL RANA','200 Woodydell ave','winnipeg','MB','CANADA','R2M2V1','(120) 496-0826 ext.: 2','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-16 16:53:23',0,NULL,3,1,17,0,' ','afzaal2010afzaal'),(13880,633837415013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','torikbuyer','mop@av-tech.no','Moritz Pörn','Voitbyvägen 292','Veikars','','FINLAND','66520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 16:58:10',0,NULL,3,1,2,1,'\\  ','torikbuyer\rHP 8pin 1.0 23cm '),(13881,780146205011,320762413525,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','sharken0','sharken@fsmail.net','Ken Jones','45 Porcher Avenue,<br>Glyncoch','Pontypridd','Mid Glam','UNITED KINGDOM','CF37 3DB','01443492124','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-16 17:03:57',0,NULL,3,1,3,1,'RA184569255CN\r ','sharken0\rHBPH001'),(13882,577603857003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','simali2k','dhmassey@hotmail.com','Dorothy Massey','2122 Longleaf Dr','Charlotte','NC','UNITED STATES','28210-7528','(704) 556-7519','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-16 17:29:14',0,NULL,3,1,1,1,'\\ ','simali2k'),(13883,865175533012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',95.99,'eastar4','akostrzewa','agnieszka.kostrzewa@gmail.com','Agnieszka Kostrzewa','Chopina 6','Kobyłka','mazowieckie','POLAND','05230','22 7864036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 17:41:39',0,NULL,3,1,3,1,'RA184569397CN\r ','akostrzewa\r原装肯辛通 Kensington K64325 专家型轨迹球CAD制图专用\rOTKE001'),(13884,865186693012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','number2guitarist','number2guitarist@yahoo.com','Matt Zillmer','2461 S 77th St','West Allis','WI','UNITED STATES','53219-1855','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 17:42:11',0,NULL,3,1,1,1,'\\ ','number2guitarist'),(13885,780268541011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',117.99,'eastar4','ragnhild_ani','ragnhildanita@hotmail.com','Ragnhild Anita S Myhre','Volloyeien 6','Svorkmo','Svorkmo','NORWAY','7327','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 18:53:41',0,NULL,3,1,3,1,'RA184569573CN\r ','ragnhild_ani\rOTSO005*2'),(13886,634491512013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','f5iko','f5iko@free.fr','Yannick Saindrenan','22 rue de Montaphilant','Trancault','Champagne-Ardenne','FRANCE','10290','03.25.21.50.93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 19:19:06',0,NULL,3,1,2,1,'\\  ','f5iko'),(13887,780292934011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','2423markj','pacoj@live.co.uk','MARK JOHNSTON','3 WESTCRAIGS PARK<br>BLACKRIDGE ,','BATHGATE','West Lothian','UNITED KINGDOM','EH48 3RY','07946305543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 19:19:20',0,NULL,3,1,2,1,'\\  ','2423markj\r英标'),(13888,780319097011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','1hayles','hayley.walton@btopenworld.com','miss hayley walton','29 lytham park<br>oundle','peterborough','Northamptonshire','UNITED KINGDOM','pe8 4fb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 19:48:58',0,NULL,3,1,2,1,'\\  ','1hayles'),(13889,780315222011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','lea.law','lealaw1@yahoo.com','Lea Law','29 Sturdee Road','Leicester','Leicestershire','UNITED KINGDOM','LE2 9ED','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-16 19:50:08',0,NULL,3,1,3,1,'RA184569264CN\r ','lea.law\rOTHP005'),(13890,865359848012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','didic85','lainecedric@yahoo.fr','cedric laine','17 rue des mimosas<br>residence les albizzias BAT A appart 5','LESCAR','Aquitaine','FRANCE','64230','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 20:23:42',0,NULL,3,1,3,1,'RA184569366CN\r ','didic85\rMOLO009'),(13891,634562653013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','omaralexmunoz','omaralex2000@hotmail.com','Omar A Munoz','3552 Morrison Rd<br>Apt 8','Denver','CO','UNITED STATES','80219-2775','(720) 215-5547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 21:51:05',0,NULL,3,1,1,1,'\\ ','omaralexmunoz'),(13892,779690613011,320737015281,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',82.99,'eastar4','cbsshuttle','bakerberea3@aol.com','michael baker','107 Locker Ct','berea','KY','UNITED STATES','40403-1138','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 22:16:03',0,NULL,3,1,1,1,'\\ ','cbsshuttle'),(13893,780414427011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','slvrravens','jbk1978@gmail.com','Jeff Kenzie','4164 Hartford St','Saint Louis','MO','UNITED STATES','63116-3925','(231) 881-4879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 22:51:33',0,NULL,3,1,1,1,'\\ ','slvrravens'),(13894,776918111011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','nataliebackattack11','backous.natalie@gmail.com','Natalie Backous','206 4th St<br># B','Encinitas','CA','UNITED STATES','92024-3247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 22:59:40',0,NULL,3,1,1,1,'\\ ','nataliebackattack11'),(13895,634585488013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','noparyz','m.coll.subi@gmail.com','Marc Coll Subirana','Joan Maragall 24, 1º 4º esc izq','Sant Pol de Mar','Cataluña','SPAIN','08395','679847686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 23:16:01',0,NULL,3,1,2,1,'\\  ','noparyz'),(13896,780424615011,320461196670,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.98,'eastar4','cunning1_1','bozncarrie@iinet.net.au','Carrie Spooner','5/80 Wilson Pde','Heathcote','New South Wales','AUSTRALIA','2233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 23:19:29',0,NULL,3,1,2,1,'\\  ','cunning1_1'),(13897,780429989011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','blackrh1n0','matt@mattellison.com','Matthew Ellison','901 Hillcrest Dr<br>Apt 203','Hollywood','FL','UNITED STATES','33021-7853','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 23:37:29',0,NULL,3,1,1,1,'\\ ','blackrh1n0'),(13898,780442827011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ti12','ti12@hotmail.com','Hoang Ho','1611 Nelson Dr','Santa Clara','CA','UNITED STATES','95054-1645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 00:11:48',0,NULL,3,1,1,1,'\\ ','ti12'),(13899,865469469012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','nofussbid','h2@ljiang.com','VisionI Systems','2416 S Canal St','Chicago','IL','UNITED STATES','60616-2224','(312) 326-9188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 00:17:47',0,NULL,3,1,1,1,'\\ ','nofussbid'),(13900,577788343003,130554587815,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',13.98,'cnfaner','minh2010le','minhmemphis@gmail.com','Quang Le','3500 S Goodlett St','memphis','TN','UNITED STATES','38118-5014','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 00:19:03',0,NULL,3,1,1,1,'\\ ','minh2010le'),(13901,634606049013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','mfgel','gelsonnakanishi@uol.com.br','Gelson Mitsuru Nakanishi','Rua Diogo Botelho, 501','Guarulhos','São Paulo','BRAZIL','07054-060','55-11-9938-8462','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 00:29:23',0,NULL,3,1,2,1,'\\  ','mfgel\r黑色的'),(13902,738630439001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','faderellen','jerc2092@aol.com','Ellen Fader','4-03 Brennan Ct','Fair Lawn','NJ','UNITED STATES','07410-5602','(201) 791-4624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 00:29:34',0,NULL,3,1,1,1,'\\ ','faderellen'),(13903,577792033003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',30.98,'cnfaner','happybuyer2u','forwhateverworks@yahoo.com','Judy Pinkous','PO BOX 655','OAK HILL','FL','UNITED STATES','32759-0655','(386) 847-2382','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 00:46:25',0,NULL,3,1,1,1,'\\ ','happybuyer2u'),(13904,864687293012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',44.98,'eastar4','iccena','iccena@hotmail.com','Ying Tao Yang','812 Bur Oak Ave','Markham','ON','CANADA','L6E1P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 00:54:01',0,NULL,3,1,3,1,'RA117779384CN\r ','iccena\rUM00011\r棕色的蕾丝花边伞 \r再发一把 Clear Transparent Dome Birdcage Rain Umbrella w/patten 发带小猫的\r '),(13905,634616125013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','piterstreak','osmosizz@hotmail.com','Piterson Massenat Desir','713 Jackson ave','Linden','NJ','UNITED STATES','07036-2105','(407) 376-4969','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 01:02:07',0,NULL,3,1,1,1,'\\ ','piterstreak'),(13906,634628462013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','steal001','steal01@hanmail.net','Eun Seok , Park','rm 2102, 311 Dong, Trizium APT<br>35 Jam Sil Dong','Seoul','Song Pa Gu','KOREA,REPUBLIC OF','138-890','+82-10-6351-8983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 01:49:31',0,NULL,3,1,2,1,'\\  ','steal001'),(13907,780479511011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','gatewaymovies','depp1965@telia.com','joerg patolla','nymaersta graend 5','maersta','','SWEDEN','19530','0859140859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 01:54:05',0,NULL,3,1,3,1,'RA184569321CN\r ','gatewaymovie\rs\rBR3D001'),(13908,577314430003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',21.9,'cnfaner','jose*viera','taladropr@yahoo.com','Jose Viera','346 Calle 3<br>Hill Brother Parcela','San Juan','PR','PUERTO RICO','00924-3959','(787) 962-7906','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 01:59:01',0,NULL,3,1,1,1,'\\ ','jose*viera'),(13909,634641608013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','jbra8844','tutocolombia@hotmail.com','Jaime Bravo','6815 Sunalay ln','Chattanooga','TN','UNITED STATES','37421-5669','(423) 488-2193','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 02:32:45',0,NULL,3,1,1,1,'\\ ','jbra8844'),(13910,780493842011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','cvazana09','cari.gulfcoastderm@yahoo.com','Cari Vazana','2505 Harrison Ave','Panama City','FL','UNITED STATES','32405-4423','(989) 529-0417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 02:39:21',0,NULL,3,1,1,1,'\\ ','cvazana09'),(13911,8881318820916478,111,'21条CAB-6060  12条NEW CAB-2660',1,'',0,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Holzhofallee 21','Darmstadt','','GERMANY','64295','',NULL,NULL,NULL,'2011-10-17 03:08:36',0,NULL,3,1,12,1,'1107476451\r ',NULL),(13912,0,320774254107,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',7.99,'eastar4','woodone337','woodone337@gmail.com','Scott B Wood','9742 Valley Ranch Pkwy West','Irving','TX','UNITED STATES','75063','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 03:18:14',0,NULL,3,1,1,1,'\\ ','woodone337'),(13913,0,220873140454,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',10.5,'eastar4','mcant1958','flashcode@hotmail.com','Moises Cantarella','Av. Henrique Dodsworth, 133/1905 - Lagoa','Rio de Janeiro','RJ','BRAZIL','22061-030','+552122876924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 03:18:39',0,NULL,3,1,2,1,'\\  ','mcant1958'),(13914,0,230685680747,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',4.25,'eastar4','bronc52','bsul@live.com','brian sullivan','17 Fidge Crescent<br>Breakwater','Geelong','Victoria','AUSTRALIA','3219','04185440990418544099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 03:20:49',0,NULL,3,1,2,1,'\\ ','bronc52\r'),(13915,0,220873140488,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',16.99,'eastar4','watchmanz','dave@dawinters.com','D.A.Winters Ltd','39 Awanui Street','New Plymouth','TA','NEW ZEALAND','4312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 03:26:51',0,NULL,3,1,2,1,'\\  ','watchmanz'),(13916,780523005011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','larryso5','ingalarry@usa.net','inga carmack','2391 Garfield Ave SE','port orchard','WA','UNITED STATES','98366','(360) 769-5458','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 04:45:58',0,NULL,3,1,1,1,'\\ ','larryso5'),(13917,776416324011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','davidkoid','davidkoid@gmail.com','koid han keat','BLK47-G-3 TINGKAT PAYA TERUBONG 4 AYER ITAM','georgetown','PENANG','MALAYSIA','11060','0164222234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 05:07:39',0,NULL,3,1,2,1,'\\  ','davidkoid'),(13918,865561517012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',24.09,'eastar4','lucaslondon','thmpsn_lk@yahoo.com.au','Luke Thompson','46 Fuller Street<br>Collaroy Plateau','Sydney','New South Wales','AUSTRALIA','2097','61420588391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 06:13:40',0,NULL,3,1,3,1,'RA184570165CN ','lucaslondon\r客户打了三美金\rWLIN016'),(13919,8881318835120753,111,'DELL1510',1,'WLDE002',0,'eastar4','bobros','bobros@ptd.net','Robert rosendale','137 Daniel Boone Rd','Birdsboro','PA','UNITED STATES','19508-8729','',NULL,NULL,NULL,'2011-10-17 07:05:20',0,NULL,3,1,1,1,'\\ ','E邮宝改一个\r补发的 \rLK065524086CN '),(13920,634685559013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','edgar.073','et.cj1@bigpond.com','Edgar Johns','12 Michael Street','Wynnum West','Queensland','AUSTRALIA','4178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 07:09:01',0,NULL,3,1,2,1,'\\  ','edgar.073'),(13921,865586760012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','chato133','sjmfoxy@aol.com','jean-michel sampay','12, avenue alphonse daudet<br>le vatican','cabannes','Provence-Alpes-Côte d\'Azur','FRANCE','13440','04.90.92.89.07.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 07:12:38',0,NULL,3,1,2,1,'\\  ','chato133'),(13922,634690400013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','woopygoldberg2','kukuh2006@ukr.net','Yaroslav Gura','st. Plehanova<br>78','Alchevsk','Luganskaya obl','UKRAINE','94200','380662634765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 07:49:57',0,NULL,3,1,2,1,'\\  ','woopygoldberg2'),(13923,865607521012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','yanoulis123','john@imaxbg.com.au','John Yanoulis','3/396 Wellington Street COLLINGWOOD','Melbourne','Victoria','AUSTRALIA','3066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 08:36:04',0,NULL,3,1,2,1,'\\  ','yanoulis123'),(13924,865610276012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','ma3nakata','masa@alpha.dti2.ne.jp','Masanori NAKATA','1-25-4-402<br>Nakacyo','Musashino-city','Tokyo','JAPAN','180-0006','+81-422-54-0484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 08:53:18',0,NULL,3,1,2,1,'\\  ','ma3nakata'),(13925,865623197012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','megasss','m.braykovsky@gmail.com','Mikhail Braikovskiy','Luteranskaya st. 27/29 apt. 45','Kiev','','UKRAINE','01024','(044) 221-4544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 09:29:05',0,NULL,3,1,3,1,'RA184569485CN\r ','megasss\rWWOT003'),(13926,865627607012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',11.95,'eastar4uk','ninoessex','nino@capricorn-upgrades.co.uk','nino brugioni','68 west road','sawbridgeworth','Hertfordshire','UNITED KINGDOM','cm210bn','07802902908','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 09:44:00',0,NULL,3,1,3,1,'RA184569410CN\r ','ninoessex\r英标\rHSMO019'),(13927,634714047013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','leahramsey2009','leah_ramsey@hotmail.com','Leah Ramsey','RSD 90 Kimba Rd','COWELL','South Australia','AUSTRALIA','5602','0458296009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 09:51:34',0,NULL,3,1,6,1,'EE491016088CN ','leahramsey2009\r兼容型3D眼镜 通用型'),(13928,780594176011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',134.99,'eastar4uk','poklonov','m.poklonov@gmail.com','Maksim Poklonov','Voroshilov str. building 183 flat 4','Ust-Kamenogorsk','','KAZAKHSTAN','070018','+7 777 3786231','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 10:03:46',0,NULL,3,1,3,1,'RA184570041CN\r ','poklonov\rMOLO010'),(13929,865636455012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','gdmorry','gdmorry@internode.on.net','Glen Morris','16 Wildwood Road','Happy Valley','South Australia','AUSTRALIA','5159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 10:13:20',0,NULL,3,1,2,1,'\\  ','gdmorry'),(13930,865359312012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','nhapas4074','nhapas@hotmail.com','diego campelos freire','Estrada da Nogueira nº24 (Viso)','redondela','Galicia','SPAIN','36810','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 10:23:15',0,NULL,3,1,2,1,'\\  ','nhapas4074\racer 6pin1.25 23cm '),(13931,865650096012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','luis.egui','luis.eguiagaray@gmail.com','Luis Eguiagaray','Dalia, 26','Alcobendas','Madrid','SPAIN','28109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 10:56:12',0,NULL,3,1,2,1,'\\  ','luis.egui'),(13932,865651711012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',33.99,'eastar4uk','alsoesk','info@as-airportservice.de','Alen Eskandary','Friedrich-Ebert-Str:34','Neckarsteinach','','GERMANY','69239','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 11:01:03',0,NULL,3,1,3,1,'RA184570109CN\r ','alsoesk\rMOMI001'),(13933,865652912012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','pyramid_88','pyramid_88@hotmail.com','Michael Ho','Block 5022 Ang Mo Kio Industrial Park 2 #01-39','N/A','N/A','SINGAPORE','569525','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 11:05:12',0,NULL,3,1,3,1,'RA184570024CN\r ','pyramid_88\rHSIT001'),(13934,865658510012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','george_naka','hmmy.ntua@gmail.com','GJERGJI NAKA','KOKKINOPOULOU 6<br>NEES ESTIES EMP','ZOGRAFOU','ATHENS','GREECE','15771','+306984039336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 11:21:10',0,NULL,3,1,2,1,'\\  ','george_naka\r欧标'),(13935,634737496013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sz.csabi','sz.csabi.3@gmail.com','Szabó Csaba','Tagló utca 10<br>2. emelet / 7','Budapest','','HUNGARY','1097','+36-70-258-7484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 11:45:55',0,NULL,3,1,2,1,'\\  ','sz.csabi'),(13936,865671244012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',3,'OTCN005*10',42.6,'eastar4','goldbergua','china2ua@hotmail.com','Konev Kirill Vladimirovich','ul.Strijskaya, d.12/3, kv.29','Kiev','Kievskaya obl','UKRAINE','03062','+380986908595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 11:59:24',0,NULL,3,1,3,1,'RA184569715CN\r ','goldbergua\rOTCN005*10'),(13937,0,130585830549,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',10.99,'cnfaner','yadimskiy','dimskiy@gmail.com','Dmitriy Yatsenko','Gorkogo 9. f 85','Cherkassy','Cherkassy','UKRAINE','18016','+380935433091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:36:29',0,NULL,3,1,3,1,'RA184570038CN\r ','yadimskiy\rHSPL001\r新地址\rDmitriy Yatsenko\rGorkogo 9. kv. 85\rCherkassy 18016\rUkraine\r\r'),(13938,780644000011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','jcvign2b','jcv350@hotmail.com','Vignoli Jean Claude','17 rue du Professeur Santiaggi','Corte','Corse','FRANCE','20250','0495331527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:42:36',0,NULL,3,1,2,1,'\\  ','jcvign2b'),(13939,0,320774254078,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',9.5,'eastar4','jcampo2','jcampo2@gmail.com','John Campomizzi','3380 Destination Drive','Mississauga','ON','CANADA','L5M 7W7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:45:08',0,NULL,3,1,2,1,'\\  ','jcampo2'),(13940,780645174011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','causalities','causalities@gmail.com','Simon Lai','10 COCHRANE CRESCENT, THEODORE','CANBERRA','Australian Capital Territory','AUSTRALIA','2905','0262983681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:47:21',0,NULL,3,1,2,1,'\\  ','causalities'),(13941,780650462011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','yantrixyz','info@hyperportal.net','Jan Devjatko','Gonsiori 10 - 40','Tallinn','Harju','ESTONIA','10117','(372) 54518300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 13:01:27',0,NULL,3,1,2,1,'\\  ','yantrixyz'),(13942,634759018013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','lotekro','raul.oancea@yahoo.co.uk','Raul Emilian Oancea','Skoltehaugen 8','Bergen','Hordaland','NORWAY','5063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 13:22:59',0,NULL,3,1,3,1,'RA184569732CN\r ','lotekro\rMOSA003'),(13943,780661965011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','eduakrisspy','tayronn@hotmail.com','TYRONE NARVAEZ','640 Jefferson Ave','ELIZABETH','NJ','UNITED STATES','07201-1239','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 13:34:55',0,NULL,3,1,1,1,'\\  ','eduakrisspy'),(13944,634771450013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','pinguinosl65','pinguinosl65@gmail.com','Angel Pose Mayor','C/Antoni sedó 60/68 B Bj-1ª','Rubi','Cataluña','SPAIN','08191','936979130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:02:25',0,NULL,3,1,2,1,'\\  ','pinguinosl65\rHP 8pin 1.0 23cm '),(13945,634770642013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','sma328','sma328@yahoo.ca','Stephen Ma','#603 8340 Jasper Ave., NW.,','Edmonton','AB','CANADA','T5H4C6','(780) 990-8088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:04:42',0,NULL,3,1,3,1,'RA184570585CN ','sma328\rGLOT001*3\r兼容型3D眼镜 通用型'),(13946,634774414013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','2jw1052','bears10522@hotmail.com','Jae Wan Jung','Unit 30, Phoenix Distribution Park<br>Phoenix Way','Heston','Middlesex','UNITED KINGDOM','TW5 9NB','07894233815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:14:54',0,NULL,3,1,3,1,'RA184569865CN\r ','2jw1052\rMOSA004'),(13947,780611986011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','odemiral12','odemiral@superonline.com','OGUZHAN DEMIRAL','SOYAK OLIMPIYAKENT C2-2 ATAKENT<br>HALKALI','ISTANBUL','','TURKEY','34303','+90 212 4654658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:16:34',0,NULL,3,1,2,1,'\\  ','odemiral12'),(13948,865722645012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',27.78,'eastar4','xavomai52','xavomai@gmail.com','Sean Meadows','767 Clinton Pkwy<br>Copiah Bank','Clinton','MS','UNITED STATES','39056-5245','(601) 924-2200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 14:17:46',0,NULL,3,1,1,1,'\\  ','xavomai52'),(13949,634786706013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','pixel1240','pixel1240@yahoo.com.sg','Stanley Pek','Blk 536 Ang Mo Kio Ave 10 #03-2557<br>S(560536)','default','','SINGAPORE','560536','+65 93871806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:58:56',0,NULL,3,1,11,1,'RA184569785CN\r ','pixel1240\rHSSA002'),(13950,780691164011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',75.96,'eastar4','wanjalichtenwald','w.lichtenwald@web.de','Johannes Lichtenwald','Lützowstr. 31','Siegen','','GERMANY','57076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:58:58',0,NULL,3,1,3,1,'RA184569729CN\r ','wanjalichtenwald\rHSNO019\r欧标\r一共买了两个'),(13951,577961341003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',12.9,'cnfaner','sjallipa','sjallipalli@gmail.com','Sreekanth Jallipalli','9706 S 92nd East Ave','Tulsa','OK','UNITED STATES','74133-6128','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 15:15:59',0,NULL,3,1,1,1,'\\  ','sjallipa'),(13952,865747300012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','maxflow','mpoiesz@gmx.de','Martin Poiesz','Universitätsstraße 49','Köln','','GERMANY','50931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 15:19:29',0,NULL,3,1,2,1,'\\  ','maxflow'),(13953,634807581013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','2011stasy777','stasy777@mail.ru','Anastasiya Shishin','hazaz haim 3','Haifa','Haifa','RUSSIAN FEDERATION','34996','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 16:12:41',0,NULL,3,1,2,1,'\\  ','2011stasy777'),(13954,780718135011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','fishsoupisgood','ebay@madingley.org','James McKenzie','Citrix R<br>101 Science Park','CAMBRIDGE','Cambridgeshire','UNITED KINGDOM','CB4 0FY','01223225900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 16:48:39',0,NULL,3,1,3,1,'RA184569763CN\r ','fishsoupisgood\r英标\rHSPL010'),(13955,634826132013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','epeolatric','megan@meganbaker.net','Megan Baker','Hermannstr. 144','Berlin','','GERMANY','12051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:01:32',0,NULL,3,1,2,1,'\\  ','epeolatric'),(13956,780753527011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','jacksonsy1','yasinalam1@gmail.com','yasin alam','104 nollamara avenue','nollamara ','Western Australia','AUSTRALIA','6061','0861423106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:16:52',0,NULL,3,1,3,1,'RA184570055CN\r ','jacksonsy1\rBR3D001'),(13957,577995769003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.95,'cnfaner','createmyworld','kamelion@paonline.com','Beth Petricoin','938 Orchard St','Akron','PA','UNITED STATES','17501-1526','(717) 859-2036','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 17:22:46',0,NULL,3,1,1,1,'\\  ','createmyworld'),(13958,865801310012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','penny_bear','tardiff@andrews.edu','Charee Tardiff','1825 W Lakeview Dr<br>Apt J82','Johnson City','TN','UNITED STATES','37601-4356','(906) 399-2000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 17:24:46',0,NULL,3,1,1,1,'\\  ','penny_bear'),(13959,634835262013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','zombunis','antanasmo@hotmail.com','Antanas Mozuraitis','32 Thornfield Square<br>Clondalkin','Dublin','','IRELAND','D22','0857258443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:26:03',0,NULL,3,1,2,1,'\\  ','zombunis'),(13960,865819211012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','0191dave121234','dave121234@sky.com','David Richardson','12 Brecon Close<br>Etal park','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE5 4TD','01912711490','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 17:35:20',0,NULL,3,1,3,1,'RA184570015CN\r ','0191dave121234\rGLSG001*2'),(13961,780781294011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','nexusp','kofiansah@hotmail.com','Sangu Barnes','804 Classon Ave<br>Frnt Desk','Brooklyn','NY','UNITED STATES','11238','(646) 623-6649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 18:02:30',0,NULL,3,1,1,1,'\\  ','nexusp'),(13962,780781263011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','butcherooo','adam.stachurski@gmail.com','Adam Stachurski','47<br>Hadland Road','Abingdon','Oxfordshire','UNITED KINGDOM','OX14 3YH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 18:02:51',0,NULL,3,1,2,1,'\\  ','butcherooo'),(13963,583552004004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','dwsbones','huesos@comcast.net','David Stevens','35 Viewcrest Dr','Bountiful','UT','UNITED STATES','84010-1373','(801) 397-5705','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 18:06:49',0,NULL,3,1,1,1,'\\  ','dwsbones'),(13964,865862145012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','tuspaticas','jsoria@telepolis.com','Javier Soria','Dr Orts Llorca 16, 13º A','Benidorm','Alicante','SPAIN','03503','649316623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 18:39:28',0,NULL,3,1,2,1,'\\  ','tuspaticas'),(13965,780818520011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','ensiekei','nickv@telenet.be','Nicky Vandebeek','Spurkerweg 13','Bilzen','','BELGIUM','3740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 19:02:34',0,NULL,3,1,2,1,'\\  ','ensiekei'),(13966,780822589011,320774352320,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT003',10.99,'eastar4uk','nachfogler','svens@stackframe.org','Sven Schnelle','Kreuzstr. 4','Kronau','','GERMANY','76709','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 19:10:28',0,NULL,3,1,2,1,'\\  ','nachfogler'),(13967,780847090011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','jondoa1','jondoa@sky.com','Michael Stevens','10 Islwyn Rd<br>Wattsville','Newport','Gwent','UNITED KINGDOM','NP117QH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 19:47:40',0,NULL,3,1,2,1,'\\ ','jondoa1'),(13968,865909915012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','alexander_sydorenko','shurik303@gmail.com','OLEKSANDR SYDORENKO','200 let Khersona str. 16, apt. 35','Kherson','Kherson','UKRAINE','73034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 19:50:24',0,NULL,3,1,2,1,'\\  ','alexander_sydorenko'),(13969,865933113012,220806848943,'Transparent Dome Rain Sun Umbrella with purple trim',1,'UMTR001',19.99,'eastar4','clown_girl','nina06.05@mail.ru','Nina Garina','26 bakinskih komissarov,4/3-40','Moscow','Moscow','RUSSIAN FEDERATION','119526','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 20:25:28',0,NULL,3,0,2,1,'\\  ','clown_girl\r紫色的\r已入库'),(13970,578079476003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.98,'cnfaner','sparscale','stevep@teacher.com','Steven Parscale','9863 W 359th St<br>Steve Parscale','Paola','KS','UNITED STATES','66071-6505','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 20:31:40',0,NULL,3,1,1,1,'\\  ','sparscale'),(13971,780871392011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','alenkaonfire','sm.vladimir@gmail.com','Владимир Смогоржевский','Изюмская д.57 к.1','Москва','','RUSSIAN FEDERATION','117624','+7 (926) 1009518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 20:33:24',0,NULL,8,1,17,0,NULL,'alenkaonfire\r\r\r'),(13972,634918198013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',62.5,'eastar4','poppybandit2004','juliekeylock@sky.com','Mrs J Keylock','14 The Copse<br>Lindfield','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 2EZ','07748598981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 20:35:47',0,NULL,3,1,3,1,'RA184569777CN\r ','poppybandit2004\rHBPH002'),(13973,0,140617597289,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',17,'cnfaner','michy2011','mqn2011@gmail.com','michelle quijano','DP12 Calle Hungria<br>Santa Juanita # DP12','Bayamon','PR','UNITED STATES','00956-5323','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 20:39:16',0,NULL,3,1,1,1,'\\  ','michy2011'),(13974,780878937011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','alenkaonfire','sm.vladimir@gmail.com','Smogorzhevskiy Vladimir Sergeyevich','57-2 Izumskaja St. Apt.18','Moscow','Moscow','RUSSIAN FEDERATION','117624','(926)1009518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 20:55:22',0,NULL,3,1,2,1,'\\  ','alenkaonfire\r一共买了两个\r'),(13975,739087307001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','bullcon570','bullcon@verizon.net','angel ortiz','3 Flagstone Ln','east stroudsburg','PA','UNITED STATES','18302-8128','(570) 223-6691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:18:07',0,NULL,3,1,1,1,'\\  ','bullcon570'),(13976,634933189013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','ssmossman','sean_mossman@hotmail.com','Sean Mossman','621 Nottingham Dr.','Richardson','TX','UNITED STATES','75080','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:18:11',0,NULL,3,1,1,1,'、 ','ssmossman'),(13977,865961863012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','chiefjimmyd','james.dixson@comcast.net','James Dixson','328 N Sullivan Rd<br>Ste 3','Spokane Valley','WA','UNITED STATES','99037-8542','(509) 343-0273','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:22:17',0,NULL,3,1,1,1,'\\  ','chiefjimmyd'),(13978,634935166013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','e-saleandbuy','ebay@itisit.co.uk','John Ballard','8 Beechwood Drive','Cobham','Surrey','UNITED KINGDOM','KT11 2DX','01372849668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 21:25:18',0,NULL,3,1,2,1,'\\  ','e-saleandbuy'),(13979,578096859003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','7279mike','mbetschart@tcco.com','Mike Betschart','148 Midship Dr','Hercules','CA','UNITED STATES','94547-2083','(415) 726-9982','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 21:25:47',0,NULL,3,1,1,1,'\\  ','7279mike'),(13980,634936478013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','parrotlove','pt_blue@msn.com','Timothy Schmuck','2877 Robin Rd','York','PA','UNITED STATES','17404-5726','(717) 792-4320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:29:42',0,NULL,3,1,1,1,'\\  ','parrotlove'),(13981,780903408011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',19.99,'eastar4','ezie3256','ewaziegler@bellsouth.net','ewa ziegler','1032 Springdale Cir','palm springs','FL','UNITED STATES','33461-6358','(561) 352-8214','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:35:47',0,NULL,3,1,1,1,'\\  ','ezie3256\r西瓜伞 '),(13982,634938721013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','buggerdoug','mdzarb@yahoo.com','michael zaruba','310 E Elm St','lone tree','IA','UNITED STATES','52755-9705','(319) 629-5617','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:39:28',0,NULL,3,1,1,1,'\\','buggerdoug\r兼容型3D眼镜 通用型'),(13983,780905799011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mrcain8zuy','mrvladg@gmail.com','Vladek Gologursky','5 Gallatin Dr','Dix Hills','NY','UNITED STATES','11746-7947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 21:42:23',0,NULL,3,1,1,1,'、 ','mrcain8zuy'),(13984,780907644011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','davidsuppree','suppreedrd@googlemail.com','David Suppree','14 Rodborough Road<br>Golders Green','London','London','UNITED KINGDOM','NW11 8RY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 21:46:02',0,NULL,3,1,3,1,'RA184569794CN\r ','davidsuppree\rRELO003'),(13985,780921793011,320755995166,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.99,'eastar4','jcfudge3','chefchun@yahoo.com','Joseph Fudge','6699 Cox Ave','Gloucester','VA','UNITED STATES','23061-5192','(757) 870-4043','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 22:24:58',0,NULL,3,1,1,1,'\\  ','jcfudge3'),(13986,578109791003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','kayrican81','kvasquez0281@gmail.com','Kevin Vasquez','9040 SW 168 Ave','Miami','FL','UNITED STATES','33196','(786) 473-1504','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 22:25:07',0,NULL,3,1,1,1,'\\  ','kayrican81\r发OEM的'),(13987,780930438011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','gp4gp','gpasman@gmail.com','Gerrie Pasman','4831 Pinemont Dr','Campbell','CA','UNITED STATES','95008-5715','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 22:54:13',0,NULL,3,1,1,1,'\\  ','gp4gp'),(13988,780937681011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','celtjay','celtjay@yahoo.co.uk','Jason Gallagher','177E BLACKNESS ROAD','DUNDEE','Dundee (City of)','UNITED KINGDOM','DD1 5PH','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,0,18,0,NULL,'celtjay'),(13989,583657367004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','grnshell','rheagan3333@yahoo.com','Shelley A Glenn','2864 S Nettleton Ave','Springfield','MO','UNITED STATES','65807-5970','(417) 840-5993','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 23:33:22',0,NULL,3,1,1,1,'\\  ','grnshell'),(13990,583663510004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','evenyc24','lopeze@atlanticbb.net','Eve Lopez','100 Kings Point Dr<br>Apt 1207','Sunny Isles Beach','FL','UNITED STATES','33160-4786','(305) 949-8599','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 00:01:22',0,NULL,3,1,1,1,'\\  ','evenyc24'),(13991,634979018013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','rootb33r','naratcliffe@gmail.com','Nicholas Ratcliffe','935 Harvard St','Rochester','NY','UNITED STATES','14610-1711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 00:24:03',0,NULL,3,1,1,1,'\\  ','rootb33r'),(13992,780961137011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','2kenparent','2kenparent@rogers.com','Ken Parent','4475 White Egret Lane','Sarasota','FL','UNITED STATES','34238','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 00:41:29',0,NULL,3,1,1,1,'\\ ','2kenparent'),(13993,866039860012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','(rice)boi','edlam_168@hotmail.com','ed lam','6952 14TH AVE','MARKHAM','ON','CANADA','L6B 0G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 00:57:16',0,NULL,3,1,3,1,'RA184569879CN\r ','(rice)boi\rOTSO004*2'),(13994,780973122011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','comet_crusier','comet61@gvtc.com','Andrew Lerner','291 Laswell Lane','Bulverde','TX','UNITED STATES','78163','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 01:21:17',0,NULL,3,1,1,1,'\\  ','comet_crusier'),(13995,0,220873140322,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','canalstop','challengerli@yahoo.com','Queen Accessory INC','359 Canal St','New York','NY','UNITED STATES','10013-0493','(917) 834-0198','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 01:31:45',0,NULL,3,1,1,1,'\\  ','canalstop'),(13996,583683733004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','oscarchavesalvarado','oscar.alaorden@gmail.com','Oscar Chaves','7979 NW 21st St<br>Oscar Chaves Alvarado # SJO 45304','DORAL','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 01:42:23',0,NULL,3,1,1,1,'\\  ','oscarchavesalvarado'),(13997,631542595013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','marciototal2009','ebaymarcio@gmail.com','Marcio Fonseca','Rua Potengi 521 ap 603','Natal','Rn','BRAZIL','59020030','558488561640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 02:03:44',0,NULL,3,0,3,1,'RA184570571CN ','marciototal2009\rGLOT001*2\r兼容型3D眼镜 通用型'),(13998,578157277003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','jhau9441','tigre.hk@hotmail.com','JOSE HAU TUN','20225 Bothell Everett Hwy<br>Apt 2028','BOTHELL','WA','UNITED STATES','98012-8192','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 02:18:25',0,NULL,3,1,1,1,'\\  ','jhau9441'),(13999,0,230684151305,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',3,'eastar4','fax_petroline','petroline1@gmail.com','Aleksey Petrov','Ul. Kommuny 26-1-156','Санкт-Петербург','Saint-Petersburg','RUSSIAN FEDERATION','195298','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 02:24:14',0,NULL,3,1,2,1,'\\  ','fax_petroline'),(14000,0,230685680866,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',3.25,'eastar4','happyfinder','talunan@sbcglobal.net','Tamzon E. Alunan','1780 D St','Hayward','CA','UNITED STATES','94541-4323','(510) 690-1704','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 03:04:28',0,NULL,3,1,1,1,'\\  ','happyfinder'),(14001,635018057013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',24.99,'eastar4','bakakinchan','kinza.ahmed@hotmail.com','Kinza Ahmed','3743 Crabtree Cres','Mississauga','ON','CANADA','L4T1S7','(647) 988-1435','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'bakakinchan'),(14002,739193953001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','ammar11','ammar111@yahoo.com','ammar almansour','4071 Richfield Rd','Flint','MI','UNITED STATES','48506-2008','(810) 348-9333','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 03:46:35',0,NULL,3,1,1,1,'\\  ','ammar11'),(14003,866090459012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','varathan66','varathan@yahoo.com','veluppillai varathan','73b montezuma trail','scarborough','ON','CANADA','M1V1k4','(416) 731-2453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 03:50:43',0,NULL,3,1,2,1,'\\  ','varathan66'),(14004,721715469008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',32.99,'au-buy','lakerjames','jdmonty1@gmail.com','James Montgomery','9 Royalston','Mission Viejo','CA','UNITED STATES','92692-5143','(949) 581-5930','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-18 03:57:39',0,NULL,3,1,1,1,'\\  ','lakerjames'),(14005,635025464013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','jenti_hirji','jentigorasiya@yahoo.com','Jenti Gorasiya','12 Kensington Crescent','Enfield','South Australia','AUSTRALIA','5085','0424503576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 04:04:40',0,NULL,3,1,2,1,'\\  ','jenti_hirji\r澳标'),(14006,781020592011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','gtibo','gervaisthibault@mac.com','Gervais Thibault','44 rue des Trefles','Sept-Iles','QC','CANADA','G4S 2A4','(418) 962-9507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 04:36:15',0,NULL,3,1,2,1,'\\ ','gtibo'),(14007,777913414011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','10ftsurf','jcannard@tpg.com.au','Ange and John Cannard','2 Olive Street','Hendra','Queensland','AUSTRALIA','4011','0736301862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 04:56:00',0,NULL,3,1,2,1,'\\ ','10ftsurf'),(14008,781031257011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','celsobadaue','badauestore@gmail.com','CELSO BADAUE','1204 HIGHLAND DR','CEDAR PARK','TX','UNITED STATES','78613-7119','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 05:36:10',0,NULL,3,1,1,1,'\\ ','celsobadaue'),(14009,635042242013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',2,'BTDE2002',19.76,'eastar4','gremlin106','gremlin106@knology.net','Michael Johnson','106 Terry Ave','Summerville','SC','UNITED STATES','29485','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 06:02:35',0,NULL,3,1,1,1,'\\  ','gremlin106'),(14010,739217677001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','correauno','mgr@proempaques.com','Hernando Correa','8342 NW 56th St<br>Miami Florida 33166','Doral','FL','UNITED STATES','33166-4020','305 513 9050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 06:10:31',0,NULL,3,1,1,1,'\\  ','correauno'),(14011,781051249011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','cool_thingz','todd7310@gmail.com','Todd Palmer','100 Tarleton St','East Devonport','Tasmania','AUSTRALIA','7310','0437602550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:17:48',0,NULL,3,1,2,1,'\\  ','cool_thingz'),(14012,781053210011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',2,'RELO002',25.94,'eastar4','tokiyoo88','tokidokioki@hotmail.com','David Sackville','232 Arthur St<br>Level 1, Cru Digital','Newstead','Queensland','AUSTRALIA','4006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:28:13',0,NULL,3,1,2,1,'\\  ','tokiyoo88'),(14013,635055572013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',16.58,'eastar4','ide_1234','iejielat@gmail.com','Iyad Ejielat','Level1 367 Collins St','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:30:31',0,NULL,3,1,2,1,'\\ ','ide_1234'),(14014,635059955013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','gangefors','gangefors@gmail.com','Stefan Gangefors','Örnvägen 74 lgh 1001','Lund','','SWEDEN','22731','+46703943991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:00:29',0,NULL,3,1,2,1,'\\  ','gangefors'),(14015,578208021003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','dpvincenty11','dpvincenty@gmail.com','daniel vincenty','4 Sebastiani Blvd','gaithersburg','MD','UNITED STATES','20878-4120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 08:14:26',0,NULL,3,1,1,1,'\\  ','dpvincenty11'),(14016,781066497011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','helipilot72','iosif_mykonios@hotmail.com','IOSIF MYKONIOS','SESKLOU 9','VOLOS','MAGNISIA','GREECE','38333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:23:54',0,NULL,3,1,2,1,'\\ ','helipilot72\r欧标'),(14017,866149946012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','shaehovarr','ginka@torba.com','Regina Shaehova','Dostoevskogo 53-147','Kazan','','RUSSIAN FEDERATION','420043','7-843-9179323912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:29:50',0,NULL,3,1,2,1,'\\  ','shaehovarr\r蓝天白云长柄伞'),(14018,866150775012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','chefrob58','robin.tully@bigpond.com','Robin Tully','10 devon street','west preston','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:31:28',0,NULL,3,1,3,1,'RA184570293CN\r ','chefrob58\rOTSO004*2'),(14019,635064847013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','silvakes83','silvakes@gmail.com','Mikhail Seliverstov','Stalevarov, 4A, 19','Electrostal','','RUSSIAN FEDERATION','144008','9261111111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:33:52',0,NULL,3,1,3,1,'RA184570302CN\r ','silvakes83\rOTRA003'),(14020,8881318929076147,111,'dell 1510',1,'WLDE002',0,'eastar4','protacio440e','matt.protacio@gmail.com','Matthew Protacio','5656 Kungle Rd','Barberton','OH','UNITED STATES','44203-7837','(330) 825-8292',NULL,NULL,NULL,'2011-10-18 09:11:16',0,NULL,3,1,1,1,'\\  ',' 补发  E邮宝改一个  记得录号在这里\rLK042188545CN'),(14021,781078031011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','mrsshady64','kevin@krichardson1.orangehome.co.uk','KEVIN RICHARDSON','10 DOWNVIEW ROAD<br>MARTIN','FORDINGBRIDGE','Hampshire','UNITED KINGDOM','SP6 3LP','01725519438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 09:11:36',0,NULL,3,1,2,1,'\\  ','mrsshady64\r英标'),(14022,778592356011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',39.99,'eastar4','bmw_shcrott','zap4asti_kz@mail.ru','Anatoliy Lissin','8 Microdistrict<br>house 19, apartment 7','Almaty','','KAZAKHSTAN','050035','+7 701 739 78 92','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 09:32:19',0,NULL,3,1,2,1,'\\  ','bmw_shcrott'),(14023,635082382013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','v.kotelkov','vasily.kotelkov@gmail.com','VASILY KOTELKOV','Rustavely str. dom 3 korp.7 kv.12','MOSCOW','MOSCOW','RUSSIAN FEDERATION','127254','+74957648543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 09:59:08',0,NULL,3,1,2,1,'\\  ','v.kotelkov'),(14024,864355551012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','knackers100','pmichailides@gmail.com','032Con Michailides','20 Wild Cherry St','Melbourne','Victoria','AUSTRALIA','3032','0393182210','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'knackers100'),(14025,781099160011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',10,'HSJA006',139.5,'eastar4','1082claire','taxiclt@live.com','claire taylor','4a cheapside<br>wakefield','wakefeild','West Yorkshire','UNITED KINGDOM','wf1 2sd','01924364044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 10:29:02',0,NULL,3,1,3,1,'RA184570639CN ','1082claire\rHSJA006\r英标\r新地址\rclaire taylor\race taxis ltd \r4a cheapside\rwakefield\rwakefeild West Yorkshire wf1 2sd\rUNITED KINGDOM\r01924364044'),(14026,866190610012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','madame_bizarre','madame@atelierbizarre.com','Joanna Kostrzewa','Zwirki i Wigury 45a m.5','Warsaw','mazowieckie','POLAND','02-091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 10:50:02',0,NULL,3,1,3,1,'RA184570452CN\r ','madame_bizarre\rOTSO002'),(14027,866192463012,220806892229,'NEW Galleria Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','wiam80','liam@fcgroup.com.au','Liam Kenny','24 Lum Jim Street<br>Redlynch','Cairns','Queensland','AUSTRALIA','4870','0421798856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 10:55:52',0,NULL,3,1,2,1,'、 ','wiam80\r向日葵长柄伞  '),(14028,866203229012,220713846376,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+carcharger',1,'HSNO016+CCNO001',13.9,'eastar4uk','13sqaush','martin-harrison1@sky.com','Martin Harrison','Uttoxeter Road','Blythe Bridge','Staffordshire','UNITED KINGDOM','st11 9hq','07702380921','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 11:30:11',0,NULL,3,1,3,1,'RA184570435CN\r ','13sqaush\rHSNO016+CCNO001'),(14029,781126888011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','shkabo2008','grga69@gmail.com','Grga Kolic','Ruder Josip Boskovic 7 B','Zagreb','','CROATIA','10000','+385912338608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 11:54:26',0,NULL,3,1,2,1,'\\  ','shkabo2008'),(14030,583784522004,140583345997,'GENUINE Plantronics Voyager 520  Bluetooth Headset',2,'HSPL011',65.98,'cnfaner','nestor_j_f','nestor_j_f@yahoo.com','NESTOR RIVERA','Urb. Bairoa Park A-10 Parque de los Heroes','Caguas','PR','UNITED STATES','00727-1254','(787) 717-5709','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 12:06:03',0,NULL,3,1,1,1,'\\  ','nestor_j_f'),(14031,583791528004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','yzrusty999','rmyers467329@comcast.net','Russell Myers','17691 Oakmont Ridge Cir','Fort Myers','FL','UNITED STATES','33967-5295','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 12:43:23',0,NULL,3,1,1,1,'\\  ','yzrusty999'),(14032,781150656011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','merzkiy2005','7393422@mail.ru','Alecsey Petrov','Rimskogo-Korsakova 18 15','Moscow','','RUSSIAN FEDERATION','127566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 13:08:13',0,NULL,3,1,2,1,'\\  ','merzkiy2005'),(14033,739216445001,110715183632,'NIB CBS High Pressure Portable Car Washer wash 12L',1,'CAWA002',89.9,'buysia','minder027','elnursa@agbank.az','Elnur Alizada','16 Landau str.','Baku','','AZERBAIJAN','AZ1073','+99455 6000227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 13:11:39',0,NULL,3,0,5,1,'CP238090261CN ','minder027\rCAWA002'),(14034,866245089012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Michael Tveskov','42 AGAWAM RD','Acton','MA','UNITED STATES','01720-2446','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 13:27:50',0,NULL,3,1,1,1,'\\  ','321expressllc'),(14035,781161235011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','owlscohk','everay2003@yahoo.com','KWAN CHUN LEUNG','F14-C, Block 5, Hibiscus Court, World-wide Gardens<br>7 Lung Pak Street, Tai Wai, Shatin, N.T.,','default','','HONG KONG','default','(852) 91919841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 13:39:26',0,NULL,3,1,2,1,'\\  ','owlscohk'),(14036,781163201011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','randnhamad','rnhamad@roadrunner.com','Nancy Hamad','8451 Edgelake Oval','Sagamore Hills','OH','UNITED STATES','44067','(330) 467-8677','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 13:45:24',0,NULL,3,1,1,1,'\\  ','randnhamad'),(14037,781168382011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','1967svv','serge020767@mail.ru','Сергей Воротынцев','Фестивальная ул.,д.38,кв.131','Москва','Москва','RUSSIAN FEDERATION','125414','(926)4967937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 14:03:37',0,NULL,3,1,3,1,'RA184570497CN\r ','1967svv\rOTSA001'),(14038,781171999011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','chris_earl','chrisjohnearl@hotmail.co.uk','Chris Earl','Hatton Court Hotel<br>Upton St Leonards','Gloucester','Gloucestershire','UNITED KINGDOM','GL4 8DE','0798814372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 14:07:13',0,NULL,3,1,2,1,'\\  ','chris_earl\r英标'),(14039,866239430012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',95.99,'eastar4','mesutmrcn','mesut@mrcn.net','mesut mercan','Barbaros Bulvarı Orhan Birman Plaza No:149 Kat:9<br>Balmumcu 34349','Istanbul','','TURKEY','34349','(535)277-7727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 15:09:56',0,NULL,3,1,3,1,'RA184570608CN ','mesutmrcn\rOTKE001'),(14040,776180429011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','lillyjy','3ly@qlink.queensu.ca','Lilly Yonadam','1463 Indian Grove','Mississauga','ON','CANADA','L5H 2S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 15:12:12',0,NULL,3,1,2,1,'\\  ','lillyjy'),(14041,739363534001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','tonycheryl55','estel3511@comcast.net','Cheryl Estel','3511 W Hallett Rd','Hillsdale','MI','UNITED STATES','49242-9482','(517) 437-3786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 15:14:23',0,NULL,3,1,1,1,'\\  ','tonycheryl55'),(14042,773757899011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','a.ha1der','ali.h@gmx.com','Ali Haider','4542 Dora Cres.','Ottawa','ON','CANADA','k1j8s4','(613) 301-2544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 15:21:35',0,NULL,3,1,2,1,'\\  ','a.ha1der'),(14043,781204073011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','antbargainjr','mikerizz@gmail.com','Michael Rziemkowski','765 S Rosedale CT','Grosse Pointe Woods','MI','UNITED STATES','48236-1146','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 15:28:59',0,NULL,3,1,1,1,'\\  ','antbargainjr'),(14044,781209259011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.49,'eastar4uk','vekutin','ville.ikavalko@gmail.com','ville ikävalko','tuulikinkatu 3 D 33','kotka','SD','FINLAND','48700','+358453469419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 15:41:49',0,NULL,3,1,2,1,'\\  ','vekutin'),(14045,866301608012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',4,'OTIN005',316,'eastar4','lordvadr','ebay-do-not-disclose-do-not-spam@cjoster.com','CJ Oster','1300 S Neil St','Champaign','IL','UNITED STATES','61820','(217) 344-4444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 15:44:36',0,NULL,3,1,4,1,'YW868053212CN ','lordvadr'),(14046,866307994012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','juliagemela','karetoebay@gmail.com','Pedro Molero Requena','C/ Cuba, 29-C','Valdepeñas (Ciudad Real)','Castilla-La Mancha','SPAIN','13300','627752642','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 15:57:00',0,NULL,3,1,2,1,'、 ','juliagemela'),(14047,866313068012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','virgilio7984','vodlar@yahoo.com.mx','virgilio ordaz de la rosa','diaz quintas 113<br>centro','oaxaca','Oaxaca','MEXICO','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 16:07:14',0,NULL,3,1,2,1,'\\  ','virgilio7984'),(14048,866319409012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','dawn200179','dawn.robinson784@btinternet.com','dawn robinson','6 clump field<br>cambridge drive','ipswich','Suffolk','UNITED KINGDOM','ip2 9ga','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 16:19:47',0,NULL,3,1,3,1,'RA184570449CN\r ','dawn200179\rHSPL011\r英标'),(14049,866319448012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','bustersbrampton','s_bustersbrampton@rogers.com','bustersbrampton','295 queen street east','brampton','ON','CANADA','l6w 3r1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 16:20:02',0,NULL,3,1,2,1,'\\ ','bustersbrampton'),(14050,0,230684150417,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',17.5,'eastar4','pditty04','dmccu004@hotmail.com','Andre McCullum','1215 Starlight Dr','Shelby','NC','UNITED STATES','28152','(704) 600-5270','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 16:26:00',0,NULL,3,1,1,1,'\\  ','pditty04'),(14051,866165450012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','utta12','alan.copeland@sky.com','alan copeland','24 taplin close','stafford','Staffordshire','UNITED KINGDOM','st16 1nw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 16:38:53',0,NULL,3,1,3,1,'RA184570378CN\r ','utta12\rGLOT005'),(14052,866341321012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',2,'OTGR001+OTGR002',79.8,'eastar4','vladimirmi','finwise@gmail.com','VOLODIMIR MIHAYLOV','per.2 Odesskij dom 9 kv.2','Cherkassy','','UKRAINE','18023','+380505025230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 17:07:05',0,NULL,3,1,3,1,'RA117779305CN\r ','vladimirmi\rOTGR001+OTGR002'),(14053,635197849013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',2,'WLIN013',35.98,'eastar4','earlygimlet','dicekool@yahoo.co.jp','Daisuke Tanaka','5-33 Ebahonmachi<br>Naka-ku','Hiroshima','Hiroshima','JAPAN','730-0833','81-82-293-9082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 17:08:35',0,NULL,3,1,3,1,'RA184570381CN\r ','earlygimlet\rWLIN013'),(14054,781247667011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',39.96,'eastar4','bjmurton','bjm@noc.soton.ac.uk','Bramley Murton','Lincluden<br>Partridge Road','Brockenurst','Hampshire','UNITED KINGDOM','so42 7rz','01590624890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 17:08:58',0,NULL,3,1,3,1,'RA184570996CN\r ','bjmurton\rWLAP002'),(14055,635021622013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','jhefcarvalho','jefersonscarvalho@gmail.com','Jhef Carvalho','Rua A, Num. 60, Cond. Vila Rica, Apt. 1608-B<br>Setor Leste Vila Nova','Goiânia','Goiás','BRAZIL','74645-210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 17:17:18',0,NULL,3,1,2,1,'\\  ','jhefcarvalho'),(14056,863504129012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',2,'BALO001',23.98,'eastar4','angoram1','angoram@aol.com','A Bell','PO Box 1390','Texas City','TX','UNITED STATES','77592-1390','(409) 944-0065','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 17:29:37',0,NULL,3,1,1,1,'\\  ','angoram1'),(14057,779970531011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','making1959','m.kingsbury1@virgin.net','Michael Kingsbury','Holbury House, 13 Y Dderwen, Llangynwyd','Maesteg','Bridgend','UNITED KINGDOM','CF349HX','01656737191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 17:49:35',0,NULL,3,1,3,1,'RA184570700CN ','making1959\r兼容型3D眼镜 通用型\rGLOT001\r新地址\rSally Kingsbury\rCameron Jones Hussell and Howe\r1-3 Grove Place\rPort Talbot, West Glamorgan SA13 1HX\rUNITED KINGDOM\r01656737191\r'),(14058,0,140617596825,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',9.99,'cnfaner','deztrees','t.stallworth1@gmail.com','tobias stallworth','128 green acres rd','valley stream','NY','UNITED STATES','11581-1506','(718) 810-9256','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 18:07:20',0,NULL,3,1,1,1,'\\  ','deztrees'),(14059,583887725004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','michaelmannella','mm@leearea.net','Michael Mannella','16322 Maya Circle','Punta Gorda','FL','UNITED STATES','33955','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 18:24:20',0,NULL,3,1,1,1,'\\  ','michaelmannella'),(14060,781292284011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','stglobul','stglobul@hotmail.com','Richard Paillé','42 de l\'Artisan','Victoriaville','QC','CANADA','G6P7E3','(819) 758-7632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 18:26:12',0,NULL,3,1,2,1,'\\  ','stglobul'),(14061,578365572003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',64.99,'cnfaner','lipmanma','matthewlipman@yahoo.com','Matt Lipman','100 Jay St<br>Apt 29H','Brooklyn','NY','UNITED STATES','11201-1609','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 18:41:07',0,NULL,3,1,1,1,'\\  ','lipmanma'),(14062,781319314011,320602988656,'2.1 HP DV6300 DV6400 DV6500 Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','great_alexander23','axel23@windowslive.com','alexander hatzikampouris','aristotelous 6<br>agioi anargyroi','athens','greece','GREECE','13562','(+03)6944768443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 19:09:42',0,NULL,3,1,2,1,'\\','great_alexander23\rHP 8pin 1.25 18cm '),(14063,0,220871181762,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',7.5,'eastar4','xxprecious08xx','xxxprecious08xxx@gmail.com','Annie Huynh','1310 Havenrock Dr','Forney','TX','UNITED STATES','75126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 19:21:53',0,NULL,3,1,1,1,'\\  ','xxprecious08xx'),(14064,583913101004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','eugene8572','dacson_inc@yahoo.com','Eugene Kovinkov','1098 Lee Street','Des Plaines','IL','UNITED STATES','60016','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 19:35:09',0,NULL,3,1,1,1,'\\  ','eugene8572'),(14065,781355594011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','johncato','jc.k@online.no','John-Cato Kvanli','Båsmosjyen 21','8616','','NORWAY','Mo i Rana','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 20:12:12',0,NULL,3,1,2,1,'\\ ','johncato\r欧标'),(14066,781361604011,320730088269,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',9.99,'eastar4uk','tatevik_2009','tamea@rambler.ru','Tatevik Melkumyan','Arzumanian 34<br>apt. 30','Yerevan','','ARMENIA','0099','(+374)55 39 45 81','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 20:21:35',0,NULL,3,1,2,1,'、 ','tatevik_2009'),(14067,781366348011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',41.69,'eastar4uk','synthesizer_maniac','esioan667@gmail.com','Naoise O\' Sullivan','9 The Orchard<br>Summerhill','Mallow','Cork','IRELAND','','0857214616','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 20:31:26',0,NULL,3,1,3,1,'RA184570418CN\r ','synthesizer_maniac\rHDGE001'),(14068,781367567011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','erezetzyon','etzyon_erez@emc.com','erez etzyon','7 lilach street','nes ziona','il','ISRAEL','74203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 20:33:12',0,NULL,3,1,2,1,'\\  ','erezetzyon'),(14069,781380195011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','filipefsousa','filipe_fs@oniduo.pt','Filipe José Ferreira Sousa','Rua da Coletinha nº 70<br>Campo - Vlg','Valongo','Porto','PORTUGAL','4440-046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 20:56:36',0,NULL,3,1,3,1,'RA184570470CN\r ','filipefsousa\rGLSG001*2'),(14070,781380734011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','vitaliok_p','vitaliok@gmail.com','Vitalij Porchunov','Apt 16 Rosehaven, Carpenterstown<br>Castleknock','Dublin','Dublin','IRELAND','D15','0851323637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 20:57:12',0,NULL,3,1,3,1,'RA184570364CN\r ','vitaliok_p\rWLAT008'),(14071,781355754011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','charlesanddebra','mrriddle@earthlink.net','Charles Riddle','129 Pine St','Columbia','CT','UNITED STATES','06237-1521','(860) 228-2434','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 20:33:31',0,NULL,3,1,1,1,'\\  ','charlesanddebra'),(14072,635299014013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','kazareg','okazakov@inbox.ru','Oleg Kazakov','Malaya Filevskaya street, 16-20','Moscow','','RUSSIAN FEDERATION','121433','7 (926) 5521552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 21:16:16',0,NULL,3,1,2,1,'\\  ','kazareg'),(14073,578439994003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',30.98,'cnfaner','robbinsd10262','robbinsd102@yahoo.com','Donna Robbins','316 County Road 4264','Dayton','TX','UNITED STATES','77535-8160','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 22:28:42',0,NULL,3,1,1,1,'\\  ','robbinsd10262'),(14074,781419116011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','shed110','j_hollingshed@yahoo.com','John Hollingshed','4208 Frog Dr','Killeen','TX','UNITED STATES','76542-8307','(254) 699-3614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 22:30:51',0,NULL,3,1,1,1,'\\  ','shed110'),(14075,635331577013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',2,'HSNO023',27.98,'eastar4','alisonduarte','alison.duarte@gmail.com','Alison Duarte','Av Lacerda Franco, 1136 apto 5A','São Paulo','São Paulo/Brazil/Centro','BRAZIL','01536001','55-11-32710797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 23:15:44',0,NULL,3,1,2,1,'\\  ','alisonduarte'),(14076,781438037011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','bigpapapump57','jalexander57@gmail.com','Jeremy Alexander','17455 Parker Rd','Athens','AL','UNITED STATES','35611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 23:31:31',0,NULL,3,1,1,1,'\\  ','bigpapapump57'),(14077,739589027001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','5008angelangel','asanchezcampo@gmail.com','Angel Sánchez Campo','C/Carlos Dabán 26, esc 8, 1º dcha','Madrid','Madrid','SPAIN','28019','914726084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 23:56:05',0,NULL,3,1,3,1,'RA184570421CN\r ','5008angelangel\rBR3D007'),(14078,781447297011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',135.99,'eastar4','wickedways','brianpatterson@wcgwave.ca','Brian Patterson','826 26th Street','BRANDON','MB','CANADA','R7B 2B5','(204) 717-0126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 00:02:51',0,NULL,3,1,3,1,'RA184570599CN ','wickedways\rRCLO003'),(14079,866574096012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','gusssqc','gui_llau_me13@hotmail.com','Guillaume Tremblay','2397 hébert','Quebec','QC','CANADA','G7s1P6','(418) 699-5064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 00:44:45',0,NULL,3,1,2,1,'\\  ','gusssqc'),(14080,866575791012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','alexander.vld','alex.vld@mail.ru','Alexander Kandinsky','Kamskiy pereulok 18, 56','Vladivostok','Primorsky','RUSSIAN FEDERATION','6900062','(924) 242 - 4245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 00:50:47',0,NULL,3,1,2,1,'\\  ','alexander.vld'),(14081,866577326012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','tranceuphoria','tranceuphoria@gmail.com','Vivek Pandey','5076 Westmore Av','Montreal','QC','CANADA','H4V1Z3','(514) 827-2323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 00:54:51',0,NULL,3,0,2,1,'\\ ','tranceuphoria\r已入库\r客户要蓝色的'),(14082,781464191011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2',109.99,'eastar4','cormskis','ljcormier@hotmail.com','Shawn Cormier','2393 Robie Street<br>Apt. 306','Halifax','NS','CANADA','B3K6S2','(902) 441-2602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 01:01:29',0,NULL,3,1,3,1,'RA184570483CN\r ','cormskis\rGLSG001*2'),(14083,635356042013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','evandro_mariano','evandro.santos@saargummi.com.br','Bruno Silva Matos','Rua Zurich, 320 Apto. 13 Bloco D<br>Bairro Suisso - Taboão','São Bernardo do Campo - São Paulo','Brazil','BRAZIL','09663110','55 11 78696152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 01:02:36',0,NULL,3,1,2,1,'\\  ','evandro_mariano'),(14084,781467699011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','jendela1','jendela@gmail.com','Foo Meng How','Klinik Foo<br>3597 Jalan Ismail','Kota Bharu','Kelantan','MALAYSIA','15000','6097483518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 01:14:41',0,NULL,3,1,2,1,'\\  ','jendela1'),(14085,635360171013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','guttenberg44','ohenesefah@yahoo.com','SAMUEL KUSI','6901 Polk St<br>Apt 9','West New York','NJ','UNITED STATES','07093-1879','(201) 920-3459','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 01:23:27',0,NULL,3,1,1,1,'\\  ','guttenberg44'),(14086,635372662013,230617123256,'New Replaceable Shell for logitech Mouse M705 M 705',1,'SHLO003',12.99,'eastar4','mrstox','mrstox@hotmail.com','Leonid Svirsky','2245 Ocean Pkwy<br>Apt 5A','Brooklyn','NY','UNITED STATES','11223-4859','(718) 678-9254','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 02:11:30',0,NULL,3,1,1,1,'\\  ','mrstox'),(14087,781491479011,320755995166,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.99,'eastar4','davidplong','woblong22@yahoo.com','David long','1359 S Main Rd','vineland','NJ','UNITED STATES','08360-6538','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 02:31:14',0,NULL,3,1,1,1,'\\  ','davidplong'),(14088,584028902004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','fox74moto','toybrokersracing@aol.com','TBR.Inc','4613 wolfe way','woodland hills','CA','UNITED STATES','91364','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 02:48:37',0,NULL,3,1,1,1,'\\  ','fox74moto'),(14089,781493258011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','madmoney35','albert.robinsoniii@yahoo.com','ALBERT ROBINSON','3452 ERDMAN AVE','BALTIMORE','MD','UNITED STATES','21213-1912','(410) 483-1554','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 02:49:10',0,NULL,3,1,1,1,'\\  ','madmoney35'),(14090,781503885011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','davidc5800','castros@suddenlink.net','David Castro','135 Wildwood Dr','Natchitoches','LA','UNITED STATES','71457-6453','(318) 352-7828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 03:21:02',0,NULL,3,1,1,1,'\\  ','davidc5800'),(14091,866623973012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','ssppbub','ppd@spin.net.au','Paul Petrozzi','29 Albert Parade Ashfield','Sydney','New South Wales','AUSTRALIA','2131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 03:54:51',0,NULL,3,1,3,1,'RA184570656CN ','ssppbub\rMOAP001'),(14092,739651502001,110715183632,'NIB CBS High Pressure Portable Car Washer wash 12L',1,'CAWA002',89.9,'buysia','dangit25','black_rose_832@hotmail.com','Jared Bench','196 W 2900 S','Bountiful','UT','UNITED STATES','84010-6514','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 04:00:17',0,NULL,3,0,4,1,'YW868053223CN ','dangit25'),(14093,866640716012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','simplerabbit','bunnyfly@gmail.com','Chloe Houvener','1311 E Marion St<br>Apt C','Seattle','WA','UNITED STATES','98122-4445','(206) 855-5820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 04:35:39',0,NULL,3,1,1,1,'\\ ','simplerabbit'),(14094,866640753012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','jhokie2','jhokie@gmail.com','Justin Smith','1077 Shares Dr #2','Rockledge','FL','UNITED STATES','32955','(321) 537-4641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 04:36:24',0,NULL,3,1,1,1,'\\ ','jhokie2\rAUI Transceiver  MX20T'),(14095,781525062011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','nita2806','vs_bunny@yahoo.com','ekki arnita hapsari','PT. Pelabuhan Indonesia II, Direktorat Keuangan lantai 4 barat,  Jl. pasoso no. 1, Tanjung Priok','Jakarta','Jakarta','INDONESIA','14310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 05:23:18',0,NULL,3,1,2,1,'\\ ','nita2806'),(14096,781536602011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','konstantin.timofeyev','timofeev82@rambler.ru','Konstantin Timofeyev','Konakovskiy proezd, home12/1, appt 100 ','Moscow','Moscow','RUSSIAN FEDERATION','125565','8-962-970-8928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 06:02:01',0,NULL,3,1,2,1,'\\','konstantin.timofeyev'),(14097,8881319006096774,111,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET ',1,'HSNO017',0,'cnfaner','gastonmike','mbirrell@verizon.net','Michael E Birrell','4814 Washington Blvd','Arlington','VA','UNITED STATES','22205-2543','(703) 243-2125',NULL,NULL,NULL,'2011-10-19 06:34:56',0,NULL,3,1,3,1,' RA184570625CN','只补发一个耳机 \r发之前测试一下\rHSNO017 '),(14098,781543866011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',65.9,'eastar4','assa3assa','assa.tk@hotmail.com','Ahmad Siraj','5170 Hudson Dr<br># 61994571 Ste I','Hudson','OH','UNITED STATES','44236-3797','(440) 399-2600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 06:39:15',0,NULL,3,1,18,1,NULL,'assa3assa\r由于缺货 由卢建刚代发'),(14099,8881319006372163,111,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',0,'eastar4uk','rattanakirirun','sanyang97@hotmail.com','Neal Mitcheison','15 Sea Lane Close','East Preston','West Sussex','UNITED KINGDOM','BN161NQ','07973880481',NULL,NULL,NULL,'2011-10-19 06:39:32',0,NULL,3,1,3,1,'RA184571020CN\r ','WLAP002\r补发的 '),(14100,781545345011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','kilempin','kimmolempinen@hotmail.com','Kimmo Lempinen','Matteuksenrinne 1','Karjaa','','FINLAND','10300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 06:46:50',0,NULL,3,1,2,1,'\\ ','kilempin'),(14101,781548508011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','evgen1','guta_gruz@mail.ru','Eugene Fetisov','Sovetskaya street, 54/302','Domodedovo','Moscow region','RUSSIAN FEDERATION','142000','+7 (916) 555 - 6557','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 07:01:30',0,NULL,3,1,2,1,'\\ ','evgen1'),(14102,635423308013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','michaelsuh27','msuh27@gmail.com','myunghoon suh','6415 Schmidt Ln<br>Apt B307','El Cerrito','CA','UNITED STATES','94530-1748','(925) 956-2039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 07:16:51',0,NULL,3,1,1,1,'\\ ','michaelsuh27'),(14103,781553603011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','voxdei4u2','voxdei4u@gmail.com','HwanJoong Kwon',' 302-ho, DasanParkVille, 1479-2<br>Sa 2-dong, Sangrok-gu','Ansan-si','Gyeonggi-do','KOREA,REPUBLIC OF','426-825','82-10-2927-4384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 07:23:54',0,NULL,3,1,3,1,'RA184570642CN ','voxdei4u2\rKBNO001'),(14104,635429472013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','f.gugkaev','felicita@live.ru','Felix Gugkaev','Akademika Artsimovicha ulitsa, dom 3/3, kvartira 111','Moscow','Moscow','RUSSIAN FEDERATION','117437','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 07:56:00',0,NULL,3,1,2,1,'、 ','f.gugkaev'),(14105,578540400003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','cptboa','schillerfrau@gmx.de','Bülent Altinsoy','Reschop 9','Hattingen','','GERMANY','45525','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 08:21:12',0,NULL,3,1,3,1,'RA184570713CN ','cptboa\rWLAT003'),(14106,781572145011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'eastar4','rasfour84','rasfour@rhc.jo','Rajab Asfour','Royal Hashemite Court','Amman','','JORDAN','11100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 08:45:07',0,NULL,3,1,2,1,'、 ','rasfour84'),(14107,722251520008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','d_kearney','david.kearney@gmail.com','David Kearney','Level 4B, 26 Talavera RD','Macquarie Park','New South Wales','AUSTRALIA','2113','0290342676','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 10:27:59',0,NULL,3,1,3,1,'RA184570885CN\r ','d_kearney\r澳标\rHSPL005'),(14108,781611038011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','egor_md','spleen7777@gmail.com','Egor Hlopetki','Bulgara 72/21','Balti','','MOLDOVA, REPUBLIC OF','3100','37360029663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 11:01:28',0,NULL,3,1,2,1,'\\ ','egor_md'),(14109,781616389011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT004*2',88.99,'eastar4','aa94332111','janfowsha@hotmail.com','janet fowlkes','5280 n 65th st','milwaukee','WI','UNITED STATES','53218-3008','(414) 627-4548','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 11:24:30',0,NULL,3,1,1,1,'\\ ','aa94332111\r兼容型3D眼镜  samsung 专用'),(14110,781625394011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','johnnywongchungho','johnnywch@gmail.com','Johnny Wong','11/182 Anzac Parade','Kensington','New South Wales','AUSTRALIA','2033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 11:48:16',0,NULL,3,1,2,1,'\\  ','johnnywongchungho'),(14111,635481778013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','rimvydas.v','rimvizz@gmail.com','Rimvydas Venckevicius','Medeinos g. 19-95','Vilnius','','LITHUANIA','06136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 12:17:55',0,NULL,3,1,2,1,'\\  ','rimvydas.v'),(14112,781637854011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','roberuto_br','roberutobr@gmail.com','Roberto Nakai','Av Jonia, 559','Sao Paulo','SP','BRAZIL','04634-011','+55-11-96352421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 12:25:55',0,NULL,3,1,3,1,' RA184570951CN\r','roberuto_br\rOTSA001'),(14113,781649041011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','mrdjol','mrdjol@yahoo.fr','olivier goyffon','669 Route du Chef Lieu','Allonzier La Caille','Rhône-Alpes','FRANCE','74350','0623130673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 12:56:41',0,NULL,3,1,2,1,'\\  ','mrdjol'),(14114,781675001011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','almbeck','alexmbeck@yahoo.com','Alex M. Beck','PO BOX 7378','Avon','CO','UNITED STATES','81620','(970) 331-4115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 14:08:37',0,NULL,3,1,1,1,'\\ ','almbeck'),(14115,866806737012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','rightparty','hb0705@sccoast.net','heather belsky','2564 Tampa Ln','conway','sc','UNITED STATES','29527-5119','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 14:09:24',0,NULL,3,1,1,1,'\\ ','rightparty'),(14116,866820772012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',26.99,'eastar4uk','fgaud','starbasec4@yahoo.fr','GAUD Francis','98 route de jousson','MAGNE','Poitou-Charentes','FRANCE','79460','0688697713','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 14:46:05',0,NULL,3,1,3,1,'RA184570917CN\r ','fgaud\rGLOT004\r兼容型3D眼镜  samsung 专用'),(14117,866830559012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'eastar4','m4kin','mytih17clear@gmail.com','fernando fernandes','Avenida pedro II 2740<br>Bairro alto sao francisco','umuarama','Parana','BRAZIL','87504-440','44-36233146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:06:17',0,NULL,3,1,2,1,'\\  ','m4kin'),(14118,781701473011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','thayersoccermom','jreynold@tulane.edu','Jane Thayer','1612 Lisbon St','New Orleans','LA','UNITED STATES','70122-2819','(504) 583-2863','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 15:14:36',0,NULL,3,1,1,1,'\\ ','thayersoccermom\r兼容型3D眼镜 通用型'),(14119,781702158011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','supermo','mo@alnuaimy.com','Muhanned Al-Nuaimy','15 Churchill Avenue, #1','Toronto','ON','CANADA','M6J2B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:16:34',0,NULL,3,1,2,1,'\\ ','supermo'),(14120,781707059011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','punkday39m','punkday39@hotmail.com','Baul Jeon','112, Re Bois Musashi-Sakai,<br>1-22-8, Sakai,','Musashino-Si','Tokyo','JAPAN','180-0022','080-5361-7919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:28:35',0,NULL,3,1,3,1,'RA184570877CN\r ','punkday39m\rKBNO001'),(14121,866851350012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','egriffiths','egriffiths@ambertech.com','Eldon Griffiths','1963 Pebble Cir','Lake Point','UT','UNITED STATES','84074-9243','(801) 966-8896 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 15:50:01',0,NULL,3,1,1,1,'\\ ','egriffiths'),(14122,578638741003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',46.9,'cnfaner','kakolik','kakoli.gupta@gmail.com','Kajal Patel','2331 William Dr<br>Apt 2','Santa Clara','CA','UNITED STATES','95050-6833','4082446162','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 15:50:12',0,NULL,3,1,1,1,'\\  ','kakolik'),(14123,866853163012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','sul.vendas','sulvendas@gmail.com','MICHAEL PEREIRA SILVA','RUA OSORIO CORREIA<br>Nº 813','CACHOEIRINHA','RIO GRANDE DO SUL','BRAZIL','94935-460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:53:33',0,NULL,3,1,2,1,'\\ ','sul.vendas'),(14124,866854748012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','richardsteensma','rsteensma@gmail.com','Richard Steensma','Kajak 6','VEENENDAAL','','NETHERLANDS','3904ZW','+31318520326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:56:49',0,NULL,3,1,3,1,'RA184570925CN\r ','richardsteensma\rGLOT001\r兼容型3D眼镜 通用型'),(14125,778869577011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','flirt843','flirt843@aol.com','Samantha Fahndrich','15 Fox Trail','Lincolnshire','IL','UNITED STATES','60069','(847) 477-4341','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 16:07:50',0,NULL,3,1,1,1,'\\  ','flirt843'),(14126,635554601013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','stanleybobly','stanleybobly@hotmail.com','Hakan Karaer','Pieter Postsingel 102','Amsterdam','','NETHERLANDS','1067 AS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 16:31:48',0,NULL,3,1,2,1,'\\ ','stanleybobly'),(14127,866878661012,220778495901,'New Replaceable Shell for logitech Mouse MX518 MX 518',1,'SHLO004',12.99,'eastar4','arrzak26','arrzak@yahoo.co.uk','Ivan Satalic','Od izvora 47','Mokosica','','CROATIA','20236','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 16:42:16',0,NULL,3,1,2,1,'\\ ','arrzak26'),(14128,583622147004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','careyemeritus','carey@emeritusvineyards.com','Carey Sakai','2500 Gravenstein Hwy N','Sebastopol','CA','UNITED STATES','95472-6470','(707) 823-4464','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 16:55:16',0,NULL,3,1,1,1,'\\  ','careyemeritus'),(14129,781757998011,320755995166,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.99,'eastar4','tajisen','joakim@gissberg.nu','Joakim Gissberg','Peltomyyränkuja 2 D 13','Vantaa','','FINLAND','01450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 17:12:07',0,NULL,3,1,2,1,'\\ ','tajisen'),(14130,781756885011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',1,'BTHP2010',9.88,'eastar4','leo2006mo','susmohns@googlemail.com','Susanne Mohns','Max-von-Laue-Straße 26','Remscheid','','GERMANY','42897','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 17:13:18',0,NULL,3,1,2,1,'\\','leo2006mo\rHP 8pin 1.25 18cm '),(14131,635565091013,230668626540,'3FT CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T Cable',10,'CASS001',82.9,'eastar4','mdesport','bravoit@gmail.com','CESTE - attn: Marcos Desportes','Infantes de Espana 3','Zaragoza','Aragón','SPAIN','50012','976568586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 17:21:39',0,NULL,3,1,3,1,'RA184570863CN\r ','mdesport\rCASS001'),(14132,635577829013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','3kazuya','ffcrystallis@gmail.com','Kyriakos Giannakou','15 St Kildas Road<br>Oldfield Park','Bath','Somerset','UNITED KINGDOM','BA23QJ',' 07514269011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 17:37:24',0,NULL,3,1,2,1,'\\  ','3kazuya'),(14133,866911687012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',1,'HSJA006',8.99,'eastar4uk','haris08film','haris99@hotmail.co.uk','Imran Akhtar','14 Springbank Drive','Liversedge','West Yorkshire','UNITED KINGDOM','WF15 7QS','01924488850','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-19 17:40:14',0,NULL,3,1,3,1,'RA184570894CN\r ','haris08film\rHSJA006\r英标'),(14134,781806926011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','omid444','pedram444@hotmail.com','Mohammad Ali Mansouri','Johannes Str. 76','Bonn','','GERMANY','53225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 18:40:39',0,NULL,3,1,2,1,'\\ ','omid444\r欧标'),(14135,866901423012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','mooontheqt','moolers2000@yahoo.co.uk','Chris Mulryan','Covidien<br>Michael Collins Road','Galway','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 18:54:10',0,NULL,3,1,3,1,'RA184570948CN\r ','mooontheqt\rOTHP004'),(14136,866964512012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','mindyloubob','thestuartfamily@aol.com','Robert Stuart','22828 Riverside Dr','Mendon','MI','UNITED STATES','49072-9516','(269) 506-6300','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'mindyloubob'),(14137,781494943011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','17sfirecapt','khaney68@hotmail.com','Kelli Haney','416 Ault Rd','Signal Mountain','TN','UNITED STATES','37377-3129','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 19:22:01',0,NULL,3,1,1,1,'\\ ','17sfirecapt'),(14138,866978357012,220697788230,'New 3.0 Bluetooth BCM2070 Module+cable probook 4311S',1,'BTHP3005',19.98,'eastar4','kphilippe78','philippe.kevin@aliceadsl.fr','Kevin PHILIPPE','45 Grande rue','Tacoignières','Île-de-France','FRANCE','78910','0672421911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 19:22:17',0,NULL,3,1,2,1,'\\ ','kphilippe78\rHP 8pin1.0 18cm '),(14139,635618710013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','centreco','centre@sent.com','Ronald Foulk','aptd Correos 1034<br>La Herradura','Granada','Andalucía Ceuta y Melilla','SPAIN','18697','958640920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 19:26:10',0,NULL,3,1,2,1,'\\  ','centreco'),(14140,781841363011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','joe-hh!!','joe-hh@web.de','Joachim Gutzeit','Anemonenweg 8b','Hamburg','','GERMANY','22047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 19:31:00',0,NULL,3,1,2,1,'\\ ','joe-hh!!\r欧标'),(14141,635614301013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.9,'eastar4','daggo425','jagasteazoro@gmail.com','Jose Gasteazoro','3000 NW 83rd St<br>Rm 036 Bldg K','Gainesville','FL','UNITED STATES','32606-6210','(352) 474-0794','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 19:47:26',0,NULL,3,1,1,1,'\\  ','daggo425'),(14142,635638259013,230594480746,'Omron HJ-112 Multifunction Pedometer Walking  HJ 112',1,'OMHJ001',13.99,'eastar4','centreco','centre@sent.com','CRAIG SKEY','Pilots Point<br>The Beach, Totland Bay','Totland Bay','Isle of Wight','UNITED KINGDOM','PO39 0BQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 19:55:54',0,NULL,3,1,2,1,'\\ ','centreco'),(14143,867027643012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','jakun2002','jakun@web.de','Jacek Kunat','Quellhofstr. 45','Kassel','','GERMANY','34127','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 20:41:05',0,NULL,3,1,3,1,'RA184570979CN\r ','jakun2002\rGLOT005'),(14144,781881251011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','muh2289','jgransow@aol.com','Johannes Gransow','Bergblick 5','Radebeul','','GERMANY','01445','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 20:41:21',0,NULL,3,1,2,1,'\\ ','muh2289'),(14145,635668305013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','alexjlt92','alex.jlt@gmail.com','Geneviève JUILLOT','Appartement 788<br>3 rue Robert Barlier','SAINT DIE','Lorraine','FRANCE','88100','0329552574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 21:20:45',0,NULL,3,1,3,1,'RA184570934CN\r ','alexjlt92\rMOSA004'),(14146,635678004013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','todor.b','todor@buyukliev.com','Todor Buyukliev','16A \"G. M. Dimitrov\" Blvd, 8th floor<br>VMware','Sofia','','BULGARIA','1797','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 21:43:32',0,NULL,3,1,2,1,'\\  ','todor.b'),(14147,780001883011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','gmanb00','gbellevue@gmail.com','Gregory Bellevue','458 E Walnut ln','philadelphia','PA','UNITED STATES','19144-1054','(215) 204-3835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 22:09:08',0,NULL,3,1,1,1,'\\ ','gmanb00'),(14148,781926107011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','bestahl_de','bertram.stahl@arcor.de','Bertram Stahl','Lichtenberger Str. 24','Berlin','other','GERMANY','10179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 22:25:21',0,NULL,3,1,2,1,'\\  ','bestahl_de'),(14149,635690600013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','jrkinsella','raykinsella78@gmail.com','Ray Kinsella','Intel Shannon Limited<br>Dromore House, East Park','Shannon','Clare','IRELAND','default','0868352897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 22:31:00',0,NULL,3,1,2,1,'\\ ','jrkinsella'),(14150,781929442011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',4,'TRMX002',30.28,'eastar4','xxkci99x','xkci99x@hotmail.com','Carlos Macias','14522 Myford Rd','Irvine','CA','UNITED STATES','92606-1000','(714) 225-2973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 22:38:23',0,NULL,3,0,1,1,'\\','xxkci99x\r已入库'),(14151,781935110011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','buyforless07','patg2075@gmail.com','PAT','15 E 35th St','Bayonne','NJ','UNITED STATES','07002-3924','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 22:53:02',0,NULL,3,1,1,1,'\\  ','buyforless07'),(14152,781935575011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',2,'WLIN011+ANTY002',37.98,'eastar4','jmillard35','jmillard34@gmail.com','Graham John Millard','P.O. Box 14484','Mount Sheridan','Queensland','AUSTRALIA','4868','0740362084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 22:54:13',0,NULL,3,1,2,1,'\\ ','jmillard35'),(14153,584318435004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','fly4fish','dbissot@yahoo.com','David Bissot','11814 Asti Dr','Rancho Cucamonga','CA','UNITED STATES','91701-9004','(626) 253-8883','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 22:58:24',0,NULL,3,1,1,1,'\\  ','fly4fish'),(14154,781934090011,320626720801,'NEW Logitech Unifying Receiver 4 M505 M705 M905 mouse ',1,'RELO002',12.98,'eastar4','qb_fiji','57creativefiji@gmail.com','Qoriniasi Bale','37 Padbury Street','Downer','Australian Capital Territory','AUSTRALIA','2602','0422075640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 22:58:32',0,NULL,3,1,2,1,'\\  ','qb_fiji'),(14155,578782937003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','crux1104','cruzito1104pp@yahoo.com','angel cruz','po box 352','juncos','PR','PUERTO RICO','00777-0352','787-649-5230','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 23:04:28',0,NULL,3,1,1,1,'\\  ','crux1104'),(14156,584325928004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','surfmeister1','stefankozma@hotmail.com','Stefan Kozma','1523 Amelia Ave','Royal Oak','MI','UNITED STATES','48073','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 23:37:05',0,NULL,3,1,1,1,'\\ ','surfmeister1'),(14157,635715527013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',2,'MOSA005',131.8,'eastar4','marcelo1958','marcelo@trustindustrial.com','Marcelo De Ezkauriatza','5823 Northgate Ln<br>PMB 425','Laredo','TX','UNITED STATES','78041-2662','956 727 3186','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 00:26:26',0,NULL,3,0,18,0,NULL,'marcelo1958\r由卢建刚代发'),(14158,635717708013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','kramerwm1','kramerwm@comcast.net','William Kramer','1297 Toronto Rd<br>Ste A','Springfield','IL','UNITED STATES','62712-8682','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 00:36:31',0,NULL,3,1,1,1,'\\ ','kramerwm1'),(14159,781968785011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','cat5851049dog','stich10@sbcglobal.net','ROGER TAYFEL','13985 Hathaway Rd','Cleveland','OH','UNITED STATES','44125-5229','(216) 475-1630','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 00:52:30',0,NULL,3,1,1,1,'\\ ','cat5851049dog'),(14160,781968339011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','sriram.k','sriram.tech@gmail.com','Sriram Krishnan','Level 15, No 100<br>Arthur Street','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 01:01:22',0,NULL,3,1,2,1,'\\ ','sriram.k'),(14161,0,230687731001,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',10.5,'eastar4','wukjae','ugleepen@gmail.com','James Lee','14849 Old Creek Rd','San Diego','CA','UNITED STATES','92131-4280','(858) 564-9889','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 01:32:13',0,NULL,3,1,1,1,'\\  ','wukjae'),(14162,867135347012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','dixonwade','hiramwdixon@yahoo.com','Hiram W Dixon','1110 Lakes Dr','Royse City','TX','UNITED STATES','75189','(918) 808-2177','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 01:36:51',0,NULL,3,1,1,1,'\\ ','dixonwade\rAUI Transceiver  MX20T'),(14163,0,220875976165,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.5,'eastar4','menesteres','hatchet@wanadoo.es','Jorge de la Mata Gnaedinger','Constantino Gancedo 55 Bajo','Villablino','Castilla y León','SPAIN','24100','987480557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 01:42:40',0,NULL,3,1,2,1,'\\  ','menesteres'),(14164,578814236003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','greenhades2008','greenhades@aol.com','Hassan Estrada','59 High St','East Rutherford','NJ','UNITED STATES','07073-1427','(201) 779-4166','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 01:51:13',0,NULL,3,1,1,1,'\\  ','greenhades2008'),(14165,0,220875976132,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',15.99,'eastar4','rwasch','ruthard@rwgmbh.de','Ruthard Weber','Kreuzstrasse 3','Feldkirchen','','GERMANY','85622','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 01:55:07',0,NULL,3,1,2,1,'\\ ','rwasch\r欧标'),(14166,635732474013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','swilde23','graybrain23@gmail.com','Sean Wilde','3205 Franz Valley Rd','Santa Rosa','CA','UNITED STATES','95404-9611','(707) 545-1918','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 02:00:31',0,NULL,3,1,1,1,'\\ ','swilde23'),(14167,867144740012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','mahoodlum','smahoodlum@yahoo.com','Stephen Mahood','169 Endicott St<br>Apt 5','Boston','MA','UNITED STATES','02113-1500','(617) 417-1188','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','mahoodlum'),(14168,781990547011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','pmgardin','poem.turner@gmail.com','Poem Turner','204 Forest Run Pl','Cary','NC','UNITED STATES','27518','(919) 812-4563','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 02:11:25',0,NULL,3,1,1,1,'\\ ','pmgardin'),(14169,578820018003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','kenneth_turner0','kenneth.turner@att.net','K-TEE\'S DJ SERVICE','833 SPRINGWOOD DR','GRAND PRAIRIE','TX','UNITED STATES','75052-6092','(972) 262-4099','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 02:22:51',0,NULL,3,1,1,1,'\\ ','kenneth_turner0'),(14170,635744810013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','itsinthebag45','cat4mah8@cox.net','Cathy Mahannah','2326 S 178th St','Omaha','NE','UNITED STATES','68130-2677','(402) 850-0946','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 02:40:55',0,NULL,3,1,1,1,'\\ ','itsinthebag45\r兼容型3D眼镜 通用型'),(14171,635747729013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','danrobbins0385','robbinsd@anz.com','Dan Robbins','Level 15<br>20 Martin Place','Sydney','New South Wales','AUSTRALIA','2000','0292271819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 02:58:39',0,NULL,3,1,3,1,'RA184571991CN\r ','danrobbins0385\rMOSA005'),(14172,0,220875976069,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',9.99,'eastar4','ruchirahk','ruchiraa@gmail.com','Ruchira Ariyara','40/4 1/1, Colombo thantri Mw<br>Etul Kotte','Kotte','Western','SRI LANKA','0000','94714813351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 03:12:24',0,NULL,3,1,2,1,'\\ ','ruchirahk'),(14173,635753097013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','yuji22222','shami@sympatico.ca','YUJISTIR BANSI','20 GIANMARCO WAY','MAPLE','ON','CANADA','L6A 3J3','(416) 722-0178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 03:27:03',0,NULL,3,1,2,1,'\\ ','yuji22222'),(14174,864300612012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','ebremyhini','jean-remy.hini@laposte.net','Jean Rémy Hini','94 rue d\'Andorre','Pinsaguel','Midi-Pyrénées','FRANCE','31120','0561767937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 03:42:14',0,NULL,3,1,2,1,'\\ ','ebremyhini'),(14175,635763411013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','eddysif','torrento_123@hotmail.com','Eddy torres guzman','1305 tyson ave','philadelphia','PA','UNITED STATES','19111-4516','(215) 268-2946','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eddysif'),(14176,722631977008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',52.9,'au-buy','kengo.zia','fujitubokengo@hotmail.com','kengo fujimori','Plum tree203,1-879-1<br>Ogawa-tyo','Kodaira-city','Tokyo','JAPAN','187-0032','(080) 419-6694 ext.: 3','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 04:39:54',0,NULL,3,1,3,1,'RA184570982CN\r ','kengo.zia\rHSPL015'),(14177,781891085011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',3,'CCGR001',14.97,'eastar4','disadenis','dgamidov@gmail.com','Denis Gamidov','Bolshaya Cherkizovskaya, dom 4k1, kv 130','Moscow','','RUSSIAN FEDERATION','107061','(916)874-1189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 04:49:38',0,NULL,3,1,2,1,'\\ ','disadenis'),(14178,635766146013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','mrwhite1977','mdma_new@mail.ru','Dmitry Borisov','Paustovskogo St. 3, 636','Moscow','','RUSSIAN FEDERATION','117463','(495) 4228129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 04:55:31',0,NULL,3,1,2,1,'\\ ','mrwhite1977'),(14179,867184793012,220594073947,'2.1 Bluetooth cable Module 4 Lenovo Ideapad S10 S10e S9',1,'BTLE2101',12.39,'eastar4','fantom163','a.i.baburin@gmail.com','Baburin Andrey Ivanovich','Moscow avenue, house 45/47, apartment 65','Tolyatti','Samara region','RUSSIAN FEDERATION','445028','+79277754354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 05:00:54',0,NULL,3,1,2,1,'\\ ','fantom163'),(14180,0,220875976028,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',2.46,'eastar4','karamig','g.karamichalis@gmail.com','KARAMICHALIS GEORGIOS','FOKIONOS NEGRI 3','ATHENS','','GREECE','11257','00306972219770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 05:06:37',0,NULL,3,1,2,1,'\\  ','karamig'),(14181,782029325011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','bammo413','bammo@optonline.net','Douglas Friedman','17 Pheasant Dr','New Canaan','CT','UNITED STATES','06840-3323','(914) 659-0338','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 05:18:00',0,NULL,3,1,1,1,'\\ ','bammo413'),(14182,0,230687730717,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.31,'eastar4','oljelaksen','vinfrig@gmail.com','Vincent  Frigstad','Åsenveien 12','Arendal','','NORWAY','4841','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 05:51:24',0,NULL,3,1,2,1,'\\  ','oljelaksen'),(14183,782041781011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2',109.99,'eastar4','sturgess1234','hummerman-18@hotmail.com','Tristan Kearns','3/17 east st','warners bay','New South Wales','AUSTRALIA','2282','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 06:26:55',0,NULL,3,1,3,1,'RA184571002CN\r ','sturgess1234\rGLSG001*2'),(14184,0,320776920572,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.79,'eastar4','busteddisco','geoff.peacock@totalise.co.uk','Geoffrey Peacock','27 Ellesmere Avenue, Worsley','Manchester','Lancashire','UNITED KINGDOM','M28 0AL','01617993178','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 06:52:48',0,NULL,3,1,2,1,'\\  ','busteddisco'),(14185,782054553011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','seimsi','dseimsi@gmx.de','Daniel Simon','Taunusstraße 43','Mainz-Kostheim','','GERMANY','55246','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 07:30:19',0,NULL,3,1,2,1,'\\ ','seimsi'),(14186,8881319097497939,111,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',0,'eastar4uk','guido68_de','guido_koch@online.de','Guido Koch','Osterfeldstr.19','Bad Nenndorf','other','GERMANY','31542','',NULL,NULL,NULL,'2011-10-20 07:58:17',0,NULL,3,1,3,1,'RA184571016CN\r ','GLOT005\r补发的 \r'),(14187,782071329011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','reel-tech','reeldoctor@blueyonder.co.uk','John Graham','5 Langdon Way<br>Bispham','Blackpool','Lancashire','UNITED KINGDOM','FY2 0PX','07764992251','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-20 08:43:08',0,NULL,3,1,3,1,'RA184571308CN ','reel-tech\rHBPH002'),(14188,578874377003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',2,'HSPL013',107.98,'cnfaner','kossuetta','k_ossuetta@hotmail.com','KINGSLEY OSSUETTA','2430 Venus Dr','LOS ANGELES','CA','UNITED STATES','90046-1646','(323) 921-2607','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 09:12:47',0,NULL,3,1,1,1,'\\  ','kossuetta'),(14189,584416511004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.88,'cnfaner','grizzleyscott','scottcocking@optonline.net','Scott Cocking','47A Huron Ln','Stratford','CT','UNITED STATES','06614-8172','(203) 515-4629','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 09:24:57',0,NULL,3,1,1,1,'、  ','grizzleyscott'),(14190,867249424012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','thethinker84','lukehannifey@live.com.au','luke hannifey','55-57 Fitzroy street','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 09:40:05',0,NULL,3,1,2,1,'\\  ','thethinker84\r澳标'),(14191,782092439011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','nixxzard','dwlysenko@gmail.com','Denis Lysenko','Molodezhnaya, 19','Rostov-na-Donu','Rostovskaya oblast\'','RUSSIAN FEDERATION','344020','+79185108223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 10:05:14',0,NULL,3,1,2,1,'\\  ','nixxzard'),(14192,8881319108354516,111,'DELL1510',1,'WLDE002',0,'eastar4','timoojal','timo.ojala@gmail.com','Timo Ojala','Kauppilantie 10 C12','Oulu','Pohjois-pohjanmaa','FINLAND','90230','+358504867635',NULL,NULL,NULL,'2011-10-20 10:59:14',0,NULL,3,1,3,1,'RA184571299CN ','WLDE002 \r补发的'),(14193,584437320004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',32.99,'cnfaner','luckydog19','phyls.flowers@snet.net','FRANK REGA','29 Stonybrook Rd<br>C/O Phyls Flowers','STRATFORD','CT','UNITED STATES','06614-3715','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 11:18:58',0,NULL,3,1,1,1,'、  ','luckydog19'),(14194,782117631011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','kenjin67','kty034@hotmail.com','oktay pöhrenk','Maltepe Mah.Gumussuyu cad.Birtas San.Sit. no:61/4 Bayrampasa','Istanbul','','TURKEY','34010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:30:32',0,NULL,3,1,2,1,'\\  ','kenjin67\r欧标'),(14195,782120052011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','yanivbal','balali.yaniv@gmail.com','Neomi Balali','Herzl 9','Kiryat Ono','','ISRAEL','55209','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:39:10',0,NULL,3,1,2,1,'\\  ','yanivbal'),(14196,779846812011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','kdekor2012','kdekor2010@freemail.hu','Kovács Norbert','Akácfa str. 8/2','Komló','','HUNGARY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:39:30',0,NULL,3,1,2,1,'\\  ','kdekor2012'),(14197,867287274012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','myrkg','buchkg@gmail.com','Pavel Kuznetsov','Chui 61a #1','Bishkek','','KYRGYZSTAN','720065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:46:55',0,NULL,3,1,3,1,'RA184571965CN ','myrkg\rGLOT005*2'),(14198,782122307011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','bandar477','dallo3iti@hotmail.com','Bandar A. Ali','P.O.Box: 235839<br>+966504496675','Riyadh','Center','SAUDI ARABIA','11332','+966504496675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:47:20',0,NULL,3,1,2,1,'\\  ','bandar477'),(14199,782129249011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','billycochrane','bcochrane@virginmedia.com','william cochrane','98 woodville court','broxburn','West Lothian','UNITED KINGDOM','eh525lr','01506500959','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 12:07:50',0,NULL,3,1,2,1,'\\  ','billycochrane\r英标'),(14200,782130445011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','amorphis_user','amorphis78@inbox.ru','Anton Siverin','Konenkova 12, 325','Moscow','RU','RUSSIAN FEDERATION','127560','4066081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 12:11:39',0,NULL,3,1,2,1,'\\  ','amorphis_user'),(14201,0,230684147361,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.5,'eastar4','arvwad','arvindw@gmail.com','Arvind Wadhawan','1508 Kemah Court','Brentwood','TN','UNITED STATES','37027','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 13:55:05',0,NULL,3,1,1,1,'、  ','arvwad\r新地址\r2051 Willowmet Lane, \rBrentwood, TN - 37027\r'),(14202,782167138011,320730551325,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E card',1,'WLIN016',13.99,'eastar4uk','pedrohrz','pedroh_rz@hotmail.com','Pedro Henrique Gonçalves Rodriguez','Rua Humberto de Campos, 436, apto 1404','Rio de Janeiro','Rio de Janeiro','BRAZIL','22430-190','552125125954','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 14:25:55',0,NULL,3,1,2,1,'\\  ','pedrohrz'),(14203,782760839002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','mellim-2008','ljxdad@yahoo.com.sg','LIM BOON HUA','1020B UPPER SERANGOON ROAD','Singapore','','SINGAPORE','534758','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 13:55:34',0,NULL,3,1,11,1,NULL,'mellim-2008\rBR3D002'),(14204,866848748012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','kino29617','christian.stephens2011@gmail.com','Christian Stephens','33 Villa Rd<br>STE 300','Greenville','SC','UNITED STATES','29615-3067','(864) 751-5410','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 14:38:35',0,NULL,3,1,1,1,'\\  ','kino29617\rAUI Transceiver  MX20T'),(14205,782179455011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','dusa7784','usa.duane@yahoo.com','Duane Usa','111 Bimini Ct','Havelock','NC','UNITED STATES','28532-8994','(708) 837-8187','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 14:42:24',0,NULL,3,1,1,1,'\\  ','dusa7784'),(14206,782158006011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','omers257','omer257@gmail.com','Omer Lavi','Neve zion 16','Rishon le zion','Israel','ISRAEL','75321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 14:46:18',0,NULL,3,1,2,1,'\\  ','omers257'),(14207,635884399013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',7,'WLAP008',139.16,'eastar4','antatarteuchko','stock12.ap@free.fr','STOCK-12','17 rue Auguste Gervais','ISSY-LES-MOULINEAUX','Ile-de-France','FRANCE','92130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 15:19:11',0,NULL,3,1,3,1,'RA184571285CN ','antatarteuchko\rWLAP008'),(14208,584491555004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','bfyf8464','bubbaloie08@yahoo.com','berlin fyffe','4017 vannest ave.','middletown','OH','UNITED STATES','45042','(513) 783-8802','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 15:22:56',0,NULL,3,1,1,1,'、  ','bfyf8464'),(14209,635853310013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','dspud2006','dspud2010@gmail.com','Derek Spudich','111 Starling Creek Loop','Laredo','TX','UNITED STATES','78045-8115','(956) 508-3490','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'dspud2006'),(14210,867376349012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','kissandrun2009','vietnamesecuteguy@yahoo.com.au','Minh Nguyen','8/8-10 Weigand Ave','Bankstown','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 15:39:56',0,NULL,3,1,2,1,'\\ ','kissandrun2009'),(14211,635896879013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','moscowcimmerian','andreworlov@mail.ru','Andrew Orlov','Astradamski Proyezd, 3-55','Moscow','MO','RUSSIAN FEDERATION','127206','74957282905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 15:43:35',0,NULL,3,1,2,1,'\\  ','moscowcimmerian'),(14212,635911456013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','mo543211','michaeloak@msn.com','Michael Oak','6205 Oakport St N','Moorhead','MN','UNITED STATES','56560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 16:30:23',0,NULL,3,1,1,1,'\\  ','mo543211\rHP 8pin 1.0 23cm '),(14213,635911827013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','flyingswapper','flyingswapper@aol.com','Jason Donlan','10 Castle Court<br>Castle Road','Colne','Lancashire','UNITED KINGDOM','BB8 7RD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 16:31:02',0,NULL,3,1,2,1,'\\  ','flyingswapper'),(14214,867413667012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.4,'eastar4','ayevgeny','ayevgeny@012.net.il','Yevgeny Abramovich','60/2 Kibbutz Galuyot st.','Nahariya','','ISRAEL','22266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 16:57:30',0,NULL,3,1,2,1,'\\  ','ayevgeny'),(14215,578999839003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',12.9,'cnfaner','dandodando','dbaker13@rochester.rr.com','Dodie G Baker','30 Watrous St','Perry','NY','UNITED STATES','14530-1539','(585) 237-3997','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 17:47:13',0,NULL,3,1,1,1,'、  ','dandodando'),(14216,782263573011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','olgapz','olga.pavic_zidar@yahoo.com','Olga Pavic Zidar','Lovrakova 21','Velika Gorica','','CROATIA','HR-10410','+385911892182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 17:49:29',0,NULL,3,1,2,1,'\\  ','olgapz\r欧标'),(14217,635930212013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2',109.99,'eastar4','sixmonkey6','sixmonkey@hotmail.com','Antonio Daniel Hidalgo','1065 berri','Montreal','QC','CANADA','h2l 4c5','(514) 502-8620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 17:51:13',0,NULL,3,1,3,1,'RA184571988CN\r ','sixmonkey6\rGLSG001*2'),(14218,782275395011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','sphoenix03','sylvainphoenix@hotmail.com','Phoenix Sylvain','29 10E AV.','Maddington','QC','CANADA','G0Z1C0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 18:10:13',0,NULL,3,1,3,1,'RA184571237CN ','sphoenix03\rBR3D001'),(14219,867478334012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',8.99,'eastar4uk','enif1','heinz.spiess@spiess.ch','Heinz Spiess','Haldenstrasse 16','Aegerten','','SWITZERLAND','2558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 18:49:46',0,NULL,3,1,2,1,'\\  ','enif1'),(14220,782303978011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','myekkala99','manojkyekkala@gmail.com','Manoj Yekkala','6450 Stoneridge Mall Rd<br>Apt N104','Pleasanton','CA','UNITED STATES','94588-7350','(248) 635-0141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 18:58:16',0,NULL,3,1,1,1,'\\  ','myekkala99'),(14221,782309402011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','schlagbaum','961ettk@gmx.de','Wioletta Wasik-Kühn','Am Rosenhang 1','Jena','','GERMANY','07743','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 19:08:56',0,NULL,3,1,2,1,'\\  ','schlagbaum'),(14222,782320205011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','kilroy1974','dillon_rory@hotmail.com','Rory Dillon','22 Richards St','Worcester','MA','UNITED STATES','01603-2609','(617) 823-9084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 19:29:18',0,NULL,3,1,1,1,'\\  ','kilroy1974'),(14223,782329601011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','mbal7957','mfuensanta_84@hotmail.com','Carlos Sanchez Hernandez','C/La Gloria nº19','Puente Tocinos','Murcia','SPAIN','30006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 19:43:32',0,NULL,3,1,3,1,'RA184571974CN\r ','mbal7957\rGLSG001*2'),(14224,579049462003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.99,'cnfaner','senseney1943','wsenseney@yahoo.com','Wayne Senseney','413 Chatsworth Ct','Franklin','TN','UNITED STATES','37064-8227','(615) 591-3971','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 20:00:45',0,NULL,3,1,1,1,'\\  ','senseney1943'),(14225,635994212013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',65.9,'eastar4','dawrone','tjwrona25@gmail.com','Thomas Wrona','327 Vallejo St','Petaluma','CA','UNITED STATES','94952','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 20:01:37',0,NULL,3,0,18,0,NULL,'dawrone\r由卢建刚代发'),(14226,867531861012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','lo3d','paul.duguay@gnb.ca','Paul Duguay','111, rue DeGrâce','Shippagan','NB','CANADA','E8S 1H1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 20:11:58',0,NULL,3,1,2,1,'\\  ','lo3d'),(14227,584590520004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',2,'HSPL002',25.96,'cnfaner','corey5898','wayne_318@hotmail.com','corey young','1304 willow glen cir<br>apt 212','ft worth','TX','UNITED STATES','76134-4912','(318) 834-7821','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 20:15:59',0,NULL,3,1,1,1,'\\  ','corey5898'),(14228,636008167013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','skfno','steven.fitton1@ntlworld.com','steven fitton','38 alexander ave','earl shilton','Leicestershire','UNITED KINGDOM','LE97AF','1455844534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 20:38:14',0,NULL,3,1,3,1,'RA184571855CN\r ','skfno\rOTES001'),(14229,782360927011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'eastar4','mgdwyer70','bayowin@gmail.com','Michael Dwyer','6515 Brahman Dr','Lakeland','FL','UNITED STATES','33810-3249','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 20:40:14',0,NULL,3,1,1,1,'\\  ','mgdwyer70'),(14230,782385116011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','na122182','goodju_ju@yahoo.com','Julie Koger','2170 N Lake Dr<br>Apt 1011','Columbia','SC','UNITED STATES','29212-8112','(704) 712-5639','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 21:33:00',0,NULL,3,1,1,1,'\\  ','na122182'),(14231,636028934013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','toddbromwell1','tbromwell.bkshelving@gmail.com','Todd Bromwell','711 S Decker Ave','Baltimore','MD','UNITED STATES','21224-3946','(410) 808-3555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 21:51:25',0,NULL,3,1,1,1,'\\  ','toddbromwell1\r兼容型3D眼镜 通用型'),(14232,782400045011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',2,'BAIN001',15.96,'eastar4','waleeherr','walee-herr@hotmail.com','Paul Herr','4714 E Montecito Ave','FRESNO','CA','UNITED STATES','93702-3921','(559) 452-1219','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 22:10:53',0,NULL,3,1,1,1,'\\  ','waleeherr'),(14233,782411178011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','scapegoatnc','royer@sgoat.com','Dan Royer','8604 Sandy Glen ct','Charlotte','NC','UNITED STATES','28212-6521','(704) 605-9775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 22:45:09',0,NULL,3,1,1,1,'\\  ','scapegoatnc'),(14234,584639696004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','bigmike0816','letsrock16@verizon.net','Michael Estelle','1 Crawford St','Eatontown','NJ','UNITED STATES','07724-2906','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 23:27:40',0,NULL,3,1,1,1,'\\  ','bigmike0816'),(14235,782442992011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.88,'eastar4','fcheung2888','fcheung-ebay@generalnetworking.com','Frank Cheung','1750 39th Ave','San Francisco','CA','UNITED STATES','94122-4036','(415) 238-6727','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 00:38:18',0,NULL,3,1,1,1,'\\  ','fcheung2888\rHP 8pin 1.25 25cm '),(14236,636071397013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',33.16,'eastar4','asus8420','chernetskynick@gmail.com','Nick Chernetsky','Str. Veselinovskaya 60/3, Fl.8','Nikolaev','Nikolaev','UKRAINE','54036','380964706219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 00:44:19',0,NULL,3,1,3,1,'RA184571223CN ','asus8420\rCASS001+CASS002\r一共买了六条CAB-SS-2626\r三条CAB-SS-2660'),(14237,782446185011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',3,'CASS002',24.87,'eastar4','asus8420','chernetskynick@gmail.com','Nick Chernetsky','Str. Veselinovskaya 60/3, Fl.8','Nikolaev','Nikolaev','UKRAINE','54036','380964706219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 00:48:42',0,NULL,3,1,17,0,NULL,'asus8420'),(14238,636075298013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',16.58,'eastar4','asus8420','chernetskynick@gmail.com','Nick Chernetsky','Str. Veselinovskaya 60/3, Fl.8','Nikolaev','Nikolaev','UKRAINE','54036','380964706219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 01:01:12',0,NULL,3,1,17,0,' ','asus8420'),(14239,867645789012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.96,'eastar4','10232azee','compuparts72@gmail.com','Alfred Cao','9017 85th Rd<br>Apt 7','Woodhaven','NY','UNITED STATES','11421-1350','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 01:06:59',0,NULL,3,1,1,1,'、  ','10232azee'),(14240,636080103013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','fwang480','freddy@rubify.com','Freddy Wang','1 Amber Point<br>Amber Road #08-04','default','','SINGAPORE','439845','(972) 973-78','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 01:23:19',0,NULL,3,1,11,1,' ','fwang480\rCACN004'),(14241,584662292004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','sprnalicious','sprnalicious87@hotmail.com','Stephen Sporny','17289 72nd Place','Maple Grove','MN','UNITED STATES','55311-4555','(763) 898-3092','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 01:28:30',0,NULL,3,1,1,1,'\\  ','sprnalicious'),(14242,782459468011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','adoneto_adoneto','adoneto@gmail.com','Antônio Neto','Rua do Ouro, 78 - apto 201<br>Serra','Belo Horizonte','Minas Gerais','BRAZIL','30220-000','31 94231122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 01:35:30',0,NULL,3,1,2,1,'\\  ','adoneto_adoneto'),(14243,782451320011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','bonella','marcelobonella@yahoo.com.br','Marcelo Bonella da Silva','Rua Humberto Serrano, 520, ap 1203<br>Edif. Verdes Mares - Praia da Costa','Vila Velha','ES','BRAZIL','29101-462','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 01:13:54',0,NULL,3,1,3,1,'RA184571271CN ','bonella\rOTSA001'),(14244,579136456003,130554591005,'Omron HJ-112 Multifunction Pedometer Walking HJ 112',1,'OMHJ001',12.9,'cnfaner','simply_margo','margo.terrill@gmail.com','Margo Terrill','4298 Frances Ave<br># A','Bellingham','WA','UNITED STATES','98226-8735','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 02:11:25',0,NULL,3,1,1,1,'、 ','simply_margo'),(14245,782471508011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','77776908','msaunders113@aol.com','MIKE SAUNDERS','12113 Chip Shot Ln','upper marlboro','MD','UNITED STATES','20772-7963','(202) 257-5779','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 02:18:45',0,NULL,3,1,1,1,'\\ ','77776908'),(14246,782476102011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','lestrange11','christina.lestrange@mail.ru','Islamova Kristina Vladimirovna','ul. Kirova, d. 25A, kv. 144','Vladivostok','Primorsky krai','RUSSIAN FEDERATION','690068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 02:35:48',0,NULL,3,1,2,1,'\\  ','lestrange11\r正红色长柄婚庆伞 '),(14247,636102373013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ljmooney','lmooney@winterparkresort.com','laurie mooney','po box 356','tabernash','CO','UNITED STATES','80478','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'ljmooney'),(14248,782488375011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',1,'BTHP2111',12.39,'eastar4','mo543211','michaeloak@msn.com','Michael Oak','6205 Oakport St N','Moorhead','MN','UNITED STATES','56560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 03:28:36',0,NULL,3,1,1,1,'、  ','mo543211\rHP 8pin 1.25 25cm '),(14249,636106343013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','amat9648','avaworrie@aol.com','Ava Mattis Worrie','7962 SW 6th St','north lauderdale','FL','UNITED STATES','33068-2107','(954) 547-4461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 03:29:53',0,NULL,3,1,1,1,'\\  ','amat9648\r兼容型3D眼镜 通用型'),(14250,777821950011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','mcflurry18','mcflurry_18@yahoo.com','John Karlo Clemente','476 Minnigaffe Street','Winnipeg','MB','CANADA','R2X 1Z8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 05:17:34',0,NULL,3,1,2,1,'\\  ','mcflurry18'),(14251,584498824004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',6.99,'cnfaner','traumachsr','jces9063@aol.com','Oscar Gonzalez','126 63rd St','West New York','NJ','UNITED STATES','07093-3004','(201) 403-3003','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 05:20:12',0,NULL,3,1,1,1,'\\  ','traumachsr'),(14252,782509955011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','lindseyvalente','lindsey.valente@gmail.com','Lindsey Valente','1928 W Grace St','Chicago','IL','UNITED STATES','60613-2726','(773) 904-8141','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 05:21:45',0,NULL,3,1,1,1,'\\  ','lindseyvalente'),(14253,867712967012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','luq791','luluchannel@hotmail.com','Lu Qin','13 William Ellery Pl','Providence','RI','UNITED STATES','02904-2856','(401) 648-5618','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 05:34:47',0,NULL,3,1,1,1,'\\  ','luq791\r网眼豹纹双层网纱长柄伞  '),(14254,636131544013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','dezza7788','derek.quach@gmail.com','Derek Quach','Level 5, 100 Harris St','Pyrmont','New South Wales','AUSTRALIA','2009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 06:33:30',0,NULL,3,1,2,1,'\\  ','dezza7788'),(14255,584709195004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',6.99,'cnfaner','zestprovita2004','haltamirano@earthlink.net','Enrique Altamirano','637 Laveta Ter','Los Angeles','CA','UNITED STATES','90026-4303','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 06:54:39',0,NULL,3,1,1,1,'\\  ','zestprovita2004'),(14256,740576240001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','kiguk','khairil007@gmail.com','Khairil Hodgson','205 Lincoln Avenue','Twickenham','Middx','UNITED KINGDOM','TW2 6NL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 07:17:03',0,NULL,3,1,3,1,'RA184570245CN\r ','kiguk\rBR3D005'),(14257,867736907012,220763388903,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',16.5,'eastar4uk','earlabradley','the1rev.dave@yahoo.com','David Bradley','PO Box 1141','Grand Canyon','AZ','UNITED STATES','86023','(928) 638-3008','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 07:30:33',0,NULL,3,1,1,1,'\\  ','earlabradley'),(14258,8881319182413103,111,'New Genuine Motorola HS850 Bluetooth Headset track#',2,'HSMO019',30.98,'cnfaner',' 215zaazy20  ','zaazy20@msn.com','zakiyyah morrison','5431 W Berks St','philadelphia','PA','UNITED STATES','19131 ','',NULL,NULL,NULL,'2011-10-21 07:33:33',0,NULL,3,1,1,1,'\\  ','这票系统下不来   我手工录的 \rE邮宝改的\rLK030083026CN'),(14259,867751170012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','geomoeetrik','meelis.piller@gmail.com','Meelis Piller','Müürivahe 17-2','Tallinn','','ESTONIA','10140','003725108720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 08:23:22',0,NULL,3,1,2,1,'、 ','geomoeetrik'),(14260,738777154001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','wiwat3801','mac_exp@hotmail.com','Wiwat traphant','11/78 Siwalee village soi5 srichan rd<br>Baanped meung','Khonkean','Khonkean','THAILAND','40000','66895552424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 08:39:51',0,NULL,3,1,3,1,'RA184571339CN\r ','wiwat3801\rBR3D005'),(14261,782562303011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','twinsaa2','willetts@winqld.com.au','Sue Willett','6 Wellington Street','Mackay','Queensland','AUSTRALIA','4740','0488554569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 09:20:46',0,NULL,3,1,2,1,'、','twinsaa2'),(14262,8881319189386433,111,'JABRA  BT500',1,'HSJA010',0,'eastar4uk','steve1120_1','westie448@hotmail.com','Mr Steven P West','37 Bemerton Gardens<br>Kirby Cross','Frinton on Sea','Essex','UNITED KINGDOM','CO13 0LQ','',NULL,NULL,NULL,'2011-10-21 09:29:46',0,NULL,3,1,3,1,'RA184572008CN ','补发的 \rHSJA010'),(14263,782554531011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','136lloyd','lscbg@ntlworld.com','Steven Lloyd','4 The Old Glebe','Quorn','Leicestershire','UNITED KINGDOM','LE128LB','01509620946','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-21 09:53:55',0,NULL,3,1,6,1,'EE491016043CN ','136lloyd\r兼容型3D眼镜 通用型'),(14264,782572709011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',13.97,'eastar4','nuberoja','svalenciano@gmail.com','Sergio Valenciano Muela','Avda. America Nº 32 Esc. 1 Puerta 8','Teruel','Teruel','SPAIN','44002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 09:58:37',0,NULL,3,1,2,1,'、 ','nuberoja'),(14265,782578144011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','sbacelic','bids@el8.info','Slaven Bacelic','Strojarska 2','Zagreb','Croatia','CROATIA','10000','00385912516951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 10:18:28',0,NULL,3,1,3,1,'RA117779185CN\r ','sbacelic\rHBPH002'),(14266,782579749011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','andyferdean','alexferdean@yahoo.com','Alexandru Ioan Ferdean','str. Siderurgistilor nr. 18 bl. D7 ap. 54','Galati','Galati','ROMANIA','800374','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 10:23:45',0,NULL,3,1,2,1,'、 ','andyferdean'),(14267,782552621011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','helen_l','ebayhelenl@gmail.com','helen lawson','54 Ashford Road','Topsham','Devon','UNITED KINGDOM','EX30LA','01392877015','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-21 10:58:14',0,NULL,3,1,2,1,'\\  ','helen_l\r向日葵三折叠伞 '),(14268,636187896013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ericdantie','edantie@gmail.com','Eric Dantie','Maninidra 12 - 4A','Las Palmas de Gran Canaria','Canarias','SPAIN','35002','699701629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 11:41:40',0,NULL,3,1,2,1,'、 ','ericdantie'),(14269,579223051003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','jenci22','tucsok22@gmail.com','Almási Jenő','Újvilág 21','Újszentiván','Csongrád','HUNGARY','6754','+36306779323','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-21 11:42:09',0,NULL,3,1,3,1,'RA117779163CN\r ','jenci22\r欧标\rHSMO020'),(14270,867814422012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','kms6816','frank@kmscomputer.com.au','FrankSteffen','PO Box 81','Aspley','Queensland','AUSTRALIA','4034','0732631211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 11:53:45',0,NULL,3,1,2,1,'、 ','kms6816'),(14271,582814370004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',41.8,'cnfaner','kob1rgk','r.kummerer@comcast.net','Robert Kummerer','861 S Southmeadow Ln','Lake Forest','IL','UNITED STATES','60045-4833','(847) 848-2666','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 12:41:14',0,NULL,3,1,1,1,'\\  ','kob1rgk'),(14272,782621924011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','chris310174chris','cwilson@grace.com.au','Chris Wilson','Lot 59 Connolly st','Webberton','Western Australia','AUSTRALIA','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 12:43:17',0,NULL,3,1,3,1,'RA117779407CN\r ','chris310174chris\rGLOT001*3\r兼容型3D眼镜 通用型'),(14273,867831972012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','mjfisher1974','ejfisher13@gmail.com','Michael Fisher','24 Market Street','Boronia','Victoria','AUSTRALIA','3155','0397629095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 12:43:48',0,NULL,3,1,3,1,'RA117779322CN\r ','mjfisher1974\rGLOT001*2\r兼容型3D眼镜 通用型'),(14274,636209849013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','mjunior2006','michel_junior@hotmail.com','Michel Junior','SQS 404 BLOCO J APT 207 - ASA SUL','Brasilia','Distrito Federal','BRAZIL','70238-100','55-61-35427745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 13:14:09',0,NULL,3,1,2,1,'、 ','mjunior2006'),(14275,584457880004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.95,'cnfaner','904gloria','drgloria777@gmail.com','Gloria Kennedy','744 Moravon Ave','Jacksonville','FL','UNITED STATES','32211-6344','(904) 724-9743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 13:22:52',0,NULL,3,1,1,1,'\\  ','904gloria'),(14276,636214092013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','jwys12792','jwys12792@blueyonder.co.uk','Jeff H Wilde','46 Zetland Rd','Doncaster','South Yorkshire','UNITED KINGDOM','DN2 5EQ','01302361926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 13:28:45',0,NULL,3,1,2,1,'、 ','jwys12792'),(14277,782639662011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2',109.99,'eastar4','andritz2008','wilk1945@charter.net','john wilkie','329 Harwich Pl','rockton','IL','UNITED STATES','61072-2989','(608) 295-1546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 13:38:37',0,NULL,3,1,1,1,'、 ','andritz2008'),(14278,782644689011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','avishayavishay','avishayas1@walla.com','Avishay Assulin','Yaacov pichman 5/19','Beer sheva','','ISRAEL','84254','972523351699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 13:49:34',0,NULL,3,0,2,1,'\\  ','avishayavishay'),(14279,782650051011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','shuszczo','shuszczo@umich.edu','Sam Huszczo','21415 Civic Center Dr<br>Ste 200','Southfield','MI','UNITED STATES','48076-3953','(248) 731-0029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 14:03:17',0,NULL,3,1,1,1,'\\  ','shuszczo'),(14280,782653522011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','hj44','herve.jousset@laposte.net','Hervé Jousset','19 quai rageot de la touche','la baule','Pays de la Loire','FRANCE','44500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 14:12:51',0,NULL,3,1,2,1,'、 ','hj44\r欧标'),(14281,867869998012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','opsypa','sabrina.pagliero@laposte.net','linas sabrina','quartier le vallat','saint nazaire','Languedoc-Roussillon','FRANCE','30200','06 17 40 96 95','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 14:22:40',0,NULL,3,1,3,1,'RA184571784CN\r ','opsypa\rGLOT005'),(14282,635963978013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','birgit3513','kanariska@web.de','Birgit Hartmann','Gebrüder-Witte-Str. 21','Greifswald','','GERMANY','17489','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 14:32:10',0,NULL,3,1,2,1,'、 ','birgit3513\r欧标'),(14283,781750753011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','wgaban','waseem_gaban@hotmail.com','waseem jaban','1820 N Delany Rd<br>Apt 110','gurnee','IL','UNITED STATES','60031-1231','(224) 358-0535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 14:58:44',0,NULL,3,1,1,1,'\\  ','wgaban'),(14284,740706419001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','zulaytica','zulaytica@yahoo.com','Zulay Carvajal','1704 Kildare Woods Dr','Greensboro','NC','UNITED STATES','27407-5874','(336) 454-0620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 15:04:49',0,NULL,3,1,1,1,'\\  ','zulaytica'),(14285,740708534001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','aquej001','abeq1@aol.com','Abraham Queja','217 Stornoway Dr','Southern Pines','NC','UNITED STATES','28387-7517','(910) 684-4040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 15:10:22',0,NULL,3,1,1,1,'\\  ','aquej001'),(14286,782693225011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','attikus1987','xmaryattix@gmail.com','Marat Alymov','Kahovka st. 19-1-31','Moscow','','RUSSIAN FEDERATION','117461','(903) 125-3596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 15:52:33',0,NULL,3,1,2,1,'、 ','attikus1987'),(14287,782707424011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','lapduke','rgorman@truenetworking.com','Rob Gorman','625 Fisgard St','Victoria','BC','CANADA','V8W 1R7','(250) 360-3139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 16:28:17',0,NULL,3,1,2,1,'、 ','lapduke'),(14288,782712241011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'eastar4','danielleworsham','jason.jeross@emc.com','Jason Jeross','1719 Great Ridge Dr','Plainfield','IL','UNITED STATES','60586-1780','(630) 299-7622','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 16:35:32',0,NULL,3,1,1,1,'\\  ','danielleworsham'),(14289,740751984001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','cathyadam10','cathyadam@walla.com','adam FOGEL','HARSBA 1325','RIHSON-LZION','','ISRAEL','75484','0502080888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 16:58:18',0,NULL,3,1,3,1,'RA117779177CN\r ','cathyadam10\rBR3D004'),(14290,579307946003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','finishers49','continentaldrywall@hotmail.com','HENRY PACHECO','10809 SW 143rd Ct','MIAMI','FL','UNITED STATES','33186-3078','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 17:12:08',0,NULL,3,1,1,1,'\\  ','finishers49'),(14291,636279369013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','spinnincherub','xx_vietboi_xx@yahoo.com','Johnny Tran','2616 Friarford Rd','Fort Worth','TX','UNITED STATES','76112-6010','(817) 966-3634','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 17:12:36',0,NULL,3,1,1,1,'\\  ','spinnincherub'),(14292,782726324011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.89,'eastar4','etri4087','etriffin@rockresorts.com','Emily Triffin','1680 Michigan Ave<br>Ph 5','Miami Beach','FL','UNITED STATES','33139-2514','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 17:16:03',0,NULL,3,1,1,1,'\\  ','etri4087'),(14293,579312198003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','4on3sty','4on3sty@raydarllc.com','Ray Darrah','1122 E Pike St<br># 1318','Seattle','WA','UNITED STATES','98122-3916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 17:22:15',0,NULL,3,1,1,1,'\\  ','4on3sty'),(14294,782732432011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','piscu123','albert_padilla_miquel@hotmail.com','Albert Padilla Miquel','C/Canalejas 89 2º 2ª esc. B','Barcelona','Cataluña','SPAIN','08028','665837320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 17:22:40',0,NULL,3,1,2,1,'、 ','piscu123'),(14295,782734629011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','mustafaince1989','mustafaince13@gmail.com','mustafa ince','nurgün2 sitesi a2 blok no18 mesa/batıkent','ankara','yenimahalle','TURKEY','06370','03122574488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 17:27:13',0,NULL,3,1,2,1,'、 ','mustafaince1989'),(14296,782758084011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','yuramadhan44','yuramadhan@gmail.com','Madhan Krishnamurthy','7700 Willow Chase Blvd<br>Apt 714','Houston','TX','UNITED STATES','77070-5898','(832) 668-0643','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 18:09:36',0,NULL,3,1,1,1,'\\  ','yuramadhan44'),(14297,783314128002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','newitsmejto','itsmejto@att.net','john outhwaite','4020 Brook Cross Dr','APEX','NC','UNITED STATES','27539-8869','(919) 362-7423','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 18:11:20',0,NULL,3,1,1,1,'\\  ','newitsmejto\rOTPH003'),(14298,782736491011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','taina4n','taina4@comcast.net','Norma Andino-Cruz','4447 Huntington Forest Blvd','Jacksonville','FL','UNITED STATES','32257','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 18:19:26',0,NULL,3,1,1,1,'\\  ','taina4n'),(14299,782766898011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','jarizabe','zetalcuadrado@yahoo.es','Juan José Ariza Benítez','Calle Alayos nº 1 3ºE','granada','Andalucía Ceuta y Melilla','SPAIN','18006','667287955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 18:31:35',0,NULL,3,1,3,1,'RA117779398CN\r ','jarizabe\rGLOT001*2\r兼容型3D眼镜 通用型'),(14300,781152183011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',99.8,'eastar4','northernsummit','rgladysz@telus.net','Robert s Gladysz','2008-87a ave','Dawson Creek','BC','CANADA','v1g4w6','(250) 782-3480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 18:38:28',0,NULL,3,1,3,1,'RA117779375CN\r ','northernsummit\rGLSG001'),(14301,636320540013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','atf369','atf369@hotmail.com','ALBERTO TORANZO FERNANDEZ','C/ CARTAGENA DE INDIAS, Nº30 - 2ºC','BENAVENTE - (ZAMORA)','Castilla y León','SPAIN','49600','650515735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 19:02:17',0,NULL,3,1,3,1,'RA117779194CN\r ','atf369\rBAZA001'),(14302,782771841011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT004',44.89,'eastar4','zainmalik1','zainhassan1@hotmail.com','zain malik','CIBC, Gerrard square branch,<br>1000 Gerrard street east','toronto','ON','CANADA','m4m 3g6','(416) 997-9384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 19:18:52',0,NULL,3,1,3,1,'RA184571722CN\r ','zainmalik1\rGLOT004'),(14303,579373688003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','choudrey39','a.rashid39@gmail.com','Aamir choudrey','778 E 10th St<br>Apt A5','brooklyn','NY','UNITED STATES','11230-2308','(347) 755-0792','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 20:24:34',0,NULL,3,1,1,1,'\\  ','choudrey39'),(14304,868067129012,220812857850,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'eastar4','catmassimo','tjviolich@att.net','Thomas Violich','2295 Bella Vista Dr','Santa Barbara','CA','UNITED STATES','93108-1504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 20:42:11',0,NULL,3,1,1,1,'\\  ','catmassimo'),(14305,782846600011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','vokkin','nikkov@tpg.com.au','Lisa Dyer','16 Prospector Drive','Cairnlea Estate (Deer Park)','Victoria','AUSTRALIA','3023','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'vokkin'),(14306,781892091011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'eastar4','plabrevo','plabrevo@yahoo.com','Pascal Labrevois','15 Chemin du Pilat','SAINTE FOY-LES-LYON','Rhône-Alpes','FRANCE','69110','0624696382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 21:55:12',0,NULL,3,1,2,1,'、 ','plabrevo\r欧标'),(14307,782878024011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ykb1224','yogesh.bhayana@gmail.com','Yogesh Bhayana','1440 Stone Pine Ter<br>Apt 230','Fremont','CA','UNITED STATES','94536-4093','(630) 696-8975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 22:39:01',0,NULL,3,1,1,1,'\\  ','ykb1224'),(14308,868126324012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','firefly5719','jfhastings@bigpond.com','Janet Hastings','9 Oaklands Way','Pakenham','Victoria','AUSTRALIA','3810','0359419840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 23:14:12',0,NULL,3,1,2,1,'、 ','firefly5719'),(14309,636397780013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','alvilda4','laniel@yandex.ru','Anna Dubinina','Moldegate, 25- H0403','Oslo','','NORWAY','0445','91161386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 23:22:41',0,NULL,3,1,2,1,'、 ','alvilda4\r韩版透明伞 u'),(14310,868138642012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.39,'eastar4','wsd1103692008','wsd110369@yahoo.com','William S. Duchemin','1318 Blake ave','brooklyn','NY','UNITED STATES','11208','(718) 647-5551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 23:52:36',0,NULL,3,1,1,1,'\\  ','wsd1103692008\racer 5pin1.25 15cm '),(14311,636405346013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','shuttle_store','ebay@us.shuttle.com','Shuttle Computer Group','17068 Evergreen Pl','City of Industry','CA','UNITED STATES','91745-1819','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 00:06:05',0,NULL,3,1,1,1,'\\  ','shuttle_store\r附加的\rRichard Cheng '),(14312,782901530011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','marcosporvenir','hda@hdamusica.com','Jason Schultz c/o Mrs. Peña','1056 4th Ave','Chula Vista','CA','UNITED STATES','91911-1907','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 00:07:48',0,NULL,3,1,1,1,'\\  ','marcosporvenir'),(14313,636417241013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','dean.dla','susb89@gmail.com','D. Bower','Unit 7 - 58 Bluebell Street<br>O\'Connor','Canberra','Australian Capital Territory','AUSTRALIA','2602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 01:05:59',0,NULL,3,1,3,1,'RA184571775CN\r ','dean.dla\rGLOT005'),(14314,868160861012,220529927797,'Logitech Harmony Remote USB Cable 670 680 628 xbox 360',1,'CALO001',3.87,'eastar4','jabronie321','whiteshadow5150@yahoo.com','Joseph Marshman','2472 28th Ave','San Francisco','CA','UNITED STATES','94116-2305','(408) 218-2942','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 01:16:49',0,NULL,3,1,1,1,'\\  ','jabronie321'),(14315,782920079011,320692602270,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.97,'eastar4','pc_fastfix','dubstep@tpg.com.au','d. fallon','14 ellerslie place','toorak','Victoria','AUSTRALIA','3142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 01:32:16',0,NULL,3,1,2,1,'、 ','pc_fastfix'),(14316,740939170001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','pinkuusa2003s','pinkuusa2003@yahoo.com','HIRAL VAIDYA','6273 Maddox Blvd','Chincoteague Island','VA','UNITED STATES','23336','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 01:45:31',0,NULL,3,1,1,1,'\\  ','pinkuusa2003s'),(14317,782926250011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',65.9,'eastar4','dschwarpa','dschwar@adelphia.net','David Schwarzwaelder','6307 Harbor Dr NW','Canton','OH','UNITED STATES','44718-4117','(724) 348-7304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 01:52:09',0,NULL,3,0,18,0,NULL,'dschwarpa\r由卢建刚代发'),(14318,782931950011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','dorasdad0803','soonert@tds.net','Karen Rivet','701 C St','Elgin','OK','UNITED STATES','73538','(580) 492-5899','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 02:17:01',0,NULL,3,1,1,1,'\\  ','dorasdad0803'),(14319,0,230687754566,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',8.99,'eastar4','khlekluellin','mleazer@insightbb.com','Marvin Leazer','3021 Mid Dale Ln','Louisville','KY','UNITED STATES','40220-2508','(502) 296-0975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 02:25:17',0,NULL,3,1,1,1,'\\  ','khlekluellin'),(14320,0,220875994363,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',16.5,'eastar4','totallyx','stephen.forrest@sebadesign.com','Stephen Forrest','PO Box 2041','Dandenong','Victoria','AUSTRALIA','3175','0387910000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 02:25:46',0,NULL,3,1,2,1,'、 ','totallyx\r澳标'),(14321,782931183011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jcam2938','campbell@wellsfargo.com','Jon Campbell','395 Sussex Lane','Orono','MN','UNITED STATES','55356','(612) 667-9167','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 02:09:30',0,NULL,3,1,1,1,'\\  ','jcam2938'),(14322,782937887011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','ollie_kidd','ollie@imagestore.com.au','Oliver Kidd','1 Alpha Court, Moe','Moe','Victoria','AUSTRALIA','3825','0437990266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 02:51:34',0,NULL,3,1,2,1,'、 ','ollie_kidd'),(14323,782941249011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','patclamp','patclamp@tpg.com.au','Patrick Clamp','53 Lemonwood Circuit','Thornton','New South Wales','AUSTRALIA','2322','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 03:11:06',0,NULL,3,1,2,1,'、 ','patclamp'),(14324,868197506012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','rockhamcheng','chengrockham@hotmail.com','Ruohan Cheng','243 Fosdick St<br>Apt 2','Cincinnati','OH','UNITED STATES','45219-2341','(513) 470-8468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 03:47:30',0,NULL,3,1,1,1,'\\  ','rockhamcheng\r蓝天白云长柄伞'),(14325,782950758011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','maniamehmet','mehmet_mania@hotmail.com','Mehmet Canbek','Ramada Plaza Hotel<br>Halaskargazi Caddesi No:63 Sisli-Osmanbey','Istanbul','','TURKEY','34373','00905325504948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 03:47:45',0,NULL,3,1,3,1,'RA117779340CN\r ','maniamehmet\rGLSG001'),(14326,723488259008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','priyantha2006','priyantha60@hotmail.com','priyantha athukorala','74 kallay st<br>clayton south','clayton','Victoria','AUSTRALIA','3169','0395127500','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-22 03:43:32',0,NULL,3,1,3,1,'RA117779251CN\r ','priyantha2006\rHSPL005\r澳标'),(14327,0,220875994333,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',10.49,'eastar4','ottawa_65','may1422@hotmail.com','mohamed yawar','48 fairpark dr.','ottawa','ON','CANADA','k2g6x8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 04:03:13',0,NULL,3,1,2,1,'、 ','ottawa_65'),(14328,0,230687754510,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',1.25,'eastar4','staskachel','rusanosy@hotmail.com','Stanislav Rusanov','ul. 250-let Chelyabinska, dom 25, kv.45','Chelyabinsk','RU','RUSSIAN FEDERATION','454003','+79123183652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 04:55:34',0,NULL,3,1,2,1,'、 ','staskachel'),(14329,8881319261708089,111,'兼容眼镜',1,'GLOT001',0,'eastar4uk','imtiaz4555','imtiaz001@blueyonder.co.uk','Imtiaz Hussain','10 Fossdyke Close','Hayes','Middlesex','UNITED KINGDOM','ub4 9st','07979521905',NULL,NULL,NULL,'2011-10-22 05:35:08',0,NULL,3,1,3,1,'RA184571736CN\r ',' 补货'),(14330,636462652013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',2,'GPS0004',219.98,'eastar4','rszaz','ric.schneider@gmx.de','Richard Schneider','Guter Mann Straße 10','Zülpich','','GERMANY','53909','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 05:53:17',0,NULL,3,1,3,1,'RA117779044CN\r ','rszaz\rGPS0004'),(14331,868222567012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','alvaro_lorenzana','alvarolorenzana@gmail.com','Alvaro Lorenzana','c/ cañaveral, 8','Conil (cadiz)','Andalucía Ceuta y Melilla','SPAIN','11140','650423362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 06:00:12',0,NULL,3,1,3,1,'RA184571719CN\r ','alvaro_lorenzana\rGLOT001\r兼容型3D眼镜 通用型'),(14332,782963188011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','palmiradixson','rdixsonxpress@yahoo.com','Palmira Robertson','PO Box 321','Pocahontas','AR','UNITED STATES','72455-0321','(870) 378-5721','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 06:08:06',0,NULL,3,1,1,1,'\\  ','palmiradixson'),(14333,782979989011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','zzzkoesozzz','zzzkolesozzz@yandex.ru','Sergey Kolesnikov','Zarayskaya 25-2-16','Moscow','','RUSSIAN FEDERATION','109428','79652993333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 07:11:33',0,NULL,3,1,3,1,'RA184571767CN\r ','zzzkoesozzz\rGLOT001\r兼容型3D眼镜 通用型'),(14334,868238581012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','brazzle84074','brazzle@gmail.com','Braden Bartlett','1192 N 600 E','Tooele','UT','UNITED STATES','84074-9690','(435) 830-3750','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 07:17:40',0,NULL,3,1,1,1,'\\  ','brazzle84074'),(14335,636478632013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.89,'eastar4','kriefer','kriefer@zahav.net.il','Eran Krief','Balfor 1920','Ashkelon','','ISRAEL','78497','00972545555895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 07:43:47',0,NULL,3,1,3,1,'RA117779225CN\r ','kriefer\rMOLO009'),(14336,868246411012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','nsdabre','nimba2008@yahoo.com','nimba shankali','450 Springberry Ct','alpharetta','GA','UNITED STATES','30005','(616) 690-1511','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 07:48:44',0,NULL,3,1,1,1,'\\  ','nsdabre'),(14337,0,220875994306,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',2.25,'eastar4','karamig','g.karamichalis@gmail.com','KARAMICHALIS GEORGIOS','FOKIONOS NEGRI 3','ATHENS','','GREECE','11257','00306972219770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 08:13:56',0,NULL,3,1,2,1,'、 ','karamig'),(14338,868258109012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','a01384452','pangbobelle@gmail.com','Bo Pang','710 N 700 E<br>APT 1','LOGAN','UT','UNITED STATES','84321-3560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 08:31:33',0,NULL,3,1,1,1,'\\  ','a01384452\r24K 多色伞 '),(14339,783042647011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',1,'CCGR001',4.99,'eastar4','maor_saadon','maorsaadon@gmail.com','Maor Saadon','grinboim 28/1','lod','','ISRAEL','71276','0542431187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 10:33:54',0,NULL,3,1,2,1,'、 ','maor_saadon'),(14340,636514389013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','malkaavieli','malka.avieli@gmail.com','aviel malka','bilaik 40','kiryat shmona','israel','ISRAEL','11023','0508587668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 10:38:07',0,NULL,3,1,2,1,'、 ','malkaavieli'),(14341,868301668012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','alexhieatt','alexhieatt@yahoo.com','Dr. Alex Hieatt','Blackbird Cottage, The Green,<br>Little Thurlow','Haverhill','Suffolk','UNITED KINGDOM','CB97JL','01440783538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 10:43:50',0,NULL,3,1,2,1,'、 ','alexhieatt'),(14342,782672949011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','andyferdean','alexferdean@yahoo.com','Alexandru Ioan Ferdean','str. Siderurgistilor nr. 18 bl. D7 ap. 54','Galati','Galati','ROMANIA','800374','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:02:04',0,NULL,3,1,2,1,'、 ','andyferdean'),(14343,868308152012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','vslc285','vincentslchan@gmail.com','Vincent Chan','Flat 3, 4/F, Block C, Fortress Metro Tower<br>238 King\'s Road, North Point, Hong Kong','default','','HONG KONG','default','(852( 95080368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:03:28',0,NULL,3,1,2,1,'、 ','vslc285'),(14344,741056974001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','jakki123','jakkicolwill@aol.com','Jakki Colwill','4 Washington Square, Easington Village','Peterlee','Durham','UNITED KINGDOM','SR83AH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:11:06',0,NULL,3,1,3,1,'RA117779203CN\r ','jakki123\rBR3D005'),(14345,783058857011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','tompaexit','tomas.a.andersson@gmail.com','Tomas Andersson','Norra Hamngatan 6B','Uddevalla','','SWEDEN','45130','0705637220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 11:25:18',0,NULL,3,1,3,1,'RA117779115CN\r ','tompaexit\rHBPH002'),(14346,868321423012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.9,'eastar4','dctel09','pavel@dctel.net','Pavel Lyuty','Lenina ave 187 / 64','Zaporozhye','Zaporozhye','UKRAINE','69006','+380 50 341 76 79','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:41:40',0,NULL,3,1,2,1,'、 ','dctel09'),(14347,783066669011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',35.99,'eastar4uk','tomosalun1989','tahughes1@gmail.com','Tomos Hughes','67 Doe Close<br>Penylan','Cardiff','Cardiff','UNITED KINGDOM','CF23 9HJ','07547921507','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 11:49:23',0,NULL,3,1,3,1,'RA117779248CN\r ','tomosalun1989\rHSPL015\r英标'),(14348,585070166004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','stimey02187','richrtr@bellsouth.net','Tracy Waite','1088 Lake Weldona Dr','Orlando','FL','UNITED STATES','32806','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-22 12:09:41',0,NULL,3,1,1,1,'\\  ','stimey02187'),(14349,8881319291548883,111,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',0,'cnfaner','flotteuse','nicos1@feignoux.ch','feignoux nicolas','bauma 17','yvonand','','SWITZERLAND','1462','0764342178',NULL,NULL,NULL,'2011-10-22 13:52:28',0,NULL,3,1,3,1,'RA184571886CN\r ','HSPL002\r补货\r只发耳机 \r发之前测试一下 '),(14350,636564108013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','olez','zeljko.lon@googlemail.com','Zeljko Loncaric','Hochweg 13b','Regensburg','','GERMANY','93049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 13:58:08',0,NULL,3,1,2,1,'、 ','olez'),(14351,868411962012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','iammastersensei','jvdw007@gmail.com','Jaco van der Walt','52 Lambourne Way<br>Tongham','Farnham','Surrey','UNITED KINGDOM','gu10 1ab','07708934523','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 15:20:00',0,NULL,3,1,3,1,'RA117779129CN\r ','iammastersensei\rOTCN002'),(14352,868415119012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','ssyktl401','ssyktl40@gmail.com','Hoon Sik Cho','342 KeoSong Villa 4th Fl.<br>Pyeongchangdong Jongrogu','Seoul','','KOREA,REPUBLIC OF','110847','821034199371','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 15:28:06',0,NULL,3,1,2,1,'、 ','ssyktl401'),(14353,783161545011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','dcmcphee1968','mcpheec@hotmail.com','Donald McPhee','35 Parkland Drive','Sylvan Lake','AB','CANADA','T4S 1J5','(780) 841-0894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 15:49:41',0,NULL,3,1,3,1,'RA117779132CN\r ','dcmcphee1968\rBR3D001'),(14354,782815566002,120796487295,'NEW MIE2i Mobile In-ear Headset IE2 for iPhone Ipod',1,'HSBS002',85.99,'buysia','biglittles','littles@optonline.net','Fontaine Littles','393 Wobbly Barn Rd','Henryville','PA','UNITED STATES','18332','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 16:14:58',0,NULL,3,1,1,1,'\\  ','biglittles'),(14355,783178187011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','andi29973','andihalliday@hotmail.co.uk','Andi Halliday','49<br>Ganton Ave','Cottingham','Humberside','UNITED KINGDOM','HU165HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 16:19:18',0,NULL,3,1,3,1,'RA117779336CN\r ','andi29973\rGLOT001*2\r兼容型3D眼镜 通用型'),(14356,868446932012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','galactic-ershiep','ershiep@yahoo.com','Douglas A Burgess','58A Stoney Run','Maple Shade','NJ','UNITED STATES','08052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 16:26:28',0,NULL,3,1,1,1,'\\  ','galactic-ershiep'),(14357,868453928012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','dmitri-rastorguev','pixarplus@mail.ru','Bodaneu Tatiana','Str. Independentei  24/1  aprt. 85','Kishinev','MD','MOLDOVA, REPUBLIC OF','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 16:39:31',0,NULL,3,1,2,1,'、 ','dmitri-rastorguev\racer 5pin1.25 6cm'),(14358,783222566011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',1,'MOSA005',65.9,'eastar4','hern3438','hern3438@hotmail.com','melba hernandez','1690 Heywood St<br>Unit D','Simi VAlley','CA','UNITED STATES','93065-8500','(805) 485-1601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 17:45:16',0,NULL,3,0,18,0,NULL,'hern3438\r由卢建刚代发'),(14359,783224114011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','b.oldhaver','b.oldhaver@hitzemann.org','Bernd Oldhaver','Fischbeker Holtweg 123','Hamburg','','GERMANY','21149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:47:15',0,NULL,3,1,2,1,'、 ','b.oldhaver'),(14360,868496499012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','dinosang1964','dinosang@in.gr','KONSTADINOS CHATZIIOANNOU','KOUMANOUDI str 49-51','ATHENS','GIZI','GREECE','11474','6936456740','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 17:55:02',0,NULL,3,1,3,1,'RA117779367CN\r ','dinosang1964\rGLSG001*2'),(14361,723751948008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',32.99,'au-buy','ps_fragrances1','pet44_meg51@hotmail.com','Peter Weegink','P.O. Box 4622','Forest Lake','Queensland','AUSTRALIA','4078','0412513981','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-22 18:09:49',0,NULL,3,1,3,1,'RA117779146CN\r ','ps_fragrances1\rHSPL010\r澳标'),(14362,636660024013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','dan_a_f','danaf@globo.com','Daniel Ferreira','km 7 estrada do coco, condomíminio parque dos coqueiros quadra 1 lote 11<br>Bairro Portao','Lauro de Freitas','Bahia','BRAZIL','42700-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 18:23:28',0,NULL,3,1,2,1,'、 ','dan_a_f'),(14363,868521818012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','fouad_jh','fouad_jh@hotmail.com','Fouad Hilly','Jaguar Land Rover Limited<br>Abbey Road, Whitley','Coventry','West Midlands','UNITED KINGDOM','CV3 4LF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 18:29:40',0,NULL,3,1,3,1,'RA117779089CN\r ','fouad_jh\rOTCN002'),(14364,783780645002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','shiloh_scc','rickm@swcc.com','Rick Marucci','3810 Hamby Rd<br>The Software Construction Company','Alpharetta','GA','UNITED STATES','30004','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 18:36:28',0,NULL,3,1,1,1,'\\  ','shiloh_scc'),(14365,636672371013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','claudiaey','claudia.yoshinaga@gmail.com','Claudia Yoshinaga','Rua Prof. Carolina Ribeiro, 123 ap. 151<br>Vila Mariana','Sao Paulo','Sao Paulo/SP','BRAZIL','04116020','551155496269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 18:56:41',0,NULL,3,1,2,1,'、 ','claudiaey'),(14366,783270513011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','flighttracking','karol99_3@hotmail.com','Karol Beukema','Rustenburgerstraat 223-3','Amsterdam','','NETHERLANDS','1073GA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 19:10:08',0,NULL,3,1,2,1,'、 ','flighttracking'),(14367,868546570012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','fotomoto11','7775676@gmail.com','Mikhail Larin','9-Parkovaya dom 30 k 22','Moscow','','RUSSIAN FEDERATION','105077','(985)7775676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 19:13:01',0,NULL,3,1,3,1,'RA117779150CN\r ','fotomoto11\rWWOT001'),(14368,783286046011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','locutus001','jan.golmajer@gmail.com','Jan Golmajer','Žiganja vas 15','Križe','','SLOVENIA','4294','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 19:39:40',0,NULL,3,1,3,1,'RA117779279CN\r ','locutus001\rGLSG001'),(14369,783301685011,320721866777,'NEW Galleria Sunflower Bloom 3-section Folding umbrella',1,'UM00004',13.95,'eastar4','benitafa','benita.aslaksen@gmail.com','Benita Flåtten Aslaksen','Flåtenveien 17B','Harstad','Troms','NORWAY','9404','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 20:14:04',0,NULL,3,1,2,1,'\\  ','benitafa\r向日葵三折叠伞 '),(14370,783309541011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','doan0076v3z','doan007@yahoo.com','Doan Tran','423 E Latimer Ave<br>Apt 4','Campbell','CA','UNITED STATES','95008-1261','(408) 410-0890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 20:29:44',0,NULL,3,1,1,1,'\\  ','doan0076v3z'),(14371,783312651011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',63.99,'eastar4','edvin_75','edvinmyftiu@gmail.com','Edvin Myftiu','Nj. Bashkiake 8, Rruga Riza Cerova, ND2, H7, Ap.47','Tirane','Tirane','ALBANIA','1017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 20:46:12',0,NULL,3,1,3,1,'RA117779296CN\r ','edvin_75\rOTSO004'),(14372,783325331011,320735056905,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',13.99,'eastar4uk','iosi2419','txokissnoain@hotmail.com','IÑAKI OSINAGA CHAMORRO','CALLE MERINDAD DE PAMPLONA Nº5, 1ºB','NOAIN','Navarra','SPAIN','31110','685983018','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 21:01:42',0,NULL,3,1,2,1,'\\  ','iosi2419\r 大水量花洒'),(14373,585237353004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','utvols106','bcoxvols106@att.net','Brian Cox','1412 Trotwood Ave<br>Suite 19','Columbia','TN','UNITED STATES','38401-4979','(931) 381-1603','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-22 21:03:06',0,NULL,3,1,1,1,'\\  ','utvols106'),(14374,636705364013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','wwc-2009','tanyaprimrose@hotmail.com','wesley carlson','10 trucano close whitfield','cairns','Queensland','AUSTRALIA','4870','0434073686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 21:05:06',0,NULL,3,1,3,1,'RA117779013CN\r ','wwc-2009\rGPS0004'),(14375,868612971012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',76.99,'eastar4uk','mikeyoliver','michael.ball6@btopenworld.com','Michael Ball','1 The Ridings','Boroughbridge','North yorkshire','UNITED KINGDOM','YO51 9PD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 21:14:41',0,NULL,3,1,3,1,'RA117779234CN\r ','mikeyoliver\rOTSO004*2'),(14376,868607213012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','billhover','a.wardingham1@sky.com','Bill Mundy','Landmarc, Bld 120, Netheravon Down,<br>Salisbury Road, Netheravon','Salisbury','Wiltshire','UNITED KINGDOM','SP49RB','01980620068','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 21:22:45',0,NULL,3,1,3,1,'RA117779061CN\r ','billhover\rOTCN001'),(14377,636728583013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','anthony_tian','anthony.tian@hotmail.com','Anthony Tian','Parkgatan 4','UDDEVALLA','Vastra Gotaland','SWEDEN','45142','0702521214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 21:30:26',0,NULL,3,1,2,1,'、 ','anthony_tian'),(14378,636729066013,230676837702,'New Philips Sonicare Essence Toothbrush Handle HX5500',1,'HBPH006',19.99,'eastar4','belizephotoman','belizephotoman@aol.com','Richard Spencer','430 Diane Cir','Casselberry','FL','UNITED STATES','32707-3014','(407) 695-1309','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 21:32:45',0,NULL,3,0,1,1,'\\ ','belizephotoman\r已经退款  改发一个HX5300\r'),(14379,868661509012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','war.inc','diablosflare@hotmail.com','Omiel Fairweather','3498 Coral Springs Dr','Coral Springs','FL','UNITED STATES','33065-7400','(954) 213-3455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-22 23:29:06',0,NULL,3,1,1,1,'\\  ','war.inc\rAUI Transceiver  MX20T'),(14380,636788533013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','tonyinge56','tcamilleri56@yahoo.com.au','Tony Camilleri','78a Grove Rd<br>Lesmurdie','Perth','Western Australia','AUSTRALIA','6076','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 02:03:29',0,NULL,3,1,3,1,'RA184571841CN\r ','tonyinge56\rOTES001'),(14381,783439105011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','shm2011','shahid_mian@hotmail.com','S Mian','7 Cronulla Way<br>Cronulla Way','Taylors Hill','Victoria','AUSTRALIA','3037','0407959072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 03:43:22',0,NULL,3,1,3,1,'RA117779319CN\r ','shm2011\rGLOT001*3\r兼容型3D眼镜 通用型'),(14382,585316609004,140583345997,'GENUINE Plantronics Voyager 520  Bluetooth Headset',1,'HSPL011',32.99,'cnfaner','nabiloxyerr','nabiloxyer@yahoo.com','nabil hafez','101 Pulaski Blvd<br>italian pizza and grill','bellingham','MA','UNITED STATES','02019-2744','(508) 243-3179','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-23 04:08:51',0,NULL,3,1,1,1,'\\  ','nabiloxyerr'),(14383,783446946011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',35.5,'eastar4','andyleungkaon','andy_k_o_leung@yahoo.com','Leung Ka On Andy','2407 Ming Yan House, Ming Ngar Court, Tai Po','Hong Kong','','HONG KONG','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 04:21:50',0,NULL,3,1,2,1,'\\ ','andyleungkaon\r'),(14384,868759593012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.39,'eastar4','amics','amic@bk.ru','Mikhail Simonov','Industrii 38-176','Ekaterinburg','Sverdlovskaya oblast','RUSSIAN FEDERATION','620042','+7(904)98-27-738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 06:04:16',0,NULL,3,1,2,1,'、 ','amics\rAcer 5pin1.25 3cm'),(14385,783466092011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'eastar4','waruna6699','warunathilakarathna@yahoo.com','Waruna Thilakarathna','Commercial Bank Of PLC<br>Matale Road','Galewela','SriLanka','SRI LANKA','+94','(+94)077-3881602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 06:16:36',0,NULL,3,1,2,1,'、 ','waruna6699'),(14386,783470792011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','lakey_814','louise.lakey@hotmail.com','Louise Lakey','1/63 Ulupna Rd','Ormond','Victoria','AUSTRALIA','3204','0457719434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 06:38:07',0,NULL,3,1,2,1,'、 ','lakey_814'),(14387,0,320776936028,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.04,'eastar4','mamptah','kalef_b@hotmail.com','Bernard Kalef','72 Chemin du petit bois','Toulon','Provence-Alpes-Côte d\'Azur','FRANCE','83000','06.23.80.38.58','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 06:38:31',0,NULL,3,1,2,1,'、 ','mamptah'),(14388,636843425013,230676837702,'New Philips Sonicare Essence Toothbrush Handle HX5500',1,'HBPH006',19.99,'eastar4','australiashamar','shamar333@gmail.com','Martin Clark','15 CARROWBROOK AVE<br>GLENWOOD','sydney','New South Wales','AUSTRALIA','2768','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 07:43:45',0,NULL,3,1,2,1,'、 ','australiashamar'),(14389,8881319356841023,111,'CAB-6060',120,'CASS003',1080,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815',NULL,NULL,NULL,'2011-10-23 08:00:41',0,NULL,3,1,12,1,'1733153645 ','CASS001+CASS002+CASS003\r一共买了120条CAB-6060\r10条 CAB-2660\r40条CAB-2626\r申报三十美金'),(14390,783495521011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','drjanetm72','drjanetm72ebay@optusnet.com.au','Janet Matthews','48 McRaes Avenue','Penshurst','New South Wales','AUSTRALIA','2222','0282129788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 08:11:54',0,NULL,3,1,2,1,'、 ','drjanetm72\r澳标'),(14391,868805170012,220843026006,'New in box Panasonic Nail Polisher ES 2400c ',1,'OTPA001',16.99,'eastar4','32163622','leongjerry@hotmail.com','CHON WAI LEONG','2  KARDELLA CRESCENT<br>NARWEE','SYDNEY','New South Wales','AUSTRALIA','2209','0451669218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 08:46:42',0,NULL,3,1,2,1,'、 ','32163622\r自动美甲器'),(14392,636859329013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','elektrofuzzy88','g.schruf@gmail.com','Martin Astner','Gaisberg 17','Vomp','','AUSTRIA','6134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 08:49:37',0,NULL,3,1,2,1,'、 ','elektrofuzzy88'),(14393,783510451011,320778755250,'New Motorola H350 Bluetooth Wireless Headset',1,'HSMO005',8.95,'eastar4uk','7416jason','spud_56@msn.com','jason coles','42 farmeadow court<br>thorplands','northampton','Northamptonshire','UNITED KINGDOM','nn3 8at','07737841254','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 08:54:43',0,NULL,3,1,3,1,'RA117779075CN\r ','7416jason\rHSMO005\r英标'),(14394,741493329001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','eugen12d','eugen.dumitrescu@gmail.com','Eugen Dumitrescu','#305 13270 105A Ave','Surrey','BC','CANADA','V3T2A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 09:42:21',0,NULL,3,1,3,1,'RA117779092CN\r ','eugen12d\rBR3D008'),(14395,783532784011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','rocambol333','da.al.con@hotmail.com','maria victoria Sanchez Blazquez','Las pedrizas, nº3(junto a SEDIACO)','Aldeanueva del Camino','Extremadura','SPAIN','10740','927479031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 09:46:14',0,NULL,3,1,2,1,'、 ','rocambol333'),(14396,868833082012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','wwill1066','wwill@siu.edu','Wesley Will','519 N 9th St','Murphysboro','IL','UNITED STATES','62966','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 09:47:24',0,NULL,3,1,1,1,'\\  ','wwill1066'),(14397,8881319364734296,111,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',0,'eastar4','tommyknockerz99','renaud.henrotte@gmail.com','Renaud Henrotte','Rue Prince Henri,31','Hondelange','','BELGIUM','6780','063233094',NULL,NULL,NULL,'2011-10-23 10:12:14',0,NULL,3,1,3,1,'RA117779101CN\r ','WLIN010+ANTY002 \r补发的'),(14398,868880685012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','ralfrot1','r-zikmund@versanet.de','Ralf Zikmund','Bonnemannstrasse 35','Essen','','GERMANY','45359','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 11:27:00',0,NULL,3,1,2,1,'、 ','ralfrot1'),(14399,783581184011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','guin1966','wguiness@hotmail.co.uk','WENDY GUINESS','c/o NL Group, Riverside Building<br>Livingstone Road','Hessle','East Riding of Yorkshire','UNITED KINGDOM','HU13 0DZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 11:34:15',0,NULL,3,1,3,1,'RA184571798CN\r ','guin1966\rGLOT001\r兼容型3D眼镜 通用型'),(14400,868888065012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','coconutpete79','rene.butschek@gmail.com','René Butschek','Ungargasse 3/3/50','Wien','','AUSTRIA','1030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 11:43:02',0,NULL,3,1,2,1,'、 ','coconutpete79'),(14401,783647361011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.69,'eastar4','i3oges','boges1@hotmail.com','Matt Bogenhagen','650 7th Street North','Hudson','WI','UNITED STATES','54016','(715) 220-9941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 13:50:01',0,NULL,3,1,1,1,'\\  ','i3oges'),(14402,636984637013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','planktons','stereo@inbox.lv','Andris Orlovskis','Eveles iela 6 - 25','Riga','','LATVIA','LV1013','(+371) 29636316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 14:57:01',0,NULL,3,1,2,1,'、 ','planktons'),(14403,869010395012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','krolik1060.2008','krolik1060@onet.eu','Kamil Solowiej','14B<br>Claremont avenue','New Malden/Surrey','London','UNITED KINGDOM','KT3 6QL','02032770016','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 15:19:38',0,NULL,3,1,3,1,'RA117779035CN\r ','krolik1060.2008\rHSNO019+CCNO001'),(14404,783703799011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mp2473','lindamarco@videotron.ca','MARCO PELLETIER','148 DU JADE','GRANBY','QC','CANADA','J2H0E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 15:26:36',0,NULL,3,1,2,1,'、 ','mp2473'),(14405,783710903011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','horse1664','horse1664@hotmail.com','jason garton','82 Salisbury Road','STEVENAGE','Hertfordshire','UNITED KINGDOM','SG1 4PF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 15:42:20',0,NULL,3,1,3,1,'RA117779027CN\r ','horse1664\rRELO003\r红边优联'),(14406,783747430011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','lodle0819','lodle0819@comcast.net','Erin Odle','8139 Parkridge Cir N','Jacksonville','FL','UNITED STATES','32211-6232','(904) 727-3880','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 16:25:05',0,NULL,3,1,1,1,'\\  ','lodle0819'),(14407,783752020011,320588276103,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',18.4,'eastar4','boredyellowdog','jewels.ca@telus.net','Julie Micksch','906 Acacia Road','Comox','BC','CANADA','V9M 3Y6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 16:30:05',0,NULL,3,1,2,1,'、 ','boredyellowdog'),(14408,783727733011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','bigpopa1501','sgraefenstein@yahoo.com','Scott Graefenstein','552 Lynnmeade Rd','Gretna','La','UNITED STATES','70056-7239','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 16:54:26',0,NULL,3,1,1,1,'\\  ','bigpopa1501'),(14409,783809201011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','sandra4201','okrigovsky@extel.sk','Ondrej Krigovsky','Berlinska 17','Kosice','Slovakia','SLOVAK REPUBLIC','SK-04013','+421905521468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 17:31:20',0,NULL,3,1,2,1,'、 ','sandra4201'),(14410,869114233012,220747230769,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',11.99,'eastar4uk','sues-fashionfundus','wildesue@gmx.at','Susa Juhasz','Sarasdorfer Hauptstr.94','Sarasdorf an der leitha','','AUSTRIA','2454','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 17:15:03',0,NULL,3,1,2,1,'、 ','sues-fashionfundus\r欧标'),(14411,783826342011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','pointenergie','commercial@pointenergie.fr','POINT PILES','133 BD GAMBETTA','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06000','0493963065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 17:46:42',0,NULL,3,1,2,1,'、 ','pointenergie'),(14412,783839048011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','golf037e','golf037@gmail.com','Patchara Tangcharoen','179-185 Rasadorn-dumri road<br>Noppadol Electronics co.,ltd., Na-muang','Muang','Prachinburi','THAILAND','25000','6637211213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 17:58:19',0,NULL,3,1,2,1,'、 ','golf037e'),(14413,637115783013,230647517968,'NIB Sony TDG-BR50/P Youth Size 3D Active Glasses  pink',1,'OTSO005',59.99,'eastar4','joel_sansome','joelsansome@gmail.com','Joel Sansome','5620 Frances St.','Burnaby','BC','CANADA','V5B 1T8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 18:23:33',0,NULL,3,1,3,1,'RA117779265CN\r ','joel_sansome\rOTSO005'),(14414,783356817011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sk8er_steven','sk8er_steven@hotmail.com','steven a','7860, pierre chasseur<br>pierre chasseur','montreal','QC','CANADA','H1E 3K4','(514) 260-6069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 18:45:51',0,NULL,3,1,2,1,'、 ','sk8er_steven'),(14415,783888234011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','scudo4396','joehayes_1@msn.com','Joe Hayes','24 Harden Close<br>Great Oakley','Corby','Northamptonshire','UNITED KINGDOM','NN18 8JW','07886819826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 18:46:38',0,NULL,3,1,3,1,'RA184571824CN\r ','scudo4396\rHBPH002'),(14416,783904015011,320394905532,'Acer Aspire 7110 7000 9300 Bluetooth Module 2.0 +cable',1,'BTAC2008',9.88,'eastar4','jdelphi','jdelphi@gmx.de','Janos Siejkowski','Oberstadt 85a','Lich','','GERMANY','35423','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 18:58:33',0,NULL,3,1,2,1,' 、','jdelphi\racer 4pin1.25 18cm '),(14417,637153764013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','5shelly','gorgebar@hotmail.com','Greg Montgomery','3641 N Litchfield Ave','Wichita','KS','UNITED STATES','67204-3927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 19:17:56',0,NULL,3,1,6,1,'EE491016057CN ','5shelly\r兼容型3D眼镜 通用型'),(14418,869248780012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',13.85,'eastar4uk','wvreenen','w.reenen3@upcmail.nl','Wim van Reenen','Watertuin 208','BARNEVELD','','NETHERLANDS','3772VD','(0342) 413182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 19:22:33',0,NULL,3,1,2,1,'、 ','wvreenen\r欧标'),(14419,783940834011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','orbsplateau','orbsplateau@yahoo.ca','Cyrus Showkati','33 Parklane','Dollard-Des-Ormeaux','QC','CANADA','H9G 1B8','(514) 249-1321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 19:39:44',0,NULL,3,1,2,1,'、 ','orbsplateau'),(14420,869267556012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT004',26.99,'eastar4uk','lutzenulli','kallienelli@hotmail.com','Willi Roosen(Oedinghofen)','Breslauerstr.60','Nettetal/Kaldenkirchen','','GERMANY','41334','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 19:57:38',0,NULL,3,1,3,1,'RA184571807CN\r ','lutzenulli\rGLOT004'),(14421,585664723004,140519326541,'New Sony Ericsson HBH-PV710 BLUETOOTH HEADSET track#',1,'HSSE008',38.99,'cnfaner','whilders','willem@familiehilders.nl','Willem Hilders','Waardijnstraat 43','WEESP','','NETHERLANDS','1383CH','+31294432105','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-23 19:58:26',0,NULL,3,1,3,1,'RA184571890CN\r ','whilders\rHSSE008\r欧标'),(14422,783961469011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','519cruzon100','cruzon100@hotmail.com','elio mancuso','478 salisbury street','london','ON','CANADA','n5y3b5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 20:03:49',0,NULL,3,1,3,1,'RA117779058CN\r ','519cruzon100\rRCLO006'),(14423,869305297012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Laura Hixon','7430 NEW TECHNOLOGY WAY','FREDERICK','MD','UNITED STATES','21703-8302','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 20:11:45',0,NULL,3,1,1,1,'\\ ','bigtimepimp'),(14424,783984542011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',149.7,'eastar4','kimberlythegr8','ksn76@windstream.net','Kimberly Noland','107 Gail Dr','Tryon','NC','UNITED STATES','28782','(828) 894-3252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 20:36:35',0,NULL,3,1,1,1,'\\  ','kimberlythegr8'),(14425,869334608012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Hillary Gove','294 Hanover St<br>Apt 5G','Boston','MA','UNITED STATES','02113-1808','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 20:51:04',0,NULL,3,1,1,1,'\\  ','bigtimepimp'),(14426,869335320012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 20:52:38',0,NULL,3,1,3,1,'RA184571909CN\r ','lochearn1234\rWLAP002\r发AIRPORT'),(14427,783982885011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',149.7,'eastar4','kimberlythegr8','ksn76@windstream.net','Kimberly Noland','107 Gail Dr','Tryon','NC','UNITED STATES','28782','(828) 894-3252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 20:33:58',0,NULL,5,0,18,0,NULL,'kimberlythegr8\r客户多买了这票需要退款'),(14428,869341677012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Colin Channell','120 Pepin Dr<br>Unit B2','Newport','VT','UNITED STATES','05855-9209','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 21:03:01',0,NULL,3,1,1,1,'\\  ','bigtimepimp'),(14429,585696517004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','craig4995','thumper.211@verizon.net','craig weston','11711 Center St','north huntingdon','PA','UNITED STATES','15642-2381','(412) 580-0926','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-23 21:08:07',0,NULL,3,1,1,1,'\\  ','craig4995'),(14430,783997501011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','5rgardner11','rgardner11@comcast.net','robert gardner','2315 Lake Elmo Ave N','lake elmo','MN','UNITED STATES','55042-8407','(651) 770-8336','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 21:26:34',0,NULL,3,1,1,1,'\\  ','5rgardner11'),(14431,869361486012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','cherrie069','cherrie1williams@yahoo.com','Ebony Shelby','706 W Mitchell Cir<br>Apt 613','Arlington','TX','UNITED STATES','76013-2523','(601) 529-0040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 21:35:27',0,NULL,3,0,1,1,'\\ ','cherrie069\r已入库'),(14432,784019650011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',38.99,'eastar4uk','rupado','rupadoc@hotmail.com','Rubén  Palop Doceda','c/Germanías nº 5, 4º, 15','Xàtiva','Comunidad Valenciana','SPAIN','46800','962271234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 21:38:32',0,NULL,3,1,3,1,'RA117779282CN\r ','rupado\rOTSO004'),(14433,869388714012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','janlooijmans','jan@looijmans.be','Jan Looijmans','Kluizerdijk<br>39','Valkenswaard','','NETHERLANDS','5554 XA','040-8410600','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 22:36:31',0,NULL,3,1,2,1,'、 ','janlooijmans'),(14434,784042205011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','hezkelos','hezuz@013.net','hezi avraham','8b Emek Iron St.','Kfar Saba','','ISRAEL','44627','972523341818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 22:37:37',0,NULL,3,1,2,1,'、 ','hezkelos'),(14435,783457959011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','clairvoyance18','clairvoyance_18@yahoo.co.in','Ishan Patel','4218 Foxfire Ct','Toledo','OH','UNITED STATES','43615-7111','(267) 902-2591','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 22:45:30',0,NULL,3,1,1,1,'\\  ','clairvoyance18'),(14436,585374081004,140516860307,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',10.9,'cnfaner','sarah010106','sarah@mymobileoffice.co.uk','Sarah Thomas','6 PeelersCourt<br>Moorland Street','Axbridge','Somerset','UNITED KINGDOM','BS26 2BB','07889288965','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-23 22:56:45',0,NULL,3,1,3,1,'RA184571815CN\r ','sarah010106\rWLAT008+ANTY001'),(14437,580204348003,130466041351,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',1,'WWSI002+ANCN001',32.88,'cnfaner','csi_bus','clicksinc@gmail.com','Click Solution Inc.','PO Box 934','Bentonville','AR','UNITED STATES','72712-0934','(248) 786-8996','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-23 23:01:53',0,NULL,3,1,1,1,'\\  ','csi_bus'),(14438,784059843011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','skfox26','brain_wash26@hotmail.com','Samuel Giroux','109 115e avenue apt 6','saint-jerome','QC','CANADA','j7y1c8','(450) 516-2726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 23:33:13',0,NULL,3,1,3,1,'RA117779353CN\r ','skfox26\rGLSG001'),(14439,869419003012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.3,'eastar4','dev-boris','d.boris.k@gmail.com','Boris Devjatkin','Ocean avenue 98-7','Vladivostok','','RUSSIAN FEDERATION','690002','+79147905232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 00:21:41',0,NULL,3,1,2,1,'、 ','dev-bori\r欧标'),(14440,784084270011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','rj.lindeman','russlindeman@gmail.com','Russell Lindeman','4 Dulcify Crt','St Albans park','Victoria','AUSTRALIA','3219','0352481413','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'rj.lindeman\r'),(14441,784093679011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','serpent2424','serpent24@videotron.ca','pierre marceau','6432a roi-rene','anjou','QC','CANADA','h1k3g3','(514) 713-3707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 00:56:32',0,NULL,3,1,2,1,'、 ','serpent2424'),(14442,580234336003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',13.29,'cnfaner','8007philip','logginireland@msn.com','philip ireland','994 fruitdale dr','grants pass','OR','UNITED STATES','97527','(541) 476-8327','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 01:06:42',0,NULL,3,1,1,1,'\\  ','8007philip'),(14443,864355551012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','knackers100','pmichailides@gmail.com','032Con Michailides','20 Wild Cherry St','Melbourne','Victoria','AUSTRALIA','3032','0393182210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 01:27:00',0,NULL,3,1,2,1,'、 ','knackers100'),(14444,784114617011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','jeff55paintball','jwrightski@gmail.com','Jeffrey Wright','107/1910 6th Ave W','Vancouver','BC','CANADA','V6J1R7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 01:52:16',0,NULL,3,1,2,1,'、 ','jeff55paintball'),(14445,784596826002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','steeveric5746','steevkaplanse@comcast.net','Steve Kaplan','6308 Farmar Ln','Flourtown','PA','UNITED STATES','19031-1308','(215) 836-2760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 01:53:46',0,NULL,3,1,1,1,'\\  ','steeveric5746'),(14446,869471706012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Wendy Dombrowski','1959 Oak St<br>Apt 5','SAN FRANCISCO','CA','UNITED STATES','94117-1816','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 02:07:27',0,NULL,3,1,1,1,'\\  ','bigtimepimp'),(14447,784142676011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','nicar_store','nicarstore@gmail.com','Norka Haiek','3670 S Douglas Rd','Miami','FL','UNITED STATES','33133-6208','(305) 316-9755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 03:20:33',0,NULL,3,1,1,1,'\\  ','nicar_store'),(14448,869505385012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.99,'eastar4uk','jpeters870','jpeters870@aol.com','Joseph Peters','78 E Macon Ave','Staten island','NY','UNITED STATES','10308-1211','(347) 834-7953','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 03:57:23',0,NULL,3,1,1,1,'\\  ','jpeters870'),(14449,784157178011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','bpc872','bcahill@acm.org','Brian P Cahill','6811 Douglas St','Hollywood','FL','UNITED STATES','33024-2821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 04:23:01',0,NULL,3,1,1,1,'\\  ','bpc872'),(14450,637014476013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','sycalis','marcxtor@gmail.com','Juan Marcos Rodriguez','C Arnau D´Oms    Nº 20,  3er Piso','Barcelona','Cataluña','SPAIN','08016','670929061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 05:13:40',0,NULL,3,1,3,1,'RA184571740CN\r ','sycalis\rGLOT005'),(14451,869521850012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',38.97,'eastar4uk','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 05:16:46',0,NULL,3,1,3,1,'RA184571872CN\r ','small.mac\rWLAP008'),(14452,637340897013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','ceturan','ceturan@hotmail.com','Ceyhun TURAN','Idos Organize San. Böl. 2. Cad. No:9','Istanbul','Umraniye','TURKEY','34776','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 05:31:57',0,NULL,3,1,2,1,'、 ','ceturan'),(14453,784168779011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jazzper8','lorenandjudy@surewest.net','Loren Murray','4637 Danvers Ln','Granite Bay','CA','UNITED STATES','95746-6630','(916) 797-0788','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 05:36:59',0,NULL,3,1,1,1,'\\  ','jazzper8'),(14454,869532216012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','starvinmarvin2006','martin_russell3@sky.com','martin russell','18 INGOLDSBY CL','MARCH','Cambridgeshire','UNITED KINGDOM','PE15 9NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 06:11:45',0,NULL,3,1,3,1,'RA184571665CN\r ','starvinmarvin2006\rHSJA010\r英标'),(14455,784179133011,320701896589,'Griffin PowerJolt Dual USB Car Charger for iPhone4 3GS',2,'CCGR001',9.98,'eastar4','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 06:20:29',0,NULL,3,1,2,1,'\\  ','axonalex'),(14456,869543716012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','oleovesen123','oleovesen@gmail.com','Ole Ovesen','Højvangsvej 22','Nørresundby','Nordjylland','DENMARK','9400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 07:07:27',0,NULL,3,1,3,1,'RA117779217CN\r ','oleovesen123\rMOLO009'),(14457,868872094012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','papjohn11','pap_john@hotmail.com','john papadakis','dimokritou 9<br>salamina','athens','attika','GREECE','18901','030 2104675177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 07:14:06',0,NULL,3,1,2,1,'、 ','papjohn11\racer 8pin1.00 8cm'),(14458,8881319442462156,111,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',12.39,'eastar4','xxx_veer_xxx','veer.hi5@gmail.com','Dharamvir Chatoorsing','Royal Road    Union Park','Union Park ','Grand Port','MAURITIUS','','',NULL,NULL,NULL,'2011-10-24 07:47:42',0,NULL,3,1,2,1,'、 ','acer 4pin1.25 4cm  '),(14459,636223332013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','irnel2011','irnel.brkic@egruppen.com','Irnel Brkic','Båtholmsbacken 6','Stockholm','SC','SWEDEN','12742','+46 8 531 939 22    ','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 08:03:15',0,NULL,3,1,6,1,'EE491016026CN ','irnel2011\r兼容型3D眼镜 通用型'),(14460,584013074004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',2,'WWSI006',110.9,'cnfaner','limkelvi','limkelvi@yahoo.com.sg','Lim Kelvin','31 hougang ave 7 #13-09','default','','SINGAPORE','538800','97737127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 08:50:12',0,NULL,3,1,3,1,'RA184571838CN\r ','limkelvi\rWWSI006\r新地址\rLim Kelvin\rBlk 1026 Tai Seng Avenue #03-3544 Singapore 534413\r'),(14461,784213236011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','kuba251056','kuba2510@tlen.pl','Jakub Szefer','Nieuwstraat 117','Kerkrade','','NETHERLANDS','6462 GR','(+31)45-5461677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 08:52:17',0,NULL,3,1,2,1,'\\ ','kuba251056\racer 4pin1.25 15cm '),(14462,8881319446719786,111,'JABRA  BT  500V',1,'HSJA011',0,'cnfaner','manjinitin','manjinitin@hotmail.com','Nitin Patel','U2/130 Forrester Rd','St Marys','New South Wales','AUSTRALIA','2760','',NULL,NULL,NULL,'2011-10-24 08:58:39',0,NULL,3,1,3,1,'RA184571753CN\r ','客户打了13美金补发的 \rHSJA011'),(14463,867387111012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','i.kakoychenko','lafert@ukr.net','Igor Kakoychenko','Tampere str. 17/2, 127','Kiyv','','UKRAINE','02105','(+380)095-3380939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 09:10:23',0,NULL,3,1,3,1,'RA184571869CN\r ','i.kakoychenko\rOTSO002'),(14464,869581921012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*2',249.98,'eastar4','oldvasya1974','oldvasya@gmail.com','Valery Vasiliev','Lihachevkij prospekt, dom 74/1, kv.11','Dolgoprudnyj','','RUSSIAN FEDERATION','141707','916-688-4664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 09:54:00',0,NULL,3,1,6,1,'EE617288724CN','oldvasya1974\rEE491016030CN换单为：EE617288724CN'),(14465,637384845013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sleep820','canteker@gmail.com','Can Teker','Rami, Yenimahalle, Mazharbey Cad.<br>No:19/20','Istanbul','Eyup','TURKEY','34055','00905556796263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:00:31',0,NULL,3,1,2,1,'\\ ','sleep820'),(14466,869591559012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','pooleet','freeline710@yandex.ru','Alexey Rusyaykin','Советская 39','с. Ягодное','Самарская обл','RUSSIAN FEDERATION','445144','+79093649768','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:02:06',0,NULL,3,1,2,1,'\\ ','pooleet\r欧标'),(14467,637385214013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',111.4,'eastar4','mwu0383','mw93775261@yahoo.com.au','ming wu','8 Mildred Street','Wentworthville','New South Wales','AUSTRALIA','2145','0292674563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:02:34',0,NULL,3,1,3,1,'RA117778021CN\r ','mwu0383\rGLOT005'),(14468,869589707012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',67.48,'eastar4','alter-fuenfer','franky9870@googlemail.com','Frank Rapp','Aussiger Strasse 4','Ruesselsheim','','GERMANY','65428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:05:52',0,NULL,3,1,3,1,'RA117778052CN\r ','alter-fuenfer\rWWOT003+WLIN010\r再发一个New Intel 5300 AGN Wireless Network Mini PCI-E Card \r'),(14469,637355290013,230402659419,'Genuine Cisco PVDM-256K-12 VoiceFax DSP Module PVDM-256',1,'OTIN003',50,'eastar4','rate93','hrazakar@gatema.fr','Hery RAZAKARIVONY','14 promenade du millenaire<br>Les métrop. Code p 9461/2805','Courbevoie','Ile-de-France','FRANCE','92400','0625082574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:38:18',0,NULL,3,1,3,1,'RA117778106CN\r ','rate93\rOTIN003\r这票货被原件退回来了等客户问到时补发或退款12.30'),(14470,869603680012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','tmreilsi56','tmreilsi@tpg.com.au','Merritt Tristan','56 Robinsons Road','Deer Park','Victoria','AUSTRALIA','3023','0403956894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:40:57',0,NULL,3,1,2,1,'\\ ','tmreilsi56'),(14471,784043518011,320737035125,'2 pairs NIB Sony TDG-BR50 Youth Size 3D Active Glasses',1,'OTSO005*2',117.99,'eastar4','agneselamentin','tremblaykaren@hotmail.com','karen tremblay','2170, route coulombe','shipshaw','QC','CANADA','g7p 1p1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:52:32',0,NULL,3,1,3,1,'RA117778097CN\r ','agneselamentin'),(14472,780937681011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','celtjay','celtjay@yahoo.co.uk','Jason Gallagher','177E BLACKNESS ROAD','DUNDEE','Dundee (City of)','UNITED KINGDOM','DD1 5PH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 11:31:19',0,NULL,3,1,3,1,'RA117778083CN\r ','celtjay\rGLOT001*2\r兼容型3D眼镜 通用型'),(14473,637403586013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','ozxcess','jshaddick@hotmail.com','Punyalok Das','Level 4, Zenith Centre, Tower B<br>821 Pacific Highway','CHATSWOOD','New South Wales','AUSTRALIA','2067','61284466600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 11:32:16',0,NULL,3,1,3,1,'RA117778018CN\r ','ozxcess\rMOSA006'),(14474,784262025011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',3.5,'eastar4uk','826lucy','lucycaithness@blueyonder.co.uk','lucy caithness','34b allcroft road','london','London','UNITED KINGDOM','NW5 4NE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 11:36:38',0,NULL,3,1,3,1,'RA117778049CN\r ','826lucy\rWLAP004'),(14475,784283599011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','bevo_83','bdlewis@austin.rr.com','Barry  D Lewis','16901 Stray Cv','Round Rock','TX','UNITED STATES','78681','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 12:44:58',0,NULL,3,1,1,1,'\\ ','bevo_83'),(14476,784299840011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','actosell','rschmit1@wowway.com','Ralph Schmitt','260 Blossom Dr','Canton','MI','UNITED STATES','48188-1412','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 13:31:51',0,NULL,3,1,1,1,'\\ ','actosell'),(14477,784301647011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','rodion394','rodion127@yandex.ru','Родион Суханов','Тимуровская 26/2 кв.17','Санкт-Петербург','Санкт-Петербург','RUSSIAN FEDERATION','195297','+79500083864','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 13:35:20',0,NULL,3,1,2,1,'\\ ','rodion394'),(14478,784315386011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','elman78','elmansabre@gmail.com','Elman Suleymanov','Vitebskaya 3/1/655','Moscow','RU','RUSSIAN FEDERATION','121354','+7 916 509-8000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 14:14:56',0,NULL,3,1,2,1,'\\ ','elman78\r'),(14479,784315913011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',39.96,'eastar4','phot2001','macitech@mac.com','Richard Levitt','7475 W 5th Ave<br>Ste 101A','Lakewood','CO','UNITED STATES','80226-1673','(303) 202-6013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 14:16:56',0,NULL,3,1,1,1,'\\ ','phot2001'),(14480,784322971011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','wits_top','wits_top@hotmail.com','Witsawakorn Bandit-Adisai','150/2 Moo7<br>Donkaew','Maerim','Chiangmai','THAILAND','50180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 14:35:17',0,NULL,3,1,2,1,'\\ ','wits_top'),(14481,782966873011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jdrinke','jdrinke@hotmail.com','Jay Rinke','20667 E Oaks Dr','Farmington','MN','UNITED STATES','55024-1593','(651) 460-3604','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 14:39:32',0,NULL,3,1,1,1,'\\ ','jdrinke'),(14482,869695711012,220775189359,'New Plantronics Bluetooth USB Adapter BUA-100',1,'REPL001',10.95,'eastar4','josesoft66','joselato35@hotmail.com','Jose Latorre','La Almendra 21','Estadilla(Huesca)','Aragón','SPAIN','22423','974305241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 14:59:40',0,NULL,3,1,2,1,'\\ ','josesoft66'),(14483,784340312011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',10.99,'eastar4','jomw1961','momanyi.omwega@rabera.net','Jonathan Omwega','1400 J R Lynch St<br>Box 18413','Jackson','MS','UNITED STATES','39217-0002','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 15:20:46',0,NULL,3,1,1,1,'\\ ','jomw1961'),(14484,742239158001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','kate-mikerogers','sluggo1964@gmail.com','Michael Rogers','132 Teal Park Ln','Madison','AL','UNITED STATES','35758-7215','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 15:24:02',0,NULL,3,1,1,1,'\\ ','kate-mikerogers'),(14485,784343542011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','posthalter_000','wayne_john43@yahoo.de','Torsten Riebschläger','Königsstrasse 106','Moormerland','','GERMANY','26802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 15:26:03',0,NULL,3,1,2,1,'\\ ','posthalter_000'),(14486,580405028003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','kirk8013','kirkwilfinger@yahoo.com','Kirk Wilfinger','2556 Oak St','franklin park','IL','UNITED STATES','60131-3423','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 15:44:19',0,NULL,3,1,1,1,'\\  ','kirk8013'),(14487,637478444013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',65.9,'eastar4','ix69','ix@netherworld.com','Eric Putz','303 W Hilda St','Tampa','FL','UNITED STATES','33603-3534','(303) 881-4527','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 16:02:51',0,NULL,3,0,18,0,NULL,'ix69\r由卢建刚代发发'),(14488,869730150012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',150.99,'eastar4uk','adamfaruk','farukdudhwala@yahoo.co.uk','faruk  dudhwala','108 grasmere street','bolton','Lancashire','UNITED KINGDOM','bl1 8lh','07790892794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 16:09:57',0,NULL,3,1,6,1,'EE617288738CN','adamfaruk\rEE491015913CN这单货给您换单为：EE617288738CN'),(14489,637493679013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','bmwmotorsportpwr','vt4four@gmail.com','Miles Ross','1409 Ashford Ct','Blacksburg','VA','UNITED STATES','24060','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 16:45:54',0,NULL,3,1,1,1,'\\ ','bmwmotorsportpwr'),(14490,784383980011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','moonstone_beach','money.itsacrime@gmail.com','Marc-A. Baertsch','Dossenheimerweg 14','Schriesheim','','GERMANY','69198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 16:57:18',0,NULL,3,1,2,1,'\\ ','moonstone_beach'),(14491,784395204011,320730086052,'New brand Logitech Digital IO Writing Pen',1,'NTLO002',18.99,'eastar4uk','barneypcm','barneypcm@tiscali.co.uk','trevor burnett','the flat, 19 high street,<br>Tean','stoke-on-trent','Staffordshire','UNITED KINGDOM','st10 4dy','07974062373','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 17:18:32',0,NULL,3,1,3,1,'RA117778070CN\r ','barneypcm\rNTLO002'),(14492,868600269012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','honestbrianl','brianlovatt@tiscali.co.uk','Brian Lovatt','Woodlands<br>Old Chester Road','Helsby','Cheshire','UNITED KINGDOM','WA6 9PN','01928724020','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 17:36:41',0,NULL,3,1,3,1,'RA117779441CN\r ','honestbrianl\rWLAP002'),(14493,869798124012,220864660795,'New News Paper 3-Section Rain Sun Umbrella',2,'UM00038',39.98,'eastar4','2004walterr','walter@lambertsouvenirs.com','Jeanne Rawlings','9 Albion Villas Road','Upper Sydenham','London','UNITED KINGDOM','SE26 4DB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 18:07:09',0,NULL,3,1,2,1,'\\ ','2004walterr\r韩版加粗报纸三折伞'),(14494,784426649011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','loulou0421','marylou0421@mac.com','Marylou Goodman','1322 San Mateo Dr','punta gorda','FL','UNITED STATES','33950-6311','(941) 639-1229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 18:11:15',0,NULL,3,1,1,1,'\\ ','loulou0421'),(14495,869814557012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','andalthebest','abrennernet@gmail.com','Andreas Brenner','Hauptstr. 46','Bad Feilnbach/Au','','GERMANY','83075','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 18:33:43',0,NULL,3,1,3,1,'RA117779455CN\r ','andalthebest\rGLOT005'),(14496,637555751013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',2,'HSNO028',36.9,'eastar4','victorpimchenko','victornavolsky@yandex.ru','Victor Pimchenko','Traktorostroiteley ave.<br>h.152 f.54','Kharkiv','','UKRAINE','61121','(067)701-6613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 19:09:35',0,NULL,3,1,2,1,'\\  ','victorpimchenko\r欧标'),(14497,869864539012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',2,'OTCN005*10',28.4,'eastar4','calechote','calecho@hotmail.com','Christian Mauricio Caso Leguízamo','Atenas #38 Col. Jardines de Bellavista','Tlalnepantla de Baz','Estado de México','MEXICO','54054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 19:44:02',0,NULL,3,1,2,1,'\\ ','calechote'),(14498,784487707011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','klingor.cisco','klingor@btinternet.com','Colin Gorrie','18 The Paddock<br>Balcarres Road','Musselburgh','East Lothian','UNITED KINGDOM','EH21 7SP','01316655669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 19:47:32',0,NULL,3,1,3,1,'RA117779509CN\r ','klingor.cisco\rCASS002\r一共买了六条'),(14499,784492935011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','klingor.cisco','klingor@btinternet.com','Colin Gorrie','18 The Paddock<br>Balcarres Road','Musselburgh','East Lothian','UNITED KINGDOM','EH21 7SP','01316655669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 19:53:18',0,NULL,3,1,17,0,NULL,'klingor.cisco'),(14500,869878958012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',10,'OTCN003',49.8,'eastar4','ardaelektronik','ardaelektronik@ttnet.net.tr','Hüseyin Arda','100.san.sit.16/b blok no:10 Tekirdag','default','Türkei','TURKEY','59100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 20:09:03',0,NULL,3,1,3,1,'RA117779438CN\r ','ardaelektronik\rOTCN003'),(14501,784507104011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',4,'CASS002',33.16,'eastar4','klingor.cisco','klingor@btinternet.com','Colin Gorrie','18 The Paddock<br>Balcarres Road','Musselburgh','East Lothian','UNITED KINGDOM','EH21 7SP','01316655669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 20:18:17',0,NULL,3,1,17,0,'RA117779509CN\r ','klingor.cisco'),(14502,784507053011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','thibault45','moimaime@lavache.com','Thibault SUSINI/St Worthington DSS Ltd','Flat 1/B, 37 Lansdowne Road','Worthing','West Sussex','UNITED KINGDOM','BN11 4NF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 20:23:54',0,NULL,3,1,2,1,'\\ ','thibault45'),(14503,580519841003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','luke241275','l.campana@tecnicpanama.com','Tecnic Panama SA','Torre BBVA, Piso 12, Oficina 1<br>Avenida Balboa','Panama','','PANAMA','0000','(507) 393-9301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 20:40:58',0,NULL,3,1,3,1,'RA117779424CN\r ','luke241275\rWLAT003'),(14504,784518178011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','3129273986','chunyangwang_3986@yahoo.com','chunyangwang','291 s bolingbrook dr','bolingbrook','IL','UNITED STATES','60440-2931','(312) 927-3986','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 20:41:04',0,NULL,3,1,1,1,'\\ ','3129273986'),(14505,784521525011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','zzooiimm','zzoimm@gmail.com','Dmitry Ivanchenko','Dmitriya Ulyanova 303 - 100','Moscow','Moscow','RUSSIAN FEDERATION','117036','+79167580271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 20:50:06',0,NULL,3,1,2,1,'\\ ','zzooiimm\r欧标'),(14506,869912907012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','s_sanich','san-sanich@inbox.ru','Alexander Zhuravlev','Rublevskoe shosse 14-3-280','Moscow','','RUSSIAN FEDERATION','121615','7-916-157-22-90','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 21:08:45',0,NULL,3,1,2,1,'\\ ','s_sanich'),(14507,637616803013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',65.9,'eastar4','fendi04','christopher@munichllc.com','Christopher Picardi','8306 Wilshire Blvd<br># 1','Beverly Hills','CA','UNITED STATES','90211-2382','(310) 432-3000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 21:48:33',0,NULL,3,1,1,1,'\\','fendi04'),(14508,586076679004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','nightalon','nightalon@gmail.com','Barrett Williams','570 Park Ave','New York','NY','UNITED STATES','10065-7370','(917) 846-8761','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 22:47:05',0,NULL,3,1,1,1,'\\ ','nightalon'),(14509,784569072011,320395390620,'Samsung Q1 Q1U Bluetooth Module 2.0 EDR+cable',1,'BTSA2005',9.88,'eastar4','amstrum','darren.lee1982@googlemail.com','Darren Amstrum Lee','13 Healey Close<br>The Meadows','Nottingham','Nottinghamshire','UNITED KINGDOM','NG2 2HL','01159869746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 22:49:19',0,NULL,3,1,2,1,'\\ ','amstrum'),(14510,724981022008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',65.98,'au-buy','cheenuarora','rajivkwatra@hotmail.com','rajiv kwatra m.d.','1331 N 7th St<br>Ste 290','phoenix','AZ','UNITED STATES','85006-2769','(602) 230-6744','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 22:52:06',0,NULL,3,1,1,1,'\\ ','cheenuarora\r黑色的'),(14511,784575903011,320395390620,'Samsung Q1 Q1U Bluetooth Module 2.0 EDR+cable',1,'BTSA2005',9.88,'eastar4','brasco92400','brahim.elgamani@free.fr','Brahim El Gamani','2/4 rue donatello','Courbevoie','Île-de-France','FRANCE','92400','0147893715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 23:11:24',0,NULL,3,1,2,1,'\\  ','brasco92400'),(14512,784576904011,320762431430,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\" New version of WMN1000B',3,'MOSA005',197.7,'eastar4','wrightengineer','palmwrightnuclear@gmail.com','Anthony L. Wright','840 Meadow Ridge Ln','Birmingham','AL','UNITED STATES','35242-5410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 23:15:15',0,NULL,3,0,18,0,NULL,'wrightengineer\r由卢建刚代发'),(14513,580563944003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',1,'HSMO016',22.69,'cnfaner','jjndi','jjndishire@gmail.com','JOHN SHIRE','501 Porpoise Cv','Patrick AFB','FL','UNITED STATES','32925-3149','(662) 352-6953','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 23:32:53',0,NULL,3,1,1,1,'\\ ','jjndi'),(14514,580567462003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','10467el','eskinner2@cox.net','Ella Epps','1030 Avenue F','Norfolk','VA','UNITED STATES','23513-1708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 23:54:40',0,NULL,3,1,1,1,'\\ ','10467el'),(14515,580568106003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','honeydo278','mrhoneydo@hotmail.com','Carter DeMarco','2 Bald Hill Pl','Wilton','CT','UNITED STATES','06897','(203) 761-7928','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 23:56:11',0,NULL,3,1,1,1,'\\ ','honeydo278'),(14516,784593365011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',5,'HSJA002',99.95,'eastar4','sexyeb85','ebonie_inwood85@msn.com','Ebonie Inwood','7 Oregano Close','Griffin','Queensland','AUSTRALIA','4503','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 00:13:34',0,NULL,3,1,3,1,'RA117779490CN\r ','sexyeb85\r澳标\rHSJA002'),(14517,784595442011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','peillis','pbcars@yahoo.com','Paulius Obeliunas','6321 Harwich Center Rd','West Palm Beach','FL','UNITED STATES','33417-5458','(561) 309-6554','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 00:22:36',0,NULL,3,1,1,1,'\\','peillis'),(14518,866964512012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','mindyloubob','thestuartfamily@aol.com','Robert Stuart','22828 Riverside Dr','Mendon','MI','UNITED STATES','49072-9516','(269) 506-6300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 00:52:07',0,NULL,3,1,1,1,'\\ ','mindyloubob'),(14519,867144740012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','mahoodlum','smahoodlum@yahoo.com','Stephen Mahood','169 Endicott St<br>Apt 5','Boston','MA','UNITED STATES','02113-1500','(617) 417-1188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 01:07:04',0,NULL,3,1,1,1,'\\ ','mahoodlum\r新地址\r494 Sumner St. Apt 3\rEast Boston, MA 02128\r'),(14520,637669333013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','togrix','jburks@gmail.com','John Burks','214 Gawin Dr','Warner Robins','GA','UNITED STATES','31093-1118','(478) 334-4988','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 01:28:31',0,NULL,3,1,1,1,'\\ ','togrix'),(14521,742499459001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',30.89,'buysia','euminaka','eunaka@uol.com.br','Eurico Nakayama','Rua das Laranjeiras, 55 / 1301<br>bairro: Laranjeiras','Rio de Janeiro','Rio de Janeiro','BRAZIL','22240000','55-21-96076420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 01:47:44',0,NULL,3,1,3,1,'RA117778035CN\r ','euminaka\rBR3D005+BR3D004\rMonster House New sealed 3D Blu-ray ship tracking# \r'),(14522,784624113011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','whitesticks','david.hart@oracle.com','David Hart','4 Alperton Court','Kingsley','Western Australia','AUSTRALIA','6026','0862017684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 01:59:21',0,NULL,3,1,2,1,'\\ ','whitesticks'),(14523,784625753011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','theadrien','adrien_wolff@yahoo.fr','Adrien Wolff','La Bourdette - AGUTS','Cuq-Toulza','Midi-Pyrénées','FRANCE','81470','05.63.75.32.04','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 02:05:05',0,NULL,3,1,2,1,'\\ ','theadrien'),(14524,870016547012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','frugal_planter','ffenton@comcast.net','Frank Fenton','9455 108th Ave<br>Lot 64','Vero Beach','FL','UNITED STATES','32967-3190','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 02:10:27',0,NULL,3,1,1,1,'\\ ','frugal_planter'),(14525,0,320778641805,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',3.85,'eastar4','rei65','julashed@comcast.net','Julie Tadokoro','5776 Cherry Way','Livermore','CA','UNITED STATES','94551','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 02:11:26',0,NULL,3,1,1,1,'\\ ','rei65'),(14526,0,230689172688,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',9.5,'eastar4','mos_514','ha.bach@gmail.com','Bach Ha','2482A Notre-Dame Ouest','Montreal','QC','CANADA','H3J 1N5','(514) 377-8255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 02:11:39',0,NULL,3,1,2,1,'\\ ','mos_514'),(14527,0,220877808767,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',35.99,'eastar4','twitch126','scottw81@gmail.com','Scott Weisbaum','122 Old Forge Dr','Bath','PA','UNITED STATES','18014-1112','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 02:13:08',0,NULL,3,1,1,1,'\\ ','twitch126'),(14528,784630823011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','wobara','wobara@uol.com.br','Wilson Obara','Rua Piaui,n°1259, Apt 1001','Londrina','Paraná','BRAZIL','86020-390','43-91417151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 02:23:56',0,NULL,3,1,3,1,'RA117779415CN\r ','wobara\rBR3D001'),(14529,0,230689172646,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',10.49,'eastar4','ruchirahk','ruchiraa@gmail.com','Ruchira Ariyara','40/4 1/1, Colombo thantri Mw<br>Etul Kotte','Kotte','Western','SRI LANKA','0000','94714813351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 03:15:00',0,NULL,3,1,2,1,'\\  ','ruchirahk'),(14530,784645866011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',5,'OTCN002',19.9,'eastar4','dracicot','dracicot@sasktel.net','Devon Racicot','816 Columbia Way','Martensville','SK','CANADA','S0K0A2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 03:28:35',0,NULL,3,1,2,1,'\\  ','dracicot'),(14531,8881319518730188,111,'3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',0,'eastar4uk','heronribeiro','heronrib@yahoo.com.br','Heron Ribeiro','Rua Gilson da Costa Xavier, 542<br>Sambaqui','Florianopolis','SC','BRAZIL','88051000','+55 48-37225358',NULL,NULL,NULL,'2011-10-25 04:58:50',0,NULL,3,0,3,1,'RA117761255CN\r ',' GLOT005\r补发的 一副  投影仪兼容眼镜'),(14532,0,220877808718,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.06,'eastar4','bk7ycy','ebay@pisti.hu','C3 Alapitvany - Pecsenyanszky Istvan','Szpahi u. 20.','Budapest','','HUNGARY','1022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 07:14:09',0,NULL,3,1,2,1,'\\  ','bk7ycy'),(14533,8881319527117185,111,'2000A',1,'MOSA004',69,'eastar4',' di21777  ','dmit-kules@yandex.ru','Дмитрий Кулешов','северный бульвар дом 19 корпус б','москва ','','RUSSIA','127566','',NULL,NULL,NULL,'2011-10-25 07:18:37',0,NULL,3,1,3,1,'RA117761264CN\r ','MOSA004\r客户直接打款 '),(14534,0,220877808796,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',18.1,'eastar4','gliano','gliano@hotmail.com','G.F.C. Holman','Celebeslaan 49','Zwijndrecht','','NETHERLANDS','3333AE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 08:25:17',0,NULL,3,1,2,1,'\\  ','gliano\r欧标'),(14535,784714267011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','williamh120','williamh120@hotmail.com','William Henderson','Harters Hill House<br>Coxley','Wells','Somerset','UNITED KINGDOM','BA5 1RD','01749671006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 08:52:46',0,NULL,3,1,3,1,'RA117761278CN\r ','williamh120\rRELO003\r红边优联'),(14536,784716744011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','0035*cartalli','anastasiacartalli@hotmail.com','Anastasia Cartalli','Xerou 9 Geri','Nicosia','Cyprus','CYPRUS','2202','0035722488665','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 09:08:57',0,NULL,3,1,2,1,'\\  ','0035*cartalli\rMOAP001'),(14537,870115853012,220697786937,'New 3.0 Bluetooth BCM2070 Module+cable HP probook 4321S',1,'BTHP3002',19.98,'eastar4','algol_66','algol66@front.ru','Oleg Prokofiev','Primorsky pr. 145/2 74','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','197374','+7-911-914-07-84','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117778208CN','algol_66\rBTHP3002+WLIN014+WLIN012+ANTY002\rHP 6pin1.0 3cm \r再发一个\rNew Intel Centrino Advanced N WiMAX 6250 622ANXHMW \r一个New Intel 5350 WiMAX Wifi 802.11n PCI-E Card not IBM \r两条Triple Tyco Universal Wireless Laptop Antenna Mini PCI \r\r\r'),(14538,870121321012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','whitesxg','whitesxg2010@hotmail.com','George Healy','2, Ballincrikig,<br>Whitescross','Cork','Cork','IRELAND','default','0214676133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 09:30:47',0,NULL,3,1,3,1,'RA117778199CN\r','whitesxg\rGLSG001*2'),(14539,784725761011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','mcschulz00','dragon.00@live.com.au','mark schulz','2 roseberry st','north toowoomba','Queensland','AUSTRALIA','4350','0429539207','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 09:34:38',0,NULL,3,1,2,1,'\\  ','mcschulz00\r澳标'),(14540,784730076011,320441575818,'2.1 Acer Travelmate 5520 5530 Bluetooth Module+cable',1,'BTAC2109',12.39,'eastar4','gabu710','archgiel@gmail.com','Gabor Erdi','Nagy Lajos Kiraly ut 126 fsz 7','Budapest','Budapest','HUNGARY','1149','00362779001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 09:48:45',0,NULL,3,1,2,1,'\\  ','gabu710\racer 4pin1.25 20cm'),(14541,637763432013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','alexander_sydorenko','shurik303@gmail.com','Alexander Sydorenko','Zaliznychna st. 15 app.20','Kherson','Kherson','UKRAINE','73026','00380636888989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 10:22:36',0,NULL,3,1,2,1,'\\  ','alexander_sydorenko'),(14542,870135880012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',19.99,'eastar4','liveim','viruz33@gmail.com','Vladimir Goncharov','61b Karla Marksa st. (RFEI)','Kursk','Kurskaya obl','RUSSIAN FEDERATION','305029','471 236-0933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 10:17:45',0,NULL,3,0,2,1,'\\ ','liveim\r已入库'),(14543,637766799013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','buzzattack83','aaron@calibrebuilding.com.au','aaron murray','10 wall ave','panania','New South Wales','AUSTRALIA','2213','0451515336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 10:40:07',0,NULL,3,1,3,1,'RA117761281CN\r ','buzzattack83\rMOSA006'),(14544,784753388011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',13.97,'eastar4','togitoryo74','togitoryo@hotmail.com','Tolga okay','T. Is Bankasi a.s. Yesilyurt subesi','izmir','karabaglar','TURKEY','35160','5053173813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 11:10:44',0,NULL,5,1,18,0,NULL,'togitoryo74\r已经退款'),(14545,637777006013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','athlon70fx','althon64fx@gmail.com','Benjamin Kwok','Unit 19<br>235 Anzac Parade','Kensington','New South Wales','AUSTRALIA','2033','0421100644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 11:25:38',0,NULL,3,1,2,1,'\\  ','athlon70fx'),(14546,784756351011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','czitzmann','cgmedia@mac.com','Christopher Zitzmann','12877 Bristow Rd','Nokesville','VA','UNITED STATES','20181-3352','(937) 768-2458','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 11:22:24',0,NULL,3,1,1,1,'\\  ','czitzmann'),(14547,784766419011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','norbisipos','siposnorbi@gmail.com','Norbert Sipos','25 St. Margarets Avenue<br>Tottenham','London','London','UNITED KINGDOM','N153DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 11:53:03',0,NULL,3,1,3,1,'RA117761321CN\r ','norbisipos\rMOAP001'),(14548,870171167012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',2,'HSJA010',32.28,'eastar4uk','djbatima','djbatima@o2.pl','MONIKA KRZYZAK','2 ANEXE<br>WHEATLANDS','HOUNSLOW','London','UNITED KINGDOM','TW5 0SA','07886607795','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 12:05:07',0,NULL,3,1,3,1,'RA117761220CN\r ','djbatima\rHSJA010\r英标'),(14549,742642121001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','theturkey','perino03@yahoo.com','max perino','4241 State Park Dr','akron','OH','UNITED STATES','44319-3444','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 12:17:24',0,NULL,3,1,1,1,'\\  ','theturkey'),(14550,784781482011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','m!dnitefox','midnitefox@yahoo.com','Tony Powell','12 Burns Crescent','Sleaford','Lincolnshire','UNITED KINGDOM','NG347GD','01529410526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 12:36:53',0,NULL,3,1,2,1,'\\  ','m!dnitefox'),(14551,580703573003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','shelbyh1979','quack_61@yahoo.com','Shelby Hagood','PO Box 471','gorman','TX','UNITED STATES','76454','(254) 734-5415','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 12:55:31',0,NULL,3,1,1,1,'\\ ','shelbyh1979'),(14552,784789416011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','francisscifo','scifra1@onvol.net','Francis Scifo','Fuchsia 12,Marg street,','Attard','','MALTA','BZN13','0035679537927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:01:46',0,NULL,3,1,2,1,'\\  ','francisscifo\r欧标'),(14553,0,220875994426,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',7.99,'eastar4','firdinmirdin','giasena@hotmail.com','thomas dovras','leoforos irakleiou 500','athens','irakleio attikis','GREECE','14122','00306978036806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:15:19',0,NULL,3,1,2,1,'\\  ','firdinmirdin'),(14554,580705374003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','shadowdancerred','shadow_dancer_red@hotmail.com','Miriam Patrick','414 N Main St<br>C/O Litwiller-Craps Ins. Agency','Roanoke','IL','UNITED STATES','61561-7574','(309) 923-2861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 13:18:03',0,NULL,3,1,1,1,'\\ ','shadowdancerred'),(14555,637787518013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mannfalk','jacob@mannfalk.se','jacob Mannfalk','Corfitz Beck Friis väg 32','Höllviken','Skåne','SWEDEN','23642','0768568901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:25:27',0,NULL,3,1,2,1,'\\  ','mannfalk'),(14556,784801736011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',48.42,'eastar4uk','kagee2005','kagee2005@yahoo.co.uk','Kristen Gibson','Galleon Studios, Unit 26 Phoenix Park<br>Phoenix Close','Heywood','Lancs','UNITED KINGDOM','OL10 2JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 13:36:31',0,NULL,3,1,3,1,'RA117761349CN\r ','kagee2005\rMOAP001'),(14557,580727220003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',5,'HSPL009',299.5,'cnfaner','kendallwatches','elkotur325@gmail.com','ALFREDO DUENAS','14849 SW 42nd Ln','MIAMI','FL','UNITED STATES','33185-4313','(305) 229-8218','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 14:27:24',0,NULL,3,1,1,1,'\\ ','kendallwatches'),(14558,586253084004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','rvrbnk','jimh@jriver.com','Jim Hillegass','125 N 1st St','Minneapolis','MN','UNITED STATES','55401','(612) 677-8200 ext.: 203','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 14:48:00',0,NULL,3,1,1,1,'\\  ','rvrbnk'),(14559,635853310013,230633616001,'Griffin Dual USB Car Charger for iPhone ipad iPad2',1,'CCGR001',4.99,'eastar4','dspud2006','dspud2010@gmail.com','Derek Spudich','111 Starling Creek Loop','Laredo','TX','UNITED STATES','78045-8115','(956) 508-3490','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 15:02:36',0,NULL,5,1,18,0,' ','dspud2006\r需要退款'),(14560,870236551012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','pinkpluque','c3p0pl@gmail.com','Pedro Luque Laguna','Avenida de America 3<br>1-3','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14008','674768860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:02:58',0,NULL,3,1,2,1,'\\  ','pinkpluque'),(14561,635763411013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','eddysif','torrento_123@hotmail.com','Eddy torres guzman','1305 tyson ave','philadelphia','PA','UNITED STATES','19111-4516','(215) 268-2946','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 15:04:55',0,NULL,3,1,6,1,'EE491015683CN ','eddysif\r兼容型3D眼镜 通用型'),(14562,637835101013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','tomaigner','tomaigner@verizon.net','Thomas M Aigner','5033 Comstock Cir','Keller','TX','UNITED STATES','76244','(817) 741-0534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 15:09:24',0,NULL,3,1,1,1,'\\  ','tomaigner'),(14563,784845946011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','tangotr','rtrunov@mail.ru','Roman Trunov','Teplichnaya st. 10 apartment 304','Podolsk','','RUSSIAN FEDERATION','142134','(903)213-1208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:30:00',0,NULL,3,1,2,1,'\\  ','tangotr'),(14564,742711140001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','djmotivation','integrityvibez@gmail.com','Mark Lopez','4777 Walden Cir<br>Apt J','Orlando','FL','UNITED STATES','32811-7259','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 15:39:36',0,NULL,3,1,1,1,'\\ ','djmotivation'),(14565,586271889004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','fernvernon','fern@brooklynphono.com','Fern Vernon','270 42nd St<br>Brooklynphono','Brooklyn','NY','UNITED STATES','11232','(718) 788-5777','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 15:53:46',0,NULL,3,1,1,1,'\\  ','fernvernon'),(14566,784858272011,320465511597,'Logitech Harmony Remote USB Cable 510 520 550 628 659',1,'CALO001',3.87,'eastar4','0adrienne2006','adrienne.forest@hotmail.com','Adrienne Forest','251 Glenairlie Drive','Victoria','BC','CANADA','v9b1k4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 16:00:07',0,NULL,3,1,2,1,'\\ ','0adrienne2006'),(14567,742729829001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',2,'HSJB001',23.98,'buysia','mrbet1','betodd1@bellsouth.net','Brian Todd','1041 Emory Parc Pl','Decatur','GA','UNITED STATES','30033-4060','(404) 486-8931','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 16:21:35',0,NULL,3,1,1,1,'\\  ','mrbet1'),(14568,870278639012,220807319874,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',17.95,'eastar4','redfunkylizard','redredjen@yahoo.co.uk','Jennifer Clark','53 Clarendon Road<br>Flat 1','Redland','Bristol','UNITED KINGDOM','BS6 7EY','07772024582','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-25 16:23:30',0,NULL,3,1,2,1,'\\ ','redfunkylizard'),(14569,637861404013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','maimainana','cuidanke0602@yahoo.cn','Danke Cui','105 cowper st','Glebe','New South Wales','AUSTRALIA','2037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 16:32:01',0,NULL,3,1,2,1,'\\  ','maimainana'),(14570,870305887012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','atho5663','allythomson1@hotmail.co.uk','alasdair thomson','27 unitas crescent<br>carluke','carluke','South Lanarkshire','UNITED KINGDOM','ml8 5aw','07738266155','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 17:15:00',0,NULL,3,1,3,1,'RA117761304CN\r ','atho5663\rHSJA010\r英标'),(14571,784901244011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.88,'eastar4','gaber837','rbaidwan@hotmail.com','Randy Baidwan','7010 Island View Place','Saanichton','BC','CANADA','V9B5C7','(250) 642-7694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 17:29:19',0,NULL,3,1,2,1,'\\  ','gaber837\rHP 8pin 1.25 25cm '),(14572,870318985012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',73.14,'eastar4uk','krolowa2000','krol.ilona@yahoo.co.uk','Robert Gorski','54 Greenway','Dagenham','Essex','UNITED KINGDOM','RM8 1UL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 17:38:12',0,NULL,3,1,3,1,'RA117761352CN\r ','krolowa2000\rOTSO004*2'),(14573,784913370011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','aikica','aikica1@hotmail.com','Daniel Lazaro Bailo','Paseo Donantes Sangre 1- 2ºC','Pamplona','Navarra','SPAIN','31015','615507817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 17:53:56',0,NULL,3,1,3,1,'RA117761233CN\r ','aikica\rHBPH002'),(14574,870336594012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','stogmike111','mhstogdill@msn.com','Michael Stogdill','556 Frank St','Council Bluffs','IA','UNITED STATES','51503','(712) 322-7444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 18:08:55',0,NULL,3,1,1,1,'\\  ','stogmike111'),(14575,784931156011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',20.9,'eastar4uk','emperorconstantine','texasranger1@sky.com','jay willis','25 priors road<br>tadley','basingstoke','Hampshire','UNITED KINGDOM','rg264ql','07909580898','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 18:20:03',0,NULL,3,1,3,1,'RA117778123CN','emperorconstantine\rRCLO008\r'),(14576,586324938004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','airshow2','ebay@bako.us','Jean Street','6332 Wakefalls Dr','Wake Forest','NC','UNITED STATES','27587-6264','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 18:28:04',0,NULL,3,1,1,1,'\\  ','airshow2'),(14577,782556266011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',68.98,'eastar4','gtzled','ledgtz@gmail.com','gtz design','9 place de la petite rigaudie','sarlat la caneda','Aquitaine','FRANCE','24200','0680474372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 18:28:38',0,NULL,3,1,3,1,'RA117778110CN\r','gtzled\rUDAP001'),(14578,637913542013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','strelk','strelk88@gmail.com','Aleksey Vasilyev','Druzhby st., 1A, 184','Chehov','Moskovskaya oblast\'','RUSSIAN FEDERATION','142306','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 18:43:29',0,NULL,3,1,2,1,'\\  ','strelk'),(14579,637919772013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','peeweetradingco','schwegmann@bellsouth.net','Martin Schwegmann','2513 Fawnwood Rd','Marrero','LA','UNITED STATES','70072-5708','(504) 339-2050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 19:09:03',0,NULL,3,1,1,1,'\\ ','peeweetradingco'),(14580,870383417012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','opalmeta','arlindo.bento@gmail.com','Arlindo Bento','Rua Goncalo Velho 2, 7º F','Rio de Mouro','','PORTUGAL','2635-364','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 19:18:42',0,NULL,3,1,2,1,'\\  ','opalmeta'),(14581,784985532011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','maggi1970','magnus@amphilion.com','Magnus Palmarsson','Glosolum 5','Kopavogur','IS','ICELAND','201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 19:52:06',0,NULL,3,1,3,1,'RA117761162CN\r ','maggi1970\rHBPH002'),(14582,870411810012,220705174904,'New Genuine Motorola H555 Bluetooth Wireless Headset',2,'HSMO008',15.98,'eastar4uk','meraklas','rockass@insanity.net','Christos Meraklis','Menelaou 3 Ayios Nikolaos','Limassol','Cyprus','CYPRUS','3100','0035799781472','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 20:02:55',0,NULL,3,1,2,1,'\\ ','meraklas'),(14583,742847481001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','cnunez95','nunezrealtor@yahoo.com','Carlos Nunez','1706 W Cedar St','Allentown','PA','UNITED STATES','18104-4126','(484) 505-9222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 20:09:50',0,NULL,3,1,1,1,'\\  ','cnunez95'),(14584,637970114013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','jgon3994','jorgespyro@gmail.com','Jorge Gonzalez Arcos','casa del medico s/n','Lucar (almeria)','Andalucía Ceuta y Melilla','SPAIN','04887','950424505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 20:58:51',0,NULL,3,1,2,1,'\\  ','jgon3994'),(14585,870449493012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','flash20matthew','flash.woods@gmail.com','matthew woods','Polnoon Farm<br>Eaglesham','Glasgow','Glasgow (City of)','UNITED KINGDOM','G76 0PE','07704750900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 21:09:20',0,NULL,3,1,3,1,'RA117761335CN\r ','flash20matthew\r英标\rHSJA010'),(14586,870457285012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','n5966v','only_quality@hotmail.com','Maxie Saffel','528 Breezewood Ct','Brea','CA','UNITED STATES','92821-2719','(562) 690-0522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 21:25:46',0,NULL,3,1,1,1,'\\  ','n5966v'),(14587,870458580012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','nini70360','arthurleo@orange.fr','Valéry JOFFRIN','21 bis rue du PLançon','SCEY SUR SAONE','Franche-Comté','FRANCE','70360','03.84.68.89.08','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 21:27:16',0,NULL,3,1,2,1,'\\ ','nini70360'),(14588,0,230689172609,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.25,'eastar4','radbmd','rdrake40@windstream.net','Randy Drake','14973 Tomer Rd','Guys Mills','PA','UNITED STATES','16327-1725','(814) 789-4593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 22:01:31',0,NULL,3,1,1,1,'\\  ','radbmd'),(14589,638016184013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','3863guillaume','guillaume.finn@club-internet.fr','guillaume finn','quartier de l\'eglise','chateauroux les alpes','Provence-Alpes-Côte d\'Azur','FRANCE','05380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 23:44:22',0,NULL,3,1,3,1,'RA117761247CN\r ','3863guillaume\rMOSA004'),(14590,785082685011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','2011.mark1970','mark.white@nl.rogers.com','Mark White','126 Brookfield Ave','Corner Brook','NL','CANADA','A2H 2r9','(709) 634-9112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 23:49:29',0,NULL,3,1,2,1,'\\  ','2011.mark1970'),(14591,783216677011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','internet.dummy','internet.dummy@gmail.com','Simar Singh','6e, wendy apartments,<br>19 green lane, happy valley, hk','default','','HONG KONG','default','(613) 221-51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 23:59:57',0,NULL,3,1,2,1,'\\','internet.dummy\rProLee24K超轻碳纤骨长柄伞  '),(14592,785093976011,320394892496,'Acer Aspire 5735 5735Z Bluetooth Module 2.0 EDR +cable',1,'BTAC2005',9.88,'eastar4','rewindscafe','rewindman@msn.com','ALAN NEWMAN','REWINDS STUDIO\'S (UK)<br>10 CROHAM VALLEY RD','SOUTH CROYDON','Surrey','UNITED KINGDOM','CR2  7NA','07902986555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 00:24:04',0,NULL,3,1,2,1,'\\ ','rewindscafe\racer 4pin1.25 8cm '),(14593,638026361013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'eastar4','top1080','ztobdzic@nyc.rr.com','Zoran Tobdzic','8943 96th St<br>Apt 3J','Woodhaven','NY','UNITED STATES','11421-2738','(347) 561-9530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 00:25:08',0,NULL,3,1,1,1,'\\  ','top1080'),(14594,870532183012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','robertomorati87','robertomorati@gmail.com','Roberto Guimaraes Morati Junior','Rua Domingo de Povoa Lemos, Ed.: Rio de Contas 60, Jardim Camburi<br>Apartamento 101','Vitória','Espírito Santo','BRAZIL','29090-080','(27)-99493433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 00:53:19',0,NULL,3,1,2,1,'\\ ','robertomorati87'),(14595,785113991011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','andta','atannert@t-online.de','Andreas Tannert','Seeburgstr. 26','Leipzig','','GERMANY','04103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 01:29:58',0,NULL,3,1,2,1,'\\  ','andta'),(14596,785114315011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT004*2',88.99,'eastar4','ew3301','coolhandluke301@aol.com','EDWARD WEBB III','308 HUNTINGTON ST','NEW HAVEN','CT','UNITED STATES','06511','(203) 668-8765','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 01:35:35',0,NULL,3,1,1,1,'\\  ','ew3301\r兼容型3D眼镜  samsung 专用'),(14597,870536402012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.9,'eastar4','fortitude411','atsig411@yahoo.com','Aaron Leon','1804 lemon springs court','raleigh','NC','UNITED STATES','27612','(919) 423-7060','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 01:55:18',0,NULL,3,1,1,1,'\\','fortitude411'),(14598,870554639012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','wildbluecamel','jwilde34@optusnet.com.au','Ms Jennifer Wilde','15 Cassinia Avenue<br>Ashwood','Melbourne','Victoria','AUSTRALIA','3147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 01:58:37',0,NULL,3,1,3,1,'RA117761216CN\r ','wildbluecamel\rOTSO004*2'),(14599,638056612013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','orlin.r','orlin.roussev@gmail.com','Orlin Roussev','19 Torrington place','London city','London','UNITED KINGDOM','E1W 2UY','02031942513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 02:27:28',0,NULL,3,1,3,1,'RA117778242CN\r ','orlin.r\rWWOT001+ANCN001'),(14600,785130876011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',5,'TRMX002',37.85,'eastar4','tull_brandon914','btull914@comcast.net','brandon tull','2039 bangor ave','lindenwold','NJ','UNITED STATES','08021-1445','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 02:28:16',0,NULL,3,0,1,1,'\\  ','tull_brandon914'),(14601,638058410013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2',109.99,'eastar4','aaltjefish','seinen@planet.eon.net','W.L. (Bert) Seinen','10912 148 Street','Edmonton','AB','CANADA','T5N 3H7','(780) 451-2217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 02:32:34',0,NULL,3,1,3,1,'RA117761658CN\r ','aaltjefish\rGLSG001*2'),(14602,870567375012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','plinio2012','orla-1@ig.com.br','Plinio Tadeu da Silveira','Rua Janilton de Araujo Gomes, 19 apt. 21','Campos Dos Goytacazes','Rio de Janeiro/Campos dos Goytacazes','BRAZIL','28026-790','55-22-27395243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 02:36:19',0,NULL,5,0,18,0,NULL,'plinio2012\r退款了'),(14603,586370326004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',2,'HSPL001',25.9,'cnfaner','dimitris3615','mitritsakisd@gmail.com','Dimitris Mitritsakis','Sof. Venizelou 4','Hania-Souda','Crete','GREECE','73200','00302821076278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 04:24:51',0,NULL,3,1,3,1,'RA117778211CN\r ','dimitris3615\rHSPL001'),(14604,785177216011,320628756088,'New HP Atheros AR5BXB72 AR5008 MINI PCI-E card',1,'WLAT004',24.99,'eastar4','accjim','getmail520@yahoo.com','Hank Chang (Financial Service)','60 Yi-Min Liao<br>Shanhua Dist.','Tainan City','Taiwan','TAIWAN','74151','(886) 919-5757 ext.: 57','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 06:06:15',0,NULL,3,1,2,1,'\\  ','accjim'),(14605,8881319612250570,111,'雷管',1,'',0,'eastar4','mega-lo-maniack','motormaster@rambler.ru','Illya Kuzmuk','35a Vidinskaya St.,Apt. 32','Rivne','Rivnenska','UKRAINE','33018','',NULL,NULL,NULL,'2011-10-26 06:57:30',0,NULL,3,0,2,1,'\\  ','补发一个Brand new HP MCE Media Center Remote Control+ IR RECEVE 的雷管'),(14606,638100910013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','conmeno123','conmeno75@hotmail.com','minh nguyen','166 cowper st','warrawong','New South Wales','AUSTRALIA','2502','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 07:00:19',0,NULL,3,1,6,1,'EE491015697CN ','conmeno123\r兼容型3D眼镜 通用型'),(14607,870631367012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Jason Broadhead','8935 N POINTE EXECUTIVE PARK DR','HUNTERSVILLE','NC','UNITED STATES','28078-4857','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 07:24:44',0,NULL,3,1,1,1,'\\  ','321expressllc'),(14608,8881319615751044,111,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',0,'eastar4','jdseara','jdseara@gmail.com','Javier Diaz Seara','C/Monjas, Nº 5','Hinojosa del Duque  (Córdoba)','Andalucía Ceuta y Melilla','SPAIN','14270','655776410',NULL,NULL,NULL,'2011-10-26 07:55:51',0,NULL,3,1,3,1,'RA117778185CN\r ','补发的\rBTHP3000 '),(14609,785204045011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','daventu','info@bathmarine.com','BATHMARINE -Att: David Ventura','Ctra. de Nules, Km. 1  (al lado Renault)','Burriana','Comunidad Valenciana','SPAIN','12530','622161476','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 08:10:18',0,NULL,5,1,18,1,NULL,'daventu\rGLOT001\r兼容型3D眼镜 通用型\r不兼容需要退款'),(14610,638115157013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','jndgpt','jndgpt@hotmail.com','DA MA','SHOP T208, CENTRO BANKSTOWN SHOPPING CENTRE<br>STACEY STREET','BANKSTOWN','New South Wales','AUSTRALIA','2200','0415616280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 08:27:02',0,NULL,3,1,3,1,'RA117778168CN\r ','jndgpt\rOTES001'),(14611,8881319618200804,111,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'',61.99,'eastar4','opkoper10','kris.lecluyse1@telenet.be','K. Lecluyse','Tempelhof 9','brugge','','BELGIUM','8000','',NULL,NULL,NULL,'2011-10-26 08:36:40',0,NULL,3,0,3,1,'RA117778392CN\r ','HBPH002 '),(14612,870657491012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',73.14,'eastar4uk','krisbi28','ccbezzina@gmail.com','Christopher Bezzina','Oliveto/1<br>Triq Dun Gorg Fiteni','Naxxar','','MALTA','NXR 1110','+35679097909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 09:03:29',0,NULL,3,1,3,1,'RA117778273CN\r ','krisbi28\rOTSO004*2'),(14613,785215363011,320679575680,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',21.76,'eastar4uk','alexfilatov','angorod@ukr.net','Alexandr Filatov','Hrustalyov str. 43-68','Sevastopol','Crimea','UKRAINE','99029','+380509458554','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 09:04:01',0,NULL,3,1,2,1,'\\  ','alexfilatov\r'),(14614,784726717011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','piter_ek','pgrzedzinski@op.pl','Piotr Grzędziński','Aleksandra Janowskiego<br>13/3','Sosnowiec','śląskie','POLAND','41200','501 300950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 09:48:11',0,NULL,3,1,3,1,'RA117761635CN\r ','piter_ek\rGLSG001'),(14615,785240479011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','hellanora','pg007e5687@blueyonder.co.uk','Peter Gillam','109 warminster rd','Westbury','Wiltshire','UNITED KINGDOM','BA133PP','01373826657','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 10:28:01',0,NULL,3,1,3,1,'RA117778335CN\r ','hellanora\rMOAP001'),(14616,870676242012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',3,'HSPL011',41.55,'eastar4uk','neil_golding','neil.golding@gmail.com','Laura Golding','18 Venice Court<br>Dianella','Perth','Western Australia','AUSTRALIA','6059','0424824904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 10:31:21',0,NULL,3,1,3,1,'RA117761644CN\r ','neil_golding\rHSPL011\r澳标'),(14617,785250262011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','ruhlaenders','ruhlands@arcor.de','Dirk Eberlein','Rosenstr.41','Denkendorf','','GERMANY','73770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 10:59:13',0,NULL,3,1,2,1,'\\  ','ruhlaenders'),(14618,785258005011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','morgan10*11','heytobymorgan@aol.com','Toby Morgan','28/3 Shore','Edinburgh','Midlothian','UNITED KINGDOM','EH6 6QN','01315554919','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 11:23:37',0,NULL,3,1,3,1,'RA117778225CN\r ','morgan10*11\rMOAP001'),(14619,870701261012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',19.38,'eastar4uk','umer01282','umerkhatab786@hotmail.com','umer khatab','26 belgravestreet','burnley','Lancashire','UNITED KINGDOM','bb120ap','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 11:27:00',0,NULL,3,1,3,1,'RA117778313CN\r ','umer01282\rHSNO022\r英标'),(14620,638156296013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','nicmroc','nic.mroc@me.com','Panagiotis Katritsis','Dodekanisou 13','Athens','Chaidari','GREECE','12461','+306958083377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 11:48:45',0,NULL,3,1,2,1,'\\  ','nicmroc'),(14621,870715633012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','anxo102','angelentenza@hotmail.com','angel entenza piñeiro','49 Boundary brook road','Oxford','Oxfordshire','UNITED KINGDOM','ox4 4al','03467438968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 12:07:45',0,NULL,3,1,2,1,'\\  ','anxo102\racer 6pin1.25 23cm'),(14622,638168106013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','vintall_express','yaya2000@comcast.net','Pavlo Naumenko','3 Popovicha street Apt. 7','Uzyn','Kiev','UKRAINE','09161','(067) 233-8685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 12:43:30',0,NULL,3,1,2,1,'\\  ','vintall_express'),(14623,785286268011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','adamcouper2011','adamcouper@btinternet.com','Adam Couper','8 Burnside Street<br>Rosyth','Dunfermline','Fife','UNITED KINGDOM','KY11 2NX','01383412420','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 12:51:43',0,NULL,3,1,3,1,'RA117761953CN\r ','adamcouper2011\rGLOT001*2\r兼容型3D眼镜 通用型'),(14624,586569579004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','johnq78krause','markus-krause78@unitybox.de','Krause Markus','Boystr. 10','Gladbeck','','GERMANY','45968','','PayPalPaymentInProcess','CheckoutComplete','NotSelected','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117760051CN\r ','johnq78krause\rWWOT003+ANCN001'),(14625,870535366012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','myclothes1','myclothes@mac.com','michael lowes','2450 Kingscross Dr','shelby township','MI','UNITED STATES','48316-1209','(248) 361-8150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 13:25:10',0,NULL,3,1,1,1,'\\  ','myclothes1'),(14626,785305927011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','qpawel','qpawel80@gmail.com','pawel sojkowski','Heather park drive<br>110','Wembley middlesex','London','UNITED KINGDOM','Ha0 1Sz','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'qpawel'),(14627,782791732011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','boszeadrian','boszeadrian@freemail.hu','Bosze Adrian','Papkoz u. 1/4','Sarvar','Vas','HUNGARY','9600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 13:56:53',0,NULL,3,1,3,1,'RA117761560CN\r ','boszeadrian\rGLSG001*2'),(14628,785317775011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','feelings11','ryan7657@gmail.com','Deber Tunney','165 Sycamore st','Somerville','MA','UNITED STATES','02145-2738','(781) 697-1455','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 14:41:00',0,NULL,3,1,1,1,'\\  ','feelings11'),(14629,785340747011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','nikilevy9881','nikilevy@zahav.net.il','nissim levy','shay agnon 54/7 bat-yam','BAT-YAM','israel','ISRAEL','59564','972578158458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 15:18:23',0,NULL,3,1,2,1,'\\  ','nikilevy9881'),(14630,635018057013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',24.99,'eastar4','bakakinchan','kinza.ahmed@hotmail.com','Kinza Ahmed','3743 Crabtree Cres','Mississauga','ON','CANADA','L4T1S7','(647) 988-1435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 15:32:56',0,NULL,3,1,2,1,'\\  ','bakakinchan\r钢琴美女伞 '),(14631,870804683012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','ms84109','ms84124@gmail.com','Mikhail Skliar','2278 Signal Point Cir','Salt Lake City','UT','UNITED STATES','84109-1472','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 15:48:25',0,NULL,3,1,1,1,'\\  ','ms84109'),(14632,636102373013,230676837725,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ljmooney','lmooney@winterparkresort.com','laurie mooney','po box 356','tabernash','CO','UNITED STATES','80478','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 15:54:26',0,NULL,3,1,1,1,'\\  ','ljmooney'),(14633,785374249011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',57,'eastar4','sabre_rider','sabre65rider@shaw.ca','Canute A. Cupid','4151 28 Ave','Edmonton','AB','CANADA','T6L 4H2','(780) 462-5133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 16:35:21',0,NULL,3,1,3,1,'RA117778260CN\r ','sabre_rider\rHSJA011'),(14634,870827718012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',73.14,'eastar4uk','gamecollectors','fannybigdaddy@wanadoo.fr','Giovannini Nicolas','4 rue leo lagrange','monchecourt','Nord-Pas-de-Calais','FRANCE','59234','0661919366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 16:35:29',0,NULL,3,1,3,1,'RA117760564CN\r ','gamecollectors\rOTSO004*2'),(14635,638252192013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','funky_mc_monkey','funky_mc_monkey@yahoo.com','anthony virgil','8118 N Maroa Ave<br>Apt 103','fresno','CA','UNITED STATES','93711-6110','(559) 760-6823','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 17:22:42',0,NULL,3,1,1,1,'\\  ','funky_mc_monkey'),(14636,743188407001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','bourbon_smith','jackcack77@gmail.com','John Smith','26 carluke crescent<br>apt:1402','toronto','ON','CANADA','m2l2j2','(416) 224-5353','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'bourbon_smith'),(14637,743239011001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','benimports','benebessa@yahoo.com.br','Elisabete Ferreira','sousa franco, 692 - apto - 503<br>bairro - Vila Isabel','rio de janeiro','rio de janeiro','BRAZIL','20551-120','5521 9148-2689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 17:45:15',0,NULL,3,1,3,1,'RA117778358CN\r ','benimports\rBR3D008'),(14638,638273002013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','gepetotei','gepetotei@hotmail.com','Carl  Lacroix','1360 Ave Dieppe','Alma','QC','CANADA','g8c1j3','(418) 669-8392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 18:12:56',0,NULL,3,1,3,1,'RA117778239CN\r ','gepetotei\rMOSA006'),(14639,785439875011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','southstreetboogy','david.hubbard@staples.com','David Hubbard','5 Breen Rd','Westborough','MA','UNITED STATES','01581-3515','(508) 253-7389','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 18:36:37',0,NULL,3,1,1,1,'\\  ','southstreetboogy'),(14640,785429766011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','mashtar','sniketz@hotmail.com','Erik Andersson','Ferievägen 10','Sävar','Norrland','SWEDEN','91832','0703464682','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 18:43:08',0,NULL,3,1,2,1,'\\  ','mashtar'),(14641,638287933013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','x_videoeditor','petermotion@gmail.com','Pedro Vicente','Calle Santa Engracia, 42 4º Exterior Dcha','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 18:48:24',0,NULL,3,1,2,1,'\\  ','x_videoeditor'),(14642,870908907012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','mjcollins16','mjcollins@sky.com','mike collins','16 guinevere avenue','stretton','Staffordshire','UNITED KINGDOM','DE130FZ','01283530817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 18:50:23',0,NULL,3,1,3,1,'RA117778300CN\r ','mjcollins16\rWLAP002'),(14643,870927678012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','jammaster20009','wesleynelson116@o2.co.uk','W Nelson','21<br>Kirkhill Close','Coalville','Leicestershire','UNITED KINGDOM','LE67 4RW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 19:25:55',0,NULL,3,1,3,1,'RA117778327CN\r ','jammaster20009\rHSJA010\r英标'),(14644,581171884003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','theanayal8er','fmsstrznstrps@gmail.com','Anaya Andrews','1636 Villa St','Racine','WI','UNITED STATES','53403-2728','(262) 237-2726','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-26 19:27:21',0,NULL,3,1,1,1,'\\  ','theanayal8er'),(14645,638306895013,230653156192,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',46.99,'eastar4','s302','s302@msn.com','Stephen Palmer','1146 N Formosa Ave<br>Apt 4','West Hollywood','CA','UNITED STATES','90046-5821','(925) 984-3105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 19:34:38',0,NULL,3,1,1,1,'\\  ','s302'),(14646,785482281011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',115.99,'eastar4','vnraider','aqdang13@hotmail.com','Anthony dang','5200 KUNGSTING WAY','ELK GROVE','CA','UNITED STATES','95757-3516','(510) 386-7185','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 19:49:20',0,NULL,3,1,1,1,'\\ \r','vnraider'),(14647,870917132012,220681621602,'New ZAGG SPARQ 2.0 USB BATTERY CHARGER FOR iPHONE IPAD ',1,'BAZA001',33.25,'eastar4uk','steve362468','steve.sheffield@btinternet.com','Steve Sheffield','38, Evergreen Way','St. Helens','Merseyside','UNITED KINGDOM','WA9 4ZS','07706535306','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 19:52:48',0,NULL,3,1,3,1,'RA117778401CN\r ','steve362468\rBAZA001'),(14648,870950320012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',73.14,'eastar4uk','stalkernl','stalkervanbaaren@hotmail.com','Roland van Baaren','Wierbalg 1233','Den Helder','','NETHERLANDS','1788TG','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 19:56:18',0,NULL,3,1,3,1,'RA117778256CN\r ','stalkernl\rOTSO004*2'),(14649,781904625011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',2,'HSUE002',39.98,'eastar4','oromirio','roman.opalko@gmail.com','Roman Opalko','Stroitelej 14/5','Kiev','','UKRAINE','02100','+380634153739','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 20:07:09',0,NULL,3,1,2,1,'\\  ','oromirio'),(14650,638323859013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','bigp6700','paulc@royaltg.com','Paul Camera','21 Alpine Dr','East Haven','CT','UNITED STATES','06512-1451','(203) 468-0540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 20:13:35',0,NULL,3,1,1,1,'\\  ','bigp6700\r红边优联'),(14651,870963341012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',3,'OTSO004*2',219.42,'eastar4uk','mrpc_consultants','mrpc@sky.com','Martin Hodges','CFH Total Document Management Ltd.<br>St. Peter\'s Park, Wells Road','Radstock','Somerset','UNITED KINGDOM','BA3 3UP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 20:18:59',0,NULL,3,1,6,1,'EE491016009CN ','mrpc_consultants'),(14652,870968219012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','n.discs','n.discs@btinternet.com','Azad Harripaul','Hillview<br>Well Lane','Harlow','Essex','UNITED KINGDOM','CM19 5BG','07813540803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 20:26:50',0,NULL,3,1,2,1,'\\  ','n.discs'),(14653,870968046012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','aurista25','aurista25@hotmail.com','Aurash F Kamalipour','1941 Spring Cypress Rd','Spring','TX','UNITED STATES','77388-3504','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 20:31:38',0,NULL,3,1,1,1,'\\  ','aurista25'),(14654,870970395012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',108.29,'eastar4uk','7kash','k.biring@hotmail.co.uk','Kashmir Biring','28 Abbotts walk<br>Bexleyheath','Bexleyheath','Kent','UNITED KINGDOM','Da7 5rj','07951702504','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 20:34:08',0,NULL,3,1,3,1,'RA117778171CN\r ','7kash\rOTSO004*3'),(14655,638333683013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','wrightengineer','palmwrightnuclear@gmail.com','Anthony L. Wright','840 Meadow Ridge Ln','Birmingham','AL','UNITED STATES','35242-5410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 20:40:40',0,NULL,3,1,1,1,'\\  ','wrightengineer'),(14656,785512706011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','mathenyb7kh6','mathenyb@juno.com','Brian Matheny','37 Gatchell Way','Epping','NH','UNITED STATES','03042-1920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 20:46:38',0,NULL,3,1,1,1,'\\  ','mathenyb7kh6'),(14657,870981137012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','rustle93','bovin76@gmail.com','Aleksandr Bovin','40 Parkovay Str. app.48','Cherepovets','Vologodskaya obl','RUSSIAN FEDERATION','162611','7(8202)223893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 20:52:21',0,NULL,3,1,2,1,'\\  ','rustle93'),(14658,785515870011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','tuckerslot70','richard.tucker@virgin.net','geoff morphew','17 parklawn avenue','epsom','Surrey','UNITED KINGDOM','kt187sq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 20:52:31',0,NULL,3,1,3,1,'RA117778344CN\r ','tuckerslot70\rMOAP001'),(14659,785540264011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','fokasis','tadas.cep@gmail.com','Tadas Cepas','Pagegiu 8','Siauliai','','LITHUANIA','LT-78007','37065537542','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 21:51:15',0,NULL,3,1,2,1,'\\  ','fokasis\r红边优联'),(14660,638227213013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','wearver1990','wearver@terra.com.br','William da Silva','Rua Luiz Pereira de Campos, 901<br>Vila Itapanhau','Bertioga','sao Paulo','BRAZIL','11250000','13 91024567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 21:52:39',0,NULL,3,1,2,1,'\\  ','wearver1990'),(14661,638368863013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',6,'CASS001',66.32,'eastar4','capmanolo','capmanolo@eresmas.com','Manuel Martinez Alonso','Federico Carlos Sainz de Robles 31 7D','Madrid','Madrid','SPAIN','28035','678481524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 22:50:21',0,NULL,3,1,3,1,'RA117778287CN\r ','capmanolo\rCASS001+CASS002\rCAB-SS-2626\r再发两条CAB-2660'),(14662,743381638001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','bourbon_smith','jackcack77@gmail.com','John Smith','26 carluke crescent<br>apt:1402','toronto','ON','CANADA','m2l2j2','(416) 224-5353','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'bourbon_smith'),(14663,785571419011,320443637303,'Acer Timeline 4810 5810 Bluetooth Module 2.0 EDR+ cable',1,'BTAC2001',9.88,'eastar4','dwavetone','dbaudiotech@roadrunner.com','David Curtis','199 Old Webster Rd','Lewiston','ME','UNITED STATES','04240-1517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 23:30:24',0,NULL,3,1,1,1,'\\  ','dwavetone\racer 4pin 1.25 3cm '),(14664,743399435001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','tederian','pjames370@yahoo.com','phillip james','370 Ocean Pkwy<br>Apt 1L','Brooklyn','NY','UNITED STATES','11218-4620','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 00:03:15',0,NULL,3,1,1,1,'\\  ','tederian'),(14665,638385913013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','darrenbudge','budgelld@yahoo.ca','darren budgell','96 westview crst','lively','ON','CANADA','p3y 1b6','(705) 698-0080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 00:03:52',0,NULL,3,1,3,1,'RA117778295CN\r ','darrenbudge\rGPS0004'),(14666,871053413012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','underwood786','mobilerepairs@bigpond.com','Faisal Koya','P. O. Box 292<br>Shop 2b, 3231 Logan Road, Underwood','Brisbane','Queensland','AUSTRALIA','4119','0431581786','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 00:04:06',0,NULL,3,1,2,1,'\\  ','underwood786\r澳标'),(14667,785124672011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',10.99,'eastar4','soxfanzach','itszachg@gmail.com','Zach Gerard','3A Starbird RD','Jericho','VT','UNITED STATES','05465-2516','(802) 497-4147','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 00:22:50',0,NULL,3,1,1,1,'\\  ','soxfanzach'),(14668,785594514011,320737015281,'New in box genuine SONY 3D Active Glasses TDG-BR100',1,'OTSO003',82.99,'eastar4','blacktulip2007','safiamir@eastlink.ca','Safi Amir','46 Montebello Dr.','Dartmouth','NS','CANADA','B2X 3B2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 00:59:19',0,NULL,3,1,3,1,'RA117761627CN\r ','blacktulip2007\rOTSO003'),(14669,785596522011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','angel4667','sar-stu@bigpond.com','sara halliday','1366 Pine Mountain Rd','Borallon','Queensland','AUSTRALIA','4306','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 01:02:34',0,NULL,3,1,2,1,'\\  ','angel4667\r澳标\r黑色的 '),(14670,871087805012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.9,'eastar4','nking1977','neilmichaelking@hotmail.com','neil king','2140 Korat Ln','maitland','FL','UNITED STATES','32751-8639','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 02:01:02',0,NULL,3,1,1,1,'\\  ','nking1977'),(14671,782846600011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','vokkin','nikkov@tpg.com.au','Lisa Dyer','16 Prospector Drive','Cairnlea Estate (Deer Park)','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 02:20:26',0,NULL,3,1,3,1,'RA117761905CN\r ','vokkin\rGLOT001*3\r兼容型3D眼镜 通用型'),(14672,784084270011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','rj.lindeman','russlindeman@gmail.com','Russell Lindeman','4 Dulcify Crt','St Albans park','Victoria','AUSTRALIA','3219','0352481413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 02:34:12',0,NULL,3,1,3,1,'RA117761896CN\r ','rj.lindeman\rGLOT001*3\r兼容型3D眼镜 通用型'),(14673,581279759003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','ladyonthego','ladyonthego@yahoo.com','cheryl wilson','2326 63rd ave','oakland','CA','UNITED STATES','94605-1431','(510) 568-8470','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 03:21:04',0,NULL,3,1,1,1,'\\  ','ladyonthego'),(14674,638425875013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','tauaribr','tauari@live.com','Rafael Barbosa Moraes','Rua Eurico de Souza Leão, 259, Cordeiro','Recife','Pernambuco','BRAZIL','50721-100','+55(81)94802497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 03:16:00',0,NULL,3,1,2,1,'\\  ','tauaribr'),(14675,871147394012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','shootzies','shootzies@hotmail.com','Rebecca Hawkes','3659 S Colt Dr','gilbert','AZ','UNITED STATES','85297-9350','(206) 920-6611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 06:36:07',0,NULL,3,1,1,1,'\\  ','shootzies'),(14676,871159071012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','okourkoulos','okourkoulos@hotmail.com','Orestis Kourkoulos','105 / El. Venizelou<br>1st floor','Athens','na','GREECE','17123','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 07:31:28',0,NULL,3,1,2,1,'\\  ','okourkoulos'),(14677,871159891012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','ian_tindale','ian.tindale@btinternet.com','Ian Tindale','33 Boultwood Road','Beckton','London','UNITED KINGDOM','E6 5QH','07914855384','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 07:33:10',0,NULL,3,1,3,1,'RA117761984CN\r ','ian_tindale\rWLHP002'),(14678,784258261011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dopa26','patricia_buttigieg@hotmail.com','Patricia Buttigieg','135, Immaculate Conception Street','Qala','Gozo','MALTA','QLA1701','+35621562586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 07:48:36',0,NULL,3,1,2,1,'\\  ','dopa26\rMOAP001'),(14679,785695148011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',5,'BALO007',58,'eastar4','vejaika','serj_osipov@mail.ru','serj osipov','Turistskaya street<br>dom 31 corp.1 kvartira 78','Moscow','','RUSSIAN FEDERATION','125480','+7-(495)-494-8846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 08:44:47',0,NULL,3,1,3,1,'RA117761851CN\r ','vejaika\rBALO007'),(14680,578411369003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','toma.s','scala.toma@gmail.com','Thomas Scala','9 Rue Jean François Mansart','Garges-les-Gonesse','Île-de-France','FRANCE','95140','0623597431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 08:58:28',0,NULL,3,1,3,1,'RA117761922CN\r ','toma.s\rUDAP001'),(14681,785699104011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','jtsch52','jts.ch@hotmail.com','TrongTan Ho','1A Kent Ridge Road','default','','SINGAPORE','119224','(84)0933748885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 09:02:24',0,NULL,3,1,3,1,'RA117761967CN\r ','jtsch52\rRELO002\r新地址\rHo Trong Tan\r11/7 Dao Duy Tu. P.17, Quan Phu Nhuan\rHo Chi Minh city, Vietnam'),(14682,8881319706623517,111,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',0,'eastar4','toxhawk','rheyne@hotmail.com','Ryan Heyne','12659 337th Ave','Hosmer','SD','UNITED STATES','57448-5216','(605) 216-0634',NULL,NULL,NULL,'2011-10-27 09:10:23',0,NULL,3,1,3,1,'RA117761936CN\r ','BTAC2116 \racer 6pin1.25 23cm '),(14683,785701297011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','satelit23-2008','mcatargiu2005@yahoo.com','marius bogdan catargiu','141a reynolds drive','edgware','Middlesex','UNITED KINGDOM','ha8 5px','07889109977','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 09:11:07',0,NULL,3,1,3,1,'RA117761865CN\r ','satelit23-2008\rGLOT001\r兼容型3D眼镜 通用型'),(14684,638482300013,230412690573,'2.0 New ASUS Bluetooth Module +cable F5/Z53/F3/M51',1,'BTHU2003',9.88,'eastar4','danson_lampoh','dan_lampoh@yahoo.fr','Komlanvi LAMPOH','6 rue du comte Emery','Metz','Lorraine','FRANCE','57070','0611944262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 09:26:12',0,NULL,3,1,2,1,'\\  ','danson_lampoh\r华硕 10pin 1.0 15cm '),(14685,784736290011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',3,'WLAP004',10.5,'eastar4uk','muemmelchen111','regina.lenz111@yahoo.de','Regina Lenz','In der Grobe 16','Wilgersdorf','','GERMANY','57234','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 09:53:58',0,NULL,3,1,2,1,'\\  ','muemmelchen111'),(14686,785722077011,320721404615,'Transparent Dome Rain Sun Umbrella with pink trim',1,'UMTR001',19.99,'eastar4','mindfreak75','allenlaz@tpg.com.au','Allen Lazarian','3/118-124 Hamilton Road<br>Fairfield','Sydney','New South Wales','AUSTRALIA','2165','0297262306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 10:28:11',0,NULL,3,0,2,1,'\\  ','mindfreak75\r粉红色的\r已入库'),(14687,638502105013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',49.99,'eastar4','pmoorhead','paul.moorhead@ntlworld.com','Paul Moorhead','24 Pembridge Court','Belfast','Antrim','UNITED KINGDOM','BT4 2RW','07866454876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 11:06:59',0,NULL,3,1,3,1,'RA117761919CN\r ','pmoorhead\rRCLO004'),(14688,871241353012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','gordanagordana1965','samina112@hotmail.com','R.K Brennan /Gordana Budimir','15,ross court Lubbock road   chislehurst','Kent','Kent','UNITED KINGDOM','BR7 5JP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 12:19:49',0,NULL,3,1,3,1,'RA117760048CN\r ','gordanagordana1965\rHBPH007\r新地址\rGordana Budimir\rGosposvetska cesta 27\r2000 Maribor\rSLOVENIS\r\r'),(14689,785760727011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',3,'ANCN001',14.67,'eastar4','ubsnuur','lepineaude@yahoo.fr','Aude Lépine','13 ter, rue Marx Dormoy<br>appartement 105','NOISY LE GRAND','Ile-de-France','FRANCE','93160','06.72.26.15.26','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 12:48:56',0,NULL,3,1,2,1,'\\  ','ubsnuur'),(14690,638532582013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','eric_the_ace','eric.hulthe@bredband.net','Eric Hulthe','Bergsjovagen 13<br>42835 Kallered','Kallered','','SWEDEN','42835','+46317090142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 13:21:19',0,NULL,3,1,2,1,'\\  ','eric_the_ace'),(14691,870636379012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','telecast2010','bav222@gmail.com','Alexandr Baranov','Pr Bogoliubov 20-110','Dubna','Moscow region','RUSSIAN FEDERATION','141980','+ 7 926 374 64 59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 13:34:49',0,NULL,3,1,3,1,'RA117761975CN\r ','telecast2010\rCMLO001'),(14692,871272651012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','jahooten','jahooten@frontier.net','Jason Hooten','76 Riverview Dr','Durango','CO','UNITED STATES','81301-4364','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 13:44:38',0,NULL,3,1,1,1,'\\  ','jahooten'),(14693,638539862013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','wdhop66','wdhop66@aol.com','Dwight Hopkins','317 Cambridge Rd','Pasadena','Md','UNITED STATES','21122','(443) 817-2166','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-27 13:51:07',0,NULL,3,1,1,1,'\\  ','wdhop66'),(14694,785305927011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','qpawel','qpawel80@gmail.com','pawel sojkowski','Heather park drive<br>110','Wembley middlesex','London','UNITED KINGDOM','Ha0 1Sz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 13:58:46',0,NULL,3,1,3,1,'RA117761940CN\r ','qpawel\rGLOT001*2\r兼容型3D眼镜 通用型'),(14695,785792898011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','bamiry2011','bamirymeri@gmail.com','Bamir Ymeri','Dardania 1<br>Rr.1 Nr.21','Gjilan','Kosovo','ALBANIA','60000','+38649700578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 14:15:19',0,NULL,3,1,2,1,'\\  ','bamiry2011'),(14696,785798344011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','ngropman','nathan.gropman@optusnet.com.au','Nathan Gropman','20 Callander St','Hughesdale','Victoria','AUSTRALIA','3166','61412136515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 14:31:49',0,NULL,3,1,2,1,'\\  ','ngropman'),(14697,638553975013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','paulo.alem','biggahed@gmail.com','paulo alem','rua teotonio de brito, 407, ap103<br>olaria','rio de janeiro','rj','BRAZIL','21073080','+55 21 97938797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 14:41:36',0,NULL,3,1,2,1,'\\  ','paulo.alem'),(14698,785806351011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',2,'TRMX001',15.14,'eastar4','iamcanadian2u','dclongtin@coool.ca','dan longtin','RR1 Site 11 Box 65','Grande Prairie','AB','CANADA','T8V 2Z9','(780) 831-0037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 14:52:41',0,NULL,3,0,2,1,'\\  ','iamcanadian2u'),(14699,784642756011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','seeve_mcgross','iamseeve@comcast.net','wes hardin','532 Elliott Dr NW','rome','GA','UNITED STATES','30165-1008','(706) 766-9575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 14:54:50',0,NULL,3,1,1,1,'\\  ','seeve_mcgross'),(14700,638557568013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','g-ride0606','g_ride0606@yahoo.com','Goran Knapic','D.Brckovcina 56','Križevci','Koprivnicko-Krizevacka zupanija','CROATIA','48260','+385912539795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 14:55:04',0,NULL,3,1,2,1,'\\  ','g-ride0606\r欧标'),(14701,638561949013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','sgilbert54','steveinsawlog@hotmail.com','Steven Gilbert','139 Sawlog Point Road<br>RR#2','Penetanguishene','ON','CANADA','L9M 1R2','(705) 549-3762','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'sgilbert54'),(14702,638563943013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','nnatassa','nknatassa@gmail.com','MARIA NITSIOU','DIONISOU 18B ANO MELISSIA<br>15127','athens, attiki','','GREECE','15127','306946130733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 15:17:35',0,NULL,3,1,2,1,'\\  ','nnatassa\r欧标'),(14703,785833807011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','honestbrianl','brianlovatt@tiscali.co.uk','Brian Lovatt','Woodlands<br>Old Chester Road','Helsby','Cheshire','UNITED KINGDOM','WA6 9PN','01928724020','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 16:03:31',0,NULL,3,1,3,1,'RA117761825CN\r ','honestbrianl\rMOAP001'),(14704,871340016012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','talia1227rose','taliarose1227@aol.com','Natalia Martucci','518 Johnson Ave','Bohemia','NY','UNITED STATES','11716','(631) 880-9707','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 16:24:01',0,NULL,3,0,1,1,'\\  ','talia1227rose\r已入库\r粉红色的'),(14705,871342774012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','mgoldmgold_123','mgoldmgold@gmail.com','MICHAEL GOLDMAN','Polycom Israel Ltd. 94 Derech Em Hamoshavot<br>P.O. Box 3654','Petach Tikva','','ISRAEL','49130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 16:32:37',0,NULL,3,1,2,1,'\\  ','mgoldmgold_123'),(14706,726174073008,180741700577,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.99,'au-buy','siaulys77','mariui@live.com','Marius Siaulys','Fjellsvegen 62','Jorpeland','','NORWAY','4100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-27 16:44:34',0,NULL,3,1,3,1,'RA117761777CN\r ','siaulys77\rHSPL013\r欧标'),(14707,785856031011,320402064138,'HP ProBook 4510S 4515S 4710S Bluetooth Module 2.0 cable',1,'BTHP2004',9.88,'eastar4','tutmozes','rwh@hetnet.nl','Mozes Horneman','Reitdiep 53','CAPELLE AAN DEN IJSSEL','','NETHERLANDS','2904RD','0653268949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 16:56:15',0,NULL,3,1,2,1,'\\  ','tutmozes\rHP 8pin 1.0 18cm 4线连 '),(14708,871359747012,220785299925,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',66,'eastar4','greatpasta','greatpasta@telus.net','Deanna W Barrett','5879 Somerset Avenue','Peachland','BC','CANADA','V0H1X4','(250) 767-3133','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'greatpasta'),(14709,638613247013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','sany-sh','sany.sh@gmail.com','Alex Shunko','Street Trubnaya the house 21 apartment 37','Podolsk','The Moscow area','RUSSIAN FEDERATION','142111','+7 (926) 572-1427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 17:45:16',0,NULL,3,1,2,1,'\\  ','sany-sh'),(14710,871381547012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','vahik611','vahik002@yahoo.com','Vahram Jalalyan','Davitashen distr. IV block, build. 15, apt. 10','Yerevan','Yerevan','ARMENIA','0054','+37491477369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 17:50:37',0,NULL,3,0,2,1,'\\ ','vahik611\r已入库'),(14711,581464967003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',134.5,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','Chad Smith','989 Market St<br># Zendesk Fl 3','San Francisco','CA','UNITED STATES','94103-1743','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 18:17:56',0,NULL,3,1,1,1,'\\  ','321expressllc'),(14712,785906027011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','jros2105','rossi.julien@yahoo.fr','julien rossi','33 rue jules beraud','barcelonnette','Provence-Alpes-Côte d\'Azur','FRANCE','04400','04.92.32.20.01','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 18:30:51',0,NULL,3,1,3,1,'RA117761882CN\r ','jros2105\rGLOT001*2\r兼容型3D眼镜 通用型'),(14713,587013598004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','oriona51','b-bproductions@att.net','Ryan Connor','9636 Vista Dr','North Royalton','OH','UNITED STATES','44133-2317','(440) 655-5782','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 19:39:26',0,NULL,3,1,1,1,'\\  ','oriona51\r红边优联'),(14714,743748264001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','tamias46','jean-pierre.cornut@tamias.ca','Jean-Pierre Cornut','529, ch. des Pionniers Ouest','Cap-Saint-Ignace','QC','CANADA','G0R 1H0','(418) 246-4252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 19:44:41',0,NULL,3,1,3,1,'RA117762004CN\r ','tamias46\rOTSB001'),(14715,785956811011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','158goodwin','bigdady2123@hotmail.com','Travis Goodwin','158 Pleasant View Rd','Blythewood','SC','UNITED STATES','29016-9677','(803) 467-1442','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 20:01:12',0,NULL,3,1,1,1,'\\  ','158goodwin'),(14716,785972069011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',25.64,'eastar4','vrikey','barryhoman@hotmail.com','Bradley Barrett Homan','Sdr. Trandersvej 170','Gistrup','','DENMARK','9260','(+45) 9831 5581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 20:33:29',0,NULL,3,1,2,1,'\\  ','vrikey\rProLee24K超轻碳纤骨长柄伞 \r红色的'),(14717,871490310012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','555djm','dj.mansbridge@ntlworld.com','Mr David John Mansbridge','31 OLD RECTORY ROAD<br>FARLINGTON','PORTSMOUTH','Hampshire','UNITED KINGDOM','PO6 1AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 20:45:51',0,NULL,3,1,3,1,'RA117761834CN\r ','555djm\rHSPL013\r英标'),(14718,638687648013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','hacky97','arjanwiegel@hotmail.com','Arjan Wiegel','De Savornin Lohmanstraat 1c','Wierden','','NETHERLANDS','7642 xl','+316-27001870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 20:52:19',0,NULL,3,1,2,1,'\\  ','hacky97'),(14719,871501075012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','rolerzzz','davizzz@inbox.lv','Davis Lukso','Lendropsgade 1, 3','Horsens','','DENMARK','8700','+4530555031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 21:07:06',0,NULL,3,1,2,1,'\\  ','rolerzzz'),(14720,871513364012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','30272pets','derek55wiltshire@aol.com','Derek Gale','11,Barnmoor Close','Swindon','Wiltshire','UNITED KINGDOM','SN36HA','01793610506','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 21:34:10',0,NULL,3,1,3,1,'RA117760706CN\r ','30272pets\rGLOT005'),(14721,871515680012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.88,'eastar4','allanrsm2010','allanrsm@gmail.com','ALLAN RODRIGO','RUA THOMAS EDSON, 1346<br>BAIRRO: PARANGABA','FORTALEZA','CEARA','BRAZIL','60714-070','85 32451913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 21:39:19',0,NULL,3,1,2,1,'\\  ','allanrsm2010\r华硕10pin 0.8 6cm '),(14722,638710856013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',2,'BAZA001',109.98,'eastar4','69eisus','julian@battistellafs.com.au','Julian Battistella','Suite 314<br>19 Milton Parade','MALVERN','Victoria','AUSTRALIA','3144','0398320766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 22:09:00',0,NULL,3,1,3,1,'RA117761785CN\r ','69eisus\rBAZA001'),(14723,786014608011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','nikitasga','ngarganouris@yahoo.gr','NIKITAS GARGANOURIS','MESSINIS 11','HERACLION CRETE','','GREECE','71409','00306984617076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 22:12:50',0,NULL,3,1,3,1,'RA117761998CN\r ','nikitasga\rRCLO006'),(14724,786020521011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','marcosandres84','jmagz84@gmail.com','Mark A Gingerich c/o Benjamin Martin','N2726 3rd St','Conrath','WI','UNITED STATES','54731-9807','(715) 403-0007','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 22:31:15',0,NULL,3,1,1,1,'、 ','marcosandres84'),(14725,786420528002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','manicouta1','chocolat1@videotron.ca','patrick gauthier','500 croissant de murano','laval','QC','CANADA','h7m5r6','(450) 662-3630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 22:47:08',0,NULL,3,1,3,1,'RA117761817CN\r ','manicouta1\rBR3D002'),(14726,871554279012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',23.74,'eastar4','gamefreak497','pnguyen333@yahoo.com','Luybang Trinh','75 Saint Alphonsus St','Boston','MA','UNITED STATES','02120-1676','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 23:28:17',0,NULL,3,1,1,1,'\\  ','gamefreak497\r蕾丝花边伞 \r黑色的'),(14727,638738947013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ciscouser1','reece@whatthe.net','Reece Anderson','55 Crockford Street<br>Port Melbourne','Melbourne','Victoria','AUSTRALIA','3207','61421244244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 00:12:27',0,NULL,3,1,2,1,'\\  ','ciscouser1'),(14728,743849979001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','shane3958','shanes8535@yahoo.co.nz','shane smith','2 Alderson Avenue<br>Hillsborough','Christchurch','Canterbury','NEW ZEALAND','8002','3327655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 00:34:08',0,NULL,3,1,3,1,'RA117761763CN\r ','shane3958\rBR3D005'),(14729,581574437003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.95,'cnfaner','extraham','xtra6@cox.net','John Terrell','6714 Crest Rd','Rancho Palos Verdes','CA','UNITED STATES','90275-5427','(310) 541-1730','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-28 00:44:55',0,NULL,3,1,1,1,'\\  ','extraham'),(14730,871578409012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','jcpjr','jcpjr.eng@gmail.com','JULIO PEREIRA','RUA DURVALINA TAVARES BARRETO, 56 Ap25','CAMPINAS','SP','BRAZIL','13070-202','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 00:45:48',0,NULL,3,1,2,1,'\\  ','jcpjr'),(14731,743853222001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','teo7.809','teofiloisrael@yahoo.com','Jayker Henriquez, Signcro, S.A','1733 NW 79th Ave<br># CPS11033','Doral','FL','UNITED STATES','33126-1101','(829) 935-9209','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 00:52:16',0,NULL,3,1,1,1,'\\  ','teo7.809'),(14732,786080941011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','stho3230','mantha-12@hotmail.com','samantha thompson','10399 hwy 11','springville','AL','UNITED STATES','35146','(205) 602-1325','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 02:04:24',0,NULL,3,1,1,1,'\\  ','stho3230'),(14733,587117344004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','1999mustang1999','brad1962@aol.com','BRADLEY BARNHART','346 Citation Dr SW','PATASKALA','OH','UNITED STATES','43062-8510','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-28 03:22:15',0,NULL,3,1,1,1,'\\  ','1999mustang1999'),(14734,786098330011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jeremyporter.me','jporter.me@gmail.com','Jeremy Porter','645 Bates College','Lewiston','ME','UNITED STATES','04240-6067','(207) 475-6057','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 03:27:28',0,NULL,3,1,1,1,'\\  ','jeremyporter.me'),(14735,0,320779153312,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',54,'eastar4','americanonlinedepot','zinvor1918@aol.com','Rafi Demirjian','1118 N Central Ave<br>Unit 22','Glendale','CA','UNITED STATES','91202-2521','(310) 804-9929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 03:51:01',0,NULL,3,1,12,1,'5241787751\r ','americanonlinedepot\r一共买了128个'),(14736,0,220878337522,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',90,'eastar4','americanonlinedepot','zinvor1918@aol.com','Rafi Demirjian','1118 N Central Ave<br>Unit 22','Glendale','CA','UNITED STATES','91202-2521','(310) 804-9929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 03:51:07',0,NULL,3,1,12,0,'5241787751 ','americanonlinedepot'),(14737,581590075003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',45.38,'cnfaner','paulogentil10','paulogentil@hotmail.com','Paulo Gentil','SQN 216 bl.A apt.223','Brasilia','DF','BRAZIL','70875-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 04:22:25',0,NULL,3,1,3,1,'RA117760079CN ','paulogentil10\rHSMO016'),(14738,871646839012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','imv21','imvasilev@yahoo.com','Igor Vasilev','Shumilova 18-145','Cheboksary','Chuvash Republic','RUSSIAN FEDERATION','428031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 05:23:15',0,NULL,3,1,2,1,'\\  ','imv21'),(14739,871651323012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','emem88','mikem@sunwave.net','Mike Morgan','1561 20th. Ave. N.E.','Salmon Arm','BC','CANADA','V1E 3X8','(250) 803-1736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 05:45:06',0,NULL,3,1,2,1,'\\  ','emem88'),(14740,638801284013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',23.74,'eastar4','peppermint_pianist','pepperminty93@live.com','Sarah  Bleeker','17180 Deacon Ln','Cottonwood','CA','UNITED STATES','96022-9639','(530) 527-6368','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 05:55:32',0,NULL,3,1,1,1,'\\  ','peppermint_pianist\r粉红色的\r钢琴美女伞 '),(14741,638513288013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','aerozakaz','one@aerozakaz.com','Kirill Mulman','7540 McCormick Blvd<br>unit 1075','Skokie','IL','UNITED STATES','60076-4041','(773) 234-5773','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-28 06:49:25',0,NULL,3,1,1,1,'\\  ','aerozakaz'),(14742,786147851011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','marko_ven','marko.venalainen@nic.fi','Marko Venäläinen','Kolsarintie 8','KANTVIK','Finland','FINLAND','02460','+358503324116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 07:39:07',0,NULL,3,1,2,1,'\\  ','marko_ven\rHSNO019\r欧标'),(14743,0,220878338011,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',0.99,'eastar4','substi57','sebastien.nozza@laposte.net','sebastien nozza','139 citée bellevue','hayange','Lorraine','FRANCE','57700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 07:47:16',0,NULL,3,1,2,1,'\\  ','substi57'),(14744,871680965012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','maximka73','maks430@ya.ru','Maxim Belihin','Sverdlova 44a-46','Podolsk','Moscow reg','RUSSIAN FEDERATION','142114','89031899649','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:01:53',0,NULL,3,1,2,1,'\\  ','maximka73'),(14745,786154370011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',9.88,'eastar4','deivydas777','deivydasciupas@gmail.com','DEIVYDAS CIUPAS','167 BRIERFIELD','SKELMERSDALE','Lancashire','UNITED KINGDOM','WN8 9JB','07821766158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:07:10',0,NULL,3,1,2,1,'\\  ','deivydas777\racer 4pin1.25 6cm'),(14746,871688298012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',5,'RMSN002',99.95,'eastar4','koelner1963','krappu@uwekrapp.de','Uwe Krapp','Jenseitsstr. 75a','Bergheim (Quadrath-Ichendorf)','','GERMANY','50127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:38:28',0,NULL,3,1,3,1,'RA117760153CN ','koelner1963\rRMSN002'),(14747,786160992011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','carbak','canarbak@hotmail.com','Can Arbak','Y.Kemal Bayatli Sok. No:20/4 Nizam Mevkii<br>Buyukada','Istanbul','-','TURKEY','34970','555 424 3707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:40:28',0,NULL,3,1,2,1,'、 ','carbak'),(14748,871705440012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','mastercut28','ja.man@gmx.de','Manfred Jaschinski','Goldrenettenweg 5','Syke','','GERMANY','28857','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 09:33:22',0,NULL,3,1,3,1,'RA117763605CN\r ','mastercut28\rGPS0003'),(14749,786186238011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','robbi.c','robert@christophersen.info','Robert Christophersen','In Busch 48','Wegberg','','GERMANY','41844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 10:12:12',0,NULL,3,1,2,1,'\\  ','robbi.c'),(14750,871719659012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','zipyzape','liviuboz@ono.com','liviu adrian boz','c/castilla la mancha nº1 4ºb','jaen','Andalucía Ceuta y Melilla','SPAIN','23008','654295032','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 10:24:14',0,NULL,3,1,3,1,'RA117763163CN\r ','zipyzape\rHSPL013\r欧标'),(14751,786191401011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','35magpie42','matthew_mandy@yahoo.com.au','Matthew Haldane','17 LOVE STREET','SPRING HILL','Queensland','AUSTRALIA','4000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 10:34:19',0,NULL,3,1,2,1,'\\  ','35magpie42'),(14752,0,320779136188,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',2,'eastar4','garbon.2007','rodstewart4@yahoo.com','Sandra Garbon','2511 Green Ave','Bristol','PA','UNITED STATES','19007-2024','(215) 826-9442','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 10:41:59',0,NULL,3,1,1,1,'\\  ','garbon.2007'),(14753,871735692012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','les2amours','jucin@orange.fr','Granger Lisa','14 rue de catteville','Tourville la chapelle','Haute-Normandie','FRANCE','76630','0235403366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 11:15:55',0,NULL,3,1,3,1,'RA117760621CN\r ','les2amours\rGLOT005'),(14754,871747981012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',55.99,'eastar4','nismo-8','tristandunn@live.com.au','tristan dunn','12 beverley st morphett vale','adelaide','South Australia','AUSTRALIA','5162','0883253040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 11:53:01',0,NULL,3,1,3,1,'RA117760533CN ','nismo-8\rKBFF001'),(14755,786230684011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',41.69,'eastar4uk','pabz1979','p.mcshane@hotmail.com','Paul McShane','C/O One Architecture Ltd<br>3rd Floor, 145 St Vincent Street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G2 5JF','01412850260','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 12:47:58',0,NULL,3,1,3,1,'RA117760555CN ','pabz1979\rHDGE001\r英标'),(14756,581701782003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','robbinsd10262','robbinsd102@yahoo.com','Donna Robbins','316 County Road 4264','Dayton','TX','UNITED STATES','77535-8160','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-28 13:18:12',0,NULL,3,1,1,1,'\\  ','robbinsd10262'),(14757,871789400012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','tonylfc81','tonyc5times@aol.co.uk','Tony Christie','82 dunvale','ballymena','Antrim','UNITED KINGDOM','bt436ny','07743605274','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 13:51:43',0,NULL,3,1,3,1,'RA117763013CN\r ','tonylfc81\rGLOT001*3\r兼容型3D眼镜 通用型'),(14758,786256485011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','jonj14725','johnalberti@live.com','jonathan albert','6 parkhaven court<br>crabtree lane','lancing','West Sussex','UNITED KINGDOM','bn15 9ph','01903761885','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 14:01:47',0,NULL,3,1,3,1,'RA117760547CN ','jonj14725\rMOAP001'),(14759,638907309013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','ruskia0','mart0@gbg.bg','Martin  Georgiev','bul. Osmi Dekemvri 13 (Megalan) Studentski Grad','Sofia','Sofia','BULGARIA','1700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 14:45:44',0,NULL,3,1,2,1,'\\  ','ruskia0'),(14760,871814034012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','q-melk','ragnhildnordheim@live.no','Ragnhild Nordheim','Liabrekka 24','Norheimsund','Norway','NORWAY','5600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 14:54:59',0,NULL,3,1,2,1,'\\  ','q-melk'),(14761,786277339011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2',109.99,'eastar4','ptr253586','ptrpa_25@yahoo.com','Joseph G Crotti Jr','3553 Valleyview Dr','Kissimmee','FL','UNITED STATES','34746-2867','(407) 201-7014','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 15:08:22',0,NULL,3,1,1,1,'\\ ','ptr253586'),(14762,786285049011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jada60','tril4@rogers.com','David Shields','21193 Clubside Dr<br>Apt B','Boca Raton','FL','UNITED STATES','33434-4741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 15:24:21',0,NULL,3,1,1,1,'\\  ','jada60'),(14763,871831584012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','aceware.inc','ace.inc@live.ca','Christopher Poirier','4530 Ambroise Lafortune','boisbriand','QC','CANADA','j7h1s6','(450) 712-0641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 15:35:18',0,NULL,3,1,3,1,'RA117763058CN ','aceware.inc\rGLOT001*2\r兼容型3D眼镜 通用型'),(14764,871842030012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','bronc52','bsul@live.com','brian sullivan','17 Fidge Crescent<br>Breakwater','Geelong','Victoria','AUSTRALIA','3219','04185440990418544099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 15:59:32',0,NULL,3,1,2,1,'\\  ','bronc52\r'),(14765,786303054011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','nige_greenwood','nige_greenwood@msn.com','Nigel Greenwood','18 Merrifield Rd','Salisbury','Wiltshire','UNITED KINGDOM','SP4 6DF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 16:03:33',0,NULL,3,1,3,1,'RA117763089CN\r ','nige_greenwood\rRELO003\r红边优联'),(14766,786303850011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','enano111','pabloportilloalcalde@gmail.com','Pablo Portillo Alcalde','Rio Guadalquivir, 13<br>Urb. La Alcayna','Molina de Segura','Murcia','SPAIN','E-30507','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 16:05:49',0,NULL,3,1,2,1,'\\  ','enano111'),(14767,786316305011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','aaltjefish','seinen@planet.eon.net','W.L. (Bert) Seinen','10912 148 Street','Edmonton','AB','CANADA','T5N 3H7','(780) 451-2217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 16:33:39',0,NULL,3,1,3,1,'RA117760581CN\r ','aaltjefish\rGLSG001*2'),(14768,637271712013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','lnc_netquest','linc@quicklinc.com','Larry N Craig','4377 Stewart Rd','Metamora','MI','UNITED STATES','48455-9777','(248) 373-2445','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 16:43:30',0,NULL,3,1,1,1,'\\  ','lnc_netquest'),(14769,871862489012,220748695642,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',4.9,'eastar4uk','fruitslice','caceresj@sympatico.ca','Judy Caceres','26 Gulliver Rd. Apt.#304<br>Door Code: 2620','Toronto','ON','CANADA','M6M 2M8','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 16:55:55',0,NULL,3,1,2,1,'\\  ','fruitslice'),(14770,786334603011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','japthug','ikumafutaba@hotmail.com','Ikuma Futaba','142 Koyama<br>Kita ward','Okayama city','Okayama','JAPAN','701-1352','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 17:12:59',0,NULL,3,1,2,1,'\\  ','japthug'),(14771,871889853012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','marvrw','marvinwe@mac.com','Marvin Weide','8536 N Farview Dr','Scottsdale','AZ','UNITED STATES','85258-2002','(480) 948-6276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 17:35:45',0,NULL,3,1,1,1,'\\  ','marvrw'),(14772,786356950011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','iddo_kressel','iddo.kressel@gmail.com','Iddo Kressel','190 Arlozorof St.','Holon','','ISRAEL','58385','(+972)35017052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 17:59:52',0,NULL,3,1,2,1,'\\  ','iddo_kressel'),(14773,786360879011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','genealdad','theodric@gmail.com','Jeremy Sharp / Joni Steinmann','Oostzee 14','Hoofddorp','','NETHERLANDS','2133KM','0615399866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 18:09:01',0,NULL,3,1,2,1,'\\  ','genealdad'),(14774,638431729013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','proxytelecom','rxsantos@gmail.com','Roberto Xavier dos Santos','Rua Plutao 133','Curitiba','Parana','BRAZIL','81910410','554133786224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 19:00:31',0,NULL,3,1,3,1,'RA117763469CN\r ','proxytelecom\rGLOT005'),(14775,871939243012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','msandrew1','msandrew@chartermi.net','Mark Andrew','987 Post Ave','Holland','MI','UNITED STATES','49424-2551','(616) 786-9750','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 19:04:49',0,NULL,3,1,1,1,'\\ ','msandrew1\r白色的'),(14776,726694877008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',57.99,'au-buy','ffasolin','fasolin@fasolin.com','Franck FASOLIN','9 impasse des jardins rebus','Briis sous forges','Île-de-France','FRANCE','91640','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 19:30:51',0,NULL,5,1,18,0,NULL,'ffasolin\r黑色的\rGLOT005'),(14777,639003046013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','bigeddieko','hci_ed@hotmail.com','Edward Kowalski','355 River Bluff Rd','Elgin','IL','UNITED STATES','60120-2421','(847) 214-8307','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 19:35:33',0,NULL,3,1,1,1,'\\ ','bigeddieko\r红边优联'),(14778,782290585011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','scapegoatnc','royer@sgoat.com','Dan Royer','8604 Sandy Glen ct','Charlotte','NC','UNITED STATES','28212-6521','(704) 605-9775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 19:57:06',0,NULL,3,1,1,1,'\\  ','scapegoatnc'),(14779,786418094011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','paulradford1062','paul.radford1@virgin.net','Paul Radford','10 Queens Road<br>Datchet','Slough','Berkshire','UNITED KINGDOM','SL39BN','07976937216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 20:00:01',0,NULL,3,1,3,1,'RA117763150CN\r ','paulradford1062\r红边优联\rRELO003'),(14780,639045359013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','objetfetiche','silicium@orange.fr','Emmanuel Coulon','6 rue André Maurois','Le Buisson de Cadouin','Aquitaine','FRANCE','24480','+33(0)678858357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 21:39:34',0,NULL,3,1,2,1,'\\  ','objetfetiche\rCAB-6060'),(14781,872020510012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','dhaselho','ebay@sicoir.com','Dallas Haselhorst','1501 E 27th St','Hays','KS','UNITED STATES','67601-2111','(785) 628-1330','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 21:47:34',0,NULL,3,1,1,1,'\\  ','dhaselho'),(14782,786487030011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','to_dream','carlo@signplus.ca','Carlo Piro','665 Millway Ave.<br>Unit 55','Concord','ON','CANADA','L4K 3T8','(905) 738-8401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 22:58:25',0,NULL,3,1,2,1,'\\  ','to_dream'),(14783,636334445013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.39,'eastar4','murilolobato','murilo@perfilweb.com.br','Murilo Lobato','Rua 3160, 464 - Casa<br>Centro','Balneário Camboriú','Santa Catarina','BRAZIL','88330-284','(047)9966-0825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 23:55:14',0,NULL,3,1,2,1,'\\  ','murilolobato\racer 8pin1.00 10cm '),(14784,872066944012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','bonard113','bonard2.0@gmail.com','Eric Poulin','1721 albertine app.9','St-Romuald (Lévis)','QC','CANADA','G6W2P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 00:16:00',0,NULL,3,1,2,1,'\\  ','bonard113\racer 8pin1.00 8cm '),(14785,786527918011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',45.99,'eastar4','leo750','tleon@c2i.net','Tom Jarle Leonsen','Finstad','2080 Eidsvoll','Akershus','NORWAY','2080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 01:47:36',0,NULL,3,1,3,1,'RA117763027CN\r ','leo750\rBR3D001'),(14786,639096838013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','snazzydre','andresvasquez19@yahoo.com','Andres Vasquez','5998 Autumn Harvest Ave','Las Vegas','NV','UNITED STATES','89142-0803','(702) 373-6587','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 01:55:53',0,NULL,3,1,1,1,'\\  ','snazzydre'),(14787,786530277011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','megamoog','lawrence.prinner@sbcglobal.net','Lawrence Prinner','46W980 Allen Rd','Hampshire','IL','UNITED STATES','60140-9701','(847) 683-2574','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 01:58:01',0,NULL,3,1,1,1,'\\  ','megamoog'),(14788,639102450013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','isu85','flynns86@mchsi.com','Daniel A. Flynn','904 Grant St','Bettendorf','IA','UNITED STATES','52722-4742','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 02:26:15',0,NULL,3,1,1,1,'\\  ','isu85\r红边优联'),(14789,872101656012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',10.55,'eastar4uk','stingydee','denisemarsman@bellaliant.net','Denise Marsman','13 Poplar Drive','Dartmouth','NS','CANADA','B2W2K5','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 02:36:53',0,NULL,3,1,2,1,'\\  ','stingydee'),(14790,639118690013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','ossos','ottojsantos@hotmail.com','Otto Santos','1770 NW 96th Ave.<br>TRANEXCO 11821TP6CO','DORAL','FL','UNITED STATES','33172-2312','(786) 206-5300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 04:10:20',0,NULL,3,1,1,1,'\\ ','ossos\r兼容型3D眼镜 通用型'),(14791,638494201013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','djmakka952','brendy@rubicom.hu','Kurucz Mihály','Major utca 63.','Budapest','','HUNGARY','1119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 04:22:55',0,NULL,3,1,2,1,'\\  ','djmakka952\r华硕 8pin 1.0 6cm '),(14792,872143758012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','shu039','shuli6161@gmail.com','Shu Li','52 Apollo Road','Taylors Lakes','Victoria','AUSTRALIA','3038','0393903281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 06:15:46',0,NULL,3,1,3,1,'RA117760652CN\r ','shu039\rCMLO001'),(14793,786578341011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','dean_ivanov','dkivanov@gmail.com','Dean Ivanov','Cisco Systems office<br>Business Park Sofia, block 11B, fl. 4, Mladost 4','Sofia','','BULGARIA','1766','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 06:22:28',0,NULL,3,1,2,1,'\\  ','dean_ivanov\r欧标\r黑色的'),(14794,8881319869547374,111,'acer 6pin1.25 23cm 只发cable',1,'',0,'eastar4','harbisonautoparts','harbisonautoparts@hotmail.com','Harbison Auto Parts - Arthur Crosby','4434 Kiln Ct<br>Bldg A','Louisville','KY','UNITED STATES','40218-3042','(502) 458-0326',NULL,NULL,NULL,'2011-10-29 06:25:47',0,NULL,3,0,1,1,'\\  ','补货 \rLK017052801CN '),(14795,639139341013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','g3monster_89','adriandkicksebay@gmail.com','Adrian Drummond','25 Gilmour Court','Greensborough','Victoria','AUSTRALIA','3088','0425816167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 06:52:47',0,NULL,3,1,2,1,'\\  ','g3monster_89\rCAB-6060\r在发一条CAB-2660'),(14796,872155853012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',8.29,'eastar4','g3monster_89','adriandkicksebay@gmail.com','Adrian Drummond','25 Gilmour Court','Greensborough','Victoria','AUSTRALIA','3088','0425816167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 07:14:34',0,NULL,3,1,17,0,NULL,'g3monster_89'),(14797,786591292011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','zachjohn888','zachjohn88@gmail.com','Zachariah Pallikathekathil','30 Orbell Way','Bull Creek','Western Australia','AUSTRALIA','6149','0861022761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 08:09:23',0,NULL,3,1,2,1,'\\  ','zachjohn888'),(14798,786609642011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','mohamad_hussein','mohamad_67hussein@yahoo.com','Mohamad Jawad Hussein','Regeringsgatan 39 LGH 1102','Karlshamn','blekinge','SWEDEN','374 35','0737364691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 08:44:07',0,NULL,3,1,2,1,'\\ ','mohamad_hussein\r欧标'),(14799,786616636011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','deksxxl','ganja_smoker@bk.ru','Ivan Trifonov','Moskovskii prospekt, d. 66, kv. 53','Kaliningrad','','RUSSIAN FEDERATION','236006','+79114685281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 09:07:57',0,NULL,3,1,2,1,'\\  ','deksxxl'),(14800,639167820013,230652076407,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',2,'WWSI004+ANCN001',79.98,'eastar4','sernafa','snavarro@wanadoo.es','Sergio Navarro Fajardo','Trullas S/N (NISSAN)','Alginet','Comunidad Valenciana','SPAIN','46230','961751033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 09:28:42',0,NULL,3,1,3,1,'RA117763203CN\r ','sernafa\rWWSI004+ANCN001'),(14801,786626645011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','usualsuspects666','drew.gould40@googlemail.com','Andrew Gould','75 Ladderedge','Leek','Staffordshire','UNITED KINGDOM','ST13 7AG','01538373632','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 09:42:07',0,NULL,3,1,3,1,'RA117763225CN\r ','usualsuspects666\rGLOT001\r兼容型3D眼镜 通用型'),(14802,786635920011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','j_tillo','johntillotson@yahoo.com','John Tillotson','15 Eden Rise','Fareham','Hampshire','UNITED KINGDOM','PO16 0UL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 10:13:51',0,NULL,3,1,3,1,'RA117763075CN\r ','j_tillo'),(14803,639177549013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','benknackan1','benknackan@gmail.com','Joakim Bergman','Norra gubberogatan 19B','Göteborg','Västra Götaland','SWEDEN','41663','+46763495339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 10:15:16',0,NULL,3,1,2,1,'\\  ','benknackan1'),(14804,872207630012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','joro.medi','jorocoms@gmail.com','10813 GEORGI GEORGIEV-SF','15 Tottenham Lane<br>15 Tottenham Lane','London','London','UNITED KINGDOM','N8 9DJ','3590894604044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 10:15:52',0,NULL,3,1,3,1,'RA117763092CN\r ','joro.medi\r英标\rHSJA002'),(14805,786637437011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','jaqileah','robert.freeman16@orange.fr','Jaqueline Freeman','Fregeville','Saint Maurice Des Lions','Poitou-Charentes','FRANCE','16500','05455842181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 10:19:30',0,NULL,3,1,2,1,'\\  ','jaqileah'),(14806,872213299012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','farez1826','fauzan1975@yahoo.com.au','Fauzan Azima','142 Juno Parade','Greenacre','New South Wales','AUSTRALIA','2190','0434587699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 10:34:31',0,NULL,3,1,2,1,'\\  ','farez1826\r澳标'),(14807,786652915011,320439382075,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.99,'eastar4','elizgor901','gordonwayne@att.net','wayne gordon','3787 S Barron Cir','memphis','TN','UNITED STATES','38111-6444','(901) 743-6598','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 11:09:35',0,NULL,3,1,1,1,'\\  ','elizgor901'),(14808,872230420012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','dir_marillion','dir_marillion@hotmail.com','EVAGGELIA BENAKI','ANEXARTISIAS 91-93','ARGYROUPOLIS','GREECE','GREECE','16451','0036977216294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 11:24:22',0,NULL,3,1,2,1,'\\  ','dir_marillion\rAUI Transceiver  MX20T'),(14809,786659356011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','geoff.boniface','gboniface@hotmail.com','Geoffrey Boniface','27, Longmeadow Drive, Ickleford','Hitchin','Hertfordshire','UNITED KINGDOM','SG53TJ','07905145106','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 11:28:48',0,NULL,3,1,3,1,'RA117760462CN ','geoff.boniface\r红边优联\rRELO003'),(14810,872233397012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','pyme69','andy.pymer@tiscali.co.uk','Andrew Pymer','Fairlawns Lydyett Lane, Barnton','Northwich','Cheshire','UNITED KINGDOM','CW8 4JP','0160675147','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 11:32:18',0,NULL,3,1,3,1,'RA117763217CN\r ','pyme69\r英标\rHSMO007'),(14811,582008796003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',53.8,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','Aims Community College','Graphic Technology Department/Nancy Doyle<br>4911 W. 20th St.','Greeley','CO','UNITED STATES','80634-3232','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-29 13:05:46',0,NULL,3,1,1,1,'\\  ','321expressllc'),(14812,872274697012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',33.99,'eastar4uk','jogun83','ebay@chabek.de','Jürgen Chabek','Beethovenstr. 6','Berg','','GERMANY','76768','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 13:19:26',0,NULL,3,1,3,1,'RA117760520CN ','jogun83\rMOMI001'),(14813,582016836003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','jjafas','jose_joao_andre@hotmail.com','José João André Soares','Rua Dr. Afonso Cordeiro nº 50 hab. 4.3','Matosinhos','Matosinhos','PORTUGAL','4450-001','+351934282229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 13:23:08',0,NULL,3,1,3,1,'RA117763185CN\r ','jjafas\rWLAT003'),(14814,786471673011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','cyzmic1','johnlwenger@gmail.com','John Wenger','18375 Shaddox Hollow Rd','Rogers','AR','UNITED STATES','72756-7991','(479) 925-7054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 13:24:27',0,NULL,3,1,1,1,'\\  ','cyzmic1'),(14815,639235849013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','robinpeter81','mailbird81@gmail.com','Robin Peter','3/34 Wentworth Tce<br>The Range','Rockhampton','Queensland','AUSTRALIA','4700','0431261544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 14:14:04',0,NULL,3,1,2,1,'\\  ','robinpeter81'),(14816,786721133011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','trubel11','trubel@columbus.rr.com','Tom Rubel','6880 N Ocean Blvd<br>Mais. 7','Ocean Ridge','FL','UNITED STATES','33435-3348','(614) 481-7962','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 14:21:51',0,NULL,3,1,1,1,'\\  ','trubel11'),(14817,786724616011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','gregd81','dodsong@gmail.com','Greg Dodson','841 Ryans Pl','Fort Mill','SC','UNITED STATES','29715-1622','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 14:29:13',0,NULL,3,1,1,1,'\\  ','gregd81'),(14818,872320889012,220816342966,'New lady cute light lace trim Sun Stick Umbrella',1,'UM00029',14.95,'eastar4','selenavlada','smr_lena@mail.ru','Elena Sukhoruchenko','101 Strelkovoi brigady, 8-34','Aktobe','KZ, Aktyubinskaya obl','KAZAKHSTAN','030000','+77057005539','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 15:04:23',0,NULL,3,0,2,1,'\\  ','selenavlada'),(14819,786738961011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','fildipo','fildip@gmail.com','Filip Dahl','Nørre Allé 13G 2tv','København','','DENMARK','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 15:10:57',0,NULL,3,1,2,1,'\\  ','fildipo'),(14820,638520387013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','select3310','jgaravela@hotmail.com','EUGENIA GARAVELA','MOYZAKI KARDITSAS','KARDITSA','','GREECE','43060','+306975501335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 15:19:09',0,NULL,3,1,3,1,'RA117763472CN\r ','select3310\rGLOT005'),(14821,786750325011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','boidtoid','lconner20@comcast.net','Lloyd Conner','PO Box 21004','Albuquerque','NM','UNITED STATES','87154-1004','(505) 453-4938','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 15:28:41',0,NULL,3,1,1,1,'\\ ','boidtoid'),(14822,872335299012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',3,'OTCN003',14.94,'eastar4','eagleawk','diquydiq@gmail.com','J. B. Parente','2e Jacob van Campenstr 23','AMSTERDAM','','NETHERLANDS','1073XN','0031202221505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 15:30:13',0,NULL,3,1,2,1,'\\  ','eagleawk'),(14823,786750589011,320762399717,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP003',44.99,'eastar4','jackiecam123','rcam414@gmail.com','Russell T. Cammack','2491 Flowering Dogwood Dr','Orlando','FL','UNITED STATES','32828-4829','(407) 453-0948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 15:30:41',0,NULL,3,1,1,1,'\\ ','jackiecam123\r二代卡 新的'),(14824,639268006013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','rockyflanagan5z7i','rf5z7iebay@yahoo.com','Rocky Flanagan','4414 Durant St<br>Trlr 44','Deer Park','TX','UNITED STATES','77536','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 15:45:44',0,NULL,3,1,1,1,'\\  ','rockyflanagan5z7i'),(14825,786782358011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',135.99,'eastar4','greerda-half','dgreer@nextcorp.com','David Greer','6425 Suncrest Ct','Fort Worth','TX','UNITED STATES','76180-8065','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 16:32:31',0,NULL,3,1,1,1,'\\ ','greerda-half'),(14826,639289473013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','nvdsp','vds2000@xs4all.nl','N.J. van der Spek','Leliestraat 1','Rozenburg','','NETHERLANDS','3181 WR','06-48133446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 16:42:21',0,NULL,3,1,2,1,'\\  ','nvdsp'),(14827,872279747012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','goodlad55','ebay.tomj@googlemail.com','Tom James','59 Yewdale Road','Harrogate','North Yorkshire','UNITED KINGDOM','HG2 8NE','07823558477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 16:57:57',0,NULL,3,1,3,1,'RA117763146CN\r ','goodlad55\rWLAP002'),(14828,872401745012,220459525292,'Acer Aspire 5550 5551 5552 Bluetooth Module 2.0 +cable',1,'BTAC2006',9.88,'eastar4','71scoutii','alanchatterton@hotmail.com','Alan Chatterton','5170 N Pinegrove Dr','Coeur D Alene','ID','UNITED STATES','83815-8984','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 17:29:54',0,NULL,3,1,1,1,'\\  ','71scoutii\racer 4pin1.25 15cm '),(14829,872412524012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','leopoldrudolf','strnad@ah-wohnen.at','leopold strnad','schlettergasse 3 / 2 /5','wien','','AUSTRIA','1220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 17:51:23',0,NULL,3,1,2,1,'\\  ','leopoldrudolf\racer 8pin1.00 8cm '),(14830,587607565004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','kab652002','kab652002@yahoo.com','olusegun martins','20803 mansfield bay ln','richmond','TX','UNITED STATES','77407-2677','(281) 685-6360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-29 17:57:36',0,NULL,3,1,1,1,'\\  ','kab652002'),(14831,786837759011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','bzwier','bonkiebib@gmail.com','B Zwier','Franklinstraat 24','HILVERSUM','','NETHERLANDS','1221HB','06-47406866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 18:12:10',0,NULL,3,1,2,1,'\\  ','bzwier'),(14832,786851626011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',25.64,'eastar4','suadict','sunaddict@mail.ru','Konstantin Ivanov','pr. Kosmonavtov, 20/35, 132','Korolev','Moscow Region','RUSSIAN FEDERATION','141080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 18:39:13',0,NULL,3,1,2,1,'\\ ','suadict\rProLee24K超轻碳纤骨长柄伞  \r黑色的'),(14833,639342997013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','tom_horvat','tomhorvat90@gmail.com','Tom Horvat','Pekel 26i','Maribor','','SLOVENIA','2000','+38631532373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 18:54:47',0,NULL,3,1,2,1,'\\  ','tom_horvat'),(14834,786889412011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','maragopoulos13','maragopoulos@yahoo.com','Dimitris Maragkopoulos','Leoforos Alexandras 170<br>Bank of Cyprus - CRM Department','Athens','','GREECE','11521','00306974048937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 19:54:47',0,NULL,3,1,3,1,'RA117760578CN\r ','maragopoulos13\rGLSG001*2'),(14835,786924565011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','kam-sing','buetty@vr-web.de','Büttner Reiner','Obere Gasse 39','Aura an der Saale','','GERMANY','97717','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 21:02:18',0,NULL,3,1,3,1,'RA117763101CN\r ','kam-sing\rGLSG001'),(14836,787280322002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','draconic28','lccsilva@hotmail.com','LUIZ CARLOS DA SILVA','11891, RUE LACHAPELLE APP501','MONTREAL','QC','CANADA','H4J 2M2','(514) 748-2745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 21:10:05',0,NULL,3,1,3,1,'RA117763251CN ','draconic28\rBR3D002'),(14837,872532479012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','qw28695','quitawilliams90@hotmail.com','Quita Williams','8 Middle Stoke, Limpley Stoke','Bath','Avon','UNITED KINGDOM','BA2 7GE','01225723182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 21:21:15',0,NULL,3,1,2,1,'\\  ','qw28695'),(14838,639402898013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','381951','gwks24@atlanticbb.net','Wanda Gummo','174 Deep Water Ln','Tyrone','PA','UNITED STATES','16686','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 21:44:25',0,NULL,3,1,1,1,'\\  ','381951\r兼容型3D眼镜 通用型'),(14839,872542843012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','bjohnson80aa','bjohnson80a@hotmail.com','Barry Johnson','6 Southern Place','Swanley','Kent','UNITED KINGDOM','BR8 7BY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 21:47:07',0,NULL,3,1,3,1,'RA117763129CN\r ','bjohnson80aa\rHSJA010\r英标'),(14840,786952610011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','tennisfan20','gegenzocker@freenet.de','René Herzog','Winterbergstrasse 97','Dresden','','GERMANY','01237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 22:08:54',0,NULL,3,1,2,1,'\\  ','tennisfan20\r欧标'),(14841,639409868013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','bartholomew22','lisacasey@shaw.ca','Jason Casey','11009 237B Street','Maple Ridge','BC','CANADA','V2W1E7','(604) 466-0080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 22:09:57',0,NULL,3,1,2,1,'、 ','bartholomew22\rUM00001\r换发成Transparent rain Umbrella \r粉红色的'),(14842,587697396004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','jonmitch8ot5','jonmitch@charter.net','john klan','2707 Friar Tuck Ct SW','decatur','AL','UNITED STATES','35603-4429','(256) 318-4940','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-29 22:34:22',0,NULL,3,1,1,1,'\\  ','jonmitch8ot5'),(14843,786979389011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tljohnson162726','tljohnson2726@yahoo.com','Tiffany Johnson','19 Iris Ln','Ringgold','GA','UNITED STATES','30736-7682','(706) 935-8946','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 23:31:16',0,NULL,3,1,1,1,'\\  ','tljohnson162726'),(14844,639430801013,230624049713,'NIB Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',35.5,'eastar4','eugenerava','ergean_58@yahoo.com.au','Eugen Ablamit','U 1/24 Vincent Crescent<br>Noble Park','Melbourne','Victoria','AUSTRALIA','3174','0395585759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 23:37:25',0,NULL,3,1,2,1,'\\  ','eugenerava\r银色的'),(14845,786984074011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','faubourg1201','ckantrow1@cox.net','Charles Kantrow Jr','7762 Jefferson Place Blvd<br>Apt B','Baton Rouge','LA','UNITED STATES','70809-8602','(225) 281-8337','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 23:47:10',0,NULL,3,1,1,1,'\\  ','faubourg1201'),(14846,872592359012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','ggandag2003','rgnoble@ymail.com','Robert Noble','537 N Lawrence St','gibson City','IL','UNITED STATES','60936-1133','(217) 898-6844','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 00:05:31',0,NULL,3,1,1,1,'\\  ','ggandag2003'),(14847,786990148011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',4,'HSJA002',79.96,'eastar4','barrychickenman','shakey_ghost@yahoo.com','Barry Parker','24457 Mary N Smith, rd','Accomac','VA','UNITED STATES','23301','(757) 710-0737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 00:08:24',0,NULL,3,1,1,1,'\\ ','barrychickenman\rHSJA002'),(14848,872619097012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','oscarinleon','oscarinleon@yahoo.es','OSCAR GUTIERREZ DEL ARBOL','C/ PRINCIPE Nº12 3ºB','TROBAJO DEL CAMINO','Castilla y León','SPAIN','24010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 01:44:01',0,NULL,3,1,2,1,'\\  ','oscarinleon'),(14849,872624555012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','glendalahoz','astridglenn@yahoo.com','GLENDA LA HOZ','2557 97th St<br>Apt 1','EAST ELMHURST','NY','UNITED STATES','11369-1603','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 02:10:09',0,NULL,3,1,1,1,'\\  ','glendalahoz'),(14850,787021237011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','dasani14','cscvmp59@hotmail.com','MARIA GOMES','139 BATTLES FARM DR','BROCKTON','MA','UNITED STATES','02301-2221','(617) 516-6947','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 02:13:19',0,NULL,3,1,1,1,'\\  ','dasani14'),(14851,787031225011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','bartm83','bartm@op.pl','Bartłomiej Matyszkowicz','Mazaniec 59','Olkusz','none','POLAND','32-300','502348459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 03:01:59',0,NULL,3,1,2,1,'\\  ','bartm83'),(14852,639472227013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','itzsonifty','baylakates@neb.rr.com','Kayla Bates Dickinson','360 Bruce Dr','Lincoln','NE','UNITED STATES','68510-2205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 03:12:21',0,NULL,3,1,1,1,'\\  ','itzsonifty'),(14853,787034132011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.12,'eastar4uk','mytran2905','nanh3101@yahoo.com','Nhat Anh Ton','67 City Road<br>Dunkirk','Nottingham','Nottinghamshire','UNITED KINGDOM','ng7 2jl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 03:14:42',0,NULL,3,1,3,1,'RA117763132CN\r ','mytran2905\r红边优联\rRELO003'),(14854,872642557012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','smallforest','bajookajo@hotmail.com','Anthony S. Kim','PO Box 15061','portland','OR','UNITED STATES','97293-5061','(503) 232-0414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 03:21:09',0,NULL,3,1,1,1,'\\  ','smallforest'),(14855,872645120012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','louiedandy','louisvillegas@hotmail.com','Luis Villegas','1534 Meister St','Piscataway','NJ','UNITED STATES','08854-1624','(732) 331-2321','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 03:31:46',0,NULL,3,1,1,1,'\\  ','louiedandy'),(14856,787038083011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','jaegerstar2000','clubs@iangregory.com','Ian Gregory','Nomura, level 24, Governor Phillip Tower<br>1 Farrer Place','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 03:39:56',0,NULL,3,1,2,1,'\\  ','jaegerstar2000'),(14857,872649430012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',2,'BTAC2000',9.98,'eastar4','lia_umar','lia_deh@yahoo.com','Lia Umar','Blok 632 Jurong West St 65 #03-284<br>Singapore','default','','SINGAPORE','640632','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 03:53:54',0,NULL,3,1,11,1,'\\ ','lia_umar\rBTAC2000'),(14858,787045624011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','devilboy95','mysterymate@comcast.net','Andy Livingston','1113 W 37th St','Baltimore','MD','UNITED STATES','21211','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 04:14:03',0,NULL,3,1,1,1,'\\  ','devilboy95'),(14859,587756231004,140626376210,'New Griffin PowerJolt Dual USB Micro Car Charger',1,'CCGR001',4.9,'cnfaner','mindy.411','mindyarvisu@gmail.com','Maria Amanda L Arvisu','234 Quail Meadows Ln','Arlington','TX','UNITED STATES','76002-3472','(817) 966-7256','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-30 04:32:22',0,NULL,5,0,18,0,NULL,'mindy.411\r已退款'),(14860,639532181013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','strawberry_pickle','cobra148gtldx@googlemail.com','Mr and Mrs Wormsley','The Coach House<br>8, Ridge Green Close','South Nutfield','Surrey','UNITED KINGDOM','RH15RW','07855278630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 09:07:16',0,NULL,3,1,2,1,'\\  ','strawberry_pickle'),(14861,787128561011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','ripponk','kellyrippon@hotmail.com','Kelly McGregor','26 McMahon Place','Wodonga','Victoria','AUSTRALIA','3690','0260597248','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 09:47:37',0,NULL,3,1,2,1,'\\  ','ripponk\r红边优联'),(14862,872802043012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','supertruckeralan','articcruiser@gmail.com','alan whitley','45 moir crescent<br>northfield','aberdeen','Aberdeen City','UNITED KINGDOM','ab167br','01224789612','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 11:38:18',0,NULL,3,1,3,1,'RA117763248CN\r ','supertruckeralan\r英标\rHSJA002'),(14863,872812614012,220711648781,'New Powchip POW-N18 MiNI  LAN ADAPTER USB 802.11N 150M',1,'WLPO001',8.99,'eastar4','loanj002','michael.loanjoe@gmail.com','Michael Loanjoe','Astersingel 44','Berkel en Rodenrijs','','NETHERLANDS','2651 PJ','+31644285821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 11:59:55',0,NULL,3,1,2,1,'\\  ','loanj002'),(14864,639602440013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','wazthe1','wrlaurie@iinet.net.au','Warren Laurie','5 Newport Way','Darch','Western Australia','AUSTRALIA','6065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 12:42:17',0,NULL,3,1,3,1,'RA117760516CN ','wazthe1\rMOSA006'),(14865,639602973013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','daywalk3r314','blueboy314@hotmail.com','Magnus Wangberg','vestvang','løken','høland','NORWAY','1960','+47464657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 12:45:05',0,NULL,3,1,3,1,'RA117763044CN\r ','daywalk3r314\rGLOT001*2\r兼容型3D眼镜 通用型'),(14866,744950969001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','lord_ant','antonyprasad77@gmail.com','Antony Prasad','75, Pasir Panjang Hill, #05-03<br>Crystal Heights','default','','SINGAPORE','118885','+6596772336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 13:26:51',0,NULL,3,1,11,1,'\\ ','lord_ant\rBR3D005'),(14867,639621163013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','donsanchezzz','pbancso@szintezis.hu','Peter Bancso','Ady E. str 33','Győr','','HUNGARY','9026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 13:33:47',0,NULL,3,1,2,1,'\\  ','donsanchezzz'),(14868,787240742011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','vcft','vincft@yahoo.com','Vincent Chin','8 Park Ave','Richmond','Victoria','AUSTRALIA','3121','0433187247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 13:37:12',0,NULL,3,1,2,1,'\\  ','vcft'),(14869,787241284011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','tecopabu','fburgos@cnio.es','Francisco Burgos Pereira','Severo Ochoa nº6 Portal 1 1ª C','Las Rozas','Madrid','SPAIN','28230','916400995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 13:41:35',0,NULL,3,1,3,1,'RA117760604CN\r ','tecopabu\rGLSG001*2'),(14870,872891967012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','amneshamm','amnesh@inbox.com','Amnesh Singh','20 Heathway<br>The Common','Southall','Middlesex','UNITED KINGDOM','UB2 5JF','07837863783','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 14:22:01',0,NULL,3,1,3,1,'RA117760476CN ','amneshamm\rOTCN004*10'),(14871,872902311012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','ferry33tdi','anthony.kingman@gmail.com','Anthony Kingman','24 Manor House<br>Flockton','Wakefield','West Yorkshire','UNITED KINGDOM','WF4 4AN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 14:38:57',0,NULL,3,1,2,1,'\\  ','ferry33tdi'),(14872,872285386012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','santaalina','pavalina@bk.ru','Alina Pavlova','st.Dvinskaya 2-199<br>Russia','Volgograd','Central\'niy rayon','RUSSIAN FEDERATION','400087','8 961 082 85 65','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 15:07:17',0,NULL,3,1,2,1,'\\  ','santaalina'),(14873,787297969011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','ipronec_com','ebay@ipronec.com','Richard Krause','Goslarsche Strasse 29','Wolfenbüttel','','GERMANY','38304','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 15:14:20',0,NULL,3,1,3,1,'RA157511242CN\r ','ipronec_com\rTRTS001*10\rRA117760649CN 发德国的一票小包 单号破损给您换单了  换单号是RA157511242CN'),(14874,872942009012,220815927904,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',2,'ANTY001',4.36,'eastar4uk','damian.fereday','dfereday@hotmail.com','Damian Fereday','7 Mill Croft','Neston','Cheshire','UNITED KINGDOM','CH64 3TN','01513367224','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 15:38:55',0,NULL,3,1,3,1,'RA117763194CN\r ','damian.fereday\rANTY001\r'),(14875,872956657012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','cloke','clokes_navy@hotmail.com','Daniel Henry','1734 Weber Ave','Chesapeake','VA','UNITED STATES','23320','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 16:02:12',0,NULL,3,1,1,1,'\\  ','cloke'),(14876,871682422012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',23.74,'eastar4','89222128848denis','89222128848@mail.ru','denis suslov','tagilstroevskaya 17-11','nijni tagil','Swerdlowskaja','RUSSIAN FEDERATION','622049','89222128848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 16:19:31',0,NULL,3,1,2,1,'\\  ','89222128848denis\r钢琴美女伞 '),(14877,872996714012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',29.88,'eastar4','c4_de','marc.gel@gmx.net','Oliver Gelhard','Göhrdestraße 1','Hannover','','GERMANY','30161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 16:43:39',0,NULL,3,1,2,1,'\\  ','c4_de'),(14878,787417001011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','geovannigavino883','geovanni.gavino@gmail.com','geovanni gavino','1802 W Wayland Rd','phoenix','AZ','UNITED STATES','85041-4616','(602) 819-1838','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 17:41:34',0,NULL,3,1,1,1,'\\  ','geovannigavino883'),(14879,787421560011,320704213221,'NEW LOGITECH NANO USB RECEIVER 4 M215  M235  M305 M310',1,'RELO003',7.12,'eastar4uk','704flower','alena99@aol.com','Ilia Alania','2005 Grande Ct<br>Apt 925','Kissimmee','FL','UNITED STATES','34743-3134','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 17:44:26',0,NULL,3,1,1,1,'\\  ','704flower\r红边优联'),(14880,787488052011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','werder_max','c.frommhold@arcor.de','Michael Bischoff','Kirchbachstr.211','Bremen','','GERMANY','28211','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 18:47:49',0,NULL,3,1,2,1,'\\  ','werder_max\r'),(14881,787510688011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','pa1cjt','c.j.taverne@gmail.com','C.J. Taverne','Schiphollaan 69','Nootdorp','','NETHERLANDS','2631MN','0652554397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:07:49',0,NULL,3,1,2,1,'\\  ','pa1cjt'),(14882,873198604012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','nismosx','homeswithpam@yahoo.com','Pamela Wilferd','3643 Calico Cove Ct.','Las Vegas','NV','UNITED STATES','89147','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 19:56:27',0,NULL,3,1,1,1,'\\  ','nismosx'),(14883,873203874012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','jetbondtke','jetbondtke@yahoo.com','Premanand Persaud','500 Palm Ave N','Saint Petersburg','FL','UNITED STATES','33703-2228','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 19:57:40',0,NULL,3,1,1,1,'\\  ','jetbondtke'),(14884,787564432011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN ALMAGRO','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','667572708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 20:10:51',0,NULL,3,1,6,1,'EE491016012CN ','latiendadelsotano\r兼容型3D眼镜 通用型'),(14885,873220216012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',2,'MOMI001',67.98,'eastar4uk','americanspirit2000','americanspirit2000@comcast.net','Joel Chinsky','1821 Dallas Ave','Royal Oak','MI','UNITED STATES','48067-3577','(248) 321-8739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 20:17:05',0,NULL,3,1,1,1,'\\  ','americanspirit2000\r美标'),(14886,787586784011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','cedric2753','shark64@ymail.com','cedric verges','res parc du chat de guisey<br>50 ch de st etienne appt a03','bayonne','Aquitaine','FRANCE','64100','0629803220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 20:43:04',0,NULL,3,1,3,1,'RA1117760595CN ','cedric2753\rGLSG001*2'),(14887,787612913011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','gincvg','gmitsui@cinci.rr.com','glenn mitsui','4022 Petersburg Rd','Burlington','KY','UNITED STATES','41005-9720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 21:26:16',0,NULL,3,1,1,1,'\\  ','gincvg'),(14888,582644647003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'cnfaner','canabec78','leblancmickael@hotmail.com','MICKAEL LEBLANC','2064 rue Notre Dame','LACHINE','QC','CANADA','H8S 2G4','(514) 916-7349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 21:34:45',0,NULL,3,1,3,1,'RA117763061CN ','canabec78\rHBPH002'),(14889,873273388012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','shmult1','shmult@mac.com','Ultan Cooke','16 wyche grove','South Croydon','London','UNITED KINGDOM','cr2 6ex','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 21:52:49',0,NULL,3,1,3,1,'RA117763115CN\r ','shmult1\rWLAP004'),(14890,639919495013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','e12voltsdac','e12voltsdacy@gmail.com','Edwin Howard','947 Clear Creek Canyon Dr','Diamond Bar','CA','UNITED STATES','91765-2308','(949) 680-0679','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 22:39:08',0,NULL,3,1,1,1,'\\  ','e12voltsdac\rHP 8pin 1.0 23cm '),(14891,787651366011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','ca_iitk','itsabhi@gmail.com','Abhishek Choudhry','Austtunsletta 24','Stavanger','Rogaland','NORWAY','4020','94845114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 22:51:50',0,NULL,3,1,3,1,'RA117763035CN\r ','ca_iitk\rGLSG001'),(14892,787662144011,320778755250,'New Motorola H350 Bluetooth Wireless Headset',1,'HSMO005',8.95,'eastar4uk','123.daren1964','daren6@aol.com','Daren Phillips','41 Wendover Road','London','London','UNITED KINGDOM','SE9 6PF','02088569649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 23:14:23',0,NULL,3,1,3,1,'RA117763177CN\r ','123.daren1964\r英标\rHSMO005'),(14893,873328456012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.89,'eastar4uk','methenyte','methenyte25@hotmail.com','Giorgos Papanikolaou','athinon kai prifti 6','Markopoulo Attikis','Athens','GREECE','19003','00306947998591','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 23:37:30',0,NULL,3,1,2,1,'\\  ','methenyte'),(14894,787675227011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',1,'NTLO001',8.54,'eastar4uk','noki33','silverblue_fr@yahoo.fr','Sèngdeuane DOUANGPHRACHANH','34 rue François Rabelais','FLOIRAC','Aquitaine','FRANCE','33270','0686922123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 23:47:26',0,NULL,3,1,2,1,'\\  ','noki33'),(14895,873333441012,220785819830,'NIB 3D Active Shutter TV Glasses 4 Mitsubishi Japan TV',1,'GLOT001',44.89,'eastar4','awp101261','awp1012@wildblue.net','allen pilkington','1440 Hess Rd','mineral wells','TX','UNITED STATES','76067-1354','(940) 654-0174','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 23:51:22',0,NULL,3,1,1,1,'\\  ','awp101261\r兼容型3D眼镜 通用型'),(14896,873353469012,220455488862,'HP Pavilion DV5 HDX X16 Bluetooth Module 2.0 EDR+cable',1,'BTHP2013',9.88,'eastar4','campoutam','campoutfl@yahoo.com','Clinton Miller','2750 Somerset Dr<br>Apt T206','Lauderdale Lakes','FL','UNITED STATES','33311-2788','(305) 796-7412','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 00:36:49',0,NULL,3,1,1,1,'\\  ','campoutam\rHP 6pin 1.0 12cm '),(14897,745381899001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','artmate999','artmate@diginerd.com','Sergey  Chernyshov','unit 3 - 24Beswick Place<br>Birkdale','Auckland','North Shore','NEW ZEALAND','0626','+6494824214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 00:53:21',0,NULL,3,1,3,1,'RA117763234CN\r ','artmate999\rBR3D005'),(14898,787120425011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','of0xo','mr_moggin@hotmail.com','Juan Antonio Garcia Gaso','Avda General Fanjul, 88. 6º A.','Madrid','Madrid','SPAIN','28044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 01:01:34',0,NULL,3,1,2,1,'\\  ','of0xo'),(14899,787708588011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','baylee_beanner','baylee_beanner@yahoo.com','joseph weaver','2427 Texas Ave<br>Apt B','Joplin','MO','UNITED STATES','64804-2447','(417) 499-1345','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'baylee_beanner'),(14900,788017834002,120762768837,'2pair Samsung SSG-3100GB 3D Active Glasses 4 PC monitor',1,'GLSG007*2',156.99,'buysia','thorpe4s','thorpe007s@aol.com','Steven Thorpe','361 Cleveland St','Freemansburg','PA','UNITED STATES','18017-7104','(484) 274-9565','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 01:30:16',0,NULL,3,1,1,1,'\\  ','thorpe4s'),(14901,872631083012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',10,'TRMX003',88.67,'eastar4','tech-gears','sales@tech-gears.com','Techoop, LLC.','2 Holly Dr','Fairfield','NJ','UNITED STATES','07004-1326','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 01:51:17',0,NULL,3,1,1,1,'\\ ','tech-gears\r再发一个New Logitech Unifying USB Receiver 4 Anywhere MX mouse \r'),(14902,639989933013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','61amn','nic@alpetros.com.au','Aco Nic Nikolic','Alpetros Design, Building A<br>First Floor, Lot 3, 6 Innovation Parkway','Birtinya','Queensland','AUSTRALIA','4575','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 02:36:38',0,NULL,3,1,3,1,'RA117760697CN\r ','61amn\rMOSA004'),(14903,787746879011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','metaol','metaol@free.fr','Paul-Arnaud MOUGIN','2b passage des Pinsons','ANNECY LE VIEUX','Rhône-Alpes','FRANCE','74940','0650016023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 03:18:05',0,NULL,3,1,2,1,'\\  ','metaol'),(14904,640000406013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','davefc','dfc0759@att.net','David Cupp','95 17th st NW','Barberton','OH','UNITED STATES','44203-7117','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 03:24:41',0,NULL,3,1,1,1,'\\  ','davefc'),(14905,640002245013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','kenneth.h26','kennethh26@gmail.com','Kenneth Heng','170 Lentor Loop<br>#03-04','default','','SINGAPORE','789099','98461987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 03:40:05',0,NULL,3,1,11,1,'\\ ','kenneth.h26\rCACN004'),(14906,873425447012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','rcranium','rcox@shaw.ca','R. Cox','#408 - 125 Aldersmith Place','Victoria','BC','CANADA','V9A 7M7','(250) 590-6122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 04:15:37',0,NULL,3,1,2,1,'\\  ','rcranium'),(14907,787760294011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','dogfoodrox','jann@microsoft.com','Jan Nelson','PO Box 195','Wauna','WA','UNITED STATES','98395-0195','(253) 225-2498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 04:18:47',0,NULL,3,1,1,1,'\\  ','dogfoodrox'),(14908,588239978004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','jkzuber','jeanninezuber@gmail.com','Jeannine Zuber','2228 Chatsworth Blvd<br>Apt 6','San Diego','CA','UNITED STATES','92106-1666','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-31 04:26:38',0,NULL,3,1,1,1,'\\  ','jkzuber'),(14909,745441595001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','huynhfamily2011','xhuynh2000@yahoo.com','Xuan Huynh','2612 University Pl NW','Washington','DC','UNITED STATES','20009-4602','(202) 462-0643','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 04:34:41',0,NULL,3,1,1,1,'\\  ','huynhfamily2011'),(14910,640012339013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','cj1651982','cjbricksmortar@yahoo.com.au','chris eslick','1/10 st anthony crt','lara','Victoria','AUSTRALIA','3212','0352826063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 04:45:32',0,NULL,3,1,3,1,'RA117760635CN\r ','cj1651982\rGLOT001*2\r兼容型3D眼镜 通用型'),(14911,787548723011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',99.8,'eastar4','sheridan2881','tinansher@btinternet.com','SHERIDAN HODGES','66<br>St Pauls Green','Sherborne','Dorset','UNITED KINGDOM','dt9 4DY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 06:43:49',0,NULL,3,1,3,1,'RA117760618CN\r ','sheridan2881\rGLSG001'),(14912,873290668012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','philipgreen99','piratez_99@hotmail.com','Matthew Green','7 Fairmont Terrace<br>North Road','Sherborne','Dorset','UNITED KINGDOM','DT9 3JS','01935814972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 07:30:59',0,NULL,3,1,2,1,'\\  ','philipgreen99'),(14913,787802104011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','poldanratih78','poldan78@yahoo.com','Aries M Nugraha','kopo Permai III Blok 35A no 10-11','bandung','West Java','INDONESIA','40227','+628112238147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 08:17:02',0,NULL,3,1,2,1,'\\  ','poldanratih78'),(14914,640042382013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','tuan_ny24','tuan_ny@yahoo.com','Huong Trang Vu','70/313 Harris St','Pyrmont, Sydney','New South Wales','AUSTRALIA','2009','61425566063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 08:34:44',0,NULL,3,1,2,1,'\\  ','tuan_ny24\rCAB-6060'),(14915,640043905013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','alishka5155','alishka5155@mail.ru','Ali Mammadov','Narimanov,Aga Nematulla,19/87 home 21','Baku','Baku','AZERBAIJAN','AZ 1052','+994552195155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 08:46:17',0,NULL,3,0,2,1,'\\  ','alishka5155\r已入库'),(15078,788649074011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','cng2008','noremac.cameron@gmail.com','Sir Cameron','104 birkirkara hill','St Julians','','MALTA','stj1144','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 07:21:41',0,NULL,3,1,2,1,'\\  ','cng2008'),(14916,873487640012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',193.99,'eastar4','aulex95','crevetteb12@hotmail.com','sandra fradette','119 meunier','matane','QC','CANADA','g4w4e2','(418) 562-6476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 09:19:24',0,NULL,3,1,6,1,'EE645650016CN','aulex95'),(14917,640054978013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','bcomedian1','bcomedian@gmail.com','Dmitriy Malyukov','Volodarskogo, 29','Penza','Penza Region','RUSSIAN FEDERATION','440000','9374340201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 09:44:27',0,NULL,3,1,2,1,'\\  ','bcomedian1'),(14918,872936342012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','micksmad','micksmad32@yahoo.co.uk','MR Michael Annels','flat 2 13 hollingbury place<br>hollingdean','Brighton','East Sussex','UNITED KINGDOM','bn1 7ge','07720951683','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 09:50:38',0,NULL,3,1,3,1,'RA117763441CN\r ','micksmad\rWLAP002'),(14919,873506885012,220785299925,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',66,'eastar4','bluebearmo','kkeverett9@msn.com','Kimberly Everett','HC 86 Box 34','Green Spring','WV','UNITED STATES','26722-9702','(304) 492-5779','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 10:19:29',0,NULL,3,1,1,1,'\\  ','bluebearmo'),(14920,787842063011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',19.98,'eastar4','penfil','pnf1@mail.ru','Anton Panfilov','ul.klinicheskaya d.32 kv.8','samara','samarskaya obl','RUSSIAN FEDERATION','443096','+7 902 375 20 40','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 10:47:21',0,NULL,3,1,2,1,'\\  ','penfil\r欧标'),(14921,873521550012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',27.78,'eastar4','fbocatti','fabaob@yahoo.com.br','Fábio Bocatti','Rua Chile 443<br>Jd. Vila Rica','Cambé','Paraná','BRAZIL','86192-510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:06:37',0,NULL,3,1,2,1,'\\ ','fbocatti'),(14922,640077458013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jordanmchugh','jordo@jordoschopshop.com','Jordo - Jordo\'s Chop Shop','Wanniassa Shops<br>SANGSTER PL','WANNIASSA','Australian Capital Territory','AUSTRALIA','2903','0262318755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:28:53',0,NULL,3,1,2,1,'\\  ','jordanmchugh'),(14923,640082974013,230653152175,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'eastar4','santinelu','cristian.vladuca@gmail.com','Cristian Vladuca','Str. Poeziei nr.14, sector 2','Bucharest','Bucharest','ROMANIA','70000','0723531675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:55:31',0,NULL,3,1,2,1,'\\  ','santinelu'),(14924,787877563011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','jwbayer','dabayers@att.net','Wendy M Bayer','138 Rose Anne Loop','Hamilton','GA','UNITED STATES','31811-6148','(706) 801-0047','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 12:38:17',0,NULL,3,1,1,1,'\\  ','jwbayer\racer 4pin1.25 15cm '),(14925,640096394013,230649292141,'New Westwood Red w/lace Boetie Sun Rain Stick unbrella',1,'UM00027',14.95,'eastar4','chatquip','borio.family@orange.fr','david borio','Quartier \"La Savoie\"<br>Chemin du Collet de Lambert','Vidauban','Provence-Alpes-Côte d\'Azur','FRANCE','83550','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 12:50:26',0,NULL,3,1,2,1,'\\  ','chatquip\r蕾丝蝴蝶结长柄伞  '),(14926,640111551013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',132.99,'eastar4','drifter632','nceagles@embarqmail.com','Gregory Shelton','116 Lindsay Dr','Archdale','NC','UNITED STATES','27263-9436','(336) 325-6926','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 13:47:52',0,NULL,3,1,1,1,'\\ ','drifter632\r兼容型3D眼镜 通用型'),(14927,0,320779152587,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',13.93,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 13:48:45',0,NULL,5,1,18,0,NULL,'wicanc'),(14928,0,230689615560,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',10.2,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 13:48:52',0,NULL,5,0,18,0,NULL,'wicanc\r'),(14929,873582524012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','cheggers7425','danny.beswick@gmail.com','Danny Beswick','28 Heys Hunt Avenue','Leyland','Lancashire','UNITED KINGDOM','pr253ul','01772433330','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 13:54:15',0,NULL,3,1,3,1,'RA117763490CN\r ','cheggers7425\rGLSG001*2'),(14930,787906751011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','chestraviola','writemila@gmail.com','Mila Banerjee','PH03, 15 Fort York Boulevard','Toronto','ON','CANADA','M5V3Y4','(416) 342-8038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 14:06:18',0,NULL,3,1,3,1,'RA117763424CN\r ','chestraviola\rHBPH002'),(14931,873587812012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','pccstech','james.casteel@pccsmail.net','James Garcellano','454 S Harvey St','Plymouth','MI','UNITED STATES','48170-1717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 14:06:47',0,NULL,3,1,1,1,'\\  ','pccstech'),(14932,787910185011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',47.49,'eastar4uk','picic4444','mirkomihaljcic@gmail.com','Mirko Mihaljcic','Stojana Jankovica 17','Banja Luka','','BOSNIA AND HERZEGOVINA','78000','+38766454199','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 14:10:22',0,NULL,3,1,3,1,'RA117763512CN\r ','picic4444\rOTES001'),(14933,873590819012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','kiki_haramis','aharamis@rogers.com','Paul Haramis','195 Napa Valley Ave','Woodbridge','ON','CANADA','L4H 1L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 14:15:52',0,NULL,3,1,2,1,'、 ','kiki_haramis'),(14934,582766119003,130592182355,'GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO031',197.94,'cnfaner','morty240t','morty_t@hotmail.com','Morten Trøan','Paul røstadsvei 45','Trondheim','','NORWAY','7039','(+47)98860815','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-31 14:25:42',0,NULL,3,1,3,1,'RA117763591CN\r ','morty240t\r一共买了六个\r欧标\rHSNO031\r旧的 \r'),(14935,787928020011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','realp887','fascination.cuisine@videotron.ca','Réal Primeau','887 rue Belmont','McMasterville','QC','CANADA','J3G 5M6','(450) 446-0060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 14:56:33',0,NULL,3,1,2,1,'\\  ','realp887'),(14936,0,320779149304,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',3.42,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:09:42',0,NULL,5,0,18,0,NULL,'wicanc'),(14937,0,220878336614,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',2.99,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:09:49',0,NULL,5,0,18,0,NULL,'wicanc'),(14938,0,220878334685,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',3.95,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:09:56',0,NULL,5,0,18,0,NULL,'wicanc'),(14939,0,230689618794,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',13.6,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:10:03',0,NULL,5,0,18,0,NULL,'wicanc'),(14940,0,220878336858,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',4.61,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:10:10',0,NULL,5,0,18,0,NULL,'wicanc'),(14941,582862268003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',46.9,'cnfaner','dg9nay','peter.baumeister@altmuehlnet.de','Peter Baumeister','Landershofen<br>Am Haselberg 11','Eichstätt','','GERMANY','85072','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-31 15:11:47',0,NULL,3,1,3,1,'RA117763375CN\r ','dg9nay\rWWOT003'),(14942,640147472013,230575688710,'Logitech Cradle L-LG7  Harmony remote 880 890 90% new',1,'CRLO002',9.9,'eastar4','maxdensity','maxdense@hotmail.com','Mark O\'Brien','13077 Martin Rd','Akron','NY','UNITED STATES','14001-9613','(716) 542-4030','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 15:53:45',0,NULL,3,1,1,1,'\\  ','maxdensity'),(14943,873634174012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','carlosrluiz','luizcarloramos@gmail.com','Luiz Carlos Ramos','RUA MARECHAL DEODORO DA FONSECA 17<br>JARDIM NOVA BELEM','FRANCISCO MORATO','São Paulo','BRAZIL','07909040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 15:57:09',0,NULL,3,1,2,1,'\\  ','carlosrluiz'),(14944,873637027012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','bockerviktor','bocker.viktor@gmail.com','Viktor Böcker','Leonardo Da Vinci köz 1.','Budapest','Budapest','HUNGARY','1082','+36705251994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 16:03:14',0,NULL,3,1,2,1,'\\  ','bockerviktor\racer 5pin1.25 6cm  '),(14945,787962731011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','ltldrmrboy1','ltldrmrboy66@hotmail.com','Gary Coyne','1405 Fernando Ave','Upland','CA','UNITED STATES','91786','(909) 981-1230','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 16:22:14',0,NULL,3,1,1,1,'\\  ','ltldrmrboy1'),(14946,787962971011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',26.99,'eastar4','bemal24','b_maheux_28@hotmail.com','Benoit Maheux-Lacroix','TeraXion<br>2716 rue Einstein','Quebec','QC','CANADA','G1P4S8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 16:22:33',0,NULL,3,1,2,1,'\\  ','bemal24'),(14947,873440599012,220785299925,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',2,'MOLO001',132,'eastar4','brazossmokehouse99','brazossmokehouse@gmail.com','cameron davis','101 E Pearl St','Granbury','TX','UNITED STATES','76048-2406','(817) 579-1393','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 16:29:54',0,NULL,3,1,1,1,'\\  ','brazossmokehouse99'),(14948,873645360012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','scdcfe','samuelychoi@gmail.com','Sam Choi','456 Jane St<br>Unit A','Fort Lee','NJ','UNITED STATES','07024-2603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 16:30:24',0,NULL,3,1,1,1,'\\  ','scdcfe'),(14949,872910072012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','nennny1','jenny.mcmasters@gmail.com','Jennifer McMasters','1415 Bryan Ave','Tustin','CA','UNITED STATES','92780-4539','(714) 669-0855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 17:19:47',0,NULL,3,1,1,1,'\\  ','nennny1'),(14950,788001050011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','ntabos','m.michailakis@tim.gr','MANOS MICHAILAKIS','NIKIS 15','EGALEO','ATHENS/ATTICA','GREECE','12244','00302105620645','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 17:44:04',0,NULL,3,1,3,1,'RA117763486CN\r ','ntabos\rGLSG001'),(14951,0,320779151263,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',4.08,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 18:02:06',0,NULL,5,0,18,0,NULL,'wicanc'),(14952,0,220878337510,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',26.92,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 18:02:13',0,NULL,5,0,18,0,NULL,'wicanc'),(14953,0,220878320869,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.28,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 18:02:20',0,NULL,5,0,18,0,NULL,'wicanc'),(14954,0,220878335460,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.63,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 18:02:26',0,NULL,5,0,18,0,NULL,'wicanc'),(14955,640200220013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','podgorelec','miha99@gmail.com','Miha Podgorelec','Krziceva 4','Ljubljana','','SLOVENIA','1000','386 40 844 121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 18:23:36',0,NULL,3,1,2,1,'\\  ','podgorelec'),(14956,640202383013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','yaevgeny','evleikin@gmail.com','Eugene Leikin','Ben Tzvi 12/3','Kiryat Motzkin','Israel','ISRAEL','26230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 18:26:57',0,NULL,3,1,3,1,'RA117763755CN\r ','yaevgeny\rGLOT001*2\r兼容型3D眼镜 通用型'),(14957,640210885013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','zf06e','i.krenzel@hotmail.com','Gafcke Evgeny','Bahnhofstrasse 64A','Haan','','GERMANY','42781','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 18:45:17',0,NULL,3,1,2,1,'\\  ','zf06e'),(14958,640211074013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',25.88,'eastar4','cruzerov','mahdal5@seznam.cz','René Mahdal','Podlesí 4937','Zlín','Czech republic','CZECH REPUBLIC','76005','+420604920010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 18:46:39',0,NULL,3,1,2,1,'\\  ','cruzerov\r一共买了两个'),(14959,788059794011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',26.99,'eastar4','avtech908','satpros@hotmail.com','Andrew Hoffman','424 US Highway 22 W<br>Satpros, Inc.','Whitehouse Station','NJ','UNITED STATES','08889','(908) 464-6164','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 19:27:54',0,NULL,3,1,1,1,'\\  ','avtech908'),(14960,788059591011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','superbratan','master_123@mail.ru','Vitaly Panchishin','135/1 Leninsky prosp., apt 759','Moscow','Moscow','RUSSIAN FEDERATION','117513','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 19:27:58',0,NULL,3,1,3,1,'RA117763526CN\r ','superbratan\rOTSO004'),(14961,873752523012,220815929125,'NEW AKE BC 188 Inside hide PCMCIA to eSATA SATA Cardbus',1,'ADAK002',8.25,'eastar4uk','lennich54','lennich@compuserve.com','Len Nicholson','73 Falcon Avenue','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH10 4AN','01314477330','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 19:28:09',0,NULL,3,1,3,1,'RA117763455CN\r ','lennich54\rADAK002'),(14962,873743927012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','anthony8927','agay598038@o2.co.uk','Anthony Gay','41 Joseph\'s Rd','Guildford','Surrey','UNITED KINGDOM','GU1 1DN','07973800854','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 19:38:59',0,NULL,3,1,3,1,'RA117763438CN\r ','anthony8927\rRELO002'),(14963,873781155012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',2,'RELO002',16.78,'eastar4uk','hammer939','stefan.steindlmueller@freenet.de','Stefan Steindlmüller','Wörnbrunner Platz 06','München','','GERMANY','81547','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 20:15:28',0,NULL,3,1,2,1,'\\  ','hammer939'),(14964,640245364013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2',109.99,'eastar4','frazame','fraza@bp.com','Fraz Anjum','3307-220 Burnhamthorpe Rd W','Mississauga','ON','CANADA','L5B 4N4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 20:18:38',0,NULL,3,1,3,1,'RA117763384CN\r ','frazame\rGLSG001*2'),(14965,873792855012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',2,'HSJA002',27.2,'eastar4uk','andream9901','englishpoohbear@hotmail.co.uk','Andrea Marsh','9 Ridsdale','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU7 6DF','07984172868','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 20:35:18',0,NULL,3,1,3,1,'RA117763557CN\r ','andream9901\rHSJA002\r英标'),(14966,582981499003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','321expressllc','andersonmaurice.ma@gmail.com','Klas Sjogren','2972 Columbia St<br>C/O Eastbiz Corp. Ste 6523','Torrance','CA','UNITED STATES','90503-3806','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-31 20:52:11',0,NULL,3,1,1,1,'\\  ','321expressllc'),(14967,640262965013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sonka-i-toto','ho-ho-ho-ho@mail.ru','Georgiy Hudadyan','belorechenskaya<br>37/2 kv 81','Moscow','','RUSSIAN FEDERATION','109451','+7 963-605-65-84','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 21:09:07',0,NULL,3,1,2,1,'\\  ','sonka-i-toto'),(14968,788125617011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','sergeiest159356','sergeiest@mail.ru','Sergei Zarikov','Ida Aalbergin tie 5f63','Helsinki','','FINLAND','00400','+358465446104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 21:37:58',0,NULL,3,1,2,1,'\\  ','sergeiest159356\r 无线蓝牙二合一'),(14969,873837571012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',6,'WLAT009',59.88,'eastar4','agwn','ndbusek@gmail.com','Naim Busek','6101 Gateway Drive','Cypress','CA','UNITED STATES','90630-4841','(714) 820-1000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-31 22:09:08',0,NULL,3,1,1,1,'\\  ','agwn'),(14970,788150675011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',18.99,'eastar4','ilona999*','black.cherry@mail.ru','Ilona Brykalova','Nekrasova, 47','Stavropol, 355005','Stavropolsky Kray, Russian Federation','RUSSIAN FEDERATION','355005','8-918-774-82-74','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 22:44:53',0,NULL,3,1,2,1,'\\  ','ilona999*\r西瓜伞 '),(14971,583019080003,130490258143,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.95,'cnfaner','ridgey','ridgey@mackay.matilda.net.au','Matilda Internet','29 Gregor Street','Mackay','Queensland','AUSTRALIA','4740','0749530711','NoPaymentFailure','CheckoutComplete','NotSelected','2011-10-31 23:17:32',0,NULL,3,1,3,1,'RA117763367CN\r ','ridgey\rWLAP009'),(14972,873899802012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','paquipoka','poka01sc@gmail.com','Pedro F Perez','107 N Bridge St<br>Ste 1088','Hidalgo','TX','UNITED STATES','78557-2612','956 843 9457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 01:05:33',0,NULL,3,1,1,1,'\\  ','paquipoka'),(14973,788197936011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','2955simonc','bonniehome@optusnet.com.au','simon cope','94 ayr street','doncaster','Victoria','AUSTRALIA','3108','0403675715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 01:22:58',0,NULL,3,1,2,1,'\\  ','2955simonc'),(14974,640337632013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','vetrad1','doctormqb@msn.com','Michael Bailey','2735 Spring View Ct','Export','PA','UNITED STATES','15632-2634','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 01:52:11',0,NULL,3,1,1,1,'\\  ','vetrad1\rHP 8pin 1.0 23cm '),(14975,640341564013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sanskrit66','korsach@mail.ru','Dmitry Korsakov','Moskovsky pr. 186-140','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','196105','7 (812) 920-5655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 02:15:03',0,NULL,3,1,2,1,'\\  ','sanskrit66'),(14976,788219352011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','denser','denser007@att.net','dennis wong','831 Hillcrest Blvd','millbrae','CA','UNITED STATES','94030-2321','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 02:47:21',0,NULL,3,1,1,1,'\\  ','denser'),(14977,788225654011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','pedroboj','bojped15@aol.com','Pedro Boj','5621 Orduna Dr','Coral Gables','FL','UNITED STATES','33146-2645','(305) 665-3888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 03:17:54',0,NULL,3,1,1,1,'\\  ','pedroboj'),(14978,873957486012,220816847725,'New Philips SHB6102 Bluetooth Stereo Headset',1,'HSPH001',45.59,'eastar4uk','supermarcello','supermarcello@hotmail.com','AVANTIS - LEGUET MARC','12 route de Saint Mathieu','GRASSE','Provence-Alpes-Côte d\'Azur','FRANCE','06130','0663923666','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 05:05:47',0,NULL,5,0,18,1,NULL,'supermarcello\rHSPH001\r款已退'),(14979,640368634013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','fphart','fhart@nc.rr.com','Frank P. Hart','2004 Jerimouth Dr','Apex','NC','UNITED STATES','27502-8620','(919) 367-0048','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 05:10:27',0,NULL,3,1,1,1,'\\  ','fphart\racer 5pin1.25 20cm '),(14980,640373051013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','ofir617','ofir219@bezeqint.net','Ofir Ron','Haoren 85','Kiriat Ata','MI','ISRAEL','28238','+972522617132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 05:56:48',0,NULL,3,1,3,1,'RA117763530CN\r ','ofir617\rBAZA001'),(14998,640431181013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','nixdns','muhortov@gmail.com','Petr Mukhortov','prospekt Slavy 55 - 249','Saint Petersburg','','RUSSIAN FEDERATION','192241','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 11:22:00',0,NULL,3,0,2,1,'、 ','nixdns\r已入库\rWLAT003\r换成IBM New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card'),(14981,586569579004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','johnq78krause','markus-krause78@unitybox.de','Krause Markus','Boystr. 10','Gladbeck','','GERMANY','45968','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-01 06:24:04',0,NULL,3,1,3,1,'RA117763543CN\r ','johnq78krause\rWWOT003+ANCN001'),(14982,788255998011,320665724977,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',39.99,'eastar4','leemk888','mklee888@gmail.com','Michael Lee','10121 Tabor St<br>Apt 37','Los Angeles','CA','UNITED STATES','90034-4939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 06:35:48',0,NULL,3,1,1,1,'\\  ','leemk888\r黑色的'),(14983,8881320130319643,111,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',0,'eastar4','pauloeczetes','eczetes@gmail.com','Paulo Roberto Eczetes','Rua Drumond, 50 - Olaria','Rio de Janeiro','RJ','BRAZIL','21031460','55-21-25642835',NULL,NULL,NULL,'2011-11-01 06:51:59',0,NULL,3,1,3,1,'RA117760666CN\r ','补货\rCACN004 '),(14984,8881320131511861,111,'NEW Ralink RT2870F Wi-Fi USB Adapter chip WIS09ABGN',1,'OTRA003',0,'eastar4','350-lt1','slammedlt1@shaw.ca','Mike DiGasparro','9238 99 Ave','Grande Prairie','AB','CANADA','T8V3X5','',NULL,NULL,NULL,'2011-11-01 07:11:51',0,NULL,3,1,2,1,'\\  ','补货 '),(14985,640384290013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','swedishgojira','andreas@svalas.net','Andreas Svalas','Bergslagsvägen 16 A','Köping','','SWEDEN','73132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 07:24:39',0,NULL,3,1,2,1,'\\  ','swedishgojira'),(14986,873986157012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','walnjak70','walnjak@hotmail.com','Jackie  Zanker','34 Tasman Hwy.','St. Helens','Tasmania','AUSTRALIA','7216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 07:51:26',0,NULL,3,1,2,1,'\\  ','walnjak70'),(14987,869588078012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',124.99,'eastar4','diegoc5r','diegoc5r@hotmail.com','Jordi Ortega Torres','Mas de la Beatona nº 14','Reus','Cataluña','SPAIN','43204','680580138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 07:52:44',0,NULL,3,1,3,1,'RA117760670CN\r ','diegoc5r\rOTSO004*2'),(14988,870733120012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','dharshana80','charles.wijesuriya@gmail.com','Charles Wijesuriya - Manager Customer Care','PC House PLC<br>451, Galle Road,','Colombo 03','','SRI LANKA','00300','0094777916972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 08:03:41',0,NULL,3,1,3,1,'RA117760944CN\r ','dharshana80'),(14989,8881320137095661,111,'New Genuine Motorola HS850 Bluetooth Headset ',1,'KSMO019',0,'cnfaner','id57chev','sandydan99@msn.com','Dan H. Crawford','2441 N. Oconner Ave','Meridian','ID','UNITED STATES','83646','(208) 888-9222',NULL,NULL,NULL,'2011-11-01 08:44:55',0,NULL,3,0,1,1,'\\ ','HSMO019 \r已入库\r补发的\rLK069540671CN '),(14990,788287541011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','jrn0','jarno.niiranen@gmail.com','Jarno Niiranen','Myhkyrinkatu 3 A 11','Kuopio','Itä-Suomi','FINLAND','70100','0405155627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 09:04:53',0,NULL,3,1,2,1,'\\  ','jrn0'),(14991,788301992011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.88,'eastar4','jmarkley385','annetoby@roadrunner.com','John Markley','385 Patten St','Marion','OH','UNITED STATES','43302-2554','(740) 387-3308','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 09:54:47',0,NULL,3,1,1,1,'\\ ','jmarkley385\rHP 8pin 1.25 25cm '),(14992,788310428011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',2,'KBNO001',147.98,'eastar4','sdurfee123','sdurfee@mchsi.com','Steve Durfee','6987 Elegance Ct','Navarre','FL','UNITED STATES','32566-8895','(850) 939-8349','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 10:34:11',0,NULL,3,1,1,1,'\\ ','sdurfee123'),(14993,788316228011,320742961625,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube',1,'PHVE001',35.99,'eastar4','simarddj','simarddj@videotron.ca','Daniel-Jean Simard','5-1101 rue St-Alexandre','Montreal','QC','CANADA','H2Z 1P8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 10:42:26',0,NULL,3,1,2,1,'\\  ','simarddj'),(14994,788317147011,320781439714,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',2,'HSSA004',31.98,'eastar4','8cheech8','c.cicciarella@gmail.com','Corrado Cicciarella','425 Kwapis Blvd','Newmarket','ON','CANADA','L3X 3H5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 10:42:28',0,NULL,3,1,2,1,'\\  ','8cheech8'),(14995,640421683013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','ccmarinersfan78','scott.weigand@bigpond.com','Scott Weigand','15 Penang St','Point Clare','New South Wales','AUSTRALIA','2250','0243237655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 10:42:36',0,NULL,3,1,3,1,'RA117760860CN\r ','ccmarinersfan78\rGLOT005'),(14996,640426758013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',2,'HBPH002',123.98,'eastar4','rfusco109321','rfusco109@comcast.net','Ron Fusco','109 Acadia Ter','Celebration','FL','UNITED STATES','34747-5003','(321) 299-3004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 11:01:32',0,NULL,3,1,1,1,'\\ ','rfusco109321'),(14997,8881320146249056,111,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',0,'cnfaner','kit0007','ntmsajith@gmail.com','sajith NTM','169,Haja Road, sainthamaruthu-10','sainthamaruthu','Kalmunai','SRI LANKA','0094','+94777596056',NULL,NULL,NULL,'2011-11-01 11:17:29',0,NULL,3,1,3,1,'RA117763645CN\r ','补货全套\rHSNO030 '),(14999,640435294013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','roni5092','tomerk12340@walla.co.il','roni katzav','rokah 11','ramat gan','IL','ISRAEL','52535','+972544425298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 11:42:41',0,NULL,3,1,3,1,'RA117762389CN ','roni5092\rBAZA001'),(15000,788347091011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','romoles','sla@mail.ru','Vyacheslav Almazov','Beloborodova, 2k2, 105','Mytishchi','Moscow','RUSSIAN FEDERATION','141006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 12:14:12',0,NULL,3,1,2,1,'\\  ','romoles'),(15001,874068168012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','bohb100173','parvis73@gmail.com','Bo Hauglund Boisen','skipper clement alle 13, 204','københavn s','standard','DENMARK','2300','004541546773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 12:14:59',0,NULL,3,1,3,1,'RA117763680CN\r ','bohb100173\rGLSG001*2'),(15002,874070882012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','plinio2012','orla-1@ig.com.br','Plinio Tadeu da Silveira','Rua Janilton de Araujo Gomes, 19 apt. 21','Campos Dos Goytacazes','Rio de Janeiro/Campos dos Goytacazes','BRAZIL','28026-790','55-22-27395243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 12:18:43',0,NULL,3,1,3,1,'RA117763702CN\r ','plinio2012\rGLOT001\r兼容型3D眼镜 通用型'),(15003,788355080011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','anetaign','phil@polskanw.com','Aneta Ignasiak','5 Luton Street','Widnes','Cheshire','UNITED KINGDOM','wa8 7sj','07983342829','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-01 12:40:13',0,NULL,3,1,3,1,'RA117760958CN\r ','anetaign\rMOAP001'),(15004,788357103011,320721866865,'New lady lace trim sun/rain stick Umbrella 6 colors',1,'UM00011',15.95,'eastar4','best_gifts_ireland','davidfarrell116@gmail.com','David Farrell','47 The Paddock<br>Old Town Mill','Celbridge','Co Kildare','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 12:43:30',0,NULL,3,1,2,1,'\\  ','best_gifts_ireland\r蕾丝花边伞 \r象牙色的'),(15005,728179845008,180741700577,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.99,'au-buy','krestnik','slepoy42@yandex.ru','Андрей Ардатов','Мичуринский пр-т д.54корп.1,кв.113','Москва','','RUSSIAN FEDERATION','119192','(916)607-3935','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 12:57:37',0,NULL,3,1,3,1,'RA117763628CN\r ','krestnik\r欧标\rHSPL013'),(15006,788363918011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','timbuktu12','timbuktu@mac.com','Alfredo Rossi','Bates 141<br>57-59 Ho Tung Mau, Level 7','Ho Chi Minh City','','VIET NAM','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:01:44',0,NULL,3,1,3,1,'RA117760927CN\r ','timbuktu12\rHBPH002'),(15007,788367148011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','seclus01','spanielka@gmail.com','Jan Spanielka','MTF STU<br>Razusova 2','Trnava','Slovakia','SLOVAK REPUBLIC','91701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:15:22',0,NULL,3,1,2,1,'\\  ','seclus01'),(15008,788368142011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','superboms','christianmarheim@hotmail.com','Christian Marheim room #217','3 soi 2 Loi Kroh Road<br>Nice Mom Lodge Guest House','Muang Chiang Mai','Chiang Mai','THAILAND','50300','00660880061560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:29:00',0,NULL,3,1,2,1,'\\  ','superboms'),(15009,788369796011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','swiftae','grinningmongoose@gmail.com','Anthony Arenas','4564 S Kingan Ave','Cudahy','WI','UNITED STATES','53110-1038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 13:38:56',0,NULL,3,1,1,1,'\\ ','swiftae'),(15010,588657074004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',2,'HSPL010',65.98,'cnfaner','flystoyer','flystoyer@aol.com','JEFFREY M STOYER','80 Pine Brook Ct','Cheshire','CT','UNITED STATES','06410-3746','(203) 982-4489','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-01 13:53:38',0,NULL,3,1,1,1,'\\ ','flystoyer'),(15011,788383327011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',10,'eastar4','vnattis','nattis@ig.com.br','Varlei Dal Rovere Nattis','Rua Mariucha, 51 apto 84 bloco B','São Paulo','São Paulo','BRAZIL','02960-030','(011) 3931-6704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:56:58',0,NULL,5,0,18,0,' ','vnattis  款已退'),(15012,788385114011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',10,'eastar4','guythompson3147','guythompson27@yahoo.com','Mr Guy P Thompson','3 Burns Road','Gillingham','Kent','UNITED KINGDOM','ME7 1NF','07764754281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 14:03:01',0,NULL,5,0,18,0,NULL,'guythompson3147  款已退'),(15013,640474915013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','rajithamd','rajithamd@gmail.com','Rajith Dissanayaka','104,<br>ST STEPHENS ROAD','HOUNSLOW','Middlesex','UNITED KINGDOM','TW3 2BN','07515808829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 14:17:34',0,NULL,3,1,2,1,'\\  ','rajithamd\rCAB-6060'),(15014,583185726003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','archpet1','archpet1@optonline.net','Matthew Archibald','1 Cottage Pl','Baldwin','NY','UNITED STATES','11510-3308','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-01 14:43:36',0,NULL,3,1,1,1,'\\ ','archpet1'),(15015,640483113013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','nemo4sydney','monika@nemo4sydney.com','dominique brack','Unterdorf 6','Noflen','','SWITZERLAND','CH-3116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 14:44:20',0,NULL,3,1,2,1,'\\  ','nemo4sydney'),(15016,640487973013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',20,'WLAP008',397.6,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+7 (905) 7183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 14:59:27',0,NULL,3,1,3,1,'RA117760887CN\r ','michel_egorov\rWLAP008'),(15017,788410192011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',5,'KBVI001',50,'eastar4','mawelljr1','nurith_ker@hotmail.com','NURITH KER','4 Greenway Plz<br>C/O Transocean','HOUSTON','TX','UNITED STATES','77046-0400','(713) 232-7017','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 15:06:47',0,NULL,5,0,18,0,NULL,'mawelljr1  款已退'),(15018,788424855011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','khodarov','hodarov@mail.ru','Konstantin Aleynikov','40 let pobedy 4-208','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454100','+79514660924','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-01 15:45:32',0,NULL,3,1,2,1,'\\  ','khodarov\r欧标\r黑色的\r旧的'),(15019,640502324013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',10.99,'eastar4','djvigo1975','peter.rajchel@gmail.com','Piotr Rajchel','Apt 3 Palmerstown Court<br>Mungret Street','Limerick','Limerick','IRELAND','L','0862003763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 15:47:37',0,NULL,3,1,2,1,'\\  ','djvigo1975'),(15020,874155029012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','mismi211','michael.schippers@gmx.de','Michael Schippers','PostNummer 34696952<br>Packetstation 104','Mainz','','GERMANY','55116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 15:47:51',0,NULL,3,1,2,1,'\\  ','mismi211\r欧标'),(15021,874158150012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',33.99,'eastar4uk','bad_benny_2001','position1@iinet.net.au','Benjamin Muller','355 Marshall Road Tarragindi','Brisbane','Queensland','AUSTRALIA','4121','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 15:53:17',0,NULL,3,1,3,1,'RA117763693CN\r ','bad_benny_2001\rMOMI001\r澳标'),(15022,639461166013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','mguima11','mohamed_guima@yahoo.com','mohamed guima','951 W Orange Grove Rd<br>Apt 80202','tucson','AZ','UNITED STATES','85704-4089','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 16:01:05',0,NULL,3,1,1,1,'\\ ','mguima11'),(15023,788433515011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','mgon4496','miguel.gonzalezj@economistas.org','Miguel González Jiménez','c/ Luis Doreste Silva, 50 7ºD','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','616400832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 16:04:37',0,NULL,3,1,3,1,'RA117763662CN\r ','mgon4496\rGLSG001'),(15024,788445396011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','matthieu0310','matthieu02_46@msn.com','Matthieu Parruitte','3. rue du soleil levant','essigny-le-grand','Picardie','FRANCE','02690','0663703176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 16:29:16',0,NULL,3,1,2,1,'\\  ','matthieu0310'),(15025,640525334013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','spiltiai','spiltiai+ebay@gmail.com','Serguei Piltiai','Q1 Labs<br>251 Bayside dr','Saint John','NB','CANADA','E2J1A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 16:54:50',0,NULL,3,1,2,1,'\\  ','spiltiai'),(15026,788472367011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',5,'KBVI001',50,'eastar4','simonskiii','simon.frampton@gmail.com','Simon Frampton','8 Beverley Street','Derby','Derbyshire','UNITED KINGDOM','DE24 8WG','07966164414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:22:15',0,NULL,5,0,18,0,NULL,'simonskiii  款已退'),(15027,788473775011,320443658204,'New Visenta Wireless keyboard Muti-point Touch pad',3,'KBVI001',30,'eastar4','simonskiii','simon.frampton@gmail.com','Simon Frampton','8 Beverley Street','Derby','Derbyshire','UNITED KINGDOM','DE24 8WG','07966164414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:25:40',0,NULL,5,0,18,0,NULL,'simonskiii 款已退'),(15028,874217325012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','grandizom','fernandes@grandizom.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:43:40',0,NULL,3,1,2,1,'\\  ','grandizom'),(15029,874219251012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','grandizomantonio','grandizom@yahoo.com.br','fernando fernandes','RUA FRANCISCA JULIA, 44 - ANIL','RIO DE JANEIRO','RJ','BRAZIL','22755-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:46:43',0,NULL,3,1,2,1,'\\  ','grandizomantonio'),(15030,783492363011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.9,'eastar4','yfnfkmzdfhfrenf','natalja-varakuta@rambler.ru','Наталья Варакута','Губкина, 18 е, 44','Белгород','','RUSSIAN FEDERATION','308012','(920) 5563180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:47:30',0,NULL,3,1,2,1,'\\  ','yfnfkmzdfhfrenf\r欧标'),(15031,583246236003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',10,'WLAT007',138.5,'cnfaner','martinr615','mar@smartvue.com','martin renkis','305 Walnut Dr','nashville','TN','UNITED STATES','37205-2915','(615) 297-0071','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-01 17:54:44',0,NULL,3,1,1,1,'\\ ','martinr615'),(15032,874228141012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jo0418hn','johnsullivan@boone.net','linda sullivan','369 Blairmont Dr','boone','NC','UNITED STATES','28607-8714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 18:00:27',0,NULL,3,1,1,1,'\\ ','jo0418hn'),(15033,640552128013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','roman00045','romantic@ideal-access.com','Roman Tarnovetsky','320 Academy St.<br>P.O. Box 159','Newburgh,','ON','CANADA','K0K 2S0','(613) 378-0084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 18:09:02',0,NULL,3,1,3,1,'RA117763631CN\r ','roman00045\rGPS0004'),(15034,874258291012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','archy13arturs','archy_klava@msn.com','arturs klava','34a abbotstown road','dublin','Dublin','IRELAND','11','0851395882','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 18:47:04',0,NULL,3,1,3,1,'RA117763676CN\r ','archy13arturs\rGLSG001*2'),(15035,640574988013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',49.99,'eastar4','jpoole22','james.poole@bjss.co.uk','James Poole','Flat 1, Triangle House<br>6 Church Street','Crystal Palace','London','UNITED KINGDOM','SE19 2ET','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 18:57:00',0,NULL,3,1,3,1,'RA117763659CN\r ','jpoole22\rRCLO004'),(15036,640588431013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','moviedgr8ysq','moviedgr@aol.com','Douglas G. Ryan','6912 Toledo Ave N','Brooklyn Center','MN','UNITED STATES','55429-1261','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 19:27:52',0,NULL,3,1,1,1,'\\ ','moviedgr8ysq\r兼容型3D眼镜 通用型'),(15037,874313798012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','pairpointer','pinkshirt@mac.com','Douglas Bancroft','73 Fisher Way','Somerset','MA','UNITED STATES','02726-5902','(508) 974-2055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 20:11:46',0,NULL,3,1,1,1,'\\ ','pairpointer'),(15038,640316101013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ricardonegrete','ricardo.a.negrete@gmail.com','Ricardo Negrete','Luz Saviñon 1915<br>Col. Narvarte Del. Benito Juarez','Mexico D.F.','DF','MEXICO','03020','+52 55 1 55020312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:13:42',0,NULL,3,1,2,1,'\\  ','ricardonegrete'),(15039,874330357012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',35,'eastar4','adlporg','adlp@adlp.org','Antoine Delaporte','10, rue du Parc','Schwindratzheim','Alsace','FRANCE','67270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:40:13',0,NULL,3,1,2,1,'\\  ','adlporg'),(15040,583313648003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','krymes','threes5518@aol.com','edward johnson','530 alameda del prado #211','novato','ca','UNITED STATES','94949','(707) 291-1362','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-01 20:42:26',0,NULL,3,1,1,1,'\\ ','krymes'),(15041,640622066013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','ir0nranger','dale.koziol@gmail.com','Dale Koziol','602 Sterling St S','Maplewood','MN','UNITED STATES','55119-6783','(612) 889-5170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 20:49:39',0,NULL,3,1,1,1,'\\ ','ir0nranger'),(15042,788592085011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','28evo','ev0lutionvi@hotmail.com','Grant Marshall','58 Victoria Ave','Gladstone','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:53:01',0,NULL,3,1,2,1,'\\  ','28evo'),(15043,788593980011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',73.98,'eastar4','starkberra','perwe100@gmail.com','Per Westlund','Hjortvägen 10','Boden','Norrbotten','SWEDEN','96168','070-8387871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:53:40',0,NULL,3,1,3,1,'RA117760935CN\r ','starkberra\rWWSI004'),(15044,583319406003,130592183438,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','eddwalton','edd.walton@sky.com','EDWARD WALTON','22 DARBY CRESCENT','SUNBURY ON THAMES','Middlesex','UNITED KINGDOM','TW165LA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:59:12',0,NULL,3,1,3,1,'RA117763614CN\r ','eddwalton\rHBPH001\r'),(15045,640635484013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','jharp1n1','harpinent@gmail.com','Harpin Enterprises','4650 N Rainbow Blvd<br>Apt 2166','Las Vegas','NV','UNITED STATES','89108-5763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 21:24:42',0,NULL,3,1,1,1,'\\ ','jharp1n1'),(15046,874366404012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','amishs69','amit_s47@hotmail.com','Amish B.Sheth','31, Briardene close, East Herrington','Sunderland','Tyne and Wear','UNITED KINGDOM','SR3 3RU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 21:45:12',0,NULL,3,1,2,1,'\\  ','amishs69'),(15047,788625052011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','rafa.marrone','rafa.costa.marrone@gmail.com','Rafael Marrone','Rua Prof. Teodosio M Wanderley<br>195 ap 202','Florianopolis','Santa Catarina','BRAZIL','88054-520','554884466680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 21:54:43',0,NULL,3,1,2,1,'\\  ','rafa.marrone'),(15048,640639887013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','solucionesit','paypal@solucionesit.com.uy','Pablo Vainer','1942 NE 148th St<br># 6374','North Miami','FL','UNITED STATES','33181-1161','(305) 781-1546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 22:12:38',0,NULL,3,1,1,1,'\\ ','solucionesit'),(15049,640659141013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','jj13bay','lopez_pernas@yahoo.es','Juan Jose Lopez Pernas','Penas Corbeiras,6<br>Vilalba','Lugo','Galicia','SPAIN','27800','619734812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 22:40:14',0,NULL,3,1,2,1,'\\  ','jj13bay'),(15050,640661664013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',18.99,'eastar4','liuyingchun1961','suncoatproducts@yahoo.com','ying','386 LAIRD ROAD, UNIT 3<br>HANLON BUSINESS PARK','GUELPH','ON','CANADA','N1G3X7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 22:49:37',0,NULL,3,1,2,1,'\\  ','liuyingchun1961\r草莓伞 '),(15051,788588723011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','whinygrrl','whinygrrl@gmail.com','Evan Hawrysh','44 Hampel Crescent','Stittsville','ON','CANADA','K2S1E4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 23:16:55',0,NULL,3,1,2,1,'\\  ','whinygrrl'),(15052,788657070011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','pwil3523','peterwillsphotos@btinternet.com','Peter Wills','1/1, 4 Robertsons Gait','Paisley','Renfrewshire','UNITED KINGDOM','PA26DN','01418490902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-01 23:17:24',0,NULL,3,1,3,1,'RA117760913CN\r ','pwil3523\rMOAP001'),(15053,788663749011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',32,'eastar4uk','robertbelle','bellefontaine@t-online.de','Robert Bellefontaine','Böckinger Straße 6','Heilbronn','','GERMANY','74078','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 23:35:50',0,NULL,3,1,3,1,'RA117760873CN\r ','robertbelle\rWWOT003'),(15054,788672096011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','eyvindm1','eyvindm1@yahoo.com','Eyvind  Mejia','16229 SW 44 Terrace','Miami','FL','UNITED STATES','33185','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 00:02:09',0,NULL,3,1,1,1,'\\ ','eyvindm1'),(15055,874430564012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',21.84,'eastar4','peachness05','peachness05@hotmail.com','Bridget Peach','7 Doolan St<br>Invermay','Launceston','Tasmania','AUSTRALIA','7248','0407771042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 00:18:28',0,NULL,3,1,2,1,'\\  ','peachness05\r向日葵长柄伞  '),(15056,588856804004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','cat3rn','logjam3@gmail.com','William T Roney III','1402 Purple Sage Dr','GARDNERVILLE','NV','UNITED STATES','89460','(775) 790-2847','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 00:24:00',0,NULL,3,1,1,1,'\\ ','cat3rn'),(15057,0,220878337806,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',2.25,'eastar4','shera802','angelah802@yahoo.com','Daniel Hughes','6218 Creekhaven Ct','Sachse','TX','UNITED STATES','75048-5659','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 00:27:20',0,NULL,3,1,1,1,'\\ ','shera802'),(15058,788683614011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','weekend777','wilbanksd@yahoo.com','Dan Wilbanks','2 Ocean Drive','Quinns Rocks','Western Australia','AUSTRALIA','6030','0430232273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 00:38:48',0,NULL,3,1,2,1,'\\  ','weekend777'),(15059,788688315011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','amccox','adam@amccox.com','Adam Cox','24  Ascot  St','Ascot','Queensland','AUSTRALIA','4007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 00:53:41',0,NULL,3,1,2,1,'\\  ','amccox'),(15060,788690812011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','llvago','llvago23@aol.com','lisa l vago','900 laurel springs dr<br>apt 909','durham','NC','UNITED STATES','27713-6727','(301) 639-8440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 01:01:48',0,NULL,3,1,1,1,'\\ ','llvago'),(15061,640697995013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','jomafer86','i42mafej@uco.es','Jose Antonio Martínez Fernández','C/ Escritora Gloria Fuertes 4<br>Escalera 1 3º1','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14004','626854979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 01:17:38',0,NULL,3,1,2,1,'\\  ','jomafer86'),(15062,788699325011,320465511535,'NEW Logitech Harmony Remote USB Cable 670 680 720 900',1,'CALO001',3.87,'eastar4','ecooper0077','ecooper007@comcast.net','proctor cooper','1822 wasp st','north charleston','SC','UNITED STATES','29405-4046','(843) 554-1144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 01:31:40',0,NULL,3,1,1,1,'\\ ','ecooper0077'),(15063,874468995012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','tigerr854','jdemps@rochester.rr.com','James H Demps 111','854 Genesee Park Blvd','Rochester','NY','UNITED STATES','14619-2144','(585) 490-3943','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 02:10:22',0,NULL,3,1,1,1,'\\ ','tigerr854'),(15064,583398431003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','csan8553','csanchez@jgoodman.net','Cynthia Sanchez','14544 Central Ave<br># 42','Chino','CA','UNITED STATES','91710-9508','(909) 438-2626','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 02:28:17',0,NULL,3,1,1,1,'\\ ','csan8553'),(15065,788720165011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','jdb124','dan@barbourconcrete.com','James D Barbour','424 NE Parks Edge Dr','Lees Summit','MO','UNITED STATES','64064','(816) 373-4493','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 02:40:01',0,NULL,3,1,1,1,'\\ ','jdb124'),(15066,640723995013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',2,'WLIN010',38.98,'eastar4','phuonglho','pho@carolina.rr.com','Phuong Ho','6317 Goldenblush Cir','Charlotte','NC','UNITED STATES','28269-5100','(704) 402-4227','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 03:04:36',0,NULL,3,1,1,1,'\\ ','phuonglho'),(15067,874487236012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.98,'eastar4','wombyfat06','kemawayland@westnet.com.au','Marion Wayland','PO Box 268','Venus Bay','Victoria','AUSTRALIA','3956','0356637724','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 03:10:31',0,NULL,3,1,2,1,'\\  ','wombyfat06\r澳标'),(15068,640727659013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','drookie101','parin.tjandra@gmail.com','Parin Tjandra','38 Telfer Road','Castle Hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 03:24:33',0,NULL,3,1,2,1,'\\  ','drookie101'),(15069,788250905011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','mzjmo20','nccu_0688@yahoo.com','Niesha  Winfield','200 Seven Oaks Rd.<br>Apt. 10 B','Durham','NC','UNITED STATES','27704-3483','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 04:20:05',0,NULL,3,1,1,1,'\\ ','mzjmo20'),(15070,640738028013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','booniejnr','kbf1967@hotmail.com','Brook Fredericks','12 Herston Drive','Mildura','Victoria','AUSTRALIA','3500','0350233717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 04:29:59',0,NULL,3,1,6,1,'EE645650047CN ','booniejnr\r兼容型3D眼镜 通用型'),(15071,874509937012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',145.99,'eastar4','gepetotei','gepetotei@hotmail.com','Carl  Lacroix','1360 Ave Dieppe','Alma','QC','CANADA','g8c1j3','(418) 669-8392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 04:46:32',0,NULL,3,1,3,1,'RA117763720CN\r ','gepetotei\rGLSG001*3'),(15072,788745934011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','raknas_md','raknasmd@hotmail.com','Anitha Selvaraj','16414 SW Estuary Dr<br>Apt 207','Beaverton','OR','UNITED STATES','97006-7921','(503) 803-8203','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'raknas_md'),(15073,746376045001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','perfect_solution2u','lky_wilson@hotmail.com','Wilson Lim','Block 477 Sembawang Drive<br>#06-403 Singapore','default','','SINGAPORE','750477','+6581578115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 05:21:58',0,NULL,3,1,11,1,'RA117763747CN\r ','perfect_solution2u\rBR3D005'),(15074,640745969013,230637270059,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.98,'eastar4','best_digital','gabriel.itu@gmail.com','gabi itu','3355 Pierre Thomas Hurteau','St-Hubert','QC','CANADA','j3y8p3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 05:32:48',0,NULL,3,1,2,1,'\\  ','best_digital\r红边优联'),(15075,874519080012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','alcindosilva','alcindojosesilva@gmail.com','Alcindo Silva','Rua de Medancelhe, 694 4C','Porto','Rio Tinto','PORTUGAL','4435-330','00351914026196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 05:41:46',0,NULL,3,1,2,1,'\\  ','alcindosilva'),(15076,8881320216659386,111,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',0,'eastar4','alex_eri','oddghost@mail.ru','Aleksandr Stepanov','TEC-3<br>h.1, p.49','Ivanovo','Ivanovskaya','RUSSIAN FEDERATION','153042','+79158327039',NULL,NULL,NULL,'2011-11-02 06:50:59',0,NULL,3,1,3,1,'RA117763733CN\r ','WWSI005 \r补发的'),(15077,640753551013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','2011alexhenry','william.dehle@bigpond.com','William Dehle','PO Box 2054<br>Redcliffe North','Redcliffe','Queensland','AUSTRALIA','4020','61409984590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 06:39:39',0,NULL,3,1,6,1,'EE645650033CN ','2011alexhenry\r兼容型3D眼镜 通用型'),(15079,788778750011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',3,'OTCN002',11.94,'eastar4','aganim','aganim@netvision.net.il','Eliezer Aroshas','18/1 Troompeldor St.','Beer Sheva','','ISRAEL','84217','054-4320365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 07:51:13',0,NULL,3,1,2,1,'\\  ','aganim'),(15080,788279308011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','h2kristo','kristoherzmann@gmail.com','Kristo Herzmann','Sütiste tee 43-22','Tallinn','Harjumaa','ESTONIA','13414','+37258374124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 08:49:19',0,NULL,3,1,2,1,'\\  ','h2kristo'),(15081,788791405011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','alexandali','alex@alexgeller.com','Alex Geller','88, High Wych Road','Sawbridgeworth','Hertfordshire','UNITED KINGDOM','CM210HQ','01279723677','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-02 08:45:40',0,NULL,3,1,3,1,'RA117763716CN ','\rMOAP001'),(15082,788805777011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',32,'eastar4uk','fishsoupisgood','ebay@madingley.org','James McKenzie','Citrix R<br>101 Science Park','CAMBRIDGE','Cambridgeshire','UNITED KINGDOM','CB4 0FY','01223225900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-02 09:41:49',0,NULL,3,1,3,1,'RA117763795CN ','fishsoupisgood\rWWOT003'),(15083,874568563012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','palzii2020','mpalmieri14@optusnet.com.au','matthew palmieri','14 Delview Dr','Jan Juc','Victoria','AUSTRALIA','3228','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 09:31:04',0,NULL,3,1,3,1,'RA117763804CN ','palzii2020\rOTSO004*2'),(15084,640789604013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','haszczak75','piotr.madera@gmail.com','Piotr Madera','Mojmirovo Namesti 22c','Brno','','CZECH REPUBLIC','61200','+420 774 536 984','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 10:27:24',0,NULL,3,1,2,1,'\\  ','haszczak75\rCAB-6060'),(15146,8881320296382738,111,'DELL1510',2,'WLDE002',0,'eastar4','nethobby4fun','anc.cruz@sapo.pt','Antonio Cruz','R. das Almas, Lote 7<br>Póvoa do Paço','Cacia','Aveiro','PORTUGAL','3800-552','(351) 234315358',NULL,NULL,NULL,'2011-11-03 04:59:42',0,NULL,3,1,2,1,'\\  ','补发的 '),(15085,788825603011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','mr_antunes','hilarioantunes@gmail.com','Hilario Antunes','Rua Dona Leonor, 42/13<br>Bairro Rio Branco','Porto Alegre','RS','BRAZIL','90420-180','55 51 32261712','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 10:53:43',0,NULL,3,1,2,1,'\\  ','mr_antunes'),(15086,788825645011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.49,'eastar4','mrljrice-au','ebay@ljrice.com','Leon Rice','15 Peebles Cross','Sinagra','Western Australia','AUSTRALIA','6065','0404648943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 10:54:01',0,NULL,3,1,2,1,'\\  ','mrljrice-au'),(15087,8881320232059894,111,'补发ear hook',1,'',0,'cnfaner','filmworks1','andy@cameraspeed.com','Andrew Schefter','8250 NE 12th Ave','Miami','FL','UNITED STATES','33138-4148','(305) 704-7139',NULL,NULL,NULL,'2011-11-02 11:07:39',0,NULL,3,0,1,1,'\\  ','LK005792350CN '),(15088,874599182012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','blitzuser','cdhassell@gmail.com','C. Daniel Hassell','4285 Beaufort Hunt Dr','Harrisburg','PA','UNITED STATES','17110-3706','(717) 545-6905','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 11:11:21',0,NULL,3,1,1,1,'\\  ','blitzuser\racer 8pin1.00 8cm '),(15089,788704094011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','sweepn','sweepn27@aol.com','Sherryl Ackerman','19 Iroquois Dr','Galloway','NJ','UNITED STATES','08205-3705','(609) 338-8589','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 11:19:45',0,NULL,3,1,1,1,'\\  ','sweepn'),(15090,788846075011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','cobisaar','saaryagur@gmail.com','Cobi Saar','Kibbutz Yagur','Yagur','','ISRAEL','30065','+972-50-6270733','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 11:59:02',0,NULL,3,1,3,1,'RA117760975CN ','cobisaar\rHBPH002'),(15091,788856567011,320402075713,'HP DV9000 DV9000Z DV9100 Bluetooth Module 2.0 EDR+cable',2,'BTHP2011',19.76,'eastar4','smoothboy-2','bsmith12@ix.netcom.com','Barry Smith','818 Woodsdale Ct.','Wildwood','MO','UNITED STATES','63011','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 12:32:59',0,NULL,3,1,1,1,'\\  ','smoothboy-2\rHP 8pin 1.25 25cm '),(15092,874624920012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','needithaveitdean','deanand90@hotmail.com','Dean Anderson','37 Trentham Road','Tylden','Victoria','AUSTRALIA','3444','0354248081','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'needithaveitdean'),(15093,640823124013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','prokey123','cynic_ryan@hotmail.com','Ryan Greenwood and Olivia Li','6/20 Ross Street','Northcote','Victoria','AUSTRALIA','3070','0413343015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 12:55:08',0,NULL,3,1,2,1,'\\  ','prokey123\rCAB-6060'),(15094,788866084011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','sezayi31','sezayidemir@gmail.com','sezayi demir','isdemir a.s. proje müdürlügü<br>karayilan/iskenderun','hatay','hatay','TURKEY','31319','+905359265001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 13:01:48',0,NULL,3,1,3,1,'RA117760992CN ','sezayi31\r欧标\rHSSE011'),(15095,788870362011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mikhael1989','choogoon89@mail.ru','Mikhail Kopitin','Ugnoe Kychino dom 1, kv. 92.','Zheleznodorozhnyi','Moscow region','RUSSIAN FEDERATION','143981','8(916)019-7785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 13:13:47',0,NULL,3,1,2,1,'\\  ','mikhael1989'),(15096,788880893011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','rgigio','rogerio.girardi@me.com','Rogerio Gimenez Girardi','Rua Conselheiro Brotero, 1378 apto 62','Sao Paulo','Sao Paulo','BRAZIL','01232010','5511 38258947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 13:42:26',0,NULL,3,1,2,1,'\\  ','rgigio'),(15097,640835826013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',23.74,'eastar4','catyvarga','caty_varga@yahoo.com','Kata Varga','Akadémia utca 6.','Budapest','','HUNGARY','1054','3630-433-5486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 13:42:38',0,NULL,3,1,2,1,'、 ','catyvarga\r钢琴美女伞 \r紫色的'),(15098,874657293012,220759427766,'New SAMSUNG WMN1000C ULTRA SLIM WALLMOUNT LED TV  60-65',1,'MOSA003',37.99,'eastar4uk','molisko','marekczekalla@yahoo.de','Marek Czekala','Fasananweg 23','Nortrup','','GERMANY','49638','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 13:54:15',0,NULL,3,1,3,1,'RA117763923CN ','molisko\rMOSA003'),(15099,788897584011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.39,'eastar4','robertsrskudra','rskudra@inbox.lv','Roberts Skudra','Austrinu cels 21<br>Lielvarde','Latvia','Lielvarde','LATVIA','LV5070','+37126130415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:28:07',0,NULL,3,1,2,1,'\\  ','robertsrskudra\rHP 8pin 1.0 3cm'),(15100,874670753012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','dalos_t_123','dalos_t@freemail.hu','Tibor Dalos','Dózsa György út 84/b.','Budapest','Pest','HUNGARY','1068','+3612358904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 14:30:23',0,NULL,3,1,3,1,'RA117763985CN ','dalos_t_123\rGLOT005'),(15101,788900583011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','jmarag','jmarag8@hotmail.com','john maragoudakis','riga ferraiou 35','glyfada','athens','GREECE','16674','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 14:37:58',0,NULL,3,1,2,1,'\\  ','jmarag'),(15102,640854892013,230653182950,'3D Active shutter PC glasses for Geforce Nvidia series',1,'GLOT002+GLOT003',80,'eastar4','marcramo2011','leomlr@ig.com.br','marcelo ramos','Rua Roma, 80, AP. 102','SÃO CAETANO DO SUL','SÃO PAULO','BRAZIL','09571-220','55-11-39965378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:52:54',0,NULL,3,1,3,1,'RA117763910CN ','marcramo2011\rGLOT002+GLOT003'),(15103,640850266013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','6opmehtajib','master@pisem.net','Alexandr Tereschenko','Parkovaja str. 38/73','Dolgoprudnyjj','RU','RUSSIAN FEDERATION','141702','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:36:47',0,NULL,3,1,2,1,'\\  ','6opmehtajib'),(15104,788899177011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',2,'HSSE009',131.98,'eastar4','excnut','gregg_mcgowan@yahoo.com','Gregg McGowan','1132 Linda Mar Blvd','Pacifica','CA','UNITED STATES','94044-4243','(650) 922-0279','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 14:52:01',0,NULL,3,0,1,1,'\\ ','excnut\rHSSE010\r已入库'),(15105,589021607004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','mithusmagus','hjdavis@gmail.com','Henry Davis','8223 Arroyo Way','Stockton','CA','UNITED STATES','95209-2407','(209) 609-7714','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 15:26:54',0,NULL,3,1,1,1,'\\  ','mithusmagus'),(15106,788922712011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mazz1001','mikemazz@snet.net','Mike Mazzarella','27 East ST','Stratford','CT','UNITED STATES','06615-6520','(203) 375-6280','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 15:33:09',0,NULL,3,1,1,1,'\\  ','mazz1001'),(15107,788925475011,320394905532,'Acer Aspire 7110 7000 9300 Bluetooth Module 2.0 +cable',1,'BTAC2008',9.88,'eastar4','4540ianj','ianjpa.j@ntlworld.com','Ian Johnson','17 Eastway','Epsom','Surrey','UNITED KINGDOM','KT19 8SG','01372801983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 15:40:19',0,NULL,3,1,2,1,'\\ ','4540ianj\racer 4pin1.25 18cm'),(15108,788927925011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','jejaka1412','jejaka@seznam.cz','Jan Jemelka','Stupkova<br>1c','Olomouc','','CZECH REPUBLIC','77900','0042605883133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 15:46:16',0,NULL,3,1,2,1,'\\  ','jejaka1412'),(15109,640893754013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','lrus2255','russelllatasha@gmail.com','latasha russell','321 twin hill ct','austell','GA','UNITED STATES','30168-7729','(678) 251-7984','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 16:57:22',0,NULL,3,1,1,1,'\\  ','lrus2255'),(15110,788962889011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','gililustig','gililustig@gmail.com','Gili Lustrig','Golomb 30','Givatayim','Mr','ISRAEL','53463','972542522333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:05:53',0,NULL,3,1,2,1,'\\  ','gililustig'),(15111,788970454011,320774352320,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT003',10.99,'eastar4uk','curlybob92','johngc92@gmail.com','John Connolly','17 Sandwich Road<br>Eccles','Manchester','Lancashire','UNITED KINGDOM','M30 9DX','01617077025','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-02 17:20:11',0,NULL,3,1,3,1,'RA117760989CN\r ','curlybob92\rWLAT003'),(15112,589054734004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','jadewolfjr','noidjr@hotmail.com','Jacob Hernandez','4084 Oakmont Dr','Shingle Springs','CA','UNITED STATES','95682','(916) 869-0184','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 17:21:45',0,NULL,3,1,1,1,'\\  ','jadewolfjr\r红边优联'),(15113,640903559013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','p1ton','cowboy777@mail.ru','Denis Atroshchenko','st. Chertanovskaya, h. 41/2, fl. 52','Moskva','Gorod Moskva','RUSSIAN FEDERATION','117519','+7-915-400-3251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:23:52',0,NULL,3,1,2,1,'\\  ','p1ton'),(15114,788975288011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','lnguyenh','mercedes_sl_class@yahoo.com','Long D. Nguyen','7527 Camp Alger Ave','Falls Church','VA','UNITED STATES','22042','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 17:32:26',0,NULL,3,1,1,1,'\\  ','lnguyenh\r银色的\r默认的'),(15115,640899384013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','dnsm1979','dnsm@rambler.ru','Денис Монахов','ул.Феофанова, 2-18','Верхняя Пышма','Свердловская область','RUSSIAN FEDERATION','624090','9024415967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:50:16',0,NULL,3,1,2,1,'\\  ','dnsm1979'),(15116,788989791011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',95.97,'eastar4uk','ttronvik','tronvik@yahoo.no','Stein Eddy Tronvik','dønnumskia 313','Eidsvoll','','NORWAY','2080','41642030','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 17:58:11',0,NULL,3,1,3,1,'RA117764005CN ','ttronvik\rGLSG001'),(15117,640917862013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','limesdave','magd@t-online.hu','David Hatar','Budaorsi ut 231<br>Mag ICS Holding zRt','Budapest','Budapest','HUNGARY','1112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 18:00:36',0,NULL,3,1,2,1,'\\  ','limesdave'),(15118,640933487013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ihikaronator','karonator@yandex.ru','Karen Grigoryan','Krylytskie holmy st. 39.1/133','Moscow','RU','RUSSIAN FEDERATION','121614','+7 916 267 25 46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 18:38:39',0,NULL,3,1,2,1,'\\  ','ihikaronator'),(15119,789026727011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','sbg072','madokianos@yahoo.com','Michael Dokianos','474 48th Ave<br>Apt 32L','Long Island City','NY','UNITED STATES','11109-5717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 19:04:32',0,NULL,3,1,1,1,'\\  ','sbg072'),(15120,580547190003,130531519721,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',15.49,'cnfaner','gamy32','gfb3000@yahoo.com','gamaliel flores bermudez','HC 66 Box 9835','fajardo','PR','UNITED STATES','00738-9291','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 19:39:22',0,NULL,3,1,1,1,'\\  ','gamy32'),(15121,789052672011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','tyberiusz55','tyberiusz5@poczta.onet.pl','Tyberiusz Szubierajski','Nadma, ul. Pólko 46','Marki 4','mazowieckie','POLAND','05261','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:47:51',0,NULL,3,1,3,1,'RA117763937CN\r ','tyberiusz55\rGLOT001\r兼容型3D眼镜 通用型'),(15122,789055879011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','clementbp84','napolalf@aim.com','clement broca','6087 hamilton','montreal','QC','CANADA','h4e3c2','(514) 762-4678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:53:22',0,NULL,3,1,3,1,'RA117763968CN ','clementbp84\rHBPH002'),(15123,789057312011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',3,'WLAT003',44.7,'eastar4','clown86','szam.david@gmail.com','Dávid Szám','Torbágy street 11','Budapest','','HUNGARY','1118','+36204377675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:55:44',0,NULL,3,1,3,1,'RA184573842CN\r ','clown86\rWLAT003'),(15124,874888917012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','jbpasta','jbarber001@aol.com','Julian Barber','Timbers<br>74a Hiltingbury Rd','Eastleigh','Hampshire','UNITED KINGDOM','SO53 5SQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-02 21:12:41',0,NULL,3,1,3,1,'RA117763971CN\r ','jbpasta\rHSPL013\r英标'),(15125,874899416012,220772606508,'New Apple Macbook Air Software Reinstall Driver',1,'UDAP002',31.99,'eastar4uk','swissbidpower','itunes37@hotmail.com','Hans Kossig','Liegnitzer Weg 8','Weil am Rhein','','GERMANY','DE-79576','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 21:30:50',0,NULL,3,1,3,1,'RA117760961CN\r ','swissbidpower\rUDAP002'),(15126,874513688012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','cookiemonster330','maximebelzile@gmail.com','Maxime Belzile','302-2975 Ave Maricourt','Quebec','QC','CANADA','G1W4T8','(418) 948-1612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 21:43:42',0,NULL,3,1,2,1,'\\ ','cookiemonster330'),(15127,583673672003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','vimahdz8138','hernandez7709@bellsouth.net','Victor Hernandez','19340 NW 67th Pl','Hialeah','FL','UNITED STATES','33015-2475','(786) 262-6018','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 21:54:16',0,NULL,3,1,1,1,'\\  ','vimahdz8138'),(15128,787708588011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','baylee_beanner','baylee_beanner@yahoo.com','joseph weaver','2427 Texas Ave<br>Apt B','Joplin','MO','UNITED STATES','64804-2447','(417) 499-1345','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 22:19:24',0,NULL,3,1,1,1,'\\  ','baylee_beanner'),(15129,874923224012,220501842033,'2.1 Acer Aspire 6920 6920G Bluetooth Module  EDR+cable',1,'BTAC2117',12.39,'eastar4','marviana','marviana@ig.com.br','MARCELO VIANA B. LOPES','AV ALPHAVILLE N825 ALPHAVILLE I<br>COND GARDENVILLE EDF HORTENCIA APT 702','SALVADOR','BAHIA','BRAZIL','41701015','555 7133471710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 22:25:18',0,NULL,3,1,2,1,'\\  ','marviana\racer 8pin0.8 16cm'),(15130,589171211004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','tlcl2007','nisreah@yahoo.com','Tasha Cacciotti','9306 Foxcroft Ave','Clinton','MD','UNITED STATES','20735-3025','(301) 806-0803','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 22:44:08',0,NULL,3,1,1,1,'\\  ','tlcl2007'),(15131,641032403013,230654800799,'NIB Philips Sonicare HX6942 FlexCare+ Sonic Toothbrush',1,'HBPH005',124,'eastar4','pigamber','abespaloff@gmail.com','Anton Bespalov','Sharikopodshipnikovskaya ul., d. 2, kv. 66','Moscow','','RUSSIAN FEDERATION','115088','(926) 9191309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 23:15:10',0,NULL,3,1,3,1,'RA117763999CN ','pigamber\rHBPH005'),(15132,583700089003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',53.8,'cnfaner','bigtimepimp','bleepdat@yahoo.com','Community Bible Church - ANDREA JOHNSON','324 W 40TH ST','SAN BERNARDINO','CA','UNITED STATES','92407-3554','(503) 309-6418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 23:39:01',0,NULL,3,1,1,1,'\\  ','bigtimepimp'),(15133,589187497004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',32.99,'cnfaner','tektonos4444','rbrekke@prairieinet.net','Randy Brekke','58570 Lincoln Hwy','Nevada','IA','UNITED STATES','50201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 23:52:21',0,NULL,3,1,1,1,'\\  ','tektonos4444'),(15134,789166729011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','mujitaba32','olajuwon_68@yahoo.com','olajuwon kako','45 DOIRE BEAG<br>OFF ORIEL ROAD','COLLON','Louth','IRELAND','','0419819689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 00:01:38',0,NULL,3,1,2,1,'\\  ','mujitaba32'),(15135,874964202012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','darrin1719','doorwaytome@gmail.com','Darrin Posey','1719 Woodside Dr','camden','SC','UNITED STATES','29020-3146','(803) 272-8329','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 00:04:22',0,NULL,3,1,1,1,'\\  ','darrin1719\racer 6pin1.25 23cm'),(15136,789181548011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','loveland-fanman','fanman@lpbroadband.net','Clay Scott','2720 Glade Rd','Loveland','CO','UNITED STATES','80538-9228','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 00:54:26',0,NULL,3,1,1,1,'\\  ','loveland-fanman'),(15137,729296619008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','baher.samir','baher_samir@hotmail.com','Baher Kest','1 / 55 Turner St.','Blacktown','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-03 01:59:48',0,NULL,3,1,3,1,'RA117761009CN\r ','baher.samir\rHSPL005\r澳标'),(15138,789201263011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','beyondhelpin','gmmath2323@yahoo.com','gary w mathis','13053 Wells Dr','sperry','OK','UNITED STATES','74073-4872','(918) 695-4224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 02:06:00',0,NULL,3,1,1,1,'\\  ','beyondhelpin'),(15139,789208312011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','hydronic_agencies','sales@hydronicagencies.com','Sean Leonard','15363 117 Avenue','Edmonton','AB','CANADA','T5M 3X4','(780) 452-8661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 02:29:27',0,NULL,3,1,3,1,'RA184573357CN ','hydronic_agencies\rGLOT001*3\r兼容型3D眼镜 通用型'),(15140,875004342012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.39,'eastar4','dainsmail-1','dainsmail-ebay@yahoo.com','David Ainsburg','9500 Jollyville Rd<br>APT 125','Austin','TX','UNITED STATES','78759-7271','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 02:33:10',0,NULL,3,1,1,1,'\\  ','dainsmail-1'),(15141,641081825013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','anhphamcit','tkpnpham@yahoo.com','Anh Pham','4050 CADWALLADER AVE','SAN JOSE','CA','UNITED STATES','95121-1109','(408) 857-1346','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 02:35:30',0,NULL,3,1,1,1,'\\  ','anhphamcit'),(15142,875023310012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','basharania','medadc@gmail.com','Meidad Cohen','Giv\'at Beit Ha Kerem 2/42','Jerusalem','Israel','ISRAEL','96268','+972544602213','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 03:22:10',0,NULL,3,1,2,1,'\\  ','basharania'),(15143,583746836003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','rob1231967','rjb.1@netzero.com','robert beatton','210 3rd ave sw','pacific','WA','UNITED STATES','98047','(253) 939-3894','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 03:47:47',0,NULL,3,1,1,1,'\\  ','rob1231967'),(15144,641096217013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',24.87,'eastar4','veilus08','ijknight@iprimus.com.au','Ian Knight','18/37 Charlotte Street Campsie','Sydney','New South Wales','AUSTRALIA','2194','0297875720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 03:55:24',0,NULL,3,1,2,1,'\\  ','veilus08'),(15145,789229845011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','havasuauctions2','brucifer@citlink.net','Bruce Miller','3031 Silver Saddle Dr','Lake Havasu City','AZ','UNITED STATES','86406-7030','(928) 505-6548','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 04:05:56',0,NULL,3,1,1,1,'\\  ','havasuauctions2'),(15147,641105104013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','splomsk','timmeh_young@optusnet.com.au','Tim Young','11 Linton Ave','Templestowe Lower','Victoria','AUSTRALIA','3107','0408002256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 04:59:55',0,NULL,3,1,2,1,'\\  ','splomsk'),(15148,8881320297545857,111,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',0,'eastar4','xavomai52','xavomai@gmail.com','Sean Meadows','767 Clinton Pkwy<br>Copiah Bank','Clinton','MS','UNITED STATES','39056-5245','(601) 924-2200',NULL,NULL,NULL,'2011-11-03 05:19:05',0,NULL,3,1,1,1,'\\  ','补发的\r只补发一个耳机 \rLK069556155CN'),(15149,789242649011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','bustumup','boricd@rogers.com','dave boric','55 seahorse ave','brampton','ON','CANADA','l6v4n7','(647) 242-2037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 05:26:02',0,NULL,3,1,3,1,'RA117762049CN ','bustumup\rGLOT001\r兼容型3D眼镜 通用型'),(15150,789249945011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.4,'eastar4','mtran31512','mtran31512@yahoo.com','M. Tran','6 Mercure Place<br>Highland Park','Gold Coast','Queensland','AUSTRALIA','4211','0756673816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 06:14:25',0,NULL,3,1,2,1,'\\  ','mtran31512\r微软的'),(15151,641116157013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','chaplinuri','chaplin.u@gmail.com','Uri Chaplianka','HaDvir str. 21/B','Hadera','','ISRAEL','38484','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 06:38:53',0,NULL,3,1,3,1,'RA117762052CN ','chaplinuri\rGLOT005'),(15152,589254390004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','www3rd','www3rd@bellsouth.net','Woody Williams','6601 skeeter branch rd','lucedale','ms','UNITED STATES','39452-6922','(228) 588-0015','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 07:09:50',0,NULL,3,1,1,1,'\\  ','www3rd\r美标\r'),(15230,875621113012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','nik.carol','nik.carol@blueyonder.co.uk','Nik White','19 Southview Road','Tunbridge Wells','Kent','UNITED KINGDOM','TN4 9BU','01892548442','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 09:37:29',0,NULL,3,1,3,1,'RA117762772CN\r ','nik.carol\rRELO002'),(15153,789270899011,320737032375,'4 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*4',216.99,'eastar4','slon_n58','slon_58@yahoo.com','Nikolaj Zhuravlyov','E\'ngel\'sa<br>D.103 KV.136','KIROV','Kirovskaya obl','RUSSIAN FEDERATION','610046','79226689375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 08:22:57',0,NULL,3,1,6,1,'EE645650055CN ','slon_n58'),(15154,641132107013,230559746497,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710 ',1,'RELO002',12.98,'eastar4','stellapaul33','stellar@live.com.au','E Madaffari','611 Nungarin Rd (BOX 302)<br>Merredin','Perth','Western Australia','AUSTRALIA','6415','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 08:34:57',0,NULL,3,1,2,1,'\\  ','stellapaul33'),(15155,641133605013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','daveghan','torksan@hotmail.com','kaan timocin','canakkale cad 7101 sok no 6 pinarbasi','izmir','Turkey','TURKEY','35060','902324795946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 08:46:24',0,NULL,3,1,2,1,'\\  ','daveghan\r'),(15156,871288051012,220815931710,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\" TV',1,'MOSA004',43.99,'eastar4uk','szaby801','szaby80@citromail.hu','Szabolcs Csapó','Kodály Z. u. 24.','Szombathely','Vas','HUNGARY','9700','(20)3691651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 08:41:09',0,NULL,3,1,3,1,'RA117762066CN ','szaby801\rMOSA004'),(15157,8881320311384135,111,'New LCD SCREEN 4 Logitech Harmony 880 890 remote contro',1,'SCLO001',0,'au-buy','pedantique','ebay@darrenchallis.com','Darren Challis, DH International Pty Ltd','Level 31, Aurora Place<br>88 Phillip Street','Sydney','New South Wales','AUSTRALIA','2000','0282110577',NULL,NULL,NULL,'2011-11-03 09:09:44',0,NULL,3,1,3,1,'RA117762070CN ','SCLO001 \r补发的'),(15158,875074828012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alesgola','ales.gola@gmail.com','Ales Gola','Bartoskova 16','Praha','','CZECH REPUBLIC','14000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 09:29:36',0,NULL,3,1,2,1,'、 ','alesgola'),(15159,875097116012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','loralinov','designarea@bezeqint.net','Larisa Hohlinov','sokolov 60','Holon','','ISRAEL','58322','972-3-6510826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 09:33:48',0,NULL,3,1,3,1,'RA117762154CN ','loralinov\rMOAP001'),(15160,789298390011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','carstenjoe','cjo@faber.dk','Carsten Johansen','Soehusvaenget 5','Odense N','','DENMARK','5270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 10:00:05',0,NULL,3,1,2,1,'、 ','carstenjoe\r银色的\r欧标'),(15161,875110690012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','mamabird2005','thehawkesnest@gmail.com','Sam Hawke','1/4 Hercule crt','Oxenford','Queensland','AUSTRALIA','4210','0414658181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 10:17:03',0,NULL,3,1,2,1,' \\ ','mamabird2005'),(15162,788888873011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','m.friston123','m.friston@btopenworld.com','Mark Friston','Gurnett House<br>Gurnett, Sutton','Macclesfield','Cheshire','UNITED KINGDOM','SK110HQ','01260253610','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-03 10:46:35',0,NULL,3,1,3,1,'RA117762313CN ','m.friston123\rHBPH002'),(15163,583803269003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','macclio','pehcon@web.de','Frank Pehse','Jägerhofstr. 167','Radebeul','','GERMANY','01445','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 10:41:41',0,NULL,3,1,3,1,'RA184573215CN ','macclio\rWLAT003'),(15164,875125680012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','ellesone350','avas05@adam.com.au','Aaron  Vassallo','16 Poplar Road , Paralowie','Adelaide','South Australia','AUSTRALIA','5108','0882500770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 11:07:36',0,NULL,3,1,3,1,'RA117762450CN ','ellesone350\rOTSO004*2'),(15165,789319444011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.9,'eastar4','jurza333','dona.j@seznam.cz','Jiří Dona','Bohumínská 443/53','Ostrava','Czech Republic','CZECH REPUBLIC','71000','737-156-785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 11:14:46',0,NULL,3,1,2,1,' \\ ','jurza333'),(15166,789325565011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','alinakisahin','alinaki1@ttmail.com','ALI NAKI SAHIN','DEMIRCILER SIT. 10.CD. NO:36<br>ZEYTINBURNU','ISTANBUL','','TURKEY','34780','2126790585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 11:35:44',0,NULL,3,1,3,1,'RA117762361CN ','alinakisahin\rHSSE011'),(15167,875171073012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','sprizyman1','sprizyman@gmail.com','Steven Spry','PO Box 10','Sutherlands','South Australia','AUSTRALIA','5374','0885811451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:19:33',0,NULL,3,1,2,1,' \\ ','sprizyman1\racer 6pin1.25 23cm'),(15168,875170232012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','strucky01','hermforster@aol.de','Forster Simon','Luitpoldstr. 4','Dinkelsbühl','','GERMANY','D-91550','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:23:40',0,NULL,3,1,2,1,' \\ ','strucky01'),(15169,875175262012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','stighenning','stighenning@fastmail.fm','stig henning thune','hasleveien 70','OSLO','OSLO','NORWAY','0575','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:30:07',0,NULL,3,1,2,1,' \\ ','stighenning'),(15170,875175701012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','strucky01','hermforster@aol.de','Forster Hermann','Schlesienstraße 1/4','Memmelsdorf-Lichteneiche','','GERMANY','96117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:33:32',0,NULL,3,1,2,1,' \\','strucky01'),(15171,789365050011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'eastar4','filipe.rrios','filipe.rr@gmail.com','Filipe Rios','Rua Comendador Pereira da Silva, N.174, AP.106<br>BROTAS - CEP:40285-040','SALVADOR','BAHIA','BRAZIL','40285-040','+55 71 9966-6662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:36:32',0,NULL,3,1,2,1,' \\ ','filipe.rrios'),(15172,743188407001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','bourbon_smith','jackcack77@gmail.com','John Smith','26 carluke crescent<br>apt:1402','toronto','ON','CANADA','m2l2j2','(416) 224-5353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 14:19:29',0,NULL,3,1,3,1,'RA117762211CN ','bourbon_smith\rBR3D004+BR3D005\r再发一个\rAlice in Wonderland New sealed 3D Blu-ray'),(15173,743381638001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','bourbon_smith','jackcack77@gmail.com','John Smith','26 carluke crescent<br>apt:1402','toronto','ON','CANADA','m2l2j2','(416) 224-5353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 14:21:40',0,NULL,3,1,17,0,NULL,'bourbon_smith'),(15174,583850840003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','larsen24000','jeanguylepage@aol.com','Lepage jean-guy','la Boutade','Auriac du Périgord','Aquitaine','FRANCE','24290','0688098157','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-03 14:22:35',0,NULL,3,1,3,1,'RA117762344CN ','larsen24000'),(15175,789385888011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','holonite','oscar.miten@gmail.com','Colin Chan','97 Montezuma Trail','Scarborough, Toronto','ON','CANADA','M1V1K4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 14:34:07',0,NULL,3,1,2,1,' \\ ','holonite'),(15176,875200920012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','plinio2012','orla-1@ig.com.br','Plinio Tadeu da Silveira','Rua Janilton de Araujo Gomes, 19 apt. 21','Campos Dos Goytacazes','Rio de Janeiro/Campos dos Goytacazes','BRAZIL','28026-790','55-22-27395243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 14:37:58',0,NULL,3,1,3,1,'RA117762446CN ','plinio2012\rGLOT001\r兼容型3D眼镜 通用型'),(15177,789391237011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','jmor4282','elros_tar_minyatur@yahoo.com.ph','Jan Kendall Mordeno','15A Lombard Ct.','Staten Island','NY','UNITED STATES','10312','(718) 317-8186','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 14:47:30',0,NULL,3,1,1,1,'、 ','jmor4282'),(15178,875202271012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','pssandhu','parmsandhuin@yahoo.com','Parm Sandhu','Unit 2<br>34 Dublin Road','Ringwood East','Victoria','AUSTRALIA','3135','0421407545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 14:41:17',0,NULL,3,1,3,1,'RA117762392CN ','pssandhu\rWWOT001'),(15179,789397418011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','hrs11','evidence15@hotmail.com','Howard Schlossberg','76 Pheasant Rdg','Niskayuna','NY','UNITED STATES','12309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 15:08:24',0,NULL,3,1,1,1,'、 ','hrs11'),(15180,746988113001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',9.99,'buysia','attilaa2005','andatti@gmail.com','attila andruska','Samorinska 19','Bratislava','','SLOVAK REPUBLIC','82106','00421 2 45527417','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-03 15:09:57',0,NULL,3,1,3,1,'RA117762335CN ','attilaa2005\rOTAM001'),(15181,746994255001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','marydiegel','diegel.mary@gmail.com','Mary Diegel','429 Paris Dr','Pottsboro','TX','UNITED STATES','75076-3989','(214) 265-0208','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 15:24:13',0,NULL,3,1,1,1,' \\ ','marydiegel'),(15182,789408445011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','kapman001','korey.pereira@gmail.com','Korey Pereira','9802 Briar Ridge Dr','Austin','TX','UNITED STATES','78748-5939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 15:37:26',0,NULL,3,1,1,1,'、 ','kapman001'),(15183,747005522001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','foggoe','mitedu@live.com','Fernando Morgado','Avenida Nações Unidas 8341 22B','São paulo','São Paulo / Pinheiros','BRAZIL','05425-070','+55 11 64345642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 15:55:47',0,NULL,3,1,3,1,'RA117762287CN ','foggoe\rBR3D008'),(15184,583879615003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',46.9,'cnfaner','giovaneh','webgeo@gmail.com','Giovane Heleno','Rua Padre Anchieta 2146','Franca','SP','BRAZIL','14400740','5516-81145391','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-03 16:06:53',0,NULL,3,1,3,1,'RA117762401CN ','giovaneh\rWWOT003'),(15185,747016812001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','goniveseli','agves@albmail.com','AGRON VESELI','LAGJA 6 RRUGA MALIQ MUCO<br>PALLATI 973 AP.6','DURRES','DURRES','ALBANIA','2001','+355-682033567','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117762300CN ','goniveseli\rBR3D004'),(15186,789434958011,320786773657,'New Genuine Motorola H670 Bluetooth Wireless Headset',3,'HSMO010',29.97,'eastar4uk','katrinchen2388','katrin.jever@gmx.de','Katrin Pannbacker','Oldenburger Str. 125','Varel','','GERMANY','26316','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 16:40:22',0,NULL,3,1,3,1,'RA117762260CN ','katrinchen2388\rHSMO010\r欧标'),(15187,789442156011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','eb5erv','eb5erv@terra.es','Jose Luis Giner Segui','Plaza De La Creueta   1º Bloque<br>Piso 1º B Edificio Marina Niza','Alfaz Del Pi   (Alicante)','Comunidad Valenciana','SPAIN','03580','607388023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 16:56:06',0,NULL,3,1,2,1,' \\ ','eb5erv'),(15188,875265964012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',23.74,'eastar4uk','play_man89','disconnnected@abv.bg','Plamen Kolarov','2 Vernon Rise','Greenford','Middlesex','UNITED KINGDOM','UB60EQ','07525741125','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-03 17:10:34',0,NULL,3,1,3,1,'RA117762358CN ','play_man89\r英标\rHSNO019'),(15189,875275892012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',2,'SCLO002',6.78,'eastar4uk','christianpx6520','christian.seille@free.fr','Christian SEILLE','Rue du Lavoir, La Borie','SAINT-ASTIER','Aquitaine','FRANCE','24110','0675537368','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 17:25:44',0,NULL,3,1,2,1,'、 ','christianpx6520'),(15190,789482719011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.39,'eastar4','shadyhtc','shadyx7@live.fr','lahut marjorie','4 Avenue Serrano','biarritz','Aquitaine','FRANCE','64200','0636793102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 18:16:59',0,NULL,3,1,2,1,' \\ ','shadyhtc'),(15191,641232264013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ivangottijr','ivangotti@gmail.com','Ivan Gotti','Rua 4 Norte Lote 5 Bloco A Ap 1006 Residencial Cedro','Taguatinga','DF','BRAZIL','71907-540','+556192830121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 18:46:13',0,NULL,3,1,2,1,' \\ ','ivangottijr'),(15192,789508342011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',93.99,'eastar4uk','2011adrianalat30','adrianalat30@hotmail.com','LUKASZ','JANUS<br>BLANOWSKA 124','ZAWIERCIE','śląskie','POLAND','42-400','501314457','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 19:16:24',0,NULL,3,1,3,1,'RA117762375CN ','2011adrianalat30\rGLSG001*3'),(15193,583953453003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',31.5,'cnfaner','patchadwell','patchadwell1@gmail.com','Pat Dulleck','9000 Foothill Blvd','Sunland','CA','UNITED STATES','91040-1747','(408) 835-5299','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 19:41:52',0,NULL,3,1,1,1,'、 ','patchadwell'),(15194,875357730012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','jberrio1','jberrio1@wanadoo.es','jacinto berrio florencio','C/ mare deu de la salut, 4-12 esc. a 3º1ª','barcelona','Cataluña','SPAIN','08024','676942069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 19:50:41',0,NULL,3,1,3,1,'RA117762273CN ','jberrio1\rOTSO002'),(15195,789535893011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','hitman4hire561','hitman4hire561@yahoo.com','stephen partin','313 Franklin St','MARIETTA','OH','UNITED STATES','45750-2720','(740) 777-1146','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 19:53:11',0,NULL,3,1,1,1,'、 ','hitman4hire561'),(15196,789536070011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','afuksenidi.lv','azatot@inbox.lv','Aleksandr Afuksenidi','Kveles str. 24-60','Riga','','LATVIA','LV-1064','+371 29526127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 19:55:07',0,NULL,3,1,2,1,' \\ ','afuksenidi.lv'),(15197,789548189011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','crass_007','spettie@hotmail.com','Steve or Tracey Pettie','146 Abbotsfiled DR','Winnipeg','MB','CANADA','R2N 3Y4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 20:12:08',0,NULL,3,1,2,1,' \\ ','crass_007'),(15198,641328383013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','mglcomputers','mdw0@lycos.co.uk','Michael Williams','32 Hepworth Road','Streatham','London','UNITED KINGDOM','SW16 5DQ','02084807852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 20:19:24',0,NULL,3,1,2,1,' \\ ','mglcomputers'),(15199,789551132011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','magdazenek2011','magdazenek@tlen.pl','ZENON SIUDAK','21 Rue PASTEUR','MALAKOF','Ile-de-France','FRANCE','92240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 20:38:21',0,NULL,3,1,2,1,' \\ ','magdazenek2011'),(15200,875390808012,220785819830,'NIB 3D Active Shutter TV Glasses 4 Mitsubishi Japan TV',2,'GLOT001',89.78,'eastar4','linebacker43glen','rcobb5@austin.rr.com','Glen Johnson','1649 Gaylord Dr','Austin','TX','UNITED STATES','78728-5712','(512) 251-9607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 20:43:33',0,NULL,3,1,1,1,'\\ ','linebacker43glen\r兼容型3D眼镜 通用型'),(15201,583980032003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','ooltewahjim','tnjohnson@aol.com','James H Johnson','5816 Mountain Pass Dr','Ooltewah','TN','UNITED STATES','37363','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 20:51:54',0,NULL,3,1,1,1,'、 ','ooltewahjim'),(15202,641352782013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',8,'CASS003',67.92,'eastar4','jez*audio','jeremypetrusma@gmail.com','Jacinta Petrusma','8 Nicole Street','Bracken Ridge','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 21:23:21',0,NULL,3,1,3,1,'RA117762295CN ','jez*audio\rCASS003'),(15203,641356924013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','jimnielsen','jim@nielsen.org','James M Nielsen','110 Alexander Rd','Junortoun','Victoria','AUSTRALIA','3551','0354493798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 21:33:27',0,NULL,3,1,2,1,' \\ ','jimnielsen'),(15204,875420927012,220815927687,'Allied Telesyn CentreCOM AUI Ethernet 10Base-T 210T',1,'TRTT002',5.99,'eastar4uk','digitaljanitor','mpoertner@gmail.com','Matthew Poertner','PO BOX 95','Martinez','CA','UNITED STATES','94553','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 21:34:34',0,NULL,3,1,1,1,' \\ ','digitaljanitor'),(15205,789594657011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','hilarrie','hilarrie15@aol.com','hilary brooks','4734 keyser ln','milton','FL','UNITED STATES','32571-1511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 21:42:24',0,NULL,3,1,1,1,'、 ','hilarrie'),(15206,747176917001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','nagahi2','ngaray@irargi.org','Gobierno Vasco·Irargi - Natxo Garay','Palacio Rekalde - Aptdo.220','Bergara','País Vasco','SPAIN','20570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 21:43:38',0,NULL,3,1,3,1,'RA117762327CN ','nagahi2\rBR3D008'),(15207,789599462011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',16.54,'eastar4uk','r1vr11','per.astrand@gmail.com','Per Åstrand','Bengt Lidforss väg 23','LUND','','SWEDEN','22465','+46709794697','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 21:52:23',0,NULL,3,1,2,1,' \\ ','r1vr11'),(15208,641374229013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','curtbuthman','curt@besociable.me','Curt Buthman','BeSociable.me<br>17808 Malden St','Northridge','CA','UNITED STATES','91325-2610','(213) 342-1044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-03 22:24:23',0,NULL,3,1,1,1,' \\ ','curtbuthman'),(15209,641379389013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','artem.bielozierov','bielozierov@gmail.com','Artem Bielozierov','chemin Jean-Baptist Vandelle, 1<br>case postale 230','Versoix','','SWITZERLAND','1290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 22:41:06',0,NULL,3,1,2,1,' \\ ','artem.bielozierov\r华硕 8pin 1.0 6cm '),(15210,789640106011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','flewid1','nathan.phillips@veypor.com','Nathan Phillips','16 Varley Drive','Kanata','ON','CANADA','K2K1E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 23:33:50',0,NULL,3,1,2,1,' \\ ','flewid1'),(15211,875476066012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',15.14,'eastar4','belmont64','techbelmont@carolina.rr.com','David Joseph Harper','424 Hawley Ave','Belmont','NC','UNITED STATES','28012-3212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 00:09:20',0,NULL,3,1,1,1,' \\ ','belmont64\r一共买了两个\rAUI Transceiver  MX20T'),(15212,789660763011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',123.98,'eastar4','petiakuralesov','valgolovko@gmail.com','Valentyn Golovko','2548 Sandhill Way','Santa Clara','CA','UNITED STATES','95051-1244','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 00:42:54',0,NULL,3,1,1,1,'、 ','petiakuralesov'),(15213,589531266004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',32.99,'cnfaner','shywizardd05','nrjzrcreations@comcast.net','Deborah Mazingo','82 County Road 727','Corinth','MS','UNITED STATES','38834-8712','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 00:59:34',0,NULL,3,1,1,1,'、 ','shywizardd05'),(15214,875504659012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','jlus1747','jodirluscomb@hotmail.com','Jodi Luscomb','15201 Larson Loss Rd','Buckley','WA','UNITED STATES','98321-8502','(360) 897-0308','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 01:03:02',0,NULL,3,1,6,1,'EE645650064CN ','jlus1747\r兼容型3D眼镜 通用型'),(15215,789667714011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','k511820','handsomebooy@hotmail.com','Jiwon Cho','7620 201st St SW<br>Unit B','Edmonds','WA','UNITED STATES','98026-6836','(206) 327-4775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 01:06:32',0,NULL,3,1,1,1,'、 ','k511820\r'),(15216,789686978011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',2,'RELO002',25.94,'eastar4','silver315','silver315hp@hotmail.com','eli benyamin','4711 197th St<br>2nd Floor','flushing','NY','UNITED STATES','11358','(917) 577-1697','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 02:15:20',0,NULL,3,1,1,1,'、 ','silver315'),(15217,747270210001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','proletariat51','crwoodfl@hbci.com','Carlton Robinson','529 E Sanborn St','Winona','MN','UNITED STATES','55987-4362','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 02:42:18',0,NULL,3,1,1,1,'、 ','proletariat51'),(15218,789695423011,320693989145,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',17.99,'eastar4','regisranger','jesserstephens@gmail.com','Jesse Stephens','5986 S Helena St','Centennial','CO','UNITED STATES','80016-1036','(720) 306-1010','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 02:49:12',0,NULL,3,1,1,1,'、 ','regisranger'),(15219,584074453003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',31.5,'cnfaner','rc.iphone','rc4gnet@gmail.com','Mark Roberts','PO Box 105','Klawock','AK','UNITED STATES','99925-0105','(907) 755-2200','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 03:33:35',0,NULL,3,1,1,1,'、 ','rc.iphone'),(15220,789713339011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',135.99,'eastar4','pookie94002','drwlegal@yahoo.com','Danny Wiley','910 S Geneva St','Denver','CO','UNITED STATES','80247-1934','(720) 490-1694','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 04:12:57',0,NULL,3,1,1,1,'、 ','pookie94002'),(15221,875564962012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','vuthtemsiri','theeravuth@yahoo.com','Theeravuth Temsiriwattanakul','56/29 Regent Home Building, Soi Sukhumvit 85<br>Sukhumvit Road, Bangchak','Phrakhanong','Bangkok','THAILAND','10260','66851137767','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:03:59',0,NULL,3,1,3,1,'RA117762429CN ','vuthtemsiri\rHBPH001'),(15222,729775618008,180730162648,'GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',32.99,'au-buy','david8igore','david8igore@hotmail.com','Dave l Smith','CSC, Level 4 Tower B<br>26 Talavera Roard','Macquarie Park','New South Wales','AUSTRALIA','2113','0439399769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 04:51:36',0,NULL,3,1,2,1,'、 ','david8igore\r澳标'),(15223,641470661013,230641224717,'Transparent Dome Rain Sun Umbrella with yellow trim',1,'UMTR001',19.99,'eastar4','neatobri','neatobs@gmail.com','Bri Sheridan','13966 Lindbergh Cir','Chico','CA','UNITED STATES','95973-8511','(530) 624-4887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 06:36:48',0,NULL,3,0,1,1,'、 ','neatobri\r黄色的\r已入库'),(15224,8881320389272738,111,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',0,'eastar4','terzilermehmet','mehmetterziler@yahoo.com','Mehmet Terziler','1775/6 no:8 d:3 çağlar apt. Karşiyaka','İzmir','İzmir','TURKEY','35530','+905069315552',NULL,NULL,NULL,'2011-11-04 06:47:52',0,NULL,3,1,2,1,'、 ','补发的 '),(15225,641475777013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','dalleria38','antoine.dallerive@gmail.com','Antoine Dalle-Rive','40 allée du Mijou','Meylan','Rhône-Alpes','FRANCE','38240','0631500951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 07:18:00',0,NULL,3,1,2,1,'、 ','dalleria38'),(15226,729811478008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','julesinnovations','julesinnovations@hotmail.com','nathan beasley','8/16 first avenue','coolum beach','Queensland','AUSTRALIA','4573','61427612550','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 08:26:50',0,NULL,3,1,3,1,'RA184573136CN\r ','julesinnovations\rGLOT001\r兼容型3D眼镜 通用型'),(15227,641487449013,230693030604,'New logitech Battery 190310-1000 2000 2001  for G7 mouse /MX revolution Mouse ',1,'BALO005',9.49,'eastar4','marcmail','sarah@intim-care.com','Marcel Michel','Siglap PO-Box 358','default','','SINGAPORE','914506','62443320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 08:42:34',0,NULL,3,1,11,1,'RA184573167CN\r ','marcmail\rBALO005'),(15228,8881320399115023,111,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4',' clusterfer78  ','clusterfer@hotmail.com','Christopher Boughton','1/93 Alexandra Ave','Toorak Gardens South','Australia','AUSTRALIA','5065 ','',NULL,NULL,NULL,'2011-11-04 09:31:55',0,NULL,3,1,2,1,'\\ ',' '),(15229,641496592013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',10.99,'eastar4','greenvalleybuyer','mikehouli@gmail.com','J Blankenship','1200 Lamb N 161','Las Vegas','NV','UNITED STATES','89110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 09:32:46',0,NULL,3,1,1,1,'\\ ','greenvalleybuyer'),(15231,8881320402179511,111,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',188.9,'eastar4uk','krisbi28','ccbezzina@gmail.com','Christopher Bezzina','Gardenia 11','Triq Tumas Fenech','Birkirkara ','MALTA','BKR2526','',NULL,NULL,NULL,'2011-11-04 10:22:59',0,NULL,3,1,6,1,'EE645650104CN  ','OTSO004*4 \r盒装的'),(15232,789789262011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','ferscaldas2010','ferscaldas@hotmail.com','MARIA LUCI SERAFIM CALDAS','RUA QUATRO DE ABRIL, 153, AP 502','MARILIA','SAO PAULO','BRAZIL','17500010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 10:30:17',0,NULL,3,1,3,1,'RA184573175CN\r ','ferscaldas2010\rHSSE011'),(15233,875640145012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',10,'HSJA006',89.9,'eastar4uk','1082claire','taxiclt@live.com','claire taylor','4a cheapside<br>wakefield','wakefeild','West Yorkshire','UNITED KINGDOM','wf1 2sd','01924364044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 10:41:35',0,NULL,3,1,3,1,'RA184573153CN\r ','1082claire\r一共买了11个\r英标'),(15234,8881320404634392,111,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',0,'cnfaner','sparscale','stevep@teacher.com','Steven Parscale','9863 W 359th St<br>Steve Parscale','Paola','KS','UNITED STATES','66071-6505','',NULL,NULL,NULL,'2011-11-04 11:03:54',0,NULL,3,1,1,1,'\\  ','黑色的 \r补货\rLK130517122CN'),(15235,875651505012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Yea Eun Hwang','111 Lincoln St<br>Apt 2A','SAVANNAH','GA','UNITED STATES','31401-3453','(503) 309-6318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 11:22:50',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15236,789824762011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','sergedanko','plumberland@gmail.com','Serguei Danko','Lunacharskogo 29-11','Tarusa','Kaluzhskaya oblast','RUSSIAN FEDERATION','249100','916-740-1122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 12:26:06',0,NULL,3,1,2,1,'\\ ','sergedanko\r欧标'),(15237,789824962011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','872hazel','harley.haze@btinternet.com','Hazel Colton','26 Berry Avenue','Breedon on the Hill','Derbyshire','UNITED KINGDOM','DE73 8AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 12:26:45',0,NULL,3,1,3,1,'RA117762888CN\r ','872hazel\rHSPL010\r英标'),(15238,789832069011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','mrjack86','amparke47@gmail.com','Alexander Parke','1 Norfolk Street<br>Forest Lake','Brisbane','Queensland','AUSTRALIA','4078','0733726509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 12:51:46',0,NULL,3,1,2,1,'\\ ','mrjack86'),(15239,875691776012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','dogcage','alel@sasktel.net','Alan Vick','109 - 325 Keevil Crescent','Saskatoon','SK','CANADA','S7N4R8','(306) 652-3441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 13:14:52',0,NULL,3,1,2,1,'\\ ','dogcage'),(15240,641557243013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','amysname','bigmc5617@comcast.net','Valerie McClure','9042 N Backer Ave','Fresno','CA','UNITED STATES','93720-4101','(559) 434-0522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 13:57:42',0,NULL,3,1,6,1,'EE645650095CN  ','amysname\r兼容型3D眼镜 通用型'),(15241,875709582012,220578466424,'NEW GENUINE NOKIA BH-102 BLUETOOTH HEADSET BH 102',1,'HSNO001',19.39,'eastar4','sircarobi','robi.sirca@siol.net','ROBERT SIRCA','KIDRICEVA ULICA 8','SEZANA','SLOVENIA','SLOVENIA','6210','+38641778354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 14:01:35',0,NULL,3,1,2,1,'\\ ','sircarobi\r'),(15242,875727533012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','yossigadol1','yossi-gi@bezeqint.net','yossi gelinski','ehood manor 13/18','holon','','ISRAEL','58459','0779621179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 14:45:46',0,NULL,3,1,2,1,'\\ ','yossigadol1'),(15243,789878454011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',40.99,'eastar4','rabbito87','timo.kempkens@epeach.de','Timo Kempkens','Niebuhrstrasse 92','Essen','','GERMANY','45144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 14:53:16',0,NULL,3,1,3,1,'RA117762905CN\r ','rabbito87\rWWSI005+ANCN001'),(15244,584193518003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15,'cnfaner','kohn4','tlkkkohn@peoplepc.com','Lisa L Kohn','224 Taylorstown Ridge Rd','Claysville','PA','UNITED STATES','15323-1311','(412) 296-1021','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 14:55:41',0,NULL,3,1,1,1,'\\ ','kohn4'),(15245,789866423011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','alain-b','f6fff@wanadoo.fr','CHESNOY Alain','21 rue des Templiers','Bry sur Marne','Île-de-France','FRANCE','94360','0613941319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 14:23:40',0,NULL,3,1,2,1,'\\ ','alain-b'),(15246,875747259012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','minggore','mingalo@ymail.com','Ming Kwong','4 New York Plz<br>New York Daily News Fl 6','New York','NY','UNITED STATES','10004-2413','(201) 946-6076','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 15:31:11',0,NULL,3,1,1,1,'\\ ','minggore'),(15247,789893565011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',49.9,'eastar4','palencar57','ferreira.alencar@gmail.com','PAULO ALENCAR','RUA MARANHAO 95 APT 1601','VILA VELHA','ESPIRITO SANTO','BRAZIL','29101340',' 32124630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 15:37:11',0,NULL,3,1,3,1,'RA184573034CN\r ','palencar57\rGLSG001'),(15248,875756524012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','itsikg','mrgaon@gmail.com','Itsik Gaon','17 Arlozorov st.','Yehud','--','ISRAEL','56254','972 52 6180271','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'\\ ','itsikg\r一共买了两个\r一个黑色的一个白色的'),(15249,641599587013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','kr3vusha','kr3ved@gmail.com','Viacheslav Zagorodniy','Avtozavodskaya 89a, 61','Kyiv','Kyiv','UKRAINE','04114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 16:25:59',0,NULL,3,1,2,1,'\\ ','kr3vusha'),(15250,641601309013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','gaidei777','gaid777@inbox.ru','Eduard Gaidei','1202 Avenue K<br>Apt 1J','Brooklyn','NY','UNITED STATES','11230-4214','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 16:29:06',0,NULL,3,1,1,1,'\\ ','gaidei777'),(15251,789924350011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','j.applegame','japplegame@gmail.com','Evgeny Grigoryan','Birulyovskaya, 48, corp. 1<br>apt. 113','Moscow','','RUSSIAN FEDERATION','115547','+79262800464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 16:44:44',0,NULL,3,1,3,1,'RA184573184CN\r ','j.applegame\rTRTS001*10'),(15252,638561949013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','sgilbert54','steveinsawlog@hotmail.com','Steven Gilbert','139 Sawlog Point Road<br>RR#2','Penetanguishene','ON','CANADA','L9M 1R2','(705) 549-3762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 16:44:50',0,NULL,3,1,3,1,'RA117762843CN\r ','sgilbert54\rGPS0004'),(15253,871359747012,220785299925,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',66,'eastar4','greatpasta','greatpasta@telus.net','Deanna W Barrett','5879 Somerset Avenue','Peachland','BC','CANADA','V0H1X4','(250) 767-3133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 16:44:59',0,NULL,3,1,3,1,'RA184573255CN\r ','greatpasta\rMOLO001'),(15254,584227307003,130592183438,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','svegl148','sv_gl@hotmail.com','Svetlana Krishnan','230 W 55th St<br>Apt 10F','New York','NY','UNITED STATES','10019-5210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 16:54:20',0,NULL,3,1,1,1,'\\ ','svegl148'),(15255,789931230011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','kathy7652','eemmerson5018@charter.net','Kathy Emerson','13431 SE Shawnee Rd','Prineville','OR','UNITED STATES','97754-7671','(541) 447-5607','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 16:59:29',0,NULL,3,1,1,1,'\\ ','kathy7652'),(15256,790151066002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','atec567','bigblockgp@aol.com','david j. kulik','1006 Grover Rd','east aurora','NY','UNITED STATES','14052-9715','(716) 652-8620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 17:20:06',0,NULL,3,1,1,1,'\\ ','atec567'),(15257,584246888003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','luckypow79','maryfeliciano@comcast.net','MARY FELICIANO','3098 RAFAHI WAY','HAYWARD','CA','UNITED STATES','94541','(510) 881-7741','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 18:02:55',0,NULL,3,1,1,1,'\\ ','luckypow79'),(15258,789963648011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','jake266','jankomorowski@aol.com','Jan Komorowski','19 Shafto Place','Boness','West Lothian','UNITED KINGDOM','EH51 9JE','01506510314','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 18:05:42',0,NULL,3,1,3,1,'RA184573309CN ','jake266\rGLOT001\r兼容型3D眼镜 通用型'),(15259,875836910012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','adamengland82','adsa1982@yahoo.com','Andruszewski, Adam','Wahoo West Beach<br>79-81 West Street','Brighton','East Sussex','UNITED KINGDOM','BN1 2RA','07702879790','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 18:27:24',0,NULL,3,1,3,1,'RA184573017CN\r ','adamengland82\rOTSO004*3'),(15260,584266935003,130583982440,'New Genuine Motorola H555 Bluetooth Headset track#',2,'HSMO008',23.54,'cnfaner','afzaal2010afzaal','afzaal81@yahoo.com','AFZAAL RANA','200 Woodydell ave','winnipeg','MB','CANADA','R2M2V1','(120) 496-0826 ext.: 2','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-04 19:04:08',0,NULL,3,1,3,1,'RA117762891CN\r ','afzaal2010afzaal\rHSMO008'),(15261,875880673012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',34.9,'eastar4uk','tolpuddlejodie','coxy1963@live.co.uk','jodie cox','15 tolpuddle way','liverpool','Merseyside','UNITED KINGDOM','l41yf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 19:45:14',0,NULL,3,1,3,1,'RA184573122CN\r ','tolpuddlejodie\rLGRM001'),(15262,584292682003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',26.58,'cnfaner','virginiabeachbum','robert11952@hotmail.com','Robert Paparelli','895 Garrow Rd','Newport News','VA','UNITED STATES','23608-3387','(757) 870-8865','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 20:03:38',0,NULL,3,1,1,1,'\\ ','virginiabeachbum'),(15263,589782378004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',26.12,'cnfaner','88maiz','bigalatsd@yahoo.com','Brian maizuss','546 pepper Dr','El Cajon','CA','UNITED STATES','92021-1024','(619) 729-3869','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 20:29:02',0,NULL,3,1,1,1,'\\ ','88maiz'),(15264,875916186012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','avered','avered1@optonline.net','Amos Vered','7256 Bergen Ct','Brooklyn','NY','UNITED STATES','11234','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 20:51:34',0,NULL,3,1,1,1,'\\  ','avered'),(15265,875920464012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',10,'OTIN002',350,'eastar4','williamscomm','ebay@wmscom.com','Williams Communications, Inc.','5046 Tennessee Capital Blvd','Tallahassee','FL','UNITED STATES','32303-7812','(850) 385-1121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 21:00:21',0,NULL,3,1,1,1,'、 ','williamscomm\r发2个PVDM-256K-8 \r5个PVDM-256K-12 \r然后退三个的钱'),(15266,747616709001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','kilothedog078','davejoanne133@yahoo.co.uk','David McLaughlin','133 Lisnablagh Road<br>Coleraine','Londonderry','Londonderry','UNITED KINGDOM','bt52 2hd','07851123503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 21:07:27',0,NULL,3,1,2,1,'\\ ','kilothedog078'),(15267,875935678012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',23.74,'eastar4uk','jainish91','jainish91@hotmail.com','Jainish Patel','49 Valley Drive<br>Kingsbury','London','London','UNITED KINGDOM','NW9 9NJ','02089315275','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 21:34:07',0,NULL,3,1,3,1,'RA117762769CN\r ','jainish91\rHSNO019\r英标'),(15268,875938296012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',61.99,'eastar4uk','markmurray43','markadundee@aol.com','mark murray','6 Gaitside crescent<br>Garthdee','Aberdeen','Aberdeen City','UNITED KINGDOM','ab107eg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 21:36:02',0,NULL,3,1,3,1,'RA184573082CN\r ','markmurray43\rGLSG001*2'),(15269,0,220877808811,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',7.5,'eastar4','8717cmiller','rdd3v1l@yahoo.com','chris miller','2214 5th ave','Kearney','NE','UNITED STATES','68845-5213','(308) 224-1498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 22:35:05',0,NULL,3,1,1,1,'\\ ','8717cmiller'),(15270,589833433004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',1,'HSJA004',18.98,'cnfaner','xanderwds','xanderwds@yahoo.com','Alexander McLeod','3208 Humboldt Ave S','Minneapolis','MN','UNITED STATES','55408','(612) 281-7828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 23:29:57',0,NULL,3,1,1,1,'\\ ','xanderwds\r黑色的'),(15271,790121534011,320756093124,'New Logitech Wireless laser Mouse M505 unifying receive',1,'MOLO008',34.99,'eastar4','andypgk','andypgk@hotmail.com','Valentina Wong','61 Dumond Steet','Bentley','Western Australia','AUSTRALIA','6102','014 30882714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 23:56:56',0,NULL,3,1,2,1,'、 ','andypgk\r红色的'),(15272,790122290011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',34.1,'eastar4uk','rclife','rclife@gmail.com','Kevan  F  Rimmer','1 The Garey','Lezayre','Isle of Man','UNITED KINGDOM','IM7 2EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 00:00:05',0,NULL,3,1,3,1,'RA184573241CN\r ','rclife\rMOLO005\r英标\r蓝牙版旧的'),(15273,589845601004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',24.22,'cnfaner','americastaffing','americastaffing@yahoo.com','Vanessa Medrano','5005 Crestwood Dr','Cibolo','TX','UNITED STATES','78108-2183','(830) 387-4393','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 00:28:37',0,NULL,3,1,1,1,'\\ ','americastaffing'),(15274,876016288012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','ironwolf7985','j.brownbridge@hotmail.com','Jeri-Ann Brownbridge','412-2001 Cornwall Street','Regina','SK','CANADA','s3p3x9','(306) 205-3463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 01:13:30',0,NULL,3,1,6,1,'EE645650081CN  ','ironwolf7985\r兼容型3D眼镜 通用型'),(15275,876021628012,220880695871,'New GENUINE NOKIA HS-26W BLUETOOTH HEADSET HS 26W',1,'HSNO032',15.99,'eastar4','jefferson08-10','coutinho.jo@gmail.com','Jefferson de Oliveira Coutinho','Rua: Jasmim de Porcelana 457','São Paulo','São Paulo','BRAZIL','08050-090','55 11 7492-2559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 01:25:12',0,NULL,3,1,2,1,'、 ','jefferson08-10'),(15276,641775027013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.39,'eastar4','jcpsone','jchang.ebay@gmail.com','Jed Chang','9726 43rd Ave<br># 1F','Corona','NY','UNITED STATES','11368-2141','(347) 534-8825','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 01:55:46',0,NULL,3,1,1,1,'\\ ','jcpsone'),(15277,876033602012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','banshee*dogs','kegephart@att.net','Keith e Gephart','5229 Giacomo ct nw','Canton','OH','UNITED STATES','44709-4864','(330) 493-0608','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 02:07:42',0,NULL,3,1,1,1,'\\  ','banshee*dogs\rAUI Transceiver  MX20T'),(15278,584385254003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','tomp598','tzpitts@mail.com','Tom Pitts','4 Broadmoor Way','Wylie','TX','UNITED STATES','75098-8819','(972) 442-5174','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 02:17:27',0,NULL,3,1,1,1,'\\ ','tomp598'),(15279,790163046011,320773581847,'4 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*4',103.99,'eastar4uk','stevwatto','stephenwatson73@bigpond.com','steven watson','194 hearn street','colac','Victoria','AUSTRALIA','3250','0352315605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 02:42:35',0,NULL,3,1,6,1,'EE645650121CN  ','stevwatto\r兼容型3D眼镜 通用型'),(15280,876047184012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','felicehay','felice.hayward@gmail.com','Max Hayward','Second Floor Flat<br>30 Redland Grove','Redland','Bristol','UNITED KINGDOM','BS6 6PR','07806639640','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 03:03:06',0,NULL,3,1,3,1,'RA117762865CN\r ','felicehay\rRELO002'),(15281,584397504003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'cnfaner','mking75075','mking75075@yahoo.com','Kristin L McLoughlin','1257 Hardy Pointe Dr','Evans','GA','UNITED STATES','30809-5283','(706) 496-7190','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 03:38:05',0,NULL,3,1,1,1,'\\ ','mking75075'),(15282,730217580008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.15,'au-buy','jcds1963','jchp@tadaust.org.au','John De Smet','PO BOX 1258','Toodyay','Western Australia','AUSTRALIA','6566','0895742039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-05 05:13:22',0,NULL,3,1,2,1,'\\ ','jcds1963'),(15283,876079751012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','gabrielle7536','rexsmerten@bigpond.com.au','Gabrielle Merten','8 Denman St','Hurstville','New South Wales','AUSTRALIA','2220','0295802808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 06:04:22',0,NULL,3,1,11,1,'、 ','gabrielle7536'),(15284,589892492004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.29,'cnfaner','lm92469','iamnsane69@gmail.com','Froy Andalajao','1137 Candleberry Ct','Fairfield','CA','UNITED STATES','94533-7020','(707) 427-3139','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 06:06:12',0,NULL,3,1,1,1,'\\ ','lm92469'),(15285,790202646011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',35.99,'eastar4','olgaolga1968','serko@orange.net.il','olga Kozlov','Nahshonim51/4, Nahshonim51/4<br>Nahshonim51/4','Ariel','center','ISRAEL','40700','0546771468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 06:24:56',0,NULL,3,1,2,1,'\\ ','olgaolga1968'),(15286,790213933011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','natashik2111','natashik21@gmail.com','Natalia Kopicheva','Zelenograd, 1450-34','Moscow','','RUSSIAN FEDERATION','124617','916-816-2059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 07:32:50',0,NULL,3,1,2,1,'\\ ','natashik2111\r欧标'),(15287,790230953011,320785748313,'New Logitech G7 Rechargeable Battery MX revolution mous',1,'BALO005',7.49,'eastar4uk','rieche1967','mrieche@googlemail.com','Matthias Rieche','144 Stuart Road','Market Harborough','Leicestershire','UNITED KINGDOM','LE16 9PJ','00000000000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 08:49:14',0,NULL,3,1,3,1,'RA184573224CN ','rieche1967\rBALO005'),(15288,790233053011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','xy219','markus219@gmx.de','Markus Gebhardt','Schloßstr. 14','Creußen','','GERMANY','95473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 08:55:25',0,NULL,3,1,2,1,'\\ ','xy219\r欧标'),(15289,790245294011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','reishapira','reishapira@hotmail.com','Rei Shapira','Ha-Ilanot 14','Moshav Tzofit','','ISRAEL','44925','+972+9+7483435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 09:39:06',0,NULL,3,1,2,1,'\\ ','reishapira'),(15290,790245467011,320773581847,'4 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*4',103.99,'eastar4uk','barics2011','barics.istvan@upcmail.hu','Barics Istvan','Attila street 125 1.1','Budapest','Budapest','HUNGARY','1012','+36-70.426-4892','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 09:44:16',0,NULL,3,1,6,1,'EE645650135CN  ','barics2011\r兼容型3D眼镜 通用型'),(15291,790259032011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','bobichus','elpibelopez@gmail.com','Miguel Angel lopez Alvarez','Avenida Ensanche de Vallecas Nº79 1ºC','Madrid','Madrid','SPAIN','28051','616119610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 10:26:27',0,NULL,3,1,2,1,'、 ','bobichus'),(15292,876157821012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','era7er','am75@bk.ru','Andrey Shchedrin','ul. Parizhskoi kommuny 43-12','Kansk','Krasnoyarskiy kray','RUSSIAN FEDERATION','663600','+79138399555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 11:07:10',0,NULL,3,0,2,1,'、 ','era7er\r已入库\r紫色的'),(15293,790281667011,320755995166,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.99,'eastar4','rentmach','libersky@gmail.com','Alex Libersky','Moshe Dayan str. 44/17','Tel-Aviv','','ISRAEL','67653','(972)502702244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 11:33:39',0,NULL,3,1,2,1,'\\ ','rentmach'),(15294,876177864012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','kolpakovsergey','kolpakovsi@gmail.com','Sergey Kolpakov','Kosmonavta Komarova, d. 45, korp. 1, kv. 14','Kaluga','Kaluzhskaya oblast','RUSSIAN FEDERATION','248600','(84842)727686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 11:59:54',0,NULL,3,1,2,1,'\\ ','kolpakovsergey\r欧标'),(15295,790301538011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','ufitfitness','info@ufitfitnessedinburgh.co.uk','ryan nicholas','22/9 marionville road','edinburgh','Edinburgh (City of)','UNITED KINGDOM','eh75tx','01313334512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 12:30:23',0,NULL,3,1,2,1,'\\ ','ufitfitness'),(15296,790306235011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','primoz.jereb','jerebp@ymail.com','Primož Jereb','Oblakov Vrh 33a','Spodnja Idrija','','SLOVENIA','5281','0038653742339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 12:44:23',0,NULL,3,1,3,1,'RA117762874CN\r ','primoz.jereb\rHBPH002'),(15297,790309849011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','carbak','canarbak@hotmail.com','Can Arbak','Y.Kemal Bayatli Sok. No:20/4 Nizam Mevkii<br>Buyukada','Istanbul','-','TURKEY','34970','555 424 3707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 12:53:01',0,NULL,3,1,2,1,'\\ ','carbak'),(15298,641890361013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','cyd7','chris@duvert.ca','Christian Duvert','2049 Newcarlisle Crescent','Orleans','ON','CANADA','K4A 4M6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 12:54:53',0,NULL,3,1,2,1,'\\ ','cyd7'),(15299,589969516004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','ekane66','ekane66@comcast.net','Edward Kane','19327 78th Avenue Ct E','Spanaway','WA','UNITED STATES','98387-3032','(253) 875-8402','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 13:00:41',0,NULL,3,1,1,1,'\\ ','ekane66'),(15300,641903906013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','maxsa78','olga.belshin@gmail.com','Maxim Gordover','Caspi str. , 10/4','Haifa','','ISRAEL','35015','+972522268844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 13:42:43',0,NULL,3,1,2,1,'\\  ','maxsa78\r\r韩版透明伞'),(15301,641909264013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','9276vanness','vanness@optonline.net','John Van Ness','97 Notch Rd','Oak Ridge','NJ','UNITED STATES','07438-8841','(973) 697-0384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 14:01:56',0,NULL,3,1,1,1,'\\ ','9276vanness'),(15302,790340652011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','saramakeup38','renato.kesic@si.t-com.hr','Danijela Kesic','Zatonska 25','Vodice','Croatia','CROATIA','22211','0038522442216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 14:14:55',0,NULL,3,1,2,1,'\\ ','saramakeup38\r欧标'),(15303,876248309012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','sul.vendas','sulvendas@gmail.com','Michael Pereira Silva','Rua Osório Correia 813','Cachoeirinha','Rio Grande do Sul','BRAZIL','94935-460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 14:43:33',0,NULL,3,1,2,1,'\\ ','sul.vendas'),(15304,590003488004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','mighty_mo','cj2a@roadrunner.com','Richard N. Meagley Sr.','10440 Monclova Rd','Monclova','OH','UNITED STATES','43542-9640','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 15:00:17',0,NULL,3,1,1,1,'\\ ','mighty_mo'),(15305,876287211012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',23.74,'eastar4','nyakitaa','nyakita@gmail.com','Nikolett Elek','Klapka tér 3.','Budapest','Hungary','HUNGARY','1201','+36205173671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 16:02:30',0,NULL,3,1,11,1,'、','nyakitaa\r蕾丝花边伞 \r黑色的'),(15306,641949016013,230452710244,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET HS 3W',1,'HSNO021',15.8,'eastar4','waruna6699','warunathilakarathna@yahoo.com','Waruna Thilakarathna','Commercial Bank Of PLC<br>Matale Road','Galewela','SriLanka','SRI LANKA','+94','(+94)077-3881602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 16:06:03',0,NULL,3,1,2,1,'\\ ','waruna6699'),(15307,790404116011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','pickleslovesyou','picklessaysno@hotmail.com','Laura Turner','46 Bankfield Road<br>Meir','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST3 5NH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 16:30:03',0,NULL,3,1,3,1,'RA117762928CN\r ','pickleslovesyou\rMOAP001'),(15308,790408799011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.88,'eastar4','pilot69sam','pilot_69@hotmail.com','Essam Shaaban','sjådamveien 55a','kragerø','','NORWAY','3770','45416106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 16:40:33',0,NULL,3,1,2,1,'\\ ','pilot69sam'),(15309,790423290011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','craigp0069','craig.partusch@gmail.com','Craig Partusch','3108 Woodland Cir','San Angelo','TX','UNITED STATES','76904-6124','(325) 656-9895','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 17:07:45',0,NULL,3,1,1,1,'\\ ','craigp0069'),(15310,790424023011,320753598425,'NIB Genuine Samsung 3D glasses+2010 FIFA world cup disc',1,'GLSG001*2',109.99,'eastar4','diameesh','jennifer.rorye@rogers.com','jennifer rorye','67 shadeland cres','kitchener','ON','CANADA','n2m2j1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 17:08:25',0,NULL,3,1,3,1,'RA184573860CN\r ','diameesh\rGLSG001*2\r新地址\rjennifer rorye\r130 Mountain mint cres \rKitchener. Ontario \rN2e 3R7\rCanada \r\r'),(15311,747975991001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','jim7344dog','jimjimbie@aol.com','jim birchall','15 windsor crescent','crowle scunthorpe','Lincolnshire','UNITED KINGDOM','dn17 4en','01724711946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 17:26:45',0,NULL,3,1,2,1,'\\ ','jim7344dog'),(15312,641982216013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.97,'eastar4','pishpesh.d','imortalitzik@gmail.com','itzik levy','haitzhar 7<br>apartment 4','rishon lezion','','ISRAEL','75493','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 17:32:10',0,NULL,3,1,3,1,'RA184573207CN\r ','pishpesh.d\rLGAD001'),(15313,790454470011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','edemaesims','laurie@denverpetsit.com','Laurie Simmons','3165 S Bellaire St','Denver','CO','UNITED STATES','80222-7201','(720) 495-7873','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 18:06:50',0,NULL,3,1,1,1,'\\ ','edemaesims'),(15314,584590906003,130583982440,'New Genuine Motorola H555 Bluetooth Headset track#',1,'HSMO008',11.77,'cnfaner','mamayayyo','chiich2000@hotmail.com','Roxana Chavez','PO Box 3779','San Jose','CA','UNITED STATES','95156-3779','(408) 464-3014','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 18:07:28',0,NULL,3,1,1,1,'\\ ','mamayayyo'),(15315,876361812012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.14,'eastar4uk','2011taxibob173','taxibob173@yahoo.com','robert dixon','17 streamside close','coventry','West Midlands','UNITED KINGDOM','cv59ff','02476633708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 18:10:11',0,NULL,3,1,3,1,'RA117762931CN\r ','2011taxibob173\rHSJA010\r英标'),(15316,790471053011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','patrickmhorn','hornpatrickm@gmail.com','Patrick  Horn','2581 Nicholson Rd','Sewickley','PA','UNITED STATES','15143-8502','(412) 225-8939','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 18:36:19',0,NULL,3,1,1,1,'、 ','patrickmhorn'),(15317,790467553011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','redsquirrelbrown','markuslogan4.0@hotmail.co.uk','Luke Smith','3 Barnwell Drive','Hockley','Essex','UNITED KINGDOM','ss5 4uz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 18:26:55',0,NULL,3,1,3,1,'RA117762945CN\r ','redsquirrelbrown\rMOAP001'),(15318,642016206013,230649288384,'New Replaceable Shell 4 logitech Anywhere MX Mouse M905',1,'SHLO005',15.99,'eastar4','udscalifornia','info@ultimatedesignstudios.com','Ultimate Design Studios, LLC','125 4th St','Hermosa Beach','CA','UNITED STATES','90254','(678) 267-3273','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 18:53:17',0,NULL,3,1,1,1,'、 ','udscalifornia'),(15319,790493640011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','pen.0174','kenneth@bradleykenneth.orangehome.co.uk','PENNY BRADLEY','CRAFTY FOX COTTAGE, OCCUPATION LANE<br>CHELMARSH','BRIDGNORTH','Shropshire','UNITED KINGDOM','WV16 6BE','01746862337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 19:15:13',0,NULL,3,1,2,1,'\\ ','pen.0174\r英标'),(15320,584619114003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',63.5,'cnfaner','sharron6058','sharron8@hotmail.co.uk','Sharron Alderman','15 Oxford Close<br>Bassingbourn Barracks','ROYSTON','Hertfordshire','UNITED KINGDOM','SG8 5LL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 19:21:19',0,NULL,3,1,3,1,'RA117762812CN\r ','sharron6058\rHBPH002'),(15321,790498661011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','slickw0rm','ibaibikov@yahoo.com','Ilya Baibikov','Lihachevskoe shosse, d. 20 korp. 1 kv. 26','Dolgoprudny','','RUSSIAN FEDERATION','141707','+7(916)0619061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 19:25:28',0,NULL,3,1,2,1,'\\ ','slickw0rm'),(15322,790499533011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','cincinenterprises','cincinenterprise@aol.com','Cin Cin Enterprises','1025 N Via Verano','Tucson','AZ','UNITED STATES','85710-8835','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 19:28:31',0,NULL,3,1,1,1,'\\ ','cincinenterprises'),(15323,790500414011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','pcivo','philip.crawford@btinternet.com','Philip Crawford','11 Clontylew Road','Portadown','Armagh','UNITED KINGDOM','BT62 1RE','07887538663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 19:28:41',0,NULL,3,1,3,1,'RA117762826CN\r ','pcivo\rHSPL010\r英标'),(15324,790503349011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','kainen75','hugokainen@yahoo.fr','yann boudry','27 rue de marnes','ville d\'avray','Ile-de-France','FRANCE','92410','0147504394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 19:36:30',0,NULL,3,1,3,1,'RA184573079CN\r ','kainen75\rGLSG001*2'),(15325,584633656003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'cnfaner','311ytc','kent_hutchings@hotmail.com','Kent Hutchings','713 Vivian Dr','Livermore','CA','UNITED STATES','94550','(925) 325-8312','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 20:03:38',0,NULL,3,1,1,1,'\\ ','311ytc'),(15326,876433531012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','darksmagician','darksmagician@hotmail.com','Jing Qiang Wu','6301 8th ave<br>Oneway Mobile Tech Inc','Brooklyn','NY','UNITED STATES','11220-4717','(646) 255-6570','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 20:17:33',0,NULL,3,1,1,1,'\\  ','darksmagician'),(15327,876443218012,220632531974,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'eastar4','scheidg','scheids@me.com','Tracy Scheid','3887 The Ridings','Mason','OH','UNITED STATES','45040','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 20:35:26',0,NULL,3,1,1,1,'\\ ','scheidg'),(15328,790538164011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','homerwars','homerwars@hotmail.com','RENAUD Alexandre','1 rue Anatole france','mainvilliers','Centre','FRANCE','28300','0675676219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 20:44:29',0,NULL,3,1,2,1,'\\ ','homerwars'),(15329,790546753011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','alextophi','alex_tophi@hotmail.com','Christophe ALEXANDRE','Domaine de chante-chouette<br>Hameau de Mantaille','ANNEYRON','Rhône-Alpes','FRANCE','26140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 21:02:38',0,NULL,3,1,2,1,'\\ ','alextophi'),(15330,642047486013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','gusevio','gusio@yandex.ru','Илья Гусев','ул.Зиповская 5/2 кв.75','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350010','(918)414-9300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 21:17:30',0,NULL,3,1,3,1,'RA117762830CN\r ','gusevio\rHBPH002'),(15331,748091755001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','johnyvan0_0','johnvandevander@aol.com','JOHN VANDEVANDER','7843 Americana Cir<br>Apt 203','GLEN BURNIE','MD','UNITED STATES','21060-7804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 21:22:39',0,NULL,3,1,1,1,'\\ ','johnyvan0_0'),(15332,876473508012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','$helldrake','jlshaw@nbnet.nb.ca','John Shaw','PO Box 1363','Calais','ME','UNITED STATES','04619-6363','(506) 529-8924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 21:34:55',0,NULL,3,1,1,1,'\\ ','$helldrake'),(15333,876474332012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','zoubek-2007','mzoubek@bigpond.com','Michelle Zoubek','41 Coowarra Way','Berwick','Victoria','AUSTRALIA','3806','0397056693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 21:35:59',0,NULL,3,1,3,1,'RA184573958CN\r ','zoubek-2007\rGLOT001*2\r兼容型3D眼镜 通用型'),(15334,876478611012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.2,'eastar4uk','jumpythedog45','ykhazin@gmail.com','Yuri Khazin','1109-60 Disera dr','Thornhill','ON','CANADA','L4J 9G1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 21:47:15',0,NULL,3,1,2,1,'\\ ','jumpythedog45'),(15335,790568116011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','centreck','jan.terje@mac.com','Jan Terje Rønningbakken','Risørveien 651<br>Bosvik','Risør','Aust-Agder','NORWAY','4950','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 21:49:38',0,NULL,3,1,2,1,'\\ ','centreck'),(15336,584666093003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',40.56,'cnfaner','saud_alsheeb','alsheeb_ebay@yahoo.com','Saoud Abdulaziz Al Sheeb','14729 182nd St<br>DOH 4030','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 21:51:11',0,NULL,3,1,1,1,'\\ ','saud_alsheeb'),(15337,790569582011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','tomcompr','tomaz.rehar@avnet.com','Tomaz Rehar','Postni vrt 6','Logatec','','SLOVENIA','1370','0038631620094','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 21:52:55',0,NULL,3,1,2,1,'\\ ','tomcompr'),(15338,876487864012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','recklessrogo','andyrogoebay@gmail.com','Andy Rogerson','Flat 35 Waterside Court','Runcorn','Merseyside','UNITED KINGDOM','WA7 1GL','07851512931','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 22:03:38',0,NULL,3,1,3,1,'RA117762959CN\r ','recklessrogo\rHBPH003'),(15339,642084569013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.97,'eastar4','godfather303','oriolnf@gmail.com','Oriol Navarro Ferrer','Avgda. Vallvidrera 83','Barcelona','Cataluña','SPAIN','08017','932045195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 22:11:14',0,NULL,3,1,3,1,'RA184573198CN\r ','godfather303\rLGAD001'),(15340,790591459011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.9,'eastar4','bombers18','hckay@optusnet.com.au','harry kay','c/o Goodman Law<br>GPO Box 1674','Canberra City','Australian Capital Territory','AUSTRALIA','2601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 22:45:11',0,NULL,3,1,3,1,'RA184573238CN\r ','bombers18\rOTGR001+OTGR002+OTGR003'),(15341,642098296013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','347808313','chrism@mlbilling.com','Christopher Maryniuk','425 Huehl Rd<br>C/O Ml Medical Billing Co. Bldg 8','Northbrook','IL','UNITED STATES','60062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 22:56:08',0,NULL,3,1,1,1,'、 ','347808313'),(15342,790611486011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','richie275','richie275@yahoo.com','Rich Schemitsch','3100 Merrianne Dr','Raleigh','NC','UNITED STATES','27607','(919) 801-5397','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 23:40:45',0,NULL,3,0,1,1,'、 ','richie275\r已入库'),(15343,589639468004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','tt_1111','survey@hauskauf.net','Therese Telepski','Kirchfeld 32','Süstedt','','GERMANY','27305','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-05 23:57:13',0,NULL,3,1,3,1,'RA117763000CN\r ','tt_1111\rWWOT003+ANCN001'),(15344,642123380013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','josdoum66','josdoum@hotmail.com','Dominique Laliberte','769 route 139 nord','acton vale','QC','CANADA','j0h1a0','(450) 546-4819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 00:36:32',0,NULL,3,1,6,1,'EE645650166CN  ','josdoum66\r兼容型3D眼镜 通用型'),(15345,790632001011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','capitanesripoll','casa@eantonio.com','Juan M Huéscar Baño','Juan de Miranda, 14','S/C de Tenerife','Canarias','SPAIN','38007','659585858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 00:46:51',0,NULL,3,1,2,1,'、 ','capitanesripoll\r欧标'),(15346,642135248013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','yacsf2008','yacsf@yahoo.com.sg','Chong Sen Fong','Blk 467 #03-512 Jurong West St 41','default','','SINGAPORE','640467','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 01:32:06',0,NULL,3,1,11,1,' ','yacsf2008\rHSNO016+CCNO001\r'),(15347,584726336003,130592181875,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.9,'cnfaner','boulderdave','dgutow@ball.com','David Gutow','4672 Quail Creek Ln','Boulder','CO','UNITED STATES','80301','(303) 581-0229','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 02:02:39',0,NULL,3,1,1,1,'\\ ','boulderdave'),(15348,790652444011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','jzarzar2011','jzarzar@terra.com.br','João Neto','R. Prof. Augusto lins e Silva, 497, boa viagem<br>Ap1002','Recife','Pernambuco','BRAZIL','51030030','08130312502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 02:15:38',0,NULL,3,1,2,1,'\\ ','jzarzar2011'),(15349,790673192011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','vilageoi2011','rioma1955@live.com.au','leite mario','47sackville ','ingleburn','New South Wales','AUSTRALIA','2565','0296051940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 03:35:23',0,NULL,3,1,3,1,'RA184573065CN\r ','vilageoi2011\rGLSG001*2'),(15350,790689881011,320402064138,'HP ProBook 4510S 4515S 4710S Bluetooth Module 2.0 cable',1,'BTHP2004',9.88,'eastar4','dcostajj','johnny@dcosta.net','Johnson J D\'Costa','4046 NW 59th AVE','Gainesville','FL','UNITED STATES','32653','(352) 505-4067','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 04:41:31',0,NULL,3,1,1,1,'、 ','dcostajj\rHP 8pin 1.0 18cm 4线连 '),(15351,790691851011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','privatelinesnv','privatelines@gmail.com','Private Lines','507 Casazza Dr<br>Ste D','Reno','NV','UNITED STATES','89502-3346','(775) 410-5177','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 04:51:16',0,NULL,3,1,1,1,'\\ ','privatelinesnv'),(15352,748225426001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','indiboyamay','matrimonial4mee@gmail.com','Amay singh','24 friend street<br>Wakerley','Brisbane','Queensland','AUSTRALIA','4154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 05:18:59',0,NULL,3,1,2,1,'\\ ','indiboyamay'),(15353,876625309012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','ckunyit','chamchulkunyit@gmail.com','Samsul HB','No 250 Kg Sengkurong \'B\',<br>KM 16 Jln Sengkurong \'A\', Brunei Darussalam.','BSB','Brunei','BRUNEI DARUSSALAM','BG1321','+6738822866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 05:35:13',0,NULL,3,1,2,1,'\\ ','ckunyit'),(15354,790710091011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','joseluis_m','joseluis_m@hotmail.com','Jose Luis Martinez','Valle de Caceres # 235<br>Valle del Zambezi','Nezahualcóyotl','Estado de Mexico','MEXICO','57100','5519014751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 06:51:47',0,NULL,3,1,2,1,'\\ ','joseluis_m'),(15355,876639233012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','m_ruges','mruges@gmail.com','Mark Rugendyke','86 Macquarie St','Dubbo','New South Wales','AUSTRALIA','2830','0268826322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 06:54:56',0,NULL,3,1,2,1,'\\ ','m_ruges'),(15356,0,220885109776,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.99,'eastar4uk','rovertubbs','chris@webxd.co.uk','Chris Gray','40 Beckingham<br>Orton Goldhay','Peterborough','Cambridgeshire','UNITED KINGDOM','pe2 5tl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 07:44:13',0,NULL,3,1,3,1,'RA117762993CN\r ','rovertubbs\rANCN001'),(15357,790773607011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','art_dark','daknis.artur@gmail.com','Arturas Daknis','Proletarskaya 30-107','Penza','Penzenskaya obl','RUSSIAN FEDERATION','440061','9033233380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 10:19:32',0,NULL,3,1,3,1,'RA117762980CN\r ','art_dark\rRCLO006'),(15358,642249954013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','guitarmitsos','donor178@yahoo.com','dim fra','salaminos 17','vrilissia','athens','GREECE','15235','6946453347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 11:18:28',0,NULL,3,1,3,1,'RA184573768CN\r ','guitarmitsos\rCACN004\rDimitris Fragiskatos\rsalaminos 17\rvrilissia athens 15235\rGREECE\r6946453347'),(15359,790806026011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',31.99,'eastar4uk','brumpig','rob.ericsson@hotmail.co.uk','Robert Ericsson','77 Landor Road<br>Knowle','Solihull','West Midlands','UNITED KINGDOM','B93 9JA','01564778350','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 11:19:41',0,NULL,3,1,3,1,'RA184573025CN\r ','brumpig\rGLSG001'),(15360,642269135013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','nickmaik','nickcorinna@gmail.com','nick maikantis','80 pethajohn parade','geelong','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 12:03:54',0,NULL,3,1,3,1,'RA184573272CN ','nickmaik\rMOSA006'),(15361,642267566013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','sebben22','nin@netrix.com.au','Nina Car','102 Stone Street','Bayswater','Western Australia','AUSTRALIA','6053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 12:08:01',0,NULL,3,1,2,1,'\\ ','sebben22'),(15362,790840873011,320738496776,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',24.69,'eastar4','furskog101','furskog@gmail.com','Mattias Furskog','Rektor Ödbergs gata 19','Skara','','SWEDEN','53233','+4651115157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 12:30:56',0,NULL,3,1,11,1,'、','furskog101\rLED发光伞\r黑色的'),(15363,790849528011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','hilsabeck1','jawdoctor2@aol.com','richard hilsabeck','1 Apple Creek Ct','appleton','WI','UNITED STATES','54913-8357','(920) 739-6954','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 12:49:44',0,NULL,3,1,1,1,'\\ ','hilsabeck1'),(15364,790871086011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','brainmaze','jonathan.dunn@globetrotter.net','Jonathan Dunn','602 rue des voiliers','Rimouski','QC','CANADA','g5l1l5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 13:29:58',0,NULL,3,1,2,1,'\\ ','brainmaze'),(15365,748383099001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','ms5263','splice_it2@yahoo.com','margaret healey','222 Alameda Ave','Salinas','CA','UNITED STATES','93901-4119','(831) 596-1622','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 13:33:09',0,NULL,3,1,1,1,'\\ ','ms5263'),(15366,876816742012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','zf06e','i.krenzel@hotmail.com','Gafcke Evgeny','Bahnhofstrasse 64A','Haan','','GERMANY','42781','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 13:42:09',0,NULL,3,1,2,1,'\\ ','zf06e'),(15367,790886660011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','happyguy7','pweil@onetel.com','Peter Weil','Flat 1F3<br>32 Oxford Street','Edinburgh','Scotland','UNITED KINGDOM','EH8 9PL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 13:58:38',0,NULL,3,1,2,1,'\\ ','happyguy7'),(15368,790888353011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',109.99,'eastar4','mr.ski48','terry@szy-tech.com','Terry Szymanski','5244 Mansford Rd','Winchester','TN','UNITED STATES','37398-4110','(931) 967-1977','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 14:00:13',0,NULL,3,1,1,1,'\\ ','mr.ski48'),(15369,876831854012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',9.9,'eastar4uk','homelands2011','malcsleep@btinternet.com','malcolm sleep','hillside','launceston','Cornwall','UNITED KINGDOM','pl159ph','07855831317','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 14:09:20',0,NULL,3,1,3,1,'RA117762976CN\r ','homelands2011\rHSMO017\r英标'),(15370,790893757011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','seilerthecanadian','kmseiler@shaw.ca','Kris Seiler','1332 Kapyong Avenue','Edmonton','AB','CANADA','T5E 0C3','(780) 641-6484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:11:00',0,NULL,3,1,2,1,'\\ ','seilerthecanadian'),(15371,790914652011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','ma.walther','martinwalther@gmx.net','Dipl. Verw. Martin Walther','Horner Weg 109','Hamburg','','GERMANY','22111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:47:42',0,NULL,3,1,2,1,'、 ','ma.walther\r\r'),(15372,789754375011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','cancerbar','baris_cancer@hotmail.com','BARIŞ ORAK','ZİYA GÖKALP CADDESİ<br>NO:68/B KOLEJ-ÇANKAYA','ANKARA','ANKARA','TURKEY','06600','+905072179660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:48:18',0,NULL,3,1,2,1,'\\ ','cancerbar'),(15373,584909606003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','marsbrut','d.masek@vtxmail.ch','Davor Masek','Maiengasse 12','Basel','','SWITZERLAND','4056','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:53:16',0,NULL,3,1,3,1,'RA117762962CN\r ','marsbrut\rWLAT003'),(15374,876863982012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.9,'eastar4','bakrepair','ebay@bak-re-pair.com','Bak-Re-Pair Inc.','6383 Nancy Ridge Drive<br>Suite 101','San Diego','CA','UNITED STATES','92121','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 14:59:52',0,NULL,3,1,1,1,'\\ ','bakrepair'),(15375,730907459008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',15.15,'au-buy','wonderin5670','wonderin.ebay@gmail.com','Lee Martin','65 Glencoe Cres','Tiwi','Northern Territory','AUSTRALIA','0810','0400768286','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 15:08:30',0,NULL,3,1,2,1,'\\ ','wonderin5670'),(15376,748444022001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','kenfrengs','kfrengs@beaufortco.com','Kenneth Frengs','366 Cedar St','Belhaven','NC','UNITED STATES','27810-1505','(252) 702-7228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 15:14:41',0,NULL,3,1,1,1,'\\ ','kenfrengs'),(15377,790939735011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',115.99,'eastar4','100873-100797','flamenko73@mail.ru','Nadezhda Stragauska','Nicgales 48/1-40','Riga','Latvia','LATVIA','1035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 15:27:41',0,NULL,3,1,3,1,'RA184573105CN\r ','100873-100797\rGLSG001*2'),(15378,876883870012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','mattijslangelaar','langelaar@gmx.net','Mattijs Langelaar','Immenbergweg 34 26','Beekbergen','','NETHERLANDS','7361 GP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 15:29:18',0,NULL,3,1,2,1,'\\ ','mattijslangelaar'),(15379,790955220011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.39,'eastar4','hoodnik','tschoenknecht@gmx.net','Torsten Schönknecht','Zimmerstraße 3','Cottbus','','GERMANY','03044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 15:50:10',0,NULL,3,1,2,1,'\\ ','hoodnik\racer 4pin1.25 6cm\r'),(15380,642364782013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','usafsoc53','usafsoc@gmail.com','John Falkenhagen','550 Tribble Creek Dr','grayson','GA','UNITED STATES','30017-1834','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 15:54:28',0,NULL,3,1,1,1,'\\  ','usafsoc53\r黑色的'),(15381,584940671003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',45.22,'cnfaner','ana895','sinorak@aol.com','Anastasia Karonis','7234 W North Ave<br>Apt 1712','Elmwood Park','IL','UNITED STATES','60707-4232','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 16:01:35',0,NULL,3,1,1,1,'\\ ','ana895'),(15382,790971845011,320730481564,'New lady Leopard lines w/lace Bowtie sun stick Umbrella',1,'UM00024',23.74,'eastar4','pomogalova','tanechka19837@mail.ru','Tatyana Pomogalova','pos. Himinstituta, 24-87','Tver','Tver region','RUSSIAN FEDERATION','170032','+79206906171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 16:10:25',0,NULL,3,1,3,1,'RA184573269CN ','pomogalova\rUM00010+UM00024\r野性豹纹蕾丝蝴蝶结长柄伞\r再发一把钢琴美女伞 紫色的'),(15383,876916780012,220806882622,'New lady Piano Rain Sun Parasol Stick Umbrella purple',1,'UM00010',23.74,'eastar4','pomogalova','tanechka19837@mail.ru','Tatyana Pomogalova','pos. Himinstituta, 24-87','Tver','Tver region','RUSSIAN FEDERATION','170032','+79206906171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 16:11:37',0,NULL,3,1,17,0,' ','pomogalova'),(15384,790997951011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','romol','r.molter@nord-com.net','Rolf Molter','Schönebecker Str. 52','Bremen','','GERMANY','28759','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 16:42:15',0,NULL,3,1,2,1,'\\ ','romol'),(15385,791002070011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','maestromedia','jeannette.meadows@sky.com','Jeannette Meadows','16 Radnor Close','Hindley Green, Wigan','Greater Manchester','UNITED KINGDOM','WN2 4RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 16:47:14',0,NULL,3,1,3,1,'RA184573051CN\r ','maestromedia\rMOAP001'),(15386,791010634011,320737015281,'New in box genuine SONY 3D Active Glasses TDG-BR100',2,'OTSO003',165.98,'eastar4','cjwin69','c.winter@btinternet.com','Craig Winter','12 Chestnut Drive','Bexleyheath','Kent','UNITED KINGDOM','DA74EN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 16:57:33',0,NULL,5,1,18,1,NULL,'cjwin69\rOTSO003'),(15387,730985669008,180699061588,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',22.79,'au-buy','s57huk349','dkamenov@amis.net','Dimitar Kamenov','Valvasorjeva 7','Ljubljana','','SLOVENIA','1000','+38640612675','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 17:00:48',0,NULL,3,1,2,1,'\\ ','s57huk349'),(15388,791041203011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','karch3333','kamal.azar@gmail.com','Kamal Azar','3727 Overlook Ave.','Macon','GA','UNITED STATES','31204','(478) 714-7855','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 17:29:58',0,NULL,3,1,1,1,'\\ ','karch3333'),(15389,585001231003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.29,'cnfaner','702cuellar','chavacue@hotmail.com','salvador cuellar','3125 parkdale cir','las vegas','NV','UNITED STATES','89121-2632','(702) 203-6208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 17:40:14',0,NULL,3,1,1,1,'\\ ','702cuellar'),(15390,876998382012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT004*2',52.99,'eastar4uk','kingtubbymichael','michaelcarter1@hotmail.com','michael raymond carter','estrada jose benedito de oliveira,800<br>Bairro dos Freitas.  Condominio village alpino','Sao Jose dos Campos','Estado de Sao Paulo CEP','BRAZIL','12214-422','00551291215468','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-06 17:40:19',0,NULL,3,1,3,1,'RA184573944CN\r ','kingtubbymichael\rGLOT004*2\r兼容型3D眼镜  samsung 专用'),(15391,791059300011,320786808112,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',39.9,'eastar4','123yanivsk','yanivsk@gmail.com','yaniv skornik','m.p hevel eilot','kibbutz yotvata','','ISRAEL','88820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 17:50:25',0,NULL,3,1,2,1,'、 ','123yanivsk\r黑色的'),(15392,791067596011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO031',67.98,'eastar4','j_jsales0','jjjdevinney@frontier.com','joe devinney','707 Aurora Knoll Ln','fort wayne','IN','UNITED STATES','46825','(260) 515-7497','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 17:55:09',0,NULL,3,1,1,1,'\\ ','j_jsales0\r旧的'),(15393,877036425012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','ollioffizz','polluxx@pixelheim.de','Oliver Esseling','Robertstrasse 12','Köln','','GERMANY','51105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:13:38',0,NULL,3,1,2,1,'\\ ','ollioffizz'),(15394,791099367011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.39,'eastar4','erik_4812','erik.ferking@c2i.net','Erik Ferking','Almannamyrv. 46','Skudeneshavn','','NORWAY','4280','+47 52828883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:23:58',0,NULL,3,1,2,1,'\\ ','erik_4812\racer 4pin1.25 6cm '),(15395,877072040012,220797313937,'Shell cover 4 Logitech Harmony 890 Pro remote control',1,'SHLO007',29.9,'eastar4','ssm_2936','smetcalfe@whoalaw.com','Sally Metcalfe','388 Cortona Dr.','West Lake Hills','TX','UNITED STATES','78746','(512) 413-9721','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 18:41:05',0,NULL,3,1,1,1,'\\ ','ssm_2936'),(15396,791131777011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'eastar4','voifman','vladimir.oifman@mail.ru','Vladimir Oifman','Etzion 8a ap.1','Ramat Gan','israel','ISRAEL','52383','+972547809083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:55:56',0,NULL,3,1,2,1,'\\ ','voifman'),(15397,791145933011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',99.8,'eastar4','pallett89','greigpallett@hotmail.co.uk','greig pallett','30 copse road<br>townhill park','southampton','Hampshire','UNITED KINGDOM','so182gz','07590684303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 19:11:50',0,NULL,3,1,3,1,'RA184573096CN\r ','pallett89\rGLSG001'),(15398,791174779011,320681554413,'Triple Tyco Universal Wireless Laptop Antenna Mini PCI',1,'ANTY002',3.58,'eastar4','afuksenidi.lv','azatot@inbox.lv','Aleksandr Afuksenidi','Kveles str. 24-60','Riga','','LATVIA','LV-1064','+371 29526127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 19:43:52',0,NULL,3,1,2,1,'\\ ','afuksenidi.lv'),(15399,642069695013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','marc-antoine22','caruzzoboulot@hotmail.fr','CARUZZO Marc-Antoine','2 rue des oliviers','PUISSALICON','Languedoc-Rousillon','FRANCE','34480','06 16 73 70 52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 19:58:00',0,NULL,3,1,3,1,'RA184573048CN\r ','marc-antoine22\rGLOT005'),(15400,748703038001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','chelsea040508443','chelsea040508@yahoo.com','Chelsea Hurd','7115 Forest Ave','Hanover','MD','UNITED STATES','21076-1148','(410) 379-0827','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 20:06:55',0,NULL,3,1,1,1,'\\ ','chelsea040508443'),(15401,877181309012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','marshawest7','marsha_v_7@hotmail.com','Marsha Westerop','3966 200a street','Langley','BC','CANADA','v3a 1n6','(778) 241-6434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 20:19:28',0,NULL,3,1,2,1,'\\ ','marshawest7'),(15402,791242316011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','bigbottombasses','drabideau2001@yahoo.com','David Rabideau','10 Bickford St','Scarborough','ME','UNITED STATES','04074-9235','(207) 205-2162','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 20:43:20',0,NULL,3,1,1,1,'、 ','bigbottombasses'),(15403,877212975012,220682404337,'2.1 HP DV2500 DV2600 DV2700  Bluetooth Module+ cable',1,'BTHP2103',12.39,'eastar4','aristo79','aristotelis79@gmail.com','Aristotelis Papantonis','D. LAPPA 147','KARDITSA','KARDITSA','GREECE','43100','6972871877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 20:55:26',0,NULL,3,1,2,1,'\\ ','aristo79\rHP 8pin 1.0 12cm '),(15404,877200968012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','xistanz83','xistanz@walla.com','Robert Erwin','21 Ward Dr','Barrie','ON','CANADA','l4n7n9','(705) 795-7836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 21:01:03',0,NULL,3,1,3,1,'RA184573873CN\r ','xistanz83\rGLOT005*2\r新地址\rRobert Erwin\r44 moir cres\rBarrie. On. Canada\rL4n8b2\r(705)252-3356\r\r'),(15405,877232938012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','bent_mg','bentmg@gmail.com','Dana Miller','3609 S Shore Dr','Delavan','WI','UNITED STATES','53115-3416','(262) 725-1223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 21:17:23',0,NULL,3,1,1,1,'\\ ','bent_mg'),(15406,791280965011,320738499440,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',12.85,'eastar4','pedrocabeleira','geral@grupocabeleira.com','Pedro cabeleira','Rua Principal 14<br>Carvalhal do Pombo','Torres Novas','Santarém','PORTUGAL','2350-016','00351249799000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-06 21:35:14',0,NULL,3,1,2,1,'\\  ','pedrocabeleira\r\r\rCute cat patten\r'),(15407,877242280012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',27.9,'eastar4','klokik-klo','deletesobaka@gmail.com','Kolia Dolgij','Gavro Layosha St.<br>9ZH 67','Kiev','Kiev','UKRAINE','04211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 21:43:33',0,NULL,3,1,2,1,'\\ ','klokik-klo'),(15408,590633193004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.29,'cnfaner','madiezmd','markrday@yahoo.com','Mark Day','326 Greenfield Ave','San Anselmo','CA','UNITED STATES','94960-2418','(415) 457-7680','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 21:48:07',0,NULL,3,1,1,1,'\\ ','madiezmd'),(15409,791293796011,320716558180,'Logitech Harmony RF extender 890 pro 1000 1100',1,'RCLO007',26.99,'eastar4','kseb84','s_krafft18@hotmail.com','sebastien krafft','250 westcroft','beaconsfield','QC','CANADA','h9w2m4','(514) 630-9967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 21:54:06',0,NULL,3,1,2,1,'、 ','kseb84'),(15410,877279644012,220858454297,'New original Apple AirPort Extreme WiFi Card 54M',1,'WLAP003',14.99,'eastar4uk','recicledsoul','pkrk7@hotmail.com','Keisly Fiumari','Sonae Sierra<br>Rua Amilcar Cabral, 23','Quinta do Lambert','Lisboa','PORTUGAL','1750 – 018','00351915819926','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-06 22:29:10',0,NULL,3,1,2,1,'\\ ','recicledsoul'),(15411,791324697011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','plou65','paradajo@laposte.net','GARCIA Raphaël','12 rue Pierre et Marie CURIE','SEMEAC','Midi-Pyrénées','FRANCE','65600','0567453016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-06 22:51:38',0,NULL,3,1,3,1,'RA184573140CN\r ','plou65\rGLOT001\r兼容型3D眼镜 通用型'),(15412,791324595011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','mkolundzic','theserb4u@hotmail.com','Milos Kolundzic','4/7 Medley Street Chifley','Canberra','Act','AUSTRALIA','2606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 22:52:00',0,NULL,3,1,2,1,'\\ ','mkolundzic'),(15413,877304983012,220769590609,'New Atheros AR9287 Wireless PCI-E Half Card+antenna',1,'WLAT007+ANTY001',15.95,'eastar4','strupniveral','lucaster@gmail.com','Luca Moscatelli','Windeggstrasse 11','Dietikon','','SWITZERLAND','8953','0786372256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 23:18:01',0,NULL,3,1,2,1,'\\ ','strupniveral'),(15414,791348392011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','cody07','kdccc5@aol.com','Kevin OConnor','1576 N Mitchell Canyon Rd','Clayton','CA','UNITED STATES','94517-1147','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-06 23:45:12',0,NULL,3,1,1,1,'\\ ','cody07'),(15415,731298390008,180699061588,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',4,'HSJA001',91.16,'au-buy','taekwondad','jpryan@wideopenwest.com','James P. Ryan','22655 Colony St','Saint Clair Shores','MI','UNITED STATES','48080-2183','(586) 945-0798','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 23:58:39',0,NULL,3,1,1,1,'\\ ','taekwondad'),(15416,642648577013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','carsrockinron','wrenchhead26@hotmail.com','Ron Godda','30 Caddy Drive','Scarborough','ON','CANADA','M1G2G1','(416) 439-9939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 23:58:52',0,NULL,3,1,3,1,'RA184573119CN\r ','carsrockinron\rLGAD001'),(15417,791361120011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','flyingeddy-22','edwardt@blueyonder.co.uk','Edward Taylor','22 Fore Street, Eastcote','Pinner','Middlesex','UNITED KINGDOM','HA52HY','01895472838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 00:20:03',0,NULL,3,1,2,1,'\\ ','flyingeddy-22'),(15418,877333841012,220566625683,'Genuine Cisco PVDM-256K-8 VoiceFax DSP Module PVDM-256',1,'OTIN002',35,'eastar4','metronet-its','sales@mnits.net','A G Pham','8427 Jonquil Ln N','Maple Grove','MN','UNITED STATES','55369-3012','(763) 494-0434','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 00:24:35',0,NULL,3,1,1,1,'\\ ','metronet-its'),(15419,791385256011,320738496776,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',24.69,'eastar4','maxindeal','basketballfreak25@hotmail.com','Melody Malapad','463 21st E Ave.','Vancouver','BC','CANADA','V5V 1R3','(778) 869-8184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 01:20:53',0,NULL,3,1,11,1,'、','maxindeal\rLED发光伞\r黑色的'),(15420,791399691011,320755995166,'Logitech Harmony Rechargeable battery 890 880 950mAh',1,'BALO008',6.99,'eastar4','bmanbman99','bobmann@columbus.rr.com','Bradley Obmann','5081 Calais Dr','Columbus','OH','UNITED STATES','43221-5686','(614) 946-1413','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 01:59:30',0,NULL,3,1,1,1,'\\ ','bmanbman99'),(15421,877369551012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','tzortziscoachgd','coachgd@gmail.com','FENERBAHCE SPORTS CLUBU (Didem Akin-GD)','LEFTER KUCUKANTONYADIS TESISLERI<br>MUNIR NURETTIN SELCUK CADDESI','KIZILTOPRAK','ISTANBUL','TURKEY','36726','+905512193646','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 02:05:37',0,NULL,3,1,3,1,'RA117762857CN\r ','tzortziscoachgd\rOTSO002'),(15422,791403364011,320691686054,'2 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',97.99,'eastar4','tussell11','eyoung726@gmail.com','Russell DeYoung','211 Center St','Randolph','MA','UNITED STATES','02368-5423','(781) 986-6641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 02:15:47',0,NULL,3,1,1,1,'\\ ','tussell11'),(15423,642689493013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','kimmm20000','kimm20000@yahoo.com','Kim Auzston','7713 Peabody Dr.','Austin','TX','UNITED STATES','78729','(832) 425-6869','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 02:17:07',0,NULL,3,1,1,1,'\\ ','kimmm20000'),(15424,642686958013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','normanrshearer','j-msmith@hotmail.com','Norman Shearer','809-2200 woodview dr sw','Calgary','AB','CANADA','T2W 3N6','(403) 719-3886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 02:17:59',0,NULL,3,1,6,1,'EE645650170CN  ','normanrshearer\r兼容型3D眼镜 通用型'),(15425,791412696011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','beardog648','hawkinsjamesh@gmail.com','James Hawkins','648 Ridge Hill Dr','New Braunfels','TX','UNITED STATES','78130-6607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 02:37:21',0,NULL,3,1,1,1,'\\ ','beardog648'),(15426,791417797011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',135.99,'eastar4','bvexpress','shop@brianvierra.com','Brian Vierra','5666 La Ribera St<br>Ste A','Livermore','CA','UNITED STATES','94550','(925) 310-3100 ext.: 216','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 03:05:36',0,NULL,3,1,1,1,'\\ ','bvexpress'),(15427,8881320635845843,111,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',0,'eastar4','mustang19_123','jasonlane_16@yahoo.com','Jason Lane','3980 Morrice rd','Webberville','MI','UNITED STATES','48892-9749','',NULL,NULL,NULL,'2011-11-07 03:17:25',0,NULL,3,1,1,1,'\\  ','补货 \rLK004407673CN'),(15428,877401586012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','59264655','bhsw012@hotmail.com','Ryan Lee','322 W 57th St.<br>26V','New York','NY','UNITED STATES','10019','(404) 245-0473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 03:18:34',0,NULL,3,1,1,1,'、 ','59264655\r新地址\rRyan Lee\r322 W. 57th St. 35F \rNew York, NY 10019\rUNITED STATES\r(404) 245-0473\r\r'),(15429,8881320636086615,111,'Acer Aspire 5100 5110 3100 Bluetooth Module 2.0+cable',1,'BTAC2021',0,'eastar4','ses_cz','jursaj@centrum.cz','Jiri Jursa','Mrenkova 58','Ivancice','Czech Republic','CZECH REPUBLIC','66491','+420608000408',NULL,NULL,NULL,'2011-11-07 03:21:26',0,NULL,3,1,2,1,'\\  ','acer 8pin1.00 8cm  \r补货'),(15430,590731655004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.1,'cnfaner','cjam5115','pal_a11@yahoo.co.in','chintan jameria','115 hemingway ave apt. A2','east haven','CT','UNITED STATES','06512','(718) 801-0905','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-07 03:42:47',0,NULL,3,1,1,1,'\\  ','cjam5115'),(15431,874665809012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','amar_prabhu','amarprabhu@rediffmail.com','Amarnath Prabhu','1/333 Milton Road, Auchenflower','Brisbane','Queensland','AUSTRALIA','4066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 04:12:32',0,NULL,3,1,2,1,'\\  ','amar_prabhu'),(15432,877421497012,220581067419,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2002',9.88,'eastar4','neuronspikes','stephane@c-denis.com','Stéphane Denis','148 rue Bisson','Delson','QC','CANADA','J5B 2G9','(514) 418-4323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 04:34:27',0,NULL,3,1,2,1,'\\  ','neuronspikes\r8pin 1.0 8cm 五线连接'),(15433,877438668012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',9.19,'eastar4uk','drewskilandy','drewskilandy@outgun.com','Andrew Wright','54 Bryony Way','MansfieldWoodhouse','Nottinghamshire','UNITED KINGDOM','NG19 9AN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 06:04:11',0,NULL,3,1,3,1,'RA184573670CN\r ','drewskilandy\r英标\rHSPL005'),(15434,590753935004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','natasha2062','tashatabert@yahoo.com','Natasha Tabert','7930 S Mt Oaks Dr','Salt Lake City','UT','UNITED STATES','84121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-07 06:38:40',0,NULL,3,1,1,1,'\\  ','natasha2062'),(15435,791465380011,320735039422,'New HP Media Center receiver+microsoft Remote Control',2,'OTHP006',36.8,'eastar4','blakeneyterry','terryt@purpleblanket.net','Purpleblanket Ltd','Rainbows End<br>Prosper Lane','Coalway','Gloucestershire','UNITED KINGDOM','GL16 7JW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 06:46:33',0,NULL,3,1,2,1,'\\  ','blakeneyterry\r微软的'),(15436,791470861011,320737032375,'4 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*4',216.99,'eastar4','berettheman','berettheman@hotmail.com','Nick Barratt','17 New Street<br>Oakengates','Telford','Shropshire','UNITED KINGDOM','TF2 6ES','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 07:20:17',0,NULL,3,1,6,1,'EE645650183CN  ','berettheman'),(15437,642713565013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',273.99,'eastar4','hey_mey','andrewvanderhaak@bigpond.com','Andrew Vanderhaak','60 Rudall Ave','Whyalla Playford','South Australia','AUSTRALIA','5600','04198105690419810569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 07:45:34',0,NULL,3,1,6,1,'EE645650197CN ','hey_mey'),(15438,877465989012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','atskalunas','darius_juozainis@yahoo.com','Darius Juozainis','L.Giros 80-26','Vilnius','Lithuania','LITHUANIA','06315','(370) 657 54588','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 08:17:00',0,NULL,3,1,3,1,'RA184573799CN\r ','atskalunas\rLGAD001'),(15439,877469186012,220807319834,'Fashion Rainbow Trim parasol Sun/Rian stick umbrella',1,'UM00009',31.9,'eastar4','pearldave','pnd@guam.net','Pearl A. CHAPMAN','PO Box 3538','Hagatna','GU','UNITED STATES','96932-3538','(671) 777-5505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 08:36:25',0,NULL,3,1,1,1,'\\ ','pearldave\rUM00009+UM00007\r黑底七色边彩虹伞 \r再发一把\rNew Map Anti-UV Rain Sun Parasol Stick Umbrella\r'),(15440,877472281012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',2,'HSNO006',29.96,'eastar4','jakovdom66','garmin1@gmail.com','Jakov Sheinbein','b-r Karbisheva, 14-214','Moskov','MO','RUSSIAN FEDERATION','123154','(7903) 2380630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:43:15',0,NULL,3,1,2,1,'\\  ','jakovdom66\r欧标'),(15441,589644601004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','baptiste-83','tbweb13@gmail.com','Baptiste Tournois','145 Chemin de la Tuilière','Vinon sur Verdon','Provence-Alpes-Côte d\'Azur','FRANCE','83560','0650833173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:47:58',0,NULL,3,1,3,1,'RA184573808CN\r ','baptiste-8\rHSPL002'),(15442,791328691011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','hard-luck-lodge','hardlucklodge@hotmail.com','John Jarrett','2520 Ritson,Road,North.<br>RR#5,','Oshawa,','ON','CANADA','L1H 8L7','(905) 723-7480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:58:12',0,NULL,3,1,2,1,'\\  ','hard-luck-lodge'),(15443,8881320656593156,111,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'',1.25,'eastar4','corsicat04','dagnafr@yahoo.fr','DAGNA pierre','70 rue Douy Delcupe','montreuil ','','FRANCE','93100','',NULL,NULL,NULL,'2011-11-07 09:03:13',0,NULL,5,1,18,0,NULL,NULL),(15444,642756034013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','2011peterross','niliross@gmail.com','peter ross','17 corrigan ave','toormina','New South Wales','AUSTRALIA','2452','0266586974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 09:05:41',0,NULL,3,1,3,1,'RA184573935CN\r ','2011peterross\rGLOT001*2\r兼容型3D眼镜 通用型'),(15445,0,230696401439,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.25,'eastar4','corsicat04','dagnafr@yahoo.fr','DAGNA pierre','70 rue Douy Delcupe','montreuil','Ile-de-France','FRANCE','93100','0614303053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:56:36',0,NULL,3,1,2,1,'\\  ','corsicat04'),(15446,791499545011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','daveychan','daveychan@hotmail.com','Davey  Williams','NISHIKI M-ONE BLDG 1-6-38 NISHIKI, NAKA-KU','Nagoya','Aichi','JAPAN','460-0003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 09:22:14',0,NULL,3,1,2,1,'\\  ','daveychan'),(15447,877498240012,220785299925,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',66,'eastar4','nivnoov','niv_555@hotmail.com','Frida Babliki','ohalei yaakov 13<br>Neve Offer','Tel aviv','Israel','ISRAEL','68192','0523583099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 10:22:47',0,NULL,3,1,3,1,'RA184573771CN\r ','nivnoov\rMOLO001'),(15448,791516949011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',7.57,'eastar4','gerrykav','gerryk@gmail.com','Gerry Kavanagh','Derry, Cregannabeg<br>Oranmore','Galway','Galway','IRELAND','default','0877996336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 10:25:34',0,NULL,3,0,2,1,'\\  ','gerrykav\r已入库'),(15449,877502466012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','clipper3rbyc','drgarydavison@optusnet.com.au','Dr Gary Davison','Level 8<br>459 Little Collins Street','Melbourne','Victoria','AUSTRALIA','3000','0402339900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 10:28:57',0,NULL,3,1,3,1,'RA184573825CN\r ','clipper3rbyc\rOTSO004*2'),(15450,0,320787444873,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',3.99,'eastar4uk','steelpathhead','allan@thesteelfamily.co.uk','Allan Steel','12A Glen Orrin Avenue','Kilmarnock','Ayrshire','UNITED KINGDOM','KA20LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 11:09:46',0,NULL,3,1,3,1,'RA184573900CN\r ','steelpathhead\rBALO007'),(15451,590807524004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','tuefteltorge','torge.luebker@gmx.de','Torge Lübker','Groothegen 34','Glinde','','GERMANY','21509','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-07 11:51:42',0,NULL,3,1,3,1,'RA184573710CN\r ','tuefteltorge\rWWOT003+ANCN001'),(15452,8881320667436088,111,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',0,'eastar4','ducktoad','ducktoad@hotmail.com','Jody Weiand','1207 Canal St','Custer','SD','UNITED STATES','57730-2109','(605) 673-2321',NULL,NULL,NULL,'2011-11-07 12:03:56',0,NULL,3,1,1,1,'\\  ','补货全套 \rLK004407660CN'),(15453,8881320668482144,111,'New Genuine Motorola HS850 Bluetooth Headset track#',1,'HSMO019',0,'cnfaner','lharvell73','live2pay@hotmail.com','LaSchon Harvell','4400 Birchtree Ln','Temple Hills','MD','UNITED STATES','20748-5733','',NULL,NULL,NULL,'2011-11-07 12:21:22',0,NULL,3,1,1,1,'\\ ','补发的  \r只发耳机 \rLK004054375CN'),(15454,877544175012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','rhar8287','harrisenhance@gmail.com','Robert Harris Jr.','3212 Latona Street','Philadelphia','PA','UNITED STATES','19146','(215) 334-2191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 12:36:31',0,NULL,3,1,6,1,'EE645650206CN ','rhar8287\r兼容型3D眼镜 通用型'),(15455,791558018011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','fika1969','fikret.azimov@gmail.com','Fikrat Azimov','General Mehmandarov str. 52 apt 94','Baku','Khatai','AZERBAIJAN','AZ1015','00994-70-270-0070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 12:37:33',0,NULL,3,1,3,1,'RA184573723CN\r ','fika1969\rOTSO004'),(15456,877550483012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','maxce4fun','markus.benda@badminton-wels.at','Markus Benda (Fa. Sophos)','Leonfeldnerstrasse 2','Linz','','AUSTRIA','4040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 12:58:24',0,NULL,3,1,2,1,'\\  ','maxce4fun'),(15457,877561648012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.44,'eastar4uk','jhugli','jacques.hugli@sfr.fr','Hugli Jacques','455 Avenue des Plaines','Gagnières','Gard','FRANCE','30160','0466839435','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 13:24:51',0,NULL,3,1,2,1,'\\  ','jhugli'),(15458,877578513012,220815932431,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',23.47,'eastar4uk','mpexpanos','mpexpan12@yahoo.gr','ΠΑΝΑΓΙΩΤΗΣ ΜΠΕΧΤΣΟΠΟΥΛΟΣ','ΠΟΛΥΖΩΪΔΗ 49<br>Ν. ΣΚΟΠΟΣ','ΣΕΡΡΕΣ','ΣΕΡΡΕΣ','GREECE','62100','2321032630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 14:04:21',0,NULL,3,1,3,1,'RA184573652CN\r ','mpexpanos\rSHLO002+SHLO005\r再发一个Replaceable Shell for logitech Anywhere MX Mouse M905\r'),(15459,791590605011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',16.98,'eastar4','neilij','drvolume@gmail.com','John Neilis','28 Whitehall Road<br>Rhos On Sea','Colwyn Bay','Conwy','UNITED KINGDOM','LL28 4ET','07586295537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 14:06:57',0,NULL,3,1,2,1,'\\  ','neilij'),(15460,877579472012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','vwal6666','20v07@gmx.com','Vincent Walkden','2 Clarks House<br>Hendford Grove','Yeovil','Somerset','UNITED KINGDOM','BA20 1UT','07849100448','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 14:07:39',0,NULL,3,1,3,1,'RA184573754CN\r ','vwal6666\rOTSO004*2'),(15461,642849630013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','pokemon.1','drago.gre@gmail.com','Milena Tomažič','Kog 70','Kog','','SLOVENIA','2276','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 15:33:21',0,NULL,3,1,2,1,'\\  ','pokemon.1'),(15462,589048513004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','phakdeejirundron','thailandthailand@hotmail.com','Phakdee Jirundron','238/264 , Srivara Mansion 2 ,<br>Soi Nathong 3 , Ratchadapisek Road','Dindaeng','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 15:41:30',0,NULL,3,1,3,1,'RA184573666CN\r ','phakdeejirundron\rHSJA011'),(15463,642852777013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','livelaughlovethelife','pinkaholic09@hotmail.com','Lacey Bishop','6530 S Meridian Rd','sedgwick','KS','UNITED STATES','67135-9099','(316) 293-6644','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 15:44:06',0,NULL,3,1,1,1,'\\  ','livelaughlovethelife\r带波尔卡圆点图案的\r韩版透明伞'),(15464,876591280012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','ifchix','13_ifchix@inbox.lv','Ivars Galins','9 Lomond Close','Portsmouth','Hampshire','UNITED KINGDOM','PO2 7HQ','07518844925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 15:44:10',0,NULL,3,1,3,1,'RA184573706CN\r ','ifchix\rLGAD001'),(15465,642853139013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',4,'GLOT001*2',355.96,'eastar4','chiefs07','jthuffman7@cox.net','Jason Huffman','2760 Fenimore Dr','Sumter','SC','UNITED STATES','29150-2206','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 15:45:47',0,NULL,5,0,18,0,NULL,'chiefs07\r客户买错了  要求退款撤单'),(15466,642855712013,230653158551,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',29.9,'eastar4','lendraputra','nurezki@gmail.com','Nurezki Lendra','Block 940 Tampines Ave 5<br>#02-179','Singapore','','SINGAPORE','520940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 15:56:32',0,NULL,3,1,3,1,'RA184573887CN\r ','lendraputra\rOTGR006\r一共买了两个Grohe 水枪'),(15467,642860629013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','boater34','ddunne@nf.sympatico.ca','John Dunne','208A Oconnell Drive','Corner Brook','NL','CANADA','a2h 5n4','(709) 634-4578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 16:10:33',0,NULL,3,1,3,1,'RA184573839CN\r ','boater34\rGPS0004'),(15468,791640263011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',9.49,'eastar4','francisco7182','fgaral@gmail.com','francisco garcia alfonso','general goded nº 73','santa cruz de tenerife','Canarias','SPAIN','38006','616428064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 16:11:39',0,NULL,3,1,2,1,'\\  ','francisco7182'),(15469,791644413011,320787383671,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',15.95,'eastar4uk','naomi9782','babygirluta@hotmail.com','Cynthia Barber','7 Cedar Close','St Leonards on Sea','East Sussex','UNITED KINGDOM','TN37 7HR','01424753813','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 16:22:55',0,NULL,3,1,3,1,'RA184573635CN\r ','naomi9782\rUM00005\r向日葵长柄伞  '),(15470,642866340013,230653158551,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',29.9,'eastar4','lendraputra','nurezki@gmail.com','Nurezki Lendra','Block 940 Tampines Ave 5<br>#02-179','Singapore','','SINGAPORE','520940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 16:27:22',0,NULL,3,1,17,0,NULL,'lendraputra'),(15471,877657202012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','413tusker','robertorme@hotmail.com','Robert Orme','539 Montrose rd','Belleville','ON','CANADA','K8R 1B2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:01:32',0,NULL,3,1,3,1,'RA184573927CN\r ','413tusker\rGLOT001\r兼容型3D眼镜 通用型'),(15472,791666139011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','aper8980','disde@hotmail.es','Antonio Perez Sanchez','Sant Felip i de Roses<br>58-62 3º 2ª','Badalona','Cataluña','SPAIN','08915','667712354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:06:47',0,NULL,3,1,2,1,'\\  ','aper8980'),(15473,791669650011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','skimatix','trisparamor@gmail.com','Tristan Paramor','2 Martyr Court<br>Martyr Road','Guildford','Surrey','UNITED KINGDOM','GU1 4LF','01483300772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:12:37',0,NULL,3,1,2,1,'\\  ','skimatix'),(15474,642881459013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','area51lp','larry.page@firstnaz.org','Larry P. Page','1400 E Kellogg Dr','Wichita','KS','UNITED STATES','67211-2660','(316) 858-1400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 17:13:14',0,NULL,3,1,1,1,'\\ ','area51lp'),(15475,584018405003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',1,'HSJA006',13.55,'cnfaner','okiedj61','info@kerrteam.com','wally kerr','2500 McGee Dr<br>Suite 147','norman','OK','UNITED STATES','73072','(405) 321-8326 ext.: 278','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-07 17:19:45',0,NULL,3,1,1,1,'\\  ','okiedj61'),(15476,791672787011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','yanivbr','yaniv.brokman@gmail.com','yaniv brokman','7 Ha\'Shalom Street','Kfar Saba','','ISRAEL','44377','+972526132206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:20:20',0,NULL,3,1,2,1,'\\  ','yanivbr\r欧标'),(15477,877685771012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','tonio0608','tomaszm1@op.pl','Tomasz Marciniak','5 yale close','Hounslow Heath','London','UNITED KINGDOM','tw4 5eh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 17:49:28',0,NULL,3,1,3,1,'RA184573745CN\r ','tonio0608\rHSPL013\r英标'),(15478,791688793011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','victor1826','vj.jakovlev@gmail.com','Victor Jakovlev','Ursinusstr. 4','Manching','','GERMANY','85077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:50:02',0,NULL,3,1,2,1,'\\  ','victor1826\r欧标'),(15479,642898578013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','eagle02021972','eagle@mail.ru','Alexey Orlov','Bronnickaya street 21, kv.18','Ramenskoe','Moscow region','RUSSIAN FEDERATION','140100','7(926)211-1230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 17:52:37',0,NULL,3,1,2,1,'\\  ','eagle02021972'),(15480,791704083011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','la-timer','bmlhospitality@sbcglobal.net','Brian Latimer','1818 1/2 Webster Ave','Los Angeles','CA','UNITED STATES','90026-1259','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 18:17:01',0,NULL,3,1,1,1,'\\  ','la-timer'),(15481,791704026011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','nick_pet665','vortex79@otenet.gr','Nikos Fotiadis','Leoforos Thessalonikis 29','Peraia','Thessaloniki','GREECE','57019','0030 697 6850989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 18:17:55',0,NULL,3,1,2,1,'\\  ','nick_pet665'),(15482,877710187012,220858471777,'New PLANTRONICS EXPLORER 220 Bluetooth headset E220',2,'HSPL001',19.98,'eastar4uk','sevicon','ebay@sevicon.com','Luis','C/ Forjadores nº 2 Bajo A','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','655527493','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 18:37:49',0,NULL,3,1,2,1,'\\  ','sevicon'),(15483,877712538012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',3,'HSMO011+CCMO001',41.97,'eastar4uk','metteogmartin','mb.ventilation@stofanet.dk','mette Larsen','Svingelen 3','Næstved','standard','DENMARK','4700','(045)28561573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 18:38:39',0,NULL,3,1,3,1,'RA184573811CN\r ','metteogmartin\rHSMO011+CCMO001'),(15484,877732269012,220815928644,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',12.82,'eastar4uk','davebear1763','davesimmons@blueyonder.co.uk','Dave Simmons','25 Coniston Road,Patchway<br>Patchway','Bristol','Bristol','UNITED KINGDOM','BS345JN','01179076284','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 19:01:19',0,NULL,3,1,3,1,'RA184573895CN\r ','davebear1763\rWLIN010'),(15485,877736415012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','kavejay','kylejang@gmail.com','Kyle Jang','3255 Scott Blvd<br>Ste 3-101','Santa Clara','CA','UNITED STATES','95054-3019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 19:05:14',0,NULL,3,1,1,1,'\\ ','kavejay\rAUI Transceiver  MX20T'),(15486,877753381012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','lambambasx','lambrettasx1968@aol.com','aj watkin','9 albion street<br>buttershaw','bradford','West Yorkshire','UNITED KINGDOM','bd62es','07765113134','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 19:31:12',0,NULL,3,1,3,1,'RA184573737CN ','lambambasx\rOTGR001'),(15487,791763625011,320443637303,'Acer Timeline 4810 5810 Bluetooth Module 2.0 EDR+ cable',1,'BTAC2001',9.88,'eastar4','brbeli','ebaycepin@gmail.com','Tomislav Gajsek','Mokricka 66','Zapresic','','CROATIA','10290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:49:13',0,NULL,3,1,2,1,'\\  ','brbeli\racer 4pin 1.25 3cm '),(15488,791783344011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',41.5,'eastar4uk','snoja_74','yabintski@hotmail.com','sonya scott','733 Route des Gaillands','Chamonix','','FRANCE','74400','0033671396280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 20:29:22',0,NULL,3,1,3,1,'RA184573856CN\r ','snoja_74\rHBPH002'),(15489,590976852004,140631796832,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',25.99,'cnfaner','profac.factoring','suporte@profac.com.br','Afonso Monteiro','Rua Aquidaba, 88 apt 703','Recife','Pernambuco','BRAZIL','51030280','55-81-33414419','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-07 20:36:25',0,NULL,3,1,3,1,'RA184572277CN ','profac.factoring\rLGGL001\r\r'),(15490,790118541011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.14,'eastar4uk','madvicks','victoria@hampshirev.freeserve.co.uk','Victoria Louise Diana Hampshire','1226A Yardley Wood Road<br>Shirley','Solihull','West Midlands','UNITED KINGDOM','B90 1JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 20:39:05',0,NULL,3,1,3,1,'RA184573618CN\r ','madvicks\rMOAP001'),(15491,791814054011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','uboninijr','ubonini6232@embarqmail.com','Uriel Bonini','4631 SW 21st Pl','Ocala','FL','UNITED STATES','34474-9230','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 21:09:11',0,NULL,3,1,1,1,'\\  ','uboninijr'),(15492,791828639011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tlfields6667','tnflds@yahoo.com','Tina Fields','3152 Cobblestone Dr','Birmingham','AL','UNITED STATES','35215-1225','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 21:47:39',0,NULL,3,1,1,1,'\\  ','tlfields6667'),(15493,877843092012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','poisson11','the.breizh.fisher@gmail.com','PERRAUD Julien','58 B rue de la ville GAUTIER','ETABLES SUR MER','Bretagne','FRANCE','22680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 21:48:39',0,NULL,3,1,2,1,'\\  ','poisson11\racer 8pin1.00 8cm'),(15494,791856029011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','mustafa1915','mkosarog@iinet.net.au','Mustafa Kosaroglu','Kebab Spot, Shop 4, Casula Mall Shopping Centre<br>Corner Kurrajong Rd and Ingham Dr','Casula','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:34:50',0,NULL,3,1,3,1,'RA184572056CN\r ','mustafa1915\r澳标\r一共买了两个\r发铬色的'),(15495,791857779011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','mustafa1915','mkosarog@iinet.net.au','Mustafa Kosaroglu','Kebab Spot, Shop 4, Casula Mall Shopping Centre<br>Corner Kurrajong Rd and Ingham Dr','Casula','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:38:01',0,NULL,3,1,17,0,NULL,'mustafa1915'),(15496,877873910012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','outdoor.living.online','galerienormande@gmail.com','Art-En-Ligne','2820 LIPPE','MONTREAL','QC','CANADA','H4R1M1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:50:11',0,NULL,3,1,2,1,'\\  ','outdoor.living.online'),(15497,791872095011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','gonefishing223','nyyanks@hvc.rr.com','Walter Klimczak','29 Deer Path Ct','Bloomingburg','NY','UNITED STATES','12721-5309','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 23:13:36',0,NULL,3,1,1,1,'\\  ','gonefishing223'),(15498,877885856012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','2kerouac','jasonfellin@yahoo.com','Jason Fellin','709 E Aloha St<br>Apt 1','Seattle','WA','UNITED STATES','98102-4560','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 23:20:39',0,NULL,3,1,1,1,'\\  ','2kerouac'),(15499,791881081011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','gem4you','yes4ebay@yahoo.com','Normand Bomhower','965, 5e Avenue App: 2','Lachine','QC','CANADA','H8S 2W6','(514) 812-6526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 23:38:02',0,NULL,3,1,2,1,'\\  ','gem4you'),(15500,749341694001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','paldapizpatricia','paldapiz@msn.com','patricia aldapiz','14082 lotus ln<br>apt 318','centreville','VA','UNITED STATES','20120-6363','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 00:25:23',0,NULL,3,1,1,1,'\\ ','paldapizpatricia'),(15501,731800425008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','ultrafireuk','chasegardiner@blueyonder.co.uk','Chase Gardiner','25b Cambray Place','Cheltenham','Gloucestershire','UNITED KINGDOM','GL50 1JN','01242693815','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-08 00:26:13',0,NULL,3,1,3,1,'RA184573683CN\r ','ultrafireuk\rHBPH007'),(15502,877905599012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','icegreen2008','greendreams900@hotmail.com','padraig o driscoll','142 greenwood estate,togher','cork','Cork','IRELAND','default','0214966347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 00:12:53',0,NULL,3,1,3,1,'RA184573785CN\r ','icegreen2008\rMOMI002'),(15503,591056400004,140516095525,'New Logitech Rechargeable battery 890 880 950mA+charger',1,'BALO001+BAIN002',17.9,'cnfaner','la2sexy','ebay@acuityconsulting.net','Edward Escarsega','15024 GREENWORTH Dr','La Mirada','CA','UNITED STATES','90638','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 01:09:06',0,NULL,3,1,1,1,'\\  ','la2sexy'),(15510,877957862012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','F1 Connect Ltd.','3401D NW 72ND AVE<br>TTW #117','MIAMI','FL','UNITED STATES','33122','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:53:47',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15504,791928833011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','nathaniel.julio','nathaniel.julio@gmail.com','Nathaniel Julio','9130 Gramercy Dr<br>Unit 406','San Diego','CA','UNITED STATES','92123-4006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:15:29',0,NULL,3,1,1,1,'\\  ','nathaniel.julio'),(15505,791929041011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','deblesfam','leslie_wright@dell.com','Les Wright','713 Brittney Ct','Franklin','TN','UNITED STATES','37067-1314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:15:34',0,NULL,3,1,1,1,'\\ ','deblesfam'),(15506,643076272013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','ricardoeisabella','ricardovasco@globo.com','ricardo costa','Rua Dias Ferreira 658 /202 - Leblon','Rio de Janeiro','RJ','BRAZIL','22431-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 02:18:50',0,NULL,3,1,3,1,'RA184573697CN\r ','ricardoeisabella\rHBPH002'),(15507,585605822003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','holly48shop','hollywatson@hotmail.com','holly watson','67417 Highway 51','fluker','LA','UNITED STATES','70436','(985) 215-9365','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 02:24:28',0,NULL,3,1,1,1,'\\ ','holly48shop'),(15508,877955628012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Josef Kissinger','19112 NE 112TH AVE','BATTLE GROUND','WA','UNITED STATES','98604-9225','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:43:38',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15509,877956761012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','John Steven Walsh','6012 IRON HORSE DR','North Richland Hills','TX','UNITED STATES','76148-4015','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:47:58',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15511,877959970012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','ripmode','mauriceshow@yahoo.com','Andrea Jack','1020 Wasco St','Hood River','OR','UNITED STATES','97031-1159','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 02:59:12',0,NULL,3,1,1,1,'\\  ','ripmode'),(15512,877961238012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','ripmode','mauriceshow@yahoo.com','Erin Fogler','366 Roachville Rd','Campbellsville','KY','UNITED STATES','42718-8885','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 03:04:12',0,NULL,3,1,1,1,'\\  ','ripmode'),(15513,643082244013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ncheply','doubleupshambles@gmail.com','Nick Cheply','420 Terrahue Rd','Victoria','BC','CANADA','v9c2b5','(250) 478-3338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 02:47:39',0,NULL,3,1,2,1,'\\  ','ncheply'),(15514,8881320724140439,111,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',0,'eastar4','d331088','drago.stz@gmail.com','Dragan Nedyalkov','44 General Gurko Str., fl.1, app.1','Stara Zagora','Stara Zagora','BULGARIA','6000','359887637139',NULL,NULL,NULL,'2011-11-08 03:49:00',0,NULL,3,0,3,1,'RA184573992CN\r ','OTCN002\r补发的 '),(15515,788745934011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','raknas_md','raknasmd@hotmail.com','Anitha Selvaraj','16414 SW Estuary Dr<br>Apt 207','Beaverton','OR','UNITED STATES','97006-7921','(503) 803-8203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 04:06:26',0,NULL,3,1,1,1,'\\  ','raknas_md'),(15516,8881320725832234,111,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',0,'eastar4','pditty04','dmccu004@hotmail.com','Andre McCullum','1215 Starlight Dr','Shelby','NC','UNITED STATES','28152','(704) 600-5270',NULL,NULL,NULL,'2011-11-08 04:17:12',0,NULL,3,1,1,1,'\\  ','补发的 \rLK003599393CN '),(15517,877985156012,220815931950,'NIB cisco Linksys DMP100 Wireless-N Music Extender',1,'OTLK001',72.99,'eastar4uk','iam2ndiino1','iam2ndiino1@googlemail.com','Ace Pace','2157 Matador St','Harvey','LA','UNITED STATES','70058-3046','(228) 255-8135','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 04:38:11',0,NULL,3,1,1,1,'\\ ','iam2ndiino1'),(15518,876536775012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','hl_cui','hl_cui@yahoo.com','Hailong Cui','10430 Shelborne St<br>Unit 41','San Diego','CA','UNITED STATES','92127-6886','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 04:47:26',0,NULL,3,1,1,1,'\\  ','hl_cui'),(15519,877989314012,220816316678,'NEW Autopop 3-section Sun umbrella w/Paris Eiffel tower',2,'UM00015',47.48,'eastar4','retroman22','mkdk2jk@comcast.net','Mark Kasper','1360 Little Meadow Rd','Guilford','CT','UNITED STATES','06437','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 04:58:09',0,NULL,3,1,1,1,'\\  ','retroman22\r银胶巴黎铁塔 '),(15520,877989400012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','rswsmayga','rswsmay@gmail.com','Robert May','8347 McKenzie Pl','Lithonia','GA','UNITED STATES','30058','(770) 316-5997','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 05:00:40',0,NULL,3,1,1,1,'\\  ','rswsmayga'),(15521,877991017012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','pacific_fitness','pinedo_miguel@live.com.mx','MIGUEL PINEDO','324 Willow Rd<br>Apt 6G','SAN YSIDRO','CA','UNITED STATES','92173-3038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 05:06:40',0,NULL,3,1,1,1,'\\  ','pacific_fitness'),(15522,643108622013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','johnny355','johnwinansjr@gmail.com','John Winans','837 Talbot Dr','Morgan Hill','CA','UNITED STATES','95037-3156','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 05:18:11',0,NULL,3,1,1,1,'\\  ','johnny355'),(15523,791972146011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','mrsbigalow','karenle@hotmail.com','Karen Le','4 Dransfield Road','Edensor Park','New South Wales','AUSTRALIA','2176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 05:26:45',0,NULL,3,1,2,1,'\\  ','mrsbigalow'),(15524,8881320732336753,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',2,'BALO007',0,'eastar4uk','danlii','danlii@frozenbanana.net','Daniel Liikamaa','Jagaregatan 140','Lund','','SWEDEN','S-22653','',NULL,NULL,NULL,'2011-11-08 06:05:36',0,NULL,3,1,3,1,'RA184574009CN\r ','BALO007\r '),(15525,643116797013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','mjdittmer35','mjdittmer@gmail.com','Mark Dittmer','4310 Ventura Canyon Ave<br>Apt 9','Sherman Oaks','CA','UNITED STATES','91423-5061','(818) 854-5354','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 06:19:10',0,NULL,3,1,1,1,'\\  ','mjdittmer35'),(15526,591112404004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','voyager477','bruin477@hotmail.com','Larry Wirsch','4155 Deep Lake Boundary Rd<br># 12','Colville','WA','UNITED STATES','99114','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 06:59:30',0,NULL,3,1,1,1,'\\  ','voyager477'),(15527,791993184011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','princed9','dnguyen04@gmail.com','Dan Nguyen','2201 W Royal Ln<br>Ste 165','Irving','TX','UNITED STATES','75063-3200','(832) 797-4932','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 07:20:58',0,NULL,3,1,1,1,'\\  ','princed9'),(15528,791995725011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006*3',132.99,'eastar4','niko28091973','botata1973@gmail.com','Nikolay Dvukrayev','Hahelmonit 2<br>apt.27','Rishon Lezion','','ISRAEL','75420','+972547757566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 07:32:10',0,NULL,3,1,3,1,'RA184573913CN\r ','niko28091973\rGLOT006*3\r兼容型3D眼镜  Korea TV专用'),(15529,585659431003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','cvirts','chester_virts@hotmail.com','Chester Virts','929 Rosedale Ave','Rosedale','MD','UNITED STATES','21237','(443) 759-5566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 08:29:50',0,NULL,3,1,1,1,'\\  ','cvirts'),(15530,792014528011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','robin_kroeze','robin_kroeze@hotmail.com','Robin Kroeze','Calslaan 9-205','Enschede','','NETHERLANDS','7522 MH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 08:51:28',0,NULL,3,1,2,1,'\\  ','robin_kroeze'),(15531,591041422004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','rcsv-65','rcsvicenza@alice.it','Pilastro Giorgio','via Pittarini n 76','vicenza','VI','ITALY','36100','3358379186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 09:12:31',0,NULL,3,1,3,1,'RA184572192CN\r ','rcsv-65\rHSJA002\r'),(15532,878057474012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','robome78','robert.meller@apus.biz.pl','Robert Meller','1 Maja 35','Truskolasy','śląskie','POLAND','42134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 09:54:09',0,NULL,3,1,2,1,'\\  ','robome78'),(15533,643160670013,230649255329,'New Fasion lady with Mirror Sun Rain Stick Umbrella',1,'UM00018',23.74,'eastar4','bumblemecro','marina.katicic@gmail.com','Marina Katicic','Slavka Krautzeka 8','Rijeka','','CROATIA','51000','00385915341867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 10:39:24',0,NULL,3,1,2,1,'\\ ','bumblemecro\r照镜子伞 \r白色的'),(15534,792052879011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',16.58,'eastar4','ericthebolt','gunstone@deakin.edu.au','eric gunstone','5 Archer Place','Mill Park','Victoria','AUSTRALIA','3082','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 11:09:01',0,NULL,3,1,2,1,'\\  ','ericthebolt'),(15535,878091544012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','0173tomy','tontoalice6969@googlemail.com','paul blackman','36 forest grove','tonbridge','Kent','UNITED KINGDOM','tn103es','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 11:46:46',0,NULL,3,1,3,1,'RA184572232CN\r ','0173tomy\rWLAP002'),(15536,643175382013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','maligojus','tadej.maligoj@gmail.com','Tadej Maligoj','Cesta na Laze 10','Ljubljana','Ljubljana','SLOVENIA','1000',' 0038615155600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 11:49:25',0,NULL,3,1,2,1,'\\  ','maligojus'),(15537,878107090012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','bennydaman1992','ben_sice@optusnet.com.au','Ben Sice','10 Eldridge Street','Cherrybrook','New South Wales','AUSTRALIA','2126','0458985403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 12:28:51',0,NULL,3,1,2,1,'\\  ','bennydaman1992'),(15538,792092513011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','michael51147','mgauzman@zahav.net.il','Michael Gauzman','Sigalit st. 4 /2','Qiryt Yam','','ISRAEL','29068','972-4-8423064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 13:13:53',0,NULL,3,1,2,1,'\\  ','michael51147'),(15539,792115797011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',135.99,'eastar4','capecoralvilla','kevfitz08@gmail.com','Kevin Fitzpatrick','5628 Del Rio Ct','Cape Coral','FL','UNITED STATES','33904-5920','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 14:13:58',0,NULL,3,1,1,1,'、 ','capecoralvilla'),(15540,878147585012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','leoniiiii','marcin_leon@o2.pl','Marcin Bielatowicz','Tuwima 7/45','Debica','podkarpackie','POLAND','39200','50 4051882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 14:19:10',0,NULL,3,1,3,1,' RA184572475CN\r','leoniiiii\rOTSO002'),(15541,878155183012,220886977249,'New genuine LG AG-F210 3D Cinema Series Glasses 2 Pack',2,'LGGL001',27.98,'eastar4uk','ashrif2','joeashrif@rocketmail.com','mohammed joseph ashrif','62 burnside view','glasgow','Glasgow (City of)','UNITED KINGDOM','g75 9fz','01355248219','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 14:37:29',0,NULL,3,1,3,1,'RA184572215CN\r ','ashrif2\rLGGL001'),(15542,792135000011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','ladyhamilton_2008','ladyhamilton56@msn.com','H Mercer','12 Braemar Close<br>Wyken','Coventry','West Midlands','UNITED KINGDOM','CV2 3BE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 15:02:05',0,NULL,3,1,3,1,'RA184572229CN\r ','ladyhamilton_2008\rHSNO026\r英标'),(15543,585746718003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA004',36.06,'cnfaner','castacwa','castacwa@hotmail.com','Charles Stevens','7714 25th Ave. East','Tacoma','WA','UNITED STATES','98404','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 15:12:05',0,NULL,3,1,1,1,'、 ','castacwa\r银色的'),(15544,585743572003,130466041789,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',44.56,'cnfaner','duncanvr6','duncanvr6@hotmail.com','A.R. Slingerland (Hot ITem B.V.)','Danzigerkade 19','Amsterdam','','NETHERLANDS','1013 AP','+31613101990','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-08 15:12:31',0,NULL,3,1,3,1,'RA184572246CN\r ','duncanvr6\rWWOT003'),(15545,878127191012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','jodikai73','jodiewebb@cox.net','Joseph Webb','3390 Arizona Dr','Pensacola','FL','UNITED STATES','32504-4407','(850) 437-9852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 15:20:55',0,NULL,3,1,1,1,'、 ','jodikai73'),(15546,878175219012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','tgaracing','tga@tga.co.uk','Graham Boothby','Ferme de Labry','Bosmont sur Serre','Picardie','FRANCE','02250','0323214501','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 15:24:17',0,NULL,3,1,3,1,'RA184572294CN\r ','tgaracing\rMOLO001'),(15547,792155932011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','fahadmajeed','fahadkhalil001@hotmail.com','Fahad Khan','15 Sherwood Street','Reading','Berkshire','UNITED KINGDOM','RG30 1LJ','07838670814','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 15:54:53',0,NULL,3,1,6,1,'EE645619400CN ','fahadmajeed\r兼容型3D眼镜 通用型'),(15548,585758106003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','icallem8','pfreels105@aol.com','Philip Freels','307 N Weisgarber Rd','Knoxville','TN','UNITED STATES','37919-4015','(865) 604-5672','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 15:58:20',0,NULL,3,1,1,1,'\\  ','icallem8'),(15549,749588476001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','magda3ke','magda3k@hotmail.com','Magdalena M Garza','30 S Hawthorne Hollow Cir','The Woodlands','TX','UNITED STATES','77384-4751','(936) 273-3589','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 16:08:25',0,NULL,3,1,1,1,'、 ','magda3ke'),(15550,792164162011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','3808richardl','richard-2005@hotmail.co.uk','richard leussa wandeu','4 pinedene<br>carlton grove','soutwark','London','UNITED KINGDOM','se15 2ul','02076399712','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'3808richardl'),(15551,792182596011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','jiri_cisler','jiricisler@gmail.com','Jiri Cisler','Polska 42','Prague 2','','CZECH REPUBLIC','12000','737379170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 16:53:33',0,NULL,3,1,2,1,'\\  ','jiri_cisler'),(15552,792185589011,320575318115,'New Genuine Logitech Harmony 628  Remote Control',1,'RCLO006',46.99,'eastar4','nails1975','nails1975@hotmail.com','Neil Skyrme','Box 185','Grindrod','BC','CANADA','V0E1Y0','(250) 838-9674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 16:59:31',0,NULL,3,1,3,1,'RA184572161CN\r ','nails1975\rRCLO006'),(15553,878231789012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','rhonda123*','rgoodall1@hotmail.co.uk','Rhonda Goodall','13 Lilac Close<br>Horsford','Norwich','Norfolk','UNITED KINGDOM','NR10 3EN','01603710558','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 17:18:07',0,NULL,3,1,3,1,' RA184572816CN','rhonda123*\rHSPL013\r英标'),(15554,591251424004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','greatdeals-super','greatdealsonfilm@aol.com','YOSEF NEWMAN','478 ALBANY AVE','BROOKLYN','NY','UNITED STATES','11203-1002','(646) 438-4276','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 17:25:29',0,NULL,3,1,1,1,'、 ','greatdeals-super'),(15555,878248349012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','edwinlala','edwin8282@gmail.com','Edwin Abdalian Chigani','7260 Apperson St<br>Apt 108','Tujunga','CA','UNITED STATES','91042-1871','(818) 813-1290','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 17:52:43',0,NULL,3,1,1,1,'、 ','edwinlala'),(15556,643285046013,230693030604,'New logitech Battery 190310-1000 2000 2001  for G7 mouse /MX revolution Mouse ',2,'BALO005',18.98,'eastar4','compet21','clement.arthur@gmail.com','CLEMENT Arthur','34 Rue Jean-Baptiste Pigalle','Paris','Ile-de-France','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 18:03:05',0,NULL,3,1,2,1,'\\  ','compet21'),(15557,878262892012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','thomasrfisher','thomasrfisher@comcast.net','Thomas Fisher','9330 SW Brooks Bend Pl','Portland','OR','UNITED STATES','97223','(503) 977-0508','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 18:11:44',0,NULL,3,1,1,1,'、 ','thomasrfisher'),(15558,792224838011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','bernd_alfa','b.hapke@yahoo.de','Bernd,Manfred Hapke','Ludwigstr.19','Pliening','','GERMANY','85652','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 18:15:33',0,NULL,3,1,2,1,'\\  ','bernd_alfa'),(15559,749650854001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','lpnkath2009','kathrobertson1@gmail.com','Adam Johnstone','2690 Highway 97 N','Kelowna','BC','CANADA','V1X4J4','(250) 870-1585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 18:19:26',0,NULL,3,1,2,1,'\\  ','lpnkath2009'),(15560,749562428001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','sakis321','k_nimit@hotmail.com','NIMIT KREUSANEH','Benyada Lodge, 106/52 Moo 3, Surin Beach<br>Cherngta lay, Talang,','Phuket','PET','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-08 18:30:58',0,NULL,3,1,2,1,'\\  ','sakis321\r'),(15561,792250744011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','byossii2009','byossii@gmail.com','yossi barooch','hzamir<br>2','naryia','israel','ISRAEL','22260','97248154000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 19:00:08',0,NULL,3,1,2,1,'\\  ','byossii2009'),(15562,878294804012,220620860324,'NEW GENUINE NOKIA BH-207 BLUETOOTH HEADSET BH 207',2,'HSNO010',49.8,'eastar4','jeffhuns','jeffh@clearviewglass.com','Jeff Hunsberger','11215 2nd Ave SE','Everett','WA','UNITED STATES','98208-5011','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-08 19:06:29',0,NULL,3,1,1,1,'\\  ','jeffhuns'),(15563,591288720004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',26.12,'cnfaner','tednarkansas','tednarkansas@cox-internet.com','Ted Nordsell','1408 S 11th St','Rogers','AR','UNITED STATES','72756-5232','(479) 631-6323','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 19:07:03',0,NULL,3,1,1,1,'、 ','tednarkansas'),(15564,591303583004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','madykoule','madysissoko@aol.com','MADY SISSOKO','9923 greenbelt rd<br>Apt 103','Lanham','MD','UNITED STATES','20706-2249','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 19:41:03',0,NULL,3,1,1,1,'、 ','madykoule'),(15565,792290757011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','cgbp2006','cb_1427@comcast.net','Carlos Bregante','1427 7th Pl S','Edmonds','WA','UNITED STATES','98020','(425) 776-5059','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 20:02:54',0,NULL,3,1,1,1,'、 ','cgbp2006'),(15566,643211732013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','hardtmuthsv','svetlovskiy@gmail.com','Oleksandr Svitlovskyi','str. Shturmanskiy 1/35','Dnipropetrovsk','Dnipropetrovsk','UKRAINE','49018','+380971005555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 20:05:31',0,NULL,3,1,2,1,'\\  ','hardtmuthsv'),(15567,585865250003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','fred.zeher','keysinspector@yahoo.com','FRED ZEHER','121 Sapodilla Dr','ISLAMORADA','FL','UNITED STATES','33036-4101','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 20:37:28',0,NULL,3,1,1,1,'\\  ','fred.zeher'),(15568,792327649011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006',26.99,'eastar4uk','ninamelvinkenny','niiiiina@live.se','Nina Lundström','Odlarvägen 6 J','Umeå','Västerbotten','SWEDEN','904 20','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 21:04:47',0,NULL,3,1,3,1,'RA184572303CN\r ','ninamelvinkenny\rGLOT006\r兼容型3D眼镜  Korea TV专用'),(15569,643375973013,230400357732,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',11.99,'eastar4','aniolek76','dobias76@yahoo.com','Tomasz Dobias','33 Leliarts Ln<br>Apt 2','Elmwood Park','NJ','UNITED STATES','07407-3201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 21:32:06',0,NULL,3,1,1,1,'、 ','aniolek76'),(15570,792346316011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','knutsteine','knut.steine@yahoo.no','Knut Steine','Frafjordgate 17','Sandnes','Rogaland','NORWAY','4307','98206679','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 21:34:16',0,NULL,3,1,2,1,'\\  ','knutsteine\r欧标'),(15571,749762714001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','gtooz1','chapinada@gmail.com','Hensy Centeno','120 6TH St<br>APT B','Pelham','NY','UNITED STATES','10803-1322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 21:34:36',0,NULL,3,1,1,1,'、 ','gtooz1'),(15572,643381113013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','zeddus','zed.zed@t-online.de','Zdravko Horvat','Dreherstrasse 247','Düsseldorf','','GERMANY','40625','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 21:44:38',0,NULL,3,1,2,1,'\\  ','zeddus\rHP 8pin 1.0 23cm '),(15573,877179106012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick Welsh','6 Langford Pl<br>Renfrewshire','Glasgow','Renfrewshire','UNITED KINGDOM','g53 7hz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 21:53:10',0,NULL,3,1,3,1,'RA184572189CN\r ','lochearn1234\rWLAP002'),(15574,878414692012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','bobmillie2007','robert@rsmith96.orangehome.co.uk','robert smith','24 purbrock avenue<br>garston','watford','Hertfordshire','UNITED KINGDOM','wd25 0ad','07773052766','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 22:08:18',0,NULL,3,1,3,1,'RA184572250CN\r ','bobmillie2007\rOTGR001+OTGR002'),(15575,585925119003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','trecia09','trecianeal@gmail.com','Trecia Neal','2433 Kingscliff Dr NE','Atlanta','GA','UNITED STATES','30345-2140','(770) 493-9175','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-08 23:46:34',0,NULL,3,1,1,1,'\\  ','trecia09'),(15576,792402083011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','kasiemsen11','kasiemsen@aol.com','Karen Siemsen','4866 Calle Bella Ave','Las Cruces','NM','UNITED STATES','88012-7057','(925) 525-6268','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 23:47:05',0,NULL,3,1,1,1,'、 ','kasiemsen11'),(15577,878477880012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.1,'eastar4','alarm-surplus','cyasurveillance@gmail.com','Darcy Willey','611 24 street','Brandon','MB','CANADA','R7a1X8','(204) 725-9390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 00:42:26',0,NULL,3,1,3,1,'RA184572175CN ','alarm-surplus\rOTCN004*10'),(15578,585936088003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','bratass1','jtazandbrat@yahoo.com','gerald massie','3915 fairfax dr','mims','FL','UNITED STATES','32754-5202','(321) 698-9717','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 00:40:13',0,NULL,3,1,1,1,'、 ','bratass1'),(15579,749857114001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','olah24','olah124@sbcglobal.net','Keith Brubaker','63 Berwyck Dr','Akron','OH','UNITED STATES','44312-1101','(330) 784-6133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 02:09:56',0,NULL,3,1,1,1,'、 ','olah24'),(15580,591429974004,140631692992,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',35.98,'cnfaner','thehorsevet','shawnfrehner@aol.com','Shawn Frehner','7245 N Tenaya Way','Las Vegas','NV','UNITED STATES','89131-2231','(702) 683-7910','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 03:09:47',0,NULL,3,1,1,1,'、 ','thehorsevet\r一共买了两个'),(15581,591437859004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',3,'HSPL010',94.02,'cnfaner','hugh-tei','hsimpson@trisim.com','Hugh Simpson','252 W. 20th St.<br>Unit B','Merced','CA','UNITED STATES','95340','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 03:56:08',0,NULL,3,1,1,1,'、 ','hugh-tei'),(15582,749885272001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','nobutapowershop','nobutapowerdivx@yahoo.com','Arie Wardhana Putra','Toko Monas Photo<br>Jl. Sisingamangaraja no 102','Kisaran','SUMATRA UTARA','INDONESIA','21222','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 04:10:26',0,NULL,3,1,2,1,'\\  ','nobutapowershop'),(15583,789531278011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','stickycharacters','sticky_characters@yahoo.com','Carlos Valero','1300 Banner Ct','Winter Springs','FL','UNITED STATES','32708-5233','(703) 475-3620','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 05:39:22',0,NULL,3,1,3,1,'RA184572285CN ','stickycharacters\rTRTS001*10'),(15584,792501622011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','j_b_a_v','joe_boyle@hotmail.com','Joe Boyle','The Zone Family Entertainment Complex<br>1 Gildea Lane, East Bendigo','Bendigo','Victoria','AUSTRALIA','3550','0417545325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 06:13:29',0,NULL,3,1,2,1,'\\  ','j_b_a_v'),(15585,792357863011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','paub0303','p.estrada5@yahoo.com','Paul Estrada','898 Ellen st','Colton','CA','UNITED STATES','92324-1122','(909) 885-7271','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'paub0303'),(15586,590647928004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',26.12,'cnfaner','ea356','bananazou812@hotmail.com','Larry Miranda','5126 Walnut Grove Ave','San Gabriel','CA','UNITED STATES','91776','(310) 741-8949','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 06:38:54',0,NULL,3,1,1,1,'、 ','ea356'),(15587,0,220886855461,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.25,'eastar4','corsicat04','dagnafr@yahoo.fr','DAGNA pierre','70 rue Douy Delcupe','montreuil','Ile-de-France','FRANCE','93100','0614303053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 08:42:28',0,NULL,3,1,2,1,'\\  ','corsicat04'),(15588,792533543011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','sirluvalot','blablabla@ozimail.com.au','Rob Bennett','P.O.Box 62<br>Toorak','Melbourne','Victoria','AUSTRALIA','3142','0404667202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 08:47:00',0,NULL,3,1,2,1,'\\  ','sirluvalot\r 无线蓝牙二合一'),(15589,643533566013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','talmihail','aronov_d@mail.ru','Daniel Aronov','kohen eli 24/28','Bat yam','','ISRAEL','59644','0507631952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 10:07:10',0,NULL,3,1,2,1,'\\  ','talmihail'),(15590,878635336012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','dee.0154','ddpinches@btinternet.com','delia pinches','195 rugeley road<br>chase terrace','burntwood','Staffordshire','UNITED KINGDOM','ws7 1ns','01543683754','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-09 10:44:37',0,NULL,3,1,3,1,' RA184572507CN\r','dee.0154\rLGAD001'),(15591,749977348001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','peterd3909','a44@xtra.co.nz','Peter Davidson','flat1 20 hellyers st birkdale','North shore city','Auckland','NEW ZEALAND','0626','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 11:21:29',0,NULL,3,1,2,1,'\\  ','peterd3909'),(15592,792580537011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',3,'ADAK002',37.8,'eastar4','mt.b-m.a','mt.b_m@tg.commufa.jp','Masatugu Aoyama','236-5 futago','kitanagoya-shi','Aichi','JAPAN','4810013','090-5603-1755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 11:32:33',0,NULL,3,1,2,1,'\\  ','mt.b-m.a'),(15593,732451793008,180699060430,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT006',42.74,'au-buy','satecomsystems','sarandos@satecom.gr','Costas Sarandos','13 a poseidonos<br>ATHENS GREECE','Moschato Athens greece','','GREECE','18344','302104833722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 12:40:23',0,NULL,3,1,3,1,' RA184572498CN','satecomsystems\rGLOT006\r兼容型3D眼镜  Korea TV专用'),(15594,643571507013,230653156192,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',46.99,'eastar4','bernardraj','bernraj@gmail.com','BERNARD RAJ THOMAS','59, JALAN BUKIT NONING 2,<br>TAMAN BUKIT NONING','BUKIT MERTAJAM','PENANG','MALAYSIA','14000','0124018597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 13:02:02',0,NULL,3,1,3,1,' RA184572419CN','bernardraj\rHSIT001'),(15595,586073294003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOSA007',49.99,'cnfaner','computerdoctor911','computerdr911@gmail.com','COMPUTER DOCTOR','597 E 138th St','Bronx','NY','UNITED STATES','10454-2727','(646) 533-3617','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 13:38:49',0,NULL,3,1,1,1,'\\  ','computerdoctor911\r发OEM的'),(15596,792618797011,320691205829,'New Original Nokia SU-8W Wireless Bluetooth Keyboard',1,'KBNO001',73.99,'eastar4','eegon_46','esko.turma@nic.fi','Esko Turma','Jokiranta 3','Rauma','','FINLAND','26100','+358405439795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 13:45:20',0,NULL,3,1,3,1,' RA184572484CN\r','eegon_46\rKBNO001'),(15597,878712209012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Lillian Fonvielle','1620 NORTHBROOK DR','CHARLOTTE','NC','UNITED STATES','28216-3778','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 14:20:44',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15598,878706128012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',2,'BTAC2013',19.76,'eastar4','epure11','eliodorviorel@yahoo.com','Epure Eliodor-Viorel','Tintasului 25','Bucuresti','Bucuresti','ROMANIA','012165','0040730051273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 14:05:46',0,NULL,3,1,2,1,'\\  ','epure11\racer 5pin1.25 15cm '),(15599,878713540012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Angela Beardon','5325 ORCHARD PARK LN','SANTA BARBARA','CA','UNITED STATES','93111-1674','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 14:24:15',0,NULL,3,1,1,1,'\\  ','321expressllc'),(15600,878716721012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','jbs70706','jbs70706@yahoo.com','Jon Smith','7850 Summer Place Ave','Baton Rouge','LA','UNITED STATES','70811-2624','(225) 405-7680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 14:33:50',0,NULL,3,1,1,1,'\\  ','jbs70706'),(15601,586077802003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',103.2,'cnfaner','mindoeh','minachu7+k@gmail.com','youje kim','41 Bancker St<br># KJ4618','Englewood','NJ','UNITED STATES','07631-4136','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 14:45:40',0,NULL,3,1,1,1,'\\  ','mindoeh'),(15602,643613036013,230624059030,'Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO009',40.89,'eastar4','ottlaptops','patrick.brochu@gmail.com','Patrick Brochu','20 rue de l\'Equateur','Gatineau','QC','CANADA','J9A3H4','(819) 772-9918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 15:29:31',0,NULL,3,1,3,1,' RA184572555CN','ottlaptops\rMOLO009'),(15603,792664906011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',20.9,'eastar4uk','alexiaseb','sebytrep@yahoo.fr','TREPIER SEBASTIEN','2 Lotissement le pré de la grange','ST JEAN DE CHEVELU','Rhône-Alpes','FRANCE','73170','0650954788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 15:35:07',0,NULL,3,1,2,1,'\\ ','alexiaseb'),(15604,591573491004,140631692992,'New Genuine Motorola HS850 Bluetooth Headset  track#',1,'HSMO019',17.99,'cnfaner','omat1111','matos1094@yahoo.com','Osvaldo Matos Fuentes','5776 Akron Ct','Las Vegas','NV','UNITED STATES','89142-2683','(702) 885-9650','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 16:01:49',0,NULL,3,1,1,1,'\\  ','omat1111'),(15605,0,320787444842,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',3.99,'eastar4uk','gnther6297','gwbauer@vr-web.de','Günther Bauer','Ostergadener Str.4','Altdorf/Eugenbach','','GERMANY','84032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 16:22:34',0,NULL,3,1,2,1,'\\  ','gnther6297'),(15606,878811235012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','peters3495','petersilvester41@hotmail.com','Peter Silvester','56 Constance Avenue<br>Trentham','Stoke on Trent','Staffordshire','UNITED KINGDOM','ST4  8XJ','01782644735','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-09 17:50:03',0,NULL,3,1,3,1,'RA184572541CN ','peters3495\rOTSO004*2'),(15607,0,320787313929,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',0.99,'eastar4','govea9','miguel.govea@yahoo.com','juan govea','2517 tristian ct','dallas','TX','UNITED STATES','75211','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 17:56:32',0,NULL,3,1,1,1,'\\  ','govea9'),(15608,792738293011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','toolfan','xplocvo@gmail.com','Brian Puntney','611 Sunnyview Ln','Marshall','WI','UNITED STATES','53559','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-09 18:01:19',0,NULL,3,1,1,1,'\\  ','toolfan'),(15609,878835200012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-09 18:30:50',0,NULL,3,1,3,1,'RA184572515CN\r ','lochearn1234\rWLAP002'),(15610,792820023011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','fredrick-floor','fredrickfloor@gmail.com','Fredrick Floor','Houttuinen-Zuid 21','APELDOORN','','NETHERLANDS','7325RJ','0681859811','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'fredrick-floor'),(15611,878927622012,220864622210,'New Philips Sonicare Essence 5500 Toothbrush Handle HX5500',1,'HBPH006',13.99,'eastar4uk','elitecoms1','john.leaves@talktalk.net','John Leaves','24 Tenby Court','Caerphilly','Caerphilly','UNITED KINGDOM','CF83 2UE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-09 20:44:58',0,NULL,3,1,3,1,'RA184578155CN\r ','elitecoms1\rHBPH006\r改发成HX5300'),(15612,792870561011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','vicenmp','vimarponce@gmail.com','Vicente Martinez Ponce','C/ Las Nieves nº2 3G','Molina de Segura','Murcia','SPAIN','30500','658928728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 21:42:10',0,NULL,3,1,2,1,'\\  ','vicenmp'),(15613,792882729011,320605519548,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',35.89,'eastar4','anthonydenine','anthony@toker.us','Anthony Denine','98 Donovan\'s Road<br>PO Box 926','Gould\'s','NL','CANADA','A1S 1H1','(709) 747-2613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 22:04:05',0,NULL,3,1,2,1,'\\  ','anthonydenine'),(15614,591718797004,140626376379,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',17.4,'cnfaner','sillyillyondra','sillyillyondra@yahoo.com','Sondra Cameron','6415 Old Orchard Way','Orangevale','CA','UNITED STATES','95662-4148','(916) 342-0956','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 22:37:53',0,NULL,3,1,1,1,'\\  ','sillyillyondra'),(15615,879007895012,220747231036,'NewGenuine SonyEricsson HBH-PV703 703 Bluetooth Headset',1,'HSSE004',13.9,'eastar4uk','si.marshall.1975','marshall.1975@hotmail.co.uk','simon marshall','30 scott road','crawley','West Sussex','UNITED KINGDOM','rh10 5dd','07867808750','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-09 23:12:00',0,NULL,3,1,3,1,' RA184572422CN\r','si.marshall.1975\rHSSE004\r英标'),(15616,879020114012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','jdasilva76','julie_dasilva2003@yahoo.com','Julie Levesque-DaSilva','1599 Startop Rd','Ottawa','ON','CANADA','K1B 5P5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 23:46:05',0,NULL,3,1,3,1,' RA184572467CN\r','jdasilva76\rGLOT005*2'),(15617,879028457012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','rcole62685','rcole62685@cox.net','frank cole','12959 N 149th Dr','surprise','AZ','UNITED STATES','85379-6903','(623) 412-0547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 00:05:26',0,NULL,3,1,1,1,'\\  ','rcole62685'),(15618,750322442001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',3,'OTAM001',17.97,'buysia','sakis321','k_nimit@hotmail.com','NIMIT KREUSANEH','Benyada Lodge, 106/52 Moo 3, Surin Beach<br>Cherngta lay, Talang,','Phuket','PET','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-10 00:53:21',0,NULL,3,1,2,1,'\\ ','sakis321'),(15619,879050133012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',19.76,'eastar4','mjelsma2006','marcel.jelsma@telfort.nl','Marcel Jelsma','Kamstrastraat 32','Franeker','','NETHERLANDS','8801VL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 01:09:19',0,NULL,3,1,2,1,'\\  ','mjelsma2006\racer 8pin1.00 15cm\r再发一个\rAcer Aspire 9410 9411 Bluetooth Module 2.0 EDR+cable\racer 4pin 1.25 18cm\rBTAC2008\r'),(15620,8881320889313629,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','David Birdwell','535 WAYLAND AVE<br>APT D','Kenilworth','IL','UNITED STATES','60043-1084','(503) 309-6418',NULL,NULL,NULL,'2011-11-10 01:41:53',0,NULL,3,1,1,1,'\\ ','补发的 \rLK011166139CN'),(15621,792973656011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',160.99,'eastar4','dairec2010','pes_dl@yahoo.com','Darik Luton','672 Shetland St','Little Elm','TX','UNITED STATES','75068-5905','(214) 202-6452','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-11-10 02:30:39',0,NULL,3,1,4,1,'YW867661886CN ','dairec2010'),(15622,586312761003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','carrie51','birdsbaby@comcast.net','CARRIE HOLMES','2503 Seven Oaks Rd','WAYNESBORO','GA','UNITED STATES','30830-5104','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 02:52:33',0,NULL,3,1,1,1,'\\  ','carrie51'),(15623,792976155011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','chuanlin','chli@esn.net','Xiaoshong Li','11 Mainhouse Ln','Savannah','GA','UNITED STATES','31419-8914','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 02:38:46',0,NULL,3,1,1,1,'\\  ','chuanlin'),(15624,643860449013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','jth86','onejth86@hotmail.com','Joe Hubbard','2508 Minnesota Ave<br>Apt O260','Lynn Haven','FL','UNITED STATES','32444-4820','(850) 271-1677','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 04:35:58',0,NULL,3,1,1,1,'\\  ','jth86'),(15625,591793772004,140630817542,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',53.19,'cnfaner','gemazdavit','gemazashvili@rambler.ru','davit gemazashvili','8 McCullough dr.<br>U40478','New Castle','DE','UNITED STATES','19720','(866) 411-9401','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 05:31:35',0,NULL,3,1,1,1,'\\  ','gemazdavit'),(15626,643884606013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','m-o-s-h','m-o-sh@yandex.ru','Dmitriy Zaytsev','40 Let Pobedi 90-57','Togliatty','Samarskaya oblast','RUSSIAN FEDERATION','445056','8(927)788-88-31','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 07:30:06',0,NULL,3,1,2,1,'\\  ','m-o-s-h'),(15627,8881320910842981,111,'2pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*2',0,'eastar4','sfox','grim_jack@rogers.com','Andrew Paton','15 Marshall Ave','Ottawa','ON','CANADA','K1Z 7X1','(613) 728-6023',NULL,NULL,NULL,'2011-11-10 07:40:42',0,NULL,3,1,3,1,' RA184572538CN\r','OTSO004*2\r补发\r盒装的\r两副'),(15628,793050123011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','kishan16','kriship5@gmail.com','Krish Nalam','1 Barrett Street','Kensington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 08:34:35',0,NULL,3,1,2,1,'\\  ','kishan16'),(15629,586368967003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',27.54,'cnfaner','lalin123','etaipe@aol.com','jesus taipe','45 Hampton Gdns','MIDDLESEX','NJ','UNITED STATES','08846-2182','(908) 334-1198','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 09:29:50',0,NULL,3,1,1,1,'\\  ','lalin123'),(15630,879181368012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','gbms13','geoffbecmatty@hotmail.com','Geoff Steele','65 Sunbury St','Geebung','Queensland','AUSTRALIA','4034','0738658875','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'gbms13'),(15631,732882618008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','kyawsannlwin09','kyawsannlwin@gmail.com','Kyaw Lwin','13 Bush Close<br>Beckenham','Perth','Western Australia','AUSTRALIA','6107','61423402716','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 09:48:17',0,NULL,3,1,2,1,'\\  ','kyawsannlwin09\r澳标'),(15632,879167190012,220886272004,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',31.85,'eastar4uk','fred_keks','vitaliylifr@gmail.com','Vitaliy Nesterenko','street Revenko 46/14','Kremenchuk','Poltava','UKRAINE','39600','0503085101','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 10:08:48',0,NULL,3,1,3,1,' RA184572847CN','fred_keks\rHSSE011\r欧标'),(15633,643919519013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','figenschouthoresen','siljefig@hotmail.com','silje figenschou thoresen','Bokbindarvägen 51, 5tr','129 34 Hägersten','Hägersten','SWEDEN','129 34','+46733950811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 10:51:44',0,NULL,3,1,2,1,'\\  ','figenschouthoresen'),(15634,642828485013,230623270363,'NIB 3D Active Shutter TV Glasses with IR emitter',1,'GLOT002+GLOT003',80,'eastar4','needithaveitdean','deanand90@hotmail.com','Dean Anderson','37 Trentham Road','Tylden','Victoria','AUSTRALIA','3444','0354248081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 11:10:20',0,NULL,3,1,3,1,' RA184572855CN','needithaveitdean\rGLOT002+GLOT003'),(15635,643928014013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','kandras83','kandras1983@freemail.hu','Kovárczi András','Pf.: 36.','Debrecen','','HUNGARY','4003','(36)30-9208255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 11:36:10',0,NULL,3,1,3,1,' RA184572864CN','kandras83\rLGGL002'),(15636,8881320925827485,111,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',0,'eastar4uk','satelit23-2008','mcatargiu2005@yahoo.com','marius bogdan catargiu','141a reynolds drive','edgware','Middlesex','UNITED KINGDOM','ha8 5px','07889109977',NULL,NULL,NULL,'2011-11-10 11:50:27',0,NULL,3,1,3,1,' RA184572820CN','补发的\rGLOT001 \r兼容型3D眼镜 通用型'),(15637,879219828012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Jennifer Barthold','2783 Shermer Rd<br>C/O Con-Tech Lighting','Northbrook','IL','UNITED STATES','60062-7708','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 12:09:28',0,NULL,3,1,1,1,'\\  ','bigtimepimp'),(15638,732922240008,180730162648,'GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',31.34,'au-buy','sesamico','kprintservice@gmail.com','Kalin Chakarov','kw. Chaika, villa149','Varna','Varna','BULGARIA','9010','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 12:16:35',0,NULL,3,1,3,1,' RA184572714CN','sesamico\r欧标\rHSPL011'),(15639,643942248013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','imysak','ihor.mysak@gmail.com','Ihor Mysak','Nasypna str. 11, fl. 3','Lviv','Lviv','UKRAINE','79019',' 380931445890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 12:43:04',0,NULL,3,1,2,1,'\\  ','imysak'),(15640,643952041013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lemon8haasi','haas_th@web.de','Thomas Haas','Hege 71','Wasserburg','','GERMANY','88142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 13:29:56',0,NULL,3,1,2,1,'\\  ','lemon8haasi'),(15641,750505061001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','ziggylongleaf','nagrom7@rodneyokee.com','Morgan Fain','12450 NE 22nd Ave','Okeechobee','FL','UNITED STATES','34972-4810','(863) 634-9462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 13:42:18',0,NULL,3,1,1,1,'\\  ','ziggylongleaf'),(15642,793141517011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','tasoulis4','tasoulis12@hotmail.com','Tassos Mousoulides','Block A, Hazlerigg-Rutland, Loughborough University','LOUGHBOROUGH','Leicestershire','UNITED KINGDOM','LE11 3TZ',' 07719160741','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-10 13:49:02',0,NULL,3,1,3,1,' RA184572802CN','tasoulis4\rMOAP001'),(15643,793146980011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',67.96,'eastar4uk','mac111s','yannmac@yahoo.com','yann mccullough','62 city way','rochester','Kent','UNITED KINGDOM','me1 2ae','07770692641','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-10 14:06:17',0,NULL,3,1,3,1,' RA184572728CN','mac111s\rMOAP001'),(15644,585009286003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.03,'cnfaner','solifer2012','svein@ursin.us','Svein Olav Ursin','Seida','Tana','','NORWAY','9845','95028507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 14:34:07',0,NULL,3,1,3,1,' RA184572793CN','solifer2012\r黑色的 欧标\rHSJA004'),(15645,643967026013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','needlenudl','needle.nudl@gmail.com','Oleg Malevsky','Profsoyznaya 114-6-829','Moskow','Moskow','RUSSIAN FEDERATION','117437','+79651592645','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 14:38:48',0,NULL,3,1,2,1,'\\  ','needlenudl'),(15646,793179331011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','blackcorrot','assero@globo.com','Ricardo Assero Gonçalez','Rua Sao Damasio, 16','Sao Paulo','SP','BRAZIL','04255-100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 15:29:54',0,NULL,3,1,2,1,'\\  ','blackcorrot'),(15647,643988281013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 15:35:42',0,NULL,3,1,6,1,'EE645619149CN ','revikom\r兼容型3D眼镜 通用型'),(15648,879309052012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',23.74,'eastar4','convesp','convesp@aol.com','Joanna Rios','3729 N Bay Horse Loop','Tucson','AZ','UNITED STATES','85719-1983','(520) 247-3704','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 16:01:42',0,NULL,3,1,1,1,'\\  ','convesp\r蓝天白云长柄伞'),(15649,879331159012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','dwof5603','fa35jsf@yahoo.com','Drew Wofford','1800 Beaumont Dr<br>Appt: 1622','Norman','OK','UNITED STATES','73071-2255','(281) 636-4263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 16:49:30',0,NULL,3,1,1,1,'\\  ','dwof5603'),(15650,793225561011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','butchboi326','butchboi326@yahoo.com','preston myers','457 main st<br>#4','East Haven','CT','UNITED STATES','06512','(203) 809-7831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 17:34:41',0,NULL,3,1,1,1,'\\  ','butchboi326'),(15651,793234250011,320730085617,'New Atheros AR5008 802.11N Wireles WiFi Mini PCI-E Card',1,'WLAT001',8.99,'eastar4uk','mikler_darmik','miklergm@gmail.com','Michael Orlov','ul. Nevskyj pr., d. 146, kv. 111','Saint-Petersburg','','RUSSIAN FEDERATION','191024','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 17:35:39',0,NULL,3,1,2,1,'\\  ','mikler_darmik\r已发货     \r点不了'),(15652,733048656008,180730162648,'GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',31.34,'au-buy','sesamico','kprintservice@gmail.com','Kalin Chakarov','kw. Chaika, villa149','Varna','Varna','BULGARIA','9010','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 18:03:23',0,NULL,8,1,17,0,NULL,'sesamico'),(15653,586494959003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.34,'cnfaner','gorditochulo2009','gorditochulo2008@yahoo.com','Nasser Abdellah','600 Concord Ave<br>Apt 5A','Bronx','NY','UNITED STATES','10455','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 18:03:34',0,NULL,3,1,1,1,'\\  ','gorditochulo2009'),(15654,644050397013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','lvc-executor','jscythe@gmail.com','Oleg Kosan','Kashtanova str. 26-4','Obukhiv,','Kyiv region','UKRAINE','08704','(+380) 68 599-30-12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 18:51:47',0,NULL,3,1,2,1,'\\  ','lvc-executor'),(15655,879394945012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','end90-_iljung','enderson_kinjo@yahoo.com.br','Enderson Hideki Kinjo','R. Lino Coutinho, 1397<br>Ipiranga','Sao Paulo','Sao Paulo','BRAZIL','04207-001','55 11 92572067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 18:52:13',0,NULL,3,1,3,1,' RA184572776CN','end90-_iljung\rWWOT003'),(15656,793281725011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','metraa_01','dimitrea.hanley@gmail.com','Dimitrea A Hanley','1200 US Highway 22<br>U.s. Express #10136 Ste 2000','Bridgewater','NJ','UNITED STATES','08807-2943','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 19:09:51',0,NULL,3,1,1,1,'\\  ','metraa_01'),(15657,793361641002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','pastpart','nickyoatesuk@yahoo.co.uk','nicky OATES','1 Druridge Crescent,Newsham Farm Estate','BLYTH','Northumberland','UNITED KINGDOM','NE244SA','01912669846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 19:37:46',0,NULL,3,1,2,1,'\\  ','pastpart\r加勒比海盗'),(15658,586539156003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','ezzellmooney201','wmezzell@gmail.com','William Ezzell','1555 Burgundy Ct','Elkhart','IN','UNITED STATES','46514-4764','(574) 262-1934','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 19:55:13',0,NULL,3,1,1,1,'\\  ','ezzellmooney201'),(15659,793319099011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','moogum961','terrysuz@optusnet.com.au','Terence McWhinney','460 Elliots Road','Myrtle Creek','New South Wales','AUSTRALIA','2469','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 20:05:41',0,NULL,3,1,2,1,'\\  ','moogum961'),(15660,793325874011,320730084394,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',20.65,'eastar4uk','woottog','gary.wootton@btinternet.com','gary wootton','33 blythwood drive','camberley','Surrey','UNITED KINGDOM','gu168ty','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-10 20:15:48',0,NULL,3,1,3,1,' RA184572731CN','woottog\rHSPL010\r英标'),(15661,793361710011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','denzel0626','bukimelman@gmail.com','Benjamin Kimelman','1748 Novato Blvd<br>Ste 100','Novato','CA','UNITED STATES','94947-7855','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 21:15:13',0,NULL,3,1,1,1,'\\  ','denzel0626'),(15662,592032137004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','alexmart845','nintram2@citlink.net','Alexander Martin','56 Acorn Ave','Middletown','NY','UNITED STATES','10941-1670','(845) 695-1401','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 21:42:20',0,NULL,3,1,1,1,'\\  ','alexmart845'),(15663,643567499013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','azimut2010','alejandro.pedroche@hotmail.com','Alejandro Fernandez de la','C/Zuloaga, 16 - Bajo D','Majadahonda','Madrid','SPAIN','28222','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 22:05:10',0,NULL,3,1,2,1,'\\  ','azimut2010'),(15664,586589901003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','eklisuarf','holters@uni-muenster.de','Jürgen Hölters','Meinertzstraße 10b','Münster','','GERMANY','48159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 22:09:58',0,NULL,3,1,3,1,' RA184572780CN','eklisuarf\rWLAT003'),(15665,590978667004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.29,'cnfaner','g.giungato','gdonato@itdnsd.it','Giuseppe Donato','Via Cagliari 28','Torino','TO','ITALY','10153','3351293210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 22:35:34',0,NULL,3,1,3,1,' RA184572833CN','g.giungato\rWLDE002'),(15666,586604243003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','slov2080','sl6561@aol.com','Susan Lovell','38 Woodhill Drive','Rochester','NY','UNITED STATES','14616','(585) 865-6561','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 22:58:26',0,NULL,3,1,1,1,'\\  ','slov2080'),(15667,592057808004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','407fritz6','fritzdieujuste97@yahoo.com','Fritz Dieujuste','5636 OAk hill Manor DR','Orlando','FL','UNITED STATES','32839-2502','(407) 879-0046','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 23:05:52',0,NULL,3,1,1,1,'\\  ','407fritz6'),(15668,793409941011,320519483654,'8V AC Adapter Charger Power Supply Logitech Harmony 880',1,'POLO001',6.99,'eastar4','jay_c2617','jay_carters@hotmail.com','Jay Carters','Unit 27<br>202 The Esplanade','Burleigh Heads','Queensland','AUSTRALIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 22:57:59',0,NULL,3,1,2,1,'\\ ','jay_c2617'),(15669,750771454001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','judie399','judiemelton@aol.com','JUDIE MELTON','6511 PRAIRIE FLOWER','ROSCOE','IL','UNITED STATES','61073-7262','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 23:28:20',0,NULL,3,1,1,1,'\\ ','judie399'),(15670,879571786012,220845507435,'NIB Genuine Samsung 3D glasses + monster VS Aliens disc',1,'GLSG001*2+BR3D002',121.99,'eastar4','kashe84','kashe2003@hotmail.com','ISAAC HUERTA','1710 MAPLE LN','elgin','IL','UNITED STATES','60123','(630) 329-5229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 00:12:26',0,NULL,3,1,1,1,'\\  ','kashe84'),(15671,750783275001,110694697092,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',17.97,'buysia','sakis321','k_nimit@hotmail.com','T00A1864 NIMIT KREUSANEH','17230 NE Sacramento St<br>Ste T00A1864','Portland','OR','UNITED STATES','97230-5940','503 736 5916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 00:14:15',0,NULL,3,1,1,1,'\\ ','sakis321\r一共买了三个\rLK016180217CN\r没下来'),(15672,750797951001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','kelygary','shbmw323@aol.com','gary hamer','5382 steven rd','boynton beach','FL','UNITED STATES','33472','(561) 317-8485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 01:06:24',0,NULL,3,1,1,1,'\\  ','kelygary'),(15673,879590401012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','penny1956purple','pennys56@neo.rr.com','Penny Smith','90 Walker Ave S','Mansfield','OH','UNITED STATES','44905-3051','(419) 589-9424','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 01:08:00',0,NULL,3,1,1,1,'\\  ','penny1956purple'),(15674,733245958008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','jreinseth','jreinseth@yahoo.com','james reinseth','P.O. Box 8007','Nanwalek','AK','UNITED STATES','99603','(907) 281-2351','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 01:29:41',0,NULL,3,1,1,1,'\\  ','jreinseth'),(15675,8881320976592409,111,'AUI-AT210T',30,'TRTT002',210,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Holzhofallee 21','Darmstadt','','GERMANY','64295','',NULL,NULL,NULL,'2011-11-11 01:56:32',0,NULL,3,1,12,1,'1733260255\r ','AUI Transceiver  210T\rTRTT002 \r直接打款的'),(15676,879607808012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','graton19','graton19@hotmail.com','Simon Blain Auclair','89 osborne','scotstown','QC','CANADA','j0b 3b0','(819) 657-4272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 02:00:46',0,NULL,3,1,3,1,' RA184572762CN','graton19\rGLOT001*2\r兼容型3D眼镜 通用型'),(15677,8881320977620062,111,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',4,'MOOE003',199.96,'cnfaner','karimusu','karinita1230@hotmail.com','Rixon Moreno','888 Biscayne Blvd #4106','Miami','FL','UNITED STATES','33132','',NULL,NULL,NULL,'2011-11-11 02:13:40',0,NULL,3,1,4,1,'YW867660490CN ','MOOE003 \r发OEM的'),(15678,0,230696401553,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',0.99,'eastar4','forcexlz','timcordero@gmail.com','William Cordero','540 Mobley Dr','Deltona','FL','UNITED STATES','32725-8271','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 02:40:19',0,NULL,3,1,1,1,'\\  ','forcexlz'),(15679,644195099013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','paintpro88','77.cabadaj@gmail.com','Peter Cabadaj','Zdravotnicka 703/5','Dunajska Luzna','','SLOVAK REPUBLIC','90042','00421911313469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 02:40:31',0,NULL,3,1,3,1,'RA184572904CN ','paintpro88\rGPS0006'),(15680,793480582011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','philippewic','phwi@hotmail.com','Philippe Wieczorek','4871 draper','montreal','QC','CANADA','h3x3p6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 02:52:28',0,NULL,3,1,2,1,'\\  ','philippewic'),(15681,793516571011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',2,'HSJA006',27.9,'eastar4','jaxown','ourrefuge@msn.com','Joan John Fields','440 Mt Hood Dr SW','Issaquah','WA','UNITED STATES','98027','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 05:34:36',0,NULL,3,1,1,1,'、 ','jaxown'),(15682,793518390011,320687874748,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.99,'eastar4','blairdanielle','blair.d.schmidt@gmail.com','Blair Schmidt','866 Reddekopp Drive','Martensville','SK','CANADA','S0K 0A2','(306) 384-4201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 05:45:58',0,NULL,3,1,2,1,'、 ','blairdanielle'),(15683,8881320992803109,111,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'aliexpress','1005193651','ryurix@gmail.com','Yuriy Gorbachev	','Pirogova 3/1 apt.802','Tyumen','Tyumen','RUSSIAN FEDERATION	','625043','89220799807',NULL,NULL,NULL,'2011-11-11 06:26:43',0,NULL,3,1,3,1,' RA184579575CN\r','RMSN002\rSONY MCE 遥控  白色   RM-MCE20E'),(15684,8881320992895145,111,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',0,'eastar4','davefc','dfc0759@att.net','David Cupp','95 17th st NW','Barberton','OH','UNITED STATES','44203-7117','',NULL,NULL,NULL,'2011-11-11 06:28:15',0,NULL,3,1,1,1,'、 ','只补发一个 遥控器LK014127222CN '),(15695,879722014012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Ronald E. Alford','1075-182 Space Park Way','Mountain View','CA','UNITED STATES','94043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 09:54:57',0,NULL,3,1,1,1,'\\ ','321expressllc'),(15685,8881320994600776,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000 ',1,'BALO007',0,'eastar4','mos_514','ha.bach@gmail.com','Bach Ha','2482A Notre-Dame Ouest','Montreal','QC','CANADA','H3J 1N5','(514) 377-8255',NULL,NULL,NULL,'2011-11-11 06:56:40',0,NULL,3,1,2,1,'、 ','补发的 '),(15686,793541428011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','locutus001','jan.golmajer@gmail.com','Jan Golmajer','Žiganja vas 15','Križe','','SLOVENIA','4294','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 07:42:59',0,NULL,3,1,3,1,'RA184572895CN ','locutus001\rGLSG001'),(15687,591446158004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','essexcounty','dodgekia@gmail.com','RORIEANN  VERNON c/o ORAL VERNON','370 Central Ave<br>Apt T4','ORANGE','NJ','UNITED STATES','07050-2427','(862) 438-2347','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-11 08:17:24',0,NULL,3,1,1,1,'、 ','essexcounty\r'),(15688,793548015011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','durdom7777','starikov_e@xaker.ru','Evgeny Starikov','Parkway Tuhvata Janabi 24 sq. 87<br>Бульвар Тухвата Янаби 24 кв. 87','Ufa / Уфа','Kalininskij rajon / Калининский район','RUSSIAN FEDERATION','450039','89273434490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 08:18:17',0,NULL,3,1,2,1,'、、 ','durdom7777\racer 4pin1.25 15cm '),(15689,793211699011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','Maria Jose Jimenez Benitez','C/ JUAN DE ORTEGA Nº9 BLQ 3 11ºA','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 09:00:25',0,NULL,3,1,3,1,' RA184572970CN\r','latiendadelsotano\rGLOT001*4\r兼容型3D眼镜 通用型'),(15690,0,220886855293,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.99,'eastar4','micah.smet','micah.smet.ebay@gmail.com','Micah Smet','305 Duke St<br>Apt 2','Saint John','NB','CANADA','E2L 2W4','(506) 721-4661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 09:09:12',0,NULL,3,1,2,1,'、 ','micah.smet'),(15691,592159199004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','chuchu0298','pascal.lachuer@orange.fr','Pascal Lachuer','44 rue de la baie, ploujean','Morlaix','Bretagne','FRANCE','29600','0298720784','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-11 09:13:41',0,NULL,3,1,3,1,' RA184572966CN\r','chuchu0298\rRCLO006'),(15692,8881321004146924,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'aliexpress','1005196392','nossster@gmail.com','Dmitry Pominov	','st. Odesska, 3, app 7','Moscow','Russia','RUSSIAN FEDERATION	','117638','+7 926 2624888',NULL,NULL,NULL,'2011-11-11 09:35:46',0,NULL,3,1,3,1,' RA184579363CN','WLAT008 '),(15693,879719881012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','estevan garcia','600 West Arizona<br>Bogard Hall Rm 234','Ruston','LA','UNITED STATES','71272-0001','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 09:47:40',0,NULL,3,1,1,1,'\\ ','321expressllc'),(15694,879721000012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Phoebe Zwyssig','132 Coral Cay Dr','Palm Beach Gardens','FL','UNITED STATES','33418-4007','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 09:50:20',0,NULL,3,1,1,1,'\\ ','321expressllc'),(15696,793198212011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','funkenerosionbes','info@bes-edm.de','bes Funkenerosion GmbH','Hafnerweg 3','Fluorn-Winzeln','','GERMANY','78737','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 10:22:05',0,NULL,3,1,3,1,' RA184579536CN\r','funkenerosionbes\rTRTS001*10'),(15697,877981703012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','lovegaku2002','liquid@mx10.ttcn.ne.jp','Osamu Kawabe','7-40<br>Idasugiyama-cho Nakahara-ku','Kawasaki','Kanagawa','JAPAN','211-0036','090-4943-5074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 10:29:55',0,NULL,3,1,3,1,' RA184579425CN','lovegaku2002\rMOAP001'),(15698,879734577012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','James Cullom','5961 134th Ave','Hamilton','MI','UNITED STATES','49419-9317','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 10:34:42',0,NULL,3,1,1,1,'\\ ','321expressllc'),(15699,879795874012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ericernie1','tonyov@sky.com','Anthony  Overett','75, Argyll Road','Blackpool','Lancashire','UNITED KINGDOM','FY2 9TH','01253508171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 13:36:23',0,NULL,3,1,3,1,' RA184579451CN','ericernie1\rHBPH007'),(15700,586764426003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','jrdlab','lisaannb1@sunflower.com','Lisa Blosser','1416 Lawrence Ave','Lawrence','KS','UNITED STATES','66049','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-11 13:41:04',0,NULL,3,0,1,1,'\\ ','jrdlab'),(15701,793651824011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',20.9,'eastar4uk','bram1701','ger.kors@upcmail.nl','Ger Kors','Westerzoom 8','Koog aan de Zaan','','NETHERLANDS','1541TW','0652275443','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 14:03:42',0,NULL,3,1,2,1,'\\  ','bram1701'),(15702,879812888012,220449147561,'Samsung R40 R45 R70 Bluetooth Module 2.0 EDR+cable',1,'BTSA2001',9.88,'eastar4','ultrafinopanamasombrero','santysono@yahoo.es','santiago parreño','santa tecla # 43 piso bajo c','madrid','Madrid','SPAIN','28022','622072870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 14:16:23',0,NULL,3,1,2,1,' \\ ','ultrafinopanamasombrero'),(15703,644339800013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',23.74,'eastar4','vivi.suckow','vi.csuckow@gmail.com','Viviane Suckow','Rua Colombo, 869','Curitiba','Paraná','BRAZIL','201000','41 3352-9272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 14:27:17',0,NULL,3,1,11,1,'、 ','vivi.suckow\r钢琴美女伞 \r粉红色的'),(15704,793661549011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','maggiemouli','masa60@rf6.so-net.ne.jp','MASAHIRO MURE','YUZATO 1-2-12<br>HIGASHISUMIYOSHI KU','Osaka','Osaka','JAPAN','5460013','+818031092528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 14:28:26',0,NULL,3,1,3,1,' RA184579690CN\r','maggiemouli\rHSNO031+HSNO006\r再发一个NEW GENUINE NOKIA BH-202 '),(15705,0,320787444786,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',0.99,'eastar4uk','chris-hovercraft-museum','srn4@ntlworld.com','Mr Christopher Potter','12 Ferndale Road<br>Collier Row','Romford','Essex','UNITED KINGDOM','RM5 3ER','07971607556','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 14:29:57',0,NULL,3,1,3,1,' RA184579496CN\r','chris-hovercraft-museum\rSCLO004'),(15706,644341395013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','sona813016','ivpww@bww.com','ivan pesina','8334 JENNINGS ST','HOUSTON','TX','UNITED STATES','77017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 14:31:15',0,NULL,3,1,1,1,'\\ ','sona813016'),(15707,879820648012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','haja*2010','hagit.mulian@gmail.com','Hagit Mulian','9 B Arlozorov St<br>APT 17','Ramat Gan','','ISRAEL','52481','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 14:39:32',0,NULL,3,1,11,1,'\\  ','haja*2010\r蕾丝蝴蝶结伞 黑色'),(15708,879822746012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.98,'eastar4','maggiemouli','masa60@rf6.so-net.ne.jp','MASAHIRO MURE','YUZATO 1-2-12<br>HIGASHISUMIYOSHI KU','Osaka','Osaka','JAPAN','5460013','+818031092528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 14:39:58',0,NULL,8,1,17,0,' ','maggiemouli\r'),(15709,733429997008,180699061189,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',94.98,'au-buy','odeddo','doron.oded@gmail.com','Doron Oded','Dafna 12 (b) st.','Ramat Ishay','Israel','ISRAEL','30095','04-6555589','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 14:47:00',0,NULL,3,1,3,1,' RA184579709CN\r','odeddo\rGLSG001'),(15710,644357587013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','stevenstpierre','stevenstpierre@hotmail.com','Steven St-Pierre','2-5740 rue Corneille','Brossard','QC','CANADA','J4Z 0K5','(438) 881-1814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 15:26:05',0,NULL,3,1,2,1,'\\ ','stevenstpierre'),(15711,793686051011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','momoney243','kelldog243@aol.com','Elaine Jordon','5256 Saint Charles Ave','Baltimore','MD','UNITED STATES','21215-5043','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 15:37:48',0,NULL,3,1,1,1,'\\ ','momoney243'),(15712,793703551011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',20.9,'eastar4uk','gsloney4281','gsloney@bellsouth.net','Gary Loney','10665 NW 69th Pl','Parkland','FL','UNITED STATES','33076-2969','(954) 344-4708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 16:13:20',0,NULL,3,1,1,1,'\\ ','gsloney4281'),(15713,644372444013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','silvarg17','serebriakov.oleg@gmail.com','Oleg Serebryakov','Zakharinskiye dvoriki, 3, 303','Moscow','','RUSSIAN FEDERATION','117148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 16:15:02',0,NULL,3,1,2,1,' \\ ','silvarg17'),(15714,793722258011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','jim-jamgemma','jim-jam27291@hotmail.com','Gemma Powrie','17 Knutsford Street','Salford','Greater Manchester','UNITED KINGDOM','M6 5QU','01612781750','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 16:50:11',0,NULL,3,1,3,1,' RA184579655CN\r','jim-jamgemma\rLGGL002'),(15715,751095484001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','wildbill12953','wbh2101@hotmail.com','Bill Hickok','2101 Plainfield Dr','Des Plaines','IL','UNITED STATES','60018-2732','(847) 800-5326','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 18:23:23',0,NULL,3,1,1,1,'\\ ','wildbill12953'),(15716,879942749012,220759961775,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',25.99,'eastar4','flurffmeister','ifury@me.com','Dennis Field','1713 Cobalt Dr','Louisville','KY','UNITED STATES','40299-2449','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 18:34:57',0,NULL,3,1,1,1,'\\ ','flurffmeister'),(15717,793781504011,320752524259,'Original Logitech Harmony 890 LCD Remote Control US',1,'RCLO003',160.99,'eastar4','jmon4772','shirley.lake@gdtruck.com','James Montagnino','22 Way Road','Gloucester','MA','UNITED STATES','01930','(978) 815-8346','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-11-11 18:45:22',0,NULL,3,1,4,1,'YW867660501CN ','jmon4772'),(15718,879952190012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','gobbo7556','martin@hull1554.freeserve.co.uk','martin hull','L.M.Motors<br>emscote street south','halifax','west yorkshire','UNITED KINGDOM','hx1 3an','07855505546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 18:49:52',0,NULL,3,1,3,1,' RA184579301CN','gobbo7556\rOTGR001'),(15719,879954916012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','hautboish','hautboish@free.fr','hervé hautbois','6 rue du Chemin Vert','La Ville aux Clercs','Centre','FRANCE','41160','0684338723','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 18:55:17',0,NULL,3,1,2,1,' \\ ','hautboish'),(15720,751118498001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','benimports','benebessa@yahoo.com.br','ENZO GAGLIANONE','Rua Sousa Franco Nº - 692 Apto - 503','RIO DE JANEIRO','RIO DE JANEIRO','BRAZIL','20551-120','5521 9664-2723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 19:07:49',0,NULL,3,1,2,1,'\\  ','benimports'),(15721,879977362012,220815931012,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',12.99,'eastar4uk','wish*you*well','rain171bow@gmail.com','Svitlana Capewell','37 Lodge Road','Coventry','West Midlands','UNITED KINGDOM','CV3 1FU','02476440070','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 19:32:17',0,NULL,3,1,3,1,'RA184579743CN ','wish*you*well\rHSJA012\r  英标'),(15722,793810211011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','noirchapitre','dominiquepiotte@hotmail.com','PIOTTE dominique','Chemin de l\'Inquiétude 6 - 7 - 8<br>( Police Judiciaire Fédérale )','MONS','','BELGIUM','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 19:37:42',0,NULL,3,1,2,1,' \\ ','noirchapitre'),(15723,793828933011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','lysgeir','geir@lysnes.com','Geir Lysnes','Lystad','Kvelde','Vestfold','NORWAY','3282','99030030','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 20:12:12',0,NULL,3,1,3,1,' RA184579584CN\r','lysgeir\rLGGL002'),(15724,733591639008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','5696leeo','l_ohara@sky.com','Mrs Jayne O\'Hara','T@lecom Limited<br>The Technocentre, Puma Way','Coventry','West Midlands','UNITED KINGDOM','CV1 2TT','07807060987','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 20:12:54',0,NULL,3,1,3,1,' RA184579403CN','5696leeo\rHBPH007'),(15725,586903420003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',19.85,'cnfaner','reborn1911','toeknee.loser@hotmail.com','Tony Tang','606 Alvarado Ave<br>Apt. 93','Davis','CA','UNITED STATES','95616-0731','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-11 20:46:13',0,NULL,3,1,1,1,'\\ ','reborn1911'),(15726,880023776012,220539231537,'New Logitech Cradle L-LG7 for Harmony remote 880 890',1,'CRLO001',12.99,'eastar4','bitwiserprof','prof@bitwisertraining.com','Terry Haury','13775 Pine Country Ln','Conifer','CO','UNITED STATES','80433-5012','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 20:48:39',0,NULL,3,1,1,1,'\\ ','bitwiserprof\rBALO001\r再发两个罗技遥控电池 蓝色 新 950mah'),(15727,793851814011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','123.grickett05','grickett05@googlemail.com','gary rickett','5 lennox avenue','carrickfergus','Antrim','UNITED KINGDOM','bt387bb','02893350594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 20:51:47',0,NULL,3,1,3,1,' RA184579434CN','123.grickett05\r英标\rHSNO026'),(15728,793851339011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',2,'BALO001',23.98,'eastar4','bitwiserprof','prof@bitwisertraining.com','Terry Haury','13775 Pine Country Ln','Conifer','CO','UNITED STATES','80433-5012','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-11 20:51:53',0,NULL,8,1,17,0,NULL,'bitwiserprof'),(15729,880039890012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','vcimendag69','vcimendag@msn.com','vedat çimendağ','ivedik organize sanayi 88. oto san sitesi 2. bölge 726.sokak 26<br>yenimahalle','ankara','turkey','TURKEY','06160','+903123954574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 21:19:07',0,NULL,3,1,3,1,' RA184579346CN','vcimendag69\rGLOT001*2\r兼容型3D眼镜 通用型'),(15730,793873166011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','bddear','bngdear@bell.net','brian dear','4339 Henry Ave.','Beamsville','ON','CANADA','L0R 1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 21:34:57',0,NULL,3,1,2,1,' \\ ','bddear'),(15731,586921584003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.34,'cnfaner','cklinvestmentsco','cklinvestments@att.net','JOHN LE','1018 OAK HILL PARK','KENNEDALE','TX','UNITED STATES','76060-5619','(817) 673-3014','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-11 21:37:35',0,NULL,3,1,1,1,'\\ ','cklinvestmentsco'),(15732,880066352012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','shotie-450','shotie450@hotmail.com','Fred Fleming','1 Epping Street<br>Glenroy','Melbourne','Victoria','AUSTRALIA','3046','0393591220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 22:10:10',0,NULL,3,1,2,1,' \\ ','shotie-450'),(15733,880080043012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','telhaug1','telhaug1@frisurf.no','John Olav Telhaug','Bryggeså','EIKEN','','NORWAY','4596','+4795207119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 22:39:17',0,NULL,3,1,2,1,' \\ ','telhaug1'),(15734,793918488011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dwg1892','dwgamble@hotmail.com','David Gamble','23 Ballyskeagh Road<br>Artigarvan','Strabane','Tyrone','UNITED KINGDOM','BT82 0HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 23:23:59',0,NULL,3,1,3,1,' RA184579377CN','dwg1892\rMOAP001'),(15735,586980023003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','mrob3237','poch641@yahoo.com','Michael Robinson','15741 Glenwood St','Detroit','MI','UNITED STATES','48205-3056','(313) 957-9409','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-12 01:48:30',0,NULL,3,1,1,1,'\\ ','mrob3237'),(15736,793328970011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','tormetropc','mtp67@telus.net','David  Black','8411-135 Avenue','Edmonton','AB','CANADA','T5E 1M9','(780) 456-4334','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-12 02:07:16',0,NULL,3,1,2,1,' \\ ','tormetropc'),(15737,879904948012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',23.74,'eastar4','2412_evgen','maska2s@mail.ru','Evgeniy Goshko','Ulyanovskiy str. 18-20','KRASNOYARSK','Krasnoyarsk','RUSSIAN FEDERATION','660111','+79607524947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 02:20:02',0,NULL,3,1,11,1,'\\  ','2412_evgen\r蕾丝花边伞 '),(15738,751298898001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','mikelowe168','mikelowe168@yahoo.com','michael lowe　(KIRIN　PRODUCE)','22 Oxford St<br>(Basement) # 24','BOSTON','MA','UNITED STATES','02111-2038','(617) 719-6114','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 03:41:15',0,NULL,3,1,1,1,'\\ ','mikelowe168'),(15739,592448167004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',26.2,'cnfaner','marier218','mtigers2001@gmail.com','Marie Clausen','1115 Oak St<br>Apt 2','Crosby','mn','UNITED STATES','56441-1145','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-12 03:44:17',0,NULL,3,1,1,1,'\\ ','marier218'),(15740,793988618011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','mart_2010','martbashnetru@gmail.com','ANDREY OBUKH','Aksakova 62-147','Ufa','Bashkortostan','RUSSIAN FEDERATION','450052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 03:51:58',0,NULL,3,1,2,1,' \\ ','mart_2010'),(15741,880187380012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','meggaman101','meggaman101@hotmail.com','joe simonetta','#2-2929 Quadra St','victoria','BC','CANADA','V8T4E9','(250) 893-2090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 04:45:02',0,NULL,3,1,2,1,'\\  ','meggaman101'),(15742,880186458012,220756338344,'Logitech MX1000 MX600 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',16.99,'eastar4','tabsaw','svanos49@gmail.com','Stephen Van Osdell','7182 Wethersfield Dr','Maineville','OH','UNITED STATES','45039-8870','(513) 207-5667','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 05:25:17',0,NULL,3,1,1,1,'\\ ','tabsaw\r再发一个New Logitech Rechargeable battery L-LB2 1700mAh MX1000\r'),(15743,644602605013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','udvnn2010','udv-nn@yandex.ru','Dmitriy Ulanov','Chernyahovskogo str., 9-5','Nizhniy Novgorod','Nizhegorodskaya oblast','RUSSIAN FEDERATION','603035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 06:29:08',0,NULL,3,1,2,1,' \\ ','udvnn2010'),(15744,733772915008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','brar43','braraman2009@yahoo.com','Amandeep Singh Brar','2/7 Aroona Rd.<br>KILKENNY','Adelaide','South Australia','AUSTRALIA','5009','0430043438','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 07:10:11',0,NULL,3,1,2,1,' \\ ','brar43\r澳标'),(15745,791216947011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',115.99,'eastar4','shneye1980','shneye@gmail.com','Volodymyr Shneye','Konstantina Fedina str., 5-78','Moscow','Moscow','RUSSIAN FEDERATION','105215','79057419070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 07:24:27',0,NULL,3,1,3,1,' RA184579641CN\r','shneye1980\rGLSG001*2'),(15746,880252789012,220812859649,'3DConnexion SpacePilot USB 3D Motion Controller mouse',1,'MOLO010',219.99,'eastar4','68lowestoftroad','rattyspb@btinternet.com','simon barker','31 honey close','norwich','Norfolk','UNITED KINGDOM','nr1 4lj','01603433920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:47:12',0,NULL,3,1,3,1,' RA184579006CN','68lowestoftroad\rMOLO010'),(15747,794064277011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','acaronet_atos','acarosalazar@gmail.com','Alejandro Caro Salazar','CASTILLA 82 1º 7 BQ CASTILLA','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41010','695671428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:54:55',0,NULL,3,1,2,1,' \\ ','acaronet_atos'),(15748,794063867011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','pjotrd','pm_dekker@live.nl','Piet Dekker','Tom Mandersstraat 74','Hengelo','','NETHERLANDS','7558 MR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:54:57',0,NULL,3,1,2,1,' \\ ','pjotrd'),(15749,880257597012,220448710888,'Acer travelmate 3002 Bluetooth Module 2.0 EDR+cable',1,'BTAC2024',9.88,'eastar4','blax82','bloodaxe82@gmail.com','Joel Wright','PO Box 4296','South Mackay','Queensland','AUSTRALIA','4740','0450125313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:55:50',0,NULL,3,1,2,1,'\\  ','blax82\racer 8pin1.25 10cm'),(15750,794094788011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','purelydredd','trulydredd@live.co.uk','Paul Atkinson','27 Thirston Way,Kenton Bar Estate','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE33EQ','07843230839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-12 11:32:12',0,NULL,3,1,3,1,' RA184579479CN\r','purelydredd\rWLAT008'),(15751,880328656012,220546768502,'NEW NEW NEW NEW NEW NEW Logitech battery 890 880 950mA',1,'BALO001',11.99,'eastar4','aljmor','aljmoran@hotmail.com','al moran','86 Ardagh St.','Toronto','ON','CANADA','M6S 1Y5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 13:16:49',0,NULL,3,1,2,1,' \\ ','aljmor'),(15752,587101928003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',2,'HSPL013',102.58,'cnfaner','7niuniek7','widirilo@yahoo.com','Ireneusz Piwonski','695 Proudfoot Lane app#901','London','ON','CANADA','N6H 4Y7','(313) 633-3728','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-12 13:28:32',0,NULL,3,1,3,1,' RA184579350CN','7niuniek7\rHSPL013\r一共买了三个'),(15753,644695138013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','adamhun91','m1994@freemail.hu','Adam Sipos','Hunyadi 51/b','Körmend','Vas','HUNGARY','9900','+36304001546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 13:55:32',0,NULL,3,1,2,1,'\\ ','adamhun91\r欧标\r'),(15754,880352438012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','sassamifrass','sassamifrass@gmail.com','Wendy White','22 Alfred St','Belmont','Western Australia','AUSTRALIA','6104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 14:17:57',0,NULL,3,1,2,1,'\\  ','sassamifrass'),(15755,794172726011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','aleckxss','ebayaleckxss@videotron.ca','Alexandre Couillard','2566 de l\'ombrette','Laval','QC','CANADA','H7L 4P4','(514) 555-5778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 14:52:52',0,NULL,3,1,2,1,' \\ ','aleckxss'),(15756,587140453003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','aznboi101210','aznboi101210@hotmail.com','Tien Ngo','3028 Coral Bell Ln','Franklin','TN','UNITED STATES','37067-8658','(615) 668-6274','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-12 15:38:30',0,NULL,3,1,1,1,'\\ ','aznboi101210\rMOOE003\rOEM的'),(15757,880346131012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','cosmicgirlndc','eritho7@yahoo.com','Erica Thompson Briggs','PO Box 826','Burtonsville','MD','UNITED STATES','20866','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cosmicgirlndc'),(15758,587148535003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','7niuniek7','widirilo@yahoo.com','Ireneusz Piwonski','695 Proudfoot Lane app#901','London','ON','CANADA','N6H 4Y7','(313) 633-3728','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-12 16:03:13',0,NULL,8,1,17,0,NULL,'7niuniek7'),(15759,751506697001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','61756jose','pepegastanaga@yahoo.com','jose gastanaga','24029 Fawn st','Moreno Valley','CA','UNITED STATES','92553-6249','(281) 468-0777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 16:10:02',0,NULL,3,1,1,1,'\\ ','61756jose'),(15760,750963702001,110701366235,'Alice in Wonderland New sealed 3D Blu-ray tracking#',1,'BR3D005',14.99,'buysia','gulalp21','gulhanerceltik@hotmail.com','gulhan geissler','cimen toygar sokak<br>cimen toygar sitesi no.7','Bademli, Mudanya','Bursa','TURKEY','16940','00905307809474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 16:42:37',0,NULL,3,1,2,1,' \\ ','gulalp21'),(15761,644771439013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','redpony022dennis','redpony022@yahoo.com','Dennis Resman','5252 Cobblefield Ln','Kalamazoo','MI','UNITED STATES','49004-8700','(269) 349-1571','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 17:35:49',0,NULL,3,1,6,1,'EE645619152CN ','redpony022dennis\r兼容型3D眼镜 通用型'),(15762,794270112011,320672752385,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',6.99,'eastar4','quebecois_sti','legomind@hotmail.com','Olivier Mathieu','14025 12e Avenue','Saint-Georges','QC','CANADA','G5Y 7H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 17:59:18',0,NULL,3,1,2,1,' \\ ','quebecois_sti'),(15763,644787656013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','arsenio47911','arsenij.c.o@gmail.com','Арсений Чувикин','ul. Frunzenskaya, dom 5, kv. 9','Tejkovo','Ivanovskaya oblast\'','RUSSIAN FEDERATION','155040','+79158241384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 18:05:42',0,NULL,3,1,2,1,'\\ ','arsenio47911\r'),(15764,880389399012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','saci3863','irena.ferkulj@gmail.com','Irena Ferkulj','Martinceva 27','Ljubljana','Slovenia','SLOVENIA','1000','+38631344788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 18:19:02',0,NULL,3,1,3,1,' RA184579615CN\r','saci3863\rHBPH001'),(15765,644815084013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',8.29,'eastar4','username.hmz','mheintz@gmx.de','Michael Heintz','Am Baumstück 25','Bad Camberg','','GERMANY','65520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 19:19:05',0,NULL,3,1,2,1,' \\ ','username.hmz\rCASS001+CASS003\rCAB-SS-2626\r再发一条CAB-6060'),(15766,587214122003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',3,'HSNO019',107.4,'cnfaner','xtecgmbh','info@x-tec.de','Friederike Hoheisel','Ludwigsplatz 4, X-tec GmbH','Rosenheim','','GERMANY','83022','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-12 19:24:12',0,NULL,3,1,3,1,' RA184579465CN\r','xtecgmbh\rHSNO019\r欧标'),(15767,644825332013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','username.hmz','mheintz@gmx.de','Michael Heintz','Am Baumstück 25','Bad Camberg','','GERMANY','65520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 19:28:37',0,NULL,8,1,17,0,NULL,'username.hmz'),(15768,644569207013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lucas.romano','lucasromanojf@gmail.com','Lucas Lucena Romano','Rua Batista de Oliveira, 482','Juiz de Fora','Minas Gerais','BRAZIL','36010120','(32) 3311-1155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 19:29:00',0,NULL,3,1,2,1,' \\ ','lucas.romano'),(15769,880538303012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','orlando_rego','sidrego@sapo.pt','Orlando Rego','Rua Quintas-aguela n 18','4730-240 Lage','','PORTUGAL','4730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 19:36:10',0,NULL,3,1,2,1,' \\ ','orlando_rego\racer 8pin1.00 8cm'),(15770,794335291011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mlara569100','lara569100@bellsouth.net','Mario Lara','498 Lee Miller Dr','Suwanee','GA','UNITED STATES','30024-7208','(404) 925-0910','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 19:50:08',0,NULL,3,1,1,1,'\\ ','mlara569100'),(15771,794378084011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','amani9602','camillefern@yahoo.com','CAMILLE FERNANDEZ','11412 203rd St','SAINT ALBANS','NY','UNITED STATES','11412-2815','(718) 600-0362','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-12 21:02:09',0,NULL,3,1,1,1,'\\ ','amani9602'),(15772,587261874003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',20.8,'cnfaner','janniche76','janniche@kranringen.no','Janniche Ekeland','V. Vardane 88','Erdal','Erdal','NORWAY','5306','90602354','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-12 20:53:28',0,NULL,3,1,3,1,' RA184579332CN','janniche76\r欧标\rHSSE004'),(15773,880601679012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','jluis_ps','joseluis.pena@gmail.com','José Luis Peña Sánchez','Prado Redondo 73','El Molar','Madrid','SPAIN','28710','644415699','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-12 21:11:30',0,NULL,3,1,3,1,' RA184579669CN\r','jluis_ps\rMOLO001'),(15774,644868987013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',2,'HSNO016',27.88,'eastar4','mosoberg9161','mosoberg@online.no','Morten Søberg','Vesthagan 64','default','Blaker','NORWAY','1925','91611972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 21:15:21',0,NULL,3,1,2,1,' \\ ','mosoberg9161\r欧标'),(15775,794396253011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',2,'RELO003',15,'eastar4uk','nikkie1984','toledotottie@hotmail.com','Nikkie Bell','32 Hornbeam Close<br>Larkfield','Aylesford','Kent','UNITED KINGDOM','ME20 6LY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-12 21:36:11',0,NULL,3,1,3,1,' RA184579448CN','nikkie1984\rRELO003\r红边优联'),(15776,880637930012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',62.99,'eastar4','without_chemicals','ebk@alumni.sfu.ca','Ethan Krindle','3751 Nancy Hanks St','Victoria','BC','CANADA','V8P 4W6','(604) 463-8075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 22:21:14',0,NULL,3,1,3,1,' RA184579289CN','without_chemicals\rMOMI001\r美标'),(15777,587297817003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','jesterpictures','paypal@jesterpictures.com','Jarek Zabczynski','8 Hi View Rd','Wappingers Falls','NY','UNITED STATES','12590','(914) 474-5478','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-12 22:32:52',0,NULL,3,1,1,1,'\\ ','jesterpictures'),(15778,592752558004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','mmkjc23','michaelp.biz@mmpeterson.com','Michael Peterson','4450 Barry Dr','Klamath Falls','OR','UNITED STATES','97603','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-12 23:11:41',0,NULL,3,1,1,1,'\\ ','mmkjc23'),(15779,880661207012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','baby28','karen@boxerden.com','Karen Chan','15409 95A Avenue','Surrey','BC','CANADA','V3R 7T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 23:15:58',0,NULL,3,1,3,1,' RA184579329CN','baby28\rGLOT001\r兼容型3D眼镜 通用型'),(15780,794448568011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','damien0663','damienmonnet@videotron.ca','Damien Monnet','2545 rue Belanger','Montreal','QC','CANADA','H1Y 1A2','(514) 618-4676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 23:37:36',0,NULL,3,1,2,1,' \\ ','damien0663'),(15781,880672848012,220815928836,'Logitech RF Wireless Extender for Harmony 890 Pro 1000',1,'RCLO007',18.8,'eastar4uk','tonio0029','ebay4429@yahoo.fr','Anthony Cadiou','Rutan','Collorec','Bretagne','FRANCE','29530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-12 23:44:15',0,NULL,3,1,2,1,'\\  ','tonio0029'),(15782,880690677012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','cperin10','cperim@gmail.com','Charles Cruz','R PAULINA MARANGONI 20<br>MATA DA PRAIA','VITORIA','ES','BRAZIL','29065-590','55-27-30820298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 00:30:56',0,NULL,3,1,2,1,'\\  ','cperin10'),(15783,592784906004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','dominioncomputersource','troark@dominioncomputersource.com','Dominion Computer','5245 Millcreek Cir','Independence','KY','UNITED STATES','41051-8610','(859) 363-7644','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-13 01:28:17',0,NULL,3,1,1,1,'\\ ','dominioncomputersource'),(15784,794489091011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','rhinoburns','ebay@robertburns.net','Robert M. Burns','2405 134TH PL SE','Mill Creek','WA','UNITED STATES','98012-4684','(425) 949-4000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 01:54:05',0,NULL,3,1,1,1,'\\ ','rhinoburns'),(15785,794490333011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','scorpioxvva','vvardanian@gmail.com','Vardan Vardanian','Bagratunyats 17, 55','Yerevan','Yerevan','ARMENIA','0006','+37493771415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 01:54:12',0,NULL,3,1,2,1,' \\ ','scorpioxvva'),(15786,794493386011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','casseylou','casseylou@yahoo.com','cassey hanks','4747 W Waters Ave<br>apt 4016','tampa','FL','UNITED STATES','33614-1443','(813) 215-7501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 02:16:09',0,NULL,3,1,1,1,'\\ ','casseylou\r兼容型3D眼镜 通用型'),(15787,794494586011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.99,'eastar4','gimle1gimle','gimle@direct.ca','Bent  J Haagerup','580 Meadow Creek rd.,<br>PO Box 141','Meadow Creek,','BC','CANADA','V0G 1N0','(250) 366-0004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 02:16:56',0,NULL,3,1,2,1,' \\ ','gimle1gimle'),(15788,794496759011,320730086052,'New brand Logitech Digital IO Writing Pen',1,'NTLO002',18.99,'eastar4uk','schumisantreas','konstantinouads@hotmail.com','ANTREAS KONSTANTINOU','2, AIOLOY STREET POTAMOS GERMASOGEIAS','LIMASSOL','','CYPRUS','4041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 02:16:57',0,NULL,3,1,2,1,'\\  ','schumisantreas'),(15789,794504914011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',2,'WLIN011',33.98,'eastar4','strafer69','wsimms1@gmail.com','William Simms','1027 NE 33rd St','Oakland Park','FL','UNITED STATES','33334-2717','(561) 654-9105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 02:48:46',0,NULL,3,1,1,1,'\\ ','strafer69'),(15790,794504654011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',5,'HSJA002',99.95,'eastar4','lorettaandtim','ralphl@ltdkate.com','Loretta Ralph','3305 Brown Station Rd','Columbia','MO','UNITED STATES','65202-2243','(573) 814-3271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 02:48:55',0,NULL,3,1,1,1,'\\ ','lorettaandtim'),(15791,794517867011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','marks749','mbsilvey@marserv.com','Mark Silvey','177 Riverside Ave<br>Ste F','Newport Beach','CA','UNITED STATES','92663-4080','(949) 642-6229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 03:41:01',0,NULL,3,1,1,1,'\\ ','marks749'),(15792,751798695001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','edgell82','leah.edgell@yahoo.com','Leah Edgell','173 Chestnut St','Battle Creek','MI','UNITED STATES','49017-3771','(269) 282-6043','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 03:48:20',0,NULL,3,1,1,1,'\\ ','edgell82'),(15793,880754371012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',22.71,'eastar4','larryb4i1e','lbelan63@gmail.com','Larry Belan','PO Box 310<br>115 Dorthea Ave','Mc Clellandtown','PA','UNITED STATES','15458-0310','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 04:07:23',0,NULL,3,1,1,1,'\\ ','larryb4i1e\rAUI Transceiver  MX20T'),(15794,880757683012,220782958082,'New Jabra BT135 BT 135 wireless Bluetooth Headset',1,'HSJA007',14.85,'eastar4','jbpea1','joseph.pearson@chrismaconsulting.com.au','Joseph Pearson','16 Delos Street','South Oakleigh','Victoria','AUSTRALIA','3167','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 04:21:44',0,NULL,3,1,2,1,' \\ ','jbpea1\r澳标'),(15795,8881321160795056,111,'透明伞 黄边',1,'UMTR001',0,'eastar4','neatobri','neatobs@gmail.com','Bri Sheridan','13966 Lindbergh Cir','Chico','CA','UNITED STATES','95973-8511','(530) 624-4887',NULL,NULL,NULL,'2011-11-13 05:06:35',0,NULL,3,1,3,1,' RA184579385CN','UMTR001 \r补发的'),(15796,8881321163184988,111,'New Genuine Motorola HS850',1,'HSMO019',0,'cnfaner','lazlo_hollifeld','lazlo_hollifeld@hotmail.com','Jason Costa','375 Ralph McGill Blvd NE<br>Apt 1507','Atlanta','GA','UNITED STATES','30312-1249','',NULL,NULL,NULL,'2011-11-13 05:46:24',0,NULL,3,1,3,1,' RA184579482CN\r','HSMO019\r只补发一个耳机'),(15797,644646277013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','geyslermaksim','geysler@e1.ru','Geysler Maksim','Street Pribaltiyskaya, the house 33, apartment 142','Ekaterinburg','Sverdlovskaya','RUSSIAN FEDERATION','620007','9022797427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 05:52:26',0,NULL,3,1,2,1,'\\  ','geyslermaksim'),(15798,794545435011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',24.99,'eastar4uk','echovet1zlf','echovet@aol.com','Mark Kopit','3201 Vermont Ave','Costa Mesa','CA','UNITED STATES','92626-2260','(714) 813-9982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 06:00:03',0,NULL,3,1,1,1,'\\ ','echovet1zlf'),(15799,751860983001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','laimikis69','laimikis@mail.ru','darijus laimikis','skaffarvegen 15','stranda','','NORWAY','6200','4746395236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 08:56:54',0,NULL,3,1,2,1,'\\  ','laimikis69'),(15800,794589267011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','vladimir72vladimir','vladimir.u6@gmail.com','vladimir ushakov','eliyahu ben-hur st. 4/7','beer-sheva','darom','ISRAEL','84276','+972508454950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 09:01:36',0,NULL,3,1,2,1,' \\ ','vladimir72vladimir'),(15801,734325879008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',13.58,'au-buy','mohammad.albeydani','mohammad_ak56@hotmail.com','ali albeydani','40 morris st','merrylands','New South Wales','AUSTRALIA','2160','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-13 10:12:28',0,NULL,3,1,2,1,' \\ ','mohammad.albeydani\r澳标'),(15802,794622576011,320441564486,'2.1 Acer Aspire 5550 5551 5552 Bluetooth Module +cable',1,'BTAC2106',12.39,'eastar4','vitaliy-st','stupko-vit@yandex.ru','Vitaliy Stupko','pereulok Shadrina, dom 1, kvartira 78','Naberezhnye Chelny','Respublika Tatarstan','RUSSIAN FEDERATION','423800','+79196443120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 10:20:59',0,NULL,3,1,2,1,'、 ','vitaliy-st\racer 4pin1.25 15cm '),(15803,794636526011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','somkiat.s','somkiat.s1977@gmail.com','Somkiat Seekhongkeaw','180/25 Suksawad Modern Condo, Suksawad Rd.<br>Ratburana','Ratburana District','Bangkok','THAILAND','10140','+66819193144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 10:57:21',0,NULL,3,1,2,1,' \\ ','somkiat.s'),(15804,645059747013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','magarju','mgarju@yahoo.es','Mario García Juan','Avda. País Leonés, 18, 1º C','León','Castilla y León','SPAIN','24010','696330610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 11:01:14',0,NULL,3,1,2,1,' \\ ','magarju'),(15805,794643802011,320737032375,'4 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*4',216.99,'eastar4','debsmclernon','debsmclernon@hotmail.com','Deborah Harper','1 Penbrooke Avenue','Bangor','Down','UNITED KINGDOM','BT19 7WY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 11:10:22',0,NULL,3,1,3,1,' RA184579261CN','debsmclernon\rGLOT005*4'),(15806,794646340011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','norwegian_68','edgar.valhammer@broadpark.no','Edgar Valhammer','Skagegaten 55','Haugesund','Rogaland','NORWAY','5523','+4791127001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 11:10:41',0,NULL,3,1,2,1,' \\ ','norwegian_68\r无线蓝牙二合一'),(15807,794643818011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.88,'eastar4','petit131','petit131@wp.pl','Steve Wagner','35c Lare DR 35','BRIDGEWATER','NJ','UNITED STATES','08807','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 11:13:05',0,NULL,3,1,1,1,'\\ ','petit131'),(15808,880891117012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.89,'eastar4uk','ervinspolis','ervins789@inbox.lv','Ervins Polis','27 Lielirbes str.','Riga','RIGA','LATVIA','LV-1046','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 11:24:39',0,NULL,3,1,2,1,' \\ ','ervinspolis'),(15809,794655786011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','radio835','ronhamilton@me.com','Ron Hamilton','Kingswood Prep School<br>College Road','Bath','Avon','UNITED KINGDOM','BA15SD','07578252920','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 11:30:41',0,NULL,3,1,3,1,' RA184579553CN\r','radio835\rLGGL002'),(15810,789337941011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','ma12345','samjo30@hotmail.com','Muin Nassir , AMM  6992','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 11:46:20',0,NULL,3,0,1,1,'\\ ','ma12345\r已入库'),(15811,794665100011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','**timerider**','ebay@casadezip.com','Fernando Armada','Av. Viñuelas, 24<br>3.C','Tres Cantos','Madrid','SPAIN','28760','607558415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 11:49:28',0,NULL,3,1,2,1,'\\  ','**timerider**'),(15812,880926084012,220816317096,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',27.54,'eastar4','stigtrondheim','stig.westerhus@online.no','Stig Westerhus','Moltmyra 71','TILLER','','NORWAY','7091','4795876700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 12:28:06',0,NULL,3,1,2,1,'、 ','stigtrondheim\r16骨长柄自动伞\r黑色的'),(15813,645091078013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','yourgen_russia','yourgen@mail.ru','Yury Maslennikov','K. Marksa 14-34','Nevyansk','Sverdlovskaya oblast','RUSSIAN FEDERATION','624190','+7 9022543131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 12:29:45',0,NULL,3,1,2,1,' \\ ','yourgen_russia\r欧标'),(15814,880955261012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','radek.tuma','tumakradek@seznam.cz','Radek Tůma','Kounice 394','Kounice','výchozí','CZECH REPUBLIC','28915','739759053','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 13:20:09',0,NULL,3,1,2,1,' \\ ','radek.tuma'),(15815,880959972012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',23.74,'eastar4','paulopercigo2009','paulopercigo@gmail.com','PAULO PERCIGO','R. Dr Rubens Machado Camara n.26 SB2','CURITIBA','Parana/Curitiba/Brazil','BRAZIL','82520-300','05541 96359667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 13:27:10',0,NULL,3,1,3,1,'RA184578204CN ','paulopercigo2009\rUM00025+UM00034+UM00021\r一把蓝天白云长柄伞\r一把w.p.c条纹碎花伞\r一把ProLee24K超轻碳纤骨长柄伞'),(15816,794717755011,320730481626,'New Japan Lady Stripe w/color trim Sun  Stick Umbrella',1,'UM00025',23.74,'eastar4','paulopercigo2009','paulopercigo@gmail.com','PAULO PERCIGO','R. Dr Rubens Machado Camara n.26 SB2','CURITIBA','Parana/Curitiba/Brazil','BRAZIL','82520-300','05541 96359667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 13:29:52',0,NULL,3,1,17,0,NULL,'paulopercigo2009'),(15817,794720493011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',25.64,'eastar4','paulopercigo2009','paulopercigo@gmail.com','PAULO PERCIGO','R. Dr Rubens Machado Camara n.26 SB2','CURITIBA','Parana/Curitiba/Brazil','BRAZIL','82520-300','05541 96359667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 13:34:49',0,NULL,3,1,17,0,NULL,'paulopercigo2009'),(15818,794721146011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',29.99,'eastar4','benngfg','ben@foto88.com','Ben Ng','54 Jalan Mutiara','default','','SINGAPORE','249226','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 13:37:37',0,NULL,3,1,11,1,NULL,'benngfg\rWLAP009'),(15819,794728639011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','denmarkstreet','ebay1@0post.dk','Thomas Damgaard','Esromgade 4B, 2.','Copenhagen N','','DENMARK','2200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 13:51:30',0,NULL,3,1,2,1,' \\ ','denmarkstreet'),(15820,794737167011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','gisellechao2011','gisellefchao@gmail.com','Giselle Fonseca Chao','Rua Edgar Falcão, 130 apto 402 Bloco D<br>Bairro Presidente Kennedy','Fortaleza','Ceara','BRAZIL','60356-090','+558532375651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 14:05:21',0,NULL,3,1,2,1,'\\  ','gisellechao2011'),(15821,645139393013,230512575271,'Genuine Logitech Harmony LED 515 Remote Control',1,'RCLO004',49.99,'eastar4','-ajl1-','aletizio@ajletizio.com','Al Letizio','91 Indian Rock Rd','Windham','NH','UNITED STATES','03087','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 14:32:09',0,NULL,3,1,1,1,'\\ ','-ajl1-'),(15822,794772962011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',25.64,'eastar4','romchikr8','romchik.r8@gmail.com','Roman Pfefer','Yehuda Burla 12/18','Haifa','','ISRAEL','32811','+972-0542111581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 15:04:12',0,NULL,3,1,2,1,'\\  ','romchikr8\r24K超轻碳纤骨长柄伞  '),(15823,794769616011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','ggbass31','pons.g@free.fr','Gérard  Pons','7 rue des Quatre Vents','Fonsegrives','Midi-Pyrénées','FRANCE','31130','06.03.17.29.93.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 15:07:30',0,NULL,3,1,2,1,' \\ ','ggbass31'),(15824,881027769012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','jaasonmaster','jay-designs.com@live.com','Jason Sweeney','5 Carrann Ln','Egg Harbor Township','NJ','UNITED STATES','08234-7531','(609) 653-1919','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-13 15:11:29',0,NULL,3,1,1,1,'\\ ','jaasonmaster'),(15825,794779389011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','jvn85','jelle_van_nieuwenhuizen@hotmail.com','Jelle Van Nieuwenhuizen','Salentijnerhout 1','Harderwijk','','NETHERLANDS','3845es','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 15:15:00',0,NULL,3,1,2,1,' \\ ','jvn85'),(15826,645179671013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','jeremyagarrett','garrettlaw@charter.net','Jeremy Garrett','2506 Badger Ln','Madison','WI','UNITED STATES','53713','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 15:56:20',0,NULL,3,1,1,1,'\\ ','jeremyagarrett'),(15827,645181003013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',4,'CACN004',51.76,'eastar4','rutin_f','fartunin@gmail.com','Aleksey Fartunin','Olhovaya str., 9-239<br>6 mrk.','VIDNOE','Moscow region','RUSSIAN FEDERATION','142701','7-910-427-63-67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 15:57:51',0,NULL,3,1,3,1,' RA184579315CN','rutin_f\rCACN004'),(15828,793771375011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',65.98,'eastar4uk','tinofigueiras','tinofigueiras@vodafone.es','Agustin Carballa Figueiras','Avda. Dr. Moreira Casal Nº4, 3ºC','Villagarcía de Arosa','Galicia','SPAIN','36600','607904547','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 16:10:34',0,NULL,3,1,3,1,' RA184579607CN\r','tinofigueiras\rLGGL002\r一共买了两个'),(15829,881090123012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','hselectrical','stephen.smith383@yahoo.co.uk','stephen smith','19 pump lane','rugeley','Staffordshire','UNITED KINGDOM','ws152tw','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 16:32:59',0,NULL,3,1,3,1,' RA184579417CN\r','hselectrical\rHBPH007'),(15830,794844040011,320700068373,'NEW LOGITECH USB Receiver 4 LX5 LX7 LX8 Wave S510 EX90',1,'RELO001',8.9,'eastar4','pitbeast77','pitbeast777@gmail.com','Petr Kudinov','Gorno-Altayskaya st. 77, 22','Biysk','Altay region','RUSSIAN FEDERATION','659315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 16:41:49',0,NULL,3,1,2,1,' \\ ','pitbeast77\r'),(15831,645208370013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','redemptioncustoms','rob.brown@redemptioncustommotorcycles.com','Rob Brown','1011 - 1320 16 ave SW','Calgary','AB','CANADA','T3C 3S6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 16:46:47',0,NULL,3,1,2,1,' \\ ','redemptioncustoms'),(15832,794874141011,320785748313,'New Logitech G7 Rechargeable Battery MX revolution mous',1,'BALO005',7.49,'eastar4uk','hataaka','hataakaebay@gmail.com','Laszlo Szabo','25 Cowley Close','Southampton','Hampshire','UNITED KINGDOM','SO16 9WD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 17:12:13',0,NULL,3,1,2,1,'\\  ','hataaka'),(15833,645233894013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','phihubert','philippe@prove.demon.co.uk','Philippe Hubert','PROVE SYSTEMS LTD<br>Unit 1 Mill court Mill Lane','Tayport','Fife','UNITED KINGDOM','DD6 9EL','01382552085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 17:21:46',0,NULL,3,1,3,1,' RA184579522CN\r','phihubert\rLGAD001'),(15834,794893554011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','kamekaowens','owensbrian10@yahoo.com','Kameka J Owens','1080 Vos Ave','DeWitt','Ar','UNITED STATES','72042-9603','(870) 946-4342','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 17:31:48',0,NULL,3,1,1,1,'\\ ','kamekaowens'),(15835,794864626011,320793265044,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',199.98,'eastar4','haddag2007','ffaa1974@hotmail.com','faisal  alshuaibi','18221 150th Ave<br>kwi 35068','springfield gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 17:53:07',0,NULL,3,1,1,1,'\\ ','haddag2007\r一共买了四个'),(15836,587629624003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17,'cnfaner','ntai','ntai@smartfruit.com','Naoyuki Tai','37 Wellington St','Arlington','MA','UNITED STATES','02476','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-13 17:38:24',0,NULL,3,1,1,1,'\\ ','ntai'),(15837,794931695011,320793265044,'New genuine Garmin GPS 12XL GPS Receiver',2,'GPS0009',199.98,'eastar4','haddag2007','ffaa1974@hotmail.com','faisal  alshuaibi','18221 150th Ave<br>kwi 35068','springfield gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 18:05:43',0,NULL,8,1,17,0,NULL,'haddag2007'),(15838,794950324011,320465511704,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.87,'eastar4','danjoh','ducatista999@gmail.com','John Andre Danielsen','Schøllers gate 19','Trondheim','','NORWAY','7043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 18:21:14',0,NULL,3,1,2,1,' \\ ','danjoh'),(15839,881235538012,220886272004,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',31.85,'eastar4uk','shehan.kevin2009','shehan.kevin@gmail.com','Shehan Anthonypillai','99/43 G<br>Old D.R.O Road, 4th Lane','Kandana','Gampaha','SRI LANKA','11320','0094-112-232337','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 18:40:32',0,NULL,3,1,3,1,' RA184579598CN\r','shehan.kevin2009'),(15840,645298872013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','gurugil2009','gurugil@gmail.com','benji rosenfeld','sokolov 90B','ramat hasharon','israel','ISRAEL','47237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 19:02:51',0,NULL,3,1,2,1,'、 ','gurugil2009'),(15841,752258582001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','the_rock54','larokabrona@yahoo.com','Mauricio Franco','6270 Havenside Dr<br>Apt 2','Sacramento','CA','UNITED STATES','95831-1532','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 19:11:13',0,NULL,3,1,1,1,'\\ ','the_rock54'),(15842,795020553011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','blitzburgh47','pstunder@hotmail.com','PJ Tunder','130 S Dunton Ave','Arlington Heights','IL','UNITED STATES','60005','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-13 19:15:37',0,NULL,3,1,1,1,'\\ ','blitzburgh47'),(15843,881294826012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','tr_ca_sa','keslo@hotmail.no','Kai Espen Lønhaug','Negardsveien 2','Raufoss','','NORWAY','2830','95177489','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 19:21:22',0,NULL,3,1,3,1,' RA184579275CN','tr_ca_sa\rGLOT001*2\r兼容型3D眼镜 通用型'),(15844,795028515011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',139.98,'eastar4','zaffar121','zaffarkasim@hotmail.com','mumsab khan','115 north rd<br>ravensthope','dewsbury','West Yorkshire','UNITED KINGDOM','wf133ag','01924510074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 19:22:57',0,NULL,3,1,3,1,' RA184579213CN','zaffar121\rOTSO004'),(15845,645339835013,230622774836,'Logitech MX1000 Mouse special bluetooth  version',1,'MOLO005',59.8,'eastar4','b52rus','mitinoracing@mail.ru','Ryvkin Aleksandr','ul.Generala Beloborodova d.14 k.2 kv.78','Moscow','','RUSSIAN FEDERATION','125222','(926)387-5628','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 19:32:45',0,NULL,5,1,3,1,'RA184579672CN\r','b52rus\rMOLO005\r已发货，改不了状态，只能改成订单取消'),(15846,795051766011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','nguwland','niek@nguwland.com','Niek Uwland','Helder Camarastraat 27','Delft','','NETHERLANDS','2622BH','0152564342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 19:41:26',0,NULL,3,1,2,1,' \\ ','nguwland'),(15847,795075474011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','paul12347','paul.ayling@sky.com','PAUL AYLING','THE LODGE<br>23 ORSETT AVENUE','LEIGH ON SEA','ESSEX','UNITED KINGDOM','ss9 4tt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 20:03:28',0,NULL,3,1,3,1,' RA184579505CN\r','paul12347\rMOAP001'),(15848,795079417011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',68.98,'eastar4','kr3snata','w.kresnata@hotmail.com','Wisnu Kresnata','Jl. Kaliwaru 73B','Sleman','Yogyakarta','INDONESIA','55283','87738155787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 20:36:45',0,NULL,3,1,3,1,'RA184578650CN ','kr3snata\rUDAP001  用另外一个账户arektataek@hotmail.com<arektataek@hotmail.com>;付款了 70美金'),(15849,881421917012,220701722271,'New genuine Logitech QuickCam Pro4000 Webcam Pro 4000',1,'CMLO001',49.99,'eastar4','limpdd','metfanutd@gmail.com','David Dunphy','Ballincur, Mooncoin','Co.Kilkenny','CoKilkenny','IRELAND','default','051895454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 21:12:01',0,NULL,3,1,3,1,' RA184579757CN\r','limpdd\rCMLO001'),(15850,881422589012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','92rhp74wx6z','matjasec@telus.net','mark matjasec','6291 no. 7 road','richmond','BC','CANADA','v6w 1e8','(604) 278-1305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 21:15:14',0,NULL,3,1,3,1,' RA184579394CN','92rhp74wx6z\rHBPH007'),(15851,645453595013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','funpoleece','tommy.le2@gmail.com','Tommy Le','1290 Heritage Way Unit 25','Oakville','ON','CANADA','L6M 4M4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 22:14:42',0,NULL,3,1,2,1,' \\ ','funpoleece'),(15852,881468558012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','cosmequintana2','cosmequintana@gmail.com','Cosme Quintana','601 S Mesa Hills Dr<br>Apt 412','el paso','TX','UNITED STATES','79912-5543','(915) 449-5686','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cosmequintana2'),(15853,795192570011,320609312177,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',11.6,'eastar4','crazyrogy','crazyivans@web.de','Killian Andreas','Killian GmbH<br>Wolfsbendenstr. 60','Aachen','','GERMANY','52080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 22:29:37',0,NULL,3,1,2,1,' \\ ','crazyrogy'),(15854,794912023011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 22:32:01',0,NULL,3,1,3,1,' RA184579519CN\r','javier197900\rGLSG001*2'),(15855,645463516013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','krigge92','kristofer92@gmail.com','Kristofer Strömberg','Citronfjärilsvägen 3','Stenungsund','Västra Götaland','SWEDEN','44446','0046739406316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 22:37:15',0,NULL,3,1,3,1,' RA184579292CN','krigge92\rMOSA006'),(15856,593279251004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',24.22,'cnfaner','ptlt23','ptlt@live.com','Thu Thu Lam','1783 Sagamore Dr','YORK','PA','UNITED STATES','17406-1809','(717) 755-7601','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-13 23:15:43',0,NULL,3,1,1,1,'\\ ','ptlt23'),(15857,645484040013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',10.99,'eastar4','cromar72','cromar1972@msn.com','Cristian Rodríguez Martin','C. Carmen Conde, Blq. 8 3º B','Alcala de Guadaira','Andalucía Ceuta y Melilla','SPAIN','41500','609726848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 23:37:13',0,NULL,3,1,2,1,' \\ ','cromar72'),(15858,645488628013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',7.96,'eastar4','igneusz','sergey@baykin.name','Sergey Baykin','Vavilova str. 79-106','Moscow','Moscow','RUSSIAN FEDERATION','117335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 23:49:52',0,NULL,3,1,2,1,' \\ ','igneusz'),(15859,645492916013,230622386439,'NEW LOGITECH USB Receiver for MX3200 MX3000 MX600 LX710',1,'RELO001',8.9,'eastar4','fwonlinesales','fwvendasonline@gmail.com','José Martins','Rua de Carvalhinho Nº15, Pedra Furada','Barcelos','Braga','PORTUGAL','4755-395','+351931615187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 00:03:24',0,NULL,3,1,2,1,'\\  ','fwonlinesales'),(15860,795204432002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','cooldude841979','cooldude8479@yahoo.co.in','Praveen Kumar','3516 Ravens Crest Dr','Plainsboro','NJ','UNITED STATES','08536-2404','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 00:37:36',0,NULL,3,1,1,1,'\\ ','cooldude841979'),(15861,794910900011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','estherld123','eldiaz@zoominternet.net','Esther L Diaz Maxwell','518 Conowingo Cir','Oxford','PA','UNITED STATES','19363-1487','(610) 707-2146','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 00:47:20',0,NULL,3,1,1,1,'\\ ','estherld123'),(15862,587870034003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','wildsexsug*2061wahe','reerie67@aol.com','HELENMARIE WALL','1780-FIRST AVENUE #20-G','NEW YORK','NY','UNITED STATES','10128','(212) 722-1828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 00:51:57',0,NULL,3,1,1,1,'\\ ','wildsexsug*2061wahe\r一共买了两个副耳机'),(15863,881545249012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','tmr234','tmryerson70@gmail.com','Tammy Ryerson','54 Hetzel Rd','Ridley Park','PA','UNITED STATES','19078-1540','(215) 429-8533','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 00:53:30',0,NULL,3,1,1,1,'\\ ','tmr234'),(15864,587865242003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','wildsexsug*2061wahe','reerie67@aol.com','HELENMARIE WALL','1780-FIRST AVENUE #20-G','NEW YORK','NY','UNITED STATES','10128','(212) 722-1828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 00:40:23',0,NULL,8,1,17,0,NULL,'wildsexsug*2061wahe'),(15865,881554592012,220682003276,'2.1 Acer Timeline 1810T 1810TZ Bluetooth Module cable',1,'BTAC2111',12.39,'eastar4','guardianz64','k_guldner@gmx.de','Kai Guldner','Lorisstrasse 110','Saarlouis','','GERMANY','66740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 01:17:16',0,NULL,3,1,2,1,'\\  ','guardianz64\rAcer 5pin1.25 3cm'),(15866,645515542013,230698832233,'logitech Battery 190310-1000 2000 2001  for G7 mouse /MX revolution Mouse',1,'BALO009',7.99,'eastar4','beyond1999','rcai2@uwo.ca','Rongyi Cai','75 South Town Centre Blvd, Suite 910','Markham','ON','CANADA','L6G0B3','(647) 449-1616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 01:18:02',0,NULL,3,1,2,1,' \\ ','beyond1999'),(15867,8881321234139653,111,' BCM2070 无线蓝牙二合一卡',10,'WLIN015',139.9,'aliexpress','1005209568','engmaxalves@gmail.com','Maximiliano Alves	','Rua Giuseppe Barbieri, 197','Sao Paulo	','SP','BRAZIL','04850040','+55 11 55285009',NULL,NULL,NULL,'2011-11-14 01:28:59',0,NULL,3,1,3,1,' RA184579686CN\r','WLIN015 .\rNew BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card * 10'),(15868,734928475008,180699062479,'2 pairs genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',93.09,'au-buy','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN MANUEL ALMAGRO ROJAS','C/ ARAGONITO 7A','MALAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 01:30:56',0,NULL,3,1,3,1,' RA184579540CN\r','latiendadelsotano\rGLSG001*2'),(15869,795277904011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','petro5','petro28119@aol.com','Thomas Petrokubi','5818 Hughes Rd','Galena','OH','UNITED STATES','43021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 01:47:00',0,NULL,3,1,1,1,'、 ','petro5'),(15870,881574303012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','goaliestud72','brown_jon@hotmail.com','Jonathon Brown','6040 Willow Creek Dr','Canton','MI','UNITED STATES','48187-3327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 01:52:10',0,NULL,3,1,1,1,'、 ','goaliestud72'),(15871,645531058013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','m8rs','marcin.damas@gmail.com','Marcin Damas','146 Edward St','Osborne Park','Western Australia','AUSTRALIA','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 02:05:04',0,NULL,3,1,2,1,'\\  ','m8rs\rCAB-6060'),(15872,645535981013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','wowannie554','mjmacklin@internode.on.net','Michael Macklin','6 Madigan Crescent<br>Woodcroft','Adelaide','South Australia','AUSTRALIA','5162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 02:19:21',0,NULL,3,1,2,1,'\\  ','wowannie554'),(15873,752517655001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','minimalpeti','swenergy666@gmail.com','Peter Banko','36 Schooner Ct','Saint Augustine','FL','UNITED STATES','32080-6545','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 02:19:55',0,NULL,3,1,1,1,'\\ ','minimalpeti'),(15874,881596705012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Chalmers H. Knight','3292 Alpine Dr','Ann Arbor','MI','UNITED STATES','48108-1766','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 02:45:48',0,NULL,3,1,1,1,'、 ','bigtimepimp'),(15875,734958557008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',57.94,'au-buy','julieannez123','thezims@bigpond.com','JULIE A ZIMMERMAN','53 ENMORE DRIVE','CRAIGMORE','South Australia','AUSTRALIA','5114','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-14 02:52:15',0,NULL,3,1,3,1,'RA184579955CN\r ','julieannez123\rHBPH002'),(15876,881604244012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','roxa8','roxa8@msn.com','Ian Roxburgh','468 Yannawah Lane','Young','New South Wales','AUSTRALIA','2594','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 03:10:32',0,NULL,3,1,2,1,'\\  ','roxa8'),(15877,645554745013,230698832233,'logitech Battery 190310-1000 2000 2001  for G7 mouse /MX revolution Mouse',2,'BALO009',15.98,'eastar4','qyrus01','sheungho@hotmail.com','Jimmy  Lee','2138 Scarboro Ave.','Vancouver','BC','CANADA','V5p 2L3','(604) 561-2238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 03:23:01',0,NULL,3,1,2,1,' \\ ','qyrus01'),(15878,645561677013,230693030604,'New logitech Battery 190310-1000 2000 2001  for G7 mouse /MX revolution Mouse ',2,'BALO005',18.98,'eastar4','pragmatek2k7','ionelanton@yahoo.ca','ionel anton','7006 Des Ecores','Montreal','QC','CANADA','H2E 2V8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 03:49:53',0,NULL,3,1,2,1,' \\ ','pragmatek2k7'),(15879,645562457013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'eastar4','21coleridge','ksamu@euscom.com','Kenneth Samu','6 Timber Wolf Dr','TRENTON','NJ','UNITED STATES','08620-1331','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 03:54:02',0,NULL,3,1,3,1,'RA184578147CN\r ','21coleridge\rGPS0006'),(15880,795334433011,320419818527,'New Logitech Harmony Rechargeable battery 890 880 720',1,'BALO001',11.99,'eastar4','rialonso','ricardoalonsojorge@gmail.com','Ricardo Alonso Jorge','1900 NW 97th Ave<br>Ste 720-18410','Doral','FL','UNITED STATES','33172-2310','(786) 265-4880','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 04:37:45',0,NULL,3,1,1,1,'、 ','rialonso'),(15881,881635026012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jpmobydick','slikmys@hotmail.com','Jim Myslik','3 Blue Forest Cres.','Guelph','ON','CANADA','N1H 6J2','(519) 822-6654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 04:39:46',0,NULL,3,1,2,1,' \\ ','jpmobydick'),(15882,587930300003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',20.8,'cnfaner','cassievegas','cassievegas55@yahoo.com.tw','shufen yang','5070 S Rainbow Blvd<br>Unit 103','Las Vegas','NV','UNITED STATES','89118-0681','(702) 882-3625','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 04:40:47',0,NULL,3,1,1,1,'\\ ','cassievegas'),(15883,752566520001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','radicaal_1','fresh2roll@gmail.com','parham taagholi','798 DALIP COURT<br>(Basement Suite)','Coquitlam','BC','CANADA','v3j 7y3','(778) 708-6426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 05:08:15',0,NULL,3,1,2,1,'\\ ','radicaal_1'),(15884,881645799012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.39,'eastar4','gcb3460','gordoncbell@hotmail.com','Gordon Bell','24 Liversidges Lane','Sailors Falls','Victoria','AUSTRALIA','3461','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 05:26:28',0,NULL,3,1,2,1,' \\ ','gcb3460'),(15885,587939904003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','narmer17','feras_17@yahoo.com','Feras Hanano','11814 Meadow Branch Drive<br>Apt 1228','Orlando','FL','UNITED STATES','32825','(941) 268-1058','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 05:42:55',0,NULL,3,1,1,1,'\\ ','narmer17'),(15886,593382391004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',6.99,'cnfaner','dipperlake267','spwheel357@gmail.com','Mary Shier','267 W Barnes Lake Rd','Columbiaville','MI','UNITED STATES','48421-9717','(319) 208-9332','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 06:38:17',0,NULL,3,1,1,1,'\\ ','dipperlake267'),(15887,881663443012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','codyjl15','codylample@yahoo.com','Cody Lample','350 Famgate','gurnee','IL','UNITED STATES','60031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 06:53:28',0,NULL,3,1,1,1,' 、','codyjl15'),(15888,881664249012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','mada100','madaet@rpi.edu','Thomas P. Madaelil','1055 Cetronia Rd<br>Apt Q3','Breinigsville','PA','UNITED STATES','18031-1767','(931) 216-6016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 06:57:22',0,NULL,3,1,1,1,'、\r ','mada100'),(15889,881669102012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','abenusa','allen@benusa.com','Allen D. Benusa','425 Kay St SW','Hutchinson','MN','UNITED STATES','55350-2127','(320) 587-9749','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 07:21:42',0,NULL,3,1,1,1,'、 ','abenusa'),(15890,795368338011,320692603659,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.97,'eastar4','jozef-unno','j.ivancak@gmail.com','Jozef Ivančák','Tatranská 107','Banská Bystrica','','SLOVAK REPUBLIC','97411','+421915066995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 07:30:45',0,NULL,3,1,2,1,' \\ ','jozef-unno'),(15891,881677616012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',95.99,'eastar4','resoundsound','info@resoundsound.com','Ilpo Karkkainen','Hallituskatu 14 A 26','Tampere','Finland','FINLAND','33200','+358503318756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 07:59:25',0,NULL,3,1,3,1,'RA184579730CN ','resoundsound\rOTKE001'),(15892,645603586013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','tigroulis','tigroulios@hotmail.com','Athanasios Monopavlidis','Vosporou 28','Thessaloniki','Greece','GREECE','54454','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 08:07:30',0,NULL,3,1,2,1,'\\  ','tigroulis'),(15893,587966292003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','ivorysoapsuds','ivorybyers@gmail.com','Jenny Byers','2993 Cohansey Dr','San Jose','CA','UNITED STATES','95132-1619','(360) 710-8523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 08:56:41',0,NULL,3,1,1,1,'\\ ','ivorysoapsuds'),(15894,8881321261146872,111,'logitech screen 890',50,'SCLO001',800,'eastar4','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 SnowdoniaCove','Bee Cave','TX','UNITED STATES','78738','',NULL,NULL,NULL,'2011-11-14 08:59:06',0,NULL,3,1,4,1,'YW867660512CN ',NULL),(15895,735039769008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','leonid-54','leonid_mamaev@hotmail.com','Leonid Mamaev','Sovetskaya, 13-26','Novosibirsk','','RUSSIAN FEDERATION','630007','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 09:01:23',0,NULL,3,1,3,1,'RA184579981CN\r ','leonid-54\rHBPH002'),(15896,795390260011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','xardas1977','pavol.comaj@gmail.com','Pavol Comaj','Palarikova 293/6','Senica','','SLOVAK REPUBLIC','90501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 09:02:39',0,NULL,3,1,2,1,'\\  ','xardas1977\rLESY SR\rPavol Comaj\r90841 Sastin Straze\rSLOVAKIA\r\r'),(15897,587968294003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','jonesey99','ordinaryjones@gmail.com','Greg Jones','302 E Pettigrew St<br>Ste 240','Durham','NC','UNITED STATES','27701-2393','(919) 259-6666','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 09:07:50',0,NULL,3,1,1,1,'\\  ','jonesey99'),(15898,795391664011,320791705447,'New genuine Garmin GPS 12XL GPS Receiver',2,'GPS0009',133.98,'eastar4uk','mohdalmuhairi','almuhairii@eim.ae','Mohamed Almuhairi','Dubai<br>Alhamriah','Dubai','','UNITED ARAB EMIRATES','86818','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-14 09:12:01',0,NULL,3,1,3,1,'RA184578102CN\r ','mohdalmuhairi\rGPS009'),(15899,645619273013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','elindogg','elind@simnet.is','Dekkjahollin-Johann Jonsson','1424 Baker Rd<br>Shopusa Ste IS17326','Virginia Beach','VA','UNITED STATES','23455-3320','(354) 660-7977','NoPaymentFailure','CheckoutIncomplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,' \\ ','elindogg\rHSNO017 \r一个NOKIA BH-800 BLUETOOTH HEADSET和一个BH-600\rLK021378075CN'),(15900,795399234011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','elindogg','elind@simnet.is','Elín Dögg Gunnarsdóttir','Dekkjahöllin<br>Draupnisgata 5','Akureyri','','ICELAND','603','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-14 09:34:56',0,NULL,3,1,2,1,' \\','elindogg\r'),(15901,881709168012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','big-trucker0815','a.weissenberger@cablelink.at','andreas weissenberger','lärchenweg 8','grödig','','AUSTRIA','5082','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-14 09:54:42',0,NULL,3,1,3,1,'RA184579916CN\r ','big-trucker0815\rHSPL013\r欧标'),(15902,795417980011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',2,'HSNO019',75.96,'eastar4','sbogach','s_bogach@mail.ru','Sergey Bogachev','Svechnaya st., 24','Orenburg','','RUSSIAN FEDERATION','460528','+79225474022','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-14 10:42:39',0,NULL,3,1,3,1,'RA184579933CN\r ','sbogach\r欧标\rHSNO019'),(15903,881726449012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',2,'GLOT001*2',177.98,'eastar4','molnar7036','almolnar@mcs.net.au','alexander molnar','78 silingardies rd <br>walkerston','mackay','Queensland','AUSTRALIA','4751','0749593373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 10:50:22',0,NULL,3,1,3,1,'RA184579880CN\r ','molnar7036\rGLOT001*2\r兼容型3D眼镜 通用型'),(15904,645642171013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','tauet15','jacint.llambrich@urv.cat','Jacint Llambrich Montecino','Universitat Rovira i Virgili - SRI i TIC<br>Av. Països Catalans 5-7','Tarragona','Cataluña','SPAIN','43007','606133459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 11:26:48',0,NULL,3,1,2,1,'\\ ','tauet15'),(15905,881742954012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','trompesoft2','francis2k@telefonica.net','francisco jose Garrido Exposito','C/ Oropendola nº 3','trigueros','Andalucía Ceuta y Melilla','SPAIN','21620','959305051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 11:41:37',0,NULL,3,1,3,1,'RA184579964CN\r ','trompesoft2\rGLOT001*2\r兼容型3D眼镜 通用型'),(15906,795436501011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','mr-warzowsky','jnavarro@esid.uji.es','José Luis Navarro Lizandra','Av. Vicente Sos Baynat - 11 - 4º A','Castellón','Comunidad Valenciana','SPAIN','12006','649992707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-14 11:42:13',0,NULL,3,1,2,1,'\\ ','mr-warzowsky'),(15907,751220708001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','5008angelangel','asanchezcampo@gmail.com','Angel Sánchez Campo','C/Carlos Dabán 26, esc 8, 1º dcha','Madrid','Madrid','SPAIN','28019','914726084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 12:19:35',0,NULL,3,1,2,1,'\\ ','5008angelangel'),(15908,795146139011,320793265044,'New genuine Garmin GPS 12XL GPS Receiver',10,'GPS0009',1099.89,'eastar4','khawla.s','ya_9a7ebeee@hotmail.com','Khawla Salim Abdalla/DXB 6982','182nd Street 147-29','Springfield Gardens','NY','UNITED STATES','11413','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 13:07:32',0,NULL,3,1,6,1,'EE645619360CN ','khawla.s\r一共买了11个\r新地址\rErhama Ahmed Rashed\rP.O.Box: 31512\rRas Al Khaimah\rUnited Arab Emirates\r00971502365332\r'),(15909,735116675008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','iukiss','mikeakiss@gmail.com','Michael Kiss','816 W Drew Ln','Palatine','IL','UNITED STATES','60067-0916','(847) 496-7899','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 13:23:42',0,NULL,3,1,1,1,'\\','iukiss\r'),(15910,881778958012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',3,'UM00016',71.22,'eastar4','charmme2007','laurita.brown@msd.net.au','Laurita Brown','13 Aurora Crescent','Kenmore','Queensland','AUSTRALIA','4069','0738786909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 13:23:48',0,NULL,3,1,3,1,'RA184578076CN\r ','charmme2007\r网眼豹纹双层网纱长柄伞  \rUM00016\r发不同颜色的'),(15911,795476165011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','mark_kr','markkriger@gmail.com','Mark Kriger','Levi Eshkol 19','Natanya','','ISRAEL','42463','972-50-7732211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 13:39:37',0,NULL,3,1,2,1,'\\ ','mark_kr'),(15912,881782965012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','neoprenefish','martin@harley-jones.co.uk','Martin Jones','2 Coldharbour Farm<br>Herne Road','Crowborough','East Sussex','UNITED KINGDOM','TN6 2NT','07796113047','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 13:32:35',0,NULL,3,1,3,1,'RA184578045CN\r ','neoprenefish\rWLIN013'),(15913,735133430008,180755522235,'2 pairs of NIB Samsung SSG-2200AR Rechargeable Adult 3D Active Glasses for 2010',1,'GLOT006*2',87.99,'au-buy','zachleai','denisbord@hotmail.com','Eric Bordeleau','104,  rue du Pacifique','Farnham','QC','CANADA','J2N 2J4','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 14:12:24',0,NULL,5,1,3,1,NULL,'zachleai\rGLOT006*2'),(15914,795489689011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','markc36','markfly@tpg.com.au','Mark Hayler','83 Oceana<br>100 Old Burleigh Road','Broadbeach','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 14:14:59',0,NULL,3,1,2,1,'\\ ','markc36\r澳标'),(15915,742530161007,170728921103,'New Genuine Sony Ericsson HBH-PV703 Bluetooth Wireless Headset',1,'HSSE004',21.9,'au-buy','arunas1960','arunas.z@iris.lt','Arunas Zukauskas','Naujoji 50b<br>UAB Iris','Alytus','','LITHUANIA','LT-62381','37068616657','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 14:31:30',0,NULL,3,1,2,1,'\\ ','arunas1960\r欧标'),(15916,795490209011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','torch_garden','kitwoolley@hotmail.com','Kit Woolley','11 Kings Ride','Camberley','Surrey','UNITED KINGDOM','GU15 4HU','01276685987','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 14:15:04',0,NULL,3,1,3,1,'RA184579995CN\r ','torch_garden\rMOAP001'),(15917,645691774013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','kirkinstein','kirkinsteinnn@gmail.com','Kirill Ivanin','Federativniy prospekt, dom 15, korpus 4, kvartira 42','Moscow','','RUSSIAN FEDERATION','111399','+7(495)3041696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 14:41:56',0,NULL,3,1,3,1,'RA184578031CN\r ','kirkinstein\rLGGL002'),(15918,795510441011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','nealyjg','nealyj80@gmail.com','Jeaneal Guy','1025 Beech Tree Rd','Jacksonville','NC','UNITED STATES','28546-6001','(910) 619-0513','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 15:09:38',0,NULL,3,1,1,1,'\\ ','nealyjg'),(15919,735157867008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','miko_1983','miko_05@mail.ru','Магомед Магомедов','Энгельса 31 кв. 89','Махачкала','Дагестан','RUSSIAN FEDERATION','367026','+79604110505','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 15:19:13',0,NULL,3,1,3,1,'RA184579978CN\r ','miko_1983\rGLOT001'),(15920,795529162011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','cacbarueri2011','cacbarueri@hotmail.com','carlos florentino junior','av henriqueta mendes guerra<br>600','barueri','são paulo','BRAZIL','06401160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 15:53:17',0,NULL,3,1,3,1,'RA184578059CN\r ','cacbarueri2011\rGLOT001\r兼容型3D眼镜 通用型'),(15921,735175410008,180755522235,'2 pairs of NIB Samsung SSG-2200AR Rechargeable Adult 3D Active Glasses for 2010',1,'GLOT006*2',87.99,'au-buy','tcopler','tcopler@hotmail.com','Tom Copler','14097 Big Bear Ct.','Montpelier','VA','UNITED STATES','23192','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 16:03:40',0,NULL,5,1,1,1,NULL,'tcopler'),(15922,645722165013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','dylan001.0407','sharon3011@onvol.net','Sharon Mangion','Block 6, Flat 1<br>Garden Drive','Sta Lucia','','MALTA','PLA 15','+35621636146','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 16:19:09',0,NULL,3,1,11,1,'\\ ','dylan001.0407\r带彩色的泡沫\r不挂号'),(15923,881856951012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','chrisfire50','cleefire50@yahoo.com','Christopher R Lee','928 Carswell Ct','Elk Grove Village','IL','UNITED STATES','60007-4564','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 16:23:14',0,NULL,3,1,1,1,'\\  ','chrisfire50'),(15924,881806392012,220565577390,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',16.99,'eastar4','t_rexweb','christian.lecuyer@videotron.ca','Adacel inc. - Attention: Christian Lecuyer','4005 Matte Blvd, Suite E','Brossard','QC','CANADA','j4Y2P4','(514) 501-3751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 17:09:29',0,NULL,3,1,2,1,'\\ ','t_rexweb\r\rChristian Lecuyer\rAdacel inc. \r4005 Matte Blvd, Suite E\rBrossard QC j4Y2P4\rCANADA\r(514) 501-3751'),(15925,735217101008,180699062479,'2 pairs genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',93.09,'au-buy','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 17:33:40',0,NULL,5,1,18,0,NULL,'javier197900'),(15926,795099170011,320441564486,'2.1 Acer Aspire 5550 5551 5552 Bluetooth Module +cable',1,'BTAC2106',12.39,'eastar4','pashok62','pashokc@yandex.ru','Pavel Hohlov','Zubkovoy str, 30, apr. 324','Ryazan','Ryazan obl','RUSSIAN FEDERATION','390048','(910) 645-3688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 17:43:50',0,NULL,3,1,2,1,'、 ','pashok62\racer 4pin1.25 15cm '),(15927,881912566012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',23.74,'eastar4','tubogomez','maibvv@roadrunner.com','marco ibarra','5228 katherine st','simi valley','CA','UNITED STATES','93063-4561','(805) 584-0357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 18:01:12',0,NULL,3,1,1,1,'\\ ','tubogomez\r一共买了两把网眼豹纹双层网纱长柄伞  '),(15928,881913506012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',23.74,'eastar4','tubogomez','maibvv@roadrunner.com','marco ibarra','5228 katherine st','simi valley','CA','UNITED STATES','93063-4561','(805) 584-0357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 18:02:19',0,NULL,3,1,17,0,NULL,'tubogomez'),(15929,795598554011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','xenophot','saganet@free.fr','M. El Ouazzani','4 rue de la Terrasse','Boissy Saint-Léger','val de Marne','FRANCE','94470','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 18:11:05',0,NULL,3,1,2,1,'\\ ','xenophot'),(15930,881918213012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','bigtimepimp','bleepdat@yahoo.com','Nick Seuser','405 14th St<br>Ste 700','OAKLAND','CA','UNITED STATES','94612-2706','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 18:11:30',0,NULL,3,1,1,1,'\\ ','bigtimepimp'),(15931,881920907012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Floyd Alvarez, Jr.','22776 Highcrest Cir','Ashburn','VA','UNITED STATES','20148-6952','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 18:16:45',0,NULL,3,1,1,1,'\\ ','bigtimepimp'),(15932,735241778008,180755522235,'2 pairs of NIB Samsung SSG-2200AR Rechargeable Adult 3D Active Glasses for 2010',1,'GLOT006*2',87.99,'au-buy','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 18:20:00',0,NULL,5,1,18,1,' ','客户开paypal case  退款了\rGLOT006*2+GLSG001*2\r再发2 pairs genuine Samsung 3D Active Glasses SSG-2100AB'),(15933,881927868012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',69.99,'eastar4uk','acsacddirect','acsacd@hotmail.co.uk','David Langley','16 Caldene Croft<br>Mytholmyrod Hebden Bridge','Halifax','West Yorkshire','UNITED KINGDOM','HX7 5AE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 18:23:40',0,NULL,3,1,3,1,'RA184578080CN\r ','acsacddirect\rGLSG001*2'),(15934,881930626012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','olega1975','oleg.ch.oleg@yandex.ru','Oleg Chervyakov','Veteranov 155, 47','Saint-Petersburg','','RUSSIAN FEDERATION','198264','+7 (905)280-5745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 18:29:33',0,NULL,3,1,3,1,'RA184580004CN\r ','olega1975\rWWOT001'),(15935,881946434012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','eyemd','andrewdahl@pol.net','Andrew Dahl','1 Gus Siko Rd','Poughkeepsie','NY','UNITED STATES','12601','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 18:51:00',0,NULL,3,1,1,1,'\\ ','eyemd'),(15936,0,220886980592,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',3.99,'eastar4uk','roytheblade','roy.christie@ntlworld.com','roy christie','25 waldenhurst road<br>orpington','kent','Kent','UNITED KINGDOM','br5 4hn','07956885727','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 19:17:32',0,NULL,3,1,3,1,'RA184579862CN\r ','roytheblade\rBALO007'),(15937,795668184011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','braga1112','diogosbraga@hotmail.com','DIOGO DE SOUSA BRAGA','Avenida Anhanguera, 4470<br>Centro','Goiânia','Goiás','BRAZIL','74040-010','6284125199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 19:56:11',0,NULL,3,1,2,1,'\\ ','braga1112'),(15938,881918189012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','bigtimepimp','bleepdat@yahoo.com','Ralph Ciurleo','CBS Sports, 524 West 57th Street<br>Rm 3E12-16','New York','NY','UNITED STATES','10019','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 19:56:47',0,NULL,3,1,1,1,'\\ ','bigtimepimp'),(15939,882048688012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','eirik_gannestad1qnw','egannest@online.no','Eirik Gannestad','Jacob Langesv. 19','N-3610 Kongsberg','','NORWAY','N-3610','+47 93059538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 21:17:04',0,NULL,3,1,3,1,'RA184578028CN\r ','eirik_gannestad1qnw\rGPS0009'),(15940,882057362012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',1,'HSMO007',7.99,'eastar4uk','thowmian','thowmian@hotmail.co.uk','Thowmian Yoganathan','381 Ley Street','Ilford','London','UNITED KINGDOM','IG1 4AB','0205531584','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 21:28:04',0,NULL,3,1,3,1,'RA184579893CN\r ','thowmian\rHSMO007\r英标'),(15941,593630098004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','underdog3111','underdog311@hotmail.com','Tyler Underdahl','1010 20th st s','Fargo','ND','UNITED STATES','58103-2936','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 21:34:49',0,NULL,3,1,1,1,'\\ ','underdog3111'),(15942,881698670012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',7,'GPS0009',769.93,'eastar4','ma110*10','gtr35.hks@gmail.com','Mohamed Ali Saeed Ali Almuhairi','14729 182nd St<br>DXB 8324','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 21:40:46',0,NULL,3,1,4,1,'YW867660523CN ','ma110*10'),(15943,795735403011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','gboyd1250','gb@xpose.com.au','Allan Graham Boyd','30 Fairbrae Avenue','Belmont','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 21:50:20',0,NULL,3,0,2,1,'\\ ','gboyd1250'),(15944,588213957003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',54.49,'cnfaner','jjjp3us','jjjp3us@sbcglobal.net','Jennifer Pistone','10 Oak Crest Dr','Brookfield','CT','UNITED STATES','06804-2321','(203) 775-5430','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 21:54:34',0,NULL,3,1,1,1,'\\  ','jjjp3us'),(15945,645885283013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','geminipacific','clay_atkins@yahoo.com','Atkins','245 NW 88th Ave','Portland','OR','UNITED STATES','97229-6621','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 22:59:17',0,NULL,3,1,1,1,'\\ ','geminipacific'),(15946,795779167011,320568313808,'Genuine Apple USB External dial-up Modem All Mac',1,'WLAP009',26.99,'eastar4','sdevney','ebay@hoppinmusic.com','Steven Devney','PO Box 77','Fairview','SD','UNITED STATES','57027','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 23:17:36',0,NULL,3,1,1,1,'\\ ','sdevney'),(15947,882116213012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','imadkent','imad_naqqash@yahoo.com','imad jawad','25611 98th Ave S<br>Apt G207','Kent','WA','UNITED STATES','98030-6394','(206) 445-8171','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 23:25:01',0,NULL,3,1,1,1,' \\','imadkent\rAUI Transceiver  MX20T'),(15948,593675833004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','carpenter12206','bnelson22@cox.net','Bill Nelson','3804 Twin City Dr','Council Bluffs','IA','UNITED STATES','51501-7972','(712) 366-9501','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-14 23:39:49',0,NULL,3,1,1,1,'\\ ','carpenter12206'),(15949,792471359011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tailormade266','shante2lucas@aol.com','David Lucas','3306 Maine Ave','Long Beach','CA','UNITED STATES','90806-1238','(213) 392-4324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 23:59:27',0,NULL,3,1,1,1,'\\ ','tailormade266'),(15950,882138488012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','pduche01','bernard.duchesne@cegeptr.qc.ca','Bernard Duchesne','2150 boul. Laviolette','Trois-Rivières','QC','CANADA','G8Z1C9','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 00:27:41',0,NULL,3,1,3,1,'RA184579876CN\r ','pduche01\rOTSO004*4'),(15951,645920979013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','tomasu123','thomhod@gmail.com','Thomas Kristian Hodnemyr','Liveien 3','Venensla','Vest-Agder','NORWAY','4700','004791894427','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 00:48:04',0,NULL,3,1,2,1,'\\ ','tomasu123'),(15952,588260839003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','rcklesslydriven','thecaptainc12@hotmail.com','Jonathan Hiemstra','544 Terrace Ln','Ypsilanti','MI','UNITED STATES','48198-3044','(734) 478-9716','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 00:52:18',0,NULL,3,1,1,1,'\\ ','rcklesslydriven'),(15953,795819981011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','jmey6470','meyer730@gmail.com','Jamie Meyer','2543 E Camellia Dr','Gilbert','AZ','UNITED STATES','85296','(480) 861-5281','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 01:15:09',0,NULL,3,1,1,1,'\\  ','jmey6470'),(15954,795821303011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','jmey6470','meyer730@gmail.com','Jence Salas','48 Baxtar Ave','Quincy','MA','UNITED STATES','02169','(480) 861-5281','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 01:19:18',0,NULL,3,1,1,1,'\\ ','jmey6470'),(15955,795825136011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',2,'HBPH002',83,'eastar4uk','frankies_nipples','robert_cottrell@btinternet.com','Robert Cottrell','46 Harbour St','Whitstable','Kent','UNITED KINGDOM','CT5 1AH','01227273272','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 01:32:35',0,NULL,3,1,3,1,'RA184579947CN\r ','frankies_nipples\rHBPH002'),(15956,645933751013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','trevor16362','trewood@gmail.com','TREVOR WOOD','PO Box 480','Port Macquarie','New South Wales','AUSTRALIA','2444','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 01:41:07',0,NULL,3,1,2,1,'\\ ','trevor16362'),(15957,882165578012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',3,'ANTY001',8.94,'eastar4','florisks','ebay@slotemaker.net','Floris Kellermann Slotemaker','Schoonstraat 4-L','Heesch','','NETHERLANDS','5384AN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 01:56:53',0,NULL,3,1,2,1,'\\ ','florisks'),(15958,588275104003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','brianmstone','bmstone1@optonline.net','Brian Stone','1026 E Broadway','Milford','CT','UNITED STATES','06460-6413','(203) 298-0768','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 01:57:33',0,NULL,3,1,1,1,'\\  ','brianmstone'),(15959,588275581003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','lovelife702','thawk702@gmail.com','tobias besse','7698 Barbican Ct','las vegas','NV','UNITED STATES','89147-5161','(702) 372-2068','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 02:01:05',0,NULL,3,1,1,1,'\\ ','lovelife702'),(15960,645941786013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',273.99,'eastar4','2byitnow4u','nachosx1@bigpond.com','Scott Horton','10 Elora Rd','Oakleigh South','Victoria','AUSTRALIA','3167','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 02:13:00',0,NULL,3,1,6,1,'EE645619166CN ','2byitnow4u'),(15961,795849712011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','hoosierstuff4','sajordan001@gmail.com','Scott Jordan','300 North County Road 650 West','Yorktown','IN','UNITED STATES','47396','(765) 730-4010','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 02:48:42',0,NULL,3,1,1,1,'\\ ','hoosierstuff4'),(15962,795850648011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','katrinacross0116','katrinacross@ymanx.com','katrina cross','groby road<br>glenfield','leicester','Leicestershire','UNITED KINGDOM','LE3 8GN','01162872887','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 02:50:49',0,NULL,3,0,3,1,'RA184578195CN ','katrinacross0116'),(15963,882186086012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',37.85,'eastar4','sydney20','ayed.altamimi@hotmail.com','Ayed Binshahbal','1933/702 Harris St<br>Ultimo','Sydney','New South Wales','AUSTRALIA','2007','0424430008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 02:37:18',0,NULL,3,1,3,1,'RA184578249CN ','sydney20\rAUI Transceiver  MX20T或者210T'),(15964,882194418012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','cheec_l','rku294@freescale.com','Chee Choy Liew','51, Jalan BU 7/3 Bandar Utama,','Petaling Jaya','Selangor','MALAYSIA','47800','0122071751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 03:03:29',0,NULL,3,1,3,1,' RA184575401CN','cheec_l\rWWOT003'),(15965,882202269012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','mchr2727','matthewlc17@gmail.com','Matthew Christensen','26160 Twain Place','Stevenson Ranch','CA','UNITED STATES','91381','(661) 799-0531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 03:27:11',0,NULL,3,1,3,1,'RA184578181CN ','mchr2727  matthewlc27 \r兼容型3D眼镜 通用型'),(15966,882205121012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',10,'WLAT007',139.5,'eastar4','markd_vuw','mark@ecs.vuw.ac.nz','Mark Davies','Room 358, Cotton Building, Victoria University<br>Kelburn Parade','Wellington','Wellington','NEW ZEALAND','6012','+6444635055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 03:39:00',0,NULL,3,1,3,1,'RA184578093CN\r ','markd_vuw\rWLAT007'),(15967,593735770004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','mnagrani','mnagrani@cfl.rr.com','mark nagrani','612 Palmetto St','new smyrna beach','FL','UNITED STATES','32168-7327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 04:25:25',0,NULL,3,1,1,1,'\r\\ ','mnagrani'),(15968,645968625013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',75,'eastar4','simbaellis','harrye78@yahoo.com.au','Anthony Ellis','3 McCrory street','Coburg','Victoria','AUSTRALIA','3058','0755313103','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 04:15:07',0,NULL,3,1,3,1,'RA184578252CN ','simbaellis\rTRTT002*10\rAUI Transceiver  210T'),(15969,882223392012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','phil990099','flip909@gmail.com','Philip Dawson','Flat 4  no 17 Boscombe Cliff Road<br>Boscombe','Bournemouth','Dorset','UNITED KINGDOM','BH5 1JL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 04:43:26',0,NULL,3,0,3,1,'RA184578164CN ','phil990099\rLGAD001*1'),(15970,593738588004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','alien46','rhjarchitect@juno.com','Robert H. James','4601 Avenue B','Austin','TX','UNITED STATES','78751','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 04:46:10',0,NULL,3,1,1,1,'\\ ','alien46'),(15971,795885634011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO031',67.98,'eastar4','fedorini2010','5073950@mail.ru','Sergey Fedorchuk','Lipeckaya 54/21-74','Moscow','','RUSSIAN FEDERATION','115598','(925)507-3950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 05:07:21',0,NULL,3,1,3,1,'RA184578178CN ','fedorini2010\rHSNO031\r欧标\r旧的'),(15972,588313816003,130583982411,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',14.16,'cnfaner','dmcarroll3','dmcarroll3@aol.com','Dan M Carroll','906 Morning Sun Ln','Mc Gregor','TX','UNITED STATES','76657-9731','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 05:50:12',0,NULL,3,1,1,1,'\\ ','dmcarroll3'),(15973,588320811003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',15.24,'cnfaner','danistrauss69','arg480@gmail.com','Daniel Strauss','p.o.b 272','Migdal Ha Emek','Migdal Ha Emek','ISRAEL','23102','0522674046','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-15 06:31:08',0,NULL,3,1,2,1,'\\ ','danistrauss69'),(15974,795841889002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','dothoy2008','mazdaspeed80@yahoo.com','Joshua Peter Yu','Village 2-A, Libertad c/o Gen. Celso J. Curitana','butuan city','agusan del norte','PHILIPPINES','8600','0858161548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 06:51:06',0,NULL,3,1,17,0,NULL,'dothoy2008'),(15975,753099601001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','dothoy2008','mazdaspeed80@yahoo.com','Joshua Peter Yu','Village 2-A, Libertad c/o Gen. Celso J. Curitana','butuan city','agusan del norte','PHILIPPINES','8600','0858161548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 06:54:42',0,NULL,3,1,2,1,'\\ ','dothoy2008\rBR3D009\r再发一个3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides'),(15976,735547597008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',50.26,'au-buy','arugbynut','petemiller@optusnet.com.au','Peter Miller','L25 100 Miller St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 09:05:07',0,NULL,3,1,3,1,'RA184578544CN ','arugbynut\rHSPL015'),(15977,8881321348205375,111,'洗车器的手柄',1,'',0,'buysia','minder027','elnursa@agbank.az','Elnur Alizada','16 Landau str.','Baku','','AZERBAIJAN','AZ1073','+99455 6000227',NULL,NULL,NULL,'2011-11-15 09:10:05',0,NULL,3,0,3,1,'RA184578632CN ','minder027\r'),(15978,882289243012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','werwolf_fin','hautala.marko@gmail.com','Marko Hautala','Lyckselev. 68 2tr','Vallingby','Stockholm','SWEDEN','16267','(004) 670-4951 ext.: 495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 09:26:28',0,NULL,3,1,2,1,' \\ ','werwolf_fin\racer 6pin1.25 23cm'),(15979,8881321349409887,111,'New 2010 FIFA World Cup Film 3D Blu-ray BD Region Free',1,'',0,'buysia','goniveseli','agves@albmail.com','AGRON VESELI','LAGJA 6 RRUGA MALIQ MUCO<br>PALLATI 973 AP.6','DURRES','DURRES','ALBANIA','2001','+355-682033567',NULL,NULL,NULL,'2011-11-15 09:30:09',0,NULL,3,0,3,1,'RA184578473CN ','goniveseli '),(15980,588351756003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','zorglub_one','eric.grandjean@bluewin.ch','Eric Grandjean','37 Avenue de la Praille','Carouge','','SWITZERLAND','1227','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-15 09:47:55',0,NULL,3,1,3,1,'RA184574692CN ','zorglub_one\rMOOE003\r2000B OEM '),(15981,880003099012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','nevros85','hammeren85@yahoo.no','Dan-Gøran Hammer','Olsvikmarken 58','Bergen','Olsvik','NORWAY','5183','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 10:16:21',0,NULL,3,1,3,1,'RA184578527CN ','nevros85\rGLOT001*2'),(15982,8881321353525258,111,'New GENUINE Plantronics Explorer 330 ',1,'HSPL005',13.58,'buysia','ilya1908','voytolovsky@gmail.com ','ILLYA VOJTOLOVSKIJ','3 Pivdenno-Kiltseva St Apt 177','Chernivtsi','Chernivtsi Region','UKRAINE','58013','',NULL,NULL,NULL,'2011-11-15 10:38:45',0,NULL,5,0,18,0,NULL,NULL),(15983,8881321353664562,111,'New GENUINE Plantronics Explorer 330 ',1,'HSPL005',13.58,'buysia','ilya1908','voytolovsky@gmail.com ','ILLYA VOJTOLOVSKIJ','3 Pivdenno-Kiltseva St Apt 177','Chernivtsi','Chernivtsi Region','UKRAINE','58013','',NULL,NULL,NULL,'2011-11-15 10:38:45',0,NULL,5,0,18,0,NULL,NULL),(15984,8881321353679025,111,'New GENUINE Plantronics Explorer 330 ',1,'HSPL005',13.58,'buysia','ilya1908','voytolovsky@gmail.com ','ILLYA VOJTOLOVSKIJ','3 Pivdenno-Kiltseva St Apt 177','Chernivtsi','Chernivtsi Region','UKRAINE','58013','',NULL,NULL,NULL,'2011-11-15 10:38:45',0,NULL,3,1,2,1,' \\ ',' ilya1908\r欧标\r\r'),(15985,882313667012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','liverpool-furniture','furnitureliverpool@hotmail.co.uk','mark rosenblatt','12 Kempston Street','Liverpool','Merseyside','UNITED KINGDOM','L3 8NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 10:45:18',0,NULL,3,1,3,1,' RA184575358CN','liverpool-furniture\rUM00027\r蕾丝蝴蝶结长柄伞   umbrella 红色'),(15986,882319784012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',159.99,'eastar4','grzegorzdrzazga','drzazgag@tlen.pl','Grzegorz Drzazga','13 Woodleigh Grove','Blessington','Wicklow','IRELAND','045','0688890013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 11:04:17',0,NULL,3,1,3,1,'RA184578601CN ','grzegorzdrzazga\rGLSG001*3'),(15987,645623872013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',23.74,'eastar4','hmckenna10310','helen_stanley2004@hotmail.co.uk','Helen Stanley','5 LEONARDA DRIVE<br>ARANA HILLS','BRISBANE','Queensland','AUSTRALIA','4054','0416169431','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'hmckenna10310'),(15988,588383336003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','andrzejb077','andrzejb@sbcglobal.net','Andrzej Bajguz','93 Country Hill Rd','Naugatuck','CT','UNITED STATES','06770','(203) 723-8632','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 12:25:11',0,NULL,3,1,1,1,' \\ ','andrzejb077'),(15989,593821908004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','akusher','akusher_2000@yahoo.com','Aleksey Ikhelson','29 Crystal Ln','paterson','NJ','UNITED STATES','07501-3373','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 12:55:28',0,NULL,3,1,1,1,' \\ ','akusher'),(15990,646069547013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.39,'eastar4','tgrick','tgrick@pobox.com','Rick Socarras','2238 SW 27TH WAY','MIAMI','FL','UNITED STATES','33133','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 13:15:10',0,NULL,3,1,1,1,' \\ ','tgrick'),(15991,796010863011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',2,'HBPH003',39,'eastar4','mannyb81','aquiestoy81@yahoo.com','Manuel Barajas','3404 Broadway','Huntington Park','CA','UNITED STATES','90255-6444','(321) 303-0449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 13:17:42',0,NULL,3,1,1,1,' \\ ','mannyb81'),(15992,796021011011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.88,'eastar4','der_chris_aus_bielefeld','cj.maass@googlemail.com','Christoph Maass','Karl-Marx-Str. 50','Heilbronn','','GERMANY','74080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 13:45:30',0,NULL,3,1,2,1,' \\ ','der_chris_aus_bielefeld'),(15993,882377088012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','mayscomputersltd','mayscomputers@googlemail.com','Alan May','57 Church gate','Leicester','Leicestershire','UNITED KINGDOM','le1 3al','01162915555','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 13:46:36',0,NULL,3,1,3,1,'RA184578460CN ','mayscomputersltd\rRELO002'),(15994,646079133013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','mcrush0774','crush0774@gmail.com','Mikhail Ivanov','Profsoyuznaya 19 - 72','Moscow','','RUSSIAN FEDERATION','117218','9032017434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 13:51:03',0,NULL,3,1,11,1,'、 ','mcrush0774\rUM00033'),(15995,646082669013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','terminandy','net-wars@web.de','Andreas Baranowski','Schierenstr.12','Königslutter/Lelm','','GERMANY','38154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 14:03:52',0,NULL,3,1,2,1,' \\ ','terminandy'),(15996,882383898012,220816317096,'NewAutofold Solid Durable16K businss Man stick Umbrella',2,'UM00020',55.08,'eastar4','iluznoam','noamiluz@gmail.com','noam iluz','igal alon 40/7','haifa','israel','ISRAEL','32983','972549883030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 14:06:28',0,NULL,3,1,3,1,'RA184578938CN ','iluznoam\r一把黑色和一把咖啡色的\rUM00020'),(15997,646090150013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','pijnap75','ebay@arno-pijnappels.com','A.M. Pijnappels','Kruinstraat 7','Wanroij','','NETHERLANDS','5446VE','0628700895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 14:31:10',0,NULL,3,1,2,1,' \\ ','pijnap75'),(15998,646090986013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','veilakillar125','veilakillar@gmail.com','Anna Krutova','Vasilyeva St, 29 - 59','Snezhinsk','RU','RUSSIAN FEDERATION','456770','89617893238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 14:33:46',0,NULL,3,1,2,1,' \\ ','veilakillar125\r欧标'),(15999,882408829012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','internetdefender','kaasblad+ebay@gmail.com','Jamie Schembri','Keverlaan 36<br>Son','Son','','NETHERLANDS','5692 VT','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 15:03:01',0,NULL,3,1,2,1,' \\ ','internetdefender'),(16000,646106531013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.39,'eastar4','carriedby6','dillon@hour6.com','Bill Dillon','5 Hattie Lane','Billerica','MA','UNITED STATES','01821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 15:27:53',0,NULL,3,1,1,1,' \\ ','carriedby6'),(16001,796076739011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',24.99,'eastar4uk','borport7','borport@netvision.net.il','Boris Rapoport','Alenbi 84','Haifa','','ISRAEL','35666','0525281232','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 16:09:07',0,NULL,3,1,2,1,' \\ ','borport7'),(16002,796077954011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','plindset','plindset@online.no','Per Lindseth','Knutstien 1','Isfjorden','','NORWAY','6320','004790838334','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 16:10:22',0,NULL,3,1,2,1,' \\ ','plindset'),(16003,646119721013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','triomphe3','tras3@gmx.net','Javier Ruiz Baragaño','c/ Antonio Sacramento, 17, esc.1 pta. 44','Valencia','Valencia','SPAIN','46013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 16:12:19',0,NULL,3,1,2,1,' \\ ','triomphe3'),(16004,796079166011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','androyp','roy.plod@live.co.uk','Roy Pollard','34 Arnside<br>Stapleford','Nottingham','Nottinghamshire','UNITED KINGDOM','NG9 7EY','07931800188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 16:12:47',0,NULL,3,1,3,1,'RA184578495CN\r ','androyp\rMOAP001'),(16005,593888310004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',13.98,'cnfaner','tgtyler','travisgtyler@att.net','Travis Tyler','1703 Windy Meadow Dr','Houston','TX','UNITED STATES','77084','(832) 244-2111','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 16:55:56',0,NULL,3,1,1,1,' \\ ','tgtyler'),(16006,645675280013,230661758325,'NEW Ralink RT2870F Wi-Fi USB Adapter chip  WIS09ABGN',1,'OTRA003',35.99,'eastar4','shurikdelfin','shurik_65@gmx.com','Fomin Aleksej Sergeevich','Gajdara, 9-64','Novopolock','','BELARUS','211443','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 16:57:35',0,NULL,3,1,2,1,' \\ ','shurikdelfin'),(16007,796106677011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','bayonne67','didier.joulia@laposte.net','Didier JOULIA','4 rue des Acacias','WINTERSHOUSE','Alsace','FRANCE','67590','0628348181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 17:10:50',0,NULL,3,1,3,1,'RA184578535CN ','bayonne67\rGLOT001'),(16008,882486010012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','felipecupzzz','cupmailz@gmail.com','Felipe Martins','Rua Frei Caneca n.58 apt. 104','Sao Paulo','Sao Paulo','BRAZIL','01307000','551397069445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 17:42:14',0,NULL,3,1,2,1,' \\ ','felipecupzzz'),(16009,796134216011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','tic600644tic','ttiicc@yandex.kz','Вадим Насыпайко','проспект Mеталлургов 3/1-19','Темиртау','','KAZAKHSTAN','101400','+7 7213 909956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 18:04:02',0,NULL,3,1,2,1,'、 ','tic600644tic'),(16010,796142074011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mk520t','mk420v@me.com','James Hastings','8609 Dunlap St','Houston','TX','UNITED STATES','77074-7723','(281) 546-3930','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 18:19:44',0,NULL,3,1,1,1,' \\ ','mk520t'),(16011,792357863011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','paub0303','p.estrada5@yahoo.com','Paul Estrada','898 Ellen st','Colton','CA','UNITED STATES','92324-1122','(909) 885-7271','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 18:59:42',0,NULL,3,1,1,1,' \\','paub0303'),(16012,646192420013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','cpen7621','courtneyp@ljs.com','Courtney Penn','2151 Old Willow Road','Northfield','IL','UNITED STATES','60093','(847) 386-9350','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 19:08:51',0,NULL,3,1,1,1,' \\ ','cpen7621'),(16013,796183223011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',2,'BAIN001',9.96,'eastar4uk','khristianangel','flip25_2003@yahoo.com','cherwin dayoan','27621 ginger way','santa clarita','CA','UNITED STATES','91350-1646','(805) 824-1223','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 19:23:55',0,NULL,3,1,1,1,' \\ ','khristianangel'),(16014,796186754011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','bobtina1955','tinawhitby@aol.com','tina whitby','180 Eastcote Road','Ruislip','Middlesex','UNITED KINGDOM','HA48DY','01895621880','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 19:34:08',0,NULL,3,1,3,1,'RA184578558CN ','bobtina1955\rHSNO026\r英标'),(16015,882573346012,220459522492,'Acer Aspire 5680 5630 3690  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','breakboyleo','pernestor_@hotmail.com','Leonardo Victoriano','8400 NW 25th St<br>Ste 110','Doral','FL','UNITED STATES','33122-1530','(305) 593-5383','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 19:52:08',0,NULL,3,1,1,1,' \\ ','breakboyleo\racer 8pin1.00 8cm'),(16016,646214938013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','shaidn1','shaidn12@gmail.com','shai daniel','ben zion leon 15 pisgat zeev mizrah','jerusalem','','ISRAEL','97583','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 19:56:56',0,NULL,3,1,2,1,' \\ ','shaidn1'),(16017,882603409012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',12.39,'eastar4','dar7914','dar7914@o2.pl','Dariusz Zardulewicz','20 Munster Avenue','Galway','Galway','IRELAND','0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 20:29:26',0,NULL,3,1,2,1,' \\ ','dar7914\racer 5pin1.25 15cm'),(16018,735824842008,180755479461,'New Jabra BT125 Bluetooth headset',1,'HSJA006',13.55,'au-buy','amc_maura','123antic@web.de','Maura Kummer','Ridlerstr. 29E','Muenchen','','GERMANY','80339','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-15 20:42:08',0,NULL,3,1,2,1,' \\ ','amc_maura'),(16019,796255150011,320730088383,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',48.99,'eastar4uk','darkondarkon','darko.grasic@amis.net','Darko Grasic','Maroltova 9','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 21:13:36',0,NULL,3,1,3,1,'RA184578411CN ','darkondarkon\rMOSA006'),(16020,743258250007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.9,'au-buy','capital.713','barronace@yahoo.com','Adam Barron','10125 Telephone Rd.','Houston','TX','UNITED STATES','77075-1554','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-15 21:32:22',0,NULL,3,1,1,1,' \\ ','capital.713'),(16021,882660122012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','rossflanagan1982','ross.flanagan@hotmail.co.uk','Ross Flanagan','24 Buckingham Road<br>Cheadle Hulme','Cheadle','Cheshire','UNITED KINGDOM','SK8 5EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 21:53:35',0,NULL,3,1,3,1,'RA184578487CN\r ','rossflanagan1982\rHBPH003'),(16022,882660369012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','wrenbabson1','wrenbabson@gmail.com','Warren Babson','70 10th St<br>Apt 1','Hoboken','NJ','UNITED STATES','07030-5127','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-15 21:56:27',0,NULL,3,1,1,1,' \\ ','wrenbabson1'),(16023,796292066011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',2,'LGGL002',65.98,'eastar4uk','marcow00711','marcow007@hotmail.fr','Hotel st quentin a l attention de Mr sfaxi','27 rue st quentin','PARIS','Ile-de-France','FRANCE','75010','0617408523','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 22:20:10',0,NULL,3,1,3,1,'RA184578513CN ','marcow00711\rLGGL002'),(16024,796292886011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','coreyasa','brown_21@live.ca','Corey Brown','169 Garden Avenue','Richmond Hill','ON','CANADA','l4c 6l7','(905) 764-9568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 22:21:49',0,NULL,3,1,2,1,' \\ ','coreyasa'),(16025,594028372004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','lindsayibarra','ibarra.lindsay@gmail.com','Lindsay Ibarra','24875 Prielipp Rd<br>Apt 1128','Wildomar','CA','UNITED STATES','92595-7789','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 22:43:40',0,NULL,3,1,1,1,' \\ ','lindsayibarra'),(16026,796305070011,320730085617,'New Atheros AR5008 802.11N Wireles WiFi Mini PCI-E Card',1,'WLAT001',8.99,'eastar4uk','rapid-power','win0lin1@gmail.com','Linvydas Lapinskas','Sermuksniu 3','Vievis','','LITHUANIA','LT-21379','+37063684269','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 22:47:56',0,NULL,3,1,2,1,' \\ ','rapid-power'),(16027,646291652013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','marlusr','marlu@marlu.sk','Marian Luspai','Romanova 44','Bratislava','','SLOVAK REPUBLIC','85102','0903888989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 23:05:01',0,NULL,3,1,2,1,' \\ ','marlusr'),(16028,882701339012,220877932141,'New HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'eastar4','hermnnchen','erwalder@gmx.de','Mario Graf','Rudolf-Leonhard-Str. 43','Dresden','','GERMANY','01097','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 23:11:58',0,NULL,3,1,2,1,' \\ ','hermnnchen'),(16029,646294154013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','glouck_eb','glouck@gmail.com','Ilya Gribov','PROFSOUZNAYA UL.,D. 85, KOR. 1, KV. 251','Moscow','','RUSSIAN FEDERATION','117279','+7-916-684-7433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 23:11:15',0,NULL,3,1,2,1,' \\ ','glouck_eb'),(16030,588615504003,130553147002,'New Jabra BT125 Bluetooth Wireless Headset BT 125',2,'HSJA006',25.74,'cnfaner','la_bestia2005','jdeoleo1984@gmail.com','jose de oleo','15 Storms Ave<br># 1','jersey city','NJ','UNITED STATES','07306-3372','(201) 780-7409','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-15 23:59:54',0,NULL,3,1,1,1,' \\ ','la_bestia2005'),(16031,796343247011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','metallicarra','adam_carra@hotmail.com','Adam  Carra','1, Warwick Road, Derwen Fawr','Swansea','Swansea','UNITED KINGDOM','SA28DZ','01792419942','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 00:28:05',0,NULL,3,1,3,1,'RA184578500CN ','metallicarra\rMOAP001'),(16032,796278091002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','gsamonte','gsamonte@aol.com','Glenn Samonte','9686 Coney Island Cir','Elk Grove','CA','UNITED STATES','95758-3650','(916) 709-9281','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 01:02:44',0,NULL,3,1,1,1,' \\ ','gsamonte'),(16033,796358183011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','leandrogarroti','garroti@hotmail.com','Leandro Carlos Garroti Juvenal','Av. São José, 406 apto 24 TA','Diadema','UT/São Paulo/BR','BRAZIL','09910-380','+55 11 8060-4810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 01:12:25',0,NULL,3,1,2,1,' \\ ','leandrogarroti'),(16034,594064700004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','phatdak305','phatdak@gmail.com','Francesca A Watson','500 14th St<br>Apt 106','miami beach','FL','UNITED STATES','33139-4094','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 01:41:47',0,NULL,3,1,1,1,'\\  ','phatdak305'),(16035,646338115013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','kenshin6x','junior.synthax@gmail.com','Vicente de Paulo Andrade Junior','Nova Parnamirim, Rua Adail Pamplona de Menezes, 398<br>Park Towers, Torre A, Apartamento 804','Parnamirim','Rio Grande do Norte','BRAZIL','59151-680','55 84 94316634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 02:03:04',0,NULL,3,1,2,1,' \\ ','kenshin6x'),(16036,743373364007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.9,'au-buy','shawaustralia','service@besawa.com.au','Keith Baker','12/13<br>Church Road','Maddington','Western Australia','AUSTRALIA','6109','0894935520','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 02:47:06',0,NULL,3,1,3,1,'RA184578561CN ','shawaustralia\rHSPL013\r澳标\r'),(16037,882788425012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','wilsonos2','wilsonos2@hotmail.com','Donald  Wilson','120 Plank Rd','York Springs','PA','UNITED STATES','17372-9605','(717) 577-8832','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 02:58:25',0,NULL,3,1,6,1,'EE645619373CN ','wilsonos2'),(16038,646354794013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',10.99,'eastar4','alexandr_makarenko','alex_mak@inbox.ru','Alexandr Makarenko','Panfilovcev st. 5 - 77','Novosibirsk','','RUSSIAN FEDERATION','630039','+7 923 2247337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 02:59:13',0,NULL,3,1,2,1,' \\ ','alexandr_makarenko'),(16039,743380304007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','pugdogsrule','espresso54@aol.com','ARINC, Matt Sirkis','7666 E 61st St<br>Suite 625','Tulsa','OK','UNITED STATES','74133-1155','(918) 606-0999','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 03:10:34',0,NULL,3,1,1,1,'、 ','pugdogsrule'),(16040,646358103013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','kyle12983','livinitupforever@hotmail.com','Kyle Knoepfle','5309 Antelope Dr','Bar Nunn','WY','UNITED STATES','82601-7469','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 03:12:39',0,NULL,3,1,1,1,'、 ','kyle12983'),(16041,882800756012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',23.74,'eastar4','izos','elgraph@gmail.com','Izoslav Elenbogen','Shdema str. POB 15028<br>78/7','Karmiel','Galil','ISRAEL','21610','972-523-720-961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 03:33:27',0,NULL,3,1,11,1,'\\','izos\rUM00016'),(16042,588665009003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.29,'cnfaner','bidgiefroe','froebidgie@yahoo.com','BIDGIE FROE','PO BOX 5874','CAPITOL HEIGHTS','MD','UNITED STATES','20791-5874','(202) 812-9001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 03:39:19',0,NULL,3,1,1,1,'、 ','bidgiefroe'),(16043,8881321415156875,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',0,'eastar4','sim.0n','simon.kneringer@gmail.com','Simon Kneringer','Prof.-Franz-Spath-Ring 3/10','Graz','','AUSTRIA','8042','',NULL,NULL,NULL,'2011-11-16 03:45:56',0,NULL,3,1,2,1,' \\ ','补发的 '),(16044,8881321417574175,111,'只补发一条线  HP 8PIN 1.25   18CM',1,'',0,'eastar4','leo2006mo','susmohns@googlemail.com','Susanne Mohns','Max-von-Laue-Straße 26','Remscheid','','GERMANY','42897','',NULL,NULL,NULL,'2011-11-16 04:26:14',0,NULL,3,0,2,1,'、 ',NULL),(16045,796418928011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','msharma1111','manojdevikasharma@msn.com','Manoj Sharma','1 Hunters Ridge Dr','Saginaw','MI','UNITED STATES','48609-9318','(989) 781-6489','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 04:33:31',0,NULL,3,1,1,1,'、 ','msharma1111'),(16046,796420898011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','streets1971','mrgoodbar239@msn.com','conrad MCDONALD','239 REMSEN AVE','BROOKLYN','NY','UNITED STATES','11212-1351','(917) 627-0899','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 04:42:14',0,NULL,3,1,1,1,'、 ','streets1971'),(16047,796421493011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','tomcatdriver1','tomcatdriver@gmail.com','James Hineline','PO Box 27388','Panama City','FL','UNITED STATES','32411-7388','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 04:44:18',0,NULL,3,1,1,1,' \\ ','tomcatdriver1'),(16048,882824534012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','rogersbrent','brent-rogers1@rogers.com','Brent Rogers','50 Victoria Street','Etobicoke','ON','CANADA','M8V1M6','(416) 251-3591','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 05:00:39',0,NULL,3,1,2,1,' \\ ','rogersbrent'),(16049,796431992011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sunchobg','support@sepia-bg.com','Evgeny Pavlov','11 august 30','Sofia','Sofia','BULGARIA','1000','+359 878 309 223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 05:33:39',0,NULL,3,1,2,1,' \\ ','sunchobg\r欧标'),(16050,882833750012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','ez_2007','aa2000@hotmail.com','kyuwon yon','1827 Brown Deer Cv','coralville','IA','UNITED STATES','52241-1170','(515) 257-2026','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 05:39:37',0,NULL,3,1,1,1,' \\ ','ez_2007'),(16051,882836444012,220816317096,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',27.54,'eastar4','settonavi','setton.avi@gmail.com','avi setton','ramat raziel 1','ramat raziel','','ISRAEL','90974','025797088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 05:58:40',0,NULL,3,1,11,1,'、 ','settonavi\rUM00020\r咖啡色的'),(16052,879181368012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','gbms13','geoffbecmatty@hotmail.com','Geoff Steele','65 Sunbury St','Geebung','Queensland','AUSTRALIA','4034','0738658875','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 06:01:17',0,NULL,3,1,3,1,'RA184578592CN ','gbms13\rOTSO004*3'),(16053,8881321426145792,111,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',0,'eastar4','drookie101','parin.tjandra@gmail.com','Parin Tjandra','38 Telfer Road','Castle Hill','New South Wales','AUSTRALIA','2154','',NULL,NULL,NULL,'2011-11-16 06:49:05',0,NULL,3,1,2,1,'\\','补发的 '),(16054,796447284011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',177.98,'eastar4','probe.canady22','bryon.canady@att.net','Bryon Canady','6041 Katie Emma Dr','Powder Springs','GA','UNITED STATES','30127-8341','(770) 694-6744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 07:08:08',0,NULL,3,1,6,1,'EE645619206CN ','probe.canady22\r一共买了四副'),(16055,796462055011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','gustavo.canedo','gustavocanedo@terra.com.br','Gustavo Medeiros','Rua Homem de Melo<br>55, Bloco2, Apto 503','Rio de Janeiro','Rio de Janeiro','BRAZIL','20510-180','21-22980515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 08:05:08',0,NULL,3,1,3,1,'RA184578646CN ','gustavo.canedo\rGLOT001\r兼容型3D眼镜 通用型'),(16056,882877049012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','domriccc','domriccc@hotmail.com','Dominic Richer','21 Lesieur','Ste-Geneviève de Batiscan','QC','CANADA','G0X2R0','(418) 362-2962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 08:50:15',0,NULL,3,1,2,1,'、 ','domriccc\racer 8pin1.00 15cm '),(16057,796489945011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','torhak','shop@jannkruse.de','Jann Eike Kruse','Odos Ethnikis Antistasis 5 - Marathitis<br>ΟΔΟΣ ΕΘΝΙΚΗΣ ΑΝΤΙΣΤΑΣΗΣ 5 - ΜΑΡΑΘΙΤΗΣ','Heraklion','Crete','GREECE','71409','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 09:53:48',0,NULL,3,1,2,1,'、 ','torhak'),(16058,796418233002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','udvardy','karoly.udvardy@y7mail.com','Karoly Udvardy','Unit 9 / 27 Walton St.','Southport','Queensland','AUSTRALIA','4215','070421313674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:05:55',0,NULL,3,1,2,1,'\\ ','udvardy'),(16059,882899622012,220820867548,'New Grohe handheld Shower Head big water output + hose',1,'OTGR005+OTGR002',39.9,'eastar4','ernest_mr','ernest_p@optusnet.com.au','Ernest Pramana','16 Rosemary Street','Chadstone','VICTORIA','AUSTRALIA','3148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:06:35',0,NULL,3,1,2,1,'\\ ','ernest_mr'),(16060,646434779013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','alex.radinsky','radinsky@gmail.com','Alex Radinsky','haMaavak 31<br>Flat 1','Givataim','IL','ISRAEL','53523','972544668325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:23:39',0,NULL,3,1,2,1,'\\ ','alex.radinsky'),(16061,743493836007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','pointenergie','commercial@pointenergie.fr','POINT PILES','133 BD GAMBETTA','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06000','0493963065','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 11:24:51',0,NULL,3,1,2,1,'\\ ','pointenergie'),(16062,646461645013,230653158623,'New Grohe handheld Shower Head big water output Massage',2,'OTGR005',45.8,'eastar4','gilad_b','gilad_b@netvision.net.il','Gilad Barnea','P.O. Box 87','Jerusalem','','ISRAEL','91000','972-26713883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 12:27:27',0,NULL,3,1,3,1,'RA184578819CN\r ','gilad_b\rOTGR005'),(16063,882948285012,220886921872,'Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',12.95,'eastar4uk','ranger166','ussmalta@gmail.com','Patrick D`agostino','43/7 canada Flats<br>ganni bencini str','gzira','','MALTA','gzr 1200','35699458575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 12:37:22',0,NULL,3,1,11,1,'\\ ','ranger166\rUM00001\r紫色的 \r不挂号'),(16064,796522997011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','myrsias','myrsias@hotmail.com','Petros Lamprides','177 Demirdessiou str','Athens','','GREECE','14233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 12:39:48',0,NULL,3,1,2,1,'\\ ','myrsias'),(16065,882971617012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','dormeagain','tswright@rochester.rr.com','Tom Wright','74 Highledge Dr','Penfield','NY','UNITED STATES','14526-2408','(585) 218-9227','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 13:40:18',0,NULL,3,1,1,1,'、 ','dormeagain'),(16066,882991287012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','rhar8287','harrisenhance@gmail.com','Robert Harris Jr.','3212 Latona St','Philadelphia','PA','UNITED STATES','19146-3416','(215) 334-2191','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 14:27:17',0,NULL,3,1,6,1,'EE645619210CN ','rhar8287\r兼容型3D眼镜 通用型'),(16067,588785253003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','k-ofalltrades','k_ofalltrades@yahoo.com','Karl Hamrick','607 K St','Mt Lake Park','MD','UNITED STATES','21550-3300','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 14:27:59',0,NULL,3,1,1,1,'、 ','k-ofalltrades'),(16068,743557333007,170728921103,'New Genuine Sony Ericsson HBH-PV703 Bluetooth Wireless Headset',1,'HSSE004',21.9,'au-buy','jlmclk2563po','meltopo@yahoo.gr','ΒΑΣΙΛΕΙΟΣ ΜΕΛΙΣΣΑΣ','ΗΛΙΟΚΩΜΗ','ΣΕΡΡΕΣ','ΑΝΑΤΟΛΙΚΗ ΜΑΚΕΔΟΝΙΑ','GREECE','62047','6977541193','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 14:36:47',0,NULL,3,1,2,1,'\\ ','jlmclk2563po\r欧标\r'),(16069,588797310003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',5,'SCLO001',87,'cnfaner','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 574-4595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 15:12:55',0,NULL,3,1,1,1,' 、','4278dennis'),(16070,594231604004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','junrbarnes','junrbarnes@gmail.com','Robert Siegel','119 Mount Olivet Dr','Six Mile','SC','UNITED STATES','29682-9788','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 15:15:38',0,NULL,3,1,1,1,'、 ','junrbarnes'),(16071,646520226013,230623270363,'NIB 3D Active Shutter TV Glasses with IR emitter',1,'GLOT002+GLOT003',80,'eastar4','hopkins07956','hopkins@ringaringtone.com','andrew hopkins','19 rowantree road','enfield','middx','UNITED KINGDOM','en28qa','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 15:58:38',0,NULL,3,1,3,1,'RA184578875CN\r ','hopkins07956\rGLOT002+GLOT003'),(16072,796608163011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',3,'HSNO026',31.2,'eastar4uk','redbirdwutz','wutz@igghe.de','Petra Meier','Am Desenberg 4','Schlangen-Kohlstädt','','GERMANY','33189','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 15:43:38',0,NULL,3,1,3,1,'RA184574560CN\r ','redbirdwutz\r欧标\rHSNO026'),(16073,646523866013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','jeromef76','jf_amiens@hotmail.com','FOUQUET Jerome','Batiment D10 - 4eme étage porte droite<br>136, rue georges le du','CORBEIL ESSONNES','Ile-de-France','FRANCE','91100','0686152782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 16:09:15',0,NULL,3,1,2,1,'\\ ','jeromef76'),(16074,646521250013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','ayrton_senna74','iakovos_74@hotmail.com','Panagiotis Gigklas','Arkadiou 8','Maroussi','','GREECE','15124','(0030) 6944141950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 16:09:38',0,NULL,3,1,3,1,'RA184578898CN\r ','ayrton_senna74\rLGGL002'),(16075,796412650011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','kaoss6911','mattykaoss@gmail.com','Vicki McKee','Second Foundation<br>45 Washburn Drive','Kitchener','ON','CANADA','N2R 1S1','(226) 989-0972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 16:13:36',0,NULL,3,1,2,1,'\\ ','kaoss6911\racer 8pin1.00 8cm'),(16076,588815695003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.24,'cnfaner','jd72cv11','jwalters@fnal.gov','Johnathan Walters','805 W Bergera Rd','Braidwood','IL','UNITED STATES','60408','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 16:15:38',0,NULL,3,1,1,1,'、 ','jd72cv11'),(16077,743598858007,170728921067,'New Genuine Sony Ericsson HBH-PV702 Bluetooth Wireless Headset',1,'HSSE003',21.9,'au-buy','tatkid','autistickid@hotmail.com','Pauline Lam','1009<br>55 South Town Centre Blvd.','Markham','ON','CANADA','L6G0B1','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'\\ ','tatkid'),(16078,646533980013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','26031963374134','jelov@mail.ru','Zhelov Alexandr','Cultures 37/4','Bryansk','Bryansk area','RUSSIAN FEDERATION','241020','583280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 16:55:23',0,NULL,3,1,2,1,'\\ ','26031963374134'),(16079,883068221012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','420goofyfoot','codemon@fastmail.fm','Sam W Coody','213 S Hill Dr','Weatherford','TX','UNITED STATES','76086-5150','(817) 598-8820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 17:11:45',0,NULL,3,1,1,1,'、 ','420goofyfoot'),(16080,795545962011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','theqj2020','justanavgjoe2@gmail.com','Johnnie Quezada','632 State Highway 11C, Nos. 331<br>Apt. 6','Winthrop','NY','UNITED STATES','13697','(305) 208-8019','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 17:32:17',0,NULL,3,0,1,1,'、 ','theqj2020\r已入库'),(16081,588841672003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.03,'cnfaner','zoomzpro','zoomdepro@hotmail.com','Kirill Garnets','Schipholtstraat 154','Enschede','','NETHERLANDS','7534 dc','0031634825823','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-16 17:42:41',0,NULL,3,1,2,1,'\\ ','zoomzpro\r欧标\r'),(16082,646556880013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','sosb3122','osborne6022@bellsouth.net','Sandra Osborne','256 N Fork Branch Rd','Rogersville','TN','UNITED STATES','37857-5338','(423) 235-2011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 17:43:28',0,NULL,3,1,6,1,'EE645619223CN ','sosb3122\r兼容型3D眼镜 通用型'),(16083,588846917003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',22.61,'cnfaner','dameonmom','kimberlyprather@hotmail.com','Kimberly M Prather','112 Prather Dr','Selmer','TN','UNITED STATES','38375','(731) 645-3680','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 17:49:01',0,NULL,3,1,1,1,'、 ','dameonmom'),(16084,646558388013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','robertskritikrt','robertkovacic1@gmail.com','Robert Kovacic','Fani Grumove 4.','Ljubljana','Ljubljana','SLOVENIA','1129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 17:50:39',0,NULL,3,1,2,1,'\\ ','robertskritikrt\r新的  \r欧标'),(16085,883127571012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 18:48:47',0,NULL,3,1,3,1,'RA184578840CN\r ','lochearn1234\rWLAP002\r发AIRPORT 的'),(16086,588879580003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',2,'HSPL013',102.58,'cnfaner','sherbob','kmshirley@gmail.com','Kevin Shirley','1911 Cub Run Rd','Cub Run','KY','UNITED STATES','42729-9304','(270) 646-7321','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 19:10:30',0,NULL,3,1,1,1,'、 ','sherbob'),(16087,588881976003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','yallan99','ayoun1@uis.edu','Allan Young','849 Oxford dr.','Chatham','IL','UNITED STATES','62629','(217) 483-7414','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 19:14:23',0,NULL,3,1,1,1,'、 ','yallan99'),(16088,796706360011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','feridounahmed','fareedoon@gmail.com','Fareedoon Ahmed','4 Fowey Avenue','Ilford','Essex','UNITED KINGDOM','IG4 5JT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 19:16:49',0,NULL,3,1,3,1,'RA184578836CN\r ','feridounahmed\r红边优联\rRELO003'),(16089,883134894012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','machovevgeniy','machov@post.ru','Евгений Mахов','Мурманский проезд,дом8,кв.36','Ярославль','','RUSSIAN FEDERATION','150061','(8910) 9786839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 19:25:32',0,NULL,3,1,3,1,' RA184575335CN','machovevgeniy\rWWOT003'),(16090,883157728012,220885115378,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',21.99,'eastar4uk','reinaldoherrig','reinaldo_herrig@hotmail.com','reinaldo Herrig','28 Park Road<br>Smallfield','Horley','Surrey','UNITED KINGDOM','RH69RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 19:30:20',0,NULL,3,1,3,1,'RA184578765CN\r ','reinaldoherrig\rHSPL008\r英标'),(16091,796740160011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','daw1826','treharne@uku.co.uk','david walker','19 roffes lane','chaldon','surrey','UNITED KINGDOM','cr3 5pu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 19:44:31',0,NULL,3,1,3,1,'RA184578822CN\r ','daw1826\rUDAP001'),(16092,646620368013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','jasongatt05','jason.gatt@optusnet.com.au','Jason Gatt','3 Hughes<br>Avenue','Castle Hill','New South Wales','AUSTRALIA','2154','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jasongatt05'),(16093,883197497012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','donkeyflock1','john@jmsharlow.co.uk','Mr John Mann','The Lyceum Theatre<br>21 Wellington Street,','London','London','UNITED KINGDOM','WC2E 7RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 20:25:46',0,NULL,3,1,3,1,'RA184578853CN\r ','donkeyflock1\rOTCN004*10'),(16094,883202265012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','geneskcan','gfroc@sasktel.net','Gene Froc','608 McLeod Street','Regina','SK','CANADA','S4N 4Y1','(306) 721-7100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 20:32:26',0,NULL,3,1,3,1,'RA184578907CN\r ','geneskcan\rOTSO004*2'),(16095,588917431003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',45.22,'cnfaner','pmwmitchell','senderror@gmail.com','William Mitchell','9710 Traville Gateway Dr<br># 161','Rockville','MD','UNITED STATES','20850-7408','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 20:38:24',0,NULL,3,1,1,1,'、 ','pmwmitchell'),(16096,796768157011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',39.96,'eastar4','elsosocaustico','marc@marcdemiguel.com','Marc de Miguel','Av. Diagonal, 401 Entresol','Barcelona','Cataluña','SPAIN','08008','620710896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 20:39:31',0,NULL,3,1,2,1,'\\ ','elsosocaustico'),(16097,883213767012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','angikelley1','angikelley1969@gmail.com','ms angela kelley','17, Cranbrook way','pontefract','West Yorkshire','UNITED KINGDOM','WF8 2UT','01977798404','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 20:49:43',0,NULL,3,1,3,1,' RA184575300CN','angikelley1\rUM00027\r蕾丝蝴蝶结长柄伞   '),(16098,880346131012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','cosmicgirlndc','eritho7@yahoo.com','Erica Thompson Briggs','PO Box 826','Burtonsville','MD','UNITED STATES','20866','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 21:06:30',0,NULL,3,1,1,1,'、 ','cosmicgirlndc\r蕾丝蝴蝶结伞 黑色'),(16099,743771618007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','liquidstar_com','rem@liquidstar.com','Remik Kotecki','Chipworks<br>500-3685 Richmond Rd.','Ottawa','ON','CANADA','K2H 5B7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 21:26:26',0,NULL,3,1,3,1,'RA184578867CN ','liquidstar_com\rRCLO003'),(16100,646608758013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sagartxiki','eritz.agirre@gmail.com','Eritz Agirre','artbai 14<br>3-D','Ondarroa','País Vasco','SPAIN','48700','686664698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 21:36:46',0,NULL,3,1,2,1,'\\ ','sagartxiki'),(16101,588946159003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','30210917','dales4@ptd.net','les dale','152 Fisher Rd','selinsgrove','PA','UNITED STATES','17870','(570) 743-1133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 21:53:23',0,NULL,3,1,1,1,'、 ','30210917'),(16102,881468558012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','cosmequintana2','cosmequintana@gmail.com','Cosme Quintana','601 S Mesa Hills Dr<br>Apt 412','el paso','TX','UNITED STATES','79912-5543','(915) 449-5686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 23:06:38',0,NULL,3,1,1,1,'、 ','cosmequintana2\r兼容型3D眼镜 通用型'),(16103,883292115012,220886272004,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',31.85,'eastar4uk','axelalex888','axelalex88@ya.ru','Alexander Lutsenko','ul. Karbisheva d.10., kv. 24','Kiev','','UKRAINE','02139','380913051166','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 23:26:16',0,NULL,3,1,3,1,'RA184578884CN\r ','axelalex888\r欧标\rHSSE011'),(16104,646704470013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','mackjax1','jemeyers@chla.usc.edu','DeSoto Pharmacy','20914 Roscoe Blvd<br>C/O Jenifer Meyers','Canoga Park','CA','UNITED STATES','91304-4308','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 00:01:49',0,NULL,3,1,1,1,'、 ','mackjax1'),(16105,796794489002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','shol7718','c_der_wood@live.com','Cedric Hollowell','po box 5456','groton','CT','UNITED STATES','06349','(502) 229-9887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 00:54:01',0,NULL,3,1,1,1,'、 ','shol7718'),(16106,646718047013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',2,'HSNO023',27.98,'eastar4','alisonduarte','alison.duarte@gmail.com','Alison Duarte','Av Lacerda Franco, 1136 apto 5A','São Paulo','São Paulo/Brazil/Centro','BRAZIL','01536001','55-11-32710797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 00:59:41',0,NULL,3,1,2,1,'\\ ','alisonduarte'),(16107,588997345003,130489883385,'New Sony Ericsson HBH-PV702 BLUETOOTH HEADSET track#',1,'HSSE003',20.8,'cnfaner','shirmila','shirmila@yahoo.com','Nalini S Johnas','1293 Laveille Ct','San Jose','CA','UNITED STATES','95131-2475','(510) 366-2009','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 01:12:02',0,NULL,3,1,1,1,'、 ','shirmila'),(16108,646727954013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','kabukibr','kabukibr@yahoo.com','Fernando Pinto','35 Garden St<br>Fl 1','newark','NJ','UNITED STATES','07105-1146','(973) 380-2028','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 01:47:26',0,NULL,3,1,1,1,'、 ','kabukibr'),(16109,594438798004,140550602611,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',20.8,'cnfaner','poonjohn','john.poon@rocketmail.com','Brian Braet','3029 Kellogg St','San Diego','CA','UNITED STATES','92106-3454','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 01:57:58',0,NULL,3,1,1,1,'、 ','poonjohn'),(16110,646752500013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','borgkz','tmkz@mail.ru','RYL NIKOLAY','Kalinina 48-18','Kokshetau','Akmolinskaya obl','KAZAKHSTAN','020000','+77017133406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 03:30:50',0,NULL,3,1,3,1,'RA184578955CN ','borgkz\rBAZA001'),(16111,796934631011,320751625518,'2 pairs NIB genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',119.99,'eastar4','jpop1494','jpoplin@lathropgage.com','Justin Poplin','9612 McCormack Dr','Lenexa','KS','UNITED STATES','66227','(913) 748-1402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 03:37:42',0,NULL,3,1,1,1,'、 ','jpop1494'),(16112,736484221008,180755479839,'ULTIMATE EARS METRO.FI 220 EARPHONE',2,'HSUE002',37.98,'au-buy','69travzdevil69','travzdevil69@hotmail.com','Trav Easton','49 Valcan Road, Orange Grove','Perth','Western Australia','AUSTRALIA','6109','0894532115','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 03:43:09',0,NULL,3,1,2,1,'\\ ','69travzdevil69'),(16113,646764101013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','astrolynx','astrolynx@frontiernet.net','ROBERT  J  EDWARDS','8991 211th st w','Lakeville','MN','UNITED STATES','55044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 04:32:50',0,NULL,3,1,1,1,' 、','astrolynx\r新的'),(16114,796946973011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','xmuven','xruben@clear.net','ben M','503 mary st','Wilmington','DE','UNITED STATES','19804-1420','(302) 655-0659','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 04:41:57',0,NULL,3,1,1,1,'、 ','xmuven'),(16115,646775291013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','mattyg024','gale@bigpond.net.au','Alan Gale','PO Box 191','Mooloolaba','Queensland','AUSTRALIA','4557','0438729807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 05:56:17',0,NULL,3,1,3,1,'RA184578941CN ','mattyg024\rGPS0006'),(16116,8881321512062035,111,'New genuine LG 3D Active Shutter Glasses AG-S110 S110Image not available    * Zoom    * EnlargeMouse here to zoom inPlease waitImage not availableSell one like this	New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',0,'eastar4','edson0055','edson@proxy.com.br','Edson Alves','Rua Congo 500','Jundiaí','São Paulo','BRAZIL','13207340','005511 4587-3148',NULL,NULL,NULL,'2011-11-17 06:41:02',0,NULL,3,1,3,1,'RA184578915CN ','客户补的差价9.1美元LGGL002 \rLG 3D glasses AG-S110 '),(16117,883430725012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','wowannie554','mjmacklin@internode.on.net','Michael Macklin','6 Madigan Crescent<br>Woodcroft','Adelaide','South Australia','AUSTRALIA','5162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 07:22:24',0,NULL,3,1,2,1,'\\ ','wowannie554\rAUI Transceiver  MX20T'),(16118,796988826011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',55.19,'eastar4','brooksee16','banshee__911@hotmail.com','Justin Brooks','7537B Thompson Rd.','port alberni','BC','CANADA','v9y 8m4','(250) 724-4919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 08:06:35',0,NULL,3,1,3,1,'RA184578924CN ','brooksee16\rLGRM001'),(16119,8881321517237670,111,'韩版加粗报纸三折伞白色的',1,'UM00038',0,'eastar4','2004walterr','walter@lambertsouvenirs.com','Jeanne Rawlings','9 Albion Villas Road','Upper Sydenham','London','UNITED KINGDOM','SE26 4DB','',NULL,NULL,NULL,'2011-11-17 08:07:17',0,NULL,3,1,2,1,' \\','补发的 '),(16120,883440787012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','fornitureforcomfort','zbz@tpg.com.au','Zena Bass','2/249 Military road<br>Dover Heights','Sydney','New South Wales','AUSTRALIA','2030','0405236216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 08:40:04',0,NULL,3,1,2,1,'\\  ','fornitureforcomfort'),(16121,797005516011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','r0b5ki','dygular@talktalk.net','Robert Dygula','4 Heol Brynglas<br>Brackla','Bridgend','Bridgend','UNITED KINGDOM','CF312QE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 09:18:50',0,NULL,3,1,2,1,'\\  ','r0b5ki'),(16122,645635487013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ragnararakas','ragnar@kn.ee','Ragnar Arakas','Paadi 5','Tallinn','Harjumaa','ESTONIA','10151','372 - 56677337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 10:17:17',0,NULL,3,1,2,1,'\\  ','ragnararakas'),(16123,646835533013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','bogolepov','pbogolepov@me.com','Peter Bogolepov','st. Svobody 79-62','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-926-222-8531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 11:43:46',0,NULL,3,1,2,1,'\\  ','bogolepov'),(16124,797053960011,320762413525,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','maestrromusic','danielmitchell45@gmail.com','Daniel Mitchell','20 Angel Hill Drive','London','Surrey','UNITED KINGDOM','sm1 3bx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 12:09:11',0,NULL,3,1,3,1,' RA184575375CN','maestrromusic\rHBPH001'),(16125,589108883003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',2,'HSNO019+CCNO001',81.12,'cnfaner','contaengo','contaengo@gmx.de','Axel Jansen','Kirchstr. 5','Berlin','','GERMANY','14199','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-17 13:09:03',0,NULL,3,1,3,1,' RA184575295CN','contaengo\rHSNO019+CNNO001'),(16126,646857127013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','ayechon','aich.siad@free.fr','Aich SIAD','5 Petite rue de la Rize','Villeurbanne','Rhône-Alpes','FRANCE','69100','06 72 65 59 67','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 13:17:20',0,NULL,3,1,3,1,' RA184578990CN','ayechon\rGLOT001*3\r兼容型3D眼镜 通用型'),(16127,883539810012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006',44.89,'eastar4','dadasverc','dadabihac@gmail.com','Brkic Sadeta','Hatinački progon 45','Bihać','Unsko Sanski Kanton','BOSNIA AND HERZEGOVINA','77000','0038761767153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 13:36:04',0,NULL,3,1,3,1,' RA184575242CN','dadasverc\rGLOT006\r韩国专用'),(16128,646863248013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','urbanstyleswrx','carl@sapsol.ca','Carl Elliott','10260 112th Street','Edmonton','AB','CANADA','T5K 1M4','(780) 288-0367','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 13:42:20',0,NULL,5,1,18,0,NULL,'urbanstyleswrx\rMOSA006\r没货了   等客户回复是退款还是换其他的'),(16129,797079926011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','jirachai_tar','abystar@msn.com','Jirachai Arsakij','Korbfar Resident Room 505<br>81/29-32 Soi Korbfar Intamara 40, Suthisarn Vinitchai Rd. ','Dindaeng','Bangkok','THAILAND','10400','66866723379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 13:27:49',0,NULL,3,1,2,1,'\\  ','jirachai_tar'),(16130,883544406012,220759427766,'New SAMSUNG WMN1000C ULTRA SLIM WALLMOUNT LED TV  60-65',1,'MOSA003',39.99,'eastar4uk','aksystems','arthur@alstertreff.de','Arthur  Krol','Grandweg 115','Hamburg','','GERMANY','22529','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 13:49:42',0,NULL,3,1,3,1,' RA184575225CN','aksystems\rMOSA003\r'),(16131,744042778007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',2,'HSPL013',107.8,'au-buy','jmsayyar','jm.sayyar@gmail.com','jassem alhosani','al marfa<br>p.o.box: 77019','abudhabi','western region','UNITED ARAB EMIRATES','ad','0506333557','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 13:55:36',0,NULL,3,1,3,1,' RA184575287CN','jmsayyar\rHSPL013'),(16132,883559054012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','sanneamt36','ksmix@arcor.de','Klaus Sauder','Westenderstr. 38','Duisburg','','GERMANY','47138','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 14:25:31',0,NULL,3,1,2,1,'\\  ','sanneamt36'),(16133,797121741011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','creativemotion','tojustinechen@yahoo.com','Justine Chen','129 Walter Hays Dr','Palo Alto','CA','UNITED STATES','94303-2924','(626) 392-3888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 15:24:22',0,NULL,3,1,1,1,'\\  ','creativemotion'),(16134,646838684013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',5,'WLIN014',139.95,'eastar4','klmvalex','klmvlksndr@rambler.ru','Aleksandr Klimov','ul. Shkuljova, d.3, kv.26','Moskva','','RUSSIAN FEDERATION','109390','+79264906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 15:26:19',0,NULL,3,1,3,1,' RA184575313CN','klmvalex\rWLIN014'),(16135,883587678012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.98,'eastar4','ebsandakelum','aisandakelum@gmail.com','Indika Sandakelum','204/1, Kasikanaththa,<br>Batuwita,','Thihagoda,','Matara','SRI LANKA','81000','0713484212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 15:36:11',0,NULL,3,1,2,1,'\\  ','ebsandakelum'),(16136,589161009003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',35.8,'cnfaner','cellprorepair','cellularcpr@aol.com','CELLULAR PHONE REPAIR','75 Maiden Ln<br>Ste 311','NEW YORK','NY','UNITED STATES','10038-4810','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 15:44:08',0,NULL,3,1,1,1,'\\  ','cellprorepair'),(16137,797133746011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','codypepp11','dgsaquella44@gmail.com','Donna Saquella','2560 N Lindsay Rd<br>Unit 46','Mesa','AZ','UNITED STATES','85213-1521','(480) 244-9084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 16:04:21',0,NULL,3,1,1,1,'\\  ','codypepp11'),(16138,797139556011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','geonegas','george.negas@sky.com','George Negas','BANKRUFF<br>Gaddesden Turn - Billington','LEIGHTON BUZZARD','Bedfordshire','UNITED KINGDOM','LU7 9BW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 16:09:54',0,NULL,3,1,3,1,' RA184575256CN','geonegas\rMOAP001'),(16139,669102059005,150700951575,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','chinkeng360','chinkeng88@yahoo.com','Chin Lim','196G West Coast Road','default','','SINGAPORE','127382','96780104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 16:24:08',0,NULL,3,0,3,1,' RA184575239CN','chinkeng360\rBR3D003'),(16140,883615303012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','ramil09111969','rhr1969@gmail.com','Ramil  Khisamutdinov','centralnaya 35-44','Kazan','Tatarstan','RUSSIAN FEDERATION','420097','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,'\\  ','ramil09111969\r一共买了两个\r分别是黑色和白色的'),(16141,589176464003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.24,'cnfaner','maineleroy','lpalmer1@maine.rr.com','Leroy Palmer','85 Granite St','Portland','ME','UNITED STATES','04102-2845','(207) 415-2952','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 16:35:52',0,NULL,3,1,1,1,'\\  ','maineleroy'),(16142,797013353011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN MANUEL ALMAGRO ROJAS','C/ ARAGONITO 7A','MALAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 17:20:47',0,NULL,3,1,6,1,'EE645619237CN ','latiendadelsotano\rGLOT001*4\r兼容型3D眼镜 通用型'),(16143,646929037013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','its2b4me','tuckerptt@gmail.com','Paul Tucker','788 Ashburton Dr','Naples','FL','UNITED STATES','34110-7905','(239) 300-2188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 17:24:58',0,NULL,3,1,1,1,' \\ ','its2b4me'),(16144,797193047011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',2,'NTLO001',17.98,'eastar4uk','cheetah_the_cat','michel.arpel@bluewin.ch','Michel A Pellaton','58, rue de la Courtine','Moutier','BE','SWITZERLAND','2740','413249361','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 18:02:33',0,NULL,3,1,2,1,'、 ','cheetah_the_cat'),(16145,646947900013,230633020392,'New Samsung WMN2000C Ultra Slim Wall Mount 58\" - 65“ TV',1,'MOSA006',72.9,'eastar4','telmop','telmop84@gmail.com','Telmo Pombo','54 Lappin ave.','Toronto','ON','CANADA','m6h 1y4','(416) 432-6731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 18:13:31',0,NULL,5,1,18,0,NULL,'telmop\rMOSA006\r没货了  退款'),(16146,589225218003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',2,'WLAT007',26.32,'cnfaner','jlan7530','b1ackd3at4@gmail.com','James Lancaster','392 Linda Circle','Daytona Beach','FL','UNITED STATES','32119','(386) 334-5860','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 18:51:42',0,NULL,3,1,1,1,'\\ ','jlan7530'),(16147,797231646011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','eldadhadas','eldadh@gmail.com','Eldad hadas','Moshav Avigdor 226','Avigdor','Hadarom','ISRAEL','83800','0545686920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 19:10:43',0,NULL,3,1,2,1,'\\  ','eldadhadas'),(16148,883704999012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','10benr','benroper2907@gmail.com','ben roper','1, corndon close','kidderminster','Worcestershire','UNITED KINGDOM','dy11 7ef','01562638415','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 19:13:49',0,NULL,3,1,3,1,' RA184575344CN','10benr\rHSJA010\r英标'),(16149,883716707012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',11.99,'eastar4uk','8326david','davkelsall@ntlworld.com','David Kelsall','8f blackthorn rd, limeside','Manchester','Greater Manchester','UNITED KINGDOM','0l8 3pf','01613452460','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 19:31:33',0,NULL,3,1,3,1,' RA184575450CN','8326david\rWLAP002'),(16150,883715514012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','tonymaint2010','tonymaint@yahoo.co.uk','anthony horvath','hydro aluminium extrusion<br>durham road','chester le street','Durham','UNITED KINGDOM','dh3 2ah','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 19:33:57',0,NULL,3,1,2,1,'\\  ','tonymaint2010\rAUI Transceiver  MX20T'),(16151,646955368013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','champion1214','cchampion@tracktvinc.com','Cindy Champion','2988 GA Highway 142','Shady Dale','GA','UNITED STATES','31085-3085','(706) 819-9534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-17 19:34:48',0,NULL,3,1,1,1,'\\ ','champion1214'),(16152,883725695012,220807244626,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AB',1,'GLOT006*2',88.99,'eastar4','55goran','s-g-busic@gmx.ch','Goran Busic','Grubenstrasse 132','Schönried','','SWITZERLAND','3778','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 19:47:32',0,NULL,3,1,3,1,' RA184575392CN','55goran\rGLOT006*2\r韩国专用'),(16153,797265362011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','se7entyse7en','thepages4@tiscali.co.uk','Chris Page','138b Hoddern<br>Avenue','Peacehaven','East Sussex','UNITED KINGDOM','BN107QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 20:05:24',0,NULL,3,1,3,1,' RA184575389CN','se7entyse7en\rHSJA011\r英标'),(16154,736808407008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','ray916mn','ray.e.kang@gmail.com','Ray Kang','4295 Watertown Rd','Maple Plain','MN','UNITED STATES','55359-9384','(612) 387-6501','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 20:31:07',0,NULL,3,1,1,1,'\\  ','ray916mn\r'),(16155,883780094012,220858448904,'Original Apple AirPort Extreme WiFi Card 54M',2,'WLAP002',23.98,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 21:10:41',0,NULL,3,1,3,1,'RA184575361CN ','lochearn1234\rWLAP002'),(16156,589290756003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','kecajp','kecajp@wp.pl','Jacek Piotrowicz','101 Ringwood Highway','Coventry','Warwickshire','UNITED KINGDOM','CV2 2GT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 21:32:53',0,NULL,3,0,3,1,' RA184575273CN','kecajp\rHBPH009'),(16157,797326197011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','rdbezerra','skiner@gmail.com','Rodolpho Bezerra','R. Dr Vicente Meira, 180 / apt 1404<br>Graças','Recife','Pernambuco','BRAZIL','52020130','8186776851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 21:52:34',0,NULL,3,1,2,1,'\\  ','rdbezerra'),(16158,589300622003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','xavierfelix','xavierfelix22@msn.com','Xavier Felix','Urb Covadonga<br>3K4 Calle Nalon','Toa Baja','PR','UNITED STATES','00949-5333','(787) 643-0578','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 22:03:08',0,NULL,5,1,18,1,NULL,'xavierfelix\rWMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\" \r\r客户要求订单取消，需要退钱\r'),(16159,647072933013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',273.99,'eastar4','aaron5423','aaron.thevenet@exemail.com.au','Aaron Thevenet','29 Goodenia Road','Mount Annan','New South Wales','AUSTRALIA','2567','0246481097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 23:49:07',0,NULL,3,1,6,1,'EE645619245CN ','aaron5423'),(16160,792820023011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','fredrick-floor','fredrickfloor@gmail.com','Fredrick Floor','Houttuinen-Zuid 21','APELDOORN','','NETHERLANDS','7325RJ','0681859811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 00:03:05',0,NULL,3,1,2,1,'\\  ','fredrick-floor'),(16161,797388839011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','dima_bnt','dbrennon@gmail.com','Dmitriy Sheremet','Kirova str 1-2-24','Kharkov','','UKRAINE','61001','+380503231539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 00:35:20',0,NULL,3,1,2,1,'\\  ','dima_bnt\r欧标'),(16162,647089667013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','landersonii','landersonii@lycos.com','Lloyd Anderson','565 Canlite St.','Henderson','NV','UNITED STATES','89015','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 01:01:05',0,NULL,3,1,1,1,'\\  ','landersonii'),(16163,589359173003,130596106005,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',77.99,'cnfaner','drock_1','jdrealiz@aol.com','Derrick Johnson','424 Tincher Dr','Versailles','KY','UNITED STATES','40383-1903','(859) 227-4776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 02:20:49',0,NULL,3,1,1,1,'\\  ','drock_1'),(16164,589377552003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.03,'cnfaner','samp5757','samirp57@comcast.net','Samir Patel','3312 Dickerson Pike','Nashville','TN','UNITED STATES','37207-2955','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 03:55:52',0,NULL,3,1,1,1,'\\  ','samp5757'),(16165,8881321590366527,111,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',0,'cnfaner','fedg3717','fredge23@yahoo.com','fredrick edge','1441 deer forest dr<br>null','fort mill','SC','UNITED STATES','29707-7738','',NULL,NULL,NULL,'2011-11-18 04:26:06',0,NULL,5,0,18,0,NULL,' fedg3717\rHSPL010\r补发的 '),(16166,744396507007,170728978814,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',54.59,'au-buy','webstar1985','webbyss@hotmail.com','brenton webster','1 sandra st','kings park','Victoria','AUSTRALIA','3021','0424087585','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 04:49:53',0,NULL,3,1,3,1,' RA184575211CN','webstar1985\rLGRM001'),(16167,647144961013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','betty.d.2068','betty.doughty@bigpond.com','Shaun Leslie','9 the high tor','castlecrag','nsw','AUSTRALIA','2068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 05:27:45',0,NULL,3,1,2,1,'\\  ','betty.d.2068'),(16168,589391685003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','sixandlindsey','six-n-lindsey@hotmail.com','Six','4925 N 73rd St<br>Apt 10','Scottsdale','AZ','UNITED STATES','85251-1367','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 05:30:12',0,NULL,3,1,1,1,'\\  ','sixandlindsey'),(16169,647145582013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','hvtsupplies','ivanleon@gmail.com','Ivan Leon','6617 NW 84th AVE','Miami','FL','UNITED STATES','33166-2612','(786) 228-8286','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 05:30:57',0,NULL,3,1,1,1,'\\  ','hvtsupplies'),(16170,594825940004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','mark6622','mfwillimann@yahoo.com','Mark F. Willimann','3839 W Argo St','Tucson','AZ','UNITED STATES','85742-5013','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 06:15:55',0,NULL,3,1,1,1,'\\  ','mark6622'),(16171,883969133012,220886272004,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',31.85,'eastar4uk','art-atc','thanumas@tpg.com.au','Art Thanumas','4 Reston Court','Deer Park,','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 06:22:19',0,NULL,3,1,3,1,' RA184575260CN','art-atc\r澳标\rHSSE011\r'),(16172,8881321602010006,111,'Logitech Harmony RF extender+4 emitter for 890 pro 1000',1,'RCLO007+POLO001+RCLO008*4',0,'eastar4','ma.walther','martinwalther@gmx.net','Dipl. Verw. Martin Walther','Horner Weg 109','Hamburg','','GERMANY','22111','',NULL,NULL,NULL,'2011-11-18 07:40:10',0,NULL,3,1,2,1,'\\  ','补发的 \r只补发EXTENDER\r'),(16173,797486193011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','denis44800','denis.senard@capelia.fr','DENIS SENARD','19 ALLEE MOZART','SAINT-HERBLAIN','Pays de la Loire','FRANCE','44800','0608015486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 07:27:35',0,NULL,3,1,3,1,' RA184575446CN','denis44800\rTRTS001*10'),(16174,737000504008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'au-buy','paladin_jnb','paladinsub@sublight.com.au','Joe','21 Lillie Street','GLEBE','Tasmania','AUSTRALIA','7000','0362319396','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 07:31:45',0,NULL,3,1,2,1,'\\  ','paladin_jnb'),(16175,744429334007,170730545297,'New Logitech harmony remote Li-ion Rechargeable Battery 930mAh WHITE',1,'BALO002',10.99,'au-buy','rstampy','stampy1@hotmail.com','Richard Stamp','114 Twist Creek Road<br>PO Box 86','Yackandandah','Victoria','AUSTRALIA','3749','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 07:58:03',0,NULL,3,1,2,1,'\\  ','rstampy'),(16176,754598789001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','theprince511','wael_511@hotmail.com','WAEL SAADOUN','11934 Royal Rd<br>Apt 2','El Cajon','CA','UNITED STATES','92021-1350','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 08:18:14',0,NULL,3,1,1,1,'\\  ','theprince511'),(16177,647168535013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',55.98,'eastar4','thanks502','yes502@empal.com','Hou oyoung','Daewon Cantaville Apt 101-1702<br>Myeonmok 7-dong, Jungnang-gu','Seoul','Seoul Korea','KOREA,REPUBLIC OF','131-760','82-10-2499-5024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 08:19:10',0,NULL,3,1,3,1,'RA184575415CN ','thanks502\rWLIN014'),(16178,647181041013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','yoc0','yoc@free.fr','Yohann Colombat','DEP, 9 rue Edmond Michelet','Neuilly-Plaisance','Seine saint denis','FRANCE','93360','0685239778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 09:24:29',0,NULL,3,1,2,1,'、 ','yoc0'),(16179,8881321608873914,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',0,'eastar4','ranbenderli','ranb34@nana.co.il','ran benderli','hacharov 7','kefar yona','','ISRAEL','40300','',NULL,NULL,NULL,'2011-11-18 09:34:33',0,NULL,3,1,2,1,'、','补发的 '),(16180,647183591013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','nemiath','k.koutsoyiannopoulos@adel.gr','Karolos Koutsogiannopoulos','Olimpou 8-12','Athens','Attika','GREECE','10442','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 09:34:48',0,NULL,3,1,2,1,'、 ','nemiath'),(16181,884030165012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',23.74,'eastar4','a_dondish1978','a_dondish@mail.ru','alexei dondish','peretz 11/3','Rehovot','','ISRAEL','76204','+972542600008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 10:27:09',0,NULL,3,1,11,1,'、 ','a_dondish1978\rUM00016'),(16182,884034240012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','hk-new-time','sergey@nosul.com.ua','Sergiy Nosul','p.Geroev Bresta 83 kv 31','Kremenchug','','UKRAINE','39631','+380664358285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 10:39:31',0,NULL,3,1,2,1,' \\ ','hk-new-time\r白色的'),(16183,884034376012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','yb2k','yk.yael@gmail.com','YAEL KUNICHER','Haeschar 6','haifa','haifa','ISRAEL','35844','97248338074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 10:45:18',0,NULL,3,1,2,1,' \\ ','yb2k'),(16184,884048903012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','mpsarros','mgpsarros@gmail.com','Michael Psarros','Zisimopoulou 43','Paleo Faliro','','GREECE','17564','+306974746235','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 11:27:25',0,NULL,3,1,3,1,'RA184574180CN\r ','mpsarros\rRCLO006\r新的'),(16185,737060385008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT006',85.48,'au-buy','corre_es','atalayaya@yahoo.es','veira font francisco','c/Australia 7','melilla','Andalucía Ceuta y Melilla','SPAIN','52005','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 11:35:33',0,NULL,3,1,3,1,'RA184574281CN\r ','corre_es\rGLOT006'),(16186,797558057011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',18.99,'eastar4','rudineiomar2010','rudichapa@hotmail.com','Rudinei Omar Zwirtes','Rua Prefeito Segundo Dalla Costa, 719','Concórdia','Santa Catarina','BRAZIL','89700000','55-49-3444-4254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 11:58:22',0,NULL,3,1,11,1,'、 ','rudineiomar2010\r正红色长柄婚庆伞 \rUM00022'),(16187,797572839011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','timpkins1990','thomasbrodie@talktalk.net','Thomas Sangster','199 John Ruskin Street<br>Camberwell','London','London','UNITED KINGDOM','Se5 0pt','020777930393','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 12:44:17',0,NULL,3,1,3,1,' RA184574012CN\r','timpkins1990\rMOAP001'),(16188,884067653012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jilet_sensor','steffdevos@telenet.be','Steff De Vos','Stationsplein 15 bus 2','Geraardsbergen','','BELGIUM','9500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 12:23:14',0,NULL,3,1,2,1,'、  ','jilet_sensor'),(16189,647231345013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','szegezdikittike','szegezdikittyke@freemail.hu','Tibor Korsos','Honved u. 20','Kalocsa','Bacs-Kiskun','HUNGARY','6300','(0036)309738578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 13:14:14',0,NULL,3,1,2,1,' \\ ','szegezdikittike\r欧标'),(16190,884098012012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','5128robl','rob@rdlew.freeserve.co.uk','Rob Lewis','9 Gospel Hall Tce<br>Gadlys','Aberdare','Rhondda Cynon Taff','UNITED KINGDOM','CF44 8DW','01685875662','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 13:46:44',0,NULL,3,1,3,1,'RA184574193CN\r ','5128robl\rOTSO004*3'),(16191,884102438012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',4,'OTCR001',110.72,'eastar4','paschoarelli','ruben@estratege.com.br','Ruben Paschoarelli','av. Analice sakatauskas, 204<br>Bela Vista','Osasco','São Paulo','BRAZIL','06060-000','551136535126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 13:56:25',0,NULL,3,1,3,1,'RA184574074CN\r ','paschoarelli\rOTCR001'),(16192,884102217012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',4,'CASS002',33.16,'eastar4','wilsonian-uk','paulwilson89@hotmail.com','Paul Wilson','34 Brookfold','Failsworth','Greater Manchester','UNITED KINGDOM','M35 0DH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 13:57:18',0,NULL,3,1,2,1,' \\ ','wilsonian-uk\rCAB-SS-2660'),(16193,884107803012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','constandine.p','constandine.p@gmail.com','paraskevopoulos kostas','kampouroglou 13','athens','greece','GREECE','115 25','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 14:09:39',0,NULL,3,1,2,1,'、  ','constandine.p'),(16194,884126415012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT006*3',78.99,'eastar4uk','stubbington_steve','steve.boddy11@virginmedia.com','Stephen Boddy','11 Sumar Close<br>Stubbington','Fareham','Hampshire','UNITED KINGDOM','PO14 2EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 14:55:45',0,NULL,3,1,3,1,'RA184574295CN\r ','stubbington_steve\rGLOT006*3\r兼容型3D眼镜  Korea TV专用'),(16195,647266648013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','p8qui','fos3380@bellsouth.net','Frank Saladrigas','3380 Taconic Dr','West Palm Beach','FL','UNITED STATES','33406-5047','(561) 965-5298','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 15:21:12',0,NULL,3,1,1,1,' \\ ','p8qui\r黑色的'),(16196,881957881012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',2,'HSNO019+CCNO001',51.98,'eastar4uk','algirdas_suris','algirdassurgautas@gmail.com','Algirdas Surgautas','Navarsoniu km.<br>Panevezio sen.','Panevezio raj.','LT','LITHUANIA','38365','0037061221808','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 15:38:27',0,NULL,3,1,3,1,' RA184574091CN\r','algirdas_suris\rHSNO019+CCNO001\r'),(16197,884141756012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','ter_zero','ter_zero@hotmail.com','LUIS MIGUEL TRIVIñO MANJON','C/ANCHA DE CAPUCHINOS,13,4ºB DERECHA','GRANADA','','SPAIN','18012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 15:39:28',0,NULL,3,1,2,1,'、  ','ter_zero'),(16198,884155423012,220705197723,'New Genuine Motorola RAZR H3 Bluetooth Wireless Headset',1,'HSMO003',7.99,'eastar4uk','darth_alru','darthalru@yandex.ru','Ilya Baranov','Kosmicheskiy prospekt, 89-37','Omsk','Omsk Oblast','RUSSIAN FEDERATION','644076','8(951)1092745','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 16:04:23',0,NULL,3,1,2,1,' \\ ','darth_alru\r欧标'),(16199,589520871003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','sgpaul','stephengpaul+ebay@gmail.com','Stephen Paul','7571 E 26th Ave','Denver','CO','UNITED STATES','80238-2482','(303) 482-2017','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 16:21:00',0,NULL,3,1,1,1,'\\  ','sgpaul'),(16200,647286222013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',23.74,'eastar4','balegold','staycool.gold@gmail.com','Alex Goldenberg','Ben Zvi 46/13','Ashkelon','Shfela','ISRAEL','78461','+972544656345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 16:27:50',0,NULL,3,1,11,1,NULL,'balegold\rUM00010\r绿色的 实际没发货 '),(16201,647298017013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','cefepe27','cefepe@ono.com','Cesar Ferrer Perez','c/ Aguas de Sax 20 5ºA','Alicante','Comunidad Valenciana','SPAIN','03009','647251388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 16:56:30',0,NULL,3,1,2,1,'、  ','cefepe27'),(16202,884196191012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',11.4,'eastar4uk','geoff3305','fisherci1995@yahoo.co.uk','Geoff Fisher','19 ledston ave garforth','leeds','West Yorkshire','UNITED KINGDOM','ls25 2bp','01132863818','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 17:23:43',0,NULL,3,1,3,1,' RA184574065CN\r\r','geoff3305\rHSNO022\r英标'),(16203,797701906011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','themaddog59','steveworsnop@btinternet.com','Steve Worsnop','65 Hailstone Drive','Northallerton','North Yorkshire','UNITED KINGDOM','DL6 1SP','01609773995','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 17:56:07',0,NULL,3,1,3,1,'RA184574026CN\r\r ','themaddog59\rMOAP001'),(16204,647324821013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mwodtke','marcel.fw@gmail.com','Marcel Wodtke','Rua Alberto Silva 864/202 Vila Ipiranga','Porto Alegre','Rio Grande do Sul','BRAZIL','91370-000','5133727522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 18:09:52',0,NULL,3,1,2,1,' \\ ','mwodtke'),(16205,594988577004,140550602611,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',20.8,'cnfaner','jojo42009','hansen@suntrol.com','Kathie Hansen','6691 Breezewood Rd','Painesville','OH','UNITED STATES','44077-9752','(216) 533-5299','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 18:17:40',0,NULL,3,1,1,1,' \\ ','jojo42009'),(16206,797713785011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','yahek01','jperezguio@gmail.com','Joaquin Perez Guio','C/ Real, 5','Yuncos(Toledo)','Castilla-La Mancha','SPAIN','45210','649952960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 18:18:57',0,NULL,3,1,2,1,'、','yahek01'),(16207,647331461013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','marcos_kpn','kikopanter@yahoo.com.br','Jose Marcos Domingues Junior','Rua Terra Roxa, 04','Sao Paulo','Sao Paulo','BRAZIL','03305010','+551122251221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 18:26:07',0,NULL,3,1,3,1,'RA184575525CN\r ','marcos_kpn\rLGGL002'),(16208,589562927003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',2,'WWOT001+ANCN001',77.52,'cnfaner','ecoshopbiz','eg@ecomstation.ru','Gorbunov Victor Petrovich','Svetlanovsky prospekt d. 40, korpus 2, kv. 279','St.Petersburg','StPetersburg','RUSSIAN FEDERATION','195427','(812)556-5877','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-18 18:30:39',0,NULL,3,1,3,1,'RA184574030CN\r ','ecoshopbiz\rWWOT001+ANCN001\r对包装纸有要求 \r\r'),(16209,589571420003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',22.61,'cnfaner','maydenn','maydenn@peoplepc.com','Dennis May','6910 Meaghan Ln','Warrenton','VA','UNITED STATES','20187','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 18:51:18',0,NULL,3,1,1,1,' \\ ','maydenn'),(16210,647345163013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','hewell225','tjh225@gmail.com','Tim Hewell','1346 E Columbia Ave','Philadelphia','PA','UNITED STATES','19125-3213','(215) 680-3766','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 19:04:40',0,NULL,3,1,6,1,'EE491015927CN ','hewell225\r兼容型3D眼镜 通用型'),(16211,797741009011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006',26.99,'eastar4uk','braingregory2009','briangregory2009@gmail.com','Brian Gregory','13 Woodlands Close<br>Llanmiloe','Pendine','Carmarthenshire','UNITED KINGDOM','SA334UL','0792789380','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 19:07:27',0,NULL,3,1,3,1,'RA184574233CN\r ','braingregory2009\rGLOT006\r兼容型3D眼镜  Korea TV专用'),(16212,797743747011,320730088269,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',9.99,'eastar4uk','kieranjfleming','kieranjfleming@eircom.net','kieran fleming','9a market street','clogheen ,  cahir','Tipperary','IRELAND','9a','0527465925','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 19:13:58',0,NULL,3,1,3,1,' RA184574088CN\r','kieranjfleming\rHSSA003\r英标'),(16213,797755522011,320590826661,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',119,'eastar4','elektric_light','mark-pm@comcast.net','Mark Meredith','536 S Seminary St','Charles Town','WV','UNITED STATES','25414-1347','(304) 724-1499','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 19:33:24',0,NULL,3,1,1,1,'、  ','elektric_light'),(16214,584348178003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','2011sircharles','sircharles2235@yahoo.com','charles paige','2235 Saint Marys Ave<br>Apt 405','omaha','NE','UNITED STATES','68102-2436','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 19:39:59',0,NULL,3,1,1,1,' \\ ','2011sircharles'),(16215,647365067013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ifouzi','rachdane@gmail.com','Fouzi Rachdane','C/ Antonio Machado 58','Seseña Viejo','Castilla-La Mancha','SPAIN','45223','696602710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 19:49:35',0,NULL,3,1,2,1,'、 ','ifouzi'),(16216,884292192012,220886977249,'New genuine LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',13.99,'eastar4uk','ovey-2008','jolvanhill@sky.com','JOHN OLVANHILL','46 FROSTOMS ROAD','WORKINGTON','Cumbria','UNITED KINGDOM','CA143UR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 20:01:26',0,NULL,3,1,3,1,'RA184574255CN\r ','ovey-2008\rLGGL001'),(16217,797778974011,320730544219,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT006*2',52.99,'eastar4uk','miss_liana21','lianasokolova@inbox.lv','Liana Sokolova','163 Hillington Square<br>Chesnut House','King\'s Lynn','Norfolk','UNITED KINGDOM','PE30 5HS','07754432115','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 20:17:25',0,NULL,3,1,3,1,'RA184575517CN\r ','miss_liana21\rGLOT006*2\r兼容型3D眼镜  Korea TV专用'),(16218,589615594003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','pinksam1950','beverlyk_cooper@yahoo.com','Beverly Cooper','3730 E Diagonal Way','kingman','AZ','UNITED STATES','86409','(928) 279-7411','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 20:48:46',0,NULL,3,1,1,1,' \\','pinksam1950'),(16219,797672836002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','dsrtdweler','dsrtdweler@yahoo.com','Angelia Haynes','14542 E Monument Dr','Scottsdale','AZ','UNITED STATES','85262-4976','(480) 471-0933','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 20:50:13',0,NULL,3,1,1,1,'  \\','dsrtdweler'),(16220,595046858004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',3,'HSPL001',36.9,'cnfaner','aroman6215','aroman6216@aol.com','Anthony Romano Jr.','6 Magnolia Ln','Colts Neck','NJ','UNITED STATES','07722','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 20:50:22',0,NULL,3,1,1,1,' \\ ','aroman6215'),(16221,589620289003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.03,'cnfaner','rickmillscsl','rickmillscsl@yahoo.com','rick mills','850 Rosedale Ave<br>Apt 10','capitola','CA','UNITED STATES','95010-2235','(510) 364-9479','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 21:02:54',0,NULL,3,1,1,1,'  \\','rickmillscsl'),(16222,884338169012,220581067419,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2002',9.88,'eastar4','nikgou','nikos@goumenakis.com','Nikos Goumenakis','6 Ath Diakou str','Athens','','GREECE','17455','2109843916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 21:22:59',0,NULL,3,1,2,1,' \\ ','nikgou\r8pin 1.0 8cm 五线连接'),(16223,736879246008,180730161545,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',3,'HSPL005',40.74,'au-buy','bosshart111','p.harty@laserelectrical.com.au','paul harty','2/27 simms road greensborough','melbourne','Victoria','AUSTRALIA','3088','0394322244','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 21:45:52',0,NULL,3,1,3,1,'RA184575596CN\r ','bosshart111\rHSPL005\r澳标'),(16224,884380508012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','xutie60','xutie60@gmail.com','Tie xu','25 Adrian Court','Carlingford','New South Wales','AUSTRALIA','2118','0421431052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 22:48:51',0,NULL,3,1,2,1,' \\ ','xutie60'),(16225,797862905011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','discovermexico','mircaed@prodigy.net.mx','Eduardo Miranda','Lisboa 164-A Versalles','Puerto Vallarta','Jalisco','MEXICO','48310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 23:11:44',0,NULL,3,1,2,1,' \\ ','discovermexico'),(16226,797873165011,320394892477,'Acer Aspire 5235 5335 5535 Bluetooth Module 2.0 +cable',1,'BTAC2005',9.88,'eastar4','mute446','radek.mikulica@tiscali.cz','Radek Mikulica','Kurdějov 105','Kurdějov','výchozí','CZECH REPUBLIC','69301','00420721508691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 23:41:54',0,NULL,3,1,2,1,' \\','mute446\racer 4pin1.25 8cm'),(16227,797880498011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','alry77','saulteyes@ymail.com','Mario Alberto Rosas Munive','Plaza del Clavel 002 U Hab INFONAVIT','Atlixco','Puebla','MEXICO','74227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 00:05:24',0,NULL,3,1,2,1,' \\ ','alry77'),(16228,797752675002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',5,'OTAM001',29.95,'buysia','sakis321','k_nimit@hotmail.com','NIMIT KREUSANEH','Benyada Lodge, 106/52 Moo 3, Surin Beach<br>Cherngta lay, Talang,','Phuket','PET','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-19 00:09:55',0,NULL,3,1,2,1,' \\ ','sakis321'),(16229,589673494003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','tkdick','tkd.ftminc@yahoo.com','Katie Dick','1523 8th Ave NE','Brainerd','MN','UNITED STATES','56401-2105','(406) 861-0027','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 00:16:00',0,NULL,3,1,1,1,' \\ ','tkdick'),(16230,797759422002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','serhiychik','zadko1967@yahoo.com','Serhiy  Zadko','4175 W 59th St','Cleveland','OH','UNITED STATES','44144-1717','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'serhiychik'),(16231,647462874013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','franja19','franja800@hotmail.com','EMBAIXADA DA VENEZUELA Francisco Javier Chávez','SES AV DAS NAÇÕES QUADRA 803<br>LOTE 13','BRASILIA','DF','BRAZIL','70451-900','005561-21011030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 00:59:24',0,NULL,3,1,3,1,' RA184575636CN\r','franja19\rGLOT001*4\r兼容型3D眼镜 通用型'),(16232,884438291012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','misiu_nike','misiu_nike@verizon.net','Chris Misiewicz','2005 Cougar Dr','La Porte','IN','UNITED STATES','46350-6413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 01:38:11',0,NULL,3,1,1,1,'、 ','misiu_nike'),(16233,884439527012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','mwm-digital-art','mwmedia@bigpond.net.au','Brett Mulcahy','45 Grosvenor Terrace','Deception Bay','Queensland','AUSTRALIA','4508','0731390766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 01:41:41',0,NULL,3,1,2,1,'、  ','mwm-digital-art'),(16234,595124110004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','aawharvey8','awharvey8@yahoo.com','Warren Harvey','3207 Collard St','Alexandria','VA','UNITED STATES','22306-1421','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 02:01:48',0,NULL,3,1,1,1,' \\ ','aawharvey8'),(16235,647473218013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','jeffdesgraves11','jeffdesgraves@yahoo.com','jeff desgraves','6460 College Park Cir<br>Apt 203','naples','FL','UNITED STATES','34113-7325','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 02:02:30',0,NULL,3,1,1,1,' \\ ','jeffdesgraves11\r新的'),(16236,884441311012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','mtlalouettes','mikeschacter@gmail.com','Michael Schacter','Kaufman Laramee<br>800 Rene-Levesque West, Suite 2220','Montreal','QC','CANADA','H3B1X9','(514) 916-1514','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 01:48:08',0,NULL,3,1,3,1,'RA184574162CN\r ','mtlalouettes\rRCLO006'),(16237,797915536011,320475111586,'2.0 New ASUS Bluetooth Module +cable for V1S E99 F8 N80',1,'BTHU2002',9.88,'eastar4','oniell','lkdorlig@gmail.com','Loren Dorlig','19411 12th Avenue Ct E','Spanaway','WA','UNITED STATES','98387-3401','(520) 390-9397','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 02:15:25',0,NULL,3,1,1,1,' \\ ','oniell\r华硕10pin 0.8 10cm '),(16238,884449610012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','mbrinkleycht1991','mbrinkleycht@me.com','Marta Brinkley','2565 Crescent Rd','Navarre','FL','UNITED STATES','32566-8705','(912) 398-2732','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 02:20:19',0,NULL,3,1,1,1,' \\ ','mbrinkleycht1991'),(16239,884453704012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','zimzillakilla','zimzillakilla@gmail.com','israel chagollan','1650 Redondo Ave<br>Apt 5','long beach','CA','UNITED STATES','90804-2648','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 02:33:13',0,NULL,3,1,1,1,' \\ ','zimzillakilla'),(16240,595135221004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',18.52,'cnfaner','homer75025','d.junglefever@verizon.net','Michael Smith','1701 Snowmass Drive','Plano','TX','UNITED STATES','75025','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 03:02:18',0,NULL,3,1,1,1,'\\ ','homer75025'),(16241,797925961011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','hippiebryce','breezybleezy@yahoo.com','Bryce Myers','735 NE Grattan St','topeka','KS','UNITED STATES','66616-1236','(785) 845-5289','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'hippiebryce'),(16242,755019774001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','logums','bryanlynch7601@yahoo.com','Bryan Lynch','7601 Zane Ave N<br>Apt 319','Brooklyn Park','MN','UNITED STATES','55443-3131','(763) 566-1138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 04:14:47',0,NULL,3,1,1,1,' \\ ','logums'),(16243,797952462011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','mateeeus','leal.mateus@rocketmail.com','Mateus Ferreira','QI 01 LOTE 160 APE 214 - SETOR INDUSTRIAL LESTE - ED. RENASCENÇA','BRASILIA','GAMA','BRAZIL','72445-010','55 61 91451987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 04:54:31',0,NULL,3,1,2,1,'\\ ','mateeeus'),(16244,737435243008,180699062016,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',32.77,'au-buy','mateeeus','leal.mateus@rocketmail.com','Mateus Ferreira','QI 01 LOTE 160 APE 214 - SETOR INDUSTRIAL LESTE - ED. RENASCENÇA','BRASILIA','GAMA','BRAZIL','72445-010','55 61 91451987','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 04:55:16',0,NULL,3,1,2,1,'\\ ','mateeeus'),(16245,589722515003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',20.8,'cnfaner','cigaras','chiosas@yahoo.com','Gitenis Salyga','7855 Deerfield Ave','Woodridge','IL','UNITED STATES','60517','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 05:02:10',0,NULL,3,1,1,1,' \\ ','cigaras'),(16246,797828224002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','marothy','marothy@gmail.com','André Martins Marothy','Rua dos Tapes 67, ap 32','São Paulo','São Paulo','BRAZIL','01527-050','55-11-2387-1013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 05:27:15',0,NULL,3,1,2,1,' \\ ','marothy'),(16247,744877633007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','xperthost','ethilanka@gmail.com','Thilanka Mendis','No.3,<br>Jaya Mawatha','Ratmalana','Western','SRI LANKA','10370','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 05:41:57',0,NULL,3,1,2,1,'、 ','xperthost\r\r'),(16248,647518872013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','simohammed123','simo.elamri2@hotmail.com','si mohammed elamri','2 Allandale Dr<br>Apt B19','newark','DE','UNITED STATES','19713-3143','(302) 345-1198','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 06:10:47',0,NULL,3,1,1,1,'、  ','simohammed123'),(16249,589733960003,130490601966,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',15.68,'cnfaner','disczones','albert@disczones.com','Albert  Kim','14841 WALNUT GROVE CT','TUSTIN','CA','UNITED STATES','92780-1603','(949) 829-3359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 06:35:59',0,NULL,3,1,1,1,' \\ ','disczones'),(16250,797973646011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','wasimuzzaman','wasimuzzaman@gmail.com','Muhammad Wasimuzzaman','1/97,Yangoora road,Lakemba','Sydney','New South Wales','AUSTRALIA','2195','0297503979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 06:57:05',0,NULL,3,1,2,1,' \\ ','wasimuzzaman'),(16251,744894175007,170731735241,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',2,'LGGL003',39.8,'au-buy','conradwerner72','conrad_werner@hotmail.com','conrad werner','30 ann st','proserpine','Queensland','AUSTRALIA','4800','0749453673','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-19 07:19:44',0,NULL,3,1,3,1,'RA184574216CN\r ','conradwerner72\rLGGL003'),(16252,884525589012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',159.99,'eastar4','rukmantorsalim56','rsalim56@gmail.com','Rukmanto Salim','jl Yogyakarta no 3 Antapani Kidul<br>BANDUNG','default','JI','INDONESIA','40291','628122342113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 08:03:09',0,NULL,3,1,3,1,' RA184575582CN\r','rukmantorsalim56\rGLSG001*3'),(16253,884559824012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','stemland-2008','tor_ove_olsen@hotmail.com','Tor Ove Olsen','Stemland<br>stemland','Valnesfjord','valnesfjord','NORWAY','8215','+4791615112','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 09:58:56',0,NULL,3,1,3,1,'RA184574220CN\r ','stemland-2008\rHSPL013\r欧标'),(16254,884570958012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','nastylemon','nastylemon@gmail.com','Hyoung Bin Kang','Room 602, 126-32, Sangdo-dong','Dongjak-gu','Seoul','KOREA,REPUBLIC OF','156030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 10:30:27',0,NULL,3,1,2,1,'、  ','nastylemon'),(16255,798043943011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','martinepittaway','martinpittaway@mac.com','Martin Pittaway','6 Hawthorn Close<br>Little Paxton','St Neots','Cambridgeshire','UNITED KINGDOM','PE19 6QQ','07717896871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 11:13:09',0,NULL,3,1,3,1,'RA184574159CN\r ','martinepittaway\rMOAP001'),(16256,647581762013,230678645057,'New Sweet Princess 3-section Auto Folding Rain Umbrella',1,'UM00035',18.99,'eastar4','rubin82009','rubin82000@hotmail.com','Rubin Khaimov','Nisan Turchin 4/22','Yehud','ID','ISRAEL','56361','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 11:43:26',0,NULL,3,1,2,1,' \\ ','rubin82009\r路易甜美公主自动三折伞 ');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (16257,798056197011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','sikam59','sikam959@otenet.gr','ΙΑΚΩΒΟΣ ΖΩΡΖΟΣ','ΡΗΓΑ ΦΕΡΑΙΟΥ 81','ΑΘΗΝΑ ATHENS','ΚΕΡΑΤΣΙΝΙ','GREECE','18758','2104316646','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 12:03:46',0,NULL,3,1,3,1,' RA184575605CN\r','sikam59\rGLOT001\r兼容型3D眼镜 通用型'),(16258,884607021012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',69.99,'eastar4uk','poloplayer711','patmcconachie@tiscali.co.uk','PAT Mc CONACHIE','196 ARDGAY STREET<br>SANDYHILLS','GLASGOW','Glasgow (City of)','UNITED KINGDOM','G32 9XF','01417788939','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 12:13:26',0,NULL,3,1,3,1,'RA184575548CN\r ','poloplayer711\rGLSG001*2'),(16259,884607285012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',2,'OTSO004*2',275.98,'eastar4','sirionbb','fleurbibby@hotmail.com','Fleur Bibby','137 camm rd','Mt Julian','Queensland','AUSTRALIA','4800','0410489742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 12:19:36',0,NULL,3,1,6,1,'EE491015944CN ','sirionbb'),(16260,884611614012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.88,'eastar4','schroepfer_de','schroepfer.juergen@googlemail.com','Jürgen Schröpfer','Schwalbenweg 5','Körle','','GERMANY','34327','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 12:24:35',0,NULL,3,1,2,1,'、 ','schroepfer_de\r4pin 1.25 '),(16261,798070947011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',3,'GLOT006',80.97,'eastar4uk','pbarro8','pbarro@westnet.com.au','Paul Barentsen','20 Sir Donald Bradman Drive','Mile End','South Australia','AUSTRALIA','5031','610404137634','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'pbarro8'),(16262,589187819003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',18.03,'cnfaner','zoomzpro','zoomdepro@hotmail.com','Kirill Garnets','Schipholtstraat 154','Enschede','','NETHERLANDS','7534 dc','0031634825823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 13:40:15',0,NULL,3,1,2,1,' \\ ','zoomzpro'),(16263,647614998013,230576114243,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',14.98,'eastar4','ari4697','ari.saarihuhta@gmail.com','Ari Saarihuhta','Jokelanranta 2 b 9','palokka','','FINLAND','40270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 13:53:00',0,NULL,3,1,2,1,' \\ ','ari4697'),(16264,647616335013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',8.29,'eastar4','mesut747','mtufan_1@hotmail.com','Mesut Tufan','2 Deepwater drive','Waterways','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 13:53:36',0,NULL,3,1,2,1,' \\ ','mesut747\rCAB-SS-2626'),(16265,884676505012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','jobberking','reinkarnator@list.ru','Timur Timur','S.Rahimov str. h.213  f.19','Baku','','AZERBAIJAN','AZ 1010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 14:55:54',0,NULL,3,1,11,1,'、 ','jobberking\r蕾丝蝴蝶结伞 黑色\rUM00006\r不挂号'),(16266,884682149012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',11.4,'eastar4uk','wneranjan','w_neranjan@hotmail.com','Neranjan Wickramasinghe','47 lessington avenue','Romford','Essex','UNITED KINGDOM','RM7 9ED','01708720386','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 15:07:24',0,NULL,3,1,3,1,'RA184574043CN\r ','wneranjan\rHSNO022\r英标'),(16267,798135202011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',4,'GLOT001',179.56,'eastar4','rockshell815','rockshell815@yahoo.com','michelle knutsen','1070 Straightaway Ct','Oceanside','CA','UNITED STATES','92057-1949','(954) 806-8582','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 15:09:03',0,NULL,3,1,6,1,'EE645650210CN ','rockshell815\r兼容型3D眼镜 通用型'),(16268,745047029007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','roye129','roye@cgocable.ca','Réjean Roy','3 avenue Couillard de Beaumont','Montmagny','QC','CANADA','G5V 2G4','(418) 248-8341','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 15:13:00',0,NULL,3,1,2,1,' \\ ','roye129'),(16269,798134112011,320791295540,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking  TK103-2',1,'GPS0008',223.98,'eastar4','ktpevgen','ktsfs@hotmail.com','Yevgeniy Korolev','Krivoguza, 5 , 308','Karagandy','','KAZAKHSTAN','100019','+77212416448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 15:14:22',0,NULL,3,1,3,1,'RA184577535CN ','ktpevgen\rGPS0008\r一共买了两个'),(16270,798145380011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',85.98,'eastar4uk','karol3571','famulsk@aol.com','Karol Famulski','107 Marks Ave.','Carlisle','Cumbria','UNITED KINGDOM','CA2 7HP','07882938364','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 15:34:28',0,NULL,3,1,3,1,'RA184575494CN\r ','karol3571\r一共买了两个\rOTSO004'),(16271,589859406003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','jtmoney31029','djhercurock@gmail.com','johnathan hughley','4336 hwy 83','forsyth','GA','UNITED STATES','31029','(478) 994-8367','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 15:54:52',0,NULL,3,1,1,1,' \\ ','jtmoney31029'),(16272,647657178013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','hrvmusic90','hrv.sandro@gmail.com','Sandro Bilandzic','Dioklecijanova 102','Solin','Splitsko-Dalmatinska','CROATIA','21210','00385981742344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 15:55:39',0,NULL,3,1,3,1,'RA184575551CN\r ','hrvmusic90\rOTES001'),(16273,737603524008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',5,'HSPL010',156.7,'au-buy','kw910736','boogaboo0927@hotmail.com','walter friesen','310 keenleyside street','winnipeg','MB','CANADA','r2l 1z1','(701) 520-3233','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 16:02:39',0,NULL,3,1,3,1,'RA184575503CN\r ','kw910736\rHSPL010'),(16274,647659564013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','smola99','uros.smolnik@gmail.com','Uroš Smolnik','Vanganelska 79e','Koper','Koper','SLOVENIA','6000','0038641814919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 16:03:38',0,NULL,3,1,2,1,' \\ ','smola99'),(16275,798174533011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','pallavitsingh','pallavitsingh@gmail.com','Pallavi Singh','920 S Washington ave<br>Apt 1K','Lansing','MI','UNITED STATES','48910-1672','(479) 871-8117','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 16:29:04',0,NULL,3,1,1,1,'  \\','pallavitsingh'),(16276,798228968011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',33.99,'eastar4','gehydro33','gehydro33@yahoo.ca','Martin Corbeil','586 Felix Leclerc','St-Eustache','QC','CANADA','J7P 5P2','(450) 974-9267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 18:04:58',0,NULL,3,1,2,1,'、\r ','gehydro33'),(16277,798270669011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.39,'eastar4','cleodis1','cleodis1@msn.com','Jerome Johnson','5451 Sundale Way S.','Memphis','TN','UNITED STATES','38135-4206','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 19:12:45',0,NULL,3,1,1,1,'  \\','cleodis1\racer 4pin1.25 6cm'),(16278,884838536012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','danit9','d_t9@walla.co.il','danit peretz','shimon avidan 85','rishon le zion','AL','ISRAEL','75339','0528024258','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 19:28:05',0,NULL,3,1,3,1,' RA184574264CN\r','danit9\rGLOT001*2\r兼容型3D眼镜 通用型'),(16279,745192008007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','gadget!','n1kld@aol.com','Robert W Stanton','516 Merwin Ave','Milford','CT','UNITED STATES','06460-7111','(203) 626-1866','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 19:39:13',0,NULL,3,1,1,1,' \\ ','gadget!'),(16280,647745217013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','nounours045','ulysse45@imode.fr','sebastien REMY','3 les menardins','ERVAUVILLE','Centre','FRANCE','45320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 19:42:12',0,NULL,3,1,2,1,' \\ ','nounours045\r欧标'),(16281,798304369011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','ea4djw','jcmerino@ya.com','JUAN CARLOS MERINO OLMO','CTRA ALMODOVAR Nº17, 3ºB','PUERTOLLANO','Castilla-La Mancha','SPAIN','13500','699771611','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 20:09:24',0,NULL,3,1,3,1,' RA184575622CN\r','ea4djw\rGLOT001*2\r兼容型3D眼镜 通用型'),(16282,884880697012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','designfunk.eu','info@designfunk.eu','Andrei Hernovich','vul. Bagdanovicha 143, kv. 196','Minsk','','BELARUS','220100','+375297030077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 20:35:52',0,NULL,3,1,2,1,'、  ','designfunk.eu\r白色的'),(16283,745233214007,170731735241,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',2,'LGGL003',39.8,'au-buy','jariv70','jaero@luukku.com','Jari Eronen','Rajalantie 20','Muurame','','FINLAND','40950','358407198983','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 20:52:49',0,NULL,3,1,2,1,' \\ ','jariv70'),(16284,589902993003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','carriepop_76','ajtinklepaugh@gmail.com','Carrie Price-Tinklepaugh','4180 Monarch Way','Salt Lake City','UT','UNITED STATES','84124-3154','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 21:21:33',0,NULL,3,1,1,1,'、  ','carriepop_76'),(16285,745259374007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','shimizu.luiz','luiz_shimizu@yahoo.com.br','Luiz Fernando Shimizu','Rua Gonçalves Crespo, 294','São Paulo','São Paulo/Capital/Tatuapé','BRAZIL','03066-030','05511-83004840','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 21:42:52',0,NULL,3,1,2,1,'、 ','shimizu.luiz'),(16286,647796769013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','tugboatbrad','waterbugs@comcast.net','Brad Thomas','1587 Lake Holiday Dr','Sandwich','IL','UNITED STATES','60548-9372','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 21:44:25',0,NULL,3,1,1,1,' \\ ','tugboatbrad\r兼容型3D眼镜 通用型'),(16287,798359732011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',33.99,'eastar4','deano3vlw','deanbarbara@embarqmail.com','Dean Jepson','13 Pine View Rd','Platte City','MO','UNITED STATES','64079-9370','(816) 858-3790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 21:47:32',0,NULL,3,1,1,1,'  \\','deano3vlw'),(16288,798227085002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','jairobotassi123','jairo.botassi@hotmail.com','Jairo Botassi dos Santos','Rua Prof. Belmiro Siqueira, 85<br>apto 1701, Torre 2, Enseada do Suá','Vitoria','Espirito Santo','BRAZIL','29050-580','+552733245889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 22:13:37',0,NULL,3,1,2,1,' \\ ','jairobotassi123'),(16289,745293612007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',2,'SCLO001',36.8,'au-buy','infocalypse','matt@infocalypse.net','Matt Stein','54 Chaiwood Ct.','Maple','ON','CANADA','L6A 0V9','(416) 227-1019','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 22:59:16',0,NULL,3,1,2,1,' \\ ','infocalypse'),(16290,798411596011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','nguwland','niek@nguwland.com','Niek Uwland','Helder Camarastraat 27','Delft','','NETHERLANDS','2622BH','0152564342','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 23:47:04',0,NULL,3,1,2,1,'、  ','nguwland'),(16291,798266567002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','schmerbear10','schmerbear@gmail.com','Leanne Schraeder','136 Orchard Dr','Penn Hills','PA','UNITED STATES','15235-3561','(412) 798-9572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 23:58:11',0,NULL,3,1,1,1,'\\  ','schmerbear10'),(16292,798417633011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','nigelplummer','ebay@nigey.com','Nigel Plummer','4 Green Lane','redhill','Surrey','UNITED KINGDOM','rh12dq','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 00:05:20',0,NULL,3,1,3,1,' RA184574202CN\r','nigelplummer\rHBPH002'),(16293,647847941013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','zzinned','dennizz505@msn.com','Dennis Brown','10 Campaspe Cres','Keilor','Victoria','AUSTRALIA','3036','0393363540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 00:11:50',0,NULL,3,1,6,1,'EE491015799CN ','zzinned\rGLOT001*4+MOLA001\r再发一个100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse'),(16294,798427518011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO008',20.9,'eastar4uk','taylor9430','josteve@esc.net.au','Stephen Taylor','11 Glenthorn Crescent','O\'Halloran Hill','South Australia','AUSTRALIA','5158','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 00:36:32',0,NULL,3,1,2,1,'、  ','taylor9430'),(16295,798429321011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','zzinned','dennizz505@msn.com','Dennis Brown','10 Campaspe Cres','Keilor','Victoria','AUSTRALIA','3036','0393363540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 00:40:27',0,NULL,3,1,17,0,NULL,'zzinned'),(16296,590051810003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','johnschindler14','john@capitalad.net','John Schindler','10239 Ojai Santa Paula Rd','Ojai','CA','UNITED STATES','93023','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 01:05:20',0,NULL,3,1,1,1,' \\ ','johnschindler14'),(16297,885013817012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','pinknorthern*lights','sherri.pirkl@ndm.gov.on.ca','Sherri Pirkl','313 1st Ave SW<br>C/O Lynn Ellis Box 732','Baudette','MN','UNITED STATES','56623-2870','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 01:34:30',0,NULL,3,1,1,1,' \\ ','pinknorthern*lights'),(16298,885015359012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','ms010s','addisontsui@netscape.net','Chi Tsui','4517 NE 21st PL','Renton','WA','UNITED STATES','98059-3853','(206) 353-0756','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'  \\','ms010s\racer 6pin1.25 23cm \r再发一个\rNew Atheros AR9281 802.11N Wireless WiFi over AR5008\rBTAC2015\r'),(16299,590060863003,130583982411,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',14.16,'cnfaner','abdulgokal786','abdulgokal@gmail.com','Abdul Rahman Gokal','7088 scott trail','Riverdale','GA','UNITED STATES','30296','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 01:48:20',0,NULL,3,1,1,1,' \\ ','abdulgokal786'),(16300,885019518012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','jxg26','jgontour@gmail.com','Juliet Gray','1/96 Britten Jones Drive','Holt','Australian Capital Territory','AUSTRALIA','2615','0417001086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 02:03:57',0,NULL,3,1,11,1,'、 ','jxg26\r24K 多色伞 '),(16301,755499378001,110728899326,'NIB Samsung SSG-3100GB 3D Active Glasses for PC monitor',1,'GLSG007',79.99,'buysia','wikwik85','wikwik85@hotmail.com','Komaldath Ramlall','Blauwtjes 52','Breda','','NETHERLANDS','4814TP','0624244334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 02:04:55',0,NULL,3,1,3,1,' RA184575579CN\r','wikwik85\rGLSG007'),(16302,647884342013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',12,'CASS003',101.88,'eastar4','jardim','hfjardim@gmail.com','HAROLDO JARDIM','43 THISTLECROFT','PRESTON','Lancashire','UNITED KINGDOM','PR2 7BS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 02:55:38',0,NULL,3,1,3,1,'RA184574278CN\r ','jardim\rCASS003'),(16303,885045227012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','why_garage','nabdanpaull@hotmail.com','Dan  Paull','18 Bight Crt','Mermaid Waters','Queensland','AUSTRALIA','4218','0755277520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 03:18:57',0,NULL,3,1,2,1,' \\ ','why_garage'),(16304,885060980012,220451430196,'Acer Aspire 5710 5710G  Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','robmac007','rmacdonell@optusnet.com.au','Robert MacDonell','7 Wandoo Crt<br>Karana Downs','Brisbane','Queensland','AUSTRALIA','4306','0732010995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 04:15:12',0,NULL,3,1,2,1,' \\ ','robmac007\racer 8pin1.00 15cm'),(16305,885061408012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','flossdoc7','jjorgdmd@yahoo.com','Jack Jorgensen','3011 NE 116th St','Vancouver','WA','UNITED STATES','98686-3929','(360) 566-0367','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 04:16:30',0,NULL,3,1,1,1,' \\ ','flossdoc7'),(16306,737932404008,180755478910,'New Genuine Motorola RAZR H3 Bluetooth Wireless Headset',1,'HSMO003',11.99,'au-buy','wolf4eva','ky_deeb@iinet.net.au','Kylie Riashi','165 McFarlane Drive','Minchinbury','New South Wales','AUSTRALIA','2770','0407935931','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-20 04:16:58',0,NULL,3,1,2,1,' \\ ','wolf4eva\r澳标\r'),(16307,885064837012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','pardi100','pardi@telefonica.net','Martín Pardilla Jiménez','C/ Los carros, 4','Membrilla','Castilla-La Mancha','SPAIN','13230','615017727','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 04:30:37',0,NULL,3,1,2,1,'、','pardi100'),(16308,885065056012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','superper','joeyyung911@yahoo.com','Arnold Voong','213 Lomitas Ave','South San Francisco','CA','UNITED STATES','94080-4143','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 04:30:38',0,NULL,3,1,1,1,' \\ ','superper\rAUI Transceiver  MX20T'),(16309,885074362012,220885745410,'New genuine Microsoft Wired Optical Wheel Mouse white',1,'MOMI004',13.79,'eastar4','ksdinnyc','ksdinnyc@yahoo.com','Kenny Duftler','127 Fox Boulevard','Merrick','NY','UNITED STATES','11566','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 05:09:42',0,NULL,3,0,1,1,' \\ ','ksdinnyc\r已入库'),(16310,885079034012,220816388534,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',2.99,'eastar4uk','il0x','ilchenko_al@hotmail.com','Aleksey Ilchenko','Soldatova 24-180','Perm','Permskij Kraj','RUSSIAN FEDERATION','614111','+79048497050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 05:31:16',0,NULL,3,1,2,1,' \\ ','il0x'),(16311,885075804012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','krivochshekov','hatebreader@mail.ru','Кривощеков С.С.','Крисина 5-73','Киров','Кировская область','RUSSIAN FEDERATION','610001','(912) 7052438','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 05:17:02',0,NULL,3,1,11,1,'、 ','krivochshekov\r蕾丝蝴蝶结伞 黑色\rUM00006\r不挂号'),(16312,798506929011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','bagels00','bradste@sbcglobal.net','Brad Stevenson','7007 Oakbrook St SE','Grand Rapids','MI','UNITED STATES','49546-6870','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 05:45:05',0,NULL,3,1,1,1,' \\ ','bagels00'),(16313,798508202011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','deni559','deninason@gmail.com','Deni Nason','4699 W Dinuba Ave','Fresno','CA','UNITED STATES','93706-9138','(559) 269-5291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 05:53:55',0,NULL,3,1,1,1,' \\ ','deni559'),(16314,798368237002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','jbcapt','jbcapt@insightbb.com','JERRY BURRIS','4117 Samoset Ct','LOUISVILLE','KY','UNITED STATES','40299-1451','(502) 499-8864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 06:34:35',0,NULL,3,1,1,1,'  \\','jbcapt'),(16315,798375778002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','rikki20102010','terrikki2@verizon.net','Rosetta Gadson','5928 N 12th St.<br>apt. 2','Philadelphia','PA','UNITED STATES','19141-3220','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 07:16:40',0,NULL,3,1,1,1,' \\ ','rikki20102010'),(16316,647929781013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',23.74,'eastar4','helen_max123','echidnahead1@bigpond.com','helen589 velissaris','2A Loftus Street','Campie','New South Wales','AUSTRALIA','2194','0417698589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 07:28:33',0,NULL,3,1,11,1,'、 ','helen_max123\r黑底七色边彩虹伞 \r不挂号\rUM00009'),(16317,745423140007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','civic82_4dr','civic82_4dr@yahoo.com','Edwin Chan','27 Richard Underhilll Ave','Stouffville','ON','CANADA','L4A0J1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 07:39:03',0,NULL,3,1,2,1,'、  ','civic82_4dr'),(16318,885110156012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','jastrl','portajohnnyjas@yahoo.com','john sembrot','24 Carol Dr','Succasunna','NJ','UNITED STATES','07876','(973) 927-5872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 07:52:58',0,NULL,3,1,1,1,'、  ','jastrl'),(16319,590141608003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','jkool-1961','jkool37042@yahoo.com','Joe Allen','406 Spencer Ln','Clarksville','TN','UNITED STATES','37042-6225','(931) 647-1961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 09:29:56',0,NULL,3,1,1,1,' \\ ','jkool-1961'),(16320,8881321781656236,111,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',0,'eastar4','leatherm0nkey','a.ahlsten@gmail.com','anton ahlsten','Tilkankatu 39 b 53','Helsinki','Helsinki','FINLAND','00300','',NULL,NULL,NULL,'2011-11-20 09:34:16',0,NULL,3,1,11,1,'、 ','补发的\rUM00008 24K 多色伞 \r不挂号'),(16321,745468458007,170731735241,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.9,'au-buy','mark13364','ms1041@hotmail.co.il','mark sitbon','sheshet haymim<br>14/4','kiriat haim','haifa','ISRAEL','26250','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 10:01:54',0,NULL,3,1,2,1,' \\ ','mark13364'),(16322,885166438012,220816388534,'New Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',5.98,'eastar4uk','mar35lus','marko.lustimaki@sci.fi','Marko Lustimäki','Dallasinpolku 5 B','Tyrnävä','','FINLAND','91800','044-5272701','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 10:17:33',0,NULL,3,1,2,1,' \\ ','mar35lus'),(16323,8881321784478235,111,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',0,'eastar4','n6175308','n61753@gmail.com','Stephen Holas','Unit 1/6 Rae Street','Chadstone','Victoria','AUSTRALIA','3148','0408359374',NULL,NULL,NULL,'2011-11-20 10:21:18',0,NULL,3,1,2,1,'、 ','补发的 '),(16324,885175427012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','caroleangelamelia','carole.melia@yahoo.com','Carole Melia','100 Albert Road<br>Morley','Leeds','West Yorkshire','UNITED KINGDOM','LS27 8RT','7799332998','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 10:35:47',0,NULL,3,1,3,1,'RA184577172CN ','caroleangelamelia\rUM00027\r蕾丝蝴蝶结长柄伞    红色'),(16325,797797587011,320791705447,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',96.99,'eastar4uk','mala1555','m.e.oman@hotmail.com','Mohammed ALAraimi','81 chichester road','south shields','Tyne and Wear','UNITED KINGDOM','ne33 4ae','07587362612','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 11:22:37',0,NULL,3,1,3,1,'RA184574247CN\r ','mala1555\rGPS0009'),(16326,738065930008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.34,'au-buy','sonjahancock','dwhancock66@gmail.com','Sonja Hancock','25 Kevin Avenue','AVALON','New South Wales','AUSTRALIA','2107','0414815412','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-20 11:54:56',0,NULL,3,1,2,1,' \\ ','sonjahancock\r澳标'),(16327,885228872012,220815929156,'New in box Iqua bluetooth Smart Badge BHS-608 BHS 608',1,'HSIQ001',29.99,'eastar4uk','wilfshooting','rayrayner2000@yahoo.co.uk','ray rayner','75 panfield lane','braintree essex','Essex','UNITED KINGDOM','CM75RP','01376550409','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 12:19:34',0,NULL,3,1,3,1,'RA184575534CN\r ','wilfshooting\rHSIQ001\r英标'),(16328,648019579013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','hussainnkm','nkmhussain@yahoo.com','kachchi mohideen hussain','3119/1.pubudupura road<br>stage 3','anuradhapura','anuradhapura','SRI LANKA','50000','0094714393878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 12:36:42',0,NULL,3,1,2,1,' \\ ','hussainnkm'),(16329,648032647013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','flame885uk','silverscafe.co.uk@gmail.com','Michael Anthony','34 St Johns Drive','Harrogate','North Yorkshire','UNITED KINGDOM','HG1 3AG','07533150930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 13:09:16',0,NULL,3,1,2,1,'、  ','flame885uk'),(16330,798674002011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',2,'NTLO001',21.98,'eastar4uk','cvylnq','cvylnq@gmail.com','Mme Gabriel','150 Ch de la tuilerie','Bouc Bel Air','Bouches Du Rhone','FRANCE','13320','0660313611','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 13:15:24',0,NULL,3,1,2,1,'、 ','cvylnq'),(16331,798681989011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','crazyb6969','colinmichaelhall@hotmail.com','Colin Michael Hall','25 Mallion Street Embleton','Perth','Western Australia','AUSTRALIA','6062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 13:34:11',0,NULL,3,1,2,1,' \\ ','crazyb6969'),(16332,885286674012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','tinglis3879','tommyinglis@aol.com','Tom Inglis','Kinnaber<br>4 Blair of Tarradale','Muir of Ord','Highland','UNITED KINGDOM','IV67PY','01463870693','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 13:58:07',0,NULL,3,1,3,1,'RA184575463CN\r ','tinglis3879\rOTGR001'),(16333,798747095011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','chibi020','ricecrackers87@hotmail.com','Miss borame dickens','55 speer road','thames ditton','Surrey','UNITED KINGDOM','kt7 0pj','02083390799','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 15:15:11',0,NULL,3,1,3,1,' RA184575565CN\r','chibi02\r红边优联\rRELO003'),(16334,885352274012,220711648781,'New Powchip POW-N18 MiNI  LAN ADAPTER USB 802.11N 150M',3,'WLPO001',26.97,'eastar4','diop78','ikt@chello.hu','Tibor Kajtár','Széchenyi István krt. 31','Szolnok','Jász-Nagykun-Szolnok','HUNGARY','5000','++36705201404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 15:31:11',0,NULL,3,1,2,1,'\\ ','diop78'),(16335,745643694007,170728988806,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',39.99,'au-buy','ndaicqs','pjpgdt@live.fr','GAUDILLAT PASCAL','10 rue jean Bart','brest','Bretagne','FRANCE','29200','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 15:32:34',0,NULL,3,1,2,1,' \\ ','ndaicqs\r欧标\r'),(16336,8881321781656236,111,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',0,'eastar4','leatherm0nkey','a.ahlsten@gmail.com','anton ahlsten','Tilkankatu 39 b 53','Helsinki','Helsinki','FINLAND','00300','',NULL,NULL,NULL,'2011-11-20 09:34:16',0,NULL,5,0,18,0,NULL,'UM00008\r 不挂号\r补发的'),(16337,590283240003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','txmom_9299','txmom9299@hotmail.com','Lisa kelley','18711 Egret Bay Blvd<br>Apt 316','Houston','TX','UNITED STATES','77058-3823','(281) 515-0829','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 15:45:09',0,NULL,3,1,1,1,' \\ ','txmom_9299'),(16338,648106593013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',1,'BTHP2102',12.39,'eastar4','corey-497','corey497@yahoo.com','Corey A Cirino','94 Wellworth Pl','Cheektowaga','NY','UNITED STATES','14225','(716) 874-7738','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 15:52:41',0,NULL,3,1,1,1,'  \\','corey-497\rHP 8pin 1.0 3cm 线序反 '),(16339,798786353011,320679575629,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',32,'eastar4uk','sailmailse','daniel@sailmail.se','Daniel Christiansson','Gjutegarden 193','Askim','Askim','SWEDEN','43645','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 16:10:51',0,NULL,3,1,3,1,' RA184574128CN\r','sailmailse\rWWOT003'),(16340,798769124011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','lilleybrook','garrydillon@onetel.com','Ceri Davies','Barfield Prep School<br>Guildford Road','Runfold, Farnham','Surrey','UNITED KINGDOM','GU10 1RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 15:53:43',0,NULL,3,1,3,1,'RA184574145CN\r ','lilleybrook\rMOAP001'),(16341,595726714004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','rfuchs001','ibowhunt78@gmail.com','Richard Fuchs','1333 Abigail Ct','Clarksville','TN','UNITED STATES','37042','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 16:30:01',0,NULL,3,1,1,1,' \\ ','rfuchs001'),(16342,798847368011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','tom--e','tom@xbos.nl','Tom Bisschops','Landvoogdstraat 108','Heerlen','','NETHERLANDS','6411 XA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 17:17:24',0,NULL,3,1,2,1,' \\ ','tom--e'),(16343,885457505012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','caroline2505','shiney_monkey@hotmail.com','Caroline Daryanani','LovePhotography Ltd<br>1 Heathcoat Street','Nottingham','Nottinghamshire','UNITED KINGDOM','NG1 3AF','07402743792','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 17:24:35',0,NULL,3,0,3,1,'RA184577186CN ','caroline2505\rUM00027'),(16344,885469761012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',23.74,'eastar4','slrfrr','slr8888@walla.co.il','Boguslavski Malvina','Tzamarot 5/7','Lod','','ISRAEL','71457','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 17:36:46',0,NULL,3,1,11,1,'、 ','slrfrr\r蓝天白云长柄伞 \r不挂号'),(16345,798869274011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','babbsagg','c.todtenbier@gmx.de','Christian Todtenbier','Benediktinerstraße 44','Paderborn','','GERMANY','33098','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 17:40:16',0,NULL,3,1,2,1,' \\ ','babbsagg'),(16346,885491184012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',15.93,'eastar4uk','isto6996','ianstott@hotmail.co.uk','ian stott','65 tynecastle street<br>springboig','glasgow','Glasgow (City of)','UNITED KINGDOM','g32 0bt','01417746674','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 17:52:36',0,NULL,3,1,3,1,'RA184574304CN\r ','isto6996\rHSMO014\r英标\r黑色的\r旧的'),(16347,885509338012,220886923190,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',17.95,'eastar4uk','dariuszgd','darekkuma@o2.pl','Dariusz KUMA','Carretera Sentmenat 103<br>PINTURAS HEMPEL','Polinya','Barcelona','SPAIN','08213','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 18:09:37',0,NULL,3,1,11,1,'\\ ','dariuszgd'),(16348,796257178011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','orbenhaim88','orbenhaim8@walla.co.il','or benhaim','hagnim','bustan hagalil','north','ISRAEL','25213','0545777188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 18:16:01',0,NULL,3,1,3,1,'RA184575485CN\r ','orbenhaim88\rLGAD001'),(16349,885539953012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',23.74,'eastar4','rmoni85','rmonica85@gmail.com','Monica Martinez','1539 ricardo st','los angeles','CA','UNITED STATES','90033-1540','(323) 379-0039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 18:30:17',0,NULL,3,1,1,1,'、 ','rmoni85\r黑色的\r蕾丝花边伞 '),(16350,648201670013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','walley_6','walley.6@hotmail.com','Amy & Mike Walley','404 McKenna Dr','Cape Girardeau','MO','UNITED STATES','63701','(573) 335-8872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 18:11:55',0,NULL,3,1,6,1,'EE645650223CN ','walley_6\r兼容型3D眼镜 通用型'),(16351,648218426013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','6for2','28004900v@gmail.com','David Valone','58 Crown Cir','Bristol','TN','UNITED STATES','37620-4843','(423) 573-4768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 18:28:56',0,NULL,3,1,1,1,' \\ ','6for2'),(16352,798979347011,320730549023,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',78.99,'eastar4uk','sexycherub1980','sarahhall10@btinternet.com','se hall','1 palace square<br>leadenhall','milton keynes','Buckinghamshire','UNITED KINGDOM','mk6 5jz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 19:08:54',0,NULL,3,1,3,1,' RA184575653CN\r','sexycherub1980\rGLOT001*3\r兼容型3D眼镜 通用型'),(16353,885591311012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',111.96,'eastar4','jkhay2007','jkhay@yahoo.com','John Khaydarov','2151 Abbey Ln','Campbell','CA','UNITED STATES','95008-3923','(408) 370-9366','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 19:10:04',0,NULL,3,1,1,1,'、  ','jkhay2007'),(16354,799007188011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','paul1234cat','paul.garfield@live.co.uk','MR P Garfield','15 Coupland Close','Chesterfield','Derbyshire','UNITED KINGDOM','S419TB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 19:31:46',0,NULL,3,1,3,1,' RA184574105CN\r','paul1234cat\rOTHP005'),(16355,885637992012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','phillipsbill','phillipsbill@msn.com','Bill Phillips','21107 SE 28th Pl','Sammamish','Wa','UNITED STATES','98075-7416','(425) 837-0400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 19:40:33',0,NULL,3,1,1,1,' \\ ','phillipsbill\rAUI Transceiver  MX20T'),(16356,885653038012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','artem-klevtssov','artem-klevtsov@rambler.ru','Artem Klevtsov','Nastavnikov prospekt.<br>26/2 app.15','St.Petersburg','','RUSSIAN FEDERATION','195298','+79119134971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 19:51:48',0,NULL,3,1,2,1,'、  ','artem-klevtssov\racer 6pin1.25 23cm'),(16357,885685488012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','beuvelande','pdprice_2000@hotmail.com','philip price','the cottage<br>beuvelande','st martin,Jersey','Channel Islands','UNITED KINGDOM','je3 6ez','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 20:17:32',0,NULL,3,1,3,1,'RA184575477CN\r ','beuvelande\rOTGR001'),(16358,885693212012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','kikou484','bdonato@videotron.ca','Guylaine Beliveau','42 Calais','Kirkland','QC','CANADA','H9H 3V3','(514) 426-4361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 20:25:31',0,NULL,3,1,2,1,'、  ','kikou484'),(16359,738482899008,180755478832,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',15.99,'au-buy','schippdienst','schippen@mhacky.de','Markus Hack','Brühlweg 22','Waldenbuch','','GERMANY','71111','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 20:34:31',0,NULL,3,1,2,1,' \\ ','schippdienst\r欧标\r'),(16360,799105649011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',4,'GLOT001',179.56,'eastar4','jjm92159','joe@joemunroe.com','Joe Munroe','PO Box 19788','San Diego','Ca','UNITED STATES','92159-0788','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 21:02:48',0,NULL,3,1,6,1,'EE491015958CN ','jjm92159\r兼容型3D眼镜 通用型'),(16361,885804821012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','inesshani75','inesshani@gmail.com','Inessa Koifman','sd` Jerusalem 4/3','Ashdod','','ISRAEL','77523','+972546938855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 22:37:04',0,NULL,3,1,11,1,'、 ','inesshani75\r不挂号\rUM00008'),(16362,885808880012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','duliak19','duliak@gmail.com','Jan Puhovich','Novosadna<br>20','Bratislava','','SLOVAK REPUBLIC','85110','00421910900719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 22:43:46',0,NULL,3,1,2,1,' \\ ','duliak19\r黑色的'),(16363,648403049013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','q8hamany','q8.hamany@gmail.com','Abdulrhman Abdulaziz','18221 150th Ave<br>KWI 32510','Springfield gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 22:54:45',0,NULL,3,1,1,1,'\\ ','q8hamany'),(16364,595987327004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',16.5,'cnfaner','stonplace','arne@steinstad.com','Arne Steinstad','Noklesvingen 44<br>--','Oslo','Oslo','NORWAY','0689','004795211085','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-20 22:57:29',0,NULL,3,1,3,1,' RA184574131CN\r','stonplace\rBALO007'),(16365,799185376011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','genadigenakuks','genakuks@netvision.net.il','genadi kuksinsky','sigaliot<br>13/6','Maalot','North','ISRAEL','24952','054-627-38-81','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 23:03:43',0,NULL,3,1,2,1,'、  ','genadigenakuks\r红边优联'),(16366,738605452008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.34,'au-buy','seinfeldfan1','jerryzkid@yahoo.com','joel petrone','18523 Michaelangelo Dr','Dallas','TX','UNITED STATES','75287','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 23:59:04',0,NULL,3,1,1,1,' \\ ','seinfeldfan1'),(16367,596005373004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','louis*707','louisnarcisse@ymail.com','louis narcisse','2396 Vanderford Dr','santa rosa','CA','UNITED STATES','95407-6325','(707) 703-0590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-20 23:59:55',0,NULL,3,1,1,1,' \\ ','louis*707'),(16368,885860621012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','davidgeorgencl','david.a.george@blueyonder.co.uk','David George','21 Sullivan Walk','Hebburn','Tyne and Wear','UNITED KINGDOM','NE31 1YN','07976362345','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 00:28:25',0,NULL,3,1,3,1,' RA184574114CN\r','davidgeorgencl\rSCLO004'),(16369,798430578011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA012',39.96,'eastar4','s_2','ssquared57@yahoo.com','S. See','24304 N Lakeview Blvd','Rathdrum','ID','UNITED STATES','83858-6636','(208) 350-3000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 02:16:31',0,NULL,3,1,1,1,'、 ','	pinknorthern*lightss_2\r两个都是黑色的'),(16370,738657768008,180755479461,'New Jabra BT125 Bluetooth headset',1,'HSJA006',13.55,'au-buy','islandconch1460','islandconch@aol.com','Tracy Hoeffer','1160 Comanche St<br>Apt 2','Jacksonville','FL','UNITED STATES','32205-6497','(305) 766-6259','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 02:21:03',0,NULL,3,1,1,1,'\\  ','islandconch1460'),(16371,885920268012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','natalya2222','natalya_shats@yahoo.com','Natalya Shats','40 Chester St','Los Gatos','CA','UNITED STATES','95032-7323','(408) 460-0316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 02:42:12',0,NULL,3,1,1,1,'、  ','natalya2222'),(16372,885927475012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','hazzabishop','jamesmillar35@gmail.com','James Millar','63 Ardmillan Road<br>Moonee Ponds','Melbourne','Victoria','AUSTRALIA','3039','0418143419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 02:57:27',0,NULL,3,1,2,1,' \\ ','hazzabishop'),(16373,590659877003,130489915552,'New Motorola H800 Bluetooth Wireless Headset track#',2,'HSMO016',43.12,'cnfaner','mxfile','cpittman@seiu99.net','C. Pittman','1063 Browning Blvd','Los Angeles','CA','UNITED STATES','90037-1603','(323) 373-9533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 04:18:53',0,NULL,3,1,1,1,'\\  ','mxfile'),(16374,590662998003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','legbroke1','brokeleg65@cox.net','Andrew Brass','po box 751402','Las Vegas','NV','UNITED STATES','89136-1402','(702) 325-6846','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 04:37:55',0,NULL,3,1,1,1,'\\  ','legbroke1'),(16375,746191982007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','kobi_tomer','kobitomer@hotmail.com','kobi tomer','hertzel<br>22/7','ramle','israel','ISRAEL','72244','0525112121','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 05:44:47',0,NULL,3,1,2,1,'、  ','kobi_tomer'),(16376,648532976013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','pospelko2910','pospelko@mail.ru','Konstantin Pospelov','Kommunarov 14-123','Vladivostok','Primorsky kray','RUSSIAN FEDERATION','690077','4232767040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 07:23:40',0,NULL,3,1,2,1,' \\','pospelko2910\r新的  欧标'),(16377,8881321861434428,111,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',0,'cnfaner','tomasroda67','tomasroda@interia.pl','Tomasz Popiel','8 David Road','Rugby','Northamptonshire','UNITED KINGDOM','cv227px','',NULL,NULL,NULL,'2011-11-21 07:43:54',0,NULL,3,1,3,1,'RA184577138CN\r','HSNO019\r补发 \r只补发一个耳机\r2 Greenhill Road Rugby CV226BJ'),(16378,648540124013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',18.99,'eastar4','danzbbox2','danzbbox2@hanmail.net','Karen Chang','3731 Wilshire Blvd<br>Ste 300','Los Angeles','CA','UNITED STATES','90010-2821','(213) 380-0777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 08:09:56',0,NULL,3,1,1,1,'、 ','danzbbox2\r草莓伞 '),(16379,8881321862998564,111,'New Genuine Motorola HS850 Bluetooth Headset ',1,'',0,'cnfaner','krsbunnies','karenreneesmail@yahoo.com','karen hixson','11131 ragan way','grass valley','CA','UNITED STATES','95949','(530) 273-8348',NULL,NULL,NULL,'2011-11-21 08:09:58',0,NULL,5,0,18,0,NULL,NULL),(16380,8881321862998564,111,'New Genuine Motorola HS850 Bluetooth Headset ',1,'',0,'cnfaner','krsbunnies','karenreneesmail@yahoo.com','karen hixson','11131 ragan way','grass valley','CA','UNITED STATES','95949','(530) 273-8348',NULL,NULL,NULL,'2011-11-21 08:09:58',0,NULL,3,0,1,1,' LK026455225CN \\ ','已入库 \rHSMO019\r补发 全套\r'),(16381,886022250012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','natalia*','natalia_tabuenca@hotmail.com','TUDELA SOLAR, S.L.','POL. LA BARRENA, C/ CANAL DE TAUSTE, S/N<br>A/A NATALIA TABUENCA HORARIO DE 8 A 3','TUDELA','Navarra','SPAIN','31500','619975042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 08:56:56',0,NULL,3,0,11,1,'、 ','natalia*\r已入库\rUMTR001\r不挂号\r粉红色的'),(16382,648553027013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','tiffyrashell','xxtiffy_stumpxx@yahoo.com','Tiffani Edge','5821 Hartwick Rd','Houston','TX','UNITED STATES','77016','(832) 419-7922','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 09:24:47',0,NULL,3,1,1,1,'、','tiffyrashell\rHP 8pin 1.0 23cm '),(16383,799379716011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','Agustin Manuel Almagro Rojas','C/DE ARAGONITO 7A','MÁLAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 09:31:27',0,NULL,3,1,6,1,'EE491015992CN ','latiendadelsotano\r兼容型3D眼镜 通用型'),(16384,648560910013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','4154kathyh','pkhol@bigpond.net.au','kathy holland','4 galaxy court<br>capalaba','brisbane','Queensland','AUSTRALIA','4157','0738235112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 10:06:13',0,NULL,3,1,6,1,'EE491015989CN ','4154kathyh\r兼容型3D眼镜 通用型'),(16385,799393061011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','semit54','sitkes@rambler.ru','semion itkes','silver 109/31','haifa','','ISRAEL','32696','048325926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 10:17:26',0,NULL,3,1,3,1,'RA184575004CN\r ','semit54'),(16386,648572494013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','amster929','valdas929@gmail.com','Valdas Kuraitis','Putinu 12-2','Garliava','Kauno rajonas','LITHUANIA','LT-53267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 11:01:32',0,NULL,3,1,3,1,'RA184574967CN ','amster929\rLGGL002'),(16387,648574467013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',59.64,'eastar4','necr0filius','aleksey.mikhaylovskiy@gmail.com','Aleksey Mikhailovsky','ul. Geroev Dnepra 65,  kv. 28','Kiev','','UKRAINE','04214','+380443837563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 11:38:29',0,NULL,3,1,3,1,'RA184574468CN\r ','necr0filius\rWLAP008'),(16388,793930599002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','5008angelangel','asanchezcampo@gmail.com','Angel Sánchez Campo','C/Carlos Dabán 26, esc 8, 1º dcha','Madrid','Madrid','SPAIN','28019','914726084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 11:40:16',0,NULL,3,1,2,1,'\\  ','5008angelangel'),(16389,648559044013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','freak-monk','darcksider@gmail.com','Sergey Savchuk','Rybalko 13/166','Novograd-Volynskiy','ZT','UKRAINE','11709','+380938634442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 11:44:39',0,NULL,3,1,2,1,'\\  ','freak-monk'),(16390,738796553008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',50.26,'au-buy','duraace10spd','braso111@gmail.com','shane brasen','52 currawong road','Tumut','New South Wales','AUSTRALIA','2720','0269473781','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 11:45:52',0,NULL,3,1,3,1,'RA184574998CN\r ','duraace10spd\rHSPL015\r澳标'),(16391,648586326013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',42.45,'eastar4','antoran061','antonio.rancan@gmail.com','Antonio Rancan','140 Sussex St','Sydney','New South Wales','AUSTRALIA','2000','0403981720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 12:05:50',0,NULL,3,1,3,1,'RA184574485CN\r ','antoran061\rCASS003\rCAB-6060'),(16392,886079971012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',2,'WLAT005',19.78,'eastar4','bobier82','juventus_ita@yahoo.com','Frankie Chan','56 Bukit Batok East Ave 5, 11-05','default','','SINGAPORE','659804','6597559517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 12:07:31',0,NULL,3,1,11,1,'\\ ','bobier82\rWLAT005\r不挂号'),(16393,799428797011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',4,'OTCN002',15.92,'eastar4','stamosach','stamos@hcc.com.gr','Stamos Achtidas','45 Polizoidou St.','ILIOUPOLI','ATTIKI','GREECE','16346','2109955158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 12:14:15',0,NULL,3,1,2,1,'\\ ','stamosach'),(16394,799431266011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','leszek-uk','elgielegie@gmail.com','Leszek Gorny','11 Blandford Avenue','Luton','Bedfordshire','UNITED KINGDOM','LU2 7AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 12:22:24',0,NULL,3,1,3,1,'RA184574573CN\r ','leszek-uk'),(16395,799441508011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','funtomas78','soul.to.house@seznam.cz','Jan Tomasek','Eliasova 31','Prague','Czech republic','CZECH REPUBLIC','16000','00420773567988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 12:54:00',0,NULL,3,1,2,1,'\\  ','funtomas78'),(16396,799450394011,320730086763,'New GENUINE NOKIA BH-203 BLUETOOTH HEADSET',2,'HSNO007',18.98,'eastar4uk','pixiedoestattoos','lemonface@hotmail.co.uk','Madison walsh','116 radstock way','redhill','Surrey','UNITED KINGDOM','rh1 3nh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 13:18:52',0,NULL,3,1,3,1,'RA184574525CN\r ','pixiedoestattoos\rHSNO007\r英标'),(16397,885980914012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','armanchiksatenik','badkarmaa@bigmir.net','Satenik Aivazyan','Mayakovskovo 62a','Kiev','Kiev district','UKRAINE','02222','0936574819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 13:59:42',0,NULL,3,1,2,1,'\\  ','armanchiksatenik'),(16398,648620989013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','klaes712','annette1709@gmx.de','Annette   Kläs','Alte Juelicher Str. 84','Dueren','','GERMANY','52353','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 14:26:11',0,NULL,3,1,3,1,'RA184574975CN\r ','klaes712\rHBPH002'),(16399,648627244013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',38.82,'eastar4','amtler','jaspa10@gmail.com','Patryk Jaskurzynski','Skrzynka Pocztowa 276<br>Białystok 1','Białystok 1','Podlaskie','POLAND','15-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 14:52:00',0,NULL,3,1,2,1,'\\  ','amtler'),(16400,799485332011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jkfjr53','jkfjr@ducom.tv','James Fugate','220 Fallowfield Drive','Leola','PA','UNITED STATES','17540','(717) 656-8406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 14:56:01',0,NULL,3,1,1,1,'\\  ','jkfjr53'),(16401,799490687011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','spindle-shell','fyro_ant@hotmail.com','anant sukha','155 flat 22 erddig block wrexham village<br>crispin lane','wrexham','Wrexham','UNITED KINGDOM','ll11 2ht','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 15:08:42',0,NULL,3,1,3,1,'RA184574471CN\r ','spindle-shell\rHSUE001'),(16402,799501685011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',33.99,'eastar4','smokey1616','dee.lindsey@charter.net','Dee   Lindsey','2817 Winthrop Dr SW','Decatur','AL','UNITED STATES','35603-1171','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 15:37:21',0,NULL,3,1,1,1,'\\  ','smokey1616'),(16403,799509124011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','pixiesandimps','evonnejoan@yahoo.com','Rickie Fazakerley','65 Eastfield Drive, South normanton','Alfreton','Derbyshire','UNITED KINGDOM','DE55 2HN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 15:58:27',0,NULL,3,1,3,1,'RA184574953CN\r ','pixiesandimps\rGLOT001*2\r兼容型3D眼镜 通用型'),(16404,886179606012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4uk','qtwerk','karl.norton@blueyonder.co.uk','karl norton','47 holmwood drive','gloucester','Gloucestershire','UNITED KINGDOM','GL40PN','01452542238','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 16:13:41',0,NULL,5,1,18,1,NULL,'qtwerk\rUM00031\r黑色的\rLED发光伞 '),(16405,738895608008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','jagil71','jasonegill@yahoo.ca','Jason Gill','455 Granville Street<br>Suite 200','Vancouver','BC','CANADA','V6C 1T1','(604) 649-0909','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 16:30:56',0,NULL,8,1,17,0,NULL,'jagil71'),(16406,738898926008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','jagil71','jasonegill@yahoo.ca','Jason Gill','455 Granville Street<br>Suite 200','Vancouver','BC','CANADA','V6C 1T1','(604) 649-0909','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 16:46:22',0,NULL,3,1,2,1,'\\  ','jagil71\r再发一个New Logitech Harmony Remote USB Cable for 880 890   \rCALO001'),(16407,886202754012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','calsi','caroline.rolfe@virgin.net','caroline rolfe','16 victoria avenue','chard','somerset','UNITED KINGDOM','ta20 1he','0146061658','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 16:59:43',0,NULL,3,1,3,1,'RA184574984CN\r ','calsi\rHBPH003'),(16408,648670342013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',5,'HSNO019',189.9,'eastar4','vtuc5626','tuckervj@ccrsb.ca','Valerie Tucker','Chignecto-Central Reg Sch Brd<br>60 Lorne Street','Truro','NS','CANADA','B2N3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 17:04:10',0,NULL,3,1,3,1,'RA184574595CN\r ','vtuc5626\rHSNO019\r新的'),(16409,886218094012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','vrodharleydav','daniel.machault@live.fr','MACHAULT DANIEL','49 Rue Gabriel PERI','ROMILLY Sur Seine','Champagne-Ardenne','FRANCE','10100','0325248887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 17:37:53',0,NULL,3,1,3,1,'RA184574940CN ','vrodharleydav\rGLOT001*2\r兼容型3D眼镜 通用型'),(16410,886224903012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',65.99,'eastar4uk','danieletx','danieletx@hotmail.com','Daniel Badia','C/Nord  N.7 4º 2ª','Vic','Barcelona','SPAIN','08500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 17:40:44',0,NULL,3,1,3,1,'RA184574919CN ','danieletx\rGLOT005*2'),(16411,648682963013,230679976738,'NIB LCD/DLP Projector Ceiling Mount Braket Universal',1,'OTNB001',35,'eastar4','audryla74','audrylav@gmail.com','Audrius Varneckas','Darbininku 22-1','Kaunas','','LITHUANIA','LT-50173','0037068583969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 17:52:46',0,NULL,3,1,2,1,'\\ ','audryla74\rOTNB001'),(16412,886235980012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',15.14,'eastar4','gg_holsteins','gg_holsteins@yahoo.com','Katie Gerlach','2568 K Ave','Toledo','IA','UNITED STATES','52342-9435','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 18:03:03',0,NULL,3,1,1,1,'、 ','gg_holsteins\r一共买了两个\rAUI Transceiver  MX20T'),(16413,799430322002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',5,'OTAM001',29.95,'buysia','sakis321','k_nimit@hotmail.com','T00A1864 NIMIT KREUSANEH','17230 NE Sacramento St<br>Ste T00A1864','Portland','OR','UNITED STATES','97230-5940','503 736 5916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 19:08:37',0,NULL,3,1,17,1,' ','sakis321\r修改发货地址 \rNIMIT KREUSANEH\rBenyada Lodge, 106/52 Moo 3, Surin Beach\rCherngta lay, Talang,\rPhuket\rPET, 83110\rThailand\r\r\r'),(16414,886152532012,220825062314,'New 3.0 Bluetooth BCM92070 Module+cable Asus N43 N73',1,'BTAS3001',19.98,'eastar4','nixkaze','nix-kaze@hotmail.com','Nick Kosmopolis','129 Saint Ellen St','O Fallon','IL','UNITED STATES','62269-1635','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 19:08:53',0,NULL,3,1,1,1,'\\  ','nixkaze\r3.0 ASUS 6pin 6CM '),(16415,746476838007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.9,'au-buy','sylvio2336','sylviogouin@hotmail.com','Gouin Sylvio','2336,rang 2 est','St-Julien','QC','CANADA','g0n1b0','(418) 423-2439','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 19:20:36',0,NULL,3,1,3,1,'RA184574542CN\r ','sylvio2336\rHSPL013'),(16416,799461604002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',5,'OTAM001',29.95,'buysia','sakis321','k_nimit@hotmail.com','NIMIT KREUSANEH','Benyada Lodge, 106/52 Moo 3, Surin Beach<br>Cherngta lay, Talang,','Phuket','PET','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-21 19:54:33',0,NULL,3,1,3,1,'RA184574644CN ','sakis321\rOTAM001\r一共发13个其中包括3个补发的'),(16417,886321062012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','dooge431','dooge43@yahoo.com','Douglas Jacobs','1630 Devon Dr','Albany','GA','UNITED STATES','31721-7118','(229) 343-5254','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 20:00:39',0,NULL,3,1,1,1,'\\  ','dooge431'),(16418,648755212013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*4',351.98,'eastar4','phuey-70','phu.nhu@gmail.com','Phu Nhu','8 Robyn dr','Nunawading','Victoria','AUSTRALIA','3131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 20:12:39',0,NULL,3,1,6,1,'EE491015961CN ','phuey-70\r兼容型3D眼镜 通用型'),(16419,648761998013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','porexx','valdas@laverna.lt','Valdas Bieris','Ežero g, 1<br>Šlienava','Kauno raj.','','LITHUANIA','LT-53150','+37069840960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 20:25:24',0,NULL,3,1,2,1,'\\  ','porexx'),(16420,590931902003,130590294283,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',51.29,'cnfaner','adolfocirlos','cirlosjr.adolfo@yahoo.com','Adolfo Cirlos Jr','505 W Starr Ave','Pharr','TX','UNITED STATES','78577-8846','(956) 483-0565','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 21:30:54',0,NULL,3,1,1,1,'\\  ','adolfocirlos'),(16421,739070288008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','cameronpettiona','campettiona@gmail.com','Cameron Pattiona','1/75 Berry Ave','Edithvale','Victoria','AUSTRALIA','3196','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 21:40:56',0,NULL,3,1,2,1,'\\  ','cameronpettiona'),(16422,799715075011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','jessyca825','bazoule@hotmail.com','Jessica Tremblay','3512 7E Rue','Val d\'Or','QC','CANADA','J9P7G2','(819) 825-1138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 21:45:01',0,NULL,3,1,3,1,'RA184574936CN\r ','jessyca825\rGLOT001\r兼容型3D眼镜 通用型'),(16423,886402198012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',10,'TRMX003',75.7,'eastar4','don_bae_sys','donald.j.repetto@baesystems.com','BAE Systems - D. Repetto','1098 Clark Street<br>Material Distribution Center','Endicott','NY','UNITED STATES','13760','(607) 206-2626','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 22:03:56',0,NULL,3,1,1,1,'、 ','don_bae_sys'),(16424,590958668003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',17.4,'cnfaner','sjf66sjf66','sjfree66@gmail.com','stephen j free','1300 Chestnut St','Wilmington','NC','UNITED STATES','28401','(910) 254-0366','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 22:51:42',0,NULL,3,1,1,1,'\\  ','sjf66sjf66'),(16425,590959398003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',17.09,'cnfaner','mabouche','mabouche@hotmail.com','Mike Boucher','21 Chesterfield Rd','Milton','MA','UNITED STATES','02186-4119','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 22:54:24',0,NULL,3,1,1,1,'\\  ','mabouche'),(16426,799752954011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',4,'ANTY002',11.96,'eastar4uk','neal1111','neal-king@blueyonder.co.uk','Neal King','Secure Systems & Technologies<br>Brunell Court','Waterwells','Gloucester','UNITED KINGDOM','GL2 2AL','01452371999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 23:07:58',0,NULL,3,1,3,1,'RA184574556CN\r ','neal1111\rANTY002'),(16427,886467318012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','markus_hyvonen','markus.hyvonen@gmail.com','Markus Hyvonen','Reserve Bank of Australia<br>65 Martin Place','Sydney','New South Wales','AUSTRALIA','2000','0295518846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 00:39:21',0,NULL,3,1,3,1,'RA184574922CN ','markus_hyvonen\rOTSO004*2'),(16428,799817081011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',33.99,'eastar4','gladiator88','edwardy88@yahoo.com','Edward Yip','10 Sunny Glenway Apt 1104','Toronto','ON','CANADA','M3C 2Z3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 02:26:45',0,NULL,3,1,2,1,'、 ','gladiator88'),(16429,799822615011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',33.99,'eastar4','hashalex3','help@wmebay.ru','Plusin Nikolay','ul. Proletarskay d.100 kv. 24','Mozur','Gomelskaya oblast','BELARUS','247772','+375297358735','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-22 02:48:04',0,NULL,3,1,2,1,'、 ','hashalex3\r旧的\r名字改一下\rPlusnin Nikolay'),(16430,799827727011,320701927743,'NIB Samsung G2 2.5\" 320GB External Hard Disk drive',1,'HDSG001',75.9,'eastar4','colorblindworld','mynameismud98@gmail.com','mike elchuk','#3 5343 200 street','langley','BC','CANADA','v3a 1m2','(778) 278-1714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 03:02:08',0,NULL,5,1,18,1,NULL,'colorblindworld\rHDSG001\r无货了  已客户退款'),(16431,886526713012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','rajesh_babwah','rajesh_babwah@hotmail.com','Rajesh Babwah','TT92X3541N<br>7801 N.W. 37TH STREET','DORAL','FL','UNITED STATES','33166-6503','868 798 8979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 03:32:51',0,NULL,3,1,1,1,'、 ','rajesh_babwah'),(16432,886527226012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','kkuznet42','kkuznet@gmail.com','Konstantin  Kuznetsov','Shornikova, 1, 39','Kemerovo','Kemerovskaya obl','RUSSIAN FEDERATION','650036','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 03:34:48',0,NULL,3,1,3,1,'RA184574627CN ','kkuznet42\rGLOT001\r兼容型3D眼镜 通用型'),(16433,799838662011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','aneda_bg','aneda_bg@yahoo.com','Teodor Alexandrov','2193 McKenzie Road','Abbotsford','BC','CANADA','V2S4A1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 03:44:30',0,NULL,3,1,2,1,'、 ','aneda_bg'),(16434,646279212013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',84.9,'eastar4','she_ahm','sheraz.ibms@gmail.com','Sheraz Ahmad','80 Ave 99 Street 9929 house and 201 suite','Edmonton','AB','CANADA','T6E1T2','(980) 200-7496','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 04:04:18',0,NULL,3,1,3,1,'RA184574658CN ','she_ahm\rCASS003'),(16435,799850626011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','rocketblast314','rocketblast@gmail.com','Marty Jablonski','1176 West St','Benzonia','MI','UNITED STATES','49616-8636','(515) 257-6583','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 04:34:05',0,NULL,3,1,1,1,'、 ','rocketblast314'),(16436,886559653012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.4,'eastar4','tharudn','tharindu.n@live.com','Tharindu Nanayakkara','No. 144/9A, Pamunuwila<br>Gonawala','Kelaniya','','SRI LANKA','11630 ','+94772092674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 05:55:21',0,NULL,3,1,2,1,'、 ','tharudn\r英标'),(16437,799868705011,320785748313,'New Logitech G7 Rechargeable Battery MX revolution mous',2,'BALO005',14.98,'eastar4uk','piploid','piploid80@gmail.com','Stanislav Malahov','internacional\'naja 51-58','nizhnevartovsk','KHMAO','RUSSIAN FEDERATION','628617','(9028)53-51-71','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 06:02:18',0,NULL,3,1,2,1,'、 ','piploid'),(16438,799877388011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','jarrl','jessfull@gmail.com','JESUS ANGEL BALLESTEROS SAN JUAN','AVDA. SCHULZ<br>138 3º IZQDA.','GIJON','ASTURIAS','SPAIN','33208','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:46:56',0,NULL,3,1,2,1,'、 ','jarrl'),(16439,648925088013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','liljonkr3w','babyjohnny2@hotmail.com','Jonathon Davidson','172 Townson Ave Palm Beach','Gold Coast','Queensland','AUSTRALIA','4221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:56:03',0,NULL,3,1,6,1,'EE491015785CN ','liljonkr3w\r兼容型3D眼镜 通用型'),(16440,886541028012,220820895778,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',27.99,'eastar4uk','ascc76','ascc76@hotmail.com','amen soh','7-3-4 Lorong 4/92B<br>Taman Kobena','Cheras','Wilayah Persekutuan','MALAYSIA','56100','0123930161','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 07:08:02',0,NULL,3,1,2,1,' RA184576177CN\r','ascc76\rHSIT001'),(16441,886576130012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','longeflucht','chris.fodera@gmail.com','Christopher M. Fodera','45875 Boulder Way','Temecula','CA','UNITED STATES','92592-4228','(760) 782-7710','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 07:08:44',0,NULL,3,1,1,1,'、 ','longeflucht\rAUI Transceiver  MX20T'),(16442,886583002012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','amsalemix','ramsalem1@walla.co.il','Rony Amsalem','HaTurmos 8, Apartment Number 2<br>+972509938568','Rishon LeTsiyon','','ISRAEL','75722','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 07:39:58',0,NULL,3,1,2,1,'、 ','amsalemix'),(16443,596473261004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',13.98,'cnfaner','4pachecos','jose@irvinesocceracademy.com','Jose Pacheco','1918 S Main St','Santa Ana','CA','UNITED STATES','92707-2828','(714) 589-5788','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-22 07:49:27',0,NULL,3,1,1,1,'、\r','4pachecos'),(16444,648934648013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','xxxghostxstaffordxxx','gooddvin@gmail.com','Vasiliy Glukhov','12 Krasnoselyskaya Str. Apt. 14','Moscow','','RUSSIAN FEDERATION','107140','+7(985)775-22-04','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-22 07:55:01',0,NULL,3,1,2,1,'、 ','xxxghostxstaffordxxx\r新的  欧标'),(16445,886600029012,220448674413,'Acer Travelmate 5110 5610 Bluetooth Module2.0 EDR+cable',1,'BTAC2008',9.88,'eastar4','050554cmgg','cmiragg_1@telefonica.net','Carlos Mira Garcia-Gutierrez','Los Refranes 4, 1º A','Albacete','Castilla-La Mancha','SPAIN','02006','649626520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 08:49:24',0,NULL,3,1,2,1,'、','050554cmgg\rBTAC2008\racer 4pin1.25 18cm'),(16446,799722934002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',6,'OTAM001',35.94,'buysia','sakis321','k_nimit@hotmail.com','T00A1864 NIMIT KREUSANEH','17230 NE Sacramento St<br>Ste T00A1864','Portland','OR','UNITED STATES','97230-5940','503 736 5916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 09:06:00',0,NULL,3,1,3,1,'RA184574825CN\r ','sakis321\rOTAM001\r新地址\rNIMIT KREUSANEH\rBenyada Lodge, 106/52 Moo 3, Surin Beach\rCherngta lay, Talang,\rPhuket PET 83110\rThailand\r\r'),(16447,799923728011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','ipodamou','arnaud-b@optionplus.com','Option + Arnaud Bordalis','107 avenue Georges Clemenceau','Nanterre','Île-de-France','FRANCE','92000','336 1434 2998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 10:02:20',0,NULL,3,0,3,1,'RA184577141CN ','ipodamou\rTRTS001*10\r已入库'),(16448,799924282011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','olegknoroz','knol2009@gmail.com','Oleg Knoroz','1 Gvardeyskoy Armii st., 16-96','Chernihiv','UA','UKRAINE','14005','380501751990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 10:04:09',0,NULL,3,1,3,1,'RA184577800CN\r ','olegknoroz\rHSSE011\r已入库  欧标'),(16449,799937836011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','3808richardl','richard-2005@hotmail.co.uk','richard leussa wandeu','4 pinedene<br>carlton grove','soutwark','London','UNITED KINGDOM','se15 2ul','02076399712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 10:52:10',0,NULL,3,1,3,1,'RA184577022CN ','3808richardl\rOTSO004'),(16450,886608211012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','shderi','sh_deri@walla.co.il','shlomo deri','hatenim 22/9','keriat ata','lsrael','ISRAEL','28000','0524586408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 11:01:03',0,NULL,3,0,3,1,'RA184577075CN ','shderi\rGLOT001*4\r兼容眼镜\r已入库'),(16451,648970105013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',2,'UM00010',47.48,'eastar4','smedley027','raseystacey@hotmail.com','Stacey Higgins','158 Moores Pocket Rd<br>Moores Pocket','Brisbane','Queensland','AUSTRALIA','4305','0732828408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 11:10:00',0,NULL,3,0,3,1,'RA184577190CN ','smedley027\rUMOO010*2\r已入库\r黑的和粉，白选1'),(16452,886640149012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','tommys-gadgets','zaheer786uk@aol.com','Zaheer Islam','174 Derby Road<br>Newtown','Southampton','Hampshire','UNITED KINGDOM','SO14 0DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 11:10:00',0,NULL,3,1,3,1,'RA184574896CN\r ','tommys-gadgets\r英标'),(16453,799938484011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',7.57,'eastar4','ragadore','bronie@exemail.com.au','Steve Luxford','21 The Sanctuary','Umina Beach','New South Wales','AUSTRALIA','2257','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 11:14:44',0,NULL,3,0,2,1,'\\ ','ragadore\rTRMX001\r已入库'),(16454,596512892004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','macku','mack63@gmail.com','Mack Utley','2504 Chestnut Oak Rd','Kuttawa','KY','UNITED STATES','42055','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'macku'),(16455,886664907012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','goldfishkz','vs.min@mail.ru','Vladimir Min','str. Khusainova<br>h.157, fl.7','Uralsk','ZKO','KAZAKHSTAN','090002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 12:24:24',0,NULL,3,1,2,1,'\\  ','goldfishkz\rOTTP001\r已入库'),(16456,886671105012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',3,'HSMO014',47.79,'eastar4uk','ericcadenel','k2autoplus@free.fr','eric cadenel','10 boulevard charlemagne','marseille france','Provence-Alpes-Côte d\'Azur','FRANCE','13012','0491661924','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 12:41:43',0,NULL,3,1,3,1,'RA184574905CN ','ericcadenel\rHSMO014\r欧标（法国）'),(16457,799984472011,320774356757,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',101.97,'eastar4','halldoratinna','tinnakaren.gudbjarts@gmail.com','Halldora Thormodsdottir','Leirubakki 8','Reykjavik','','ICELAND','109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 13:26:17',0,NULL,3,0,3,1,'RA184577019CN ','halldoratinna\rHSNO031\r已入库 旧的\r一共买了3个'),(16458,739337573008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','panter_999','gd@theplanet.ch','Guido Dubler','Kirchweg 44c','Nussbaumen','','SWITZERLAND','5415','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 14:03:32',0,NULL,3,1,3,1,'RA184574834CN\r ','panter_999\rHBPH007'),(16459,649021527013,230657633130,'KODAK Wi-Fi Card 4 EasyShare Camera printer dock',1,'WLKO001',25.99,'eastar4','rokko1974','rokko74@gmail.com','Yiannis Rozis','Ionos 21','Ilioupoli','Attica','GREECE','16341','+306933333155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 14:42:16',0,NULL,3,0,2,1,'\\ ','rokko1974\rWLKO001\r已入库'),(16460,746721770007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','jeffgerrard1','cement-head@hotmail.com','Jeff Gerrard','1404 Maple Road. P.O. Box 333','Belle Ewart','ON','CANADA','L0L 1C0','(705) 795-7558','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 14:49:12',0,NULL,3,1,2,1,'\\ ','jeffgerrard1'),(16461,800021876011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',23.74,'eastar4','boni-boy','gilwaiss@gmail.com','Gil Waissmann','39 Burla St. ap.9.','Tel Aviv','','ISRAEL','69364','0522781337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 15:04:08',0,NULL,3,1,11,1,'、 ','boni-boy\rUMOO007\r已入库'),(16462,886728757012,220886923190,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',17.95,'eastar4uk','boni-boy','gilwaiss@gmail.com','Gil Waissmann','39 Burla St. ap.9.','Tel Aviv','','ISRAEL','69364','0522781337','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 15:13:57',0,NULL,3,1,11,1,'、 ','boni-boy\rUM00008\r24骨彩虹伞'),(16463,886742134012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','bamberkat13','themichaelis@msn.com','Sylvia Elwell-Michaelis','1132 N Pebble Beach Dr','Gilbert','AZ','UNITED STATES','85234','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 15:46:11',0,NULL,3,0,1,1,'\\ ','bamberkat13\rMOMI002\r已入库'),(16464,757002937001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','vesper_lynd_07','rbass_7@hotmail.com','Araceli Ríos Barrientos','Plan de Caborca # 9 Col. San Lorenzo La Cebada<br>Delegación: Xochimilco','México','Distrito Federal','MEXICO','16034','56 53 07 62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 16:18:18',0,NULL,3,1,2,1,'\\ ','vesper_lynd_07'),(16465,800050565011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',1,'NTLO001',10.99,'eastar4uk','alyn1573','adam.e.lynch@gmail.com','Adam Lynch','60, Newcombe Rise,<br>Yiewsley,','West Drayton','Middlesex','UNITED KINGDOM','UB7 8QF','077598430325','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 16:21:53',0,NULL,3,1,3,1,'RA184577036CN ','alyn1573'),(16466,649061891013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','ihcfan','ihcfan@braincookie.com','Keith Ballantyne','2030 Roosevelt Ave','York','PA','UNITED STATES','17408-9199','(717) 505-8564','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 16:52:47',0,NULL,3,0,1,1,'\\ ','ihcfan\rWLAT008\r已入库'),(16467,589215272003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','jsevert09','joshsevert@gmail.com','joshs severt','3160 W Beaver St','jacksonville','FL','UNITED STATES','32254-3174','(904) 669-2813','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-22 17:05:31',0,NULL,3,1,1,1,'\\ ','jsevert09\r2000B  OEM'),(16468,886781790012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','marko123450_0','dsubara@trebnet.com','marko subara','457 the kingsway','toronto','ON','CANADA','m9a 3w3','(416) 937-5960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 17:12:08',0,NULL,3,1,2,1,'\\ ','marko123450_0\rOTGR002\r已入库'),(16469,800097481011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.49,'eastar4uk','dbkwk','steven@williams-knights.com','Steven Williams','10 Cuckmere Crescent','Crawley','West Sussex','UNITED KINGDOM','RH11 8DL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 17:51:28',0,NULL,3,1,3,1,'RA184574848CN\r ','dbkwk'),(16470,800099395011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','penge76','nyirkos_zoltan@freemail.hu','Zoltan Nyirkos','11 Northwood Gardens','Greenford','Middlesex','UNITED KINGDOM','UB6 0LE','07935869148','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 17:54:36',0,NULL,3,1,3,1,'RA184574882CN\r ','penge76\r英标'),(16471,649048034013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',5,'OTCN001',19.9,'eastar4','momelesha','elesha_howard@hotmail.com','Elesha Howard','27 Kathleen Court','Hamilton','ON','CANADA','L8T5B1','(905) 383-5205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 17:55:52',0,NULL,3,0,2,1,'\\ ','momelesha\rOTCN001\r已入库'),(16472,799918998002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','*duke!','duke_88_me@hotmail.com','ED DURANTE','220 Egypt Rd','NORRISTOWN','PA','UNITED STATES','19403-3402','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 18:18:42',0,NULL,3,1,1,1,' \r\\','*duke!'),(16473,886827636012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',4,'OTIN005',316,'eastar4','hilliard_l','lee.hilliard@canyons.edu','Lee Hilliard','26455 Rockwell Canyon Rd','Santa Clarita','CA','UNITED STATES','91355-1899','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 18:40:25',0,NULL,3,0,4,1,'YW867660803CN ','hilliard_l\rOTIN005\r已入库'),(16474,800125354011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',1,'TRTS001',6.99,'eastar4uk','donkubik','jvaqueroc@hotmail.com','Altaix Electrónica SA','Att. Juan A. Vaquero<br>Colquide 6, P2 3B','Las Rozas','Madrid','SPAIN','28230','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 18:41:23',0,NULL,3,1,2,1,'\\ ','donkubik'),(16475,596636332004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.59,'cnfaner','gurband211','gurband@bk.ru','Lada Gurevich','Hativat Yiftah 73/3','Karmiel','Israel','ISRAEL','21610','972527566010','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-22 18:57:23',0,NULL,3,1,2,1,'\\ ','gurband211'),(16476,796734094011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','shrike2214','jason.thompson1989@hotmail.co.uk','Jason Thompson','10 Halifax Place<br>Ryhope','Sunderland','Tyne and Wear','UNITED KINGDOM','SR2 0RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 19:04:20',0,NULL,3,1,3,1,'RA184574865CN\r ','shrike2214'),(16477,886850518012,220501842733,'2.1 Acer Travelmate 5110 5610 Bluetooth ModuleEDR+cable',1,'BTAC2108',12.39,'eastar4','music_express','protech_1@sbcglobal.net','Michael Scully','6714 Elmridge Dr','Flint','MI','UNITED STATES','48505-2480','(810) 787-0888','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 19:04:26',0,NULL,3,0,1,1,'\\ ','music_express\rBTAC2108\r已入库'),(16478,649119928013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','troyboy21','tmaas@kullysupply.com','Troy maas','14120 Orchard cir NE','Prior Lake','MN','UNITED STATES','55372-1343','(952) 292-4967','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 19:20:37',0,NULL,3,0,1,1,'\\ ','troyboy21\rGPSO004\r已入库'),(16479,886869745012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','herbo747','callymoore@hotmail.com','Cally Moore','Ace Transport<br>Winchester Industrial Estate, Winchester Avenue','Blaby','Leicestershire','UNITED KINGDOM','LE8 4GZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 19:32:53',0,NULL,3,1,3,1,'RA184577107CN\r ','herbo747\r英标'),(16480,649125763013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','dmbfox62','distrand@cisco.com','Diane Strand','115 Birch Hill Rd','York','ME','UNITED STATES','03909-5338','(508) 878-5841','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-22 19:49:57',0,NULL,3,0,1,1,'\\ ','dmbfox62\rHSNO019\r已入库'),(16481,886901158012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','johnve10','johnveitch10@hotmail.com','John Veitch','33 East Hemming Street','Letham','Angus','UNITED KINGDOM','DD8 2PT','07736233010','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 20:18:23',0,NULL,3,1,3,1,'RA184577040CN ','johnve10'),(16482,886879516012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','artfanica','artfani@gmail.com','Siavash Fani','2308 - 5793 Yonge ','Toronto','ON','CANADA','M2M 0A9','(647) 344-5335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 19:47:24',0,NULL,3,0,2,1,'\\ ','artfanica\rMOAP001\r已入库'),(16483,886907258012,220886272004,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',31.85,'eastar4uk','myopica','benjamespatterson@gmail.com','Pearce Delphin','PO Box 194','Essendon North','Victoria','AUSTRALIA','3041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 20:26:57',0,NULL,3,1,3,1,'RA184577795CN\r ','myopica\rHSSE011\r澳标'),(16484,886922208012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',37.85,'eastar4','loriot74','mikelorenz@schosemail.de','Nancy Ehrlich','Golben 4','Gutenborn OT Bergisdorf','','GERMANY','06712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 20:48:46',0,NULL,3,0,2,1,'\\ ','loriot74\rTRMX003*5\r已入库'),(16485,746580634007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','plohish','plohish013@yandex.ru','ALEKSEY BOLEZNOV','Glavmosstroja dom 8 -74','Moskva','','RUSSIAN FEDERATION','119618','(499)7925034','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 20:51:11',0,NULL,3,1,3,1,'RA184577124CN ','plohish\rRCLO003 \r欧标'),(16486,883115018012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','ntemos23','ntemosv@yahoo.gr','VASILIOS DEMOS','petrou boua 13','tripolis','arcadia','GREECE','22100','+306937354102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 22:37:58',0,NULL,3,0,2,1,'\\ ','ntemos23\rHSSE003\r已入库'),(16487,799933984011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',3,'HSUE002',59.97,'eastar4','oromirio','roman.opalko@gmail.com','Roman Opalko','Stroitelej 14/5','Kiev','','UKRAINE','02100','+380634153739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 22:52:19',0,NULL,3,0,3,1,'RA184574879CN\r ','oromirio\rHSUE002*3\r已入库'),(16488,800281459011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','faris8646','prgord@yahoo.com','Faris Gloz','Hvozdikova 2576/9','Prague 10','','CZECH REPUBLIC','10600','7735621833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 23:11:34',0,NULL,3,0,2,1,'\\ ','faris8646\rHBPH003\r已入库'),(16489,887000971012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','cbal40','alison22@gmail.com','Alison Smith','c/o Angiotech<br>1618 Station Street','Vancouver','BC','CANADA','V6A 1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 23:11:49',0,NULL,3,0,3,1,'RA184574851CN\r ','cbal40\rGLOT001\r兼容眼镜 \r已入库'),(16490,757230137001,110701383504,'NIB CBS High Pressure Portable Car Washer wash',1,'CAWA001',69.9,'buysia','rogeriomoreno','roberval.moreno@yahoo.com.br','rogerio moreno','R. dos Atuns, n°19, apt 11<br>Pq. Res. Aquarius','Sao Jose dos Campos','São Paulo','BRAZIL','12246-320','55012-39342254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 00:01:48',0,NULL,3,1,3,1,'RA184577084CN ','rogeriomoreno\rCAWA001'),(16491,739625988008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',1,'HSPL010',31.34,'au-buy','padgould','aspace@shaw.ca','Paul A Gould','4330 Gladstone Street','Vancouver','BC','CANADA','V5N 4Z5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 00:40:56',0,NULL,3,1,2,1,'\\ ','padgould'),(16492,739635911008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',3,'GLOT001',128.22,'au-buy','tookie_ding','mcoler@nycap.rr.com','Marsha L Coler','12 Arbor View Dr','Ballston Lake','NY','UNITED STATES','12019','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 01:17:45',0,NULL,3,1,1,1,'、 ','tookie_ding'),(16493,757251248001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','superiorhair1','faith991973@hotmail.com','Stuart Angus','201 Symonds Street<br>Newton','Auckland','Auckland','NEW ZEALAND','1010','006421858335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:18:20',0,NULL,3,1,17,0,NULL,'superiorhair1'),(16494,757251572001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','superiorhair1','faith991973@hotmail.com','Stuart Angus','201 Symonds Street<br>Newton','Auckland','Auckland','NEW ZEALAND','1010','006421858335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:19:28',0,NULL,3,1,3,1,'RA184577053CN\r ','superiorhair1\rBR3D007\r再发一个BR3D006'),(16495,596761865004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',6.99,'cnfaner','417carlj65','carljungm@yahoo.com','Carl  Jungmann Jr','974 SW 20th Rd','Liberal','MO','UNITED STATES','64762','(417) 843-3896','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 01:21:02',0,NULL,3,1,1,1,'\\ ','417carlj65'),(16496,887045592012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','angelo5134','angelo_5134@hotmail.com','Ângelo Martins','Rua Major Mousinho de Albuquerque, 32','Povoa de Santo Adrião - Odivelas','','PORTUGAL','2620 - 153','+351931831172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:22:19',0,NULL,3,0,2,1,'\\ ','angelo5134\rBTAC2005\r已入库'),(16497,887049105012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','ketrri','blendi@blendikraja.info','Blendi Kraja','Sheshi Rus','Shkodra','Albania','ALBANIA','4000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:29:29',0,NULL,3,0,2,1,'\\ ','ketrri\rOTCN004*10\r已入库'),(16498,800325629011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',56.99,'eastar4','bodek1','bkilar1@cogeco.ca','Bob Kilar','3193 Greenbough Cres.','Burlington','ON','CANADA','L7M 3A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:30:25',0,NULL,3,0,3,1,'RA184577098CN\r ','bodek1\rHSSE011\r已入库'),(16499,649245801013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','gerioct2008','geridelacruz2002@yahoo.com.hk','Geraldin Dela Cruz','Tarlac College of Agriculture<br>Camiling','default','Tarlac','PHILIPPINES','2306','9286698847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:31:06',0,NULL,3,0,2,1,'\\ ','gerioct2008\rOTCN001\r已入库'),(16500,800327672011,320678793994,'New  Motorola H500 Bluetooth Wireless Headset pink',1,'HSMO006',8.98,'eastar4uk','mher7771','jerimar2002@hotmail.com','Maria Hernandez','U2 Calle 14<br>Urb. Villa Linares','Vega Alta','Puerto Rico','PUERTO RICO','00692','(787) 515-6403','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 01:37:36',0,NULL,3,1,1,1,'\\ ','mher7771'),(16501,649254564013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','shirl2008.315','omashirley@yahoo.com','shirley vandewalker','7317 Dublin Street','Lima','NY','UNITED STATES','14485','(585) 519-1273','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 02:10:46',0,NULL,3,1,1,1,'\\ ','shirl2008.315\rGPSO004\r已入库'),(16502,739672485008,180755478681,'New Genuine Motorola H700 Bluetooth Wireless Headset',1,'HSMO011',15.99,'au-buy','argonsagas','duckpie@yahoo.com','Ron Martin','46 Weybridge Trail','Brampton','ON','CANADA','L6V 3Y3','(905) 454-1965','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 03:38:34',0,NULL,3,1,2,1,'\\ ','argonsagas'),(16503,8881322019542127,111,'HP media center only',1,'',0,'eastar4','mtran31512','mtran31512@yahoo.com','M. Tran','6 Mercure Place<br>Highland Park<br>bat. 7, esc. 24, 5 etage, apt. 458','Gold Coast','Queensland','AUSTRALIA','4211','0756673816',NULL,NULL,NULL,'2011-11-23 03:39:02',0,NULL,3,0,2,1,'\\ ',' 补货 只给HP media center\r'),(16504,8881322019542127,111,'HP media center only',1,'',0,'eastar4','mtran31512','mtran31512@yahoo.com','M. Tran','6 Mercure Place<br>Highland Park<br>bat. 7, esc. 24, 5 etage, apt. 458','Gold Coast','Queensland','AUSTRALIA','4211','0756673816',NULL,NULL,NULL,'2011-11-23 03:39:02',0,NULL,5,0,18,0,NULL,NULL),(16505,649279503013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','bigkiwishopa','lukew_w@hotmail.com','Luke Williams','159 pine hill road','Dunedin','','NEW ZEALAND','9010','0273149799','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 04:02:03',0,NULL,3,0,3,1,'RA184577155CN\r ','bigkiwishopa\rBAZA001\r已入库'),(16506,8881322023870756,111,'New Logitech Rechargeable battery L-LB2 1700mAh ',1,'BALO007',0,'eastar4','tabsaw','svanos49@gmail.com','Stephen Van Osdell','7182 Wethersfield Dr','Maineville','OH','UNITED STATES','45039-8870','(513) 207-5667',NULL,NULL,NULL,'2011-11-23 04:51:10',0,NULL,3,1,3,1,'RA184577115CN\r ',' 补货'),(16507,8881322023870756,111,'New Logitech Rechargeable battery L-LB2 1700mAh ',1,'BALO007',0,'eastar4','tabsaw','svanos49@gmail.com','Stephen Van Osdell','7182 Wethersfield Dr','Maineville','OH','UNITED STATES','45039-8870','(513) 207-5667',NULL,NULL,NULL,'2011-11-23 04:51:10',0,NULL,5,0,18,0,NULL,NULL),(16508,739687983008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','italiano690lba','antonellisl@yahoo.com','Loreto B Antonellis','26 Lenglen Rd','Newton','MA','UNITED STATES','02458-1421','(617) 642-5849','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 04:52:13',0,NULL,3,1,1,1,'\\ ','italiano690lba'),(16509,591393857003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',17.4,'cnfaner','warmaq','kareem.bracamonte@gmail.com','Kareem Bracamonte','13692 N Napoli Way','Oro Valley','AZ','UNITED STATES','85755-8559','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 05:18:05',0,NULL,3,1,1,1,'\\ ','warmaq'),(16510,800390629011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','rwoodrow2007','woodrow@talktalk.net','Mr R Woodrow','14<br>Connaught Circuit','Kellyville','New South Wales','AUSTRALIA','2155','0296291815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 05:47:26',0,NULL,3,0,2,1,'\\ ','rwoodrow2007\rOTCN002\r已入库'),(16511,887124343012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','123osmin','osmin773@hotmail.com','osmin hernandez','841 flagler dr','Gaithersburg','MD','UNITED STATES','20878-1957','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 06:03:57',0,NULL,3,0,1,1,'\\ ','123osmin\rGLOT001*2\r已入库\r兼容眼镜'),(16512,645623872013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',23.74,'eastar4','hmckenna10310','helen_stanley2004@hotmail.co.uk','Helen Stanley','5 LEONARDA DRIVE<br>ARANA HILLS','BRISBANE','Queensland','AUSTRALIA','4054','0416169431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 06:44:05',0,NULL,3,0,11,1,'\\ ','hmckenna10310\rUMOO010\r'),(16513,646620368013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','jasongatt05','jason.gatt@optusnet.com.au','Jason Gatt','3 Hughes<br>Avenue','Castle Hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 06:51:21',0,NULL,3,0,6,1,'EE491015975CN ','jasongatt05\rGLOT*4\r兼容眼镜'),(16514,649307936013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',23.74,'eastar4','sadoved','a-sadoved@rambler.ru','андрей садоведов','кобозева 29-74','екатеринбург','свердловская','RUSSIAN FEDERATION','620134','89638549812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 06:52:04',0,NULL,3,1,11,1,'\\','sadoved\rUMOO009'),(16515,596816749004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','stribman2031','allen7@nu-z.net','Allen Stribling','2031B Thomson Hwy','lincolnton','GA','UNITED STATES','30817-1749','(706) 359-5788','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 06:52:33',0,NULL,3,1,1,1,'\\ ','stribman2031'),(16516,591406952003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','wjsdkdudwhgusdn','hs77cho@gmail.com','HanSeok, Cho','5F, Doowon Bldg.,<br>503-5, Sinsa-dong, Gangnam-gu,','Seoul','','KOREA,REPUBLIC OF','135-746','82-10-5268-4468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 06:56:28',0,NULL,3,1,2,1,'\\ ','wjsdkdudwhgusdn'),(16517,887138041012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','abenusa','allen@benusa.com','Allen D. Benusa','425 Kay St SW','Hutchinson','MN','UNITED STATES','55350-2127','(320) 587-9749','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 07:09:48',0,NULL,3,0,1,1,'\\ ','abenusa\rWLIN016'),(16518,671994433005,150700951575,'#$3D Blu-Ray Disc AVATAR 3-D BD Region Free New Sealed ',1,'',69.99,'eusmile','dlp750','dlp750@comcast.net','Dennis L Paul','2207 Tamarack Dr','Champaign','IL','UNITED STATES','61821-6225','(217) 840-8538','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-23 07:17:34',0,NULL,3,0,1,1,'\\  ','dlp750\r已入库\rBR3D003\r'),(16519,8881322033106145,111,'Replaceable Shell for logitech MX AIR Laser Mouse',1,'SHLO001',0,'eastar4','vlad-boss','vbedenko@hotmail.com','test','test','test','','FRANCE','06300','0699195950',NULL,NULL,NULL,'2011-11-23 07:25:06',0,NULL,3,1,3,1,'RA184577169CN ',NULL),(16520,649313358013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','black_viki71','jiri.viktorin@volny.cz','Jiri Viktorin','Capkova 4','Brno','Morava','CZECH REPUBLIC','60200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 07:27:12',0,NULL,3,1,2,1,'\\','black_viki71\rCACN004'),(16521,887145267012,220682410000,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',22.9,'eastar4','kearts','clarkcarter@sbcglobal.net','Clark Carter','505 Lynne Dr','Grand Prairie','TX','UNITED STATES','75052-6437','(972) 264-6916','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 07:54:18',0,NULL,3,1,1,1,'\\  ','kearts\rHSSE003'),(16522,8881322034945364,111,'3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005',0,'eastar4uk','soupkitchen555','peter_shaw555@hotmail.com','Peter Shaw','1 Tutor Bank Drive<br>Newton-Le-Willows','Merseyside','Merseyside','UNITED KINGDOM','WA129LZ','07970127331',NULL,NULL,NULL,'2011-11-23 07:55:45',0,NULL,3,1,3,1,'RA184577257CN ','补发 '),(16523,800305372011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','encdpnew','pjnewcombe@gmail.com','Mr Paul Newcombe','35 Flat A<br>Finsbury Park Road','London','London','UNITED KINGDOM','N4 2JY','07877294626','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 08:47:33',0,NULL,3,1,3,1,'RA184577393CN\r ','encdpnew\rMOAP001'),(16524,887184426012,220826598356,'100% Brand New Original HP Wireless mobile 2.4G mouse ',1,'MOHP001',19.9,'eastar4','pistons_vinicius','vinicius_pistons@hotmail.com','Marcos Vinicius Abdulhak','Rua Coronel Cosme, 660 Qd:G Lt:9<br>setor: Leste Vila Nova','Goiânia','Goias / Brasil / Centro Oeste','BRAZIL','74635030','5506232619392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 10:05:01',0,NULL,3,1,2,1,'\\  ','pistons_vinicius'),(16525,8881322042937143,111,'IBM lenovo Ericsson F3507G 3G WWAN card FRU43Y6513',1,'WWOT002',0,'eastar4','rewinhanrahan10','rewinhanrahan@yahoo.com','Rewin Hanrahan','Jalan Kelapa Sawit X, Blok BG 04/03<br>Sektor 1B, Gading Serpong','Tangerang','Banten','INDONESIA','15326','(6221) 542-03956',NULL,NULL,NULL,'2011-11-23 10:08:57',0,NULL,3,1,2,1,'、 ',NULL),(16526,8881322044054403,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',0,'eastar4uk','mac111s','yannmac@yahoo.com','yann mccullough','62 city way','rochester','Kent','UNITED KINGDOM','me1 2ae','07770692641',NULL,NULL,NULL,'2011-11-23 10:27:34',0,NULL,3,1,3,1,'RA184577345CN\r ',' 一定挑成色好的测试  是为了撤差评用的  \rMOAP001\rRA184577345CN\r这票还没有包是为了让客户撤差评 先给他号的'),(16527,8881322044422315,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4uk','tasoulis4','tasoulis12@hotmail.com','Tassos Mousoulides','Block A, Hazlerigg-Rutland, Loughborough University','LOUGHBOROUGH','Leicestershire','UNITED KINGDOM','LE11 3TZ',' 07719160741',NULL,NULL,NULL,'2011-11-23 10:33:42',0,NULL,3,1,3,1,'RA184577402CN\r ','MOAP001 '),(16528,800463115011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','nil_nilich','nill@inbox.lv','Kirills Galikins','Klaipedas 106-1','Liepaja','Kurzeme','LATVIA','LV-3416','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 10:44:27',0,NULL,3,1,2,1,'\\  ','nil_nilich \r欧标'),(16529,649350370013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','pitisifu','ptitlaurent@hotmail.com','Laurent Van Den Berghe','KARDEX SA<br>Rue Saint-Denis 155','Bruxelles','','BELGIUM','1190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 10:53:11',0,NULL,3,1,2,1,'\\  ','pitisifu \r欧标'),(16530,800472822011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',36.99,'eastar4','d4433d','right083@gmail.com','MYEONGGU JO','1025-1 , Naei-dong , Miryang-si<br>NEWOPTICS LTD','Gyeongsangnam-do','Korea','KOREA,REPUBLIC OF','627-803','+82-10-2552-4884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 11:15:30',0,NULL,3,1,2,1,'、 ','d4433d'),(16531,649360867013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.96,'eastar4','mrts13','mrts13@yandex.ru','Victor Yarosh','Soyuzniy pr-t, 12-1-37','Moscow','','RUSSIAN FEDERATION','111396','+7 (495) 961-82-80','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-23 11:45:29',0,NULL,3,1,3,1,'RA184577362CN\r ','mrts13  \r欧标\r新的\rHSNO019'),(16532,8881322048967987,111,'jabra adapter +英标头',2,'',0,'eastar4uk','andream9901','englishpoohbear@hotmail.co.uk','Andrea Marsh','9 Ridsdale','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU7 6DF','07984172868',NULL,NULL,NULL,'2011-11-23 11:49:27',0,NULL,3,0,3,1,'RA184577481CN\r ',' 补货\r'),(16533,887226205012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','pyvizarro','pedro@yebenes.com','Pedro Yébenes Vizarro','Avda. España, 22 local derecha','Priego de Córdoba','Córdoba','SPAIN','14800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 12:16:03',0,NULL,3,1,2,1,'\\  ','pyvizarro'),(16534,800513297011,320787383550,'NEW Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',13.95,'eastar4uk','telfol','terence.foley3@ntlworld.com','terry foley','14 essex road','london','London','UNITED KINGDOM','E106HP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 13:24:26',0,NULL,3,1,3,1,'RA184577464CN\r ','telfol\rUM00004\r向日葵三折叠伞 '),(16535,596888097004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','leolaras','maxprotection.sonicwall@gmail.com','Maxprotection','7854 NW 62nd St<br>Capitol Freight','Miami','FL','UNITED STATES','33166-3539','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 13:26:02',0,NULL,3,1,1,1,'\\  ','leolaras'),(16536,800532837011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','nokkairc','tanadon@hotmail.com','Tanadon Ramasong','112/172 Airport villa soi 9<br>Phabath Road,Tumbol Phabath','Mueng','Lampang','THAILAND','52000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 14:22:30',0,NULL,3,1,2,1,'\\  ','nokkairc'),(16537,887291619012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','pierrebuck','rkskcamp@netzero.com','robert paquette','110 White Loaf Rd','southampton','MA','UNITED STATES','01073-9550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 15:10:08',0,NULL,3,1,1,1,'\\ ','pierrebuck'),(16538,799590900011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',71.98,'eastar4','dmitriy110370','dmitriy.levchenko2011@yandex.ru','Dmitriy Levchenko','Atarbekova 23-24','Krasnodar','Krasnodar territory','RUSSIAN FEDERATION','350062','+7(988)24-42-900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 15:34:05',0,NULL,3,1,3,1,'RA184577376CN\r ','dmitriy110370  \rCC00002\r再发一个  一共两个'),(16539,887308316012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','egopsycho','kucukayi@gmail.com','ilkay ayata','Buyukdere cd. No:185 Levent Kanyon AVM<br>TURKCELL STORE -  Besiktas','istanbul','','TURKEY','34295','+902123535030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 15:51:29',0,NULL,3,1,3,1,'RA184577549CN\r ','egopsycho  \rGLOT001*2\r兼容型3D眼镜 通用型'),(16540,649426800013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','alehousesinger','jhsnr@hotmail.com','CATHERINE HEWISH','ROSE COTTAGE','BELFORD','Northumberland','UNITED KINGDOM','NE707NG','01668213924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 15:54:44',0,NULL,3,1,2,1,'\\  ','alehousesinger  \r'),(16541,800596064011,320441946712,'2.1 HP NW8240 NW8440 Bluetooth Module EDR + cable',1,'BTHP2101',12.39,'eastar4','robertsrskudra','rskudra@inbox.lv','Roberts Skudra','Austrinu cels 21<br>Lielvarde','Latvia','Lielvarde','LATVIA','LV5070','+37126130415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 16:50:50',0,NULL,3,1,2,1,'\\  ','robertsrskudra\rHP 8pin 1.0 3cm'),(16542,887335802012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','alphatay','alpha_tay@hotmail.com','Alpha Tay','77, Jalan Berlian 1, Taman Berlian Biru,<br>86000 Kluang, Johor.','Kluang','Johor','MALAYSIA','86000','07-7722586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 16:53:58',0,NULL,3,1,2,1,'\\  ','alphatay'),(16543,887339022012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','dndoyebe','dndoyebe@hotmail.com','Dandois alexandre','Rue Vînave 143','Engis','St georges','BELGIUM','4480','0495719560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 16:54:13',0,NULL,3,1,2,1,'\\  ','dndoyebe'),(16544,887377859012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','superbratan','master_123@mail.ru','Vitaly Panchishin','135/1 Leninsky prosp., apt 759','Moscow','Moscow','RUSSIAN FEDERATION','117513','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 18:05:55',0,NULL,3,1,3,1,'RA184577243CN\r ','superbratan\rOTSO004*2'),(16545,887378354012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','blastyflankers','russellwhite@nl.rogers.com','russell white','207 lower road','outer cove','NL','CANADA','A1K 4B9','(709) 437-6916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 18:07:39',0,NULL,3,1,3,1,' RA184576251CN\r','blastyflankers\rGPS0003'),(16546,596988208004,140644120619,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip silver',1,'SHLO008',12.95,'cnfaner','ahurrle','adam@hurrle.com','Adam Hurrle','6033 Garbe Ave','Woodbury','MN','UNITED STATES','55125','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 18:42:09',0,NULL,3,1,1,1,'\\ ','ahurrle'),(16547,797759422002,120814231961,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','serhiychik','zadko1967@yahoo.com','Serhiy  Zadko','4175 W 59th St','Cleveland','OH','UNITED STATES','44144-1717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 19:16:10',0,NULL,3,1,1,1,'\\  ','serhiychik'),(16548,887427089012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','mcsn_2_aav','oconnors_liverpool@hotmail.com','Mary O\'Connor','8 Longridge Walk','LIVERPOOL','Merseyside','UNITED KINGDOM','L4 4QW','1512072146','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 19:21:09',0,NULL,3,1,3,1,'RA184577478CN\r ','mcsn_2_aav\rGLOT001*2\r兼容型3D眼镜 通用型'),(16549,797925961011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','hippiebryce','breezybleezy@yahoo.com','Bryce Myers','735 NE Grattan St','topeka','KS','UNITED STATES','66616-1236','(785) 845-5289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 19:36:32',0,NULL,3,1,1,1,'\\  ','hippiebryce\r兼容型3D眼镜 通用型'),(16550,887449095012,220815928819,'Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO009',25.9,'eastar4uk','shadowlarsen','shadow_jens@hotmail.com','Jens Bonde Larsen','Praestbrovej 109','Erslev','Denmark','DENMARK','7950','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 19:53:42',0,NULL,3,1,3,1,'RA184577416CN\r ','shadowlarsen\rMOLO009'),(16551,887456617012,220816376663,'4 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',135.99,'eastar4uk','zeberd1y','robert-sims@sky.com','robert sims','59 heol pant y deri','cardiff','Cardiff','UNITED KINGDOM','cf5 5pn','02920596991','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 20:04:01',0,NULL,3,1,6,1,'EE491015745CN ','zeberd1y\rGLSG001*4'),(16552,649566843013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',2,'HSNO023',27.98,'eastar4','talmihail','aronov_d@mail.ru','Daniel Aronov','kohen eli 24/28','Bat yam','','ISRAEL','59644','0507631952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 21:32:05',0,NULL,3,1,2,1,'\\  ','talmihail'),(16553,800558283002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','caridi48m','bona50@adam.com.au','Corrado Caridi.','20 Sunday Boulevard','Aldinga Beach','South Australia','AUSTRALIA','5173','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 22:04:30',0,NULL,3,1,2,1,'\\  ','caridi48m'),(16554,800771280011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.39,'eastar4','trp1492','tman1492@verizon.net','Timothy Penna','15 Tooker Pl','Springfield','NJ','UNITED STATES','07081-1707','(862) 849-0040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 21:53:46',0,NULL,3,1,1,1,'\\  ','trp1492      \racer 4pin1.25 6cm'),(16555,800823295011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','johnpongo1','johnsmyth998@btinternet.com','john smyth','4 millington drive','selsey','West Sussex','UNITED KINGDOM','po20 0ff','01243602542','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-24 00:08:47',0,NULL,3,1,3,1,'RA184577552CN\r ','johnpongo1\rGLSG001'),(16556,800824513011,320735056853,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',18.99,'eastar4uk','shepcar123','danny@drdiesel.co.uk','Daniel Shepcar','DR DIESEL<br>Shore Street','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9BR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-24 00:14:06',0,NULL,3,1,3,1,'RA184577380CN\r ','shepcar123\rOTGR006'),(16557,649626996013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','auswild','gezandal@hotmail.com','Gerry Pearce','22 Mathews Street','Davidson','New South Wales','AUSTRALIA','2085','0289649324','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 01:10:32',0,NULL,3,1,3,1,'RA184577314CN\r ','auswild\rLGAD001'),(16558,800850913011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','moorjunk','moorjunk@hotmail.com','Eric Schultz - KB8RJS','41134 Belvidere St','Harrison Township','MI','UNITED STATES','48045-1401','(586) 219-3147','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 01:58:20',0,NULL,3,1,1,1,'\\  ','moorjunk'),(16559,649644201013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','kfaust-2008','kfaust@new.rr.com','Kathryn Faust','2343 Hopf Ln','De Pere','WI','UNITED STATES','54115','(920) 339-8382','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 02:34:51',0,NULL,3,1,1,1,'\\  ','kfaust-2008'),(16560,649657695013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',23.74,'eastar4','willeden21','willeden@iprimus.com.au','Sarah Hollier','PO Box 18','Cranebrook','New South Wales','AUSTRALIA','2749','0247303029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 03:45:30',0,NULL,3,1,11,1,'\\','willeden21\rUM00009\r黑底七色边彩虹伞 '),(16561,887647875012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','ezwerling','ezwerling@aol.com','Eric M. Zwerling','309 Van Neste Rd','Flemington','NJ','UNITED STATES','08822-7064','(908) 237-0218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 03:59:54',0,NULL,3,1,1,1,'\\ ','ezwerling'),(16562,8881322108113410,111,'New Jabra BT250 BT 250 wireless Bluetooth Headset ',1,'HSJA002',0,'eastar4','ykb1224','yogesh.bhayana@gmail.com','Yogesh Bhayana','1440 Stone Pine Ter<br>Apt 230','Fremont','CA','UNITED STATES','94536-4093','(630) 696-8975',NULL,NULL,NULL,'2011-11-24 04:15:13',0,NULL,3,1,1,1,' LK020970110CN','补发全套 '),(16563,800896614011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','angchinhuat','chinhuat@gmail.com','Altera Corporation (M) Sdn Bhd (Attn: Ang Chin Huat, SWIP)','Plot 6, Bayan Lepas Technoplex<br>Medan Bayan Lepas','Bayan Lepas','Penang','MALAYSIA','11900','(016) 415-3385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 05:26:38',0,NULL,3,1,2,1,'\\','angchinhuat'),(16564,798070947011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',3,'GLOT006',80.97,'eastar4uk','pbarro8','pbarro@westnet.com.au','Paul Barentsen','20 Sir Donald Bradman Drive','Mile End','South Australia','AUSTRALIA','5031','610404137634','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 06:07:21',0,NULL,3,1,3,1,'RA184577606CN ','pbarro8\rGLOT006\r兼容型3D眼镜  Korea TV专用'),(16565,597160839004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.33,'cnfaner','bhmehanna1965','bhmehanna@hotmail.com','hilal daher','6336 Williamson St','dearborn','MI','UNITED STATES','48126','(313) 582-9581','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 06:24:42',0,NULL,3,1,1,1,'\\ ','bhmehanna1965'),(16566,747725742007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','nictorious57','nictorious@hotmail.fr','Nicolas JACQUES','11 rue de l\'étang','Florange','Lorraine','FRANCE','57190','0627720845','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 06:50:13',0,NULL,3,1,2,1,'\\ ','nictorious57'),(16567,649690568013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','fmpr7342','afiripis@westnet.com.au','Arthur Firipis','PO Box 616','Belmont','Victoria','AUSTRALIA','3216','0352444469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 07:36:10',0,NULL,3,1,6,1,'EE491015723CN ','fmpr7342  通用型'),(16568,800931865011,320786773775,'New iTech Clip II mini Multipoint Bluetooth Headset white',1,'HSIT003',21.99,'eastar4uk','kobym','kobymillo@012.net.il','Koby Millo','14 Bnei-Moshe street','Tel-Aviv','','ISRAEL','62308','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 08:25:58',0,NULL,3,1,2,1,'、 ','kobym'),(16569,747747958007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','duckcatchicken','babaks1@yahoo.com','Babak Shahafar','3 Churchill Ave','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 08:35:54',0,NULL,3,1,2,1,'、 ','duckcatchicken\r澳标'),(16570,800937077011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','davet2234','davidgturner@sky.com','David Turner','Mr Fothergills Seeds<br>Gazeley Road','Kentford','Suffolk','UNITED KINGDOM','CB8 7QB','01638751161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 08:47:37',0,NULL,3,1,2,1,'、\r ','davet2234   英标'),(16571,800942850011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','rvb-glas','rvb@online.ru','Roman Bazalevsky','Sosnovaya 2-1, 42','Podolsk','Moscow region','RUSSIAN FEDERATION','142108','+7 903 7901366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 09:13:12',0,NULL,3,1,2,1,'\\ ','rvb-glas'),(16572,747768703007,170735464388,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',24.99,'au-buy','luckyturtle69','luckyturtle@optusnet.com.au','hamish barr','post restante<br>sawtell post office','sawtell','New South Wales','AUSTRALIA','2452','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 10:00:45',0,NULL,3,1,11,1,'、 ','luckyturtle69'),(16573,740229950008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'au-buy','passy12','davidyunjiang@gmail.com','David Pass','63 Garro St','Sunnybank Hills','Queensland','AUSTRALIA','4109','0737356057','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 10:17:39',0,NULL,3,1,2,1,'\\ ','passy12'),(16574,8881322130017427,111,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',0,'eastar4uk','2011taxibob173','taxibob173@yahoo.com','robert dixon','17 streamside close','coventry','West Midlands','UNITED KINGDOM','cv59ff','02476633708',NULL,NULL,NULL,'2011-11-24 10:20:17',0,NULL,3,1,3,1,'RA184577739CN\r ',' 英标 HSJA010'),(16575,800992187011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','mschumann0','damayor00@hotmail.com','Michael Schumann','934 Peach Hill Ln<br>Apt 507','Chesterfield','MO','UNITED STATES','63017','(636) 532-7069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 12:07:01',0,NULL,3,1,1,1,'\\ ','mschumann0'),(16576,747813006007,170735464359,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'au-buy','peeweekathi','katerinasonline@optusnet.com.au','Katerina Anastassiou','P.O. Box 224','South Morang','Victoria','AUSTRALIA','3752','0394088889','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 12:40:49',0,NULL,3,1,11,1,'、 ','peeweekathi'),(16577,887803033012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','4seasonstech','opaba_3@hotmail.com','Primitivo Abapo Jr.','2039 Mackenzie Rd','Toms River','NJ','UNITED STATES','08755-2342','(732) 597-5566','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 13:50:51',0,NULL,3,1,1,1,'\\ ','4seasonstech'),(16578,887806286012,220885115378,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',21.99,'eastar4uk','jakeygordon','jakegordon_123@hotmail.com','jake gordon','12 hopgarden close<br>lamberhurst','tunbridge wells','Kent','UNITED KINGDOM','tn3 8dy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-24 13:59:57',0,NULL,3,1,3,1,'RA184577756CN\r ','jakeygordon\r英标'),(16579,757925147001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','ddm07','kindofdarkblue@hotmail.com','Ran Assaf','227 Church St<br>Apt 6G','New Haven','CT','UNITED STATES','06510-1825','(203) 570-2897','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 14:55:17',0,NULL,3,1,1,1,'\\ ','ddm07'),(16580,801057065011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','nick-spencer','nicks@tcp.co.uk','Nick Spencer','6a Courtland Gardens<br>Bassett','Southampton','Hampshire','UNITED KINGDOM','SO16 3PP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-24 15:24:03',0,NULL,3,1,3,1,'RA184577671CN\r ','nick-spencer'),(16581,887847437012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','friceberg','ficeberg@yahoo.com','Frank Iceberg','3430 Sumac Ct<br>Apt 304','Jackson','MI','UNITED STATES','49202-1277','(517) 783-5016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 15:44:14',0,NULL,3,1,1,1,'\\ ','friceberg'),(16582,887848232012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','willz32','willzz32@googlemail.com','matt williams','48 dacer close<br>stirchley','birmingham','West Midlands','UNITED KINGDOM','b30 3bz','07852913308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 15:48:38',0,NULL,3,1,2,1,'\\ ','willz32'),(16583,801068458011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','rustam_ranger','rustam_hp@mail.ru','Rustam Hasanov','Xudu Mammadov street 20, Apartment 1C, Flat 19','Baku','','AZERBAIJAN','az1123','+994505173962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 15:52:04',0,NULL,3,1,2,1,'\\  ','rustam_ranger'),(16584,798909594011,320394913302,'Acer Aspire 4520 4520G Bluetooth Module EDR 2.0+cable',1,'BTAC2014',9.88,'eastar4','jkbelts-ca','frank_hqp@hotmail.com','qiupeng he','332 St. Urbain Drive','Woodbridge','ON','CANADA','L4H0M3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 16:16:27',0,NULL,3,1,2,1,'\\ ','jkbelts-ca'),(16585,591869470003,130592181875,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.9,'cnfaner','maryjo1977','jmelectronic@yahoo.com','Mary Jo Klink','1231 National Hwy','LaVale','MD','UNITED STATES','21502-7602','(301) 729-8110','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 16:47:31',0,NULL,3,1,1,1,'\\ ','maryjo1977'),(16586,649820119013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','fgilles3280bch','sonia_gillespie@comcast.net','sonia gillespie','7783 Glade Ct','Manassas','VA','UNITED STATES','20112','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 17:03:31',0,NULL,3,1,1,1,'\\ ','fgilles3280bch'),(16587,649832724013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','vmbor','mixtline@gmail.com','Alexey Ovseyenko','Sadovaya 35-30','Ivanovo','Ivanovskaya obl','RUSSIAN FEDERATION','153012','9061073727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 17:39:14',0,NULL,3,1,2,1,'\\ ','vmbor'),(16588,740378188008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',55.09,'au-buy','tbsabo','tbsabo@netbank.hu','Tibor Szabo','Rez u. 4.','Szeged','','HUNGARY','6727','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 17:42:48',0,NULL,3,1,3,1,'RA184577668CN ','tbsabo\rGLOT005'),(16589,801148283011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',50,'TRMX002',378.5,'eastar4','hypernetwork','ciscocampus.com@gmail.com','2Run Network LLC','81 Division Ave','Garfield','NJ','UNITED STATES','07026-3621','(973) 341-5990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 18:42:39',0,NULL,3,1,4,1,'YW867739796CN ','hypernetwork'),(16590,649859318013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','affmaster','affmaster91@gmail.com','Rizka Dwi Utami','Jl Kaliwaru 73B #Apt 1st Floor','Sleman','Yogyakarta Special Region','INDONESIA','55283','628566463232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 18:50:01',0,NULL,5,0,18,0,NULL,'affmaster\rpaypal 有问题\r'),(16591,887941774012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','raikijs2','raikijs2@inbox.lv','Salvis Skurjats','Aldaunas-6','Jekabpils','','LATVIA','LV-5201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 18:51:43',0,NULL,3,1,2,1,'\\ ','raikijs2'),(16592,887947136012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','perosambol','peter.sambol@gmail.com','peter sambol','pokopaliska 4','ljubljana','','SLOVENIA','1000','38640643436','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 19:00:56',0,NULL,3,1,2,1,'\\ ','perosambol'),(16593,887979777012,220815931272,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',36.99,'eastar4uk','horse4121','chase4121@msn.com','jim gately','4121 Washington St','boston','MA','UNITED STATES','02131-1714','(617) 279-7278','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 19:52:58',0,NULL,3,1,1,1,'\\ ','horse4121\r'),(16594,801205126011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','sn0wcr4sh00','coldenlight@yahoo.com','Andrew Wong','138 Berlioz, Nuns\' Island<br>Verdun','Montreal','QC','CANADA','H3E 1K5','(514) 761-3663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 20:23:46',0,NULL,3,1,2,1,'\\ ','sn0wcr4sh00'),(16595,888027931012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','dimitecon','dimitecon@aol.com','Dimitrios Economides','605 Burcham Dr','East Lansing','MI','UNITED STATES','48823-2746','(517) 351-3605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 21:13:25',0,NULL,3,1,1,1,'\\ ','dimitecon\r兼容眼镜'),(16596,888032231012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','magshen','dmhendrick@gibtelecom.net','maggie hendrick','13 amsterdam court,<br>harbour views','gibraltar','europe','GIBRALTAR','gi','+35058009320','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 21:23:07',0,NULL,3,1,3,1,'RA184577699CN ','magshen\rLGAD001'),(16597,801015131002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','erinevans123','erin@contactcom.org','Erin Thorndycraft C/O UPS Stor','2981 Ford Street Ext<br>Gateway Shp. Cntr.','Ogdensburg','NY','UNITED STATES','13669-3474','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 21:44:28',0,NULL,3,1,3,1,'RA184577742CN\r ','erinevans123\rBR3D002\r修改地址\rErin Thorndycraft\r413 King Street West\rBrockv\rille, Ontario\rCanada \rK6V3S9\r'),(16598,649942697013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','nieltete','maria.callejas@exel.com','MARIA CALLEJAS','155 Highpoint Dr<br>Apt 103','ROMEOVILLE','IL','UNITED STATES','60446-3828','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 22:23:55',0,NULL,3,1,1,1,'\\ ','nieltete'),(16599,888032382012,220825062314,'New 3.0 Bluetooth BCM92070 Module+cable Asus N43 N73',1,'BTAS3001',19.98,'eastar4','hyttjo','jouni.hyttinen@wippies.fi','Jouni  Hyttinen','leikosaarentie 25 a 9','helsinki','uusimaa','FINLAND','00990','+358505250373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 22:28:02',0,NULL,3,1,2,1,'\\ ','hyttjo'),(16600,740527220008,180755522194,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',1,'GLOT006*2',107.99,'au-buy','alexanderkrokos','alex.krokos@hotmail.com','Alexandros Krokos','Dodonis 38','Athens','','GREECE','10444','00306932764131','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 22:47:03',0,NULL,3,1,3,1,'RA184577725CN ','alexanderkrokos\rGLOT006*2'),(16601,649947640013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',31.97,'eastar4','rrreric','michel.strogoff@free.fr','Eric Robert','8-10, avenue Victor Hugo','Vanves','Île-de-France','FRANCE','92170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 22:51:51',0,NULL,3,1,2,1,'\\ ','rrreric\r加一个半高卡架子'),(16602,801274923011,320707682465,'NEW GENUINE NOKIA BH-100 BLUETOOTH HEADSET BH 100',1,'HSNO030',11.99,'eastar4','shikogem','mohammadhamdyy@yahoo.com','mohamed hamdy elsayed','Doha Qatar POBOX:32457<br>Umgowailena','Doha','Doha','QATAR','32457','(974) 774-3045 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 22:53:46',0,NULL,3,1,2,1,'\\ ','shikogem\r黑色的'),(16603,801274384011,320723268329,'New Genuine Sony Ericsson HBH-DS220 Bluetooth  Headset',1,'HSSE006',65.95,'eastar4','pabloboliveira','taquaraman@gmail.com','Pablo Oliveira','Av. Julio de Castilhos 756 ap 202','Veranópolis','Rio Grande do Sul','BRAZIL','95330000','54 9989 3732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 22:59:08',0,NULL,3,1,3,1,'RA117780008CN ','pabloboliveira'),(16604,597423134004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','mast3re','er_st@hotmail.com','Erik  Stevenson','514 N Oakland Ave','Pasadena','CA','UNITED STATES','91101-1112','(626) 316-4972','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 23:44:57',0,NULL,3,1,1,1,'\\ ','mast3re'),(16605,888097039012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','kpb7777','ancienwines@comcast.net','Kenneth Bernards','1160 2nd Ave','Napa','CA','UNITED STATES','94558-3955','(707) 255-3908','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 23:56:03',0,NULL,3,1,1,1,'\\ ','kpb7777'),(16606,649969074013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','raskull71','tiger35@att.net','angel west','3321 batley dr','tuttle','OK','UNITED STATES','73089-8739','(405) 381-9852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 00:18:09',0,NULL,3,1,1,1,'\\ ','raskull71\r兼容眼镜'),(16607,801084462002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','monkeyfruit10','sandwichdog@y7mail.com','shane giusa','73 colchester cres','kirwan','Queensland','AUSTRALIA','4817','0406628667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 01:11:50',0,NULL,3,1,2,1,'\\ ','monkeyfruit10'),(16608,888120015012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','jrhopper','jrhopper@pasty.com','Jon Hopper','46 Farnsworth St','Hamden','CT','UNITED STATES','06517-3325','(906) 869-6805','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 01:19:17',0,NULL,3,1,1,1,'\\ ','jrhopper'),(16609,649982387013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.39,'eastar4','fonguy1961','fonguy961@aol.com','Steve Conaway','6941 Rosemary Ln','Cincinnati','OH','UNITED STATES','45236-4231','(513) 791-6708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 01:26:31',0,NULL,3,1,1,1,'\\ ','fonguy1961'),(16610,597443938004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','paulrobertbland','paul.bland@exemail.com.au','Paul Bland','Pratt<br>30 Industry Court','Brisbane','Queensland','AUSTRALIA','4009','0408600688','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-25 01:54:47',0,NULL,3,1,3,1,'RA184577685CN\r ','paulrobertbland\rWWOT003+ANCN001'),(16611,888129385012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','djss777','dsutacha777@yahoo.com.au','Octavio Montoya','1/409 Forest Road<br>Penshurst','Sydney','New South Wales','AUSTRALIA','2222','0295792125','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 01:56:09',0,NULL,3,1,2,1,'\\ ','djss777'),(16612,8881322188013659,111,'210TS',30,'TRTS001',250,'eastar4','sayavongs','dennis_sys@hotmail.com','Mr. Khampasith Thavevongsa','P.O Box: 9003','Vientiane','','LAOS PDR','','8582055503919',NULL,NULL,NULL,'2011-11-25 02:26:53',0,NULL,3,1,6,1,'EE491015737CN ',' EMS 运费25美金'),(16613,8881322188741462,111,'New lady Piano Rain Sun Parasol Stick Umbrella purple',1,'UM00010',45,'eastar4','Inga Kalpina','zeltacirpa@inbox.lv','Inga Kalpina','Misas Kudra 14-11','Vecumnieki','Bauska','LATVIA','LV3906','',NULL,NULL,NULL,'2011-11-25 02:39:01',0,NULL,3,1,3,1,'RA184577711CN ','UM00010紫色的   再发一个UM00011 New lady lace trim sun/rain stick Umbrella brown '),(16614,8881322188853551,111,'New lady lace trim sun/rain stick Umbrella brown',1,'UM00011',0,'eastar4','Inga Kalpina','zeltacirpa@inbox.lv','Inga Kalpina','Misas Kudra 14-11','Vecumnieki','Bauska','LATVIA','LV3906','',NULL,NULL,NULL,'2011-11-25 02:40:53',0,NULL,8,1,17,0,NULL,NULL),(16615,8881322189889733,111,'930 白电池',1,'BALO002',0,'eastar4','jada60','tril4@rogers.com','David Shields','21193 Clubside Dr<br>Apt B','Boca Raton','FL','UNITED STATES','33434-4741','',NULL,NULL,NULL,'2011-11-25 02:58:09',0,NULL,3,1,1,1,' LK071773140CN',' 补发 '),(16616,797926384011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','bufflehead','christiandoucet@gmail.com','Christian Doucet','115 Bufflehead Way','Ottawa','ON','CANADA','K1T0G3','(613) 454-8115 ext.: 701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 02:58:40',0,NULL,3,1,2,1,'、 ','bufflehead'),(16617,8881322190374564,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','basharania','medadc@gmail.com','Meidad Cohen','test','test','Israel','ISRAEL','96268','+972544602213',NULL,NULL,NULL,'2011-11-25 03:06:14',0,NULL,5,1,18,0,' ',NULL),(16618,8881322191673575,111,'Grohe hand shower',1,'OTGR001',0,'eastar4','bombers18','hckay@optusnet.com.au','harry kay','c/o Goodman Law<br>GPO Box 1674','Canberra City','Australian Capital Territory','AUSTRALIA','2601','',NULL,NULL,NULL,'2011-11-25 03:27:53',0,NULL,3,1,3,1,'RA184577827CN ',' 看看底部灰色部分是否好'),(16619,748149391007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','l_masi*','l_masi@hotmail.com','Lucia Masi','55 Penrose Drive','DAPTO','New South Wales','AUSTRALIA','2530','0401901707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-25 03:32:56',0,NULL,3,1,11,1,'、 ','l_masi*   '),(16620,801345667011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',18.99,'eastar4','flyingwhales87','allsun8@gmail.com','Allsun Campbell','198 Markham Street<br>Basement','Toronto','ON','CANADA','M6J2G6','(416) 660-2870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 03:33:10',0,NULL,3,1,11,1,'、 ','flyingwhales87'),(16621,650006862013,230630064682,'4 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',273.99,'eastar4','philipcathy','ptm@justice.com','Catherine Mullen','14 Lansdowne St','Penshurst','New South Wales','AUSTRALIA','2222','0295804890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 03:39:31',0,NULL,3,1,6,1,'EE491015706CN ','philipcathy'),(16622,8881322194131850,111,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',0,'cnfaner','ladyonthego','ladyonthego@yahoo.com','cheryl wilson','2326 63rd ave','oakland','CA','UNITED STATES','94605-1431','(510) 568-8470',NULL,NULL,NULL,'2011-11-25 04:08:51',0,NULL,3,1,1,1,' LK106750172CN ','ladyonthego \r补货  只补耳机'),(16623,650023227013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','genoz9guy','gene.deroode@sbcglobal.net','Eugene Deroode','48 Little Brook Rd','New Hartford','CT','UNITED STATES','06057-4126','(860) 379-3539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 05:22:08',0,NULL,3,1,1,1,'、 ','genoz9guy'),(16624,888178079012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','ownerless','onlyjob@gmail.com','Dmitry Smirnov','Unit 63, 61-65 Glencoe Street','Sutherland','New South Wales','AUSTRALIA','2232','61415820374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 05:26:19',0,NULL,3,1,2,1,'\\ ','ownerless'),(16625,748174239007,170728982479,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'au-buy','1357bl','bluelakebuilding@dodo.com.au','Bronte Lockwood','39 Montebello Drive','Mount Gambier','South Australia','AUSTRALIA','5290','0412799486','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-25 05:54:18',0,NULL,3,1,3,1,'RA184577844CN ','1357bl'),(16626,650030241013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jun2ykr','junykr@hanmail.net','konghwa Jang','munjidong 104-7 KOSHA, yousunggu','Daejeon city','Daejeon city','KOREA,REPUBLIC OF','305-380','821045906691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 06:11:08',0,NULL,3,1,2,1,'、 ','jun2ykr'),(16627,8881322204099782,111,'GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO031',33.99,'aliexpress','1005425325','tres.costa@gmail.com','Edward Costa','7270 Lakeview Dr. E. side door please','Mobile','Alabama','UNITED STATES	','36695','+251 281 8737',NULL,NULL,NULL,'2011-11-25 06:54:59',0,NULL,3,1,3,1,'RA184546833CN\r\r ','第一次买个旧的（RA117764067CN），坏了; 补了$5.49(1005985917)后，再给他补发个新的（HSNO019--已入库）！'),(16628,748185542007,170728921737,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',55.99,'au-buy','quiksilver2780','sandra.0980@hotmail.com','sandra robitaille','162 lanthier','ste-sophie','QC','CANADA','j5j 2l8','(450) 504-1412','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 06:57:47',0,NULL,3,1,3,1,'RA184577835CN ','quiksilver2780\rHSSE011'),(16629,740632335008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','trammor251','trammor25@yahoo.com.au','Allision Elrdidge','144 neill street','harden','New South Wales','AUSTRALIA','2587','0263865129','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-25 07:02:14',0,NULL,3,1,3,1,'RA117779999CN ','trammor251\rGLOT001'),(16630,801390527011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','abodyabdullah','abdullah-alomari@hotmail.com','abdullah alomari','3718 Willow Pass Rd<br>Apt 102','concord','CA','UNITED STATES','94519-1029','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 07:29:24',0,NULL,3,1,1,1,'、 ','abodyabdullah'),(16631,888195813012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','kayptkd','kaytkd@hotmail.co.uk','Kayleigh Parker','91 Woodlands Road<br>Charfield','Wotton Under Edge','Gloucestershire','UNITED KINGDOM','GL12 8LT','07891403535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 07:31:52',0,NULL,3,1,3,1,'RA184577858CN ','kayptkd\rHSSE005 \r英标'),(16632,801399737011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','panchish','poncalo@mail.ru','Pavel Loginov','Koroleva<br>2-12','Peresvet','moskovskaja oblast\'','RUSSIAN FEDERATION','141320','+79852335227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 08:10:26',0,NULL,3,1,3,1,'RA117779971CN ','panchish'),(16633,801409342011,320730088816,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',159.99,'eastar4uk','kaleo666','owenbrunning@googlemail.com','owen brunning','pelistry<br>hill green road','stockbury','Kent','UNITED KINGDOM','me9 7un','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 08:49:51',0,NULL,3,1,4,1,'YW867660943CN ','kaleo666'),(16634,650051974013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','shironr123','shiron_ranasinghe@yahoo.com','Shiron Ranasinghe','No:8/2,St.Stephen Mawatha,<br>Rajagiriya Road,','Rajagiriya','Western Province','SRI LANKA','094','94112864876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 08:54:29',0,NULL,3,0,3,1,'RA117779985CN ','shironr123'),(16635,592056496003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','hijinx1975','cskelley1@gmail.com','Christopher Kelley','450 Piedmont Ave NE<br>Apt 314','Atlanta','GA','UNITED STATES','30308-3428','(864) 275-0027','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-25 09:05:46',0,NULL,3,1,1,1,'、 ','hijinx1975'),(16636,675095847010,200679221834,'Samsung 3D TV Glasses SSG-3500CR  Active 2011 new  for samsung 3d led tv ',10,'',518,'dcsamsungmall','buysia','ebay@buysia.com','Bo Fang','Rm.104, Building 124,Nanhuxiyuan, Wangjing','BEI JING','北京','CHINA','100102','+86 13911173424','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-25 09:33:45',0,NULL,5,0,18,0,NULL,'buysia'),(16637,801422944011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','sakellaris1432','stelios.sakellaris@yahoo.gr','ΣΤΥΛΙΑΝΟΣ ΣΑΚΕΛΛΑΡΗΣ','Μ. ΑΝΔΡΟΝΙΚΟΥ 2, ΣΥΚΙΕΣ','ΘΕΣΣΑΛΟΝΙΚΗ','προεπιλογή','GREECE','56626','+302310621115','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 09:47:16',0,NULL,3,1,3,1,'RA184576849CN\r','sakellaris1432\rOTSO002'),(16638,650068013013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','tason30','tason@bigmir.net','VITALII ONYSCHENKO','61a/256, ul. Bal\'zaka Onore','Kiev','','UKRAINE','02232','+380634669576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 09:59:59',0,NULL,3,1,2,1,'\\  ','tason30'),(16639,740680027008,180730162648,'GENUINE Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',31.34,'au-buy','mp**01','paul.r.millar@nab.com.au','Paul Millar','29 COLLIS STREET','BRIGHTON EAST','Victoria','AUSTRALIA','3187','0414448504','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-25 10:28:27',0,NULL,3,1,2,1,'\\  ','mp**01\r澳标'),(16640,801438507011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','venki_kc','hrvojevencl@gmail.com','Hrvoje Vencl','T. Ujevica 31','Durdevac','HR','CROATIA','48350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 10:42:58',0,NULL,3,1,2,1,'、','venki_kc'),(16641,888262201012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','darkangel11111979','skazovatov.aleksandr@gmail.com','Aleksandr Skazovatov','ul. Bogomolca 2-51','Volgograd','OBl Volgogradskaya','RUSSIAN FEDERATION','400125','+79608731740','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 11:02:20',0,NULL,3,1,2,1,'\\  ','darkangel11111979'),(16642,801455685011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','tjeerdjelle','tj.dehaan@telfort.nl','Tjeerd de Haan','Tuinstraat 68','GRONINGEN','','NETHERLANDS','9711VE','06 45778289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:38:24',0,NULL,3,1,3,1,' RA184576163CN\r','tjeerdjelle'),(16643,888298204012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.39,'eastar4uk','boo_boo_kitty_fcuk','boo_boo_kitty_fcuk6969@hotmail.com','Edward Robinson','39 Poplar Drive','Brigg','North Lincolnshire','UNITED KINGDOM','DN20 8PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 12:53:38',0,NULL,3,1,3,1,' RA184576282CN\r','boo_boo_kitty_fcuk\rCALO001'),(16644,888310562012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.99,'eastar4','keng3','kgorski@yahoo.com','Kenneth A. Gorski','517 Granada Ave','El Paso','TX','UNITED STATES','79912-5123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 13:28:17',0,NULL,3,1,1,1,'\\ ','keng3'),(16645,758350484001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','lmblackmore','leeblackmore@gmail.com','Lee Blackmore','Bow Cottage, Abbotskerswell','Newton Abbot','Devon','UNITED KINGDOM','TQ12 5NL','01626363648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 13:57:42',0,NULL,3,1,2,1,'\\','lmblackmore'),(16646,740750782008,180699061189,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'au-buy','virtual-elements','jmadjose@hotmail.com','Jose M. Lozano Rodero','Avenida de Castilla, 29, 7º-A','Gijon','Asturias','SPAIN','33203','620338210','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 14:25:37',0,NULL,3,1,3,1,'RA184576747CN\r','virtual-elements\rGLSG001'),(16647,650124380013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','roi_besor','roi_besor@yahoo.com','Roi Bsor','Migdal David 23 apartment 72','Modi\'in','','ISRAEL','71702','972-52-8484803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 14:10:59',0,NULL,3,1,3,1,'RA184576883CN\r ','roi_besor'),(16648,597037324004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','rhersey','rhersey@patlq.com','Robert Hersey','20 Andre Montpetit','Coteau-du-Lac','QC','CANADA','J0P 1B0','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-25 14:43:15',0,NULL,3,1,2,1,'\\','rhersey'),(16649,650138025013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','for2dogs','g02it@aol.com','david milligan','6700 Bayberry Dr','oklahoma city','OK','UNITED STATES','73162-6601','(405) 722-0242','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 15:00:46',0,NULL,3,1,3,1,'RA184576526CN\r','for2dogs'),(16650,597582482004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','directangent','ibrightly@gmail.com','Ivan Brightly','20 Sunset Trl','Croton on Hudson','NY','UNITED STATES','10520-2128','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-25 15:03:56',0,NULL,3,1,1,1,'\\ ','directangent'),(16651,650146480013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','vanburen1mark','lexusmvb@aol.com','mark vanburen','21541 Windham Run','estero','FL','UNITED STATES','33928-3255','(239) 825-3942','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 15:29:01',0,NULL,3,1,3,1,' RA184576591CN\r','vanburen1mark'),(16652,801542797011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','auntsylbie','misannthorpe@googlemail.com','Kazuyo Horie','127 Hatfeild Mead','Morden','Surrey','UNITED KINGDOM','SM4 5PG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 15:44:25',0,NULL,3,1,3,1,' RA184576115CN\r','auntsylbie\rMOAP001'),(16653,799069646002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','remix.format','randyvarona18@gmail.com','Randy Varona','501 E 23rd St','Hialeah','FL','UNITED STATES','33013-3909','(786) 683-6669','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 16:01:31',0,NULL,3,1,1,1,'\\ ','remix.format'),(16654,800900155002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','alfonsor1975','alroman75@yahoo.com','ALFONSO  ROMAN','450 e 4 th st<br>Apt  425','Santa Ana','CA','UNITED STATES','92701','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 16:19:12',0,NULL,3,1,1,1,'\\ ','alfonsor1975'),(16655,801561546011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','basepickers','basepickersebay@gmail.com','Jesse Reynolds c/o Jim Wiegand','200 Forge Rd','Calverton','NY','UNITED STATES','11933-1604','(802) 355-3414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 16:26:44',0,NULL,3,1,1,1,'\\ ','basepickers'),(16656,888395056012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','danutzel29','stoenac1@yahoo.com','Stoenac Mircea Daniel','Kranveien 21 H0201','Oslo','Norway','NORWAY','0684','(47)92662473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 16:50:21',0,NULL,3,1,3,1,' RA184576676CN\r','danutzel29'),(16657,650178002013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','dmitryo1','ic3ob@hotmail.com','Dmitry Obukhov','8502 Summerdale Rd<br>Apt 6','San Diego','CA','UNITED STATES','92126-5423','(415) 577-9450','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 17:01:54',0,NULL,3,1,1,1,'\\ ','dmitryo1'),(16658,592205399003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',17.4,'cnfaner','amnbowser','amnbowser@yahoo.com','Matthew','127 Fairway dr','Crestview','FL','UNITED STATES','32536-8410','(785) 207-2852','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-25 17:18:47',0,NULL,3,1,1,1,'\\ ','amnbowser'),(16659,801347029002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','bennanabred','sillybennabill@gmail.com','Benson Lee','15 Lyra Starway','Willowdale','ON','CANADA','M2J 1P1','(416) 495-7956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 17:21:57',0,NULL,3,1,2,1,'\\  ','bennanabred'),(16660,801584863011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',3,'HSJA011',85.5,'eastar4','georges1986lebanon','nassaly@hotmail.com','georges assaly','489 63 avenue','laval','QC','CANADA','h7v2h5','(450) 680-1414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 17:16:07',0,NULL,3,1,3,1,' RA184576662CN\r','georges1986lebanon'),(16661,888439520012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','therese.soderberg','theresia.soderberg@gmail.com','Therese Andrén','Fagerövägen 21B','Falun','','SWEDEN','S-79153','+46762956060','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 18:07:11',0,NULL,3,1,2,1,'\\  ','therese.soderberg'),(16662,650209952013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',23.74,'eastar4','lilidin','lilishaked@gmail.com','lili shaked','Shimon Ben-Zvi 36 Apartment 58','givatayim','','ISRAEL','53633','97237319942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 18:31:47',0,NULL,3,1,11,1,' /','lilidin'),(16663,650209575013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','a12345678a2011','ahlee1980@gmail.com','Aw Yein ling','141-2 lorong mata air satu off Jalan<br>Genting klang setapak 53200 kuala lumpur','Setapak','Kuala lumpur','MALAYSIA','53200','0129137328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 18:33:49',0,NULL,3,1,3,1,'RA184576906CN\r','a12345678a2011  '),(16664,801657160011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.88,'eastar4','rajkris27','pagalraj@gmail.com','Rajesh Krishna','2416 Erlton St SW<br>Apt No. 203','Calgary','AB','CANADA','T2S 3B7','(403) 400-7332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 19:30:22',0,NULL,3,1,2,1,'\\  ','rajkris27  acer 5pin 1.25 3cm'),(16665,801663157011,320753598425,'NIB Genuine Samsung 3D glasses+2010 FIFA world cup disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','bcodner','bcodner@hotmail.com','Bolivar Codner','2721 NW 204th Ln','Miami Gardens','FL','UNITED STATES','33056-2131','(347) 933-3928','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 19:39:01',0,NULL,3,1,1,1,'\\ ','bcodner'),(16666,740896418008,180755478932,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',3,'HSPL008',94.5,'au-buy','livenlearn-57','tranhippy@gmail.com','hiep tran','88 signal hill way s.w.','calgary','AB','CANADA','t3h 2v1','(403) 891-8282','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 19:52:17',0,NULL,3,1,3,1,'RA117764892CN ','livenlearn-57\rHSPL008'),(16667,748469773007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',2,'RCLO006',93.98,'au-buy','mpronovost1','martin@yaknet.ca','Martin Pronovost','715, rue Nobel,  local 108','St-Jérôme','QC','CANADA','J7Z 7A3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 20:10:12',0,NULL,3,1,3,1,'RA184576781CN\r ','mpronovost1\rRCLO006'),(16668,888385494012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','rebecca3698','rebecca.mcglone@ntlworld.com','Rebecca McGlone','54 Poplar Avenue','Wetherby','West Yorkshire','UNITED KINGDOM','LS22 7RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 20:25:56',0,NULL,3,1,3,1,' RA184576265CN\r','rebecca3698\rHBPH003\r英标'),(16669,801678482011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','tralthamidor','dr@4dmaze.com','Derryl Rice','8434 Orange Cliff Ct','Las Vegas','NV','UNITED STATES','89123-2820','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 20:27:24',0,NULL,3,1,1,1,'\\ ','tralthamidor'),(16670,650259459013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lqia3531','qiangliangl@yahoo.com','Liangliang Qiang','84 Foster Dr','Willimantic','CT','UNITED STATES','06226-1557','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 20:28:22',0,NULL,3,1,1,1,'\\ ','lqia3531'),(16671,801716439011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','tfd1979','theresonlyonedrabble@hotmail.com','tom drabble','49 Longfield Drive<br>Rodley','Leeds','West Yorkshire','UNITED KINGDOM','LS13 1JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 21:17:36',0,NULL,3,1,3,1,' RA184576509CN\r','tfd1979\rGLSG001'),(16672,592291750003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',2,'HSMO018',26.58,'cnfaner','rhojogirl','rjohnson@prologis.com','Rhonda Johnson','1201 West Loop N<br>Ste 100','Houston','TX','UNITED STATES','77055-7257','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-25 21:21:58',0,NULL,3,1,1,1,'\\ ','rhojogirl'),(16673,650305453013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','aper8980','disde@hotmail.es','Antonio Perez Sanchez','Sant Felip i de Roses<br>58-62 3º 2ª','Badalona','Cataluña','SPAIN','08915','667712354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 22:34:01',0,NULL,3,1,2,1,'\\','aper8980'),(16674,888602358012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','aprilfarley','farleyapril2010@yahoo.com','april Clark','301 E Golf Ave','ottumwa','IA','UNITED STATES','52501-1339','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 23:10:27',0,NULL,3,1,1,1,'\\ ','aprilfarley'),(16675,888610831012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','bjet3861','bjett@indy.rr.com','Brian Jett','724 Bakeway Ct','Indianapolis','IN','UNITED STATES','46231-1675','(317) 839-9788','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 23:31:24',0,NULL,3,1,1,1,'\\ ','bjet3861  210T'),(16676,888615948012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','ridetherhythm','mik1970@blueyonder.co.uk','Imran Khan','4 Waltham Avenue','Hayes','Middlesex','UNITED KINGDOM','UB3 1TA','02085821681','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 23:31:42',0,NULL,3,1,3,1,'RA184576835CN\r ','ridetherhythm\rSCLO002'),(16677,883797760012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',3,'WLAT007',41.85,'eastar4','ninjaman989','alexwatson22@hotmail.com','Alexander Watson','11325 Windsor Walk Ct','Laurel','MD','UNITED STATES','20723-2004','(443) 745-8541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 00:19:48',0,NULL,3,1,1,1,'\\ ','ninjaman989'),(16678,650340745013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','crystalhogan2000','dctogether2000@yahoo.com','Crystal Hogan','1145 Driscoll Ridge Rd','Troy','ID','UNITED STATES','83871-9605','(208) 835-4134','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 00:48:48',0,NULL,3,1,3,1,'RA184576557CN\r','crystalhogan2000'),(16679,650343556013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',2,'WLAT001',27.98,'eastar4','voodoochief','voodoo@voodooland.net','Jaron Parsons','117 W Harvey Ave','Wellington','KS','UNITED STATES','67152-3840','(620) 326-8989','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 00:59:04',0,NULL,3,1,1,1,'\\ ','voodoochief'),(16680,650349543013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','acut2103','amylc88@gmail.com','Amy Cutlip','591 callan ave','San leandro','CA','UNITED STATES','94577','(510) 452-7734','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 01:26:23',0,NULL,3,1,3,1,'RA184576659CN\r','acut2103'),(16681,741029001008,180730162630,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',62.68,'au-buy','ktm1online','marshdogg76@gmail.com','marshall tremblay','24 sunrise street  s.w.','medicine hat','AB','CANADA','T1B4N5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 01:32:37',0,NULL,3,1,3,1,' RA184576225CN\r','ktm1online\rHSPL010'),(16682,743598858007,170728921067,'New Genuine Sony Ericsson HBH-PV702 Bluetooth Wireless Headset',1,'HSSE003',21.9,'au-buy','tatkid','autistickid@hotmail.com','Pauline Lam','1009<br>55 South Town Centre Blvd.','Markham','ON','CANADA','L6G0B1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 02:28:19',0,NULL,5,0,18,0,NULL,'tatkid\r收到电子支票时已发货'),(16683,801829150011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','apisit69','apisit@yahoo.com','Apisit Saksomboon','170 TaladSridindang Dindang road<br>Dindang','Bangkok','Bangkok','THAILAND','10400','+66894492909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 02:38:35',0,NULL,3,0,2,1,'\\ ','apisit69'),(16684,741057201008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','trusted03','nmtrasi@gmail.com','DR NITIN TRASI','BROOK MEDICAL CENTRE<br>64 BROOK STREET','MUSWELLBROOK','New South Wales','AUSTRALIA','2333','0265431222','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 03:23:36',0,NULL,3,1,3,1,' RA184576472CN\r','trusted03\rGLOT001'),(16685,650378421013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','abram17','vyacheslav8@hotmail.com','Valeriy Abramovich','1240 Manassas Dr','hemet','CA','UNITED STATES','92545-9144','(951) 318-2284','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 03:44:49',0,NULL,3,1,1,1,'\\ ','abram17'),(16686,801858689011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',139.98,'eastar4','tbri1760','tbriskovic@yahoo.com','Tony Briskovic','10 marble ave','Pleasantville','NY','UNITED STATES','10570','(646) 523-8831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 04:37:50',0,NULL,3,1,1,1,'\\ ','tbri1760'),(16687,650388874013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','hashalex3','help@wmebay.ru','Plusnin Vladislav','ul. Pervomaiskaya d. 13 kv. 43','Mozur','Gomelskaya oblast','BELARUS','247772','+375297358735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 04:40:04',0,NULL,3,1,3,1,'RA117764314CN\r ','hashalex3  HSNO019\r'),(16688,887689457012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','ckunyit','chamchulkunyit@gmail.com','Samsul HB','No 250 Kg Sengkurong \'B\',<br>KM 16 Jln Sengkurong \'A\', Brunei Darussalam.','BSB','Brunei','BRUNEI DARUSSALAM','BG1321','+6738822866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 05:06:57',0,NULL,3,1,2,1,'\\  ','ckunyit'),(16689,741079895008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','steveke100','vankosi@yahoo.com','Steve Vankos','7801 Shasta dr','Mckinney','TX','UNITED STATES','75071','(818) 984-7464','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 05:12:24',0,NULL,3,1,1,1,'\\ ','steveke100'),(16690,650394649013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','weter5411','al-gornostaew@yandex.ru','Irina  Gornostaewa','pereulok Medizinskii 15-15','Krasnoyarsk','Krasnoyarskii krai','RUSSIAN FEDERATION','660121','(391)261-24-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 05:15:31',0,NULL,3,1,3,1,' RA184576319CN\r','weter5411'),(16691,650399263013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','baby28','karen@boxerden.com','Karen Chan','15409 95A Avenue','Surrey','BC','CANADA','V3R 7T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 05:48:39',0,NULL,3,1,3,1,' RA184576322CN\r','baby28'),(16692,748655195007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','primedaus','krhowe@bigpond.com','ken howe','67 westbury road','launceston','Tasmania','AUSTRALIA','7250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 05:58:43',0,NULL,3,1,2,1,'\\ ','primedaus'),(16693,592401218003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',2,'LGAD001',97.78,'cnfaner','cariosservices','cariosservices@gmail.com','GERARDO RIOS','598 BUCKINGHAM AVE W','OLDSMAR','FL','UNITED STATES','34677-3406','(727) 455-3052','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-26 06:07:33',0,NULL,3,1,1,1,'\\ ','cariosservices'),(16694,758700128001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','roni63a','ronytaub@inter.net.il','RONI TAUB','25 Habanim St.','Herzliyya','','ISRAEL','46379','(972) 523-6994 ext.: 94','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 06:10:35',0,NULL,3,1,2,1,'\\  ','roni63a'),(16695,888731201012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',31.39,'eastar4uk','geewizz_au','jimprice456@msn.com','Jimbo Price','50 Michell rd','CARDIFF','New South Wales','AUSTRALIA','2285','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 06:26:52',0,NULL,3,1,3,1,'RA184576866CN\r ','geewizz_au\rGLFI001'),(16696,801887479011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','hikmat68','kazimovhikmat@rambler.ru','Hikmat Kazimov','Nizami str. 114','Baku','Baku','AZERBAIJAN','AZ 1010','+994503471919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 07:13:22',0,NULL,3,1,2,1,'\\ ','hikmat68 欧标'),(16697,650413235013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','ihw2407','ian@mybiz.com.au','Ian Whitson','70 Beadnall Tce<br>Glengowrie','Adelaide','South Australia','AUSTRALIA','5044','0882941830','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 07:25:57',0,NULL,3,1,3,1,' RA184576415CN\r','ihw2407'),(16698,888748883012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','hashalex3','help@wmebay.ru','Nosko Ludmila','ul. Dzerzinskogo d. 131 kv. 88','Grodno','Grodnenskaya oblast','BELARUS','230005','+375297555555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 07:49:37',0,NULL,3,1,3,1,' RA184576336CN\r','hashalex3'),(16699,888764733012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','want2talk123','want2talk@mail.ru','Sergey Lepeshkin','Kirova, 47, 70','Podolsk','Moscow region','RUSSIAN FEDERATION','142117','+7(901)5451821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 08:53:00',0,NULL,3,1,2,1,'、','want2talk123 acer 6pin1.25 23cm'),(16700,597845431004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',6.99,'cnfaner','alex1807','alejandrocabral@gmail.com','Alejandro Cabral','2911 South Parnell Ave','Chicago','IL','UNITED STATES','60616','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-26 08:59:07',0,NULL,3,1,1,1,'\\ ','alex1807'),(16701,888775742012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','alberbay13','crales13@hotmail.com','Alberto Baños','Colina del Limon#115A','Leon','Guanajuato','MEXICO','37530','4771487560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 09:26:21',0,NULL,3,1,3,1,' RA184576398CN\r','alberbay13'),(16702,650439337013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','l_egor77','legor77@inbox.ru','Egor Lysoy','Severnoe Chertanovo 7A-24','Moscow','','RUSSIAN FEDERATION','117648','+79164430596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 09:44:55',0,NULL,3,1,3,1,'RA184576804CN\r ','l_egor77'),(16703,748726730007,170735464248,'New Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',44.98,'au-buy','dearmiss4u','dearmiss@optusnet.com.au','Karen-Maree Andrews','1 Seymour St','Dundas Valley','New South Wales','AUSTRALIA','2117','61298714742','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 10:59:48',0,NULL,3,1,11,1,'BJ01085204\r\r','dearmiss4u\r已入库\r一共发两把伞\r向日葵三折伞和向日葵长柄伞\rUM00004\rUM00005'),(16704,748733837007,170728921205,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 EARPHONE UE150 UE',1,'HSUE004',12.49,'au-buy','bonfirehead','bonfirehead@hotmail.com','Scott Joblin','53 Antill Street<br>Downer','Canberra','Australian Capital Territory','AUSTRALIA','2602','0450461251','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 11:22:43',0,NULL,3,1,2,1,'\\  ','bonfirehead'),(16705,888815354012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','kevkarbir','kevkarbir@dodo.com.au','karl ewald','10 Marrabala Court','Lyons','Northern Territory','AUSTRALIA','0810','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 11:23:23',0,NULL,3,1,3,1,'RA184576693CN\r','kevkarbir'),(16706,801961581011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','rif07011948','rif1948@yahoo.com','rif daukaev','str.Belarus,16','Ufa','RB','RUSSIAN FEDERATION','450106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 11:36:00',0,NULL,3,1,3,1,'RA184576954CN\r ','rif07011948'),(16707,741170362008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','sanderdona','spdona@gmail.com','Sander Dona','Waterhoen 11','Den Bosch','','NETHERLANDS','5221GW','0031629523743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 11:38:01',0,NULL,3,1,2,1,'/','sanderdona'),(16708,758784868001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','knu_utoo664u','knu_utoo66@hotmail.com','Archellus Bell II','1701 Crystal Creek Dr','Durham','NC','UNITED STATES','27712-2487','(919) 620-8897','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 11:49:10',0,NULL,3,1,1,1,'\\ ','knu_utoo664u'),(16709,801998331011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006',26.99,'eastar4uk','muzbiker','frode@bekvik.no','Frode Bekvik','Øvre Ringstadvegen 13','Gran','','NORWAY','2750','+47 96236200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 13:18:06',0,NULL,3,1,3,1,'RA184576716CN\r ','muzbiker\rGLOT006'),(16710,650490762013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','972elimoses5','elimoses5@walla.com','ELI MOSES','HASHEKMA 57','LAPID','israel','ISRAEL','73133','972 8 9766603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 13:18:12',0,NULL,3,1,3,1,' RA184576407CN\r','972elimoses5'),(16711,650491398013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','ana.bekteshi','abekteshi11@gmail.com','Christopher Sund','Skolhusgatan 57-61 B18','VASA','','FINLAND','65100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 13:19:40',0,NULL,3,1,2,1,'\\ ','ana.bekteshi'),(16712,741230466008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','klein472009','pavel.kleinmann@kh-berlin.de','Pavel kleinmann','Puschkinstr. 27','Schöneiche','','GERMANY','15566','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 14:25:40',0,NULL,3,1,3,1,' RA184576203CN\r','klein472009\rHBPH001'),(16713,888903942012,220815929490,'New Atheros AR9287 BGN 300M Half PCI-E card+ANTENNA',1,'WLAT007+ANTY001',9.7,'eastar4uk','bordjukov','bordjukov+ebay@gmail.com','Petko Bordjukov','51, Studentski Grad<br>apt. 312','Sofia','Sofia-grad','BULGARIA','1700','+359888322605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 14:56:10',0,NULL,3,1,2,1,'\\  ','bordjukov'),(16714,888907419012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',13.99,'eastar4uk','l200lkh.0115','lee.henshaw.1@hotmail.com','lee henshaw','1 glen parva avenue<br>redhill','nottingham','Nottinghamshire','UNITED KINGDOM','ng5 8lz','01159602371','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 15:04:29',0,NULL,3,1,3,1,' RA184576248CN\r','l200lkh.0115\rHSMO011+CCMO001'),(16715,650534792013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','dwhe6996','meatwheat2004@yahoo.com','Dale Wheatley','710 Kickapoo','Leavenworth','KS','UNITED STATES','66048','(913) 702-4099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 15:32:34',0,NULL,3,1,1,1,'\\ ','dwhe6996'),(16716,888925893012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','jenninrich0779','jenninrich@yahoo.co.uk','jenni wellings','36 cavalier court<br>balby','doncaster','South Yorkshire','UNITED KINGDOM','dn4 8tw','01302322962','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 15:40:57',0,NULL,3,1,3,1,' RA184576486CN\r','jenninrich0779\rHSPH003\r英标'),(16717,650539543013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','tr_63','tayyab_rahman@hotmail.com','Tayyab Rahman','22734 Eleanor Ct','Kildeer','IL','UNITED STATES','60047','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 15:46:26',0,NULL,3,1,3,1,' RA184576530CN\r','tr_63'),(16718,758884809001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','jorwig280211zk','jorwig2802@aol.com','James F. Orwig','131 Eldred St','Williamsport','PA','UNITED STATES','17701-3433','(570) 244-7150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 16:02:39',0,NULL,3,1,1,1,'\\ ','jorwig280211zk'),(16719,650553676013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','ricpark_123','ricpark@ig.com.br','Ricardo Amar','3239 Villa Strada Way','Orlando','FL','UNITED STATES','32835','(407) 470-5265','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 16:23:02',0,NULL,3,1,3,1,'RA184576565CN\r','ricpark_123'),(16720,888955592012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','princesslouloubelle','louisaprincess@hotmail.com','Louise Brown','51 Tewkesbury Walk','Newport','Newport','UNITED KINGDOM','NP20 5HP','07800928839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 16:32:57',0,NULL,3,1,11,1,'/\r ','princesslouloubelle\rUM00027'),(16721,650562117013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','aviationpilotman','aviationpilotman@yahoo.com','Christopher Anderson','921 Poplar St','Truth or Consequences','NM','UNITED STATES','87901','(575) 740-1395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 16:42:57',0,NULL,3,1,3,1,' RA184576543CN\r','aviationpilotman'),(16722,800027853011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.39,'eastar4','noweverythingsounds','shu-shea@yandex.ru','Denis Dmitriev','Zelenogradskaya 25-4-30','Moscow','','RUSSIAN FEDERATION','125475','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 16:46:18',0,NULL,3,1,2,1,'\\ ','noweverythingsounds  HP 8pin 1.0 23cm   新地址：\rIlya Ptahin\r3-y Mitinskiy pereulok 5-97\rMoscow Moscow 125368\rRussian Federation\r'),(16723,650564899013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','unbrokenremains','dunbroken1@msn.com','damon slaikeu','332 10th ave s','south saint paul','MN','UNITED STATES','55075-2519','(651) 497-9791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 16:56:42',0,NULL,3,1,3,1,' RA184576512CN\r','unbrokenremains'),(16724,597979304004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','mykekos','mykekos@yahoo.com','Michael Koscielski','155 N Harbor Dr<br>Apt 1503','Chicago','IL','UNITED STATES','60601-5000','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-26 17:08:21',0,NULL,3,1,1,1,'\\ ','mykekos'),(16725,802113281011,320735056905,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',13.99,'eastar4uk','markyd100','harveyd24@aol.com','mark dickinson','23 victor road','harrow','Middlesex','UNITED KINGDOM','HA26PT','07800777737','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 17:17:51',0,NULL,3,1,3,1,' RA184576441CN\r','markyd100\rOTGR005'),(16726,802114267011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','alrds724','aleros1224@yahoo.com','alex rodas','2115 powder mist ln','katy','TX','UNITED STATES','77449-3136','(832) 386-7621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 17:22:18',0,NULL,3,1,1,1,'\\ ','alrds724'),(16727,888988429012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','neor371','neor164@gmail.com','Neor Ozeri','Rashi 24','Rishon LeZion','ID','ISRAEL','75308','97239580905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 17:27:31',0,NULL,3,1,3,1,' RA184576340CN\r','neor371'),(16728,748890953007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','prosenberg80','prosenberg80@aol.com','Paul A. Rosenberg','3401 Winchester Ave<br>C/O: Yellow Cab Co.','Atlantic City','NJ','UNITED STATES','08401-3506','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 17:30:04',0,NULL,3,1,1,1,'\\ ','prosenberg80\rRCLO003'),(16729,650597177013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',1,'UDAP004',22.99,'eastar4','piepiechung','nararut@hotmail.com','Nararut Rungnoppakunsi','SH 2.11 , Osborne House (University of Bath)<br>The Avenue, Claverton Down','Bath','Somerset','UNITED KINGDOM','BA2 7AY','07428012342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 18:04:19',0,NULL,3,1,3,1,'RA184576852CN\r ','piepiechung'),(16730,650605838013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','mantzinichris','chris052@cytanet.com.cy','chrisostomos erodotou','25th  martiou costandia court 22<br>flat 102','limassol','','CYPRUS','3095','0035799667668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 18:24:02',0,NULL,3,1,2,1,'\\  ','mantzinichris  欧标'),(16731,889036620012,220723590916,'New Motorola H700 Bluetooth Wireless Headset+ Caraharge',1,'HSMO011+CCMO001',13.99,'eastar4uk','96215-oki','heikohabig@web.de','Heiko Habig','Postnummer 32377063<br>Packstation 113','Lichtenfels','','GERMANY','96215','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 18:40:17',0,NULL,3,1,2,1,'\\ ','96215-oki'),(16732,889041073012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',8.99,'eastar4uk','philem0_1','philippe.lemetayer@netcourrier.com','lemetayer','28 av bernard palissy','saint cloud','haute seine','FRANCE','92210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 18:47:16',0,NULL,3,1,2,1,'、','philem0_1'),(16733,748954566007,170730545297,'New Logitech harmony remote Li-ion Rechargeable Battery 930mAh WHITE',1,'BALO002',10.99,'au-buy','rondelau2','rondelau@upcmail.nl','ron de lau','Achterwerf 98','ALMERE','','NETHERLANDS','1357BN','0365316200','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 19:17:13',0,NULL,3,1,2,1,'\\','rondelau2'),(16734,802204235011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','noisangsannoi','noi.sangsan@gmail.com','Gobkul Ramsdale','52 Central Avenue','Hayes','Middlesex','UNITED KINGDOM','UB3 2BY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 19:43:20',0,NULL,3,1,3,1,'RA184576645CN\r','noisangsannoi\rGLOT001*4'),(16735,650643783013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','4211gail','lady0926@verizon.net','Gail Ballard','307 N Windell Avenue','Annapolis','MD','UNITED STATES','21401','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 20:00:04',0,NULL,3,1,1,1,'\\  ','4211gail'),(16736,802227970011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',52.99,'eastar4','mapin21','mapin2100@gmail.com','Miguel Ângelo Pinheiro','Rua Cel. João Augusto Lima, 222<br>Apt 401 - Guararapes','Fortaleza','Ceará','BRAZIL','60810 321','55 85 91222036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 20:22:12',0,NULL,3,1,3,1,'RA184576733CN\r ','mapin21'),(16737,802231389011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','vipalexandre','haroun.khinache@gmail.com','Haroun KHINACHE','136 rue du 18 juin<br>Bâtiment 7: Fruitselect','Ermont','Ile-de-France','FRANCE','95120','0139807598','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 20:28:57',0,NULL,3,1,3,1,' RA184576375CN\r','vipalexandre\rGLOT001'),(16738,650667425013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','joseph11h','joseph11h@gmail.com','Joseph Hamilton','496 Skaggs Rd','Morehead','KY','UNITED STATES','40351-8850','(606) 620-0412','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 20:41:12',0,NULL,3,1,1,1,'\\ ','joseph11h'),(16739,802239971011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','lil9838','lil9838@aol.com','Lillian Karamanian','2200 NE 33rd Ave. 11A','Ft. Lauderdale','FL','UNITED STATES','33305','(954) 563-0853','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-26 20:41:33',0,NULL,3,1,1,1,'\\ ','lil9838'),(16740,749002847007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',1,'RCLO006',46.99,'au-buy','mathewsparents','mathewsparents@rogers.com','Max Hansen','57 Sir Williams Lane','Toronto','ON','CANADA','M9A 1V3','(416) 234-5972','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 20:47:42',0,NULL,3,0,3,1,'RA184576778CN\r ','mathewsparents\rRCLO006'),(16741,650686814013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',1,'MOSA003',64.99,'eastar4','brunot78','b.teixeira@rogers.com','Bruno Teixeira','1006 St Clarens Ave<br>Apt 1','Toronto','ON','CANADA','M6H 3X7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 21:25:24',0,NULL,3,1,3,1,' RA184576438CN\r','brunot78'),(16742,802004889011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','yafunsales','sales@yafun.com','J. Yang','9 John cabot way','Toronto','ON','CANADA','M3N 2T5','(416) 745-3687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 22:15:37',0,NULL,3,1,2,1,'\\  ','yafunsales  acer 8pin1.00 8cm'),(16743,889184372012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','lacelle09','lacelle_marcandre@hotmail.com','Marc-André Lacelle','63 Gabrielle-Roy','Gatineau','QC','CANADA','J8R 2Y2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 22:34:38',0,NULL,3,1,3,1,' RA184576353CN\r','lacelle09'),(16744,802307550011,320801187173,'New Genuine Motorola H721 Bluetooth Wireless Headset   H  721+AC adaptor',1,'HSMO022',13.99,'eastar4uk','ks0385','k200385@yahoo.com','krystle seaton','PO Box 318<br>1112 Eddie Ford Road','mayersville','MS','UNITED STATES','39113-0318','(662) 873-1751','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 22:49:10',0,NULL,3,1,1,1,'\\ ','ks0385'),(16745,802319485011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','bandit-lt','ndeep2@frontier.com','ANGELA  L. PERRY','211 Brandywine Dr SE','POPLAR GROVE','IL','UNITED STATES','61065-8984','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 23:17:06',0,NULL,3,1,1,1,'\\ ','bandit-lt'),(16746,889208256012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.9,'eastar4uk','anguy2007','manu_singal@rediffmail.com','Dr. MANU SINGAL','APARTMENT 61, ROSEDALE MANSIONS<br>MALM STREET, BOULEVARD','HULL','East Riding of Yorkshire','UNITED KINGDOM','HU3 2TF','07944340905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 23:21:07',0,NULL,3,1,3,1,' RA184576194CN\r','anguy2007\rHSMO018\r英标'),(16747,889226463012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','posieminx','jo_king_smith@yahoo.co.uk','Mrs Joanne Green','5 Merry Lees Rd','Newbold Heath','Leicestershire','UNITED KINGDOM','LE9 9NR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 00:05:43',0,NULL,3,1,3,1,' RA184576424CN\r','posieminx\rOTGR001'),(16748,598137508004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.3,'cnfaner','laprasha660','henrylaprasha@yahoo.com','Laprasha Henry','205 jefferson','helena','AR','UNITED STATES','72342-2012','(870) 995-5138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 00:24:29',0,NULL,3,1,1,1,'\\ ','laprasha660'),(16749,749120208007,170728921103,'New Genuine Sony Ericsson HBH-PV703 Bluetooth Wireless Headset',1,'HSSE004',41.9,'au-buy','stapcnc','k1212@hotmail.com','Mr.Stappong Chuansnit','56/7  M2<br>Soi Taweewattana-Kanjanapisek20','Taweewattana,Taweewattana','Bangkok','THAILAND','10170','6681-334-6414','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 01:14:58',0,NULL,3,1,3,1,'RA184576795CN\r ','stapcnc\rHSSE004 \rPls declare as a GIFT'),(16750,650760276013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','pena2965','a.pena96@gmail.com','Alma Pena','4917 manitoba dr<br>apt 104','Alexandria','VA','UNITED STATES','22312-4915','(703) 462-3486','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 01:26:16',0,NULL,3,1,3,1,' RA184576469CN\r','pena2965'),(16751,650774878013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','marce8105','marselinoflores@yahoo.com','Marcelino  Flores','673 James Ave','Nashville','TN','UNITED STATES','37209-1267','(615) 839-5001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 02:25:12',0,NULL,3,1,1,1,'\\  ','marce8105'),(16752,650774019013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','lhackett800','lhackett800@yahoo.com','Larry Hackett','3709 N 153rd St','Basehor','KS','UNITED STATES','66007-9258','(913) 775-8000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 02:28:11',0,NULL,3,1,1,1,'\\ ','lhackett800'),(16753,889284119012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','ardywt99','ardywt99@yahoo.com','Arsadia Harris','314 Delta Dr W','Hattiesburg','MS','UNITED STATES','39402','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 02:49:45',0,NULL,3,1,1,1,'\\ ','ardywt99'),(16754,749149802007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.9,'au-buy','kevindanni','milly_danni@hotmail.com','Danni Bromley','148 sherwood rise nw','Calgary','AB','CANADA','t3l 1p7','(403) 399-8943','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 02:57:54',0,NULL,3,1,3,1,' RA184576132CN\r','kevindanni\rHSPL013 \r'),(16755,802394438011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','tippietje','gameserversales@gmail.com','Kevin Opdekamp','Geerkensveldstraat 54','Zutendaal','Limburg','BELGIUM','3690','0484847904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 03:02:58',0,NULL,3,1,2,1,'\\  ','tippietje'),(16756,741575141008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'au-buy','richiie7','richiiez@optusnet.com.au','Richard He','8 May Street','Footscray','Victoria','AUSTRALIA','3011','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 03:03:24',0,NULL,3,1,2,1,'\\  ','richiie7'),(16757,889305421012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',23.74,'eastar4','zzeh4408','zahrazehour94@hotmail.com','Zahra Zehour','2 Denfield CT<br>St Helens Park','Sydney','New South Wales','AUSTRALIA','2560','0246212653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 03:56:52',0,NULL,3,1,11,1,'/','zzeh4408'),(16758,749166321007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','books_and_clothes123','booksandclothes@hotmail.com','Mira Macdonald','36 Lee road','Winmalee','New South Wales','AUSTRALIA','2777','0247544019','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 04:02:05',0,NULL,3,1,11,1,' \\','books_and_clothes123\rUM00042'),(16759,650799039013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','strammell','strammell10@gmail.com','Samuel Trammell','1225 lackey lane','Leary','GA','UNITED STATES','39862','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 04:27:52',0,NULL,3,1,1,1,'\\ ','strammell'),(16760,889322580012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','akelley8','akmadxi@gmail.com','Allan R. Kelley','13616 N 37th Ave','Phoenix','AZ','UNITED STATES','85029-1108','(602) 743-6175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 05:03:04',0,NULL,3,1,1,1,'\\ ','akelley8'),(16761,598200369004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','shittolie','68roadster@gmail.com','Wade L Smith','458 Highway 230 E','Brookland','AR','UNITED STATES','72417-8959','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 05:49:10',0,NULL,3,1,1,1,'\\ ','shittolie'),(16762,749205563007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','archie.c','aussie321@hotmail.com','arthur calvert','3 jaf place blairmount','campbelltown','New South Wales','AUSTRALIA','2559','020403226544','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 07:22:06',0,NULL,3,1,3,1,'RA117764376CN\r ','archie.c\rLGFI001'),(16763,884080724012,220872406392,'4 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT006*4',175.99,'eastar4','alexei-rus','alexei-rus@mail.ru','Igor ABRAMENKO','Gagarina Str. #60-39','Samara','Samarskiy','RUSSIAN FEDERATION','443079','+79276921993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 07:52:37',0,NULL,3,1,3,1,'RA184576367CN\r','alexei-rus 货已经退回'),(16764,889361303012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','1987nessforless','nessforless@yahoo.com','nessfor less','76<br>annesley ave','blackpool','Lancashire','UNITED KINGDOM','fy3 7hx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 07:54:28',0,NULL,3,1,11,1,'/','1987nessforless\rUM00027'),(16765,741645553008,180755479369,'New iTech Clip II mini Multipoint Bluetooth Headset BLACK',2,'HSPL002',77.8,'au-buy','hanizozltd','ronidnn@gmail.com','danino roni','hamasger 5','netanya','ISRAEL','ISRAEL','42378','972-505425285','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 08:31:42',0,NULL,3,1,3,1,'RA117764889CN ','hanizozltd\rHSPL002'),(16766,802474819011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',8.49,'eastar4','ali_khurram','ali_khurram@hotmail.com','Ali Khurram','16 Ballantyne Cresent','Franklin, Canberra','Australian Capital Territory','AUSTRALIA','2913','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 08:42:43',0,NULL,3,1,2,1,'\\  ','ali_khurram'),(16767,802222259002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','seeprosee','ebay@imagine-that.com','Ramona Harbour','870 Roanhorse Ln','Henderson','NV','UNITED STATES','89052-0472','(702) 616-7171','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 09:35:18',0,NULL,3,1,1,1,'\\ ','seeprosee'),(16768,889420923012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','tm.joaquin','tm.joaquin@gmail.com','Joaquín Torres Martínez','Calle Campoamor 106 puerta 55','Valencia','Comunidad Valenciana','SPAIN','46022','647674506','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 10:31:30',0,NULL,3,1,2,1,'\\  ','tm.joaquin'),(16769,802541914011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','dani13978','fedya139@gmail.com','dani139 dani139','aleksandroni 5/26','kiryat gat','','ISRAEL','82000','0526432030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 11:18:08',0,NULL,3,1,2,1,'\\ ','dani13978  欧标'),(16770,884041302012,220720533789,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',11,'eastar4uk','skmaryb','karim@pobox.sk','Marian Rybansky','Kysak 358','Kysak','','SLOVAK REPUBLIC','04481','+421905221869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 11:51:45',0,NULL,3,1,2,1,'\\ ','skmaryb'),(16771,650903706013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','nilsonomori','nomori@gmail.com','Nilson Sunao Omori','Rua Antonio Valdir Zanutto, 235<br>Jd Novo Horizonte','Maringa','Parana','BRAZIL','87010-100','554432261570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 11:52:18',0,NULL,3,1,2,1,'\\  ','nilsonomori'),(16772,889469682012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','enog2747','ejgn@gmx.com','Eduardo Nogueira','Flat 2 Manse Gardens<br>Haslers Lane','Great Dunmow','Essex','UNITED KINGDOM','CM6 1BL','07738730029','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 11:53:31',0,NULL,3,1,3,1,' RA184576305CN\r','enog2747\rRELO002'),(16773,650912235013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','jufrolca64','joliveren@gmail.com','Juan Francisco Oliver Cabañero','calle argentina nº 13 5º D','fuenlabrada','Madrid','SPAIN','28944','626988780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 12:13:01',0,NULL,3,1,3,1,'RA184576821CN\r ','jufrolca64'),(16774,889483049012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','pedro_eloy','peizpe@gmail.com','Pedro Izquierdo Pereda','Venezuela Nº 6 8º B','Vigo','Pontevedra','SPAIN','36203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 12:19:29',0,NULL,3,1,2,1,'\\ ','pedro_eloy  acer 8pin1.00 15cm   two wires? 等确认 '),(16775,889479220012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','ooren17','oo13ooo@gmail.com','Oren Sharabi','P.O. Box 95','Petah Tiqva','israel','ISRAEL','49100','0502528048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 12:19:39',0,NULL,3,1,2,1,'\\  ','ooren17'),(16776,741762413008,180699003613,'New Logitech Unifying receiver for mouse and keyboard',1,'RELO002',12.97,'au-buy','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 13:03:02',0,NULL,3,1,2,1,'\\ ','wildvovan'),(16777,889513730012,220815930955,'New in sealed box Microsoft Wireless Laser Mouse 8000',1,'MOMI001',33.99,'eastar4uk','tomer-gal','tomerg@wgalil.ac.il','tomer gal','Heshel 642<br>Givat ram','kiriyat ata','israel','ISRAEL','28000','972-48480329','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 13:15:00',0,NULL,3,1,3,1,'RA184576937CN\r ','tomer-gal\rMOMI001\rplease write down 25-30 value\r'),(16778,802605402011,320786774017,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',53.9,'eastar4uk','hploss','hploss@gmail.com','Harry Ploss','3736 Woodshadow Ln','Addison','TX','UNITED STATES','75001','(972) 406-9139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 13:21:54',0,NULL,3,0,1,1,'\\ ','hploss\r已入库'),(16779,597683363004,140647853566,'3G WWan antenna  MC8775 MC8781 MC8780 MC8790 F3507G GTM380 GTM382 M250 DELL5530',1,'ANCN001',5.79,'cnfaner','saturnus24','steven.temmerman@skynet.be','steven Temmerman','begoniastraat 22','Vilvoorde','','BELGIUM','1800','0478/802821','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-27 13:39:39',0,NULL,3,1,2,1,'\\  ','saturnus24'),(16780,889531643012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',2,'WWSI002',59.76,'eastar4','insong94','bongjulee@empal.com','Bong-Ju Lee','113-704 Thesharp CentumPark 1 Cha Apt.,<br>Jaesong 1-dong ,Haeundae-gu,','Busan','','KOREA,REPUBLIC OF','612-712','82-11-831-9461','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117778582CN ','insong94  再发两个3G 天线'),(16781,802622786011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','agolfnut53','agolfnut53@hvc.rr.com','Enrique A Garrido Jr','2 Hilee Rd','Rhinebeck','NY','UNITED STATES','12572-2347','(914) 772-6444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 13:53:15',0,NULL,3,1,1,1,'\\ ','agolfnut53'),(16782,592913655003,130489928779,'New SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT TV 60\"-65\"',1,'MOSA003',64.99,'cnfaner','renuraja','renuraja@hotmail.com','Rajesh Gupta','12909 Sherbrooke Dr','Frisco','TX','UNITED STATES','75035-0448','(563) 332-1414','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 14:07:28',0,NULL,3,1,1,1,'\\ ','renuraja\r'),(16783,802648249011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','crazyemperor115','andreerdna266@hotmail.com','Andre Mella','Odlingsgatan 25','Koskullskulle','Norrbotten','SWEDEN','98341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 14:33:58',0,NULL,3,1,2,1,'\\','crazyemperor115'),(16784,802666004011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','mal1206_123','malcolme.mcwilliam@sky.com','Jean Mcwilliam','30 HALL LANE EST<br>WILLINGTON','CROOK','Durham','UNITED KINGDOM','DL15 0QF','01388747089','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 15:04:43',0,NULL,3,1,3,1,' RA184576455CN\r','mal1206_123\rGLSG001'),(16785,889585825012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','abidk90','gauhar63@hotmail.com','Abid Khan','1C Freshford Street','London','London','UNITED KINGDOM','SW18 3TG','02089476337','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 15:06:08',0,NULL,3,1,3,1,'RA117764328CN\r ','abidk90\rHSNO017+CCNO001'),(16786,598363293004,140584762695,'New in box ZAGG DUAL USB CAR CHARGER',3,'CCZG001',20.97,'cnfaner','600xc-xp','xc600xp@aim.com','Scott Knutson','2222 53rd Dr','Franksville','WI','UNITED STATES','53126-9753','(262) 835-2475','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 15:11:15',0,NULL,3,1,1,1,'\\ ','600xc-xp'),(16787,889599250012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',211.99,'eastar4','stshtr','richard.kowalczyk@sympatico.ca','Richard Kowalczyk','85 Brigade Dr.','Hamilton','ON','CANADA','L9B 1Z6','(905) 318-8183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 15:25:07',0,NULL,3,1,3,1,' RA184576234CN\r','stshtr'),(16788,889609573012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',2,'OTCN001',5.98,'eastar4uk','gilburn','ppdavis@ntlworld.com','Paul Davis','The Willows, Park View,<br>Pontnewydd','Cwmbran','Torfaen','UNITED KINGDOM','NP44 1RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 15:37:53',0,NULL,3,1,3,1,' RA184576296CN\r','gilburn\rOTCN001'),(16789,802690997011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','marcvsname','marcshilton@hotmail.co.uk','Marc Shilton','48 Arbor Road','Croft','Leicestershire','UNITED KINGDOM','LE9 3GD','01455283732','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 15:40:36',0,NULL,5,1,3,1,'\\ 发了 ','marcvsname\rMOAP001'),(16790,749444832007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','olechrgulliksen','ocg@autog.no','Ole Christian Gulliksen','Bernhard Getz gt. 7','Trondheim','','NORWAY','7043','004792086700','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 15:49:56',0,NULL,3,1,2,1,'、','olechrgulliksen'),(16791,651004392013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','14081955myb','mozal@bk.ru','Юрий Мозалев','Пушкина, д.12 кв.54','Норильск','Красноярский край','RUSSIAN FEDERATION','663305','+79135314433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 15:58:18',0,NULL,3,1,3,1,'RA184576614CN\r','14081955myb'),(16792,651027930013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','wujeczek','mjgieniec@aol.com','MAREK GIENIEC','603-537 14 AVE SW','CALGARY','AB','CANADA','T2R 0M7','(403) 245-2525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 16:25:19',0,NULL,3,1,3,1,'RA184576588CN\r','wujeczek'),(16793,651026457013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',18.98,'eastar4','alpine_design','alpine_design_slc@hotmail.com','Jonathan horne','525 S 300 W','Salt Lake City','UT','UNITED STATES','84101-2503','(801) 364-0400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 16:34:18',0,NULL,3,1,1,1,'\\ ','alpine_design'),(16794,802135708002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','damiancurtis','vegandiver2003@yahoo.com','Brian Aklestad','5632 Tranquility Oaks Dr<br>Unit 203','Tampa','FL','UNITED STATES','33624-2876','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 16:34:35',0,NULL,3,1,1,1,'\\ ','damiancurtis'),(16795,651038684013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','baypaper','ebaypaper@googlemail.com','DANG HOANG NHI','233 TRAN PHU street,<br>ward 9, district 5,','Ho Chi Minh City,','','VIET NAM','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 16:49:44',0,NULL,3,1,3,1,' RA184576129CN\r','baypaper'),(16796,802750639011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','barrosanchez','barrosanchez@hotmail.com','Raul Barros Sánchez','Travesia Santa ana nº 3 Bajo C','Bejar','Castilla y León','SPAIN','37700','666212826','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 16:54:20',0,NULL,3,1,2,1,'\\ ','barrosanchez'),(16797,889670075012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','jam762','jam762@msn.com','jam 762','161 Township Road 248 West','kitts hill','OH','UNITED STATES','45645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 16:56:59',0,NULL,3,1,1,1,'\\ ','jam762'),(16798,802491177002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','gxl99','luis_galarza@hotmail.com','Luis Galarza','8906 W Flagler St<br>Apt 108','Miami','FL','UNITED STATES','33174-3910','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 17:25:53',0,NULL,3,1,1,1,'\\ ','gxl99'),(16799,802780329011,320787341155,'New Jabra JX10 II 2 Wireless Bluetooth headset black',1,'HSJA004',12.99,'eastar4uk','husky02150','eduardoorellana30@yahoo.com','NELSON ALVAREZ','332 Washington Ave<br># 2','chelsea','MA','UNITED STATES','02150-3642','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'husky02150'),(16800,598451802004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','mgormanco','marti@martigorman.org','Marti Gorman','266 Elmwood Ave<br># 407','Buffalo','NY','UNITED STATES','14222-2202','(716) 903-7155','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 17:44:51',0,NULL,3,1,1,1,'\\ ','mgormanco'),(16801,802814978011,320700100689,'NIB cisco Linksys DMP100 Wireless-N Music Extender',1,'OTLK001',119,'eastar4','jeffhaight','jhaight@ix.netcom.com','Jeffrey D Haight','586 Rockport Dr','Sunnyvale','CA','UNITED STATES','94087-2415','(650) 279-9368','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 17:59:58',0,NULL,5,1,4,1,'YW867739811CN\r ','jeffhaight\r货发了，但点不了发货，所以选择了订单取消'),(16802,749557616007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',2,'HSUE003',41.98,'au-buy','mschris485','mschris485@hotmail.com','Christina Shanderson','4751 40th St<br>Apt 1B','Sunnyside','NY','UNITED STATES','11104-4013','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 18:01:45',0,NULL,3,1,1,1,'\\ ','mschris485'),(16803,651087589013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','cvetozar123','zari_nikolov@yahoo.com','Mariana Kosmopulu','4-6 Folegandrou str.<br>Glyfada','Athens','Attiki','GREECE','16561','(697) 270 - 4573','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-11-27 18:02:36',0,NULL,3,1,3,1,'RA117764345CN\r ','cvetozar123  欧标'),(16804,593038705003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','d_rojas','davidrojas@rgv.rr.com','David Rojas','4121 N 10th St<br>#229','McAllen','TX','UNITED STATES','78504','(877) 683-0079','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 17:55:42',0,NULL,3,1,1,1,'\\ ','d_rojas'),(16805,759591696001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','srobinson_86','mil_brown_80@hotmail.com','Stacey  Robinson','6 chantry close','peterborough','Cambridgeshire','UNITED KINGDOM','pe13ab','01733358860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 18:18:37',0,NULL,3,1,2,1,'\\  ','srobinson_86'),(16806,651112786013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','slekens','samlekens@yahoo.com','sam lekens','Streekbaan 71','vilvoorde','','BELGIUM','1800','+3250123456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 18:20:24',0,NULL,3,1,3,1,'RA184576217CN\r','slekens CAB-6060'),(16807,796214341011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','msr.highlyfavor','rorie_teresa@yahoo.com','teresa rorie','1118 Parker St','monroe','NC','UNITED STATES','28112-6210','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 18:23:31',0,NULL,3,1,1,1,'\\ ','msr.highlyfavor'),(16808,651117485013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','terryh7454','tsholt5@yahoo.com','terry holt','416 Hillcrest St','el segundo','CA','UNITED STATES','90245-2911','(310) 640-8572','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 18:25:42',0,NULL,3,1,1,1,'\\ ','terryh7454'),(16809,598486743004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',1,'HSJA004',18.98,'cnfaner','samp5757','samirp57@comcast.net','Samir Patel','3312 Dickerson Pike','Nashville','TN','UNITED STATES','37207-2955','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 18:30:15',0,NULL,3,1,1,1,'\\ ','samp5757 黑色的'),(16810,651131620013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','604phil6431','philipbrochu@shaw.ca','philip brochu','20381 118th ave','maple ridge','BC','CANADA','v2x2m5','(604) 465-6431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 18:43:13',0,NULL,3,1,3,1,'RA184576628CN\r','604phil6431'),(16811,742017773008,180757093720,'New Logitech Charging Cradle L-LG7 for Harmony 880 890 Pro',1,'CRLO001',13.99,'au-buy','flutieflake','garybarrett@hotmail.com','Gary Barrett','9 Satchell Blvd.','West Hill','ON','CANADA','M1C 3B3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 18:44:44',0,NULL,3,1,2,1,'\\  ','flutieflake'),(16812,802884397011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','redaviator15','martywings@blueyonder.co.uk','martin jeffery','15 bodiam close, pitsea','basildon','Essex','UNITED KINGDOM','SS133RA','01268459253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 18:56:31',0,NULL,3,1,3,1,' RA184576384CN\r','redaviator15\rGLOT001*2 \r兼容眼镜通用型'),(16813,651152267013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','kaddrison','karl@addrison.co.uk','Karl Addrison','Unit-2 [Ino-Plaz Building], Reservoir Road,<br>Clough Road,','Hull','','UNITED KINGDOM','HU6 7QD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 19:03:03',0,NULL,3,0,3,1,'RA184576764CN\r ','kaddrison'),(16814,802652774002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','coolronz','coolronz@hotmail.com','Ron Flood','18 Yakoun st.<br>P.O.Box 354','Port Clements','BC','CANADA','V0T1R0','(250) 557-4415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 19:46:04',0,NULL,3,1,2,1,'\\  ','coolronz'),(16815,889924171012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',4,'GLOT005',134.8,'eastar4uk','panosapos','panopavla@hotmail.gr','panagiotis apostolou','themistokli tsatou','nicosia','latsia','CYPRUS','2221','97779750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 20:15:56',0,NULL,3,1,3,1,'RA184576870CN\r ','panosapos\rGLOT005'),(16816,593173503003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',15.19,'cnfaner','haughey2004','haughey1@aol.com','Joesph P. Haughey','2642 W Coolidge St','Phoenix','AZ','UNITED STATES','85017-3768','(928) 853-5720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 20:34:30',0,NULL,3,1,1,1,'\\ ','haughey2004'),(16817,803007710011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',1,'TRMX001',7.57,'eastar4','tyfn1979','tyfn1907@hotmail.com','Tayfun Bektaş','TCG KARAYEL<br>Aksaz Deniz Us K.ligi','Marmaris','MUĞLA / Turkey','TURKEY','48760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 20:44:28',0,NULL,3,1,2,1,'\\ ','tyfn1979'),(16818,803014733011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','stuj77','stuj77@hotmail.com','Stuart Johnson','16 Fairfield Court','Bishop Auckland','Durham','UNITED KINGDOM','DL149TG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 20:47:14',0,NULL,3,1,3,1,'RA184576755CN\r ','stuj77\rGLSG001'),(16819,803028098011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tracie22','tbeamish9@hotmail.com','Tracie Beamish','C/O Biffa Waste Services<br>Queen Street','Leeds','West Yorkshire','UNITED KINGDOM','LS26 8AL','01132867121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 21:02:30',0,NULL,3,1,3,1,' RA184576279CN\r','tracie22  英标\rHSJA002'),(16820,650751618013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',1,'UDAP004',22.99,'eastar4','www12345678ca','sales@12345678.ca','kwok p chan','152 pineway blvd.,','North York','ON','CANADA','M2H 1A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 21:16:38',0,NULL,3,1,2,1,'\\ ','www12345678ca'),(16821,803055510011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','zigos77','zigadlom@hotmail.com','zigadlo michael','24 rue leon baillot','bully les mines','Nord-Pas-de-Calais','FRANCE','62160','0663730884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 21:34:25',0,NULL,3,1,3,1,'RA117764331CN\r ','zigos77 欧标\rHSNO019'),(16822,759804993001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','teamcanada','terry.macheras@mercedes-benz.ca','Terry Macheras','5511 Windy Hill Court','Mississauga','ON','CANADA','L4Z 3W4','(905) 712-9898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 21:43:39',0,NULL,3,1,2,1,'\r\\ ','teamcanada'),(16823,803066265011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','mr_seductive','markv7773@hotmail.com','Mark VanLiew','521 Garfield Ave','Jersey City','NJ','UNITED STATES','07305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 21:50:11',0,NULL,3,1,1,1,'\\ ','mr_seductive'),(16824,803069364011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',134.99,'eastar4uk','jadeyspadey69','jadeyspadey69@hotmail.co.uk','JADE TODD','1 RAVINE CLOSE','HASTINGS','East Sussex','UNITED KINGDOM','TN34 2BH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 21:53:46',0,NULL,5,1,4,1,'YW867739822CN\r ','jadeyspadey69\rMOLO010\r\r发货了,但是点不了发货,所以就改成取消了.'),(16825,890032799012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',31.39,'eastar4uk','noka01','matheus.andrade@rocketmail.com','Matheus Andrade','R: Um, nº 40 - Residencial Alto da Boa Vista<br>Jd. Fortaleza','Paulinia','SP','BRAZIL','13140000','55 19 91049061','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 22:07:19',0,NULL,3,1,3,1,'RA117764362CN\r ','noka01\rLGFI001'),(16826,651257019013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','g.parham','teamglen1@gmail.com','glen parham','2575 Delk Rd SE','marietta','GA','UNITED STATES','30067-6584','(770) 853-5411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-27 22:35:06',0,NULL,3,1,3,1,'RA184576702CN\r','g.parham   '),(16827,742237382008,180708550469,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','frogsonthemats','steve.lemieux@emageon.com','Steve Lemieux','3431 Longview Dr','San Bruno','CA','UNITED STATES','94066-1651','(415) 577-5723','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 22:43:32',0,NULL,3,1,1,1,'\\ ','frogsonthemats'),(16828,651304974013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','aussie_nomad_girl','rhondda.davies@hotmail.com','Rhondda Davies','4 hobson st','stratford','Victoria','AUSTRALIA','3862','0351456433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 22:44:47',0,NULL,3,1,3,1,' RA184576605CN\r','aussie_nomad_girl\rGLOT001*4'),(16829,593259506003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',45.22,'cnfaner','lawnpride','lawnprideoxford@aol.com','richard berman','249 Davis Lake Dr','oxford','MI','UNITED STATES','48371-4707','(248) 252-2892','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 23:44:36',0,NULL,3,1,1,1,'\\ ','lawnpride'),(16830,890095218012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','ken70000','ken.farnsfield@btinternet.com','KEN SMITH','VILLAGE GREENS<br>39/41 MAIN ST. FARNSFIELD','NEWARK','NOTTINGHAMSHIRE','UNITED KINGDOM','NG228EF','01623882354','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 00:02:02',0,NULL,3,1,3,1,' RA184576185CN\r','ken70000\rHSJA010 \r英标'),(16831,803152970011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','ludmilak2780','ludmilak@walla.com','OLEG KUROCHKIN','52 ROSEGLEN CRESCENT','WINNIPEG','MB','CANADA','R3Y 1R5','(204) 489-9433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 00:37:23',0,NULL,3,1,2,1,'\\','ludmilak2780'),(16832,802850397002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','mnun8573','nunesmail@rogers.com','Mario Nunes','4106 Bishopstoke Lane','Mississauga','ON','CANADA','L4Z 1M5','(416) 578-1903','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 00:41:24',0,NULL,5,0,18,0,NULL,'mnun8573'),(16833,651342847013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','glc2428','glc2428@internode.on.net','Rob Mitchell','17 Macintosh St','Forster','New South Wales','AUSTRALIA','2428','0265552122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 00:33:09',0,NULL,3,1,3,1,'RA184576631CN\r','glc2428\rGLOT001*4'),(16834,651350377013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','wmtc3000','wmtc4000@comcast.net','William Kahrmann','3975 SW 192nd Ave','Aloha','OR','UNITED STATES','97007-1428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 00:59:42',0,NULL,3,1,3,1,'RA184576574CN\r','wmtc3000\rGLOT001*4'),(16835,8881322444059080,111,'Original Lowrance iFinder Expedition C GPS Full-Featured Colour Handheld',1,'GPS0003',108.99,'aliexpress','1005456562','ccassidy@iinet.net.au','Christopher Cassidy	','6/ 39 Mill Point Road','South Perth	','Western Australia	','AUSTRALIA','6151','+61 08 61427193',NULL,NULL,NULL,'2011-11-28 01:34:19',0,NULL,3,1,3,1,'RA184576720CN\r ','GPS0003 \r已经发了'),(16836,593291856003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','zmqureshi','zahid@freespiritcenter.com','Zahid Qureshi','1933 Rodney Dr<br>Apt 312','Los Angeles','CA','UNITED STATES','90027-3179','(646) 642-7645','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 01:34:39',0,NULL,3,1,1,1,'\\ ','zmqureshi'),(16837,598711601004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','motor-reman','jdzing@hotmail.com','Jeff Zingmark','3328 176th pl NE','Arlington','WA','UNITED STATES','98223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 01:35:14',0,NULL,8,1,17,1,NULL,'motor-reman'),(16862,651439646013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 07:17:40',0,NULL,3,1,2,1,'\\  ','axonalex'),(16838,8881322444304766,111,'New WMN2000C Ultra Slim Wall Mount 58\" - 65\" TV',1,'MOSA006',71.99,'aliexpress','1005459648','tanboonyong@hotmail.com','Boon Yong Tan	','Blk 957, Hougang Street 91. #15-278','Singapore','','SINGAPORE','530957','+65 93854535',NULL,NULL,NULL,'2011-11-28 01:38:24',0,NULL,5,1,3,0,NULL,'MOSA006'),(16839,598712819004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','motor-reman','jdzing@hotmail.com','Jeff Zingmark','3328 176th pl NE','Arlington','WA','UNITED STATES','98223','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 01:38:59',0,NULL,3,1,1,1,'\\ ','motor-reman\r一共发两个耳机'),(16840,651327181013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',18.99,'eastar4','saranshayne','sarasiami@fastmail.net','Sara Siami','2/14 Harvey Street','Marleston','South Australia','AUSTRALIA','5033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 02:05:25',0,NULL,3,1,11,1,' BJ01085202\r','saranshayne'),(16841,593302083003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','lookalikedesignerjewelry','lb@lookalikedesignerjewelry.com','Laurie Puleri','511 SE 5th Ave<br>Apt 704','Fort Lauderdale','FL','UNITED STATES','33301-2968','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'lookalikedesignerjewelry\recheck'),(16842,598732277004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','allthegear!noidea','noidea@rocketmail.com','rene brown','4001 garienda ave','sebring','fl','UNITED STATES','33872-1904','(863) 382-9586','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 02:40:44',0,NULL,3,1,1,1,'\\ ','allthegear!noidea'),(16843,598732650004,140618876306,'GENUINE Plantronics Voyager 510  Bluetooth Headset',1,'HSPL010',31.34,'cnfaner','buckshot0721','dannylong1951@yahoo.com','DANNY LONG','109 County Road 513<br>Box 12','ENGLEWOOD','TN','UNITED STATES','37329-5216','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 02:46:48',0,NULL,3,1,1,1,'\\ ','buckshot0721\r银色的'),(16844,593319177003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','jab_joe','si12volt1@cox.net','Alfred Gray','130 Avenida De La Grulla<br>Apt A','San Clemente','CA','UNITED STATES','92672-9110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 03:09:21',0,NULL,3,1,1,1,'\\ ','jab_joe'),(16845,8881322449874005,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',0,'eastar4','homerwars','homerwars@hotmail.com','RENAUD Alexandre','1 rue Anatole france','mainvilliers','Centre','FRANCE','28300','0675676219',NULL,NULL,NULL,'2011-11-28 03:11:14',0,NULL,3,1,2,1,'、',' '),(16846,890190653012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',2,'OTGR001',39.8,'eastar4','shotie-450','shotie450@hotmail.com','Fred Fleming','1 Epping Street<br>Glenroy','Melbourne','Victoria','AUSTRALIA','3046','0393591220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 03:28:12',0,NULL,3,1,3,1,'RA184576897CN\r ','shotie-450\rOTGR001'),(16847,803217848011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','webtek33','curtis@webteknologie.com','Raymond McBroom','2356 E McNeese St','Lake Charles','LA','UNITED STATES','70607-5030','(337) 990-1234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 03:12:39',0,NULL,3,1,1,1,'\\ ','webtek33'),(16848,803224686011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','greenevg777','emoskal@mail.ru','Moskalenko Evgeniy','Sadovaya, 13','Alekseevka','Belgorod region','RUSSIAN FEDERATION','309850','+79205530018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 03:32:51',0,NULL,3,1,2,1,'\\  ','greenevg777'),(16849,803227268011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','shailukulkarni','shaykulkarni@gmail.com','Shailu Kulkarni','1805 Coliseum St<br>Apt 4','New Orleans','LA','UNITED STATES','70130-5139','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 03:43:04',0,NULL,3,1,1,1,'\\ ','shailukulkarni'),(16850,593328274003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','afro7176','dakotaaleisha@yahoo.com','Aleisha Frohlich','1807 N 8th St','Bismarck','ND','UNITED STATES','58501','(701) 391-8202','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 03:44:56',0,NULL,3,1,1,1,'\\ ','afro7176\rOEM的'),(16851,748833689007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','vjeepred','gramavi@hotmail.com','Viorel Grama','3646 Irongate Circle','Windsor','ON','CANADA','n8x 5t4','(519) 980-1307','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 03:48:10',0,NULL,3,1,11,1,'\\ ','vjeepred\rUM00042'),(16852,593329994003,130531507230,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',19,'SCLO001',330.6,'cnfaner','4278dennis','dennis.rhem@gmail.com','DENNIS RHEM','16017 Snowdonia Cv','Bee Cave','TX','UNITED STATES','78738-4001','(512) 574-4595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 03:52:52',0,NULL,3,1,1,1,'、 ','4278dennis'),(16853,8881322454088982,111,'clear transparent dome berdcage rain umberlla w/pattern',1,'UM00033',0,'eastar4','2011stasy777','stasy777@mail.ru','Anastasiya Shishin','abba hilel silver 119\\61 ','Haifa','Haifa','ISRAEL','32697','',NULL,NULL,NULL,'2011-11-28 04:21:28',0,NULL,3,1,11,1,'\\ ','可以发了'),(16854,803240773011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','got_it_4cheap1','gr8cheapdeals4u@gmail.com','CHRIS HAYDEN','1310 N Capitol Ave','INDIANAPOLIS','IN','UNITED STATES','46202-2314','(317) 332-6046','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 04:25:44',0,NULL,3,1,1,1,'\\ ','got_it_4cheap1'),(16855,802941911002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','mommycin','311cin@comcast.net','Cynthia Ponce','20 Stonegate Ln','American Canyon','CA','UNITED STATES','94503-3932','(707) 980-7772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 04:33:46',0,NULL,3,1,1,1,'\\ ','mommycin'),(16856,803249300011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','11nadim10','nbb10@mail.ru','Nadim Babayev','Nizami 114','Baki','','AZERBAIJAN','AZ 1010','+994709950050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 04:59:33',0,NULL,3,0,2,1,'\\  ','11nadim10'),(16857,890221008012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',2,'GPS0009',319.98,'eastar4','dus1993','shanira93@gmail.com','shanira silva','323/G,Batagama-north,Ja-ela.','Ja-ela','Western','SRI LANKA','11350','+94711507288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 05:05:23',0,NULL,3,1,6,1,'EE491015710CN ','dus1993'),(16858,651423166013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','dcwholesale','admin@dcwholesale.co.nz','Anthony Payne','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 05:15:12',0,NULL,3,1,2,1,'\\  ','dcwholesale  CAB-6060'),(16859,890225937012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','mr.up','mr.up@mail.ru','Yuriy Prokopyuk','91/2 Mechnikova str.','Taraz','Zhambylskaya oblast','KAZAKHSTAN','080000','+77772253590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 05:23:45',0,NULL,3,1,3,1,' RA184576680CN\r','mr.up\rOTSO004*2'),(16860,651429203013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','andreyzhukov19702707','andreyandrey19702707@yandex.com','Zhukov Andrey','Trofimova 10-49','Yubileiniy','Moscow region','RUSSIAN FEDERATION','141091','(926)2076055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 05:52:42',0,NULL,3,1,3,1,'RA184576818CN\r ','andreyzhukov19702707\rLGAD001'),(16861,8881322461746143,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',4,'BALO007',0,'eastar4','vejaika','serj_osipov@mail.ru','serj osipov','Turistskaya street<br>dom 31 corp.1 kvartira 78','Moscow','','RUSSIAN FEDERATION','125480','+7-(495)-494-8846',NULL,NULL,NULL,'2011-11-28 06:29:06',0,NULL,3,1,3,1,'RA184576945CN\r',' 补货\rBALO007  已经发了'),(16863,890260232012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.88,'eastar4','romanulis378','romanulis@yahoo.gr','Romanos Ellinidis','Thermopilon  7','Alexandrupolis','Evros','GREECE','68100','00302551081243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 07:54:15',0,NULL,3,1,2,1,'\\  ','romanulis378 acer 8pin1.00 18cm'),(16864,890260895012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','jamiec2007','mkc8888@hotmail.com','Jamie Chew','2615 Cambridge St.','Vancouver','BC','CANADA','V5K 1L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:24:46',0,NULL,3,1,3,1,'RA117764420CN\r ','jamiec2007  GLOT001*2\r'),(16865,8881322469175484,111,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',0,'eastar4','e-saleandbuy','ebay@itisit.co.uk','John Ballard','8 Beechwood Drive','Cobham','Surrey','UNITED KINGDOM','KT11 2DX','01372849668',NULL,NULL,NULL,'2011-11-28 08:32:55',0,NULL,3,1,2,1,'\\  ',NULL),(16866,890287839012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','gad_auctions','gadauctions@aol.com','John Richardson','59 Fairway Drive','Hempstead','NY','UNITED STATES','11550','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 09:33:19',0,NULL,3,1,1,1,'\\  ','gad_auctions'),(16867,803336272011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','samahat2004','hatem_elkholy@hotmail.com','Hatem Elkholy','Ebnsina medical P.O.Box 337 Julphar office floor no 9<br>Hatem Elkholy','Doha','Ebnsina medical','QATAR','337','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 10:47:37',0,NULL,3,1,3,1,'RA117764291CN\r ','samahat2004\rOTSO004'),(16868,760061984001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','gmb777footy','gregandjennefer2009@bigpond.com','greg berger','11 howson st<br>lockyer','albany','Western Australia','AUSTRALIA','6330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 10:57:10',0,NULL,3,1,2,1,'\\  ','gmb777footy'),(16869,803335781011,320721387914,'New Jabra BT125 BT 125 wireless Bluetooth Headset',1,'HSJA006',13.95,'eastar4','axixd','nik.grushin@gmail.com','Nikolay Grushin','Turgeneva str 30','N.Novgorod','','RUSSIAN FEDERATION','603000','89082303539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 11:32:05',0,NULL,3,1,2,1,'、 ','axixd  欧标\r）欧标\r'),(16870,803349957011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','sheruimov','vittl@mail.ru','Vitaliy Sheruimov','Eset-Batyra 146/14','Aktobe','','KAZAKHSTAN','030019','+77132546186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 11:32:46',0,NULL,3,1,2,1,'\\  ','sheruimov'),(16871,742468098008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'au-buy','khomenko_vadim','khomenko.vadim@gmail.com','Vadim Khomenko','av. Heroiv Stalingrada 13a, app. 295','Kiev','Kiev region','UKRAINE','04210','0930953830','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 11:44:44',0,NULL,3,1,2,1,'\\  ','khomenko_vadim'),(16872,651502654013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','cenkgursoy','cenk.gursoy@gmail.com','Cenk Gürsoy','Birlik mahallesi 409. sokak No:7 Cankaya','ANKARA','N/A','TURKEY','06610','+903124400407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 12:13:08',0,NULL,3,1,3,1,'RA117764265CN\r ','cenkgursoy  LGGL002'),(16873,890356956012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.39,'eastar4','franksennvanbasel','sennvanbasel@gmail.com','Frank Senn van Basel','Cortenaerstraat 3','Geleen','','NETHERLANDS','6163XS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 12:52:17',0,NULL,3,1,2,1,'\\  ','franksennvanbasel\rAcer 5pin1.25 3cm'),(16874,651514749013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','gushchyn2005','gushchyn@gmail.com','Peter Gushchyn','Yom Hakipurim 20<br>Appartment 10','Holon','','ISRAEL','58485','+972544678381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 13:00:17',0,NULL,3,1,2,1,'\\  ','gushchyn2005'),(16875,651517391013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','nikki88dk','nikki88dk@aol.com','Nicole Tyler','219 Webster St','Lewiston','ME','UNITED STATES','04240-5547','(207) 786-3283','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 13:08:54',0,NULL,3,1,3,1,'RA117778415CN ','nikki88dk  GLOT001*4\r'),(16876,593438216003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',3,'WLAT003',44.4,'cnfaner','insong94','bongjulee@empal.com','Bong-Ju Lee','113-704 Thesharp CentumPark 1 Cha Apt.,<br>Jaesong 1-dong ,Haeundae-gu,','Busan','','KOREA,REPUBLIC OF','612-712','82-11-831-9461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 13:23:47',0,NULL,3,1,3,1,'RA117764186CN\r ','insong94\rWLAT003'),(16877,803391924011,320786773775,'New iTech Clip II mini Multipoint Bluetooth Headset white',1,'HSIT003',21.99,'eastar4uk','majorie4','gardnerjohn2@aol.com','john gardner','37 railway ave','whitstable','kent','UNITED KINGDOM','ct5 1ll','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 13:29:07',0,NULL,3,1,3,1,'RA117764359CN\r ','majorie4\rHSIT003 白色的 英标'),(16878,742512156008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',50.26,'au-buy','iceool333','icecool33@hotmail.com','JOSÉ CARLOS CLAUSEN JUNIOR','ORLANDO MARRONI, 11<br>BLOCO 2, APTO 24','VALINHOS','São Paulo','BRAZIL','13272-101','55 19 9345 8412','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 13:53:13',0,NULL,3,1,3,1,'RA117764124CN\r ','iceool333\rHSPL015'),(16879,803409215011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',2,'HSNO007',27.96,'eastar4','hikmat68','kazimovhikmat@rambler.ru','Hikmat Kazimov','Nizami str. 114','Baku','Baku','AZERBAIJAN','AZ 1010','+994503471919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 14:12:00',0,NULL,3,1,2,1,'\\  ','hikmat68 欧标'),(16880,803413562011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',52.99,'eastar4','marcelo.baumgarten','garten@gmail.com','Marcelo Zepka Baumgarten','Avenida Loureiro da Silva, 1500, Ap. 402','Porto Alegre','Rio Grande do Sul','BRAZIL','90050-240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 14:23:33',0,NULL,3,1,3,1,'RA117764190CN\r ','marcelo.baumgarten     LGRM001  新地址\rCamila Balbela Consoni\rAv. Carlos Gomes, 111 conj. 703 \rPorto Alegre, Rio Grande do Sul \r90480-003\rBrazil'),(16881,890414717012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','yortschek2011','olivier.berchtold@gmx.ch','Olivier Berchtold','Murhaldenweg 14','Zürich','','SWITZERLAND','8057','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 15:05:48',0,NULL,3,1,2,1,'\\  ','yortschek2011'),(16882,803129121002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','amanjeral12345','amanjeral@gmail.com','angel alvarez','1060 W 74th St<br>Apt 113','hialeah','FL','UNITED STATES','33014-4658','(786) 953-7692','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 15:16:03',0,NULL,3,1,1,1,'\\  ','amanjeral12345'),(16883,890420914012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','2722ianm','ian-mace@sky.com','alison honeywood','6 bloomfield  way','lowestoft','Suffolk','UNITED KINGDOM','nr338th','01502565773','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 15:22:47',0,NULL,3,1,3,1,'RA117764393CN\r ','2722ianm  OTSO004*4'),(16884,890423932012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','schwarzerose-berlin','heckler87@gmail.com','Benus IT-Service AG z.hd. Sascha Drobniewski','Volmerstraße 9','Berlin','','GERMANY','12489','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 15:26:50',0,NULL,3,1,2,1,'\\  ','schwarzerose-berlin  欧标'),(16885,742552897008,180758271107,'Original Logitech MX1100 Mouse Mat 3M material',2,'SCLO005',11.8,'au-buy','steve-of-ohio','stevehowardofohio@hotmail.com','Steven L. Howard','3855 Holbein Dr','Zanesville','OH','UNITED STATES','43701-8715','(740) 453-6373','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 15:32:28',0,NULL,3,1,1,1,'\\  ','steve-of-ohio'),(16886,750163116007,170728978814,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',54.59,'au-buy','dschwarz64','dietmar_schwarz@mac.com','Dietmar Schwarz Webers','Abasolo 64 Casa 24<br>Col. Tepepan','Mexico','DF','MEXICO','16020','+5215591986559','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 15:47:30',0,NULL,3,1,3,1,'RA117764141CN\r ','dschwarz64\rLGRM001'),(16887,598902871004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','potamus9','pottamuss@gmail.com','Gamze Ligler','75 State Road 78','Mount Horeb','WI','UNITED STATES','53572-3122','(608) 523-4346','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 15:55:23',0,NULL,3,1,1,1,'\\  ','potamus9'),(16888,803454274011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','purplejenn4321','purplejenn63@yahoo.com','jennifer howie','25 Little Ln','walden','NY','UNITED STATES','12586-1064','(845) 778-4523','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 15:55:44',0,NULL,3,1,1,1,'\\ ','purplejenn4321'),(16889,803463182011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','rwoods1603','rachelnewton115@btinternet.com','Rachel Woods','6 Churchill Gardens','Poole','Dorset','UNITED KINGDOM','BH12 2HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 16:13:44',0,NULL,3,1,3,1,'RA117764447CN\r ','rwoods1603\rGLOT001\r兼容眼镜通用型'),(16890,651575507013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','pura_mexicana','pura_mexicana@hotmail.com','Maria E Lira','5308 Oates Road','Houston','TX','UNITED STATES','77013','(713) 671-0040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 16:15:17',0,NULL,3,1,3,1,'RA117778494CN ','pura_mexicana  GLOT001*4\r'),(16891,803459886011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',2,'TRMX002',15.14,'eastar4','restor-2008','jim.klaczko@restortelecom.com','Jim Klaczko','917 Venture Ave<br>Restor Telecom, Inc.','Leesburg','FL','UNITED STATES','34748-6631','(352) 314-1714','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 16:19:30',0,NULL,3,1,1,1,'\\  ','restor-2008'),(16892,651583853013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','soyyoquepasa','marcelino.glez@gmail.com','Marcelino González Rodríguez','Juan Ramón Jiménez 8 1º','Oviedo','Asturias','SPAIN','33013','645826740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 16:36:03',0,NULL,3,1,2,1,'\\  ','soyyoquepasa CAB-6060'),(16893,651584832013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','adri203','a_alonso83@hotmail.com','adrian romero','1290 norman st','Bridgeport','CT','UNITED STATES','06604','(203) 395-9639 ext.: 203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 16:38:27',0,NULL,3,1,3,1,'RA117778503CN ','adri203 GLOT001*4'),(16894,593497737003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','s4quatro','yary@miszone.com','Yary Mordkovich','7 Stuart St','WALDWICK','NJ','UNITED STATES','07463-2418','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 16:53:32',0,NULL,3,1,1,1,'\\  ','s4quatro\rOEM的'),(16895,890475404012,220815929558,'New brand Jabra BT125 Bluetooth headset BT 125',1,'HSJA006',8.99,'eastar4uk','viktorgnikolov','nikolov.viktor320@gmail.com','Viktor Nikolov','Nikola Petkov 2','Sofia','vMalo Buchino','BULGARIA','1362','00359885356075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 16:58:26',0,NULL,3,1,2,1,'、','viktorgnikolov\r（保加利亚）欧标\r'),(16896,593505259003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','novasboy1138','novasboy@gmail.com','Benjamin Tietjens','2236 Cambridge Ave','Charleston','SC','UNITED STATES','29405-7697','(843) 642-1473','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 16:59:56',0,NULL,3,1,1,1,'\\  ','novasboy1138'),(16897,890494178012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',2,'OTKE001',191.98,'eastar4','tiengotop','lucianotiengo@hotmail.com','Luciano Tiengo','Rua Amazonas, 88 - Centro','Águas de Lindóia','São Paulo','BRAZIL','13940-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 17:27:21',0,NULL,3,1,3,1,'RA117764495CN ','tiengotop'),(16898,760219677001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','nigelh1985','nigelheap@btinternet.com','NIGEL HEAP','10 PARK CLOSE<br>NATLAND','KENDAL','Cumbria','UNITED KINGDOM','LA9 7QE','01539561190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 17:36:04',0,NULL,3,1,2,1,'\\  ','nigelh1985'),(16899,890501762012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','jasonperry041986','jasonperry04@yahoo.com','Jason Rugg','920 N Old Highway 71','Adrian','MO','UNITED STATES','64720-8326','(660) 424-0780','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 17:39:43',0,NULL,3,1,1,1,'\\  ','jasonperry041986'),(16900,651617628013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','pergeo','georgco@fuse.net','Peri D Georgiades','1927 Wilaray Ter','Cincinnati','OH','UNITED STATES','45230-1936','(513) 231-8806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 17:58:21',0,NULL,3,1,3,1,'RA117778548CN ','pergeo  GLOT001*4'),(16901,803522510011,320700100689,'NIB cisco Linksys DMP100 Wireless-N Music Extender',1,'OTLK001',119,'eastar4','jeffkaiser','jeffrey.l.kaiser@gmail.com','Jeffrey Kaiser','6692 Lakeway St','Ypsilanti','MI','UNITED STATES','48197-1055','(734) 340-3775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 18:04:44',0,NULL,3,1,4,1,'YW867739800CN ','jeffkaiser'),(16902,760237204001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','pergeo','georgco@fuse.net','Peri D Georgiades','1927 Wilaray Ter','Cincinnati','OH','UNITED STATES','45230-1936','(513) 231-8806','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 18:07:02',0,NULL,3,1,1,1,'\\  ','pergeo'),(16903,890529205012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','f-0-z-z-y','89217427920@bk.ru','Mikhail Plekhanov','Bolsheohtinsky<br>39-48','Sain-Peterburg','','RUSSIAN FEDERATION','195027','(921)742-79-20','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 18:20:35',0,NULL,3,1,3,1,'RA117764172CN\r ','f-0-z-z-y  WWOT001'),(16904,651634964013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',27.99,'eastar4','mekesh_v','vladimir@mekesh.ru','Vladimir Mekesh','Soyuznaya street 8-19','Odintsovo','Moscow Region','RUSSIAN FEDERATION','143006','+7-916-775-77555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 18:33:09',0,NULL,3,1,2,1,'\\  ','mekesh_v'),(16905,651641469013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','vivasantu','s.santucci@vzw.blackberry.net','steven santucci','380 hitchcock rd<br>unit 147','waterbury','CT','UNITED STATES','06705-3956','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 18:46:15',0,NULL,3,1,1,1,'\\ ','vivasantu'),(16906,803572038011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',55.98,'eastar4','adelinehjalmers','haloberg@earthlink.net','holly loberg','12510 Adams Run Dr','Cypress','TX','UNITED STATES','77429-3257','(713) 459-3921','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 19:12:56',0,NULL,3,1,1,1,'\\  ','adelinehjalmers  再发LG AG-F210 3D Cinema Series Glasses 2 Pack\r'),(16907,803575006011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',21.99,'eastar4uk','georgeuoa1','georgeuoa@yahoo.com','George Konaxis','Erythrou Stavrou 87','Drapetsona','Greece','GREECE','18648','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 19:21:53',0,NULL,3,1,2,1,'\\  ','georgeuoa1\r黑色的\r欧标'),(16908,750310661007,170728978931,'Original Lowrance iFinder Expedition C GPS Full-Featured Colour Handheld',1,'GPS0003',106.99,'au-buy','go_demons','mcnab.scott@gmail.com','scott mcnab','1538 frankston-flinders rd','tyabb','victoria','AUSTRALIA','3913','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 19:53:02',0,NULL,3,1,3,1,'RA117764288CN\r ','go_demons\rGPS003'),(16909,803602974011,320730089180,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',35.99,'eastar4uk','littlenotty','crosscountrycouriers@tiscali.co.uk','MANDY NOTT','10 MOUNT PLEASANT AVENUE','TODDINGTON','Bedfordshire','UNITED KINGDOM','LU5 6EH','01525875708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 19:54:06',0,NULL,3,1,3,1,'RA117764274CN\r ','littlenotty\rHSPL015\r英标'),(16910,651681150013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','faustocoppi','peter.erdoes@gte.net','Peter Erdoes','21 E Main St<br>Ste 101','Oklahoma City','OK','UNITED STATES','73104-2400','(405) 232-3533','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 19:57:33',0,NULL,3,1,3,1,'RA117778517CN ','faustocoppi  GLOT001*4'),(16911,803614049011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','radioboi','noah.miller@world.oberlin.edu','Noah Miller, outLoud Radio','1310 Mission St','San Francisco','CA','UNITED STATES','94103-2609','(415) 658-6010 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 20:10:12',0,NULL,3,1,1,1,'\\  ','radioboi'),(16912,803610331011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','florianer54','mdparachevement@gmail.com','moreau dylane','13 rue du chateau','saint-leger','','BELGIUM','6747','0496975750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 20:23:20',0,NULL,3,1,3,1,'RA117764433CN\r ','florianer54\rGLOT001\r兼容眼镜通用型'),(16913,803627406011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',21.99,'eastar4','berjon2011','ronimilla@yahoo.com','Berjon Milla','komuna e parisit<br>kulla 5 ap. 11/b','Tirana','Albania','ALBANIA','1010','+355672241168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:25:51',0,NULL,3,1,2,1,'\\  ','berjon2011'),(16914,592449940003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','nadnevak','sijanm@pims.org','Marko Sijan','Stupnicka 16','Zagreb','','CROATIA','10000','0038516191461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:30:17',0,NULL,3,1,3,1,'RA117764138CN\r ','nadnevak\rOTES001'),(16915,760338481001,110701383504,'NIB CBS High Pressure Portable Car Washer wash',1,'CAWA001',69.9,'buysia','sukaba','sabirov.t.t@gmail.com','Timur Sabirov','Cheliabinskaya street, house 11, building 1, flat 52<br>Челябинская улица, дом 11, корпус 1, квартира 52','Moscow','RUSSIA','RUSSIAN FEDERATION','105568','8(910)422-77-15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:33:48',0,NULL,3,1,3,1,'RA117764760CN ','sukaba\rCAWA001'),(16916,651719999013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','barnes202','tre8ball2000@yahoo.com','Paul  Barnes','12814 Staton Ct','Upper Marlboro','MD','UNITED STATES','20774-1716','(202) 708-0614 ext.: 5034','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 21:07:23',0,NULL,3,1,3,1,'RA117778446CN ','barnes202  GLOT001*4\r'),(16917,593629101003,130592183281,'New Logitech H555 981-000262 Headset Stereo for laptop',1,'HSLO001',35.59,'cnfaner','bronzewings7','aberdeen007@aol.com','Amber Snow','2440 Wheeler Rd','Auburn','MI','UNITED STATES','48611-9527','(989) 859-9520','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 21:21:32',0,NULL,3,1,1,1,'\\  ','bronzewings7'),(16918,803671851011,320679568138,'NewGenuine SonyEricsson HBH-PV702 702 Bluetooth Headset',1,'HSSE003',13.9,'eastar4uk','rob250399','hheathpfloored@aol.com','Robert Clarke','12 Hollyacres','Worthing','West Sussex','UNITED KINGDOM','BN13 3TD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 21:32:20',0,NULL,3,1,3,1,'RA117764257CN\r ','rob250399\rHSSE003\r英标'),(16919,803677804011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.96,'eastar4','lblplus18h8','lblplus@aol.com','James kapsis','14 ridge road','Albertson','NY','UNITED STATES','11507','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 21:39:02',0,NULL,3,1,1,1,'\\  ','lblplus18h8'),(16920,750384814007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','eblend','eblend@hotmail.com','Dmitri Bobko','318 Everglen Rise SW','Calgary','AB','CANADA','T2Y5E7','(403) 607-0176','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 21:40:11',0,NULL,3,1,2,1,'\\  ','eblend'),(16921,890692178012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','jto671002','john@owen-uk.com','John Owen','The Tiled Cottage<br>33 Woodside Road','Beaconsfield','Buckinghamshire','UNITED KINGDOM','HP9 1JW','01494681660','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 21:51:01',0,NULL,3,1,3,1,'RA117764305CN\r ','jto671002\rOTGR001'),(16922,742778138008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT006',85.48,'au-buy','shinai.kajukenpo','cheryldalziel@live.com','Cheryl Dalziel','74 Heather Drive','Milton Station','PE','CANADA','C1E0N4','(902) 940-5095','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 21:51:13',0,NULL,3,1,3,1,'RA117764226CN\r ','shinai.kajukenpo\rGLOT006'),(16923,803687670011,320737041206,'4 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*4',127.99,'eastar4uk','cuerpo1974','agomezci@hotmail.com','Antonio Gomez CIdoncha','Montera,12','Don Benito','Badajoz','SPAIN','06400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 21:56:57',0,NULL,3,1,3,1,'RA117764504CN ','cuerpo1974\rGLOT005*4'),(16924,890700190012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','2011skibear','cynthiamcfadden85@yahoo.com','Cynthia Mcfadden','5541 Cedonia Ave','Baltimore','MD','UNITED STATES','21206-3852','(410) 483-2884','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 22:02:14',0,NULL,3,1,1,1,'\\ ','2011skibear'),(16925,890703060012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','skyrets7387','contactony@hotmail.co.uk','Tony Plahe','35 Rosemary Avenue','Hounslow West','Middlesex','UNITED KINGDOM','TW4 7JQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 22:08:11',0,NULL,3,1,3,1,'RA117764155CN\r ','skyrets7387\rOTGR001+OTGR002'),(16926,593648670003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',29.92,'cnfaner','jdub116','sweetwaters116@aol.com','Jerry Waters','1979 Christian Ln','Kinston','NC','UNITED STATES','28504-7521','(252) 939-1603','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 22:08:53',0,NULL,3,1,1,1,'、 ','jdub116'),(16927,890708072012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','beaganart','artbeagan@comcast.net','Arthur Beagan','9 Chatfield Dr','Beacon Falls','CT','UNITED STATES','06403-1482','(203) 451-0143','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 22:19:18',0,NULL,3,1,1,1,'\\  ','beaganart'),(16928,890714186012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','mitzk2006','mit24t7@hotmail.com','Mitesh Khimani','24 Cecil Road','Harrow','London','UNITED KINGDOM','HA3 5RA','02088638479','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 22:27:00',0,NULL,3,1,3,1,'RA117764169CN\r ','mitzk2006\rWLAT009'),(16929,742803447008,180699062138,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',42.75,'au-buy','mcscrufff','boyd.murray1@gmail.com','Boyd Murray','9 Bedford Road','NORTH EPPING','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 22:32:25',0,NULL,3,1,3,1,'RA117764230CN\r ','mcscrufff\rOTPL001'),(16930,599080516004,140584762584,'New HP Atheros AR5BXB72 AR5008 MINI PCI-E card',1,'WLAT004',22.79,'cnfaner','vidki','trecbernard@mchsi.com','Howard Bernard','1360 S. Avenue B','Canton','IL','UNITED STATES','61520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 22:36:04',0,NULL,3,1,1,1,'\\  ','vidki'),(16931,750418196007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','schmittytims','timothy.schmidt@ci.stpaul.mn.us','Tim Schmidt','646 Dundee Ave','River Falls','WI','UNITED STATES','54022-5793','(651) 955-3189','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 22:41:02',0,NULL,3,1,1,1,'\\  ','schmittytims'),(16932,599084701004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',1,'HSJA004',18.98,'cnfaner','4561colleen','cmalchow1@new.rr.com','Bruce Bellin','N2586 Maloney Rd','Freedom','WI','UNITED STATES','54130-8667','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 22:47:24',0,NULL,3,1,1,1,'\\  ','4561colleen'),(16933,890731946012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',33.99,'eastar4uk','leung1954','raymondleung518@hotmail.com','raymond leung','14 hollyoak road','sutton coldfield','West Midlands','UNITED KINGDOM','B742FG','01215808288','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 22:57:45',0,NULL,3,1,3,1,'RA117764243CN\r ','leung1954\rHSPL013\r英标'),(16934,890739584012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','962michael','mikerea@wowway.com','Michael Rea','376 Lange Dr','Troy','MI','UNITED STATES','48098-4624','(248) 844-9055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-28 23:15:35',0,NULL,3,1,1,1,'\\  ','962michael'),(16935,599103304004,140626376379,'New HP Media Center receiver+microsoft Remote Control',2,'OTHP006',34.8,'cnfaner','theonlygoofyone','slimjim1717@gmail.com','Douglas Hartman','7441 Oak St NE','Saint Petersburg','FL','UNITED STATES','33702-5443','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 23:48:03',0,NULL,3,1,1,1,'\\  ','theonlygoofyone'),(16936,760450028001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','jay4rose','jnraebly@bellsouth.net','rose aebly','21572 SW PeachBlossom St.','Dunnellon','FL','UNITED STATES','34431','(352) 489-0175','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 00:11:09',0,NULL,3,1,1,1,'\\  ','jay4rose'),(16937,599111073004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','julinda06','corsinijuliana@gmail.com','juliana corsini','5182 millenia blvd<br>Apt 306','Orlando','FL','UNITED STATES','32839-6000','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-29 00:17:55',0,NULL,3,1,1,1,'\\ ','julinda06'),(16938,596512892004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','macku','mack63@gmail.com','Mack Utley','2504 Chestnut Oak Rd','Kuttawa','KY','UNITED STATES','42055','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-29 00:30:36',0,NULL,3,1,1,1,'\\  ','macku\rOTHP004'),(16939,890777505012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','kimchooky','j.chick1@hotmail.com','kim steer','21 bell street','bundaberg','Queensland','AUSTRALIA','4670','0741518629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 00:40:10',0,NULL,3,1,3,1,'RA117764455CN\r ','kimchooky  GLOT001*2'),(16940,742853889008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','pucciacharron','pucciacharron@excite.com','Angela Puccia','180 Manners Ave','Willimantic','CT','UNITED STATES','06226-3553','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 00:41:18',0,NULL,3,1,1,1,'\\ ','pucciacharron'),(16941,890777685012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','eduardo_dias','eduardodias.2@gmail.com','Eduardo Pereira Dias','Rua Doutor Renato Bueno Netto, 690<br>Campo Limpo','São Paulo','São Paulo','BRAZIL','05767-350','11 8420-9099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 00:43:57',0,NULL,3,1,3,1,'RA117764212CN\r ','eduardo_dias  OTSO004*2'),(16942,651802389013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','diamondwoman','lkalemba@roadrunner.com','Lynda   Kalemba','1922 Coventry Dr','Brunswick','OH','UNITED STATES','44212-4186','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 00:48:35',0,NULL,3,1,3,1,'RA117778450CN ','diamondwoman   GLOT001*4'),(16943,890782685012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','d2chan','d2chan@rogers.com','Dunstan Chan','49 Dylan Street','Woodbridge','ON','CANADA','L4H2X5','(905) 653-5761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 00:52:42',0,NULL,3,1,2,1,'\\  ','d2chan'),(16944,803733185011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','lizajane560','tom.lisa27@gmail.com','Lisa Daley','27 Cliff Dr','Assonet','MA','UNITED STATES','02702','(774) 365-9379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 00:54:17',0,NULL,3,1,1,1,'\\  ','lizajane560'),(16945,890796298012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','carolinatradingsystems','bknollphone@yahoo.com','Brian Knoll','55 Station Lndg<br>Apt 319','Medford','MA','UNITED STATES','02155-5027','(617) 963-6634','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 01:25:39',0,NULL,3,1,1,1,'\\  ','carolinatradingsystems'),(16946,803782761011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','greencamry','yellow79classic1@verizon.net','James Epps Jr.','7807 Balineen Ct','Richmond','VA','UNITED STATES','23228-6425','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 01:38:16',0,NULL,3,1,1,1,'\\  ','greencamry'),(16947,651820191013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','d_auger','dauger@maskatel.net','David Auger','2230 Impasse Fleury','St-Hyacinthe','QC','CANADA','J2S 8M9','(450) 774-2605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 01:55:39',0,NULL,3,1,3,1,'RA117778429CN ','d_auger  GLOT001*4\r'),(16948,803793879011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',52.99,'eastar4','galandeer','paco.orte@gmail.com','Frank Ortega','50 graydon Hall<br>Apartament # 1003','North York','ON','CANADA','M3A 3A4','(647) 402-2130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 02:04:59',0,NULL,3,1,3,1,'RA117764115CN\r ','galandeer  LGRM001\r'),(16949,593717975003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','amguin','amamam@gmail.com','Akarawat Arthimokyothin','1291/1 Shinawatra Tower2(14) Phaholyothin Rd.,','phayathai','Bangkok','THAILAND','10400','+66813727733','NoPaymentFailure','CheckoutComplete','NotSelected','2011-11-29 02:06:20',0,NULL,3,1,3,1,'RA117764209CN\r ','amguin  OEM'),(16950,8881322533502902,111,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',16.99,'aliexpress','1005477734','andreccipriano@hotmail.com','Andre Cipriano	','Rua Professor Arnaldo Joao Semeraro, 621 bloco 5 apto 43','Sao Paulo	','','BRAZIL','04184000','+55 11 23350355',NULL,NULL,NULL,'2011-11-29 02:25:02',0,NULL,3,1,3,1,'RA117778375CN ','LGGL001 '),(16951,750514844007,170730544737,'Logitech Charging Cradle L-LG7 for Harmony 880 890 Pro',1,'CRLO002',9.9,'au-buy','whoseline','fyrebyte@yahoo.com','Bradford Holman','420 NE 10th St','Oklahoma City','OK','UNITED STATES','73104-3222','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 02:59:57',0,NULL,3,1,1,1,'\\  ','whoseline'),(16952,803818745011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','fashistxxx','2006s2006@mail.ru','Sergey Nemtsev','Neibuta 24 - 66','Vladivostok','Primorskii krai','RUSSIAN FEDERATION','690109','89242300899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 03:19:49',0,NULL,3,1,3,1,'RA117764380CN\r ','fashistxxx  OTSO004\r'),(16953,803514830002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','angelatalotta','atalotta@sccoast.net','ANGELA TALOTTA','6993 Woodhaven Dr','MYRTLE BEACH','SC','UNITED STATES','29588-6749','(843) 455-3095','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 03:31:13',0,NULL,3,1,1,1,'\\  ',NULL),(16954,750526312007,170728920807,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',12.99,'au-buy','asad.zeeshan','qamchaudhry@yahoo.ca','Asad Bilal','16 polar Bear Place','Brampton','ON','CANADA','L6R 3L7','(647) 802-6475','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 03:35:21',0,NULL,3,1,2,1,'\\  ',NULL),(16955,742933219008,180764313016,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','bgolson','bgolson@mba1997.hbs.edu','Brian Golson','30 Stetson Ave','Kentfield','CA','UNITED STATES','94904-1562','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 04:38:55',0,NULL,3,1,1,1,'\\  ',NULL),(16956,8881322543155432,10,'lauck8@gmail.com',1,'OTCN005',17.2,'aliexpress','lauck88 ','lauck8@gmail.com','Lau Chung Kyu','No.10, 2nd Flr<br>Jln Tuanku Osman','Sibu','Sarawak','MALAYSIA','96000','',NULL,NULL,NULL,'2011-11-29 05:05:55',0,NULL,5,1,18,0,NULL,' OTCN005  \r10 pcs of VGA 转RJ45   200g white'),(16957,651876233013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','evilmonkey301','evilmonkey300@gmail.com','Patrick Vasquez','2146 W Gramercy Pl','San Antonio','TX','UNITED STATES','78201','(210) 723-3363','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 05:20:03',0,NULL,3,1,1,1,'\\  ',NULL),(16958,750559788007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','toby_519','toby519@yahoo.com.hk','Yat Ming Chow','4/8 Dennis Street','Clayton','Victoria','AUSTRALIA','3168','61431464107','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 05:46:30',0,NULL,3,1,2,1,'\\  ',NULL),(16959,803859549011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','am49073','mms850@hotmail.com','mahmood alhinai','Oman<br>P.O.Box: 633, Phone: 95140958','Hayy Alturath','Nizwa','OMAN','611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 05:29:24',0,NULL,3,1,3,1,'RA117764402CN\r ',' GPS0007'),(16960,803868146011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','evstial10','evstial@gmail.com','Евстифеев Алексей','Marshala Golovanova, home 13, room 316<br>Россия, Москва, ул. Маршала Голованова д 13, кв 316','Moscow','Moscow','RUSSIAN FEDERATION','109144','7-929-6242471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 06:02:28',0,NULL,3,1,2,1,'\\  ',NULL),(16961,651884086013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','asusdrum2ahmed','asusdrum2@yahoo.com','Ahmed Jawad Sukkar','18221 150th Ave<br># AUH-6841','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 06:07:59',0,NULL,3,1,1,1,'\\  ',NULL),(16962,803874240011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',205.99,'eastar4','renzo240','hor31gitano@hotmail.com','renzo c hoyos','6113 Pine Crest Ln','frederick','MD','UNITED STATES','21701-7600','(240) 603-3181','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-11-29 06:32:30',0,NULL,3,1,1,1,'\\ ',NULL),(16963,648279789013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','spdriver777','alekseyrper@yandex.ru','Ivanin Mikhailovich','prospekt energetikov d.35, k.1, kv.19','Sankt-Peterburg','','RUSSIAN FEDERATION','195248','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 06:47:45',0,NULL,3,1,2,1,'\\  ',' 欧标'),(16964,651890411013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','dong13142011','deman1314@yahoo.com','xiao liang','4723 n damen ave','chicago','IL','UNITED STATES','60625-1511','(773) 968-0017','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 06:58:52',0,NULL,3,1,1,1,'\\  ',NULL),(16965,803881150011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','ice3yes','tomingram@yahoo.com','Thomas Ingram','PO BOX 1022','Port Lincoln','South Australia','AUSTRALIA','5606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 07:03:39',0,NULL,3,1,2,1,'\\  ',NULL),(16966,890914140012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','visage3000','trevor.smith@y7mail.com','Trevor Smith','9 Cronin Crt','Cheltenham','Victoria','AUSTRALIA','3192','0395851992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 07:22:03',0,NULL,3,1,2,1,'\\  ',' 澳标'),(16967,803891466011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','valdas1310','valdas.info13@gmail.com','Valdas Siniavskis','Vasario 16-osios, 11F/2','Garliava','','LITHUANIA','53213','370-699-11331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 07:47:17',0,NULL,3,1,2,1,'\\ ',NULL),(16968,760582303001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','harry1770','harryjoe@fsmail.net','harry rimmer','5,hawthorne grove','southport','Merseyside','UNITED KINGDOM','pr9 7aa','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 07:58:12',0,NULL,3,1,2,1,'\\ ',NULL),(16969,890935623012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','danzbbox2','danzbbox2@hanmail.net','Karen Chang','3731 Wilshire Blvd<br>Ste 300','Los Angeles','CA','UNITED STATES','90010-2821','(213) 380-0777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 08:46:37',0,NULL,3,1,3,1,'RA117764773CN ',NULL),(16970,8881322556804341,111,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.5,'eastar4uk','satelit23-2008','mcatargiu2005@yahoo.com','marius bogdan catargiu','141a reynolds drive','edgware','Middlesex','UNITED KINGDOM','ha8 5px','07889109977',NULL,NULL,NULL,'2011-11-29 08:53:24',0,NULL,3,1,3,1,'RA117778605CN ',' GLOT001\r兼容型3D眼镜 通用型'),(16971,8881322559082846,111,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',17.2,'eastar4','lauck88 ','lauck8@gmail.com','Lau Chung Kyu','No.10, 2nd Flr <br>Jln Tuanku Osman','Sibu','Sarawak','MALAYSIA','96000','',NULL,NULL,NULL,'2011-11-29 09:31:22',0,NULL,3,1,3,1,'RA117764787CN ',' OTCN005'),(16972,890948161012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','cosmicsunshine','cosmicsunshine@gmx.net','Individuelle Finanzberatung','Hauptstr. 47<br>Andreas Wolf','St. Leon-Rot','','GERMANY','68789','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 09:31:39',0,NULL,3,1,2,1,'\\ ',' 欧标'),(16973,890951857012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',8.99,'eastar4uk','ko-mar','marek_karolczak@web.de','Marek Karolczak','Zenkerstr. 20','Erlangen','','GERMANY','91052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 09:43:48',0,NULL,3,1,2,1,'\\ ',NULL),(16974,743013321008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','bmorebanga','john.preis@hotmail.com','John Preis','2790 Meadow Cross Way','York','PA','UNITED STATES','17402-8537','(443) 286-6153','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 10:27:14',0,NULL,3,1,1,1,'、 ',''),(16975,743018237008,180764312952,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',3,'HSPL008',94.5,'au-buy','d_lim11','des@limit.com.au','Des Lim','32 Chardonnay Crescent','Wynn Vale','South Australia','AUSTRALIA','5127','0416286986','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 10:41:22',0,NULL,3,1,3,1,'RA117764901CN ',' HSPL008'),(16976,803939609011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','johnjewitt2006','johnjewitt2004@gmail.com','John Jewitt','3 Huddart Terrace<br>Birtley','Chester le Street','Durham','UNITED KINGDOM','DH3 1NE','01914921687','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 10:41:41',0,NULL,3,1,3,1,'RA117764756CN ','MOAP001 '),(16977,651936078013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','apoliterefusal','byron.vickers@gmail.com','Byron Vickers','56 Scrivener St.','O\'connor','Australian Capital Territory','AUSTRALIA','2602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 10:54:16',0,NULL,3,1,2,1,'、 ',NULL),(17051,891516311012,220632594947,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.98,'eastar4','biggul2','aleksei.gul@gmail.com','Aleksei Gul','Kopli 96B-22','Tallinn','Harjumaa','ESTONIA','10416','+37255626370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 07:04:54',0,NULL,3,1,2,1,'、 ',' 欧标'),(16981,890989414012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','kantorsandor','kan8172@mail.iif.hu','Dr Sandor Kantor','41 Blackthorn Close','Cambridge','Cambridgeshire','UNITED KINGDOM','CB4 1FZ','7561333162','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 11:42:42',0,NULL,3,1,3,1,'RA117764685CN ','GLOT005 '),(16978,651938304013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','$katyhip','pagill@centurytel.net','Pat Gill','702 Fairwater Cr','Horseshoe Bend','AR','UNITED STATES','72512','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 11:02:35',0,NULL,3,1,1,1,'\\ ',NULL),(17050,891512460012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','chandra1321','hadinata_chandra@yahoo.com','Chandra Hadinata','3306/197 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','0280336221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 06:48:12',0,NULL,3,1,2,1,'、 ',NULL),(16979,803633681002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','melinda729680','mgbreedlove68@yahoo.com','Melinda Thompson','22442 Shakespeare Ave','Eastpointe','MI','UNITED STATES','48021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 11:09:35',0,NULL,3,1,1,1,'\\ ',NULL),(16980,651939624013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',39.99,'eastar4','alekseyilin','dencorpos@gmail.com','Alexey Ilin','Kulakova st., 9, fl. 227','Kursk','Kursk region','RUSSIAN FEDERATION','305018','+79045205573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 11:18:37',0,NULL,3,1,3,1,'RA117764671CN ',' WLIN002'),(16982,803963399011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','jmpacio','pacio@vodafone.es','José Manuel Pacio','Calle Sol 20, 1ºA','A Coruña','Galicia','SPAIN','15003','669880453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 11:54:57',0,NULL,3,1,2,1,'、 ',NULL),(16983,891000790012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','max.popov','pmmxxx@gmail.com','Maksym Popov','Keramicheskiy 7a','Kiev','Kiev','UKRAINE','03039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 12:24:54',0,NULL,3,1,2,1,'、 ',NULL),(16984,651959180013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','biancahastie91','biancahastie@live.com.au','bianca hastie','33 Hackett Terrace Street','Charters Towers','Queensland','AUSTRALIA','4820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 12:35:48',0,NULL,3,1,3,1,'RA117778432CN ',' GLOT001*4'),(16985,891034338012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','g_naf269','g_naf269@yahoo.com.sg','nafisal salim','NO.10, SIMPANG 37, JALAN PALU,<br>KG PENANJONG, TUTONG','BANDAR SERI BEGAWAN','BANDAR SERI BEGAWAN','BRUNEI DARUSSALAM','TA2741','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 13:44:38',0,NULL,3,1,3,1,'RA117764742CN ',' GPS0009'),(16986,891054980012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.9,'eastar4uk','allford*2009','markallford7278@hotmail.co.uk','Mark Allford','57 Smithfields<br>Plymouth Road','Totnes','Devon','UNITED KINGDOM','TQ9 5LR','01803865588','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 14:33:02',0,NULL,3,1,3,1,'RA117764699CN\r ','HSMO018 \r英标'),(16987,804022191011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','kadakpc','kadakpc@centurytel.net','RODNEY SHERMAN','105 Kenzie Ln','Ward','AR','UNITED STATES','72176-9565','(501) 259-1417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 14:36:39',0,NULL,3,1,1,1,'、 ',NULL),(16988,748904024007,170728921067,'New Genuine Sony Ericsson HBH-PV702 Bluetooth Wireless Headset',1,'HSSE003',21.9,'au-buy','r-harry','reinhold.elling@freenet.de','Schmeing Gmbh','Weseker Weg 38<br>[z.Hd. Herrn Elling]','Südlohn','','GERMANY','46354','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 14:38:51',0,NULL,3,1,2,1,'、 ','HSSE003 \r欧标'),(16989,651992440013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','myanmyan2011','tigerpham70@yahoo.com','myan dang','5365 ne 4th ct','renton','WA','UNITED STATES','98059-8566','(206) 226-1039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 14:42:29',0,NULL,3,1,1,1,'\\ ',NULL),(16990,652001673013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','jch401','joehenry@email.com','Joseph Henry','4528 Pin Oak Ln','Bellaire','TX','UNITED STATES','77401-2612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 15:12:26',0,NULL,3,1,3,1,'RA117778463CN ',' GLOT001*4'),(16991,804057657011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',2,'GLOT001*4',207.98,'eastar4uk','unut1','unut123@yahoo.com','Aaron Carlson','1717 S Dorsey Ln<br>Apt 1116','Tempe','AZ','UNITED STATES','85281-7011','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 16:04:15',0,NULL,3,1,6,1,'EE495359667CN ','GLOT001*4\r兼容眼镜'),(16992,804063354011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','artpasha1978','artpasha@mail.ru','Pavel Artemyev','Vybornaya 108-29','Novosibirsk','Novosibirsk obl','RUSSIAN FEDERATION','630126','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 16:15:16',0,NULL,3,1,3,1,'RA117778579CN ','GLOT001*3\r兼容眼镜 '),(16993,750731218007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','vcarroll4896','vcarroll4896@hotmail.com','Vernessa Holleman','2175 N State Highway 360<br>Apt 1031','Grand Prairie','TX','UNITED STATES','75050-1077','(817) 313-6276','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 16:25:07',0,NULL,3,1,3,1,'RA117764711CN ',' UM00001'),(16994,804073800011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','gpan6686','pankhurst366@yahoo.com','Grant Pankhurst','904 Country Club Rd. #228','Gillette','WY','UNITED STATES','82718','(208) 360-6903','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 16:35:41',0,NULL,3,1,1,1,'\\ ',NULL),(16995,750773177007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','puma_chassey','dp051401@yahoo.com','david v pham','2250 Marbetta Ln','charlotte','NC','UNITED STATES','28215-3315','(704) 906-5294','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 17:03:03',0,NULL,3,1,1,1,'\\  ',' RCLO007+POLO001+RCLO008*4'),(16996,652041533013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','716donna','donna.aliotta@gmail.com','Donna Aliotta','169 E Pinelake Ct','Williamsville','NY','UNITED STATES','14221-8328','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 17:11:23',0,NULL,3,1,3,1,'RA117778525CN ',' GLOT001*4'),(16997,652048677013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','jeffwrx2004','cyborg___66@hotmail.com','Jean-Francois Savard','579, GODIN','Québec','QC','CANADA','G1M3G7','(418) 564-3567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 17:31:48',0,NULL,3,1,3,1,'RA117778534CN ',' GLOT001*4'),(16998,804129804011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','sofiavgoustinou','akisofia@otenet.gr','SOFIA AVGOUSTINOU','OIKIA KAPODISTRIA','BANATO','ZAKINTHOS ISLAND','GREECE','29100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 18:21:58',0,NULL,3,0,3,1,'RA117764795CN ',' GLSG001'),(16999,891192097012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',89.78,'eastar4','jcfortunatus777','jcfortunatus@gmail.com','Vladimirs Spnovs','40  Arodu street, app.18','Daugavpils','Latgale','LATVIA','LV5401','0037126051957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 18:53:56',0,NULL,3,1,3,1,'RA117778565CN ',' GLOT001'),(17000,891190387012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','lefteris_k9898','lefteris_k98@hotmail.com','ΕΛΕΥΘΕΡΙΟΣ ΚΑΠΙΔΗΣ','ΚΡΕΜΟΥ 98','ΑΘΗΝΑ','ΚΑΛΛΙΘΕΑ','GREECE','17676','2109595415','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 18:55:12',0,NULL,3,1,2,1,'\\ ',NULL),(17001,652090124013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','pleasureroomsliverpool','peterbhanot@hotmail.com','Peter Bhanot','35 Howard Street<br>Unit 36 Admiralty Towers One','Brisbane','Queensland','AUSTRALIA','4000','0061429902401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 19:05:15',0,NULL,3,1,3,1,'RA117764708CN\r ',' HBPH002'),(17002,760836611001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','juhii','juho.m.jaaskelainen@student.savonia.fi','Juho Jääskeläinen','Retkeilijäntie 1 H 32','Kuopio','','FINLAND','70200','050 567 5592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 19:17:01',0,NULL,3,1,2,1,'、 ',NULL),(17003,891197060012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',15.93,'eastar4uk','yoel_hamani','yoel.hamani@gmail.com','Yoel Hamani','12 Jerusalem st.','qiryat atta','','ISRAEL','28077','054-7699500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 19:17:47',0,NULL,3,1,2,1,'、 ',NULL),(17004,652116969013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','mightier.pen','marktgittens@gmail.com','Mark Gittens','49 Chambers St<br>Records Management Unit Ste 1104','New York','NY','UNITED STATES','10007-1248','(718) 924-1336','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 19:56:37',0,NULL,3,1,1,1,'\\ ',NULL),(17005,891239714012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.39,'eastar4','domy_os','domy.os@gmail.com','Domagoj Sutalo','Vijenac Gorana Zobundzije 8','Osijek','Croatia','CROATIA','31000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 19:57:24',0,NULL,3,1,2,1,'、 ',NULL),(17006,593989888003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','leikerd','daveleiker@ymail.com','David Leiker','3286 S Nucla St','Aurora','CO','UNITED STATES','80013-2019','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-29 20:03:54',0,NULL,3,1,1,1,'\\ ',NULL),(17007,804207903011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','smurf_gr','argiris.ebay@gmail.com','argiris katsaros','episkopou makariou kitrous 2','katerini','katerini','GREECE','60100','6945525529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 20:21:33',0,NULL,3,1,2,1,'、 ',NULL),(17008,888262678012,220816317839,'New lady paris tower dot w/trim Sun Rain Stick Umbrella',1,'UM00028',21.84,'eastar4','kym39','mykeydee1957@yahoo.com.au','Kym Wallace','Unit 2<br>576 Norman Road','North Rockhampton','Queensland','AUSTRALIA','4701','0749140741','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,' echeck\r'),(17009,760901285001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','northwood49617123','northwood49617@att.net','jim mclaren','475 US Highway 31','beulah','MI','UNITED STATES','49617-9701','(231) 882-5522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 20:59:18',0,NULL,3,1,1,1,'\\ ',NULL),(17010,804237964011,320730089149,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',24.99,'eastar4uk','natty_grl83','warrenandnat1@bigpond.com','Natalie Schmid','3 Samuel Place<br>Wanneroo','Perth','Western Australia','AUSTRALIA','6065','0894059756','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 21:06:44',0,NULL,3,1,3,1,'RA117764668CN ','OTPL001 '),(17011,891296575012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','lindsey_ismail','mimmo619@hotmail.com','Lindsey Ismail','49 Linthaugh Road<br>Pollok','Glasgow','Glasgow (City of)','UNITED KINGDOM','G53 5NX','01418922747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 21:14:28',0,NULL,3,1,2,1,'\\ ',NULL),(17012,891322331012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Robert Bentley','133 Marion St','Wilmington','MA','UNITED STATES','01887-4700','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 21:54:38',0,NULL,3,1,1,1,'、 ',NULL),(17013,804085697011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','witchertidus','tidusdragonheart@hotmail.com','Cem Yılmaz','96 sokak no 23/1<br>guzelyali','İzmir','Goztepe','TURKEY','35311','+905415585537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 17:00:13',0,NULL,3,1,2,1,'\\ ',' 新地址：\rTahsin Cem Yılmaz  \r88 sokak, no 11/1, Maltepe mahallesi, Güzelbahçe/Izmir\rTURKEY'),(17014,652173173013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','amfake32','allenfake@comcast.net','Allen Fake','309 Acorn Cir<br>null','Lebanon','PA','UNITED STATES','17042-9149','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 22:00:23',0,NULL,3,1,3,1,'RA117778477CN ','GLOT001*4 '),(17015,743327154008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','jan-haefliger','janputz@anthromedia.de','Jan Haefliger','Am Heidegraben 7','Vettweiß-Müddersheim','','GERMANY','52391','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 22:00:32',0,NULL,3,1,3,1,'RA117764610CN\r ','HBPH007 '),(17016,594045167003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.34,'cnfaner','mmbclarke','mmbclarke@yahoo.com','Nicole Clarke','6360 Barton Creek Cir','Lake Worth','FL','UNITED STATES','33463','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-29 22:13:11',0,NULL,3,1,1,1,'\\ ',NULL),(17017,804278914011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','urielbonini','uboninijr@yahoo.com','Uriel Bonini','4631 SW 21st Pl','Ocala','FL','UNITED STATES','34474-9230','(352) 237-8891','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 22:15:30',0,NULL,3,1,1,1,'、 ',NULL),(17018,804286788011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','cajunmamma','beckalini@cox.net','rebecca finger','1844 State St','new orleans','LA','UNITED STATES','70118-6220','(985) 774-4097','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 22:31:59',0,NULL,3,1,1,1,'、 ',NULL),(17019,804290392011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',6,'HSNO019',227.88,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 22:39:30',0,NULL,3,1,3,1,'RA117768903CN ',' HSNO019'),(17020,891353356012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','mack-1963','ms.mackenzie@bigpond.com','Sharon Mackenzie','P.O. Box 647','Williamstown','Victoria','AUSTRALIA','3016','0408511821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 22:49:11',0,NULL,3,1,3,1,'RA117767837CN\r ',' OTGR001+OTGR002'),(17021,804296266011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT006',89.78,'eastar4','fjar27','famalho@gmail.com','FRANCISCO JOSE AZEVEDO RAMALHO','RUA MANUEL VASQUES Nº3 3ºDT. SANTO ANDRE','BARREIRO','SETUBAL','PORTUGAL','2830-535','932858072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 22:52:02',0,NULL,3,1,3,1,'RA117764725CN ',' GLOT006'),(17022,803988001002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','dp-hn','gmember71@gmail.com','HUY NGUYEN','2585 N Highway 27','La Fayette','GA','UNITED STATES','30728-7502','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 23:26:46',0,NULL,3,1,1,1,'\\ ',NULL),(17023,743369026008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','denon1500','simon072000@hotmail.com','Dany Marois','597 des trembles','quebec','QC','CANADA','g3g2g2','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 23:41:22',0,NULL,3,1,3,1,'RA117778596CN ',' GLOT001\r兼容眼镜通用型'),(17024,804317216011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','rlrimmer','rlrimotep@gmail.com','ROBERT RIMMER','1530 S STATE ST<br>SUITE 16M','CHICAGO','IL','UNITED STATES','60605-2976','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 23:43:01',0,NULL,3,1,1,1,'、 ',' 再发一个New IBM Atheros AR5BXB6 AR5424 MINI PCI-E Card+antenna'),(17025,891379058012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','forteohd','jjgarza@pemex.gob.mx','Juan Jose De la Garza Mendoza','4105 Ben Hogan Ave','Mcallen','TX','UNITED STATES','78503-8209','956 668 0794','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 23:51:34',0,NULL,3,1,3,1,'RA117778551CN ',' GLOT001*4'),(17026,804320953011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','discountwebdeals','peterbell777@gmail.com','Peter Bell','3 Scurry Street','Dunlop','Australian Capital Territory','AUSTRALIA','2615','0487721111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 23:54:30',0,NULL,3,1,2,1,'\\ ',NULL),(17027,891384373012,220708794349,'New IBM Atheros AR5BXB6 AR5424 MINI PCI-E Card+antenna',1,'WLAT005+ANTY001',11.89,'eastar4','rlrimmer','rlrimotep@gmail.com','ROBERT RIMMER','1530 S STATE ST<br>SUITE 16M','CHICAGO','IL','UNITED STATES','60605-2976','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 00:00:34',0,NULL,3,1,17,0,NULL,' '),(17028,891385017012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',69.99,'eastar4uk','milton.nunes','mnunes.pub@gmail.com','Milton Nunes','EN125 Urb. Via Mourisca Bl. B 2ºDto','Olhão','Portugal','PORTUGAL','8700-145','966582690','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 00:09:24',0,NULL,3,1,3,1,'RA117764800CN ','GLSG001*2 '),(17029,751007793007,170728921737,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',58.99,'au-buy','harkirat07','ravidolly71@yahoo.ca','inderjeet Kaur sandhu','8 clementine dr.','brampton','ON','CANADA','l6y5m1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-30 00:16:55',0,NULL,3,1,3,1,'RA117764623CN\r ','HSSE011 '),(17030,804331923011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',5,'OTCN002',19.9,'eastar4','mkant34','counter5831@hotmail.com','mehmet kanturmuş','Vişne 2 Mh.Garanti Koza Evleri 4.Cad. No:49<br>Migros Zekeriyaköy Çarşı Satış Mağazası Sarıyer İstanbul Türkiye','istanbul','Turkey','TURKEY','34450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 00:24:26',0,NULL,3,1,2,1,'\\ ',NULL),(17031,804010113002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','newo4002','newo4002@gmail.com','Tammy Washburn','1183 Morris Rd','Lapeer','MI','UNITED STATES','48446-9339','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 00:32:20',0,NULL,3,1,1,1,'\\ ',NULL),(17032,8881322616167193,111,'a pair of ThinkPad X200 3G GPS+WWAN Antenna',1,'ANCN002',17.99,'aliexpress','1005513776 ','gumau.export@gmail.com','Aurelio Campos Rincon	','Los Girasoles, 11','Los Molares	','Sevilla','SPAIN	','41750','+00 34 663526095',NULL,NULL,NULL,'2011-11-30 01:22:47',0,NULL,3,1,3,1,'RA117778905CN\r ','ANCN002 '),(17033,594098358003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.34,'cnfaner','marke3434','ngitonly@sbcglobal.net','Mark Epting','1380 Trampe Ave','Saint Louis','MO','UNITED STATES','63138','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 01:39:23',0,NULL,3,1,1,1,'\\ ',' '),(17034,804361953011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',1,'BR3D001',33.99,'eastar4','baby28','karen@boxerden.com','Karen Chan','15409 95A Avenue','Surrey','BC','CANADA','V3R 7T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 01:57:59',0,NULL,3,1,3,1,'RA117764739CN ',' BR3D001'),(17035,652244435013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','rsiengineers','paulbarham@tiscali.co.uk','Mr Paul Barham','62 / 28 Southgate Avenue<br>Southbank','Melbourne','Victoria','AUSTRALIA','3006','0438437366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 02:02:38',0,NULL,3,1,2,1,'、 ',NULL),(17036,751040232007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','gaara4000','cro0005@hotmail.com','Matthew Cross','24 Furlong rd','Melbourne','Victoria','AUSTRALIA','3023','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(17037,599530377004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',18.9,'cnfaner','celticsemite','ajgavriel@gmail.com','Akiva Gavriel','5845 S Blackstone Ave<br>Apt 206','Chicago','IL','UNITED STATES','60637-1817','(773) 419-0072','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 02:25:14',0,NULL,3,1,1,1,'\\ ',NULL),(17038,652253286013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','drunia79','andrey.alexandrenko@gmail.com','Andrey Aleksandrenko','Lermontova 134 office 208','Irkutsk','Irkutsk obl','RUSSIAN FEDERATION','664033','+79500602500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 02:36:44',0,NULL,3,1,2,1,'、 ',NULL),(17039,652256316013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','fred_savard','fred_savard333@hotmail.com','Frederic Savard','1994 harfang','chicoutimi','QC','CANADA','g7h8a9','(418) 545-0412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 02:49:55',0,NULL,3,1,3,1,'RA117778485CN ',' GLOT001*4'),(17040,804380655011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','mgab3516','travelmg@aol.com','MARY GABRIEL','P.O. BOX 40100','SAINT PETERSBURG','FL','UNITED STATES','33743','(727) 458-3293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 02:51:28',0,NULL,3,1,1,1,'、 ',NULL),(17041,743434583008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'au-buy','shammy.rock.93','shammy.rock@gmail.com','Shamrock Cossar','12 Queen Street','Gloucester','New South Wales','AUSTRALIA','2422','0202655898','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 03:09:58',0,NULL,3,1,2,1,'、 ',NULL),(17042,761045627001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','luismlmd','luismdm89@hotmail.com','luis m diaz','26 E Groveland Ave','somers point','NJ','UNITED STATES','08244-2610','(609) 788-8089','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 03:27:23',0,NULL,3,1,1,1,'、 ',NULL),(17043,891466142012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','geekfixnz','doughall@geekfix.co.nz','Douglas Hall','34 Campbells Road<br>Pine Hill','Dunedin','Otago','NEW ZEALAND','9010','021 775773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 03:45:04',0,NULL,3,1,2,1,'、 ',' '),(17044,891470347012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.99,'eastar4','khanumaiah','khanumaiah1@hotmail.com','Kiran Hanumaiah','5851 Ridgeway Center Pkwy','Memphis','TN','UNITED STATES','38120-4003','(901) 761-3480','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 03:57:09',0,NULL,3,1,3,1,'RA117778361CN ',' MOMI001'),(17045,751074821007,170737835724,'GENUINE Plantronics Voyager 510 Bluetooth Headset',2,'HSPL010',65.98,'au-buy','magellamagella2011','magmad52@hotmail.com','magella lavoie','7 gedeon lavoie','st-fulgence','QC','CANADA','G0V1S0','(418) 674-2831','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-30 04:05:19',0,NULL,3,1,3,1,'RA117769047CN ','HSPL010 '),(17046,8881322626644542,111,'GENUINE Plantronics Voyager 510 Bluetooth Headset',10,'HSPL010',263.4,'cnfaner','rcea2011','rcea88@gmail','Ronald Chiu','308 149th St','Whitestone','NY ','UNITED STATES','','',NULL,NULL,NULL,'2011-11-30 04:17:24',0,NULL,5,0,18,0,' ',NULL),(17047,8881322626978563,111,'GENUINE Plantronics Voyager 510 Bluetooth Headset',10,'HSPL010',263.4,'cnfaner','rcea2011','rcea88@gmail','Ronald Chiu','308 149th St','Whitestone','NY ','UNITED STATES','11357-1129','',NULL,NULL,NULL,'2011-11-30 04:22:58',0,NULL,3,1,1,1,'LK029124029CN ',' '),(17048,8881322633305050,111,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',0,'cnfaner','ptlt23','ptlt@live.com','Thu Thu Lam','1783 Sagamore Dr','YORK','PA','UNITED STATES','17406-1809','(717) 755-7601',NULL,NULL,NULL,'2011-11-30 06:08:25',0,NULL,3,1,1,1,'LK150172893CN ','补发 '),(17049,598945177004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',46.46,'cnfaner','xvost50','jorjina12@hotmail.com','Vyatsheslav Rastsvetalov','Gogolya 921','Tuapse','','RUSSIAN FEDERATION','352800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 06:11:55',0,NULL,3,1,3,1,'RA117764416CN ',' WWOT003+ANCN001'),(17052,8881322637106661,111,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',0,'eastar4','fastasp2dqq','fastasp@aol.com','Hayes Hutchins','13541 Sharpes Lake Rd','Northport','AL','UNITED STATES','35473','',NULL,NULL,NULL,'2011-11-30 07:11:46',0,NULL,5,1,18,1,'LK012157558CN  ',' 补发一个   但是可能不能用  需要撤单'),(17053,751130500007,170731735465,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip sliver',1,'SHLO008',12.99,'au-buy','spaceballmueller','mueller.sassnitz@live.de','Renè Müller','Mukraner Strasse 10a','Sassnitz','','GERMANY','18546','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-30 08:23:19',0,NULL,3,1,2,1,'\\ ','银色的'),(17054,891547389012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','garagechap','ywchai@mac.com','Yee Wei Chai','40 Zion Rd','Singapore','','SINGAPORE','247774','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 09:00:52',0,NULL,3,1,11,1,'、 ','WLHP002 '),(17055,761124365001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','gmoney574','gregory.tropea@yahoo.com','Gregory Tropea','130 Burdick Dr','Cranston','RI','UNITED STATES','02920-1537','(401) 996-2192','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 09:20:01',0,NULL,3,1,1,1,'\\ ',NULL),(17056,8881322645630538,111,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',0,'eastar4','underwood786','mobilerepairs@bigpond.com','Faisal Koya','P. O. Box 292<br>Shop 2b, 3231 Logan Road, Underwood','Brisbane','Queensland','AUSTRALIA','4119','0431581786',NULL,NULL,NULL,'2011-11-30 09:33:50',0,NULL,3,1,3,1,'RA117778891CN\r ',' 澳标  HSJA001'),(17057,652335740013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','troutforce','webmaster@film-tutorial.com','Denis Ekarius','Schulenburgallee 63','Wolfsburg','','GERMANY','38448','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 09:50:17',0,NULL,3,1,3,1,'RA117778976CN\r ',' GPS0004'),(17058,804481895011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',134.99,'eastar4uk','slavikriff','slavik.riff@gmail.com','Slavik Riff','HaMelech David 1<br>app. 11','Ashdod','','ISRAEL','77490','+972544903883','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 09:53:36',0,NULL,3,1,3,1,'RA117769055CN\r ','MOLO010 '),(17059,743533931008,180755478719,'New Genuine Motorola H700 Bluetooth Wireless Headset+ Car Charger',3,'HSMO011+CCMO001',53.97,'au-buy','sky25t','flyingroentec3@gmail.com','Robert A Owen','Po box 987','St Marys','New South Wales','AUSTRALIA','1790','0417411774','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 10:12:46',0,NULL,3,1,3,1,'RA117778857CN\r ','HSMO011+CCMO001\r澳标 '),(17060,652343256013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',10,'CASS003',84.9,'eastar4','kaptur84','marcin.kapturski@gmail.com','Marcin Kapturski','78 Elliotts Way<br>Caversham','Reading','Berkshire','UNITED KINGDOM','RG48BF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 10:26:07',0,NULL,3,1,3,1,'RA117778786CN\r ',' CASS003'),(17061,891576343012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',9.19,'eastar4uk','kapildugg','kapil_duggal@hotmail.com','kapil duggal','3 Ballanoma Green<br>Epping','Melbourne','Victoria','AUSTRALIA','3076','61430009441','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 10:34:28',0,NULL,3,1,2,1,'\\ ','澳标 '),(17062,804511806011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','eduardo.ampuero','edupaulista@hotmail.com','Eduardo Ampuer','Street 2448 number 228','Balneário Camboriú','Santa Catarina','BRAZIL','88330-398','554778123654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 11:14:09',0,NULL,3,1,2,1,'、 ',NULL),(17063,891593341012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','71namo','naomi@lakatos71.wanadoo.co.uk','Naomi Lakatos','Willowbrook House, Church View<br>The Green, Kingsthorpe Village','Northampton','Northamptonshire','UNITED KINGDOM','NN2 6QD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 11:24:48',0,NULL,3,1,3,1,'RA117778830CN\r ','HBPH003 '),(17064,891594170012,220890236088,'Logitech G7 Rechargeable Battery MX revolution mous',1,'BALO009',5.99,'eastar4uk','apoloxyz','romansamsonov@hot.ee','Roman Samsonov','Sepa 22','Tartu','','ESTONIA','51013','+3725188427','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 11:29:36',0,NULL,3,1,2,1,'\\ ',NULL),(17065,804517748011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','passdedutchy','passdedutchy@hotmail.com','Carol Vanderveldt','19 Neill\'s  Close','Newhaven','East Sussex','UNITED KINGDOM','BN9 9LF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 11:30:44',0,NULL,3,1,3,1,'RA117778993CN\r ','GLSG001 '),(17066,599635345004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',26.12,'cnfaner','malikshabazz2281','malikshabazz2281@hotmail.com','Ryan Brown','734 E 11th St','Wilmington','DE','UNITED STATES','19801-4118','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 12:02:37',0,NULL,3,1,1,1,'\\ ',NULL),(17067,652366183013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','megapom','esenem@iinet.net.au','Sharon Moulsdale','91 Caledonia Avenue','Currambine','Western Australia','AUSTRALIA','6028','0893054472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 12:10:18',0,NULL,3,1,3,1,'RA117778874CN\r ',' GLOT001*4'),(17068,743571617008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.99,'au-buy','legicant','kalapuikk0@hotmail.com','Janne Salminen','Kuusikonkatu 5 a 5','Tampere','','FINLAND','33820','0505337028','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-30 12:13:15',0,NULL,3,1,2,1,'\\ ','型号 black ver1'),(17069,804532459011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','mertkarabiyik','avras_ya07@hotmail.com','FERDI KARABIYIK','ASPENDOS BULVARI NO:95<br>MURATPASA','ANTALYA','TURKEY','TURKEY','07200','5425865482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 12:14:00',0,NULL,3,1,3,1,'RA117778741CN ',' OTSO004'),(17070,761188013001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','crd45','trapperd@infionline.net','carl davison','1815 Winters Rd','fort wayne','IN','UNITED STATES','46819','(260) 639-7221','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 12:56:03',0,NULL,3,1,1,1,'\\ ',NULL),(17071,804577965011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','chr1$toph','chrishudy@eircom.net','Christopher Hudy','Umiskin','Kilcar','Donegal','IRELAND','default','0861532865','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 14:15:45',0,NULL,3,1,3,1,'RA117778812CN\r ','OTSO002 '),(17072,804577906011,320696836724,'NIB Sealed Samsung 3D TRIPLE FEATURE  Blu-ray 3 IMAX',10,'BR3D001',339.9,'eastar4','aquamix_3d','3d_aquamix@tpg.com.au','Mariusz Herok','17/373 South rd','Melbourne','Victoria','AUSTRALIA','3187','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 14:16:55',0,NULL,3,1,4,1,'YW867661271CN ',' 只有6个 发了6个'),(17073,891663152012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','outdoor.living.online','galerienormande@gmail.com','Art-En-Ligne','2820 LIPPE','MONTREAL','QC','CANADA','H4R1M1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 14:20:22',0,NULL,3,1,2,1,'\\ ',NULL),(17074,804253125002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','mprubin','mprubin516@aol.com','Mark Rubin','717 Fallsgrove Dr<br>Apt 1013','Rockville','MD','UNITED STATES','20850-7782','(301) 309-6990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 14:33:37',0,NULL,3,1,1,1,'\\ ',' '),(17075,594256697003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',19.85,'cnfaner','olandil','anejo@live.com','Olga Meriuts','848 N Richmond St','Chicago','IL','UNITED STATES','60622-4310','(847) 834-1813','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 14:46:47',0,NULL,3,1,1,1,'\\ ',NULL),(17076,804464654011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',3,'CASS003',25.47,'eastar4','alyak89','josh@joneslife.com','Josh Jones','2594 E Colonial Ct','Chandler','AZ','UNITED STATES','85249-5004','(480) 433-9306','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-30 15:06:01',0,NULL,3,1,1,1,'\\ ',' '),(17077,888620337012,220720533789,'New LCD SCREEN for Logitech 880 890 PRO REMOTE CONTROL',1,'SCLO001',11,'eastar4uk','hari10676','haraldboehm@tele2.at','Niclas Böhm','Schlüsselhofgasse<br>63','Steyr','','AUSTRIA','4400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 15:44:44',0,NULL,3,1,2,1,'\\ ',NULL),(17078,891660457012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','lucassiriani','lucasiriani@aol.com','Lucas Siriani','Alameda Augusto Stellfeld,771,apt 13 B','Curitiba','Paraná','BRAZIL','80410140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 16:05:37',0,NULL,3,1,2,1,'\\ ',NULL),(17079,804644220011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','*cocacolachick*','charlottedavison10@hotmail.co.uk','Charlotte Lightfoot - Aspire Creative','AMP Technology Centre, Advanced Manufacturing Park<br>Brunel Way, Catcliffe','Rotherham','South Yorkshire','UNITED KINGDOM','S60 5WG','01142879902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 16:46:41',0,NULL,3,1,3,1,'RA117778769CN\r ',' MOAP001'),(17080,891734502012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','mamoht-1','maximalexeev@gmail.com','Maxim Alexeev','9205 Haines Drive','Lorton','VA','UNITED STATES','22079','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 16:46:57',0,NULL,3,1,1,1,'\\',NULL),(17081,891741009012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','yarad1','yonitec@gmail.com','YONATHAN  ARAD','Asavyonim 22  Po.Box 49','Givhat Avni','ISRAEL','ISRAEL','15227','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 16:59:44',0,NULL,3,1,3,1,'RA117778772CN\r ','SAFI001'),(17082,891753636012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','20mishpaha09','abdurahmanov.elena@mail.ru','igor abdurahmanov','shomron 4/20','migdal ha emeq','','ISRAEL','23014','0546134314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 17:20:32',0,NULL,3,1,11,1,'\\ ',' UM00008'),(17083,804666337011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','muiscfrequency','mark.d.sanders@hotmail.co.uk','Mr M Sanders','89 Hampton Road','Chingford','London','UNITED KINGDOM','e4 8np','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 17:28:49',0,NULL,3,1,3,1,'RA117778931CN\r ','GLOT001*4\r兼容眼镜  '),(17084,891759337012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','*bones','ians.ebay@ntlworld.com','Ian P Bourne','26, Redworth Road','Billingham','Cleveland','UNITED KINGDOM','TS23 3JE','01642739115','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 17:29:54',0,NULL,3,1,3,1,'RA117778843CN\r ','40pin to 40pin male to female IDE cable \rOTCN003\r '),(17085,804671145011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','jjwwdd123','johnny.davis@grandecom.net','Johnny Davis','549 Mountain Lake Dr','Waco','TX','UNITED STATES','76712-3234','(254) 776-1937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 17:36:32',0,NULL,3,1,1,1,'\\ ',NULL),(17086,891766429012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','934lodge','cam_chabot@yahoo.com','jonathan cameron chabot','934 grosvenor ave','winnipeg','MB','CANADA','r3m 0n5','(204) 221-5882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 17:42:16',0,NULL,3,1,2,1,'\\ ',NULL),(17087,891776117012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','sadiecakes2005','viki.harrison@blueyonder.co.uk','VICTORIA HARRISON','23 Holland Road<br>halewood','Liverpool','Merseyside','UNITED KINGDOM','L26 1UE','07941807109','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 17:57:37',0,NULL,3,1,11,1,'\\ ','UM00027 '),(17088,804743400011,320738496776,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',24.69,'eastar4','sunshinelover03','sprswtbutterfly@aol.com','Wendy Angle','2548 S Farm Road 199','Springfield','MO','UNITED STATES','65809-3170','(417) 522-4822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 19:31:00',0,NULL,5,1,3,1,'\\ ',' UM00031  蓝色的\r已发'),(17089,804735737011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','ves1820','schwenke@burg-halle.de','Steffen Schwenke','Neuwerk 1','Halle','','GERMANY','06108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 19:33:19',0,NULL,3,1,3,1,'RA117778945CN\r ','GLOT001 \r兼容眼镜 通用型'),(17090,804766155011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.39,'eastar4','zeelarry','zeelarry@comcast.net','valerian ziemski','11 Pontalba Dr','little rock','AR','UNITED STATES','72211-2128','(501) 219-1938','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 20:04:00',0,NULL,3,1,1,1,'\\  ',' acer 6pin1.25 23cm   '),(17091,891879137012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',69.99,'eastar4uk','dtay1572','david@dtaylor40.wanadoo.co.uk','david taylor','2 tweed street court<br>bentham','lancaster','Lancashire','UNITED KINGDOM','la2 7lz','01524261574','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 20:17:04',0,NULL,3,1,3,1,'RA117779000CN\r ',' GLSG001*2'),(17092,891876047012,220747230787,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',11.65,'eastar4uk','tun57','tunsow@hotmail.com','Stephen Sowole','28 parkinson house<br>frampton park road','london','London','UNITED KINGDOM','e9 7ph','07531417353','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 20:17:43',0,NULL,3,1,3,1,'RA117778826CN\r ','HSNO014\r英标 '),(17093,891885094012,220886924490,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella',1,'UM00027',14.95,'eastar4uk','teabag090502','tommy090502@hotmail.com','tom houghton','59 hart street','cleethorpes','Lincolnshire','UNITED KINGDOM','dn357rq','01472234826','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 20:30:37',0,NULL,3,1,18,1,NULL,' UM00027\r已退款 如果客户还需要可以赠送一把其他伞'),(17094,891892811012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','indolikaa','indolikaa@frontiernet.net','Marc Russell','PO Box 269','Taylor','AZ','UNITED STATES','85939-0269','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 20:36:57',0,NULL,3,1,1,1,'\\ ',NULL),(17095,886856657012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','artfanica','artfani@gmail.com','Siavash Fani','2308 - 5793 Yonge ','Toronto','ON','CANADA','M2M 0A9','(647) 344-5335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 20:51:45',0,NULL,3,1,2,1,'\\ ',NULL),(17096,891903745012,220903895872,'3 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*3',94.99,'eastar4uk','salomonrey','salomon1rey@yahoo.es','Daniel Fernandez','Tres Torres 45','Granollers','Cataluña','SPAIN','08401','606827896','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 20:52:30',0,NULL,3,1,3,1,'RA117778888CN\r ',' LGGL002*3'),(17097,891907201012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','aciddem','d.laptev@gmail.com','Denis Laptev','Proletarskiy prospekt, dom 3<br>kvartira 85','Moscow','','RUSSIAN FEDERATION','115522','916-9090981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 20:56:36',0,NULL,3,1,3,1,'RA117778959CN\r ',' GLOT001'),(17098,804817391011,320730088401,'NEW sealed Logitech Wireless Laser Mouse M505 +unifying',1,'MOLO008',21.99,'eastar4uk','ujin_id','jenyatrn@gmail.com','Evgeniy Taran','Simi Khokhlovykh St<br>8a','Kyiv','Kyiv','UKRAINE','04119','+380667776224','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 21:17:04',0,NULL,3,1,2,1,'\\ ',NULL),(17099,804819920011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','sports_mom416','ttewnion@sympatico.ca','tonya tewnion','164 Large Cres','Ajax','ON','CANADA','L1T 2S4','(416) 938-1384','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 21:22:13',0,NULL,3,1,3,1,'RA117778914CN\r ',' GLSG001*2+BR3D005'),(17100,593302083003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','lookalikedesignerjewelry','lb@lookalikedesignerjewelry.com','Laurie Puleri','511 SE 5th Ave<br>Apt 704','Fort Lauderdale','FL','UNITED STATES','33301-2968','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 21:54:14',0,NULL,3,1,1,1,'\\ ',NULL),(17101,594431360003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','prostreetgrafix','randy@prostreetlighting.com','Prostreetlighting.com','2145 Wilson Ave','National City','CA','UNITED STATES','91950-6541','(619) 477-2935','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 22:06:17',0,NULL,3,1,1,1,'\\ ',NULL),(17102,652605896013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','restivo82','restivo82@yahoo.com','Pietro Restivo','5774 Tefer Rd.','Sarnia','ON','CANADA','N7T7H2','(519) 542-2576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 22:27:38',0,NULL,3,1,3,1,'RA117778928CN\r ',' GLOT001*4'),(17103,594438858003,130592183438,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','veigadrums','rockyveiga@gmail.com','Tiago Veiga','407 Park Ave S<br>Apt 24B','New York','NY','UNITED STATES','10016','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 22:27:40',0,NULL,3,1,1,1,'\\ ',NULL),(17104,594451368003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','kevynstephy','stamper.47@osu.edu','Kevin Stamper','757 Hollywood Ln','Mansfield','OH','UNITED STATES','44907-1611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 23:07:32',0,NULL,3,1,1,1,'\\ ',NULL),(17105,652628105013,230668626540,'3FT CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T Cable',20,'CASS001',165.8,'eastar4','cisco-campus-eu','europe-sales@cisco-campus.com','Müyesser Sabuncuo','Adelung Strasse 30A<br>two-run it solution GbR.','Darmstadt','','GERMANY','64283','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 23:36:14',0,NULL,3,1,3,1,'RA117769095CN\r',NULL),(17106,594463913003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.24,'cnfaner','compusatt','jhogan1164@aol.com','jeff hogan','10739 illinois ave','jacksonville','FL','UNITED STATES','32219-2192','(904) 509-5631','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 23:56:50',0,NULL,3,1,1,1,'\\ ','钱被银行撤回 '),(17107,889968403012,220849761535,'100% Original lowrance ifinder EXPEDITION GPS TFT Color',1,'GPS0003',108.99,'eastar4','45b0bby','bestmom18@hotmail.com','robert hooper','47 carnegie st','ingersoll','ON','CANADA','n5c1k8','(519) 425-0872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 00:03:06',0,NULL,3,1,3,1,'RA117778980CN\r ',' GPS0003'),(17108,751592572007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','jamie_baby77','jamie_mccloud@hotmail.com','James McCloud','Unit 1<br>15  Longueville Road','Lane Cove, Sydney','New South Wales','AUSTRALIA','2066','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 02:05:43',0,NULL,3,1,2,1,'\\ ',NULL),(17109,804604452002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','dondoroy09','teodorome1@yahoo.com','Ted Esguerra','4517 Cinderella Ln','Las Vegas','NV','UNITED STATES','89102-5798','(702) 577-7091','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 02:12:31',0,NULL,3,1,1,1,'\\ ',NULL),(17110,652674630013,230695501261,'2 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*2',88.99,'eastar4','el_emmo','ebazan23@hotmail.com','Emmanuelle figueroa Bazan','agustin lara #121<br>olivar del conde 2 seccion frente al mercado','alvaro obregon','Distrito Federal','MEXICO','01408','(171) 345-25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 02:44:39',0,NULL,3,1,3,1,'RA117778865CN\r ',' GLOT001*2'),(17111,8881322708747056,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',0,'eastar4','shuttle_store','ebay@us.shuttle.com','Shuttle Computer Group','17068 Evergreen Pl','City of Industry','CA','UNITED STATES','91745-1819','',NULL,NULL,NULL,'2011-12-01 03:05:47',0,NULL,3,1,1,1,'LK016997399CN ',' 补货  单号录入'),(17112,8881322709095296,111,'New Replaceable Shell 4 logitech Anywhere MX Mouse M905',1,'SHLO005',0,'eastar4','udscalifornia','info@ultimatedesignstudios.com','Ultimate Design Studios, LLC','125 4th St','Hermosa Beach','CA','UNITED STATES','90254','(678) 267-3273',NULL,NULL,NULL,'2011-12-01 03:11:35',0,NULL,3,1,1,1,'LK071771912CN ',' 补发 单号录入'),(17113,804965135011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','888888888888888888888888888888888888888','singaporeacrobats@yahoo.com.sg','YT OH','750 #06-142 YISHUN ST72','default','','SINGAPORE','760750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 03:27:05',0,NULL,3,1,11,1,'\\ ',' HSUE004'),(17114,892086301012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','First Presbyterian Church','2001 S El Camino Real<br>ATTENTION: Gretchen Richardson','Oceanside','CA','UNITED STATES','92054-6230','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 03:37:41',0,NULL,3,1,1,1,'\\ ',NULL),(17115,652691625013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','marsha11353','mploats@yahoo.com','Marsha Loats','820 Holiday Ct','Kenner','LA','UNITED STATES','70065-2956','(504) 390-1767','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 03:50:14',0,NULL,3,1,1,1,'\\',NULL),(17116,751624098007,170730544640,'3DConnexion SpacePilot USB Intelligent 3D Motion Controller mouse',1,'MOLO010',219.99,'au-buy','wojtas0606','wojciechknurowski@gmail.com','Wojtek Knu','19/13-19 Bryant St.','Rockdale','New South Wales','AUSTRALIA','2216','0424066290','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(17117,804985092011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','shizpop','meridianz@xtra.co.nz','Kim Chenery','PO Box 1212','Hastings','New Zealand','NEW ZEALAND','4156','06468787467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 04:40:07',0,NULL,3,1,2,1,'\\ ',' '),(17118,744007278008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'au-buy','cruiserlei','aidenwang416@gmail.com','Lei Wang','105 N Wayne St<br>Apt 3','Arlington','VA','UNITED STATES','22201-1556','(571) 228-2808','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-01 05:20:56',0,NULL,3,1,1,1,'\\ ',NULL),(17119,751645714007,170730545213,'New Logitech Digital IO Writing Pen',1,'NTLO002',39.99,'au-buy','wollonget','trade@wollondillygetaways.com.au','Pamela Ferrari','15 lakes st','thirlmere','New South Wales','AUSTRALIA','2572','0246234449','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 05:35:10',0,NULL,3,1,3,1,'RA117769872CN ','NTLO002 \r澳标'),(17120,652710874013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',1,'BTHP2102',12.39,'eastar4','stocknawe','montanalandscape@live.com','Debra Llera','4725 53rd Ave SW','Great Falls','MT','UNITED STATES','59404-4920','(406) 899-0749','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 05:39:25',0,NULL,3,1,1,1,'\\ ',NULL),(17121,805002007011,320742961625,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube',1,'PHVE001',35.99,'eastar4','azurguy','azurguy83@hotmail.fr','siegfreed gusse','n°123 BT A        1416 avenue henri guillaume<br>résidence les jardins d\'alizarine','La Seyne sur mer','PROVENCE-ALPES-CÔTE D\'AZUR','FRANCE','83500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 05:58:28',0,NULL,3,1,2,1,'\\ ',NULL),(17122,805002910011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','gerardo5374','gerardoynidia@hotmail.com','gerardo Sanchez','PO Box 6642<br>1067 7th Ave','San Luis','AZ','UNITED STATES','85349-6642','(928) 627-3958','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 06:02:57',0,NULL,3,1,1,1,'\\ ',NULL),(17123,890305882012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','retroman_16','mrk@starforze.net','Mark de Bruijn','Frans Halskade 78','RIJSWIJK ZH','','NETHERLANDS','2282VB','06-24564883','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 06:08:05',0,NULL,3,1,2,1,'\\ ',NULL),(17124,892134117012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Andrew Beeman','70 Herrick Ave','Milton','VT','UNITED STATES','05468-3039','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 06:48:49',0,NULL,3,1,1,1,'\\ ',NULL),(17125,744028110008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','jabba800','jabba800@yahoo.com.au','Jarred Bright','26 Border Court Arana Hills','Brisbane','Queensland','AUSTRALIA','4054','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 07:10:54',0,NULL,3,1,2,1,'\\ ',NULL),(17126,594551627003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','aviamotor','alekseyh@yandex.ru','Aleksey Khasanov','420036, Kazan, str. Pobegimova 46-229','Kazan','Tatarstan','RUSSIAN FEDERATION','420036','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 07:46:07',0,NULL,3,1,3,1,'RA117769064CN\r ','BALO007 '),(17127,8881322725754841,111,'New Genuine Motorola HS850 Bluetooth Headset ',1,'HSMO019',0,'cnfaner','omat1111','matos1094@yahoo.com','Osvaldo Matos Fuentes','5776 Akron Ct','Las Vegas','NV','UNITED STATES','89142-2683','(702) 885-9650',NULL,NULL,NULL,'2011-12-01 07:49:14',0,NULL,3,1,1,1,'LK084602299CN ','补货，测试一下再发货 '),(17128,805025302011,320786773775,'New iTech Clip II mini Multipoint Bluetooth Headset white',1,'HSIT003',21.99,'eastar4uk','f9933174','nikitakivicky@gmail.com','Nikitaki Vicky','Etgatwn typou 36','Athens','hlioupoli','GREECE','163.46','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 07:57:48',0,NULL,5,1,3,1,'RA117769081CN\r ','HSIT003\r欧标\r白色的 \r'),(17129,594558182003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','joetattoo3','joetattoo33019@yahoo.com','Joseph Arcara','16 Blackfoot Trl','Shoreham','NY','UNITED STATES','11786-2221','(631) 312-1777','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-01 08:25:19',0,NULL,3,1,1,1,'\\\r ',NULL),(17130,805037207011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','caspuss','gw2908@gmail.com','Gerry Woolley','9, Clumber Close<br>Ripley','Derby,s','Derbyshire','UNITED KINGDOM','DE5 3TS','07976449963','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 08:41:45',0,NULL,3,1,3,1,'RA117769387CN ',' '),(17131,599980019004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','srajmund','rajmund@mail.tvnet.hu','Rajmund Stricz','Diósdi str. 107/c','Érd','','HUNGARY','2030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 08:45:15',0,NULL,3,1,3,1,'RA117769268CN ','OTSO002 '),(17201,892739999012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',23.74,'eastar4','vladimirbelov','vwhite@yandex.ru','Vladimir Belov','Repina St. 4','Azov','RU','RUSSIAN FEDERATION','346780','79518334349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 08:12:00',0,NULL,3,1,11,1,'\\ ',' UM00034 ■'),(17132,892179675012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','dane777','stan_k@freemail.hu','Daniel Cservég','Zalka Mate u. 15.','Letenye','Zala','HUNGARY','8868','+36-30-699-4593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 09:45:18',0,NULL,3,1,2,1,'\\  ',NULL),(17133,652756311013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','vpuerta11','vpuerta@gmail.com','Victor Puerta Hinojosa','Capitan Angosto Gomez Castrillon 85 1º A','Aranjuez','Madrid','SPAIN','28300','918912901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 10:08:43',0,NULL,3,1,2,1,'\\  ',NULL),(17134,805063667011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',9.49,'eastar4','lpork670805','u9416709@ccms.nkfust.edu.tw','LIN PO-JUNG','No.24, Anjheng Rd., Yanchao Township','Kaohsiung County ','','TAIWAN','82448','+886-9-37679184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 10:19:35',0,NULL,3,1,2,1,'\\  ',NULL),(17135,744077041008,180762085590,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',2,'UM00034',49.98,'au-buy','sloc6495','boolee1977@hotmail.com','Susan Lockwood','6 Macintosh pl','Wagga wagga','New South Wales','AUSTRALIA','2650','0432928657','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 10:28:58',0,NULL,3,1,3,1,'RA117769546CN ','UM00034 '),(17136,805071754011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','billu_conhecimentobr','dinho123_gc@hotmail.com','Renato almeida junior','Avenida Liberdade<br>N 653','Taiobeiras','MINAS GERAIS','BRAZIL','39550-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 10:46:47',0,NULL,3,1,3,1,'RA117769444CN ',' GLOT001'),(17137,892208863012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','monica01969','monica.husby@hotmail.com','Monica Husby Moen','Rabben','Ekne','','NORWAY','7624','+4745205310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 11:18:36',0,NULL,3,1,3,1,'RA117769360CN ',' GLOT001'),(17138,652771921013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',3,'LGGL002',161.97,'eastar4','rodinicmunch','richard.arquitetura@gmail.com','Richard Schonhofen','Rua Pe. Germano Mayer 1894','Curitiba','Parana','BRAZIL','80040-170','55 041 9945-9950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 11:22:50',0,NULL,3,1,3,1,'RA117769461CN ',' LGGL002  加上电话号+55 (041) 9929-9798\r'),(17139,805083082011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','f20b3','phicus@gmail.com','Justinas Cerniauskas','Balsiu 9','Vilnius','','LITHUANIA','08400','+37067193399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 11:24:20',0,NULL,3,1,2,1,'\\  ',NULL),(17140,805095689011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','due_roberto','roberto301073@gmail.com','Roberto Cabestre Garcia','Del Rio, 25<br>San Juan de Mozarrifar','Zaragoza','Aragón','SPAIN','50820','976150116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 12:03:54',0,NULL,3,1,2,1,'\\  ',NULL),(17141,805096696011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','hyperus','timberwolf@windowslive.com','Sarocha Toimamuang','273/94 Moo 23, Ban Ped district','Muang','Khon Kean','THAILAND','40000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 12:09:40',0,NULL,3,1,2,1,'\\  ',NULL),(17142,652784433013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','baileycassie78','waderose@y7mail.com','wade lee rose','16 padbury st','jurien bay','Western Australia','AUSTRALIA','6516','0427909248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 12:18:20',0,NULL,3,1,3,1,'RA117769475CN ',' GLOT001*4'),(17143,600027062004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',5,'HSPL001',64.75,'cnfaner','sevicon','ebay@sevicon.com','Luis','C/ Forjadores nº 2 Bajo A','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','655527493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 12:41:29',0,NULL,3,1,3,1,'RA117769529CN ','HSPL001\r欧标 '),(17144,892244569012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',12.99,'eastar4uk','pdurrant','paul@durrant.co.uk','Paul M P Durrant','82 Earlham Road','Norwich','other','UNITED KINGDOM','NR2 3HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 13:00:00',0,NULL,3,1,3,1,'RA117769400CN\r ','WLAP002 '),(17145,652811135013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','jack_3940','shivo_40@yahoo.com.ph','JACEK  KROCHMAL','3845 OLAND  DR','MISSISSAUGA','ON','CANADA','L5M 6M8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:02:38',0,NULL,3,1,2,1,'\\  ',NULL),(17146,892276570012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','legionnet','anton.sharpaev@gmail.com','Anton Sharpaev','Ul. Novo-Kievskaya, d.4, kv.9','g. Smolensk','','RUSSIAN FEDERATION','214004','+7 910 785 3439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:21:17',0,NULL,3,1,3,1,'RA117769285CN ',' WWOT001'),(17147,652821223013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','bangsin88','bangsin8@gmail.com','shin bang','Koron b/d 4f, 1450-1, Gwanyang 1-dong, Dongan-gu, Anyang-si, Gyeonggi-do, Korea','Anyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','431-807','010-5049-9883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:40:14',0,NULL,3,1,2,1,'\\  ',NULL),(17148,805147837011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',52.99,'eastar4','laurindofirmino','laurindoo@hotmail.com','Laurindo Firmino','Rua Antonio Delmiro de Medeiros, 3392<br>Belo Horizonte','Mossoró','Rio Grande do Norte','BRAZIL','59600-460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:41:56',0,NULL,3,1,3,1,'RA117769435CN ','LGRM001 '),(17149,594643795003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',3,'HSMO005',44.97,'cnfaner','avinisim10','avi.nisim.sivan@gmail.com','AVI NISIM NISIM','YOSEF TAL<br>40','BAT YAM','ISRAEL','ISRAEL','59507','03-5529799','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:53:03',0,NULL,3,1,3,1,'RA117769356CN ','HSMO005 '),(17150,600059735004,140644120633,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones  long cable red',1,'HSPH002',37.6,'cnfaner','tomer_m','tomermo@gmail.com','Tomer Motola','הבוסתן 21/16','אשקלון','','ISRAEL','78501','057-8145184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:53:07',0,NULL,3,1,3,1,'RA117769515CN ','HSPH002\r红色的 '),(17151,805163348011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','exolibar','apajuelo@apv.jazztel.es','Antonio Pajuelo','Aragon 604-6-4','Barcelona','Barcelona','SPAIN','08018','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 15:10:21',0,NULL,3,1,3,1,'RA117769395CN ','LGGL002 '),(17152,600070144004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',117,'cnfaner','danieltampa','dnelson@nelcodevelopment.net','Daniel Nelson','5114 W Longfellow Ave','Tampa','FL','UNITED STATES','33629-7534','(813) 323-3353','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-01 15:30:16',0,NULL,3,1,1,1,'\\  ',NULL),(17153,751817812007,170730544737,'Logitech Charging Cradle L-LG7 for Harmony 880 890 Pro',1,'CRLO002',9.9,'au-buy','tedwheelup','pm@vigilantsystems.co.uk','paul meredith','DVS LTD<br>UNIT K6 SOUTHPOINT INDUSTRIAL ESTATE','FORESHORE ROAD','Cardiff','UNITED KINGDOM','CF10 4SP','02920455512','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-01 15:46:36',0,NULL,3,1,2,1,'\\  ',NULL),(17154,600084696004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.95,'cnfaner','phatkidjohn','moemoney95@yahoo.com','angelique steele','1227 Indiana Ave SE','Bandon','OR','UNITED STATES','97411-9127','(916) 468-8190','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-01 16:21:04',0,NULL,3,1,1,1,'\\  ',NULL),(17155,805177798011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','zuruhirumister11','zuruhirumister@yahoo.com','Zulhilmi Safain','4/9217 KG KURNIA BATU 3<br>JALAN GAMBANG','KUANTAN','PAHANG','MALAYSIA','25150','6095367399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 16:52:51',0,NULL,3,1,3,1,'RA117769413CN ','OTES001 '),(17156,892361981012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','balraj.11','balrajverma_14@yahoo.co.in','Balraj Verma','314 lady margaret road','southall','Middlesex','UNITED KINGDOM','ub1 2nq','07403223111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 17:31:10',0,NULL,3,1,3,1,'RA117769342CN ','HSJA010 '),(17157,652048862013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',2,'LGGL002',107.98,'eastar4','lmit2619','olarry71@aol.com','Larry mitchell','234 locust pass loop','Ocala','FL','UNITED STATES','34472-9387','(321) 276-8473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 18:21:02',0,NULL,3,1,1,1,'\\  ',NULL),(17158,600135252004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','andreykattorg','kattorg@mail.ru','Andrey Stepanyuk','Stepnoi-1,13-79','Karaganda','','KAZAKHSTAN','100025','+7(702)8222212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 18:47:23',0,NULL,3,1,3,1,'RA117769325CN ','MOOE001\rOEM的 '),(17159,805274891011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','kp0655','krpabiz@hotmail.com','Krunal Patel','32 Carmelite Rd, Harrow','London','Middlesex','UNITED KINGDOM','HA35LR','07956465942','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 19:09:06',0,NULL,3,1,3,1,'RA117769339CN ','OTHP005 '),(17160,891320209012,220859194097,'NEW IN BOX Genuine Samsung 2 pair SSG-2100AB 3D glasses + monster VS Aliens disc',1,'GLSG001*2+BR3D002',121.99,'eastar4','hollenoxf10','hollen@free.fr','Mme FRESLON','7 route des essarts','LA BOISSIERE','Normandie','FRANCE','27220','0232363510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 19:25:19',0,NULL,3,1,3,1,'RA117769577CN ',' GLSG001*2+BR3D002'),(17161,805301432011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','kindrix99','shelly@shellykinyon.com','rochelle kinyon','1863 s grand drive','apache junction','AZ','UNITED STATES','85210','(480) 254-1122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 19:39:35',0,NULL,3,1,1,1,'\\ ',NULL),(17162,600159440004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','charliemaok','gard56@sbcglobal.net','JIM GARDNER','PO BOX 1133','CASTROVILLE','CA','UNITED STATES','95012','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-01 19:47:17',0,NULL,3,1,1,1,'\\  ',NULL),(17163,805330095011,320737014742,'2 pair NIB genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',75.99,'eastar4uk','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 20:23:17',0,NULL,3,1,3,1,'RA117769585CN ','GLSG001*2'),(17164,652767500013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',2,'UM00033',37.98,'eastar4','123unknown2001','evelyn.muenter@gmx.de','evelyn münter','Breslauer Straße 3','Erlangen','','GERMANY','91058','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 20:24:43',0,NULL,3,1,3,1,'RA117769550CN ',' lady shoes 和cat '),(17165,594768224003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','stevielo','steve_loomans@hotmail.com','Steven Loomans','Johan Dijkstralaan 39','Groningen','','NETHERLANDS','9744 DB','0614259717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 20:30:50',0,NULL,3,1,3,1,'RA117769501CN ','MOOE003\rOEM的 '),(17166,892507910012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','talk!nghands','peter.rump@muehlenprofi.de','Peter Rump','In der Trift 12','Westerburg','','GERMANY','56457','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 21:05:21',0,NULL,3,1,2,1,'\\  ',' 欧标'),(17167,744353243008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',3,'HSPL015',150.78,'au-buy','gjnagjna','gus.osullivan@gmail.com','Gus O\'Sullivan','50 Twelvetree Crescent','Florey','Australian Capital Territory','AUSTRALIA','2615','61418469997','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 21:13:33',0,NULL,3,1,3,1,'RA117769458CN ','HSPL015 \r澳标'),(17168,594797622003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','onebigglitch','onebigglitch@yahoo.com','eric kauffman','21412 N 14th Ave','phoenix','AZ','UNITED STATES','85027-2804','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-01 21:40:18',0,NULL,3,1,1,1,'\\  ',NULL),(17169,892529104012,220858471777,'New PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4uk','mimtiyazudd','mimtiazudd@gmail.com','mohammed imtiazudidn','91A Dallas Road<br>Hendon','London','London','UNITED KINGDOM','NW4 3JD','07574479378','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 21:40:26',0,NULL,3,1,3,1,'RA117769299CN\r ','HSPL001\r英标 '),(17170,892539386012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','jhewinbaldwin','duaneandjulie@gmail.com','Julie Hewin Baldwin','8117 Virginia Ave','West Point','VA','UNITED STATES','23181','(804) 843-7370','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 21:54:35',0,NULL,3,1,3,1,'RA117769532CN ',' UM00008'),(17171,805391336011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',50,'TRMX002',378.5,'eastar4','usedrouters','purchasing@cablesandkits.com','AtlanTech Resellers, Inc.','4555 Atwater Ct<br>Ste A','Buford','GA','UNITED STATES','30518-3498','(678) 597-5000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 22:09:42',0,NULL,3,1,4,1,'YW867661260CN ',' AUI AT-210TS   23个    PO# 16628  写在单子上'),(17172,752026843007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',53.9,'au-buy','alekzandra_101','sherelle.ryan@bigpond.com','Sherelle Ryan','65 Kosciusko AVE','Palmerston','Australian Capital Territory','AUSTRALIA','2913','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 22:13:16',0,NULL,5,1,18,0,NULL,'HSPL013\r要original packaging  退款了\r'),(17173,805401959011,320679542185,'Original Allied Telesyn AUI AT-210TS Transceiver10BaseT',23,'TRMX001',174.11,'eastar4','usedrouters','purchasing@cablesandkits.com','AtlanTech Resellers, Inc.','4555 Atwater Ct<br>Ste A','Buford','GA','UNITED STATES','30518-3498','(678) 597-5000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 22:29:40',0,NULL,3,1,17,0,' ',NULL),(17174,594815937003,130554588383,'NEW Logitech battery 890 880 950mA',1,'BALO001',10.9,'cnfaner','sommer1961','sommer@idc.ac.il','Dr. Hillel Sommer','P.O. Box 167','Herzlia','Israel','ISRAEL','46150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 22:29:59',0,NULL,3,1,3,1,'RA117769271CN\r ','BALO001 '),(17175,653015077013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','gazscarbitz','garryquinn50@yahoo.co.uk','Garry Quinn','16 Headington Avenue<br>Whitmore Park','Coventry','West Midlands','UNITED KINGDOM','CV6 2GY','02476336657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 23:10:44',0,NULL,3,1,3,1,'RA117769489CN ','GLOT001*3 '),(17176,892586926012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','durranimo','amalan@iinet.net.au','Nathan Amalan','16 Hillcrest Avenue','South Strathfield','New South Wales','AUSTRALIA','2136','0296422125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 23:31:40',0,NULL,3,1,2,1,'\\  ',NULL),(17177,805443044011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','jrsmach1','joerigby5836@msn.com','joe rigby','5836 Dahlia Ave','New Port Richey','FL','UNITED STATES','34652-4728','(727) 848-4169','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 00:10:42',0,NULL,3,1,1,1,'\\  ',NULL),(17178,805445313011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','a3127777','3127777@mail.ru','Александр Бабасинов','Короленко, 15/1, 2','Ставрополь','Ставропольский край','RUSSIAN FEDERATION','355029','+79614897777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 00:16:21',0,NULL,3,1,3,1,'RA117769603CN ',' CC00002'),(17179,744442938008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','phil0430516','phil0430@aol.com','PHILIP YOUSSEF','2280 Brody Ln','BELLMORE','NY','UNITED STATES','11710-5102','(516) 314-6856','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 00:43:42',0,NULL,3,1,1,1,'\\  ',NULL),(17180,891583204012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',23.74,'eastar4','reaktor-a42','glebov75@rambler.ru','Konstantin Glebov','11 Voloshinoy Street,<br>Appartment 22','Kemerovo','','RUSSIAN FEDERATION','650024','903-941-7663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 01:09:23',0,NULL,3,1,11,1,'\\ ',' UM00034 ■'),(17181,805467862011,320685063334,'NIB Visenta I5 wireless mouse w/ nano USB receiver',1,'MOVI003',229.98,'eastar4','henriklundmark','henrik.henke@hotmail.com','Henrik Lundmark','Smaragdvägen 28','BODEN','Norrbotten','SWEDEN','96146','0730323024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 01:29:53',0,NULL,3,1,3,1,'RA117769594CN ',' 再发3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250    OTSO004*3\r '),(17182,892629550012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','2010anita2011','anitadelcheva@hotmail.co.uk','Anita Delcheva','2A sunnydene<br>Highams Park','London','London','UNITED KINGDOM','E4 9RE','07599403729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 01:32:13',0,NULL,3,1,3,1,'RA117769492CN ',' UM00008'),(17183,891554432012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','toci_030406','sub_visser_twenty@yahoo.com','Azky Igfirianto','Jln. Kawi 2 No.149, RT/RW 04/11<br>Kel. Abadijaya, Kec. Sukmajaya','Depok','Depok Timur','INDONESIA','16417','+6285718327750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 01:37:49',0,NULL,3,1,2,1,'\\  ',NULL),(17184,744465478008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','hugojean60','hugojean@hotmail.com','Hugo Jean','1190 Boulevard René-Lévesque Ouest<br>Appartement #3','Québec','QC','CANADA','G1S 1V9','(418) 571-3757','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 02:00:16',0,NULL,3,1,3,1,'RA117769427CN ','GLOT001 '),(17185,805131656002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','scubaking503','scubaking503@hotmail.com','Marc Pelletier','68 Ste Anne<br>Appt #1','Ste-Genevieve','QC','CANADA','H9H 2Z1','(514) 784-1504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 02:11:12',0,NULL,3,1,2,1,'\\  ',NULL),(17186,805480857011,320786223346,'New Jabra JX10 Series II 2  Bluetooth headset red',1,'HSJA013',19.98,'eastar4','drewmair7','andrewdm7@gmail.com','Andrew Mair','343 Merrimon Ave<br>Sunshine Employment Resources','Asheville','NC','UNITED STATES','28801-1223','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 02:11:29',0,NULL,3,1,1,1,'\\ red ',NULL),(17187,600279514004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',2,'HSJA004',37.96,'cnfaner','drewmair7','andrewdm7@gmail.com','Andrew Mair','343 Merrimon Ave<br>Sunshine Employment Resources','Asheville','NC','UNITED STATES','28801-1223','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 02:13:51',0,NULL,3,1,1,1,'\\  ','黑色 '),(17188,892638259012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','2thess3.16','rosem721@gmail.com','ROSEMARIE MCCHESNEY','984 Edwards Lake Rd','BIRMINGHAM','AL','UNITED STATES','35235-1451','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 01:56:54',0,NULL,3,1,1,1,'\\  ',' '),(17189,762072719001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',72.97,'buysia','winter888888','elam138@yahoo.ca','Eric Lam','8 Coral Springs Park  N.E','Calgary','AB','CANADA','T3J3R1','(403) 899-1288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 02:56:21',0,NULL,3,1,3,1,'RA117769373CN ','一共三张CD\rBR3D007\rBR3D005\rBR3D002\r\r '),(17190,805152897002,120768942355,'Monsters VS Aliens New Samsung 3D Blu-ray disk blue ray',1,'BR3D002',34.99,'buysia','dreamparamedic069','paramedic007@sympatico.ca','christian lafont','5253 Du Président Kennedy #01','Sherbrooke','QC','CANADA','J1N 4C1','(819) 864-9234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 03:19:33',0,NULL,3,1,2,1,'\\  ',NULL),(17191,594885331003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',15.99,'cnfaner','krod405','rodjennings@hotmail.com','Rodger Jennings','405 Elizabeth Ln','Glencoe','AL','UNITED STATES','35905-1451','(256) 494-9196','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 03:26:35',0,NULL,3,1,1,1,'\\  ',' '),(17207,594968313003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',13.88,'cnfaner','yorkynick50','nickhaz2dogs@btinternet.com','nick foulds','30 elsdon close<br>whitwick','coalville','Leicestershire','UNITED KINGDOM','le675fx','07765865488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 11:26:36',0,NULL,3,1,3,1,'RA117767298CN\r ','HSNO007 \r英标 '),(17192,8881322801522529,111,'3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001',0,'eastar4','mchr2727','matthewlc17@gmail.com','Matthew Christensen','26160 Twain Place','Stevenson Ranch','CA','UNITED STATES','91381','(661) 799-0531',NULL,NULL,NULL,'2011-12-02 04:52:02',0,NULL,3,1,1,1,'LK016996671CN  ',' matthewlc27  改一个 单号录入'),(17193,805526106011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',3,'GLOT001*2',266.97,'eastar4','wez30','weeze@koodomobile.blackberry.com','Paul Stephens','149 Coulter Dr<br>PO Box 448','Pontypool','ON','CANADA','L0A1K0','(705) 277-2111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 05:22:48',0,NULL,3,1,6,1,'EE495359503CN ',NULL),(17194,892712637012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','nicat-au','nicat@internode.on.net','Nick Derwas','40 Sussex Terrace','Westbourne Park','South Australia','AUSTRALIA','5041','0882726077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 06:11:41',0,NULL,3,0,2,1,'、 ',NULL),(17195,600324966004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',2,'LGGL003',39.18,'cnfaner','babbacombe-boy','bevan@bevansfineart.com','Bevan Badcott','7 Johnson Place','Surf Beach','New South Wales','AUSTRALIA','2536','0244711323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 06:28:41',0,NULL,3,1,3,1,'RA117769705CN\r ','LGGL003 '),(17196,653116845013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',75,'eastar4','francoisxavier141075','groult-autoservice@orange.fr','GROULT AUTOS SERVICE','5 RUE DE L\'ABBE GROULT','PARIS','Ile-de-France','FRANCE','75015','0145333301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 06:43:44',0,NULL,3,1,3,1,'RA117769634CN\r ',' TRTT002*10'),(17197,653117816013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',23.74,'eastar4','mt89066','tuzkovms@mail.ru','Mikhail Tuzkov','Visokovoltnaya str., d. 34, k. 3, kv. 40','Ryazan','Ryazanskaya oblast\'','RUSSIAN FEDERATION','390029','8(953) 748-9005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 06:50:53',0,NULL,3,1,11,1,' \\\r',' UM00009'),(17198,805555122011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',75,'eastar4','denis44800','denis.senard@capelia.fr','DENIS SENARD','19 ALLEE MOZART','SAINT-HERBLAIN','Pays de la Loire','FRANCE','44800','0608015486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 07:05:05',0,NULL,3,1,3,1,'RA117769625CN\r ',' TRTS001*10'),(17199,600329734004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','shoker209','ravishoker09@gmail.com','Tarsem Shoker','985 Dallas Dr','Livingston','CA','UNITED STATES','95334-9224','(209) 417-2811','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 07:07:00',0,NULL,3,1,1,1,'\\  ',''),(17200,805563359011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','neo-tiv','timchenko.i@gmail.com','Igor Timchenko','Traktorostroiteley str, 79/42, 9','Kharkov','','UKRAINE','61120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 07:47:00',0,NULL,3,1,3,1,'RA117769682CN\r ','GLOT001\r兼容眼镜 通用型 '),(17202,653135171013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','tiff2303','tiffanylamb@bigpond.com','Tiffany Lamb','43 Topsail Loop','Alkimos','Western Australia','AUSTRALIA','6038','0895621312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 08:43:53',0,NULL,3,1,3,1,'RA117769679CN\r ',' GLOT001*4'),(17203,594936545003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','ntslsandun','sandun_lenora@yahoo.com','sandun lenora','07 sujatha mawatha kalubwila dehiwala<br>19 srimahavihara road kolubowila dehiwala','colombo','colombo','SRI LANKA','941','+94772990983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 08:51:13',0,NULL,3,1,2,1,'\\ ','斯里兰卡\r '),(17204,805588309011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','kromus_se','emil.stefanik@gmail.com','Emil Stefanik','OMV Solutions GmbH<br>Trabrennstrasse 6-8','Wien','','AUSTRIA','1020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 09:25:18',0,NULL,3,1,3,1,'RA117769926CN ','GLOT001*3 '),(17205,8881322818801309,111,'BH-203',1,'',0,'eastar4','davet2234','davidgturner@sky.com','David Turner','Mr Fothergills Seeds<br>Gazeley Road','Kentford','Suffolk','UNITED KINGDOM','CB8 7QB','01638751161',NULL,NULL,NULL,'2011-12-02 09:40:01',0,NULL,3,0,2,1,'、 ',' 只发adapter 不给耳机'),(17206,805618453011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','anug2133','a.nugent@yahoo.co.uk','andy nugent','brook st 66','uk','Bedfordshire','UNITED KINGDOM','lu3 1ds','07927389467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 11:15:07',0,NULL,3,1,3,1,'RA117766099CN ',' GPS0007'),(17208,805629246011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',52.99,'eastar4','marifialho','mariana.mfialho@gmail.com','Mariana Fialho','Caixa Postal 226, AC UFV','VIÇOSA','MINAS GERAIS','BRAZIL','36570000','55-031-94319982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 11:44:19',0,NULL,3,1,3,1,'RA117767355CN\r ',' LGRM001'),(17209,653182481013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','robertofeitosa','robertollima@hotmail.com','Teresinha Vieira Rodrigues','Rua Padre Guerra , 465<br>Parque Araxá','Fortaleza','Ceará','BRAZIL','60450-665','085-32140096','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 12:25:10',0,NULL,3,1,3,1,'RA117767267CN\r ',' HSSA002'),(17210,805643153011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','xtrimal','xtrimal@gmail.com','Leonid Maev','Koshurbikova st. 39 - 105','Novosibirsk','Novosibirskaya obl','RUSSIAN FEDERATION','630089','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 12:25:17',0,NULL,3,1,3,1,'RA117767205CN ','GLOT001*3 '),(17211,594991080003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','marquinho_marc','marcvericatquerol@gmail.com','Ramon Vericat Pallares','Pol. Ind. Baix Ebre c/D Parc. 93','Campredó, Tortosa','Cataluña','SPAIN','43897','678354587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 13:04:18',0,NULL,3,1,3,1,'RA117769957CN ','MOOE003\rOEM的 '),(17212,752283700007,170728978787,'NIB LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',20.99,'au-buy','lisankev','kevnlisa83@yahoo.com','lisa smith','108 landa street','lithgow','New South Wales','AUSTRALIA','2790','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-02 13:07:00',0,NULL,3,1,2,1,'、 ',' '),(17213,891914391012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',31.39,'eastar4uk','felipegontijo','felipegontijo@pop.com.br','Felipe Gontijo de Queiroz','Rua Heitor Sócrates Cardoso, 180<br>Bairro Santa Amélia','Belo Horizonte','Minas Gerais','BRAZIL','31560-320','+553188585181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 13:41:18',0,NULL,3,1,3,1,'RA117767077CN ','LGFI001 '),(17214,751972281007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','kavanarez','kavanahus@yahoo.com','Mihail Ovchinnikov','Tehnicheskaya 121','Yekaterinburg','','RUSSIAN FEDERATION','620134','89222219434','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 13:45:55',0,NULL,3,1,11,1,'BJ01600691 ','■UM00042 '),(17215,892862836012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','andreis1andrei','andrei.sserban@yahoo.com','Andrei Serban / Ban Nicoleta','Boomgaardstraat 33A','Maaseik','','BELGIUM','3680','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 14:11:51',0,NULL,3,1,11,1,NULL,'■HSJA010欧标 '),(17216,805327439002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','tkrhodes77','mstiff30@att.net','Tiffany Rhodes','205 Greenwood Ave','Sherwood','AR','UNITED STATES','72120','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 14:14:43',0,NULL,3,1,1,1,'\\  ',NULL),(17217,762247916001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',69.78,'buysia','fast-1','lpotts8163@cox.net','Lyman Potts','56 Crestwood Dr','Narragansett','RI','UNITED STATES','02882-1023','(401) 284-4067','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 14:51:33',0,NULL,3,1,1,1,'\\  ','一共买了四张\r Monster House ， ICE AGE  \r ，加勒比海盗和爱丽丝梦游仙境 \r \r '),(17218,653224262013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','magdalena4938','ptlmag@aol.com','Magdalena Patelka','269a cricklewood lane','london','London','UNITED KINGDOM','NW2 2JJ','02084550534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 14:55:43',0,NULL,3,1,3,1,'RA117767240CN ',' GLSG001*2+BR3D008'),(17219,892888011012,220815928685,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO003',22.9,'eastar4uk','kaname--nakajima','kyna.riverdog@gmail.com','Nina Stannek','Reinersstr. 06','Recklinghausen, NRW','','GERMANY','45665','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(17220,595031549003,130458926910,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 track#',1,'HSUE004',12.49,'cnfaner','roman.2262','roman.vesely@hotmail.com','Roman Vesely','Jeseniova 159','Praha 3 - Zizkov','','CZECH REPUBLIC','13000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 15:31:53',0,NULL,3,1,3,1,'RA117767386CN\r ','HSUE004 '),(17221,892901882012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','a26165','nunoinglesagostinho@gmail.com','Nuno Ingles Agostinho','Av. Duque D\'Avila 64 5A','Lisboa','Lisboa','PORTUGAL','1050-083','00351927269091','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 15:38:49',0,NULL,3,1,11,1,NULL,'■WLIN014 '),(17222,805383640002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','lenobel123','christianlenobel@hotmail.com','Christian le Nobel','PO Box 492','Whistler','BC','CANADA','V0N 1B0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 16:26:06',0,NULL,3,1,3,1,'RA117766068CN ','OTPH003 '),(17223,653255649013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','bobbyjc1984','bobbyjoecool@gmail.com','Robert Breutzmann','104 Locust St<br>Apt 24','Waverly','IA','UNITED STATES','50677-9621','(319) 939-3687','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,' echeck\r'),(17224,595050899003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','schadow63','schadow@spray.se','klas johansson','grevegårdsvägen 218','gothenburg','V:A gotaland','SWEDEN','42161','031458463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 16:30:51',0,NULL,3,1,3,1,'RA117767338CN\r ','HSPL005 \r欧标'),(17225,653269477013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','flgatorguy','flgatorguy@aol.com','STEVE BALLINGER','PO BOX 151081','ALTAMONTE SPRINGS','FL','UNITED STATES','32715','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 17:05:56',0,NULL,3,1,1,1,'\\  ',NULL),(17226,892953789012,220859193239,'100% New in box Genuine Samsung 2 pair SSG-2100AB + 3D Blu-ruy ICE AGE 3 disc',1,'GLSG001*2+BR3D006',114.99,'eastar4','shutaas','shutaas@yahoo.com','Tomas Sutas','World Skills London 2011, Oceanic H<br>5th Floor, 1A Cockspur Street','London','London','UNITED KINGDOM','SW1Y5BG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 17:15:38',0,NULL,3,1,3,1,'RA117767165CN ',' GLSG001*2+BR3D006'),(17227,653280010013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','brummiee','ebay@hines.at','Peter R. Hines','Eichenstraße 18','Unna','','GERMANY','59423','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 17:30:41',0,NULL,3,1,2,1,'、 ',' 欧标'),(17228,892969585012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','mrt13579','sthorneycroft@btinternet.com','stephen thorneycroft','67a Ingrebourne Gardens','Upminster','Essex','UNITED KINGDOM','rm14 1bn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-02 17:42:22',0,NULL,3,1,3,1,'RA117767942CN\r ','LGAD001 '),(17229,653288673013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','jhye9505','jbhyers@gmail.com','Justin Hyers','931 Chestnut Ridge Rd','Manchester','MO','UNITED STATES','63021-6925','(636) 529-1512','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 17:53:31',0,NULL,3,1,1,1,'\\  ',' '),(17230,595092384003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','russianbear2000','artnikolaev@yahoo.com','Arthur Nikolaev','8002 sky blue dr.','Alexandria','VA','UNITED STATES','22315','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 18:26:45',0,NULL,3,1,1,1,'\\  ',NULL),(17231,893002891012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','lv0872','linvoigt@gmail.com','Lin Voigt','13444 Bugatti Dr','Frisco','TX','UNITED STATES','75033-0920','(919) 650-1018','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 18:37:42',0,NULL,3,1,1,1,'\\  ',NULL),(17232,653309607013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',165.9,'eastar4','jasonsellsthings','jason.penning@gmail.com','Jason Penning','4 Studebaker','Irvine','CA','UNITED STATES','92618-2012','(949) 595-5371','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(17233,893010933012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','bodega6','donnawa@sbcglobal.net','Donna Wagoner','1358 Truchard Ln','Lincoln','Ca','UNITED STATES','95648-8144','(916) 543-9558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 18:53:51',0,NULL,3,1,1,1,'\\  ',NULL),(17234,893013256012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','santaclauserobert','robertsgifts@hotmail.com','Robert Ross','PO Box 253','Santaquin','UT','UNITED STATES','84655-0253','(801) 995-5894','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 18:54:31',0,NULL,3,1,1,1,'\\  ',' '),(17235,805830852011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','joo4440','btnusa@hotmail.com','JOOYOUNG LEE','436 Hillview Dr<br>Apt 102','Linthicum','MD','UNITED STATES','21090-1845','(443) 255-4641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 19:07:37',0,NULL,3,1,1,1,'\\  ',NULL),(17236,762382818001,110715183632,'NIB CBS High Pressure Portable Car Washer wash 12L',1,'CAWA002',89.9,'buysia','danielpreyerveloni','danielveloni@gmail.com','Daniel Veloni','Avenida Ultramarino, 660 apartamento 101','São Paulo','São Paulo','BRAZIL','02441001','55 11 91867088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 19:10:19',0,NULL,3,1,5,1,'CP211275369CN','CAWA002 '),(17237,653326654013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','e_zaec','hare_hare@mtu-net.ru','Inna Savushkina','Ostrovityanova ul., 45/3, kv. 75','Moscow','','RUSSIAN FEDERATION','117342','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 19:24:57',0,NULL,3,1,11,1,NULL,'■WLIN014 '),(17238,893037338012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',4,'WLAP002',51.96,'eastar4uk','lochearn1234','sales@ukdigitrader.co.uk','Patrick  Welsh','41 belllower ave<br>south park','glasgow','Renfrewshire','UNITED KINGDOM','g537yd','07586363761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-02 19:32:13',0,NULL,3,1,3,1,'RA117767390CN\r ','WLAP002 '),(17239,653330857013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','steficacvek','stefica_cvek@yahoo.com','Amra Serdarevic','12614 N 38th Dr','Phoenix','AZ','UNITED STATES','85029-2007','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(17240,805852915011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','deva6595','david@showchampions.com','David Evans','444 Woodhaven Place SW','Calgary','AB','CANADA','T2W 5P1','(403) 604-3023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 19:43:45',0,NULL,3,1,2,1,'、 ',NULL),(17241,653332724013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',53.99,'eastar4','edson0055','edson@proxy.com.br','Edson Alves','Rod. Dom Gabriel P. B. Couto 72500 - Cond. Reserva da Serra Lote P20<br>Medeiros','Jundiai','São Paulo','BRAZIL','13212-910','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 19:44:12',0,NULL,3,1,3,1,'RA117767871CN\r ',' LGGL002'),(17242,595140151003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','slavag1989','slava.g1989@gmail.com','Slava Golovchiner','Hodem 9 B','Maalot','north','ISRAEL','24952','0547450157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 20:24:54',0,NULL,3,1,3,1,'RA117767956CN\r ','HSMO005 '),(17243,595167053003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',2,'HSPL008',63,'cnfaner','lesthan','marinerbaseball@excite.com','Les Sliger','832 N 750 E','Orem','UT','UNITED STATES','84097-4272','(801) 368-1253','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 21:54:18',0,NULL,3,1,1,1,'\\  ',NULL),(17244,653393341013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',10,'CASS001',82.9,'eastar4','chandra1321','hadinata_chandra@yahoo.com','Chandra Hadinata','3306/197 Castlereagh St','Sydney','New South Wales','AUSTRALIA','2000','0280336221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 22:05:23',0,NULL,3,1,3,1,'RA117767275CN\r ',' CASS001'),(17245,805933297011,320665734592,'New Jabra BT320S BT 320S FreeSpeak Bluetooth Headset',1,'HSJA003',23.69,'eastar4','daniz99','danial494@gmail.com','Daniel Salami','P.O. Box 1388<br>-','Julis','Israel','ISRAEL','24980','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 22:08:02',0,NULL,3,1,11,1,NULL,'■HSJA003 '),(17246,595193495003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','mmojowrkn','clearlightphoto@comcast.net','Doug  Brown','2531 Cherry St','Bellingham','WA','UNITED STATES','98225-2003','(360) 647-1657','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 22:54:35',0,NULL,3,1,1,1,'\\  ',NULL),(17247,595200728003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','parkrajkumar','krajkumarus@gmail.com','Rajkumar Kottapalli','118 cardigan ct','parsippany','NJ','UNITED STATES','07054-3420','9732160877','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-02 23:22:23',0,NULL,3,1,1,1,'\\  ',' '),(17248,595210330003,130603400151,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver2',1,'SHLO010',12.95,'cnfaner','pmiebach','pjmiebach@gmail.com','Peter Miebach','404-3100 Carling Ave.','Ottawa','ON','CANADA','K2B6J6','(613) 864-2564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 23:58:17',0,NULL,3,1,3,1,'RA117767134CN ','SHLO010\rback ver2 '),(17249,653428944013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','bernienz','berniej@actrix.co.nz','Bernard Janssen','337 Waimea Road','Nelson','','NEW ZEALAND','7011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 23:59:51',0,NULL,3,1,2,1,'、 ',NULL),(17250,600621047004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','sieid','sieidhamid@hotmail.com','sieid ahmed','1619 Becontree Ln<br>Apt 1D','reston','VA','UNITED STATES','20190-4093','(703) 568-6084','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 00:16:21',0,NULL,3,1,1,1,'\\  ',NULL),(17251,653436581013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','shango_12','rainbow_serpent12@yahoo.com.au','Craig W. Seager','12 Pellion Pl','Bathurst','New South Wales','AUSTRALIA','2795','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 00:27:55',0,NULL,3,1,3,1,'RA117769807CN ',' GLOT001*3'),(17252,653437787013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',73.98,'eastar4','theblueeye','rzobell@gmail.com','Richard Zobell','Richard E. Zobell<br>268 Oakmere Way','Chestermere','AB','CANADA','T1X 1N5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 00:33:42',0,NULL,3,1,3,1,'RA117767324CN\r ',' WWSI005'),(17253,744960474008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','willkinn','william@kinnaird.net','Bill Kinnaird','Unit 17<br>19 Wye Street','Blacktown','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 01:10:09',0,NULL,3,1,3,1,'RA117769841CN ','GLOT001 \r兼容眼镜 通用型'),(17254,744966774008,180757094405,'Original New Replaceable Shell for logitech Mouse M705',1,'SHLO003',12.99,'au-buy','susan-9dorf','comfortableathome4655@hotmail.com','Susan Beattie','526 O\'Regan creek road','Toogoom','Queensland','AUSTRALIA','4655','0741280996','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 01:48:02',0,NULL,3,1,2,1,'\\ ',NULL),(17255,893230682012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',88.4,'eastar4','realtooltan','thanh.kieu.diem@gmail.com','Tan Nguyen','8 Sesame Grove','Manukau','','NEW ZEALAND','2105','(09)2635204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 02:18:37',0,NULL,3,1,3,1,'RA117767559CN\r ',' HBPH001  再发一个charger base HBPH003'),(17256,595246550003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','al-sada90','hsh.1@hotmail.com','hashim alsada','alkherityat st. house #36<br>P.O box 8529','doha','','QATAR','19674','(551) 171-17','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 02:54:44',0,NULL,3,1,3,1,'RA117769930CN ','MOOE003\rOEM的 '),(17257,805672488002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','jcsitanhaem','joao.carlos.soares@itelefonica.com.br','joao carlos soares','rua antonio olivio de araujo 36<br>centro','ITANHAEM','SAO PAULO','BRAZIL','11740000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 03:04:47',0,NULL,5,0,18,0,NULL,'客户要取消\r在询问 '),(17258,591693820003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',17.09,'cnfaner','chajazz1','kimcgermany@gmail.com','Kim Germany','2556 Theodosia Dr','Baton Rouge','LA','UNITED STATES','70809-1926','(225) 718-4325','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-03 03:52:44',0,NULL,3,1,1,1,'\\  ',NULL),(17259,806052411011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','letro2007','montanadon@webtv.net','DONALD LETRO','166 Main St','RANDOLPH','NY','UNITED STATES','14772-1128','(716) 358-6912','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 04:06:28',0,NULL,3,1,1,1,'\\  ',NULL),(17260,595271763003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','lbar9249','lucho9889@hotmail.com','Luis Barraza','23150 SW 104TH AVENUE','Miami','FL','UNITED STATES','33190','(786) 208-6041','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 05:15:54',0,NULL,3,1,1,1,'\\  ','OEM的'),(17261,653501988013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','conniecmac','connieerik@yahoo.com','connie macfarlane','151 baker ln','altoona','PA','UNITED STATES','16601-9650','(814) 935-9975','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 05:27:25',0,NULL,3,1,3,1,'RA117769722CN ',' GLOT001*4'),(17262,653336875013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','judyissa','jvissa@hotmail.com','Al Mansoori Production Services, C/O Ahmed Issa','P.O. Box 7663','Abu Dhabi','','UNITED ARAB EMIRATES','00000','(971) 506-4253 ext.: 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 05:44:01',0,NULL,3,1,3,1,'RA117769988CN ',' GLOT001*4'),(17263,600683197004,140519629061,'New Sony Ericsson HBH-DS220 BLUETOOTH HEADSET track#',1,'HSSE006',63.95,'cnfaner','j9mkeller','j9keller@gmail.com','Janine Keller','20519-91 Avenue','Edmonton','AB','CANADA','T5T 0W9','(780) 425-8474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 05:57:08',0,NULL,3,1,3,1,'RA117767015CN ','HSSE006 '),(17264,893300765012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','mogwaiuk','mariannec@talktalk.net','Marianne Cooney','7 JOHN CRESCENT<br>TRANENT','EAST LOTHIAN','East Lothian','UNITED KINGDOM','EH33 2HP','01875616371','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 06:35:47',0,NULL,3,1,3,1,'RA117767868CN\r ','LGAD001 '),(17265,805724847002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','digdoug225','douglas225@netzero.com','Douglas Maloney','827 Diamond Cir','Arroyo Grande','CA','UNITED STATES','93420','(805) 489-4541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 06:55:13',0,NULL,8,1,17,0,' ',NULL),(17266,805725715002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','digdoug225','douglas225@netzero.com','Douglas Maloney','827 Diamond Cir','Arroyo Grande','CA','UNITED STATES','93420','(805) 489-4541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 06:57:47',0,NULL,8,1,17,0,NULL,' '),(17267,762621357001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','digdoug225','douglas225@netzero.com','Douglas Maloney','827 Diamond Cir','Arroyo Grande','CA','UNITED STATES','93420','(805) 489-4541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 07:02:06',0,NULL,3,1,1,1,'\\  ','一共发三张 \r另外还有加勒比海盗和爱丽丝梦游仙境 '),(17268,595289358003,130583982411,'New Genuine Motorola H550 Bluetooth Headset track#',1,'HSMO007',14.9,'cnfaner','huna-runa','geno.grandinette@us.army.mil','geno grandinette','111 1st Cavalry Rd','FORT LEAVENWORTH','KS','UNITED STATES','66027-1202','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 07:26:20',0,NULL,3,1,1,1,'\\  ',NULL),(17269,653526563013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','tomassakura','tomas.sakura@one.lt','Tomas Kalibartas','Molainiu g. 88 - 5','Panevezys','Panevezys','LITHUANIA','37153','+37061253611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 08:07:39',0,NULL,3,1,11,1,NULL,'■WLIN014 '),(17270,893322965012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','alison9794','harry.spartacus@virgin.net','Christopher Haritakis','9 Quernmore Road','stroud green','London','UNITED KINGDOM','N4 4QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 08:08:29',0,NULL,3,1,3,1,'RA117767032CN ','SAFI001 '),(17271,805740388002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','wilfredop2005','wilfredopacheco@hotmail.com','wilfredo pacheco','50 Goff St','hyde park','MA','UNITED STATES','02136-1829','(617) 686-9054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 08:10:59',0,NULL,3,1,1,1,'\\  ',NULL),(17272,653536384013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','baby28','karen@boxerden.com','Karen Chan','15409 95A Avenue','Surrey','BC','CANADA','V3R 7T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 08:56:09',0,NULL,3,0,3,1,'RA117769784CN ',' GLOT001*2'),(17273,893352998012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','rambo061268','hockeyoburg@web.de','Roland Matzko','Muskauer Str. 6d','Cottbus','','GERMANY','03042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 09:42:34',0,NULL,3,1,2,1,'、 ',' acer 5pin1.25 6cm'),(17274,891254043012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','ibrahim0782','brahimbcak@yahoo.com','ibrahim Bicak','lara cad. guzeloba mah. ay1 sok.<br>no:1 Kayitur - Kayiplaza','Antalya','Muratpasa','TURKEY','07230','+905337770995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 09:45:03',0,NULL,3,1,3,1,'RA117769719CN ',' GLOT001*2'),(17275,806155215011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','kazikw1','kazimierz@gazeta.pl','Andrzej Gołębiewski','Bzowa 12','Warszawa','mazowieckie','POLAND','02708','609 220474','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 10:29:15',0,NULL,3,1,3,1,'RA117767253CN ','GLSG001 '),(17276,595327496003,130598387084,'2 pairs of New in box SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'cnfaner','muge8','mugette8@gmail.com','Miko Mustonen','Svansrominkuja 7 G 139','Helsinki','Helsinki','FINLAND','00870','0503669395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 10:33:19',0,NULL,3,1,3,1,'RA117769869CN ','OTSO004*2 '),(17277,806157878011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','hudson7272','stevenrkay@googlemail.com','Steven Kay','DAC Beachcroft LLP','6-8 Bouverie Street','London','UNITED KINGDOM','EC4Y 8DD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 10:37:17',0,NULL,3,1,3,1,'RA117769855CN ','GLOT001 '),(17278,752758861007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',1,'RCLO006',46.99,'au-buy','alon24','htpcfreak@gmail.com','Ilan Klein','4 meirovitch','Rishon Letsion','','ISRAEL','75318','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-03 10:41:45',0,NULL,3,1,3,1,'RA117767151CN ','RCLO006 '),(17279,745116535008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',50.26,'au-buy','gabanking','azrizaki@gmail.com','Azri Omar','12, Lakeview Bungalows, Saujana Resort<br>Section U2','Shah Alam','Selangor','MALAYSIA','40150','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-03 11:15:17',0,NULL,3,1,3,1,'RA117767412CN\r ','HSPL015 \r马来西亚\r'),(17280,893393014012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','sachha88','samuelhaefelfinger@gmail.com','Samuel Haefelfinger','Chrischonaweg 52','Riehen','','SWITZERLAND','4125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 11:28:06',0,NULL,3,1,11,1,NULL,'■MOAP001 '),(17281,595360259003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',2,'HSPL018',29.98,'cnfaner','rebecca3398yahoo','rebecca3398@yahoo.com','Rebecca Tang','510 Plaza Dr<br>Ste 2720','College Park','GA','UNITED STATES','30349-6042','(415) 260-6119','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 13:05:06',0,NULL,3,1,1,1,'\\  ',NULL),(17282,600773897004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','roland6543','roland6543@yahoo.ca','Alan van Wyk','4074 Eden Drive','Windsor','ON','CANADA','N9G2E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 13:13:45',0,NULL,3,1,3,1,'RA117768143CN\r ','OTHP004\r '),(17283,752824319007,170728921205,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 EARPHONE UE150 UE',1,'HSUE004',12.49,'au-buy','wogboy125','jarred.salihovic@hotmail.com','Jarred Salihovic','22937 bass highway','Smithton','Tasmania','AUSTRALIA','7330','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 13:36:19',0,NULL,3,1,2,1,'\\ ',NULL),(17284,653613262013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','m_nishimura850','mitsuya@po.synapse.ne.jp','MITSUYA NISHIMURA','ETRANGE 205,1-9-10 TAKESUE<br>YAHATA-NISHI-KU','KITAKYUSYU-SHI','Fukuoka','JAPAN','806-0045','090-2515-0197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 13:51:57',0,NULL,3,1,3,1,'RA117769775CN ',' GLOT001*4'),(17285,600788179004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','kidrossi','rosskid@adelphia.net','Stephen Ross','15 Cooper St<br>C/O Mahoney Alarms','glens falls','NY','UNITED STATES','12801','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 14:02:01',0,NULL,3,1,1,1,'\\  ',NULL),(17286,806234275011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT006*2',52.99,'eastar4uk','logan12781','amandapeteporter.wanadoo@fsmail.net','Peter Logan','68 Quantock Road','Worthing','West Sussex','UNITED KINGDOM','bn132hq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 14:11:16',0,NULL,3,1,3,1,'RA117770005CN ','GLOT006*2 '),(17287,805868764002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','freddy00e','freddy.peru@gmail.com','Jose Rojas','8213 SW 72nd Ave<br>Apt 262','Miami','FL','UNITED STATES','33143-7661','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 14:23:35',0,NULL,3,1,1,1,'\\ ',NULL),(17288,806250923011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','slvrflsh3x88','eckhardt3@frontiernet.net','Dana Eckhardt','302 Gadsontown Ln','Powell','TN','UNITED STATES','37849-7524','(865) 945-2686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 14:29:41',0,NULL,3,1,1,1,'\\  ',NULL),(17289,752851687007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','kyawsannlwin09','kyawsannlwin@gmail.com','Kyaw Lwin','13 Bush Close<br>Beckenham','Perth','Western Australia','AUSTRALIA','6107','61423402716','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 14:39:47',0,NULL,3,1,2,1,'\\ ','澳标 '),(17290,762777970001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','lemorissa','lemor3@gmail.com','limor issa','p.o box 621','gush halav','','ISRAEL','13872','+972528191125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 15:04:41',0,NULL,3,1,11,1,' ','■BR3D006 '),(17291,653653937013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','rads0126','radsuarez@yahoo.com','ROY SUAREZ','4851 LA PRINCESA CT','NORTH LAS VEGAS','NV','UNITED STATES','89031-1087','(702) 878-0774','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 15:44:51',0,NULL,3,1,1,1,'\\  ',NULL),(17292,806297564011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','cktwo2011','kitcheners01@tiscali.co.uk','Jackie kitchener','6 Chapel Street<br>Bildeston','IPSWICH','Suffolk','UNITED KINGDOM','IP7 7EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 16:01:08',0,NULL,3,1,3,1,'RA117767369CN\r ','MOAP001 '),(17293,893581942012,220903895872,'3 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*3',94.99,'eastar4uk','magnetrixxx','magnetrixxx.1981@freenet.de','Alexander Förster','Köschenrütistrasse 26','Zürich','','SWITZERLAND','8052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 17:30:57',0,NULL,3,1,3,1,'RA117767562CN\r ','LGGL002*3 '),(17294,806351967011,320730088105,'New Replaceable Shell for logitech Mouse MX518',1,'SHLO004',9.99,'eastar4uk','vadik019','vadikzebay@gmail.com','Juan Carlos Serra Brazales','Avenida Pais Valenciano nº129 , puerta 5','Torrent','Comunidad Valenciana','SPAIN','46900','697422423','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 17:35:13',0,NULL,3,1,2,1,'\\ ',NULL),(17295,806352552011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.9,'eastar4','yuval59','yuvalz1959@gmail.com','yuval zeitoun','haherut 2 nordia  b.p. 250<br>Netanya - 42954','Netanya','','ISRAEL','42954','00972546231100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 17:38:35',0,NULL,3,1,3,1,'RA117767854CN\r ',' OTGR001+OTGR002+OTGR003'),(17296,653703320013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','coeurdelion317','coeurdelion317@yahoo.com','Richard M Stanton','43 Fieldstone Ridge Dr','Cornish','ME','UNITED STATES','04020-3339','(207) 625-8062','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 17:39:57',0,NULL,3,1,3,1,'RA117769798CN ',' GLOT001*4'),(17297,600878000004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','filipebb','brito.filipe@ig.com.br','Filipe Batista de Brito','Rua Várzea de Santo Antônio, nº149, apartamento 803<br>Bairro: Caminho das Árvores','Salvador','Bahia Nordeste','BRAZIL','41820-180','071-3451-2102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 18:02:28',0,NULL,3,1,3,1,'RA117767908CN\r ',' MOOE001\rOEM的'),(17298,600885009004,140482241347,'New Genuine Motorola RAZR H3 Bluetooth Headset track#',1,'HSMO003',11.99,'cnfaner','vladrkeel','vladkeel@gmail.com','Vlad Keel','Bar-Ilan 13/4','Netanya','','ISRAEL','42258','(972)54-9794239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 18:18:52',0,NULL,3,1,3,1,'RA117767474CN\r ','HSMO003\r欧标 '),(17299,762900745001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','germinda','germin@verizon.net','Milinda','6835 Twilite Dr','Port Richey','FL','UNITED STATES','34668-4652','(727) 849-4960','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 18:46:34',0,NULL,3,1,1,1,'\\  ',NULL),(17300,595496834003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','dchurchill69','dchurchill8@yahoo.com','daniel churchill','po box 87','frazier park','CA','UNITED STATES','93225-0087','(714) 471-2193','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 18:54:39',0,NULL,3,1,1,1,'\\  ',NULL),(17301,893646436012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.99,'eastar4','bulwark1911','paintya@live.com','Jeff Sanders','4885 Lower Miller Creek Rd','Missoula','MT','UNITED STATES','59803-9718','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 19:02:23',0,NULL,3,1,3,1,'RA117768007CN\r ',' MOMI001'),(17302,653751217013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','cny819','myue889@gmail.com','Min Yue','1025 Belvoir Ln','VIrginia Beach','VA','UNITED STATES','23464-6765','(757) 589-9318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 19:21:07',0,NULL,3,1,1,1,'\\  ',NULL),(17303,806428370011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','tomb138','t_bluck_03@hotmail.com','Thomas Bluck','26 Mayfield Avenue, Newby','Scarborough','North Yorkshire','UNITED KINGDOM','YO12 6DF','07515830083','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 19:35:22',0,NULL,3,1,3,1,'RA117767925CN\r ','WLAT008 '),(17304,806457209011,320774352320,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT003',10.99,'eastar4uk','johey81','ebay.js@crypt.se','Johan Svensson','Imatragatan 210','Kista','','SWEDEN','16478','+46705955621','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 20:16:35',0,NULL,3,1,11,1,NULL,'■WLAT003 '),(17305,595542510003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','ratjenl','ronald@ronaldanita.nl','Ronald Koopmans','Asterstraat 23','Hoogeveen','','NETHERLANDS','7906JD','0654975475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 20:36:56',0,NULL,3,1,3,1,'RA117767488CN\r ','HSPL005 \r欧标 '),(17306,806508188011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','shefimodh','ledion.qirici@gmail.com','Ledion Qirici','Idriz Dollaku Pll.23 Shk.3 Ap.43','Tirane','Albania','ALBANIA','1004','00355692244602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 21:40:39',0,NULL,3,1,11,1,NULL,'■OTCN002 '),(17307,600983270004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','euneuneu','francois.nokia@gmail.com','Francois BARROERO','221 Avenue des AIRES','Gardanne','Provence-Alpes-Côte d\'Azur','FRANCE','13120','0664838545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 22:08:38',0,NULL,3,1,3,1,'RA117768130CN\r ','OTHP004'),(17308,600984174004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.95,'cnfaner','juan59*p','drxxpy5_9@yahoo.com','juan guzman','4709 Leatherleaf Trl','austin','TX','UNITED STATES','78744-4424','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 22:11:57',0,NULL,3,1,1,1,'、 ','HSPL001 '),(17309,653829368013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','acarv4414','tash34c@aol.com','Carmen Carvajal','300 NW 62ND Ct','Miami','FL','UNITED STATES','33126','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 22:18:56',0,NULL,3,1,3,1,' RA117769890CN',' GLOT001*4'),(17310,806530054011,320602990320,'NEW GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'eastar4','katenoklucky2','katenoklucky@gmail.com','Екатерина Данилова','Генерала Городнянского 1-28','Смоленск','Смоленская область','RUSSIAN FEDERATION','214032','(903) 649 - 0515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 22:21:44',0,NULL,3,1,11,1,NULL,' ■HSNO008欧标'),(17311,806533680011,320707682465,'NEW GENUINE NOKIA BH-100 BLUETOOTH HEADSET BH 100',1,'HSNO030',11.99,'eastar4','evoasman','xpnette@hotmail.com','Kenan Asman','Yeni turan mahallesi gül sokak no 10','Nusaybin','Nusaybin','TURKEY','47300',' 905445194749','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 22:30:38',0,NULL,3,1,11,1,'\\ ','■HSNO030欧标'),(17312,893309421012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','paradiseducky','sherrimarten@mail.com','Sherri Marten','5921 Camino Ln<br>Apt 7','Paradise','CA','UNITED STATES','95969-4742','(530) 872-1640','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 22:34:47',0,NULL,3,1,3,1,'RA117766045CN ',' UMTR001'),(17313,653839495013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',4,'CASS003',33.96,'eastar4','lporter200','lee.kendrick.uk@googlemail.com','Lee Kendrick','3 Upper Weald<br>Calverton','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK196EL','01908262690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 22:46:22',0,NULL,3,1,3,1,'RA117767491CN\r ',' CASS003'),(17314,893798199012,220905585248,'New GENUINE PLANTRONICS Calisto pro Bluetooth Headset only',1,'HSPL014',33.59,'eastar4uk','metatorbernite','simon.brock@debrecq.com','Simon Brock','18 Old Brewery lane','henley on Thames','OXON','UNITED KINGDOM','RG9 2DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 22:57:19',0,NULL,3,1,3,1,'RA117767103CN ','HSPL014 \r英标'),(17315,601001334004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.95,'cnfaner','avimazor13','avi-mazor@bezeqint.net','jacob or-bach','2140 Vista Circle<br>Apt 301','Virginia Beach','VA','UNITED STATES','23451','757 739 3328','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 23:02:07',0,NULL,3,1,3,1,'RA117767409CN\r ','HSPL001\r修改地址\ravi mazor\r94 bograshov st.\rtel aviv 63297\risrael\r\r '),(17316,806558694011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','pattrefle','patcarrier@hotmail.ca','Patrick Carrier','11796 Pigeon','Montreal','QC','CANADA','H1G 5W4','(438) 878-2662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 23:24:58',0,NULL,3,1,3,1,'RA117767179CN ',' GLSG001'),(17317,653861520013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','raynj','raynj07728@yahoo.com','Ray Dunsavage','2 Morgan Ct','Freehold','NJ','UNITED STATES','07728','(732) 780-7078','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 23:53:37',0,NULL,3,1,1,1,'\\  ',' '),(17318,595618931003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','251shay','skt@017.net.il','shay  tamam','tel nof','gedera','israel','ISRAEL','70710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 00:29:02',0,NULL,3,1,3,1,'RA117767457CN\r ','BALO007 '),(17319,893842261012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','fabien1482','fraissinetfabien@hotmail.com','Fraissinet Fabien','10 boulevard Robert Schuman<br>Appartement 24B','Arras','Nord-Pas-de-Calais','FRANCE','62000','0689305974','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 00:37:30',0,NULL,3,1,3,1,'RA117766085CN ','GLOT005 '),(17320,653876945013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','ehel3235','gary.helmick@cummins.com','Eleanor Helmick','4326 Hallfield Manor Dr','Nottingham','MD','UNITED STATES','21236','(443) 615-1357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 00:48:56',0,NULL,3,1,3,1,'RA117769886CN ',' GLOT001*4'),(17321,893887518012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','wcoon83','wgreycoon@gmail.com','William G. Coon','25 Woodlake Rd<br>Apt 8','Albany','NY','UNITED STATES','12203-3981','(401) 952-3991','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 02:38:47',0,NULL,3,1,1,1,'\\  ',NULL),(17322,806245087002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','clt1970','jessetruong@hotmail.com','Cuong Truong','10972 Las Flores Dr','El Monte','CA','UNITED STATES','91731-2602','(626) 297-8736','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 03:02:24',0,NULL,3,1,1,1,'\\  ',NULL),(17323,893900794012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','tomax7','tomax77@shaw.ca','Tom McLaughlin','223 Scenic Way NW','Calgary','AB','CANADA','T3L 1B6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 03:16:27',0,NULL,3,1,2,1,'\\ ',NULL),(17324,601084137004,140608710886,'New Plantronics Explorer 220 BLUETOOTH HEADSET track#',1,'HSPL001',12.95,'cnfaner','iqaruz','carlosdelcampo@hughes.net','REYES G TAPIA CONS','6710 E Golf Links Rd<br>Apt 1045','TUCSON','AZ','UNITED STATES','85730-1023','(520) 591-2483','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 05:11:14',0,NULL,3,1,1,1,'、',NULL),(17325,595682726003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','cyurnace','woodsyman2@hotmail.com','Carl Yost','21719 Calhoun Rd','Monroe','WA','UNITED STATES','98272','(425) 870-4988','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 05:39:55',0,NULL,3,1,1,1,'\\  ',NULL),(17326,893950596012,220756351504,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.99,'eastar4','max-goldencat','maxgoldencat@gmail.com','Tzu-Hsi Lin','550 Meadow Ridge Dr.','Tallahassee','FL','UNITED STATES','32312','(850) 893-3487','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 06:12:42',0,NULL,3,1,3,1,'RA117767341CN\r ',' MOMI001'),(17327,893955302012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.9,'eastar4uk','amethyst23lynn','carricknlou@hotmail.co.uk','lynn mawer','56 wycliffe<br>burton constable holiday park','hull  / skirlaugh','East Riding of Yorkshire','UNITED KINGDOM','hu114ln','07532281534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 06:33:45',0,NULL,3,1,3,1,'RA117767430CN\r ','HSMO018\r英标 '),(17328,8881322982491083,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4uk','paul12347','paul.ayling@sky.com','PAUL AYLING','THE LODGE<br>23 ORSETT AVENUE','LEIGH ON SEA','ESSEX','UNITED KINGDOM','ss9 4tt','',NULL,NULL,NULL,'2011-12-04 07:08:11',0,NULL,3,1,3,1,'RA184539449CN\r ','MOAP001 \r'),(19503,664907727013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','lenkosnowman','cr.glenn@verizon.net','Christopher Glenn','16 Sargent St','Queensbury','NY','UNITED STATES','12804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 03:26:58',0,NULL,3,1,1,1,'LK171590325CN\r ',''),(17329,8881322986166240,111,'NEW Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',0,'eastar4uk','telfol','terence.foley3@ntlworld.com','terry foley','14 essex road','london','London','UNITED KINGDOM','E106HP','',NULL,NULL,NULL,'2011-12-04 08:09:26',0,NULL,3,1,3,1,'RA117767182CN ','UM00004 '),(17330,653972284013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',5,'WLIN014',94.95,'eastar4','klmvalex','klmvlksndr@rambler.ru','Aleksandr Klimov','ul. Shkuljova, d.3, kv.26','Moskva','','RUSSIAN FEDERATION','109390','+79264906800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:32:25',0,NULL,3,1,3,1,'RA117767315CN\r ',' WLIN014'),(17331,653972250013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','jeannetteholden','alyshapaigeholden@hotmail.com','Jeannette Holden','PO Box 590','Buddina','Queensland','AUSTRALIA','4575','0466395924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:32:43',0,NULL,3,1,3,1,'RA117769909CN ',' GLOT001*3'),(17332,653972305013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','macky147','mackyhoo@yahoo.com','Pornsak Skulratanasak','105/1-3 Nares Rd Bangrak','Bangkok','','THAILAND','10500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:34:51',0,NULL,3,1,3,1,'RA117767307CN\r ',' BAZA001'),(17333,753300668007,170728920986,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'au-buy','vassallo11','tyler08@hotmail.com.au','jason grey','4/36 josephine','oak park','Victoria','AUSTRALIA','3046','0390787414','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-04 08:54:06',0,NULL,3,1,3,1,'RA117767465CN\r ','HSPL013\r澳标\r '),(17334,893994972012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','*01soul*','onesoul@dodo.com.au','Shandelle Nolan','PO BOX 926','Wonthaggi','Victoria','AUSTRALIA','3995','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:56:24',0,NULL,3,1,11,1,NULL,' UM00006■'),(17335,893493620012,220501830806,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',15.39,'eastar4','pedrobiscoitobr','pedrogabini@gmail.com','Pedro Gabini','Condomínio Jardim Botânico V<br>Conjunto D, Casa 10','Brasilia','Distrito Federal','BRAZIL','71680-368','61 - 8168-9925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 09:07:31',0,NULL,3,1,3,1,'RA117767576CN\r ','BTAC2114 \racer 5pin1.25 15cm \r'),(17336,753318547007,170739882957,'New GENUINE PLANTRONICS Calisto pro Bluetooth Headset only',1,'HSPL014',53.99,'au-buy','jonbibelots','jwphurford@gmail.com','Jon Hurford','1/15-25 Bastings Street<br>Northcote','Melbourne','Victoria','AUSTRALIA','3070','0401651958','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-04 09:38:47',0,NULL,3,1,3,1,'RA117767085CN ',' HSPL014\r澳标'),(17337,753357192007,170739867756,'ew Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'au-buy','47ruk','m_j_m_86@hotmail.com','Mark McIntosh','484 Beenleigh Road<br>Sunnybank','SUNNYBANK','Queensland','AUSTRALIA','4109','0431060265','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-04 11:09:51',0,NULL,3,1,2,1,'、 ',NULL),(17338,894083997012,220816384245,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',78.99,'eastar4uk','shanethan7','neilshahla@yahoo.co.uk','Shahla Sheasby','28 Walcot green <br>Dorridge','Solihull','West Midlands','UNITED KINGDOM','B93 8BU','01564772433','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 11:54:16',0,NULL,5,0,18,0,NULL,'型号不兼容，已取消'),(17339,595780096003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','bletwin','bletwin@comcast.net','Bruce Letwin','52 Laconia Cirlce','North Andover','MA','UNITED STATES','01845','(978) 681-7684','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 12:07:13',0,NULL,3,1,1,1,'\\  ',NULL),(17340,601187013004,140644120563,'New Genuine Motorola H721 Bluetooth Wireless Headset+AC adapter',2,'HSMO022',45.1,'cnfaner','siwiz','simon.wisdom5615@o2.co.uk','Simon Wisdom','21 Barrack Road','Bexhill on Sea','East Sussex','UNITED KINGDOM','TN402AT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 12:15:41',0,NULL,3,1,3,1,'RA117767029CN ','HSMO022\r英标 '),(17341,745743127008,180762085514,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.99,'au-buy','djfabiobrazil17','gafae@terra.com.br','fabio r. de souza','av gessy lever 915 casa 280<br>lenheiro','valinhos','sp','BRAZIL','13272-000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 12:50:53',0,NULL,3,1,11,1,NULL,'GPS0010 \r■'),(17342,894128123012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',63.99,'eastar4uk','shdjeka','dan2009@vfemail.net','Dan Eigeles','34 Picasso St.','Kiryat Ata','','ISRAEL','28260','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 13:05:08',0,NULL,3,1,3,1,'RA117767973CN\r ','LGGL002*2 '),(17343,654084968013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','heidiiver31','heidiemiversen@gmail.com','heidi iversen','høyersgate 7','larvik','vestfold','NORWAY','3257','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 13:44:15',0,NULL,3,1,3,1,'RA117769815CN ',' GLOT001*3'),(17344,894161223012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','tention66626','wesley_smith_1993@hotmail.co.uk','wesley smith','107 woodward Road','Dagenham','Essex','UNITED KINGDOM','RM9 4ST','02085170566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 13:53:57',0,NULL,3,1,3,1,'RA117767219CN\r ',' HSJA001  英标'),(17345,595833702003,130592182172,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',17.4,'cnfaner','e_mel','mel.scott@comcast.net','Mel Scott','1778 Raeboro Dr SE','Kentwood','MI','UNITED STATES','49508-6704','(616) 805-8964','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 14:16:11',0,NULL,3,1,1,1,'\\  ',NULL),(17346,894173821012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','samarasity63','k2mail@mail.ru','Artem Mitkov','41 Yubileinaya Str. ,Apt.182','Togliatti','Samarskaya region','RUSSIAN FEDERATION','445027','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 14:17:02',0,NULL,3,1,3,1,'RA117767063CN ','SAFI001 '),(17347,894178792012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','tockquan','maryken@fastmail.com.au','Ms Mary Kenneally','P O Box 311','Clifton Hill','Victoria','AUSTRALIA','3068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 14:19:55',0,NULL,3,1,11,1,NULL,' UM00008\r■'),(17348,601252327004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','gklka','gk@czo.hu','Gruber Kristóf','Baross G. u. 79/A','Győr','Győr-Moson-Sopron megye','HUNGARY','9024','+36 30 55 32 334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 14:48:57',0,NULL,3,1,3,1,'RA117767899CN\r ','CACN004'),(17349,806927289011,320735060241,'New HP Media Center IR receiv+ microsoft remote Control',1,'OTHP006',11.49,'eastar4uk','russt93','ebay@russellsmail.co.uk','Coordinate IT, Russell Daniels','16 Regent House<br>Beam Heath Way','Nantwich','Cheshire','UNITED KINGDOM','cw56pq','01270898488','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 15:01:06',0,NULL,3,1,3,1,'RA117768157CN\r ','OTHP006 '),(17350,806933340011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.98,'eastar4','luisdequadros','luisperquabr@gmail.com','luis de quadros','Av. Frey Serafim<br>3125 Centro','Teresina','Piaui','BRAZIL','64000-050','+558688550754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 15:10:00',0,NULL,3,1,11,1,NULL,' BTHP3001\r■'),(17351,894221301012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','afgan82','a.afgan@yahoo.com','Afgan Aliyev','Sabit Orucov 2, apartment 99.','Baku','Xatai','AZERBAIJAN','AZ1025','00994503811513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 15:15:49',0,NULL,3,1,11,1,' ','MOAP001■ '),(17352,806942098011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','kleah84','k.leah84@yahoo.com','Kheri Roy','16914 kilwinning dr','Houston','TX','UNITED STATES','77084-1842','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 15:21:18',0,NULL,3,1,1,1,'\\  ',NULL),(17353,894232296012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','immortal_uk','lee_jackson@blueyonder.co.uk','Lee Jackson','102 Taylor Road<br>Haydock','St Helens','Merseyside','UNITED KINGDOM','WA119yg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 15:29:12',0,NULL,3,1,3,1,'RA117767443CN\r ','SCLO002 '),(17354,806949697011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','androgengill','andygill@singnet.com.sg','Andrew Gill','16 Amber Gardens<br>#04-03 Amber Park','Singapore','Singapore','SINGAPORE','439961','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 15:32:16',0,NULL,3,1,3,1,' RA117769824CN','GLOT001*3 \r兼容眼镜通用型'),(17355,753532415007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',1,'RCLO006',46.99,'au-buy','roland8637','rolmac@rogers.com','Roland McAllister','85 Bleecker St, Apt 637','Toronto','ON','CANADA','M4X 1X1','(416) 921-7996','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 15:55:59',0,NULL,3,1,3,1,'RA117769943CN ','RCLO006 '),(17356,806971088011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',96.99,'eastar4uk','t2bull','v2bull@googlemail.com','Adrian Bull','22 Laurel Way','Totteridge','London','UNITED KINGDOM','N20 8HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 15:59:04',0,NULL,3,1,3,1,'RA117767196CN ','GLOT005*3 '),(17357,753576130007,170728920807,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',12.99,'au-buy','faridmorgan','farid.bouchaour@sfr.fr','farid bouchaour','14 route de ronsuaz<br>14 route de ronsuaz','margencel','Rhône-Alpes','FRANCE','74200','0457436010','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 16:48:07',0,NULL,3,1,2,1,'、 ','欧标 '),(17358,601354181004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','getman1973','getvv@mail.ru','Victor Getmanenko','Sergej Lazo, 25, 335','Tomsk','','RUSSIAN FEDERATION','634063','903-954-3297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 17:44:02',0,NULL,3,1,3,1,'RA117767845CN\r ','OTGR001+OTGR002 '),(17359,894396161012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','zmail004','zmail04@gmail.com','Zohar Nachshon','56th Harofe st. (app. 28)<br>Ahuza','Haifa','Israel','ISRAEL','34367','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 18:08:59',0,NULL,3,1,11,1,'\\ ','OTGR001 \r■'),(17360,807113692011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','ibeasang','ibeasa@msn.com','Angel Ibeas Portilla','Antonio Lopez 60 - 2ºIzda','Santander','Cantabria','SPAIN','39009','618286284','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 18:19:52',0,NULL,3,1,3,1,'RA117767960CN\r ','OTSO002 '),(17361,894411493012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',13.9,'eastar4uk','billy250964','wgaughan@aol.com','william gaughan','21 wensleydale drive<br>astwood farm','worcester','worcestershire','UNITED KINGDOM','wr3 8qw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 18:20:54',0,NULL,3,1,3,1,'RA117767885CN\r ','HSSE005 \r英标'),(17362,595993416003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',3.99,'cnfaner','kc7swh','hottorch451@gmail.com','Michael Bignell','163 N 100 W','Brigham City','UT','UNITED STATES','84302-2105','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 18:30:06',0,NULL,3,1,1,1,'\\  ',NULL),(17363,807112045011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT006*2',88.99,'eastar4','tinabouanba','bouanba1@hotmail.com','Tina bouanba','28 schnieder road','barrow in furness','Cumbria','UNITED KINGDOM','la14 5dw','01229825441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 18:18:40',0,NULL,3,1,3,1,'RA117766071CN ',' GLOT006*2'),(17364,807184745011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','bgib2610','briangibbs@gmail.com','Brian Gibbs','2565 Noble Canyon Rd','Chula Vista','CA','UNITED STATES','91915-1522','(619) 393-1915','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 19:11:10',0,NULL,3,1,1,1,'\\  ',NULL),(17365,753744237007,170735485494,'New lady Painting anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'au-buy','kanyanka','d-ranachowski@wp.pl','Karolina Pobłocka','Rzeczypospolitej 1B / 102','Gdańsk','pomorskie','POLAND','80-369','50 1339769','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 19:15:25',0,NULL,3,1,11,1,NULL,'UM00014 \r■\r'),(17366,807203188011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.4,'eastar4','tomitl','tomi.lamsa@pp.inet.fi','Tomi  Lämsä','Oravantie 1 as 2','Kuusamo','Oulunlääni','FINLAND','93600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 19:24:27',0,NULL,3,1,11,1,'\\ ','■OTHP006 '),(17367,894519413012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','omani_magic','moosa.subhi@gmail.com','mustafa al-subhi','P.O.BOX: 307<br>aldukhlia','nizwa','nizwa / dohat / aldukhlia','OMAN','611','0096892616868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 19:31:19',0,NULL,3,1,3,1,'RA117769767CN ',' GLOT001*2'),(17368,807213873011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','zagi2323','tzagata@gmail.com','Tomáš Zagata','Osloboditelov 77','Čaňa','Košice','SLOVAK REPUBLIC','04414','+421903656862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 19:32:43',0,NULL,3,1,3,1,'RA117767514CN\r ',' HBPH002'),(17369,654337131013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','casseylou','casseylou@yahoo.com','cassey hanks','4747 W Waters Ave<br>apt 4016','tampa','FL','UNITED STATES','33614-1443','(813) 215-7501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 19:42:08',0,NULL,3,1,1,1,'\\  ',NULL),(17370,654347828013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','angelajackson55','angelajackson5@msn.com','Angela Jackson','20409 Renton Maple Valley RD SE','Maple Valley','WA','UNITED STATES','98038-8981','(425) 457-4551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 19:54:10',0,NULL,3,1,3,1,'RA117767050CN ',' UM00033'),(17371,894550949012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','regulatorivan','regulator@net.hr','Ivan Regvat','Jurisiceva 24','Cerna','','CROATIA','32272','385-32-843185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 19:54:21',0,NULL,3,1,11,1,NULL,'■OTCN004*10 '),(17372,807242518011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','pr4cad','p.arthur@cadraw.co.uk','Paul Arthur','11 Wirral Gardens<br>Bebington','Wirral','Merseyside','UNITED KINGDOM','CH63 3BD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 19:56:03',0,NULL,3,1,3,1,'RA117767911CN\r ','RELO003 '),(17373,894570439012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','interalios','kmacadangdang@ufl.edu','Kristina Macadangdang','4000 SW 37th Blvd<br>Apt 537A','Gainesville','FL','UNITED STATES','32608-7533','(904) 707-1948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 20:09:51',0,NULL,3,1,3,1,'RA117766023CN ',' UM00008  新地址：Kristina Macadangdang\r365 NW 39th Road\rGainesville, FL 32607\rUNITED STATES\r'),(17374,807281267011,320730087674,'New Logitech Digital IO Writing Pen +IO notebook',1,'NTLO001+NTLO002',30.99,'eastar4uk','ccor6513','nancy2corrigan@hotmail.co.uk','Ciara Corrigan','247 Castlemilk Drive<br>Castlemilk','Glasgow','Glasgow (City of)','UNITED KINGDOM','g45 9uz','01415895014','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:25:27',0,NULL,3,1,3,1,'RA117767236CN ','NTLO001+NTLO002 '),(17375,654372913013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','financialgoals4u','goalsunlimited2005@yahoo.com','Tonya Montgomery','2552 MS Highway 50 E','Maben','MS','UNITED STATES','39750-6823','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 20:29:56',0,NULL,3,1,1,1,'\\  ',NULL),(17376,805893971011,320730088401,'NEW sealed Logitech Wireless Laser Mouse M505 +unifying',1,'MOLO008',21.99,'eastar4uk','a.j.patten','a.j.patten@btinternet.com','ANDY PATTEN','97 HUNTS DRIVE<br>WRITTLE','CHELMSFORD','Essex','UNITED KINGDOM','CM1 3HQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:14',0,NULL,3,1,3,1,'RA117767505CN\r\r ','MOLO008 '),(17377,807309380011,320801187144,'New Genuine Motorola H715 Bluetooth Wireless Headset   H 715+AC adaptor',2,'HSMO023',27.98,'eastar4uk','caltec69','caltec69@hotmail.co.uk','callum lamb','167 pentland park','loanhead','Midlothian','UNITED KINGDOM','eh209pd','07897622233','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:54:29',0,NULL,3,1,3,1,'RA117767148CN ','HSMO023\r英标 '),(17378,601520985004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','maninder_mahi','maninder_mahi6452000@yahoo.com','maninder mahi','12183  77a ave','surrey','BC','CANADA','v3w 1j7','(604) 727-4232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 21:07:46',0,NULL,3,1,3,1,'RA117767531CN\r ','HSPL013 '),(17379,654415839013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','sok5sok5','sok5sok5@yahoo.com','Sokun Seng','2991 Rochester Cir','Corona','CA','UNITED STATES','92879','(951) 735-2163','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 21:19:31',0,NULL,3,1,1,1,'\\  ',NULL),(17380,596140660003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','beeeby16','beeeby@ntlworld.com','Brenda Timmons','16 Gunnersbury Lane','Acton','London','UNITED KINGDOM','W38EE','07971609849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 21:23:42',0,NULL,3,1,3,1,'RA117767372CN\r ','MOLO006 '),(17381,807359604011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','corsair-bleu','rouzee.bruno@wanadoo.fr','BRUNO ROUZEE','23. RUE LOUIS MARIN PICHOU','LOUVIERS','Haute-Normandie','FRANCE','27400','0232252884','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 21:50:28',0,NULL,3,1,3,1,'RA117769838CN ','GLOT001 '),(17382,807373087011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','evrghd','evrinternet@ig.com.br','Edgard Vieira Ribeiro','Dr. Silvio Portugal, 16','Sao Paulo','Sao Paulo','BRAZIL','01247060','55-11-38654395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 22:10:01',0,NULL,3,1,3,1,'RA117767528CN\r ',' HBPH002'),(17383,601566340004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','jds-dent','jdshephard@students.latrobe.edu.au','Jacob Shephard','360 Cowanna Avenue','Merbein South','Victoria','AUSTRALIA','3505','0350256251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 22:21:46',0,NULL,5,1,18,1,NULL,'RELO003 \r客户不要了 '),(17384,894713340012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','melisalang','mlang@qualcomm.com','Melisa Lang','453 N Hunter St','Ramona','CA','UNITED STATES','92065-1766','(619) 990-2605','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(17385,753937276007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','bcof3831','bcoffee@sbcglobal.net','Brett Coffee','741 Winding Ridge Ln','Rockwall','TX','UNITED STATES','75032-7427','(972) 333-7812','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 22:37:45',0,NULL,3,1,1,1,'\\ ',NULL),(17386,894714165012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','pinto_61','paintedman1@optusnet.com.au','Daryn Brown','66 Long Street','Cleveland','Queensland','AUSTRALIA','4163','0731343188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 22:34:34',0,NULL,3,1,2,1,'、 ',' 澳标'),(17387,654468937013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','aolu1990','pengfeilian@hotmail.com','pengfei lian','7241 trivento pl','rancho cucamonga','CA','UNITED STATES','91701-8703','(626) 757-1449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 22:59:59',0,NULL,3,1,1,1,'\\  ',' '),(17388,596199702003,130596106005,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',77.99,'cnfaner','vj11434','nessa11434@yahoo.com','Vanessa Jennings','307 Prospect Ave<br>Apt 18H','Hackensack','NJ','UNITED STATES','07601-2554','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-04 23:29:21',0,NULL,3,1,1,1,'\\  ','HBPH002+HBPH003 '),(17389,654481578013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','sheena_1975','sheenarumbolt@hotmail.com','Sheena  Rumbolt','23 Hillview Road','Mary\'s Harbour, NL','NL','CANADA','A0K 3P0','(709) 921-6433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 23:33:55',0,NULL,3,1,3,1,'RA117767222CN\r ',' GPS0004'),(17390,596202109003,130592182172,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',17.4,'cnfaner','val.vz28','valz28@teksavvy.com','valdemar veiga','838 westbury crt','sarnia','ON','CANADA','N7T7R5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 23:38:11',0,NULL,3,1,3,1,'RA117767545CN\r ','OTHP003 '),(17391,753970437007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','asabid786','asabid786@hotmail.com','ali abid','43 shediac Rd.','Sc','ON','CANADA','m1k4z8','(416) 752-1784','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 23:39:33',0,NULL,3,1,2,1,'\\ ',NULL),(17392,596210272003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','jsteacy2005','jasonsteacy1@hotmail.com','Jason Steacy','2609 Sixth Line','Smiths Falls','ON','CANADA','K7A 4S7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 00:01:16',0,NULL,3,1,3,1,'RA117767426CN\r ','LGRM001 '),(17393,888262678012,220816317839,'New lady paris tower dot w/trim Sun Rain Stick Umbrella',1,'UM00028',21.84,'eastar4','kym39','mykeydee1957@yahoo.com.au','Kym Wallace','Unit 2<br>576 Norman Road','North Rockhampton','Queensland','AUSTRALIA','4701','0749140741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 00:04:22',0,NULL,3,1,11,1,NULL,' UM00028  ■'),(17394,751040232007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','gaara4000','cro0005@hotmail.com','Matthew Cross','24 Furlong rd','Melbourne','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-05 00:05:13',0,NULL,3,1,3,1,'RA117767046CN ','LGFI001 '),(17395,654490952013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','edithcvega','edith.vega@richmond.edu','Edith Vega','200 Water St<br>Apt 705','new york','NY','UNITED STATES','10038-3617','(978) 578-7268','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 00:11:59',0,NULL,3,1,3,1,'RA117769736CN ',' GLOT001*4'),(17396,596218379003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',25.9,'cnfaner','scuttle1014','robertfreer@msn.com','robert freer','15552 Three Otters Pl','manassas','VA','UNITED STATES','20112','(703) 662-1142','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-05 00:28:27',0,NULL,3,1,1,1,'\\  ','一共买了两个 \r一个银色的一共balck  ver1 '),(17397,807452956011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','Agustin Manuel Almagro Rojas','C/DE ARAGONITO 7A','MÁLAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 00:37:46',0,NULL,3,1,3,1,'RA117769991CN ','GLOT001*4 '),(17398,805675258011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','kevcook','kev747@aol.com','KEVIN MAROVICH','2420 NE 34th Ct','LIGHTHOUSE POINT','FL','UNITED STATES','33064','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 00:53:33',0,NULL,3,1,1,1,'\\',NULL),(17399,894792897012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','deyp060679','dedieko@gmail.com','Tri Kuntari','PT SURYAGITA NUSARAYA (SN CARGO)<br>Airport Square Kavling No.4 , Jl. Laksda Adicusipto KM. 10','Yogyakarta','Daerah Istimewa Yogyakarta','INDONESIA','55281','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,' RA117767580CN\r',' OTCN005*10  再发New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card  WLIN015\r'),(17400,807467672011,320730085638,'New Atheros AR5008 802.11N Wireless CARD+ANTENNA*3',1,'WLAT001+ANTY002',9.99,'eastar4uk','bonneauj123','bonneau.julien@wanadoo.fr','bonneau julien','13 av.voltaire','luneville','Lorraine','FRANCE','54300','0660910719','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 01:22:48',0,NULL,3,1,2,1,'\\ ',NULL),(17401,807049746002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','framyte','shcarpet@goldenwest.net','Ruth Flyte','105 S 6th St','Hot Springs','SD','UNITED STATES','57747-1613','(605) 890-9552','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 02:01:30',0,NULL,3,1,1,1,'\\  ',NULL),(17402,654545046013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','corral1970','thecorrals@sbcglobal.net','Amy Corral','4932 Caroline Way','San Jose','CA','UNITED STATES','95124-5261','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 02:31:39',0,NULL,3,1,3,1,'RA117769912CN ',' GLOT001*4'),(17403,596277111003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','1500htd1500','hdomingu9@aol.com','1500hugo dominguez','11036 northampton st','el paso','TX','UNITED STATES','79934-3018','(915) 630-9038','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-05 03:44:20',0,NULL,3,1,1,1,'\\  ',NULL),(17404,8881323057420134,111,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',0,'eastar4','2010andreapanescu','andreapanescu@yahoo.com','andrea maria ursu','C.A.Vlaicu,Bl.A8,et 3 ap 27','ARAD','OH','ROMANIA','31031','0729938711',NULL,NULL,NULL,'2011-12-05 03:57:00',0,NULL,3,1,3,1,'RA117766010CN ',' UM00008'),(17405,8881323057852826,111,'used Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO031',0,'eastar4','johncato','jc.k@online.no','John-Cato Kvanli','Båsmosjyen 21','8616','','NORWAY','Mo i Rana','',NULL,NULL,NULL,'2011-12-05 04:04:12',0,NULL,3,1,3,1,'RA117767125CN ','旧的 补发 HSNO031  欧标'),(17406,894888002012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','yasu61','yyyasu61@yahoo.com.au','yasuo ichikawa','1/15 katharina st','noosa heads','Queensland','AUSTRALIA','4567','0754749807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 04:16:17',0,NULL,3,1,11,1,' ',' ■UM00008 '),(17412,894924445012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','lips0628','templesgold@gmail.com','Lisa Pham','4725 Fielder St','Midland','TX','UNITED STATES','79707-2817','(281) 650-3115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 06:28:12',0,NULL,3,1,3,1,'RA117767995CN\r ',' UM00008'),(17407,894899533012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','lalacomp','papoula@gmail.com','Marcelo Lima','Rua Peixoto Gomide, 502, ap. 61-B<br>Cerqueira Cesar','Sao Paulo','Sao Paulo','BRAZIL','01409-000','1133686312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 04:51:27',0,NULL,3,1,11,1,NULL,'  ■WLHP002'),(17408,596292726003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',2,'HSMO011',31.98,'cnfaner','rols56','rolandelevy@gmail.com','Rolande LEVY','5744 LOCKWOOD','CÔTE-ST-LUC','QC','CANADA','H4W1Y9','(514) 483-4774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 04:56:57',0,NULL,3,1,3,1,'RA117767284CN\r ','HSMO011 '),(17409,894908753012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.39,'eastar4','nashville_mac','jim.mckanna@vanderbilt.edu','James McKanna','4509 Shys Hill Rd','Nashville','TN','UNITED STATES','37215-3915','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\  ','再发一个 一共两个'),(17410,654597131013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','boat1977dean','deanc1957@hotmail.com','Dean Crozier','544 S 7th St','Montesano','WA','UNITED STATES','98563-4214','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 05:57:29',0,NULL,3,1,3,1,'RA117767797CN\r ',' GLOT001*4'),(17411,894918880012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','iemills','ianmills@shaw.ca','Ian Mills','408 - 1021 Harwood st.','Vancouver','BC','CANADA','v6e3n3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 06:05:41',0,NULL,3,1,3,1,'RA117767117CN ',' GLOT001'),(17413,807155322002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','ziggyshopper','ziggysmitty22@yahoo.com','Tammy Smith','6324 B St','Springfield','OR','UNITED STATES','97478-7050','(541) 746-4358','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 06:28:47',0,NULL,3,1,1,1,'\\  ',NULL),(17414,596305433003,130603400151,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver2',1,'SHLO010',12.95,'cnfaner','fabseals','fabrice.mathieu5@free.fr','Fabrice MATHIEU','3 RUE DU MERINOS','SAINT MARTIN DE CRAU','Provence-Alpes-Côte d\'Azur','FRANCE','13310','0630205133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 06:11:59',0,NULL,3,1,3,1,'RA117767593CN\r','SHLO010\rblack ver2 '),(17415,596310323003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','smw6230','hobbshomepage@fastmail.fm','Steve Weise','13960 Whispering Meadows Lane','Jamul','CA','UNITED STATES','91935','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-05 06:33:53',0,NULL,3,1,1,1,'\\  ',NULL),(17416,8881323067924282,111,'New lady fashion Leopard lines w/lace Bowtie stick Umbrella',1,'UM00024',0,'eastar4uk','teabag090502','tommy090502@hotmail.com','tom houghton','59 hart street','cleethorpes','Lincolnshire','UNITED KINGDOM','dn357rq','01472234826',NULL,NULL,NULL,'2011-12-05 06:52:04',0,NULL,3,1,3,1,'RA117767806CN ','UM00024\r补发 可以发货\rgrey '),(17417,654610439013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ztreuma','myashin@mail.ru','Michail Yashin','Znamenskaya st. 38-1-14','Moscow','Moscow','RUSSIAN FEDERATION','107392','+79169274419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 07:13:47',0,NULL,3,1,11,1,' ','  ■CACN004 '),(17418,807594664011,320402069233,'HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR 2.0+cable',1,'BTHP2007',9.88,'eastar4','carlos_lourido','carlosj105@hotmail.com','Carlos Lourido','12/52-56<br>Gray St.','Kogarah','New South Wales','AUSTRALIA','2217','0295873972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 07:21:53',0,NULL,3,1,2,1,'、 ',' '),(17419,807598157011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','willnice101','williamnice@hotmail.com','Glenn Hull','6551 W 116th Ave','Westminster','CO','UNITED STATES','80020-3059','(808) 214-8090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 07:36:56',0,NULL,3,1,1,1,'\\  ',NULL),(17420,601722982004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',1,'HSJA004',18.98,'cnfaner','mariak6840','varenika@volny.cz','Maria Koretskaya','Otvovice 254','Otvovice','Czech Republic','CZECH REPUBLIC','27327','+420-732-667-687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 08:19:19',0,NULL,3,1,3,1,'RA117764861CN\r ','HSJA004\r欧标\r黑色'),(17421,894957036012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','MUHLENBERG COLLEGE','2400 Chew St<br>ATTN: ALAN MCPEAK IT DEPT.','ALLENTOWN','PA','UNITED STATES','18104-5564','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 08:36:53',0,NULL,3,1,1,1,'\\  ',''),(17422,654631200013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','carrymaster','carrymaster@impacta.co.uk','WARREN  MORGAN','Impacta Ltd<br>Field Street','Bilston/Wolverhampton','West Midlands','UNITED KINGDOM','WV148RW','01902496307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 09:11:46',0,NULL,3,1,3,1,'RA117764929CN\r ','GPS0004 '),(17423,894965179012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','droopynyc','genesissteve@gmail.com','Stephen Shiu','1246 S. Sycamore Ave','Los Angeles','CA','UNITED STATES','90019-1533','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 09:14:11',0,NULL,3,1,1,1,'\\ ',NULL),(17424,807630801011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','paulobarreiros','paulo.a.barreiros@gmail.com','Paulo Barreiros','Rua Ferreira de Castro, 22 Esq','Evora','Evora','PORTUGAL','7005-488','+351917745068','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 09:42:25',0,NULL,3,1,11,1,'BJ01601348\r ','OTHP005 不挂号'),(17425,894984216012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','buzzbetts','toselandblade@hotmail.co.uk','KEVIN','BETTS<br>14 BUTTS CLOSE','ILKESTON','Derbyshire','UNITED KINGDOM','DE7 4PY','07523962122','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 10:05:01',0,NULL,3,1,3,1,'RA117764875CN\rRA117764875CN\r ','HSPL013\r英标 '),(17426,894984518012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',9.19,'eastar4uk','theburke1','razorburke@gmail.com','Raymond Burke','53 gortgreine<br>rahoon','galway','Galway','IRELAND','na','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 10:06:48',0,NULL,3,1,3,1,'RA117764827CN\r ','HSPL005 \r英标'),(17427,596356036003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',31.5,'cnfaner','marik_bond','mario.klapsa@gmail.com','Mario Klapša','Cerje Nebojse 109','Maruševec','','CROATIA','42243','+385912390507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 10:44:22',0,NULL,3,1,3,1,'RA117764932CN\r ','HSPL008 \r欧标\r申报15美金'),(17428,8881323082976665,111,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',0,'eastar4','vrikey','barryhoman@hotmail.com','Bradley Barrett Homan','Sdr. Trandersvej 170','Gistrup','','DENMARK','9260','(+45) 9831 5581',NULL,NULL,NULL,'2011-12-05 11:02:56',0,NULL,3,1,3,1,'RA117779849CN\r ',' 黑色的 '),(17429,654655962013,230567467930,'New Brand SAMSUNG WMN1000C ULTRA SLIM WALL MOUNT 60\"-65',2,'MOSA003',129.98,'eastar4','e-tronicsdepot','mdmmason@yahoo.com','Daniel Mason','135 Main Street','Gananoque','ON','CANADA','K7G 2M1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 11:03:55',0,NULL,3,1,3,1,'RA117779852CN\r ',' MOSA003'),(17430,8881323083733086,111,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',0,'eastar4','stigtrondheim','stig.westerhus@online.no','Stig Westerhus','Moltmyra 71','TILLER','','NORWAY','7091','4795876700',NULL,NULL,NULL,'2011-12-05 11:15:33',0,NULL,3,1,11,1,NULL,'UM00020 只补一个伞头 +502胶水'),(17431,895016201012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','henrique_fonseca','henrique.fonseca.vet@gmail.com','Henrique Fonseca','Praceta Quinta dos Gafanhotos<br>nº162, 3º Direito','Carcavelos','Cascais','PORTUGAL','2775-410','+351966256880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 11:38:35',0,NULL,3,1,11,1,'\\ ','SCLO002 \r不挂号'),(17432,762711143001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','watch_kc','rolex_kc@yahoo.com','Jee Chook Fah','No. 870, Ground Floor<br>Tabuan Jaya Shopping Centre','Kuching','Sarawak','MALAYSIA','93350','019-8862298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 12:18:11',0,NULL,3,1,2,1,'\\  ','BR3D007 '),(17433,762787177001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','lemorissa','lemor3@gmail.com','limor issa','p.o box 621','gush halav','','ISRAEL','13872','+972528191125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 12:22:59',0,NULL,3,1,11,1,'\\ ','BR3D006 \r不挂号'),(17434,754212898007,170728921512,'New Jabra BT135 Bluetooth headset+AC power charger',1,'HSJA007',14.55,'au-buy','stoar','sto_ar@abv.bg','Stoyan Arabadzhiev','Sofiisko Shose Str, N 24','Samokov','Samokov','BULGARIA','2000','359888345866','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 12:27:01',0,NULL,3,0,11,1,'\\ ','HSJA007\r不挂号\r欧标\r '),(17435,895038781012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',6,'UM00005',131.04,'eastar4','enelidova','nelidova@rambler.ru','Elena  Soboleva','Koroleva 48-4-123','Saint Petersburg','','RUSSIAN FEDERATION','197371','+79219198233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 12:36:36',0,NULL,3,1,5,1,'CP211275749CN ',' UM00005'),(17436,895043327012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','janice beecher','303 N 4th Ave','Hill City','KS','UNITED STATES','67642-1729','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 12:47:27',0,NULL,3,1,1,1,'\\  ',NULL),(17437,807719921011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','automaniac-ams','info@automaniacservice.co.uk','Automaniac','50 oaks road','staines','London','UNITED KINGDOM','tw19 7lg','07863170364','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 13:54:37',0,NULL,3,1,3,1,'RA117765005CN\r ','RELO003 '),(17438,601805850004,140647853566,'3G WWan antenna  MC8775 MC8781 MC8780 MC8790 F3507G GTM380 GTM382 M250 DELL5530',1,'ANCN001',4.79,'cnfaner','s1mm','loh.s@arcor.de','Simon Lohrum','Fritz von Wille str 87','Trier','','GERMANY','54296','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 14:23:51',0,NULL,3,1,3,1,'RA117764950CN\r ','ANCN001 '),(17439,895087036012,220885745410,'New genuine Microsoft Wired Optical Wheel Mouse white',1,'MOMI004',13.79,'eastar4','aaroncasha','casha1@maltanet.net','Mr. Casha','495 Main Street','Mosta','','MALTA','MST 1018','00356 21411660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 14:29:28',0,NULL,3,1,11,1,'\\ ',' MOMI004 不挂号'),(17440,895095791012,220885745410,'New genuine Microsoft Wired Optical Wheel Mouse white',2,'MOMI004',27.58,'eastar4','surachai1008','surachai.wongtassaneekorn@sccc.co.th','Surachai Wongtassaneekorn','99 Moo 9 Friendship Highway, Tabkwang<br>Kaengkoi','Saraburi','Saraburi','THAILAND','18260','063765101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 14:47:09',0,NULL,3,1,2,1,'\\  ',NULL),(17441,601816244004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',19.95,'cnfaner','detti_nl','ad.hoff@upcmail.nl','Hoff Detlef','Koolzaadveld 22','Beuningen','','NETHERLANDS','6641sx','+31626208241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 14:53:29',0,NULL,3,1,3,1,'RA117764915CN\r ','WLAP002 '),(17442,754269016007,170735485699,'New News Paper 3-Section Rain Sun Floding Umbrella   newspaper',1,'UM00038',19.99,'au-buy','sasirmisbunlar','mehmetcankomurcu@hotmail.com','Mehmet Can Komurcu','Yahyakaptan mahallesi C21 D16<br>Izmit','Kocaeli','Kocaeli','TURKEY','41000','00905377318610','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 14:54:15',0,NULL,3,1,11,1,'BJ01601363\r ','UM00038\r不挂号 \r '),(17443,807763169011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',2,'LGGL001',43.98,'eastar4','oscar_jun','oscarjun@hotmail.com','Oscar Francisco da Silva Junior','Estrada União e Indústria 10.035 Sala 238 - Itaipava','Petrópolis','Rio de Janeiro','BRAZIL','25730736','(24) 22226339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 15:35:12',0,NULL,3,1,3,1,'RA117764963CN\r ',' LGGL001'),(17444,895125201012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','renato_cunha','renatinho_cunha@hotmail.com','Renato Sergio Godoy Cunha','r. joaquim mourão 150','Leme','Sao Paulo','BRAZIL','13610-070','19-35712710','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 15:48:11',0,NULL,3,1,3,1,'RA117779781CN\r ','LGRM001 \rplease declare as gift and only 10 dollars thanks so much'),(17445,895127355012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',47.96,'eastar4uk','antonio2680','avangarde26@yahoo.es','Antonio Ruiz Romero','Avenida del Brillante número 9 casa','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','615855846','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 15:54:05',0,NULL,3,1,3,1,'RA117779835CN\r ','OTGR002 \rOTGR003\rNew genuine Grohe Shower head holder made in Germany\r一共四个物品，水管和底座各两个\r'),(17446,654740994013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','heidiwrede','hwrede@carlsonwagonlit.com','Heidi Wrede','3639 Vincent Ave N','Minneapolis','MN','UNITED STATES','55412-1846','(612) 354-7534','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 15:59:37',0,NULL,3,1,1,1,'\\  ',NULL),(17447,653292783013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','vivianfogle','cfogle@sbcglobal.net','Vivian Fogle','9130 Nolan St<br>Apt 1934','Elk Grove','CA','UNITED STATES','95758-7544','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 16:00:14',0,NULL,3,1,3,1,'RA117779945CN\r ',' GLOT001*4'),(17448,807758280011,320756095112,'NIB Genuine 2 pair Samsung SSG-2100AB 3D glasses + Alice in wonderland blu-ray ',1,'GLSG001*2+BR3D005',114.99,'eastar4','sassi669','lev_adi@hotmail.com','adi balbul','vinget 23','Tel Aviv','IN','ISRAEL','67069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 15:31:52',0,NULL,3,1,3,1,'RA117779818CN\r ',' GLSG001*2+BR3D005'),(17449,754302478007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','pv31_ru','pv31ebay@gmail.com','Valentina Isaeva','DEGTYAREVA -2-126<br>ДЕГТЯРЕВА-2-126','BELGOROD','','RUSSIAN FEDERATION','308027','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 16:06:45',0,NULL,3,1,11,1,'\\ ','UM00042\r不挂号 '),(17450,807787282011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','k.sbitnev','ksbitnev@gmail.com','Konstantin Sbitnev','Chaykovskogo st, 185-587','Chelyabinsk','','RUSSIAN FEDERATION','454016','+7 351 2680036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 16:25:03',0,NULL,3,1,11,1,'\\\r ',' WLIN011  不挂号 '),(17451,654752845013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','amazoon75','amazoon@seznam.cz','Zdenek Pluskal','Držovice Fibichova 455','Prostějov','Prostějov','CZECH REPUBLIC','79607','+420724309929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 16:29:27',0,NULL,3,1,11,1,'BJ01601378\r ',' CACN004  不挂号 '),(17452,596460512003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','lucianocapato','lcapato@hotmail.com','Luciano Capato','Rua Jaguaribe, 252 - AP410<br>Vila Buarque','Sao Paulo','São Paulo','BRAZIL','01224-000','551134768932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 16:59:38',0,NULL,3,1,3,1,'RA117779795CN\r ','LGRM001 '),(17453,601852081004,140626376683,'NEW Logitech Wireless Laser Mouse M505 plus receiver',1,'MOLO008',35.4,'cnfaner','kuzmasta','sdacha_sleva@yahoo.com','Kirill Kuznetsov','haaliya 3, 5','Tel-Aviv','','ISRAEL','6606103','+972524834886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 17:04:25',0,NULL,3,1,3,1,'RA117767810CN\r ','red 红色的\rMOLO008\r'),(17454,601867025004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',161.97,'cnfaner','svetoslavterr','sv_terr@mail.bg','Svetoslav Slavchev','kv.Chayka, bl.67, vh.2, et.1, ap.22','Varna','','BULGARIA','9005','0887988530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 17:22:08',0,NULL,3,1,3,1,'RA117779906CN\r ','GLSG001 \r申报成gift 低于20美金'),(17455,807820252011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','spakama3311','spakama33@yahoo.com','toni lala','902 Arlington Ctr<br># 317','ada','OK','UNITED STATES','74820-2883','(702) 287-3330','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 17:24:35',0,NULL,3,1,1,1,'\\  ',NULL),(17456,807825362011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','pilovik2011','pilovik@gmail.com','Viktor Dubovytskyi','ulitsa Koshitsa, 9, kv.198','Kiev','','UKRAINE','02168','+380674411773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 17:34:46',0,NULL,3,1,11,1,'\\ ',' WLAP002  不挂号'),(17457,754350721007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','galaxyfoam','jorge@galaxyfoam.com','Jorge Chavez','10 E Charleston Blvd','Las Vegas','NV','UNITED STATES','89104-1036','(702) 382-8563','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 17:37:46',0,NULL,3,1,1,1,'\\  ',NULL),(17458,807836144011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',2,'GLOT001',89.78,'eastar4','bustumup','boricd@rogers.com','dave boric','55 seahorse ave','brampton','ON','CANADA','l6v4n7','(647) 242-2037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 17:50:35',0,NULL,3,1,3,1,'RA117779954CN\r ',' GLOT001'),(17459,753876865007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',2,'RCLO003',271.98,'au-buy','firestar09dm','firestar04@mail.ru','Michael Rayhelson','2415 Western Ave<br>Apt 409','Seattle','WA','UNITED STATES','98121-1367','(425) 417-2468','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 17:51:52',0,NULL,3,0,4,1,'YW867661363CN ',NULL),(17460,807840377011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','rntalb','renato@locamunck.com.br','Renato Albuquerque','Rua Deputado Emilio Carlos, nº 355<br>Apto 52 - Torre 1 - Vila Campesina','São Paulo','São Paulo','BRAZIL','06028-015','551189521190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 17:59:47',0,NULL,8,1,17,0,NULL,NULL),(17461,807843564011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','rntalb','renato@locamunck.com.br','Renato Albuquerque','Rua Deputado Emilio Carlos, nº 355<br>Apto 52 - Torre 1 - Vila Campesina','São Paulo','São Paulo','BRAZIL','06028-015','551189521190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 18:02:31',0,NULL,3,1,3,1,'RA117779866CN\r ',' GLOT001  一共发两个'),(17462,654807801013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','veslenyov_2009','veslenyov.m.a@gmail.com','Veslenyov Michail','Ul Ak.Chokina 148-55','Pavlodar','Pavlodarskaya oblast','KAZAKHSTAN','140000','+77182628630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 18:35:20',0,NULL,3,1,3,1,'RA117779764CN\r ',' OTES001'),(17463,654813348013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','tamo3103','a-s-hakim@gmx.de','Ahmad Shah Hakim','Karl-Marx-Ring 24','München','','GERMANY','81735','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 18:48:22',0,NULL,3,1,2,1,'\\  ',NULL),(17464,601904787004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',23.7,'cnfaner','korobos2010','korobos@gmail.com','Panagiotis Angelopoulos','THRAKIS 110-112','PERAMA','ATTIKIS','GREECE','18863','+306947890467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 18:50:20',0,NULL,3,1,3,1,'RA117764946CN\r ','欧标\rHSNO003'),(17465,895242726012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','krosemamirmurad','krosem155@hotmail.com','Amir Azizov','Tbilisi Ave.','Baku','','AZERBAIJAN','AZ 1065','+994502102363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 18:53:11',0,NULL,3,1,3,1,'RA117767823CN\r ',' HBPH001'),(17466,601918243004,140635369210,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',68.99,'cnfaner','marcioercoelho','merk5678@hotmail.com','Marcio Emanoel Rodrigues Coelho','Av. Prefeito Manoel Vila, 585<br>Centro','Barra de Sao Francisco','Espirito Santo','BRAZIL','29800-000','27 3756 0181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 19:17:30',0,NULL,3,1,3,1,'RA117779821CN\r ','申报gift\r费用低于50\rOTSO004'),(17467,596536362003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','g0tt80','danko.gott@gmail.com','daniel gottlicher','ivanicgradska 43','zagreb','','CROATIA','10000','385981774182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 19:47:59',0,NULL,3,1,3,1,'RA117779804CN\r ','MOAP001 '),(17468,601937431004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','petatt','peter.attrill@gmail.com','Peter Attrill','5<br>Cranbrook Drive','Twickenham','London','UNITED KINGDOM','TW2 6HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 19:55:15',0,NULL,3,1,3,1,'RA117779747CN\r ','OTHP004 '),(17469,654848771013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','errolrojas','ticoviejo@yahoo.com','Errol Rojas','250 GENOA AVE','TOMS RIVER','NJ','UNITED STATES','08753-8317','(732) 831-5260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 19:57:34',0,NULL,3,1,1,1,'\\  ',' HP 8pin 1.25 18cm '),(17470,807932118011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','cmercier1962','cmercier62@comcast.net','CLAUDE Mercier','8790 SPRING MOUNTAIN WAY','Fort Myers','FL','UNITED STATES','33908-9677','(239) 689-4743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 20:07:36',0,NULL,3,1,1,1,'\\  ',NULL),(17471,653005380013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ultimate_gadget_geek','mark@harrisoncentral.com','Mark Harrison','Fortvägen 15','Täby','','SWEDEN','187 64','(468) 756-6465','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 20:20:36',0,NULL,3,1,11,1,'\\ ',' CACN004  不挂号 '),(17472,807950322011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',16.58,'eastar4','mujitaba32','olajuwon_68@yahoo.com','olajuwon kako','45 DOIRE BEAG<br>OFF ORIEL ROAD','COLLON','Louth','IRELAND','','0419819689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 20:30:51',0,NULL,3,1,11,1,'BJ01601386\r ',' CASS002 不挂号 '),(17473,895338659012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','mara karlinsky','5750 SW 132ND TER','MIAMI','FL','UNITED STATES','33156-7274','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 20:52:47',0,NULL,3,1,1,1,'\\  ',' '),(17474,654910048013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','tybytech78','tybytech@gmail.com','Dorcu Felicia','Bl A4, Sc B, Et 1, Ap 5','sat Dancu, com Holboca','Iasi','ROMANIA','707252','+40764810820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 21:53:55',0,NULL,3,1,11,1,'\\ ','WLAT010 不挂号'),(17475,807983804011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','jordidejong','king_jordi007@hotmail.com','Jordi de Jong','Boekesteynlaan 5','SPIJKENISSE','','NETHERLANDS','3207ZG','0638305272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 21:57:33',0,NULL,3,1,3,1,'RA117779870CN\r ',' GLOT001'),(17476,895386589012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',67.4,'eastar4uk','vesbusmapa','busanny@versanet.de','Manfred Busanny','Ulmer Straße 58','Biberach','','GERMANY','88400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 21:59:09',0,NULL,3,1,3,1,'RA117779883CN\r ','GLOT005 '),(17477,895400771012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','vancarlier03','nessa03@gmail.com','vanessa carlier','3 rue voltaire','montlucon','Auvergne','FRANCE','03100','0615671428','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 22:23:36',0,NULL,3,1,3,1,'RA117779716CN\r ','SAFI001 '),(17478,602012270004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','icthylady','icthylady@aol.com','Ivy Santee','4747 Vegas Dr','Las Vegas','NV','UNITED STATES','89108-2135','(702) 486-5127 ext.: 3503','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-05 22:45:00',0,NULL,3,1,1,1,'\\  ',NULL),(17479,808036410011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','markandrews7','mdandrews@gmail.com','Mark Andrews','Flat B111<br>46 Palmers Road','Bethnal Green','London','UNITED KINGDOM','E2 0TD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 22:46:31',0,NULL,3,1,3,1,'RA117764977CN\r ','OTHP005 '),(17480,808032709011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',18.99,'eastar4','6merzlota9','novototskaya@gmail.com','Ekaterina Novototskaya-Vlasova','Novocheremushkinskaya 59-1-61','Moscow','','RUSSIAN FEDERATION','117418','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 22:46:36',0,NULL,3,1,11,1,'\\','  UM00022  不挂号'),(17481,808044869011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','neel_007','enelemans@zonnet.nl','Eric Nelemans','Lindt 16','Helmond','Noord-Brabant','NETHERLANDS','5708ZV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 23:03:34',0,NULL,3,1,11,1,'\\ ',' OTCN002 不挂号'),(17482,808053408011,320786223346,'New Jabra JX10 Series II 2  Bluetooth headset red',1,'HSJA013',19.98,'eastar4','psycadelik','duality1980@yahoo.com','John J Brode Jr','8917 Cloverleaf Cir','Parker','CO','UNITED STATES','80134-3957','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 23:22:52',0,NULL,3,1,1,1,'\\  ',NULL),(17483,808054982011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','mattgsxr1000tt','matt.hazel@live.co.uk','Matt Hazel','C/O Diasorin spa<br>Central Rd','Dartford','Kent','UNITED KINGDOM','DA1 5LR','07736308013','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 23:26:29',0,NULL,3,1,3,1,'RA117779897CN\r ','GLSG001 '),(17484,808056976011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','why990907992','why_930211@yahoo.cn','Wang Haoyang','Rialto Court, 66 Bridge road','stockton','Cleveland','UNITED KINGDOM','TS183DG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 23:32:02',0,NULL,3,1,3,1,'RA117779720CN\r ',' UDAP001'),(17485,596637425003,130598028719,'New Nokia LD-3W Bluetooth GPS Module /w Car charger',1,'OTHP004',26.99,'cnfaner','pd8321','peng-duan@hotmail.com','Duan Peng','1362<br>rue Père-Jamet, ste-foy','Québec','QC','CANADA','g1w 3g5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 00:00:29',0,NULL,3,1,3,1,'RA117779778CN\r ','申报gift\r申报价低于20，避免关税\r OTHP004'),(17486,807631497002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','bosox0502','vinnytdd@hotmail.com','Josh Celander','6225 SARATOGA BLVD<br>APT 1010','CORPUS CHRISTI','TX','UNITED STATES','78414-3447','(830) 570-2870','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 00:23:05',0,NULL,3,1,1,1,'\\  ',NULL),(17487,895476689012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','gene1085','gsinda@capac.k12.mi.us','Gene Sinda','1085 Capac Rd','Berlin','MI','UNITED STATES','48002-3005','(810) 395-7595','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 01:08:08',0,NULL,3,1,1,1,'\\  ',NULL),(17488,764270337001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',74.78,'buysia','billandgabby','billandgabby@aol.com','William Harris','4532 N Robin Ave','Odessa','TX','UNITED STATES','79764-9303','(432) 556-3015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 02:06:09',0,NULL,3,1,1,1,'\\  ','一共4个\rNarnia The Voyage of the Dawn Treader 3D Blu-Ray NEW\rAlice in Wonderland New sealed 3D Blu-ray Region: A,B,C\rICE AGE 3 New Panasonic sealed 3D Blu-ray \r\r '),(17489,754620589007,170728920259,'GENUINE Plantronics Voyager 851/855 Multi-Point Bluetooth Headset',1,'HSPL017',35.9,'au-buy','wgcisco1210','wgcisco12@yahoo.com','warren daniels jr','115 sandlewood dr','terrell','TX','UNITED STATES','75160-5105','(214) 725-9172','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 01:55:08',0,NULL,3,1,1,1,'\\  ',NULL),(17490,8881323138614615,111,'apple extreme card new',20,'WLAP003',470,'eastar4','MacWireless','manooch@gmail.com','Manooch Khajeh','1310 9th Street','Berkeley','CA ','UNITED STATES','94710','',NULL,NULL,NULL,'2011-12-06 02:30:14',0,NULL,3,1,3,1,'RA117767770CN\r ','WLAP003 '),(17491,895511082012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','everchanging02','johnsonc@msoe.edu','Christopher Johnson','1017A S 18th St','Manitowoc','WI','UNITED STATES','54220-5039','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 02:30:30',0,NULL,3,1,1,1,'\\  ',NULL),(17492,655003028013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','cymru-am-beth','stewpot99@bigpond.com','stewart knight','28 new england drive<br>woodcroft','adelaide','South Australia','AUSTRALIA','5162','0883223784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 02:43:41',0,NULL,3,1,3,1,'RA117767783CN\r ',' GLOT001*3'),(17493,745495082008,180761131351,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'au-buy','c.scott.2009','cherice_2008@yahoo.com','Cherice Scott','913 Bagwell Ave<br># A','Murray','KY','UNITED STATES','42071-3077','(573) 427-8688','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 02:54:59',0,NULL,3,1,3,1,'RA117768245CN ','UM00041 '),(17494,808136830011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','mona1369_2009','me_too_69@hotmail.com','steve ford','PO Box 2873<br>2428 n. Cambell','springfield','MO','UNITED STATES','65801-2873','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 03:04:20',0,NULL,3,1,1,1,'\\  ',NULL),(17495,895531046012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','digitica','tucherda@ca.inter.net','Tun Lim','1228 43E Avenue','Laval','QC','CANADA','H7R 5A1','(450) 962-6034','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 03:21:35',0,NULL,3,1,3,1,'RA117767766CN\r ',' GLOT001*2'),(17496,602090401004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','bigcedharris24','bigcedharris@bellsouth.net','Keangle','2100 Tuck Dr<br>Harris','Conyers','GA','UNITED STATES','30012-2892','(770) 256-6642','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-06 03:47:08',0,NULL,3,1,1,1,'\\  ',NULL),(17497,895557786012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','eleldar','eldar@boltachev.com','Eldar Boltachev','Vahtangova, 3','Sterlitamak','Bashkortostan','RUSSIAN FEDERATION','453103','+79173448655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 04:41:13',0,NULL,3,1,3,1,'RA117768086CN\r ','LGRM001 '),(17498,8881323147043354,111,'New in box Genuine Samsung 2 pair SSG-2100AB glasses',1,'GLSG001*2',0,'eastar4','kfaust-2008','kfaust@new.rr.com','Kathryn Faust','2343 Hopf Ln','De Pere','WI','UNITED STATES','54115','(920) 339-8382',NULL,NULL,NULL,'2011-12-06 04:50:43',0,NULL,3,1,1,1,'LK021378084CN ',' 原装盒子外面一定要再加一个盒子 加泡沫  上次那个就碎了 \r已回过信了\r等客户撤case后再发'),(17499,654603239013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','ihernan17','ivan.hernandez1717@gmail.com','Ivan Hernandez-Lugardo','9146 Lemona Ave<br>Unit 122','North Hills','CA','UNITED STATES','91343-3474','(818) 830-3291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 05:38:21',0,NULL,3,1,1,1,'\\  ',NULL),(17500,895581344012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','sns2032','sns2015@gmail.com','Anthony Johnson','625 N Grand St<br>Apt C12','Orange','CA','UNITED STATES','92867-6781','(805) 680-5741','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 06:19:00',0,NULL,3,1,1,1,'、 ',NULL),(17501,808191523011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','akucinta','anyttl@nate.com','CHULHYUN KIM','KT BUSAN Information Telecommunication Building 13F<br>Dong Gu Bumil 2Dong','BUSAN','','KOREA,REPUBLIC OF','601706','82 51 638 3135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 06:30:09',0,NULL,3,1,17,0,NULL,NULL),(17502,602120079004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','hackmar','kachmar@gmail.com','Ahmad Kachmar','Al Habtoor Leighton Group<br>P.O. Box 4284','Umm Al Nar','Abu Dhabi','UNITED ARAB EMIRATES','00000','(050) 498-4645','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 06:46:41',0,NULL,3,1,3,1,'RA117768072CN\r ','WLDE002 '),(17503,655059067013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','akucinta','anyttl@nate.com','CHULHYUN KIM','KT BUSAN Information Telecommunication Building 13F<br>Dong Gu Bumil 2Dong','BUSAN','','KOREA,REPUBLIC OF','601706','82 51 638 3135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 07:12:49',0,NULL,3,1,11,1,'\\ ','再发一个 MOCN001 \rBracket of half intel 5300 6250 wireless card to pci-e'),(17504,596727095003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','codecta','andre@infolink.com.br','Andre Barbosa','Correa Dutra, 59, cob 02','Rio de Janeiro','RJ','BRAZIL','22210-050','+552122866027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 07:01:19',0,NULL,3,1,3,1,'RA117768069CN\r ','申报为gift\rLGRM001 '),(17505,655061563013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','shtormzzz','shtormz@gmail.com','Alexander Zaytsev','Marshala Novikova 6-1-21<br>Маршала Новикова д.6 к1 кв.21','Moscow, Москва','','RUSSIAN FEDERATION','123098','+7-925-508-79-81','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 07:28:48',0,NULL,3,1,11,1,'\\ ','WLIN014\r不挂号 '),(17506,764567774001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','jericoalexis','cachorrowin@hotmail.com','JERICO  CASTRO','5204 WATER WALK LN','RALEIGH','NC','UNITED STATES','27616-6186','(919) 413-6608','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 07:57:56',0,NULL,3,1,1,1,'\\  ',NULL),(17507,602137306004,140626375298,'44 Pin 2.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN002',3.9,'cnfaner','nokkairc','tanadon@hotmail.com','Tanadon Ramasong','112/172 Airport villa soi 9<br>Phabath Road,Tumbol Phabath','Mueng','Lampang','THAILAND','52000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 08:41:27',0,NULL,3,1,3,1,'RA117768537CN\r ','OTCN002 \r'),(17508,602155302004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',19.95,'cnfaner','egon.p','egon.parmentier@hotmail.com','Egon  Parmentier','Mercatorstraat 9','Sint-Niklaas','','BELGIUM','9100','00324894494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 10:11:09',0,NULL,3,1,3,1,'RA117768378CN\r ','WLAP002 '),(17509,808252068011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','memolecula','evmareeva@mail.ru','Elena Konstantinova','Nansena proezd, 6-1-22','Moscow','Moscow','RUSSIAN FEDERATION','129343','89032191907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 10:20:16',0,NULL,3,1,11,1,'\\ ','OTHP005 '),(17510,808256430011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','nomad_ps','nomadps@gmail.com','Ivan Malik','Lenina, 17a, aptm. 2','Reutov','','RUSSIAN FEDERATION','143964','37377758869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 10:33:23',0,NULL,3,1,11,1,'\\ ','HBPH003 '),(17511,808257043011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.99,'eastar4','minas1981','totmin@yahoo.gr','MINAS TOTONIDIS','DIMOKRATIAS 17','KASTORIA','προεπιλογή','GREECE','52100','00302467082866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 10:36:33',0,NULL,3,1,11,1,'\\ ','HSNO004 '),(17512,8881323169247029,111,'G WWAN antenna',1,'ANCN001',0,'eastar4','bk7ycy','ebay@pisti.hu','C3 Alapitvany - Pecsenyanszky Istvan','Szpahi u. 20.','Budapest','','HUNGARY','1022','',NULL,NULL,NULL,'2011-12-06 11:00:47',0,NULL,5,1,18,1,NULL,' 3G antenna\r不挂号'),(17513,602170521004,140631612276,'New Jabra JX10 Series II 2 Bluetooth headset Black',5,'HSJA004',94.9,'cnfaner','tomoyukiminamibuchi','stnrkyv8225@me.pikara.ne.jp','Tomoyuki Minamibuchi','4283ExpressLane Suite R9752','Sarasota','FL','UNITED STATES','34238','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-06 11:24:07',0,NULL,3,1,1,1,'\\ ','黑色的  客户只要黑色的   等货到 再发'),(17514,596784753003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','ranb','rbarash@elta.co.il','Ran Barash','1 Bialik St.','Gan-Yavne','Israel','ISRAEL','70800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 12:00:33',0,NULL,3,1,3,1,'RA117768421CN\r ','HSMO020 \r欧标 220V'),(17515,602187262004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','malipericaftw','pkujundzic@gmail.com','Petar Kujundzic','Havidiceva 13','Zagreb','','CROATIA','10000','+38598813012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 12:31:46',0,NULL,3,1,3,1,'RA117768506CN ','CACN004 '),(17516,895695715012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jlaloussis','john.laloussis@gmail.com','John Laloussis','Unit 103<br>20 Reeves Street','Carlton','Victoria','AUSTRALIA','3053','0405639773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 12:35:43',0,NULL,3,1,11,1,'、 ',' MOAP001  不挂号'),(17517,764650744001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','wildthing1939','swiftyswallow@aol.com','PHILIP GORDON SWALLOW','5 ROGERS CLOSE','GOSPORT','Hampshire','UNITED KINGDOM','PO124XW','02392584302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 12:46:47',0,NULL,3,1,11,1,'\\ ','OTSB001 \r不挂号'),(17518,751713790007,170730545663,'Original Logitech MX Revolution Mouse Mat 3M material',3,'SCLO003',11.7,'au-buy','mxlamenace','le_bricolo_du66@hotmail.fr','Cazeneuve Nicolas','LES HAMADRYADES BATIMENT E<br>CHEMIN DES BAUMILLONS','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13015','0646873206','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 13:15:31',0,NULL,3,1,11,1,NULL,'SCLO003\r不挂号 '),(17519,747121451008,180699060430,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT006',42.74,'au-buy','satecomsystems','sarandos@satecom.gr','Costas Sarandos','13 a poseidonos<br>ATHENS GREECE','Moschato Athens greece','','GREECE','18344','302104833722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 13:22:26',0,NULL,3,1,3,1,'RA117768687CN ','GLOT006 '),(17520,602204897004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',50.99,'cnfaner','cappetti','bcappetti@optusnet.com.au','brett cappetti','277 musgrave road','coopers plains','queensland','AUSTRALIA','4108','0403364184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 13:40:47',0,NULL,3,1,3,1,'RA117768625CN ','LGFI001 '),(17521,895724320012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.99,'eastar4uk','js2955','garyh1000@hotmail.com','g hewitt','64 grasmere rd<br>frodsham','frodsham','Cheshire','UNITED KINGDOM','wa67lq','0192773248','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 13:44:59',0,NULL,3,1,3,1,'RA117768418CN ','OTGR002 '),(17522,654742652013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','misticx1','mjchmiel@verizon.net','Michael Chmiel','8464 Flagstone Dr','Tampa','FL','UNITED STATES','33615-4948','(813) 884-1344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 14:27:52',0,NULL,3,1,1,1,'\\  ',NULL),(17523,596821337003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','mateiix','matej.degen@siol.net','Matej Degen','Cesta na polje 31','Pragersko','','SLOVENIA','2331','02031583318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 14:29:03',0,NULL,3,1,3,1,'RA117768673CN ','SHLO009 \rbalck ver1\r邮局退回，客户还未问起'),(17524,655160880013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sandro-volkmann','sandrovolkmann@yahoo.de','Sandro Volkmann','Friedensburgstr. 18','Emmerthal','','GERMANY','31860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 14:36:17',0,NULL,3,1,11,1,'、 ',' HSNO019  欧标 不挂号'),(17525,895749491012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',20.65,'eastar4uk','advance_photo','admin@advancephoto.pl','Michal Kowieski','Powstancow Slaskich 2a/4','Zabrze','śląskie','POLAND','41800','534 127600','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 14:42:41',0,NULL,3,1,3,1,'RA184556331CN\r ','HSPL011 \r欧标\r'),(17526,808366856011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','rancano73','rancano@gmail.com','Ivan Rancano','C/Alvarez Lorenzana 23 4º A','Oviedo','Asturias','SPAIN','33006','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 15:27:30',0,NULL,3,1,3,1,'RA117768470CN ','LGGL002 '),(17527,895790763012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','bloodislav','zdenek.princ@gmail.com','Zdenek Princ','45a Kingsmead Road','London','London','UNITED KINGDOM','SW2 3HY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 16:05:22',0,NULL,3,1,3,1,'RA117768452CN\r ','WLIN014 '),(17528,764737920001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','gbha7867','govind@ccare.co.uk','Govind Bhatti','499 Oxford Road','Reading','Berkshire','UNITED KINGDOM','RG30 1HF','01889393615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 16:27:48',0,NULL,3,1,11,1,'\\ ','OTSB001 \r不挂号'),(17529,747194131008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.74,'au-buy','grumpy1976dave','grumpy1976@live.ca','dave charette','130 des seigneurs','st-etienne des gres','QC','CANADA','G0X 2P0','(819) 535-5238','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 16:33:27',0,NULL,3,1,3,1,'RA117768608CN\r ','GLOT001 '),(17530,895812168012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','nailbeautylondon','jablonskidariusz@yahoo.co.uk','Dariusz Jablonski','10 East India Way','London','Surrey','UNITED KINGDOM','CR06RZ','02086544385','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 16:54:04',0,NULL,3,1,3,1,'RA117768642CN ','GLOT005 '),(17531,655212046013,230641257901,'New lady lace trim sun/rain stick Umbrella blue',1,'UM00011',23.74,'eastar4','jcam8922','jimandannecampbell@sympatico.ca','James Campbell','2677 Preston Court','Windsor','ON','CANADA','n9e4n8','(519) 966-3434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:04:40',0,NULL,3,1,11,1,'、 ',' UM00011  蓝边 不挂号'),(17532,595311952003,130610254345,'New GENUINE PLANTRONIC Calisto pro Bluetooth Headset only',1,'HSPL014',52.99,'cnfaner','kamalwick','manamalaya@gmail.com','Kamal Wickramanayake','No 2, 2nd Lane, Pangiriwatta Road<br>Gangodawila','Nugegoda','Western','SRI LANKA','10250','719060606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:07:03',0,NULL,3,1,3,1,'RA117768894CN ','HSPL014 \r要欧标\rPlease include an EU plug compatible charger'),(17533,805071889011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',21.99,'eastar4uk','masterdikafri','master_kafrer@hotmail.com','Agapios Tsakiris','63 Diagora Str.','Thessaloniki','Ano Toumpa','GREECE','54351','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 17:07:10',0,NULL,3,1,3,1,'RA117768611CN ','HSIT002\r欧标 \r黑色的'),(17534,754914545007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',1,'RCLO006',46.99,'au-buy','719michaelw','mpwillits@yahoo.com','Michael Willits','PO Box 332<br>279 West Garnet','Granby','CO','UNITED STATES','80446-0332','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 17:11:59',0,NULL,3,1,1,1,'\\  ','RCLO006 '),(17535,655216288013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','09*miguelon','miguelito-1980@hotmail.es','juan cuevas duran','poligono ibaiondo nº11','hernani','País Vasco','SPAIN','20120','943333737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:18:57',0,NULL,3,1,3,1,' RA117768510CN\r',' GLOT001*2'),(17536,602277689004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',6,'WLAP002',119.7,'cnfaner','dcpartscom','dlutian@dcparts.com','Dan Lutian','16500 Detroit Ave','Lakewood','OH','UNITED STATES','44107-3628','(216) 228-4949','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-06 17:26:38',0,NULL,3,1,1,1,'\\  ',NULL),(17537,596871422003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',1,'HSNO008',13.88,'cnfaner','rasfour84','rasfour@rhc.jo','Rajab Asfour','Royal Hashemite Court','Amman','','JORDAN','11100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:28:13',0,NULL,3,1,3,1,'RA117768449CN\r ','HSNO008 \r约旦'),(17538,808429200011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','guandms','guandms@gmail.com','Gabi Uzan','Exsodus<br>30/6','Ashkelon','','ISRAEL','78427','972542435269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:30:45',0,NULL,3,0,11,1,'、 ',' OTHP004 不挂号'),(17539,808435905011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ljkmt42','ljthomas42@bellsouth.net','Laura Thomas','2924 SE Treasure Island Rd','Port Saint Lucie','FL','UNITED STATES','34952-5773','(772) 398-0655','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 17:42:26',0,NULL,3,1,1,1,'\\ ',NULL),(17540,655228649013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','87georgia','elsalvador2@verizon.net','jose diaz','2113 gatewood pl','silver spring','MD','UNITED STATES','20903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 17:44:31',0,NULL,3,1,3,1,'RA117768599CN\r ',' GLOT001*4'),(17541,895848083012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','gasmanl','linda.stewart2@ntlworld.com','Linda B Stewart','5 Morar Drive','Bearsden','Glasgow','UNITED KINGDOM','G61 2JZ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:45:46',0,NULL,3,1,3,1,'RA117768435CN\r ',' HBPH007'),(17542,808452012011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','olimpioa','olimpioa@uol.com.br','Olimpio de Melo Alvares Junior','Rua Gustav Hainz 196H','Cotia','SP','BRAZIL','06710765','11 82826059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 18:08:38',0,NULL,3,1,3,1,'RA117768656CN ',' GLOT001'),(17543,895869936012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','ldcfn2011','ldcfn@list.ru','Andrey Nikiforov','Kosmonavtov 53-92','Kazan','Tatarstan','RUSSIAN FEDERATION','420061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 18:20:15',0,NULL,3,1,3,1,'RA117768639CN ',' GLOT001'),(17544,602290130004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','homer969696','fixmaster96@gmail.com','Frank Skjervold','postbox 1926','trondheim','ST','NORWAY','7448','+4790685595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 18:20:17',0,NULL,3,1,3,1,'RA117768554CN\r ','BALO007 '),(17545,655251043013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','alodesigns','adriano_oppio@hotmail.com','Adriano Oppio','3430 E Jefferson Ave<br># 254','Detroit','MI','UNITED STATES','48207-4233','(519) 737-6618','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 18:34:10',0,NULL,3,1,1,1,'\\ ',NULL),(17546,895883428012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','marek1925','modoner@sbcglobal.net','Marek Odoner','2731 S 43rd St','Milwaukee','WI','UNITED STATES','53219-3201','(414) 327-7426','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 18:37:51',0,NULL,3,1,1,1,'\\ ',NULL),(17547,655260292013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','tag16c','tag16c@yahoo.com','jeff albertson','1682 haversham park dr','Winston Salem','NC','UNITED STATES','27127-7296','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 18:54:33',0,NULL,3,1,3,1,'RA117768571CN ',' GLOT001*4'),(17548,596932421003,130598387349,'3 pairs of New Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',158.99,'cnfaner','dataland147','dataland@seznam.cz','Radim Lédr','Prstná, 147','Petrovice u Karviné','','CZECH REPUBLIC','73572','724556530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 19:24:15',0,NULL,3,1,3,1,'RA117768700CN ','GLSG001*3 '),(17549,602332978004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',29.9,'cnfaner','bk5725','boris.korol@verizon.net','Boris Korol','2401 Alsop Ct','Reston','VA','UNITED STATES','20191-3021','(703) 476-6173','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-06 19:33:25',0,NULL,3,1,1,1,'\\  ',NULL),(17550,895929218012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','pia4853','lori@kidsgroove.com','Lori Moitie','25426 Bunker Hill Blvd','Hayward','CA','UNITED STATES','94542-1955','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 19:38:12',0,NULL,3,1,1,1,'\\  ',NULL),(17551,596944801003,130458358084,'New GENUINE NOKIA BH-102 BLUETOOTH HEADSET track#',1,'HSNO001',19.29,'cnfaner','gangadharnr','nr_gangadhar@yahoo.co.uk','Ram Singh','Wiesestraße 90<br>C/O Restaurant Prince of India','Gera','','GERMANY','07548','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 19:51:54',0,NULL,3,1,3,1,'RA117768545CN\r ','HSNO001\r欧标 '),(17552,655306957013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','lilmicky','michael.ermakov@gmail.com','Michael Ermakov','Nosovihinskoe shosse, dom 21, kv 98','Reutov-5','Moscow region','RUSSIAN FEDERATION','143965','+7 985 7 726 726','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 20:26:18',0,NULL,3,1,11,1,'\\ ',' WLIN014  不挂号'),(17553,808559554011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','gsanmiguel','guillermo_san_miguel@yahoo.es','Guillermo San Miguel','Mendieta Zeharbide 16 1º','Sopelana','Bizkaia','SPAIN','48600','646474438','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 20:44:49',0,NULL,3,1,3,1,'RA117768568CN ','GLOT001 '),(17554,895991620012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','atho5663','allythomson1@hotmail.co.uk','alasdair thomson','27 unitas crescent<br>carluke','carluke','South Lanarkshire','UNITED KINGDOM','ml8 5aw','07738266155','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 21:00:36',0,NULL,3,1,3,1,'RA117768497CN ','HSJA010\r英标 '),(17555,808585505011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','kuba230487','kubuszuchowicz@yahoo.com','Jakub Zuchowicz','2600 S 25th ave<br>MGBR LOGISTICS','BROADVIEW','IL','UNITED STATES','60155-4511','(773) 600-7299','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 21:22:42',0,NULL,3,1,1,1,'\\ ',NULL),(17556,808589767011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','dacordive','ch.wiesner@gmx.de','Christian Wiesner','Schwarzbachstr. 29','Ratingen','','GERMANY','40878','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 21:29:37',0,NULL,3,1,11,1,'\\ ','WLAT008\r不挂号 '),(17557,808598471011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','jwrm','jwmckeel@comcast.net','John McKeel','4322 Indigo St NE','Salem','OR','UNITED STATES','97305-2136','(503) 304-1914','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 21:43:55',0,NULL,3,1,1,1,'\\  ',NULL),(17558,896050250012,220823018383,'2 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*2',65.99,'eastar4uk','nikis_enlap','nikitalapickij@gmail.com','Nikita Lapickij','Flat 9, Luli Court<br>Trim Street','London','London','UNITED KINGDOM','SE14 6FB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 22:29:15',0,NULL,3,1,3,1,'RA117768695CN\r ','GLOT005*2 '),(17559,655370661013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','anderscarliemilli','andersca@bigpond.net.au','Anders  nielsen','20 Kooya Rd<br>mitchelton','Brisbane','Queensland','AUSTRALIA','4053','0733554926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 22:48:23',0,NULL,3,1,3,1,'RA117768585CN ',' GLOT001*4'),(17560,755124532007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','jrway81','jayway1981@gmail.com','Justin Way','4/40 Glenbarry Road','Campbellfield','Victoria','AUSTRALIA','3061','0409973152','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 22:52:23',0,NULL,3,1,11,1,'\\ ','RELO003\r不挂号 '),(17561,808638889011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','lynnzal','l.branigan@ntlworld.com','Lynnden Branigan','CARDWELYN<br>35a Plough Hill','Cuffley','Hertfordshire','UNITED KINGDOM','EN6 4DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 22:55:42',0,NULL,3,1,3,1,'RA117768364CN\r ','WLDE002 '),(17562,808643173011,320753523732,'NIB Genuine Samsung SSG-2100AB 3D glasses + Blu-ruy ICE AGE 3 disc',1,'GLSG001*2+BR3D006',114.99,'eastar4','soulowl','kevin.wiles1@virginmedia.com','Kevin C Wiles','7 Anstee rd','Long Eaton','Nottinghamshire','UNITED KINGDOM','NG10 3GQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 23:05:16',0,NULL,3,1,3,1,'RA117766584CN\r ',' GLSG001*2+BR3D006'),(17563,602433757004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','bkred14','bkred14@yahoo.com','bill redenius','504 2 nd','Moody','TX','UNITED STATES','76557','(254) 541-8816','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-06 23:38:06',0,NULL,3,1,1,1,'\\  ',NULL),(17564,755144390007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','djkanda562011','djkanda56@gmail.com','DALJIT SINGH kanda','32<br>edward st','fawkner','Victoria','AUSTRALIA','3060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 23:41:12',0,NULL,3,1,11,1,'\\ ','HSPL002\r澳标 \r不挂号'),(17565,896105206012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','alejasena16041983','alejasena@hotmail.com','Vanessa Hernández Muñoz','C/La Chercha. Nº77<br>La Gallega','Santa Cruz de Tenerife','Canarias','SPAIN','38107','686920799','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 00:23:11',0,NULL,3,1,3,1,'RA117765080CN\r ','HSPH002 '),(17566,765005589001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','mccarthy5241','mccarthy5241@hotmail.com','Thomas McCarthy','5241 Banana Ave','Cocoa','FL','UNITED STATES','32926-2026','(321) 633-4249','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\  ',' 一共三张\r另外两张是爱丽丝梦游仙境和加勒比海盗\r'),(17567,808690590011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','felicia38love','sxyfee@hotmail.com','Felicia Todd','1140 Front St<br>Apt A2','Uniondale','NY','UNITED STATES','11553-1939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 01:06:20',0,NULL,3,1,1,1,'\\  ',NULL),(17568,765014754001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',29.98,'buysia','marcj8412','m74joseph@hotmail.com','marc  joseph','14109 250th St<br>Fl 2','rosedale','NY','UNITED STATES','11422-2145','(347) 548-4624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 01:15:19',0,NULL,3,1,1,1,'\\  ','一共买了两张 还有一张爱丽丝梦游仙境 '),(17569,655415506013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','legendduke','fishingdownunder@bigpond.com','Zak Piletic','P O Box 450','Landsborough','Queensland','AUSTRALIA','4550','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 01:17:18',0,NULL,3,1,3,1,'RA117768523CN\r ',' GLOT001*4'),(17570,755185309007,170728921512,'New Jabra BT135 Bluetooth headset+AC power charger',1,'HSJA007',14.55,'au-buy','vchavkov','vchavkov@chavkov.com','Vladimir Chavkov','49 Goce Delchev str.','Asenovgrad','Plovdiv','BULGARIA','4230','00359 887 55 18 15','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-07 01:34:02',0,NULL,3,1,11,1,'\\ ','HSJA007\r欧标\r不挂号 '),(17571,597066295003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','stuartd1883','boss_stu@yahoo.co.uk','Stuart Diamond','43 Fernside Avenue, Mill Hill','London','London','UNITED KINGDOM','NW7 3AX','02082053335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 01:34:30',0,NULL,3,1,3,1,'RA117768660CN ','HSMO023\r英标'),(17572,655424792013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','sheena_1975','sheenarumbolt@hotmail.com','Sheena  Rumbolt','23 Hillview Road','Mary\'s Harbour, NL','NL','CANADA','A0K 3P0','(709) 921-6433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 01:49:48',0,NULL,3,1,3,1,'RA117768483CN ',' GPS0004'),(17573,808710102011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','grigsby_chief','hansepw@comcast.net','Phil Hansen','1205 Belford Ct','Washington','IL','UNITED STATES','61571','(309) 886-2404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 01:55:08',0,NULL,3,1,1,1,'\\  ',NULL),(17574,597077660003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',3.99,'cnfaner','deregil','deregil@carlosderegil.com','Carlos Deregil','10243 Garden State Dr','Las Vegas','NV','UNITED STATES','89135-1124','(310) 230-5497','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 02:17:29',0,NULL,3,1,1,1,'\\  ',''),(17575,751624098007,170730544640,'3DConnexion SpacePilot USB Intelligent 3D Motion Controller mouse',1,'MOLO010',219.99,'au-buy','wojtas0606','wojciechknurowski@gmail.com','Wojtek Knu','19/13-19 Bryant St.','Rockdale','New South Wales','AUSTRALIA','2216','0424066290','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 02:21:39',0,NULL,3,1,4,1,'YW867739693CN ',NULL),(17576,8881323228386269,111,'Jabra BT250 charger only',1,'',0,'eastar4','tracie22','tbeamish9@hotmail.com','Tracie Beamish','C/O Biffa Waste Services<br>Queen Street','Leeds','West Yorkshire','UNITED KINGDOM','LS26 8AL','01132867121',NULL,NULL,NULL,'2011-12-07 03:26:26',0,NULL,3,0,3,1,'\\ ',' 只发BT250的charger'),(17577,808747402011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',2,'LGGL002',65.98,'eastar4uk','robsoncedros','robsoncedro@msn.com','Robson Cedro Silva','Rua Realejo, 45<br>Jardim Recanto','São Paulo','São Paulo','BRAZIL','02877070','0151139842261','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 03:30:41',0,NULL,3,1,3,1,'RA117768815CN\r ','LGGL002\r\r '),(17578,597097560003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','blawson007','brucelawsoncpa@suddenlink.net','Bruce   Lawson','305 Dutch Rd','Charleston','WV','UNITED STATES','25302-4425','(304) 346-1400','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 03:38:08',0,NULL,3,1,1,1,'\\ ',NULL),(17579,8881323230703192,111,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',0,'eastar4uk','davidsuppree','suppreedrd@googlemail.com','David Suppree','14 Rodborough Road<br>Golders Green','London','London','UNITED KINGDOM','NW11 8RY','',NULL,NULL,NULL,'2011-12-07 04:05:03',0,NULL,3,1,3,1,'RA117768775CN\r ','RELO003\r补发的 '),(17580,808762505011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','henriquestreet','henriqueareiaspontes@yahoo.com.br','Henrique Areias Pontes','Rua Abigail Guimarães, N 35<br>AP 302, BL C, PT 1','São João de Meriti','Rio de Janeiro','BRAZIL','25540-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 04:23:19',0,NULL,3,1,3,1,'RA117768850CN\r ',' LGRM001'),(17581,808767109011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.99,'eastar4','sashamus83','bambieyez83@hotmail.com','Randi Jensen','Tranevænget 62, st. tv.','Brøndby','standard','DENMARK','2605','0045 42777181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 04:31:42',0,NULL,3,1,11,1,'\\ ',' 欧标'),(17582,655465702013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',8,'CASS001',66.32,'eastar4','kazee75','qazi.naveed@gmail.com','Naveed Qazi','2566 Hollington Cres.','Mississauga','ON','CANADA','L5K1E7','(647) 924-0031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 04:31:43',0,NULL,3,1,3,1,'RA117768761CN\r ',' CASS001'),(17583,8881323233325492,111,'1 x New IBM/thinkpad Atheros AR5BXB72 AR5008 PCI-E CARD   New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth ',1,'WLAT001+ANTY002',18.79,'cnfaner','m-griesser','m-griesser@gmx.net','Michael Griesser','Bei der Ringeljucht 11','Geseke','','GERMANY','','',NULL,NULL,NULL,'2011-12-07 04:48:45',0,NULL,3,1,3,1,'RA117766607CN\r ','SKu错误应为WLAT003+ANTY002   \r'),(17584,896220915012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','kwyjitim','adtt@gmx.net','Timothy Sass (IBM Deutschland GmbH)','Kleinfeldstrasse 4','Geisenbrunn','','GERMANY','82205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:23:04',0,NULL,3,1,17,0,NULL,NULL),(17585,597115665003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','deano570','dean.darmanin@ntlworld.com','dean darmanin carpin capers','53-54 barrack rd','northampton','northamptonshire','UNITED KINGDOM','nn1 3rl','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:06:58',0,NULL,3,1,3,1,'RA117765907CN ',' balck ver1 '),(17586,655480552013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','kwyjitim','adtt@gmx.net','Timothy Sass (IBM Deutschland GmbH)','Kleinfeldstrasse 4','Geisenbrunn','','GERMANY','82205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:25:58',0,NULL,3,1,17,0,NULL,' '),(17587,655481300013,230668626540,'3FT CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T Cable',2,'CASS001',16.58,'eastar4','kwyjitim','adtt@gmx.net','Timothy Sass (IBM Deutschland GmbH)','Kleinfeldstrasse 4','Geisenbrunn','','GERMANY','82205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:30:03',0,NULL,3,1,3,1,'RA117768727CN\r ',' CASS001  再发CASS002x2\rCASS003x2  一共6条  \r货已经 全退回'),(17588,896237686012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Rudy Anderson','21207 Avalon Blvd<br>Spc 129','Carson','CA','UNITED STATES','90745-6695','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 06:30:22',0,NULL,3,1,1,1,'\\ ',NULL),(17589,755269452007,170730545598,'NEW sealed Logitech Wireless Laser Mouse M505 plus unifying receiver',1,'MOLO008',35.5,'au-buy','ohnotthis','biznuz@adam.com.au','Paul Meier','159 Queen Street','Peterborough','South Australia','AUSTRALIA','5422','0886512398','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(17590,8881323240265308,111,'30 pcs of AT-210T and 15 pcs of AT-210TS ',1,'',340,'eastar4','microexp','alex@micro-exp.com','Micro Express International Inc.','921 E. Belleview Ave','Littleton','CO','UNITED STATES','80121','',NULL,NULL,NULL,'2011-12-07 06:44:25',0,NULL,3,1,4,1,'YW867739704CN ',NULL),(17591,808338311002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','winter888888','elam138@yahoo.ca','Eric Lam','8 Coral Springs Park  N.E','Calgary','AB','CANADA','T3J3R1','(403) 899-1288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:05:54',0,NULL,3,1,11,1,'\\ ','BR3D009 '),(17596,896279460012,220747230858,'New Motorola H800 Bluetooth Wireless Headset H 800',1,'HSMO016',14.9,'eastar4uk','uczab','fenihaim@bezeqint.net','fenichel haim','einstein 57','haifa','','ISRAEL','34602','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 09:09:58',0,NULL,3,1,11,1,'、 ','HSMO016 \r不挂号'),(17592,602533963004,140626376046,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',29.39,'cnfaner','stevy55','stevy55555@hotmail.com','TAIEB STEEVE','45 AVENUE DE GRAVELLE','CHARENTON LE PONT','Ile-de-France','FRANCE','94220','06.13.50.64.82','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:16:09',0,NULL,3,1,3,1,'RA117768713CN\r ','HSMO021\r欧标 '),(17593,655503220013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','vincent*vb','vbertonnaud@gmail.com','vincent bertonnaud','calle de los Olmos 133<br>urb. valdelagua','san agustin del guadalix','Madrid','SPAIN','28750','918489090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:42:27',0,NULL,3,1,3,1,'RA117768789CN\r ','MOSA004 '),(17594,896271474012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.3,'eastar4','isobel.p','isobelprestwich@hotmail.com','Prestwich Isobel','Daisy Cottage<br>Main Street Glapthorn','Peterborough','Cambridgeshire','UNITED KINGDOM','PE85BE','01832274358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 08:42:21',0,NULL,3,1,3,1,'RA117766553CN\r ','HSNO014 \r'),(17595,747596668008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT006',42.74,'au-buy','charles.w.gdds','charles.gdds@gmail.com','Charles Geddes','PO Box 576','Maffra','Victoria','AUSTRALIA','3860','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 09:00:19',0,NULL,3,1,3,1,'RA117766377CN\r ','GLOT006 '),(17597,655520641013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','raulbb75','raul.banares@gmail.com','Raúl Bañares Buendía','Bolivar 22 (A 2ºB)','Madrid','Madrid','SPAIN','28045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 09:15:33',0,NULL,3,1,3,1,'RA117766403CN ','MOSA004 '),(17598,808838316011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','vivanko7','tatjanakolb@list.ru','Tatjana Kolb','Buchenweg 9','Waldkraiburg','','GERMANY','84478','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 09:24:13',0,NULL,3,1,3,1,'RA117766482CN ','GLOT001*2 '),(17599,896315455012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','yayatwiste','yassine.jaa@gmail.com','Yassine JAA','2, Rue Paul Eluard BAT J N°7','Chalon sur Saône','Bourgogne','FRANCE','71100','06.09.42.14.91','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 10:57:08',0,NULL,3,1,11,1,'\\ ','BTAC2022\r不挂号 '),(17600,655558396013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','alohomora1981','alohomora@mail.ru','Dmitry Levin','Marshal Kazakov street, house 38/1, flat 17','Saint-Petersburg','RU','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:06:07',0,NULL,3,1,11,1,'','BTLE3001\r不挂号 '),(17601,597192944003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','andreasfalk','falk.andreas@yahoo.de','Andreas Falk','Hövischestraße 74','Dortmund','','GERMANY','44379','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:06:12',0,NULL,3,1,3,1,'RA117766363CN ','MOOE003 OEM'),(17602,602592364004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','dumpkofp','tech.tom@live.com','Tom Kerwin','349 Mulock Rd,','Rhodes Corner','NS','CANADA','B4V 5N4','(902) 543-8498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:11:29',0,NULL,3,1,3,1,'RA117766213CN\r ','HSPL013\r'),(17603,808890895011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','cryonru','cryonru@gmail.com','Pavel Sukharevich','Leninskii 79/2 386','Saint-Petersburg','Russia','RUSSIAN FEDERATION','198332','009046063165','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:04:13',0,NULL,3,1,11,1,'\\ ','OTCN002 \r不挂号'),(17604,896347159012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001*3',450.95,'eastar4uk','ohradni','electro.ebay@seznam.cz','Scorpion Elektro - Jiří Žalud','Ohradní 65','Praha 4 - Michle','Czech republic','CZECH REPUBLIC','14000','+420777139340','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 12:23:31',0,NULL,3,0,6,1,'EE636828855CN ','一共15副\r6幅 AG-S110原装\r3幅SSG-2100AB\r6幅AG-S110兼容'),(17605,808899768011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','Agustin Manuel Almagro Rojas','C/DE ARAGONITO 7A','MÁLAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 12:33:17',0,NULL,3,1,3,1,'RA117766479CN ','GLOT001*4 '),(17606,808037469011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','nusscreme007','boll.christian@yahoo.de','Christian Boll','Franz-Beer-Straße 18','Gengenbach','','GERMANY','77723','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,' '),(17607,808907277011,320791705383,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',37.99,'eastar4uk','obdankenobe','dan@metrow.co.uk','DAN REDFEARN','METROW FOODS LTD<br>AIRBORNE CLOSE','LEIGH ON SEA','ESSEX','UNITED KINGDOM','SS9 4EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 12:53:12',0,NULL,3,1,3,1,'RA117766346CN\r ','GPS0006 '),(17608,896359249012,220502387239,'2.0 Bluetooth Module + Cable for acer aspire D150',1,'BTAC2018',9.88,'eastar4','tazewellcook','harrison.cook@gmail.com','Harrison Cook','7857 Danby Dr','Annandale','VA','UNITED STATES','22003-5316','(703) 401-2382','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 12:53:40',0,NULL,3,1,1,1,'\\  ',NULL),(17609,808908877011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','claw6848','clawrence@marshall.edu','Carol Lawrence','#1 Heritage Drive','Huntington','WV','UNITED STATES','25704','(304) 429-2866','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 12:54:45',0,NULL,3,1,1,1,'\\  ',NULL),(17610,597104340003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','israelreyrey85','israelrzc@yahoo.com','israel orozco','1822 E Irvington Ave','South bend','IN','UNITED STATES','46614-1654','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 12:55:32',0,NULL,3,1,1,1,'\\  ',' OEM'),(17611,807554024011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'eastar4','tharuninda','gayaniwelagedara@yahoo.com','Gihan tharuninda','No35,Dodamwela Passage,<br>Asgiriya,','Kandy,','central province','SRI LANKA','00000','+940777669147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:58:05',0,NULL,3,1,11,1,'、 ','HSNO003 \r不挂号'),(17612,602621173004,140626375035,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',14.1,'cnfaner','zacqxb2r','ahmadrozaq@gmail.com','Romy Putra','Jl. Balai Baru No.4 (depan SMP 18) Samping Toko 2 Putri Gorden<br>Kec. Kuranji Balai Baru','Padang','Sumatera Barat','INDONESIA','25158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 14:01:29',0,NULL,3,1,3,1,'RA117766315CN\r ','OTCN005\r白色的\rplease put the phone number 085765218777 '),(17613,808955957011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',5,'HSJA002',99.95,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 14:50:42',0,NULL,3,1,1,1,'\\  ',NULL),(17614,896418093012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','pkg4me','thefatguy@cox.net','P Grady','P. O. Box 6650','Oceanside','CA','UNITED STATES','92052-6650','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 15:08:51',0,NULL,3,1,1,1,'\\  ',NULL),(17615,808965972011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ixia-2008','jclaude.girard@gmail.com','Jean-Claude GIRARD','res le vieux pont avenue du mont aigoual<br>log 20 bat B','ganges','Languedoc-Roussillon','FRANCE','34190','0661894736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 15:14:15',0,NULL,3,1,3,1,'RA117766289CN\r ','MOAP001 '),(17616,655618913013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',39.76,'eastar4','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 15:37:27',0,NULL,3,1,3,1,'RA117766275CN\r ','WLAP008 '),(17617,755444822007,170728921582,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA004',37.96,'au-buy','sneak613','bobby_murphy2013@yahoo.com','bobby Murphy','3402 Evans St<br>Apt C','greenville','NC','UNITED STATES','27834-4608','(252) 916-0038','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-07 16:17:14',0,NULL,3,1,1,1,'\\  ','黑色的 '),(17618,655530114013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','bchaiwat','bchaiwat@hotmail.com','chaiwat buachama','75 Seri-Thai Rd, Kannayao','Kannayao','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:22:13',0,NULL,3,1,11,1,'\\ ','CACN004\r不挂号 '),(17619,755387905007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','norway_shopping','post@privatetterforskeren.no','Ronnie Osmundsen','Grundetjern','VATNESTRØM','VATNESTRØM','NORWAY','4730','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-07 16:34:48',0,NULL,3,1,11,1,'\\ ','RCLO007+POLO001+RCLO008*4不挂号 '),(17620,896465587012,220449147548,'Samsung R18 R20 R25 Bluetooth Module 2.0 EDR+cable',1,'BTSA2003',9.88,'eastar4','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 16:40:21',0,NULL,3,1,1,1,'\\  ',NULL),(17621,809010548011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','steph32808','stephaniecopeland@yahoo.com','Stephanie Smith','95 Pointe North Dr','Cartersville','GA','UNITED STATES','30120-7914','(770) 548-8780','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 16:50:32',0,NULL,3,1,1,1,'\\ ',NULL),(17622,809021729011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','4furyblaze4','furyblaze@earthlink.net','Brandon Wilson','13048 235th St','Rosedale','NY','UNITED STATES','11422-1216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 17:09:50',0,NULL,3,1,1,1,'\\  ',NULL),(17623,896497113012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','faisalchangezi82','faisalchangezi@hotmail.com','farhan changezi','hazara mughal housing society 4b cantt','Quetta','pakistan balochistan','PAKISTAN','87300','00923218009181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 17:33:57',0,NULL,3,1,3,1,'RA117766332CN\r ','HSPL013\r巴基斯坦 '),(17624,597308742003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','joseadilson11','jadilson@ig.com.br','JOSE ADILSON DOS SANTOS','RUA ADAUTO BARBOSA DA COSTA, 426<br>BAIRRO: BUGIO','ARACAJU','SERGIPE','BRAZIL','49090730','(55) 79 3252-1463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 18:18:52',0,NULL,3,1,3,1,'RA117766258CN ','LGRM001 '),(17625,896526621012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','miomaiy','mio_maiy@yahoo.com','Anastasia Rybalkina','Kalinina<br>Str.37,16','Sochi','Krasnodar region','RUSSIAN FEDERATION','354348','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 18:27:07',0,NULL,3,1,11,1,'\\ ','UM00008\r24k多彩伞 '),(17626,653255649013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','bobbyjc1984','bobbyjoecool@gmail.com','Robert Breutzmann','104 Locust St<br>Apt 24','Waverly','IA','UNITED STATES','50677-9621','(319) 939-3687','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 18:43:48',0,NULL,3,1,3,1,'RA117766496CN ','GLOT001*4 '),(17627,597327792003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','landav','dlangton@gmail.com','David Langton','16 Pitman Rd','Marblehead','MA','UNITED STATES','01945-1434','(781) 639-0559','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 19:00:54',0,NULL,3,1,1,1,'\\  ',NULL),(17628,809123210011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','leeuwerik12','leeuwtje12@gmail.com','Patrick Prins','Leeuwerikenstraat 12','GOES','','NETHERLANDS','4461RD','0611270153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 19:48:44',0,NULL,3,1,3,1,'RA117766329CN ','GPS0007 '),(17629,809122619011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',2,'HBPH003',39,'eastar4','carolnicholls','cnicholls1@cox.net','Carol Nicholls','43137 N National Trl','Anthem','AZ','UNITED STATES','85086-8059','(602) 321-5606','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 19:51:29',0,NULL,3,1,1,1,'\\  ',NULL),(17630,896600648012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','janne.paavilainen','janne.paavilainen@luukku.com','Janne Paavilainen','Perhekunnantie 14 - 20 D 34','HELSINKI','FINLAND','FINLAND','00430','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 19:59:03',0,NULL,3,1,3,1,'RA117766160CN ','HSPL013\r欧标 '),(17631,896648000012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',2,'WLIN016',42.18,'eastar4','jwcox45','jwcox45@hotmail.com','Jason Cox','42 Outervale Pl','The Woodlands','TX','UNITED STATES','77381-4302','(281) 719-8955','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 21:20:19',0,NULL,3,1,1,1,'\\  ',NULL),(17632,809188351011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',4.98,'eastar4uk','eamonraleigh','eamonraleigh@hotmail.com','Eamon Raleigh','Tramore Garda Station','Tramore','Waterford','IRELAND','Co','051391620','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 21:22:52',0,NULL,3,1,3,1,'RA117766244CN\r ','BAIN001 '),(17633,809178715011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','yagolin','tonychups@msn.com','tony sanchez marina','C/ el valledal','Villamayor-piloña','Asturias','SPAIN','33583','617327811','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 21:31:21',0,NULL,3,1,3,1,'RA117766350CN ','LGGL002 '),(17634,602800898004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','allgodsgrace','peasnqiet@aol.com','sam micalizzi','77 Ridgedale Cir','Rochester','NY','UNITED STATES','14616-5301','(518) 221-2168','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 21:43:45',0,NULL,3,1,1,1,'\\  ',NULL),(17635,896683834012,220815931195,'New Logitech/Asus Limit MX518 MX 518 Gaming mouse USB',1,'MOLO004',26.5,'eastar4uk','pfirsicht','speedsound@gmx.net','Dieter Halicska','Kälblesrainweg 57','Aalen','','GERMANY','73430','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 21:54:11',0,NULL,3,1,3,1,'RA117766394CN ','MOLO004 '),(17636,809210274011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',71.98,'eastar4uk','bluecolonialboy','james.drayton@btinternet.com','James H Drayton','34 Hendrick Avenue','London','London','UNITED KINGDOM','SW12 8TL','07887702224','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 21:57:59',0,NULL,3,1,3,1,'RA117766448CN ','GLSG001 '),(17637,653330857013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','steficacvek','stefica_cvek@yahoo.com','Amra Serdarevic','12614 N 38th Dr','Phoenix','AZ','UNITED STATES','85029-2007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 22:01:24',0,NULL,3,1,1,1,'\\  ',NULL),(17638,755672096007,170734557522,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','maryphuongphuong','maryphuong@yahoo.com','Trang Phan','C/o Fluffy Spider Technology<br>Suite 87, 330 Wattle Street, Ultimo','Sydney','New South Wales','AUSTRALIA','2007','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 22:03:42',0,NULL,8,1,17,0,NULL,NULL),(17639,653309607013,230614815846,'New SAMSUNG WMN2000B ULTRA SLIM WALL MOUNT  TV 46\"-55\"',1,'MOSA005',165.9,'eastar4','jasonsellsthings','jason.penning@gmail.com','Jason Penning','4 Studebaker','Irvine','CA','UNITED STATES','92618-2012','(949) 595-5371','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 22:03:54',0,NULL,3,1,1,1,'\\  ',NULL),(17640,896676886012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',4,'WLIN016',84.36,'eastar4','pezui','sicksickdream@hotmail.com','tim stone','2111 NE 25th AVE<br># JF3-3-J6','Hillsboro','OR','UNITED STATES','97124-5961','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 21:43:43',0,NULL,3,1,1,1,'\\  ',NULL),(17641,896694008012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',2,'HSNO019+CCNO001',51.98,'eastar4uk','brauxer','brauxer@hotmail.fr','BRAUX ERIC','41 GRANDE RUE','BRAGELOGNE','AUBE','FRANCE','10340','03 25 29 10 13','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 22:12:47',0,NULL,3,1,3,1,'RA117766227CN\r ','HSNO019+CCNO001\r'),(17642,755680537007,170734557522,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','maryphuongphuong','maryphuong@yahoo.com','Phuong Van','18 Hunt Court','Collingwood Park','Queensland','AUSTRALIA','4301','610733890055','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 22:19:04',0,NULL,3,1,3,1,'RA117766434CN\r ',' UM00040\r一共两把爱雨透明伞，买了两次'),(17643,755688548007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','amoeb4','yuliusrivan@gmail.com','yulius rivan','unit 6/37-39 Rosewood Ave','Prestons','New South Wales','AUSTRALIA','2170','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(17644,809234585011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','akartman','sun_28@hotmail.com','Angela Stauffacher','18100 Cty C','Mineral Point','WI','UNITED STATES','53565','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 22:42:58',0,NULL,3,1,1,1,'\\  ',NULL),(17645,896714162012,220769088331,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',1,'MOVI002',107.99,'eastar4','kalouzz','sevconcours@free.fr','pascal zuccollo','16C ch Belloc','lapeyrouse','Midi-Pyrénées','FRANCE','31180','05.61.35.70.50','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 22:48:40',0,NULL,3,1,3,1,'RA117766451CN ','GLSG001*2'),(17646,894713340012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','melisalang','mlang@qualcomm.com','Melisa Lang','453 N Hunter St','Ramona','CA','UNITED STATES','92065-1766','(619) 990-2605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 23:00:34',0,NULL,3,1,1,1,'\\  ',NULL),(17647,597439277003,130522141151,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.4,'cnfaner','sambo_sun','testit@me.com','samir el borno','Fleischerstr. 6','münchen','','GERMANY','80337','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 23:27:11',0,NULL,3,1,3,1,'RA117766385CN\r ','UDAP001 '),(17648,896734878012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Exodus Cry','4429 E 139TH ST','Grandview','MO','UNITED STATES','64030-2878','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 23:31:48',0,NULL,3,1,1,1,'\\  ',NULL),(17649,896743564012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','piciaczarniak82','picia_czarniak@tlen.pl','Piotr Stefaniak','55 Sleaford Road','Newark-On-Trent','Nottinghamshire','UNITED KINGDOM','NG241NF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 23:51:39',0,NULL,3,1,3,1,'RA117766301CN\r ','HSPL013\r英标 '),(17650,809272599011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',139.98,'eastar4','drox6','sandrox2@yahoo.com.br','alexander fernandes','Rua da Lagosta, 150 apto.1002<br>Ponta Negra','Natal','Rio Grande do Norte','BRAZIL','59090500','(55)849640-7803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 00:16:07',0,NULL,3,1,3,1,'RA117766425CN ','OTSO004 '),(17651,602858099004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','amiayyam','amiay_yam@walla.co.il','amichai yamin','Dizengoff 3 ,Apartment 2','Netanya','','ISRAEL','42405','0547787890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 00:54:13',0,NULL,3,1,17,0,NULL,'BALO007 '),(17652,597461675003,130498755181,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.89,'cnfaner','amiayyam','amiay_yam@walla.co.il','amichai yamin','Dizengoff 3 ,Apartment 2','Netanya','','ISRAEL','42405','0547787890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 00:58:56',0,NULL,3,1,3,1,'RA117766261CN\r ','POLO001 \rNew Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh\rBALO007\r1个\r'),(17653,597462611003,130592183438,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','hidesser','kazseri@yahoo.fr','Hidekazu Serizawa','12-15-305 Nishisumiyoshi','Tokorozawa','Saitama','JAPAN','3591126','09022088871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 01:04:08',0,NULL,3,1,17,0,NULL,'HBPH001 '),(17654,892888011012,220815928685,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse',1,'MOLO003',22.9,'eastar4uk','kaname--nakajima','kyna.riverdog@gmail.com','Nina Stannek','Reinersstr. 06','Recklinghausen, NRW','','GERMANY','45665','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 01:13:08',0,NULL,3,1,11,1,'\\ ','MOLO003 \r不挂号'),(17655,602863287004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',2,'HBPH003',37,'cnfaner','hidesser','kazseri@yahoo.fr','Hidekazu Serizawa','12-15-305 Nishisumiyoshi','Tokorozawa','Saitama','JAPAN','3591126','09022088871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 01:16:41',0,NULL,3,1,3,1,'RA117766292CN ','HBPH003 \r2个\rNew Philips Sonicare Flexcare Toothbrush Handle HX6950\rHBPH001 \r1个\r'),(17656,809294663011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','laihjkim','laihjkim@netscape.net','Kelin Lai','No 3~2, Lane 91, Ying-Tao Rd,','Ying Ko District,','New Taipei City,','TAIWAN','239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 01:23:13',0,NULL,3,1,14,1,'301208196938 ','賴怡如\r台北縣新北市鶯歌區鶯桃路91巷3~2號, 239 , 台灣\r02-26701695'),(17657,808813190002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','lovelygoldie','joanette_pinder@hotmail.com','Joanette Pinder','312 Northlake Dr<br>C/O Edward Hinckley Apt 201','North Palm Beach','FL','UNITED STATES','33408-5241','561 718 9051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 01:34:17',0,NULL,3,1,4,1,'YW867738610CN',NULL),(17658,602872346004,140631692992,'New Genuine Motorola HS850 Bluetooth Headset  track#',2,'HSMO019',35.98,'cnfaner','bikeriderfootball','rlang13362@aol.com','Richard Langlois','2539 Stern Dr. S','Atlantic Beach','FL','UNITED STATES','32233','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 01:58:00',0,NULL,3,1,1,1,'\\  ',NULL),(17659,597477170003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','greggbd','greggbd@yahoo.com','Bryan Gregg','659 227th Street','Pasadena','MD','UNITED STATES','21122','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 02:08:34',0,NULL,3,1,1,1,'\\  ',NULL),(17664,602889730004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','jowmysteri','jowmysteri@yahoo.com','Brandon L. Hunter','7401 Blackmon Rd<br>Apt 5204','Columbus','GA','UNITED STATES','31909-7580','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 03:11:28',0,NULL,3,1,1,1,'\\  ',NULL),(17660,655873075013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','ronaldagould','labsrus@dogbreath.us','Ronald Gould','3041 Kevlyn Ct','Safety Harbor','FL','UNITED STATES','34695-5215','(727) 799-9441','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 02:45:56',0,NULL,3,1,3,1,'RA117766536CN\r ','GLOT001*4 \r兼容眼镜 通用型'),(17661,896813617012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',2,'WLHP002',35,'eastar4','friceberg','ficeberg@yahoo.com','Frank Iceberg','3430 Sumac Ct<br>Apt 304','Jackson','MI','UNITED STATES','49202-1277','(517) 783-5016','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 02:54:51',0,NULL,3,1,1,1,'\\  ',NULL),(17662,808841667002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','autoirish13','bailey.brian.r@gmail.com','Brian R. Bailey','455 Wrigley Blvd','Cochranville','PA','UNITED STATES','19330-9411','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 03:01:17',0,NULL,3,1,1,1,'\\  ',NULL),(17663,602887825004,140519326541,'New Sony Ericsson HBH-PV710 BLUETOOTH HEADSET track#',1,'HSSE008',38.99,'cnfaner','cigaras','chiosas@yahoo.com','Gitenis Salyga','7855 Deerfield Ave','Woodridge','IL','UNITED STATES','60517','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 03:03:52',0,NULL,3,1,1,1,'\\  ',NULL),(17665,655880208013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','kennedytham78','kennedytham@yahoo.com','Tham Choon Keat','Block N5-1-12, Nuri Court, Jalan Pandan Indah 6/12,<br>Pandan Indah','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','55100','0123693606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 03:18:39',0,NULL,3,1,11,1,'\\ ','WLIN014\r不挂号 '),(17666,8881323315493799,111,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#    Zoom    EnlargeSell one like this	New Plantronics Explorer 330 BLUETOOTH HEADSET',2,'HSPL005',0,'cnfaner','dimitris3615','mitritsakisd@gmail.com','Dimitris Mitritsakis','Sof. Venizelou 4','Hania-Souda','Crete','GREECE','73200','00302821076278',NULL,NULL,NULL,'2011-12-08 03:38:13',0,NULL,3,1,3,1,'RA117766519CN\r ','HSPL005\r欧标\r补发 '),(17667,597499093003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','aquamike7','mikelap@cdw.com','Michael Lapetino','19453 Victorian Dr','Mokena','IL','UNITED STATES','60448-9297','(847) 668-9674','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 03:43:42',0,NULL,3,1,1,1,'\\  ',NULL),(17668,896837950012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','ishyvish','wsherman@hvc.rr.com','William Sherman','9 Lakeside Dr','New Windsor','NY','UNITED STATES','12553-5934','(845) 926-0744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 04:07:12',0,NULL,3,1,1,1,'\\  ',NULL),(17669,806431439002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','midnight2u','c-lo2@msn.com','Cory Irons','PSC 76 Box 7225','APO','AP','AA','96319','(011) 819-0299 ext.: 05609','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 04:13:50',0,NULL,3,1,1,1,'\\  ',NULL),(17670,602905007004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','sramgr','bdkanow@bdkservices.com','Barry Kanow','12062 Long Lake Dr','Owings Mills','MD','UNITED STATES','21117','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 04:25:13',0,NULL,5,1,18,1,NULL,'客户要求比较高，已发信询问'),(17671,748088837008,180755478464,'Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO014',27.59,'au-buy','azngixxer09','azngixxer@yahoo.com','Charles Chantawansri','16058 Parthenia St','North Hills','CA','UNITED STATES','91343-4806','(818) 970-2120','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 04:45:47',0,NULL,3,1,1,1,'、 ',NULL),(17672,759677442001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',11.99,'buysia','ahmad19730806','ahmad1973@walla.com','ahmad jabaren','en-jrar b.o.x 6077 mekod 30010','umm el fahim','israel','ISRAEL','30010','0523-377331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 05:04:33',0,NULL,3,1,11,1,'\\ ','HSJB001 \r不挂号\r'),(17673,597519308003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','migunovn','migunov.n@gmail.com','Nikita Migunov','4a Guryeva str., apt. 21','Ramenskoye','Russia, Moscow reg','RUSSIAN FEDERATION','140103','8-926-65-65-651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 05:40:38',0,NULL,3,1,3,1,'RA117766417CN\r ','LGRM001 '),(17674,755825720007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','dantesparda2000','spardaforever@yahoo.com','Mun Hon Cheong','3/1,Boronia St,Kensington','Sydney','New South Wales','AUSTRALIA','2033','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-08 06:06:19',0,NULL,3,1,11,1,'\\ ','RCLO007 \r不挂号'),(17675,8881323327200994,111,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',0,'eastar4','mkmisp','kurten@matrix.com.br','Marcos K Michels','Senador Nereu Ramos street, 1445 room 05','Braco do Norte','Santa Catarina','BRAZIL','88750-000','(48) 9987-0181',NULL,NULL,NULL,'2011-12-08 06:53:20',0,NULL,3,1,11,1,'、 ','HSJA002 \r不挂号\r补发'),(17676,809389463011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','scemozkan','scemozkan@gmail.com','Cem OZKAN','Fulya Mh. Yavuz Sk. Goncagul Apt.<br>No:6/2 Sisli','Istanbul','Sisli','TURKEY','34394','00905324859500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 07:07:23',0,NULL,3,1,11,1,' \\','MOAP001\r不挂号 '),(17677,896889246012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','tason30','tason@bigmir.net','VITALII ONYSCHENKO','61a/256, ul. Bal\'zaka Onore','Kiev','','UKRAINE','02232','+380634669576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 07:44:21',0,NULL,3,1,11,1,'\\ ','ANTY001\r不挂号 '),(17678,597539902003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',18.99,'cnfaner','xooxle','erindazil@gmail.com','Erin McGowan','Altenbergstr. 126','Bern','','SWITZERLAND','3013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 08:03:28',0,NULL,3,1,3,1,'RA117766540CN\r ','HSUE002\r欧标 '),(17679,597540466003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','harsham1212','harsham121@yahoo.com','Harsha Meemaduma','No. 8A<br>Rahula Cross Road','Matara','Southern Province','SRI LANKA','81000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 08:05:40',0,NULL,3,1,3,1,'RA117766465CN\r ','HSNO019 '),(17680,809405851011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','ookiininjin','jrx_2000@hotmail.com','Jeremy Christie','6769 Chateau Crt.','Delta','BC','CANADA','V4E3M7','(604) 364-2207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 08:17:34',0,NULL,3,1,11,1,'\\ ','WLIN011\r不挂号 '),(17681,8881323334889905,111,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',0,'eastar4uk','markmurray43','markadundee@aol.com','mark murray','6 Gaitside crescent<br>Garthdee','Aberdeen','Aberdeen City','UNITED KINGDOM','ab107eg','',NULL,NULL,NULL,'2011-12-08 09:01:29',0,NULL,3,1,3,1,'RA117766598CN\r ','GLSG001\r补货 '),(17682,896917198012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Pamela Kaylor','1960 S 1200 E','Bliss','ID','UNITED STATES','83314-5044','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 09:29:03',0,NULL,3,1,1,1,'\\ ',NULL),(17683,655950030013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','kumura-yoshikatsu98','kumura99@gmail.com','Yoshikatsu Kumura','2-5-21<br>Nishi-ku Gakuen-higashi-machi','Kobe','Hyogo','JAPAN','6512102','(078)795-3410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 09:39:39',0,NULL,3,1,11,1,'\\ ','BTDE2100\r不挂号 '),(17684,808938641002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','necaxin66','jesusmj66@gmail.com','jose munoz','12156 newgard ave','sylmar','CA','UNITED STATES','91342-5268','(818) 233-9825','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 09:49:53',0,NULL,3,1,1,1,'\\ ',NULL),(17685,896927774012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','321expressllc','andersonmaurice.ma@gmail.com','Mandy Sa','401 Broadway<br>Ste 1620','New York','NY','UNITED STATES','10013-3020','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 10:03:07',0,NULL,3,1,1,1,'\\  ',NULL),(17686,809441508011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','vxinice','samuellibert@optusnet.com.au','Samuel','29 Gat cum Crt<br>Noble Park','melbourne','Victoria','AUSTRALIA','3174','0401514589','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 10:28:09',0,NULL,3,1,11,1,'\\ ','HSUE001\r不挂号 '),(17687,597571934003,130598387349,'3 pairs of New Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',158.99,'cnfaner','katarzyna2769','kasiawolska_24@hotmail.com','Katarzyna Chodyka','Partyzantów 1','Międzyrzec Podlaski','lubelskie','POLAND','21560','83 3712218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 11:03:38',0,NULL,3,1,3,1,'RA117765028CN\r ','GLSG001*3 '),(17688,755893200007,170737835667,'2 pairs LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'au-buy','shark1michael','michaelagius1@hotmail.com','Michael Agius','6 Giles Street','Coobowie','South Australia','AUSTRALIA','5583','0411095921','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-08 10:52:41',0,NULL,3,1,3,1,'RA117766981CN\r ','LGGL002*2 '),(17689,896957046012,220858471777,'New PLANTRONICS EXPLORER 220 Bluetooth headset E220',1,'HSPL001',9.99,'eastar4uk','333-interserb-333','interserb@gmx.net','Monika Prendaj','Blodigstr 28a','München','','GERMANY','80933','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 11:29:31',0,NULL,3,1,11,1,'\\ ','HSPL001\r欧标\r不挂号 '),(17690,809473651011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','legendduke','fishingdownunder@bigpond.com','Zak Piletic','P O Box 450','Landsborough','Queensland','AUSTRALIA','4550','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 12:08:17',0,NULL,3,1,3,1,'RA117766791CN\r ','GLOT001*2 '),(17691,597591125003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','browre01','hotbutta49@yahoo.com','Robert Brown','1016 Pointe Center Cv','Fort Wayne','IN','UNITED STATES','46819-1464','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 12:18:59',0,NULL,3,1,1,1,'\\  ',NULL),(17692,809482215011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','lee915016','lee.charlton@c-pac.net','Lee Charlton','3 Gordon Tce','Stanley','Durham','UNITED KINGDOM','DH90LF','01207235245','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 12:33:53',0,NULL,3,1,3,1,'RA117766876CN\r ','OTHP005 '),(17693,655991858013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','beasgre','ki_fire@yahoo.com','Gregory Beasley','312 w manning st','chesnee','SC','UNITED STATES','29323-1416','(864) 804-1309','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 12:41:57',0,NULL,3,1,1,1,'\\  ',NULL),(17694,809486525011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','stupink','stupink66@aol.com','Quality Metal Works, Inc.','385 Anchor Rd<br>Attn: Stuart Pinkerton','Elizabethtown','PA','UNITED STATES','17022-2808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 12:44:53',0,NULL,3,1,1,1,'\\  ',NULL),(17695,748209224008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT006',42.74,'au-buy','rod.03','r.carlos@cegetel.net','I-T-S Mr RODRIGUES','rue du bois des jarraux','st yorre','Auvergne','FRANCE','03270','0470587708','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 12:51:16',0,NULL,3,1,3,1,'RA117766774CN\r ','GLOT006 '),(17696,755419574007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',2,'SCLO001',36.8,'au-buy','paqf02','francois.paquet@riotinto.com','Francois Paquet','600 rue des Dahlias','Alma','QC','CANADA','G8C 0B5','(418) 669-1012','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 13:02:08',0,NULL,3,1,11,1,'\\ ','SCLO001\r不挂号 '),(17697,603004161004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','damiank89','dkaliroff@gmail.com','Damian Kaliroff','Yitzhak Velber 33<br>יצחק ולבר 33','Beer Sheba','באר שבע','ISRAEL','85697','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 13:29:50',0,NULL,3,1,3,1,'RA117766947CN\r ','RELO003 '),(17698,897022161012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',5,'OTCR001',138.4,'eastar4','paschoarelli','ruben@estratege.com.br','Ruben Paschoarelli','av. Analice sakatauskas, 204<br>Bela Vista','Osasco','São Paulo','BRAZIL','06060-000','551136535126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 14:22:54',0,NULL,3,1,3,1,'RA117766916CN\r ','OTCR001 '),(17699,802780329011,320787341155,'New Jabra JX10 II 2 Wireless Bluetooth headset black',1,'HSJA004',12.99,'eastar4uk','husky02150','eduardoorellana30@yahoo.com','NELSON ALVAREZ','332 Washington Ave<br># 2','chelsea','MA','UNITED STATES','02150-3642','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 14:41:26',0,NULL,3,1,1,1,'\\  ','黑色的 \r货被原件退回来了'),(17700,597629858003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','insong94','bongjulee@empal.com','Bong-Ju Lee','113-704 Thesharp CentumPark 1 Cha Apt.,<br>Jaesong 1-dong ,Haeundae-gu,','Busan','','KOREA,REPUBLIC OF','612-712','82-11-831-9461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 14:50:08',0,NULL,3,1,3,1,'RA117766955CN\r ','WLAT003 '),(17701,897047962012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','maximilli0n58','taxi_4u56@yahoo.co.uk','Robert Walters','25 Morgan Close<br>Penllergaer','Swansea','Swansea','UNITED KINGDOM','SA4 9BF','01792898435','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 15:12:10',0,NULL,3,1,3,1,'RA117766788CN\r ','HSSA002 \r英标\r black version'),(17702,809559273011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','tomr208','p.reid911@btinternet.com','Thomas Reid','8 Park Highatt Drive<br>Shipdham','Thetford','Norfolk','UNITED KINGDOM','IP25 7LG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 15:47:01',0,NULL,3,1,3,1,'RA117766765CN\r ','GLOT001 '),(17703,602553671004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','cybercho','avgustin@gmail.com','Avgustin Dimitrov Vasilev','zh.k. Chaika bl. 192, ent. A, fl. 2, ap. 6','Varna','','BULGARIA','9005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 16:08:50',0,NULL,3,1,3,1,'RA117766862CN\r ','WLDE002 '),(17704,603056136004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','bigdubpro','dubrx1@gmail.com','Brion La Belle','15651 MOSHER AVE','TUSTIN','CA','UNITED STATES','92780-6426','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 16:31:18',0,NULL,3,1,1,1,'\\  ',NULL),(17705,765846269001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','freddy5180','fjsongman@bellsouth.net','freddy butson','3812 Flewellyn Rd','springfield','TN','UNITED STATES','37172-5556','(615) 202-5595','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 16:54:36',0,NULL,3,1,1,1,'\\  ',NULL),(17706,597673662003,130592183438,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','tucker.909','cmcb797@aol.com','Carolyn Biggle','5545 La Deney St','Montclair','CA','UNITED STATES','91763-2029','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 17:12:42',0,NULL,3,1,1,1,'\\  ',NULL),(17707,597684235003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','stefan70','stefan_70@abv.bg','Stefan Srefanov','9575 Maple Dr<br>Apt 2N','Rosemont','IL','UNITED STATES','60018-5041','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 17:38:29',0,NULL,3,1,1,1,'\\  ',NULL),(17708,897145986012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',23.74,'eastar4','irka17.03.1983','alzira77@bk.ru','Ирина Прокопенко','352800, Краснодарский край, г. Туапсе, ул. Ленина, д. 6, кв. 50','Туапсе','','RUSSIAN FEDERATION','352800','8-918-414-60-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 18:11:43',0,NULL,3,1,11,1,'\\ ','UM00006 黑色\r不挂号'),(17709,897146421012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','beergeordie_phil','phil_murray77@hotmail.com','phil murray','burton and wilson, units 4 and 5<br>clifton street, stonefield park','lincoln','Lincolnshire','UNITED KINGDOM','ln5 8lq','01522546119','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 18:14:00',0,NULL,3,1,3,1,'RA117766814CN\r ','LGAD001 '),(17710,656105258013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',1,'BAZA001',54.99,'eastar4','joaoricardojr','joaoricardo@me.com','JOAO RICARDO SOCCA JUNIOR','RUA CUNHAMBEBE 560 APTO 26<br>CENTRO','UBATUBA','SAO PAULO','BRAZIL','11680-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 18:21:09',0,NULL,3,1,3,1,'RA117766828CN\r ','BAZA001 '),(17711,747799149008,180767057234,'Original Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',7.8,'au-buy','oenderillo','hennweb@yahoo.com','Henning Weber','Av. Rancho El Gallego 5<br>Col. Prado Coapa 1ra Seccion','Mexico','DF','MEXICO','14350','(5255) 56846956','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 18:25:55',0,NULL,3,1,11,1,'\\ ','SCLO003\r不挂号 '),(17712,597704791003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','rlateef','rezwan_lateef@nexxsystems.com','Rezwan Lateef','8 Bramble Hill Rd','Methuen','MA','UNITED STATES','01844-2690','(978) 258-3433','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-08 18:33:05',0,NULL,3,1,1,1,'\\  ',NULL),(17713,756081806007,170734557522,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','javielka.p','javielka@live.com','Javielka Polanco','55 Flora St','Providence','RI','UNITED STATES','02904-2428','(401) 648-5520','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 18:33:11',0,NULL,3,1,3,1,'RA117765102CN\r ','UM00040\r'),(17714,897181065012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','pwal2556','walkersclean@fsmail.net','Paul walker','26 sinnington end','colchester','Essex','UNITED KINGDOM','co4 9re','07950199672','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 19:05:58',0,NULL,3,1,3,1,'RA117766880CN\r ','LGAD001 '),(17715,897184098012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.88,'eastar4','nikolavridni','nikica.kocijan@gmail.com','nikica kocijan','jadranska 6','Njivice','Croatia','CROATIA','51512','00385922923808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 19:09:09',0,NULL,3,1,11,1,'\\ ','BTAC2023\r不挂号 '),(17716,809690374011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','rachelrigg4444','rachelrigg4@yahoo.co.uk','Rachel Rigg','10 Kensington Road','Lancaster','Lancashire','UNITED KINGDOM','LA1 4TL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 19:40:34',0,NULL,3,1,3,1,'RA117766859CN\r ','MOAP001 '),(17717,765944478001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','daddy2508','manny2307@hotmail.com','victor rodriguez','50 desrosiers st','springfield','MA','UNITED STATES','01104-2320','(413) 885-6589','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 19:46:14',0,NULL,3,1,1,1,'\\  ',NULL),(17718,656154987013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','julobrixo','usatyjulko@orangemail.sk','julius dobrota','s. moysesa 66/1','ziar nad hronom','','SLOVAK REPUBLIC','96501','+421904354408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 20:03:23',0,NULL,3,1,3,1,'RA117766845CN\r ','GLOT001*3\r申报为gift\r申报价为30USD '),(17719,809719977011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','capt.homie','homieal@hotmail.com','ALFRED PERALTA','13895 marvin mckoin rd','wilmot','AR','UNITED STATES','71676-9450','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 20:22:41',0,NULL,3,1,1,1,'\\  ',NULL),(17720,809215112002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','kwil6418','kwilkes@jarotrans.com','KIM WILKES','1635 State Rd NW','WARREN','OH','UNITED STATES','44481-9476','(330) 847-9956','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 20:23:30',0,NULL,3,1,1,1,'\\  ',NULL),(17721,897242339012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',63.99,'eastar4uk','gsanmiguel','guillermo_san_miguel@yahoo.es','Guillermo San Miguel','Mendieta Zeharbide 16 1º','Sopelana','Bizkaia','SPAIN','48600','646474438','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 20:28:08',0,NULL,3,1,3,1,'RA117766920CN\r ','LGGL002*2 '),(17722,748443912008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','phantom-ka','phantom@nflame.net','Arcadi Boldescu','Decebal str., 98-1','Balti','Balti region','MOLDOVA, REPUBLIC OF','MD-3101','+37369138765','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 20:53:07',0,NULL,3,1,11,1,'\\ ','BALO009\r不挂号 '),(17723,809771648011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','yoavgeva','yoavg72@014.net.il','Yoav Geva','Got Levin 8','Haifa','Israel','ISRAEL','32922','972-4-8371627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 21:46:26',0,NULL,3,1,3,1,'RA117766893CN\r ','LGAD001 '),(17724,596104265003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','jameswood*2020','woody_jim55@hotmail.com','James wood','Sunny Palms<br>Jolly’s Lane','Porthtowan','Cornwall','UNITED KINGDOM','tr48ax','01209891540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 22:11:08',0,NULL,3,1,3,1,'RA117765765CN ','SHLO009 \rbalck ver1'),(17725,656215605013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','igor.sh','igor.shtanko@gmail.com','Igor Shtanko','Korchagintsev str<br>40, apt 117','Kharkiv','','UKRAINE','61176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 22:15:47',0,NULL,3,1,11,1,'\\ ','WLIN014\r不挂号 '),(17726,603196857004,140651987037,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 adult size',1,'LGGL002*2',104.99,'cnfaner','gioris6','gioris.bougiouris@hotmail.com','Georgios Bougiouris','Lakka','Mykonos','Cyclades','GREECE','84600','6944145341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 22:24:09',0,NULL,3,1,3,1,'RA117766978CN\r ','LGGL002*2 '),(17727,809804220011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','rastaxxxxx','rasta-man@usa.net','tom costandine','1323 N Nevada Ave','colorado springs','co','UNITED STATES','80903-2431','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 22:48:28',0,NULL,3,1,1,1,'\\  ',''),(17728,603212317004,140644120619,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip silver',1,'SHLO008',12.95,'cnfaner','theyingster','yaoyingyu@hotmail.com','Yingyu Yao','101-8775 Cartier st','Vancouver','BC','CANADA','V6P4V3','(778) 887-6769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 23:10:52',0,NULL,3,1,3,1,'RA117765779CN ','SHLO008 \r银色'),(17729,655838520013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','skanno2080','askannav@hotmail.com','andrew Skannavides','477 kingsway <br>Miranda','Sydney','New South Wales','AUSTRALIA','2228','0295244204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 23:26:44',0,NULL,3,1,11,1,'\\ ','OTCN001\r不挂号 '),(17730,809325799002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','amornamorn2009','amornnon@gmail.com','Amorn Nondasuta','P.O.Box 3<br>Samoeng District','Chiangmai,','','THAILAND','50250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 00:04:54',0,NULL,3,1,11,1,'\\ ','BR3D005\r不挂号 '),(17731,603229882004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','normanl2006','terrancek2141@yahoo.com','Norman Lewis','720 E College Ave','Jacksonville','IL','UNITED STATES','62650-2501','(217) 883-7151','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-09 00:19:06',0,NULL,3,1,1,1,'\\  ',NULL),(17732,656275708013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','falha404','falha404@yahoo.com.br','Tatiana Queiroz Prado','SQN 405 bloco B apto. 308','Brasília','DF','BRAZIL','70846020','55 61 32731846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 01:41:49',0,NULL,3,1,11,1,'\\ ','CACN004 不挂号 '),(17733,897400094012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','bambam_250r','mark.lundgren@ymail.com','Mark Lundgren','10050 Tarcoola Pl','Highlands Ranch','CO','UNITED STATES','80130','(720) 344-4248','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 01:48:41',0,NULL,3,1,1,1,'\\  ',' '),(17734,756296505007,170730545598,'NEW sealed Logitech Wireless Laser Mouse M505 plus unifying receiver',1,'MOLO008',35.5,'au-buy','den080865','smi81573@bigpond.net.au','Denis Lalor','C/O Baba Slings<br>486 Hunchy Rd','Hunchy','Queensland','AUSTRALIA','4555','0400508186','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-09 01:55:42',0,NULL,3,1,11,1,'\\ ','MOLO008 \r不挂号'),(17735,603254272004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','arif10952','ari10952@gmail.com','yoel hersh felberbaum','250 Penn St<br>Apt 2','brooklyn','NY','UNITED STATES','11211-8334','(718) 388-2961','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-09 02:14:08',0,NULL,3,1,1,1,'\\  ',NULL),(17736,756301907007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','kc1322','kelseylynncooper@gmail.com','Kelsey Cooper','1718 White Oak Rd','Strasburg','PA','UNITED STATES','17579-9406','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-09 02:16:25',0,NULL,3,1,3,1,'RA117765031CN\r ','UM00042 \r'),(17737,748580968008,180755479839,'ULTIMATE EARS METRO.FI 220 EARPHONE',1,'HSUE002',18.99,'au-buy','txl80terrell','teelas@aol.com','terrell lassiter','8306 spadderdock way','laurel','MD','UNITED STATES','20724-2943','(301) 617-9325','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-09 02:45:27',0,NULL,3,1,1,1,'\\  ',NULL),(17738,809374707002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','jefemaster','jefemaster@aol.com','Jeff Teegarden','5594 Lone Star Dr','San Diego','CA','UNITED STATES','92120-1416','(619) 302-1748','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 02:57:04',0,NULL,3,1,1,1,'\\ ',NULL),(17739,8881323400905296,111,'philips brush charger base+standard brush head',1,'',25,'eastar4','parafun1234','parafun@triad.rr.com','Mark Bouldin','4155 Lambeth Mill Rd','Siler City','NC','UNITED STATES','27344-8414','(336) 879-1791',NULL,NULL,NULL,'2011-12-09 03:21:45',0,NULL,3,1,1,1,'LK033210191CN ',' 单号录入 系统'),(17740,809389260002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','cjmoney9984chris','cjmoney9984@yahoo.com','chris jackson','7701 Rachael Corrine Ct','richmond','VA','UNITED STATES','23227-2130','(804) 205-8204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 03:22:58',0,NULL,3,1,1,1,'\\  ',NULL),(17741,656309724013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','jsmi4804','jms31726@gmail.com','jordan smithey','567 northgate drive','greenwood','IN','UNITED STATES','46143','(317) 956-0180','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 03:47:40',0,NULL,3,1,3,1,'RA117766964CN\r ','GLOT001*4 '),(17742,8881323403570550,111,'NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',39.99,'eastar4',' Bernhard Rauth','berno777@gmail.com','Diana Winkler','Wagnerstraße 118','Ulm','','GERMANY','89077 ','',NULL,NULL,NULL,'2011-12-09 04:06:10',0,NULL,3,1,3,1,'RA117767001CN\r ','WWSI004+ANCN001\rTransaction ID: 1XD47768HN747703K '),(17743,809915491011,320762779367,'NIB Genuine Samsung 2 pair SSG-2100AB + Narnia 3 The Voyage of the Dawn 3d disc',1,'GLSG001*2+BR3D007',119.99,'eastar4','lindajmo67','lindajmo@hotmail.com','Linda Mooring','14 Greer Terrace','Southport','Queensland','AUSTRALIA','4215','0468326189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 04:17:12',0,NULL,3,1,3,1,'RA117765059CN\r ','GLSG001*2+BR3D007'),(17744,748610076008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',11.8,'au-buy','fiakina','ebay.fiakina@gmail.com','Adam Fiske','PO Box 308','Glenhuntly','Victoria','AUSTRALIA','3163','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-09 04:24:05',0,NULL,3,1,11,1,'\\ ','SCLO004\r不挂号 '),(17745,8881323404652155,111,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',0,'eastar4','vhmejia','vhmejia2000@yahoo.com','Victor Mejia','Jerercuaro 630<br>Col. Ricardo Flores Magon','Morelia','Michoacan','MEXICO','58147','(524) 432-7485 ext.: 48',NULL,NULL,NULL,'2011-12-09 04:24:12',0,NULL,3,1,11,1,'\\ ',' CACN004  不挂号'),(17746,656313235013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','saratara1221','multipainting1@yahoo.com.au','dany aren','6 kelvin rod','coniston','New South Wales','AUSTRALIA','2500','0242440730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 04:34:57',0,NULL,3,1,3,1,'RA117765045CN\r ','GLOT001*3 '),(17747,8881323406417909,111,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',0,'eastar4','haja*2010','hagit.mulian@gmail.com','Hagit Mulian','9 B Arlozorov St<br>APT 17','Ramat Gan','','ISRAEL','52481','',NULL,NULL,NULL,'2011-12-09 04:53:37',0,NULL,3,1,3,1,'RA117765076CN\r ',' UM00006'),(17748,655075847013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','ericrussellsmith','ericrussellsmith@yahoo.com','Eric Smith','33371 Golden Gate Canyon Rd','Golden','CO','UNITED STATES','80403-8135','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 04:58:41',0,NULL,3,1,3,1,'RA117766995CN\r ','GLOT001*4 '),(17749,896124631012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',23.74,'eastar4','nomieyoung','nomeyoung@hotmail.co.uk','Naiomi Young','11 Quirk street','Rozelle','New South Wales','AUSTRALIA','2039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 04:59:20',0,NULL,3,1,11,1,'\\ ','UM00008\r不挂号 '),(17750,809936394011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',2,'BAIN001',15.96,'eastar4','gmcurey','gmcurey@aol.com','Darrell W Urey','PO Box 315','North Branch','MN','UNITED STATES','55056-0315','(763) 567-9514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 05:47:54',0,NULL,3,1,1,1,'\\  ',NULL),(17751,809936557011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','moshic10','antonmayday@mail.ru','Антон Нургалеев','Октябрьской революции, 3-58','Нижний Тагил','Свердловская область','RUSSIAN FEDERATION','622013','+79068571789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 05:48:04',0,NULL,3,1,11,1,'\\ ','UDAP001 \r不挂号'),(17752,8881323411673698,111,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',4,'SAFI001',190,'cnfaner','andrewburne','andrew.burne@zimmer.com','Andrew Burne','5 Dilga St','Kings Langley','NSW','AUSTRALIA','2147','',NULL,NULL,NULL,'2011-12-09 06:21:13',0,NULL,3,1,3,1,'RA117766933CN\r ','SAFI001 '),(17753,8881323411975592,111,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',0,'au-buy','ndaicqs','pjpgdt@live.fr','GAUDILLAT PASCAL','10 rue jean Bart','brest','Bretagne','FRANCE','29200','',NULL,NULL,NULL,'2011-12-09 06:26:15',0,NULL,3,0,11,1,'\\ ','不挂号  补发\r只发一个  European plug adapter 不发耳机'),(17754,756368405007,170730545154,'New Logitech Cradle L-LG7 for Harmony remote 880 890 + US AC adapter',1,'CRLO001+POLO001',16.99,'au-buy','victorandang','adam@raconteur.net.au','adam dangelo','40 brougham street','potts point','New South Wales','AUSTRALIA','2011','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-09 06:41:19',0,NULL,3,1,11,1,'\\ ','CRLO001+POLO001\r不挂号 '),(17755,656341984013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','tachan33','tachan33@yahoo.com','tatsunori suzuki','1040 W Riverside Way','san jose','CA','UNITED STATES','95129-2859','(408) 821-2457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 06:43:23',0,NULL,3,1,1,1,'\\  ',NULL),(17756,897496047012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','ronlyforever','rosoft1968@gmail.com','Rosen Radoslavov','ul P. R. Slavejkov 26<br>et 2 ap 3','Levski','Pleven','BULGARIA','5900','+359888009755','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 07:10:34',0,NULL,3,1,3,1,'RA117765155CN\r ','HSPL013 \r欧标'),(17757,603017601004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',107.98,'cnfaner','ilia990','ipservice@novoch.ru','ILYA PEROV','GVARDEYSKAY 26 KV 17','NOVOCHERKASSK','Rostovskay obl','RUSSIAN FEDERATION','346405','79281290444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 07:11:45',0,NULL,3,1,3,1,'RA117765147CN\r ','GLSG001 '),(17758,897498664012,220458920723,'Acer Aspire 3810 3810T  Bluetooth Module 2.0+cable',1,'BTAC2017',9.88,'eastar4','pride_kae','kae@pride.ru','Alex Kovalenko','pr. Lunacharskogo 42-2-125','St-Peterburg','St-Peterburg','RUSSIAN FEDERATION','194356','7-921-303-61-49','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 07:20:54',0,NULL,3,1,11,1,'\\ ','BTAC2017\r不挂号 '),(17759,597921264003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','pimemig1','pimemig@gmail.com','miguel antonio pino mendéz','pino triste 586<br>paseos del roble','cienega de flores','Nuevo León','MEXICO','65550','528118114967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 07:56:06',0,NULL,3,1,3,1,'RA117765204CN\r ','HSPL005 '),(17760,603325335004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','ilir.selimaj84','ilir.selimaj@hotmail.com','Ilir Selimaj','Bisittare vegen 26<br>43345 Partille','Partille','Västragötalandslän','SWEDEN','43345','0046704044599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 08:53:28',0,NULL,3,1,3,1,'RA117765116CN\r ','HSJA002 \r欧标'),(17761,603329299004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.88,'cnfaner','tzahey2009','roimt2006@nana.co.il','tzahey  peretz','shlomo h\'meleh','beer sheva','israel','ISRAEL','84547','0547607061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 09:22:49',0,NULL,3,1,3,1,'RA117765120CN\r ','HSNO006 '),(17762,809995730011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','xerin1104','xerin11@hotmail.com','sharon Barbara','70, Triq karmenu Ciantar','Mqabba','','MALTA','MQB 1053','(356) 79254140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 10:00:13',0,NULL,3,1,3,1,'RA117765535CN\r ','LGGL002 '),(17763,810001970011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','eichner76','t.elchner@gmx.de','Torsten Elchner','5750 lake resort dr Apt. f125','chattanooga','TN','UNITED STATES','37415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 10:21:29',0,NULL,3,1,1,1,'\\ ',NULL),(17764,897554638012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.98,'eastar4','thumph87961f37','thumph8796@hotmail.co.uk','Tony Humphreys','21 Stepping Stones<br>Hemmingford Grey','Huntingdon','Cambridgeshire','UNITED KINGDOM','PE28 9EL','07576688948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 10:40:36',0,NULL,3,1,11,1,NULL,'OTCN003 \r不挂号'),(17765,602741344004,140631796832,'LG AG-F210 3D Cinema Series Glasses 2 Pack',1,'LGGL001',41.98,'cnfaner','wario121','franklin.maia@brturbo.com.br','franklin maia cardoso','QR 608 CONJUNTO 08 CASA 01<br>Samambaia Norte','SAMAMBAIA NORTE','Distrito Federal','BRAZIL','72322-309','55+61-3358-5989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 10:48:18',0,NULL,3,1,3,1,'RA117765221CN\r ','LGGL001\r一共2个 '),(17766,766236356001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','aguilarguilarte','yerene00@yahoo.es','felipe perez garcia','cetina 10 puerta 5','san fernando','CADIZ','SPAIN','11100','956486674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 10:48:22',0,NULL,3,1,11,1,'RA117765368CN\r ','BR3D008 '),(17767,8881323429094042,111,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',0,'eastar4','saci3863','irena.ferkulj@gmail.com','Irena Ferkulj','Martinceva 27','Ljubljana','Slovenia','SLOVENIA','1000','+38631344788',NULL,NULL,NULL,'2011-12-09 11:11:34',0,NULL,3,1,3,1,'RA184541456CN ','HBPH001\r补发 电池需要测试 '),(17768,897564989012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Jimmie Best','15400 N Mustang Rd','Piedmont','OK','UNITED STATES','73078-9694','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 11:13:00',0,NULL,3,1,1,1,'\\ ',NULL),(17769,603354080004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',23.7,'cnfaner','biduguentooriginal','biduguento@hotmail.com','Carlos Santos','Estrada da Palhada nº460<br>casa 108','Nova Iguaçu','Rio de Janeiro','BRAZIL','26290003','+55 (21) 2698-7506','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:14:43',0,NULL,3,1,3,1,'RA117765955CN\r ','HSNO003\r美标 '),(17770,8881323429931101,111,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',0,'eastar4','egor_md','spleen7777@gmail.com','Egor Hlopetki','Bulgara 72/21','Balti','','MOLDOVA, REPUBLIC OF','3100','37360029663',NULL,NULL,NULL,'2011-12-09 11:25:31',0,NULL,3,1,11,1,'、 ',NULL),(17771,810000934011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',11.94,'eastar4','arax82','sim.kessler@gmail.com','simon kessler','haldenstrasse 113','zürich','','SWITZERLAND','8055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:09:45',0,NULL,3,1,11,1,NULL,'OTCN002\r一共3条 \r不挂号'),(17772,756444522007,170737835682,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.99,'au-buy','tooras45','ken.foletta@optusnet.com.au','ken foletta','60 stanley st toora <br>south gipsland','melbourne','Victoria','AUSTRALIA','3962','0355862277','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-09 11:37:31',0,NULL,3,1,11,1,NULL,'LGGL003\r不挂号 '),(17773,897590102012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Al Grega','90 6th Ave','Holtsville','NY','UNITED STATES','11742-2372','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 12:23:25',0,NULL,3,1,1,1,' \\',NULL),(17774,897605526012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','phoenixwestl','phoenixwestl@hotmail.co.uk','sean mann','73 hopefield road','blackburn','West Lothian','UNITED KINGDOM','EH47 7HT','01506631842','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-09 13:03:13',0,NULL,3,1,3,1,'RA117765898CN ','HSSA002\r英标 \r黑色'),(17775,597985651003,130613527106,'New 44 Pin Female to Female Mini IDE Cable for PC 30 cm',1,'OTCN002',3.9,'cnfaner','peejs','pjcajiuat@hotmail.com','PJ Cajiuat','14 Yakal St. Mary the Queen Homes, San Sebastian','Hagonoy','Bulacan','PHILIPPINES','3002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:04:21',0,NULL,3,1,3,1,'RA117765725CN ','OTCN002 '),(17776,656428471013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','peasduke','neuronic@narod.ru','Nikitin Danil','Borisevicha 16-84','Krasnoyarsk','KRASNOYARSK','RUSSIAN FEDERATION','660124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:40:45',0,NULL,3,1,11,1,NULL,'WLIN014\r不挂号 '),(17777,897621831012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','cnik5531','cnikolau@hotmail.com','CHRISTOS NIKOLAOU (OFFICE 612)','LEGAL COUNCIL OF THE STATE<br>AKADIMIAS 68','ATHENS','ATTIKI','GREECE','10678','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:43:04',0,NULL,3,1,11,1,'RA117766006CN\r ','OTGR001+OTGR002\r不挂号 '),(17778,656445305013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','byroadejr','byroadejr@yahoo.com','Ed Byroade Jr.','1408 83rd St NW','Bradenton','FL','UNITED STATES','34209-9626','(717) 515-3737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 14:32:40',0,NULL,3,1,1,1,'\\ ',' BTHP2107\rHP 8pin 1.0 23cm '),(17779,656457697013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',3,'WLIN014',56.97,'eastar4','meldll','l-l@nm.ru','Aleksei Meldianov','Antonova-Ovseenko 3/12','Moscow','Moscow','RUSSIAN FEDERATION','123317','79163100274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 15:09:58',0,NULL,3,1,3,1,'RA184556932CN ','WLIN014 '),(17780,810104423011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','jeliza.rose','vanessa-battisti@hotmail.com','Vanessa Battisti','Via Angelo Nessi 15','Locarno','','SWITZERLAND','6600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 15:16:39',0,NULL,3,1,11,1,'、 ','UDAP001\r不挂号 '),(17781,595066087003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','b_fango','bgourvellec@gmail.com','BARTHELEMY GOURVELLEC','Le vieux bourg - 11, rue au moines','TAUPONT','FRANCE/MORBIHAN/BRETAGNE','FRANCE','56800','0680445768','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 15:25:26',0,NULL,3,1,3,1,'RA117765442CN\r ','BALO007 '),(17782,897677893012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','bigtimepimp','bleepdat@yahoo.com','Christopher Canote','1819 Kirkland Ave','San Jose','CA','UNITED STATES','95125-1875','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 15:48:53',0,NULL,3,1,1,1,'\\ ',NULL),(17783,598040155003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','karapanikas','lukaonas@gmail.com','panagiotis platonis','baiou tzella 70','karditsa','karditsa','GREECE','43100','24410-20502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 16:10:36',0,NULL,3,1,3,1,'RA117765805CN ','RELO002 '),(17784,808512097002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','compramosporti.cl','aquijada@compramosporti.cl','Alejandra Quijada B.','8200 NW 93rd St','Medley','FL','UNITED STATES','33166-2028','(786) 287-2740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 16:13:57',0,NULL,3,1,1,1,' \\',' '),(17785,810142265011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.9,'eastar4','lavina000','lexiemap@hotmail.com','LEXIE MAPLESON','70 TYMKIN RD','ROKEBY','Victoria','AUSTRALIA','3821','0417614248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 16:24:20',0,NULL,3,1,3,1,'RA117765558CN\r ','OTGR001+OTGR002+OTGR003 '),(17786,897714476012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','hbitan','henbitan@zahav.net.il','hen bitan','P.O.B 2381','kadima','','ISRAEL','60920','+972-54-7778683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 16:53:58',0,NULL,3,0,11,1,'RA117765663CN\r\r','UMTR001\r蓝边的 '),(17787,810199968011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',57,'eastar4','matrixjhx','jheilmann@gmx.de','Jens Heilmann','Uhlandstr. 12 A','Salzgitter','','GERMANY','38259','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 18:14:55',0,NULL,3,1,3,1,'RA117765782CN ','HSJA011\r欧标 '),(17788,810198576011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','andreykathe','andreyka.gusev@gmail.com','Гусев Андрей Николаевич','Заревый проезд 14/12 кв80','Moscow','','RUSSIAN FEDERATION','127282','(963) 655-3810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 18:15:37',0,NULL,3,1,11,1,'、 ','HSJA012银色\r不挂号 '),(17789,656552296013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','pontiacpetegto','pontiacpete@sbcglobal.net','Pedro Araujo Jr.','8809 Norton St','El Paso','TX','UNITED STATES','79904-1918','(915) 751-7200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 19:10:30',0,NULL,3,1,1,1,'、  ','BTAC2115\racer 5pin1.25 20cm \r换发成2.1的\r客户补了差价'),(17790,897804946012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','y_lugovtsev','lugovtsev@gmail.com','Yuriy Lugovtsev','Revolutsyonnaya str., 148 - 133','Samara','','RUSSIAN FEDERATION','443069','+7 902-374-0193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 19:21:08',0,NULL,3,1,3,1,'RA117765252CN\r ','GLOT001 '),(17791,895358258012,220807244626,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AB',1,'GLOT006*2',88.99,'eastar4','ivgen2010','ivgeni@inbox.ru','Yevgenii Bezverkhnii','G. Mazepy st. 5/10','Ternopil','','UKRAINE','46009','380506708285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 19:50:25',0,NULL,3,1,3,1,'RA117765235CN\r\r ','GLOT006*2 '),(17792,603525077004,140626375035,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',14.1,'cnfaner','enmy1979','alexisrg1969@gmail.com','enmy reyes','3328 White Blossom Ln','clermont','FL','UNITED STATES','34711-6370','(407) 864-1443','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-09 20:06:28',0,NULL,3,1,1,1,'、 ','白色的 '),(17793,603526431004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','9725zakovichmichael2','zakovichmichael2@gmail.com','Michael Zakovich','Mihaanavi 12','Modiin','','ISRAEL','71723','972545786042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 20:11:49',0,NULL,3,1,3,1,'RA117765938CN\r ','HSPL002 '),(17794,810272047011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','old_men','k.klatt@arcor.de','Karsten Klatt','Vogelbeerweg 4','Weissach','','GERMANY','71287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 20:17:34',0,NULL,3,1,11,1,NULL,'HSUE002\r不挂号 '),(17795,656590030013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',18.99,'eastar4','vwspeedwagon','peter.bennett@pwc.ca','PETER BENNETT','10 FIRST POND DRIVE','KETCH HARBOUR','NS','CANADA','B3V1K7','(902) 868-2349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 20:35:43',0,NULL,3,1,11,1,NULL,'UM00033\rheart 心形的\r不挂号 '),(17796,897864805012,220816317839,'New lady paris tower dot w/trim Sun Rain Stick Umbrella',1,'UM00028',21.84,'eastar4','anklebashers','mcgregor99@bigpond.com','David  McGregor','PO Box 83<br>81 Anderson rd','Crookwell','New South Wales','AUSTRALIA','2583','0248320895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 20:50:22',0,NULL,3,1,11,1,NULL,'UM00028\r不挂号 '),(17797,766507341001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','grozzz','grozzz@comcast.net','STEVE GROSMICK','7210 SE Elsa St','GRESHAM','OR','UNITED STATES','97080-8221','(503) 663-0500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 21:02:21',0,NULL,3,1,1,1,' \\',NULL),(17798,810327862011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','joza1980','sacher.gitarist2@gmail.com','Josip Sacher','Alagoviceva 15','Zagreb','Croatia','CROATIA','10000','00385915237851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 21:55:50',0,NULL,3,1,11,1,NULL,'OTHP004\r不挂号 '),(17799,897939814012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','exlipt','abodwa@yandex.ru','Androsau Vasili','Gorodische post ofice,m/b 1068,h2-4','Minskij rajon','','BELARUS','223027','+375295673408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 23:10:59',0,NULL,3,1,3,1,'RA117765164CN\r ','GLOT001 '),(17800,897942861012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','keylovesani','leandra115@yahoo.com','nicholas raineri','323 verona st','oneida','NY','UNITED STATES','13421-1120','(315) 363-4772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 23:12:23',0,NULL,3,1,1,1,' \\',NULL),(17801,897953045012,220501826158,'2.1 Acer Aspire 5220 5220G  Bluetooth Module+cable',1,'BTAC2124',12.39,'eastar4','pedro8767','p.vaquero@vodafone.pt','Pedro Vaquero dos Santos','Rua Jerónimo Mendonça, 274-1ºdto','Porto','','PORTUGAL','4200-335','225028055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 23:34:48',0,NULL,3,1,11,1,NULL,'BTAC2124\racer 8pin1.00 15cm \r不挂号 '),(17802,603598140004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','klgrem','gremlin@ec.rr.com','Ken Gremillion','216 Ashwood Ct','Havelock','NC','UNITED STATES','28532','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-09 23:42:59',0,NULL,3,1,1,1,'\\ ',NULL),(17803,603602139004,140635368949,'4 pairs of New in box SONY 3D Active Glasses TDG-BR250',1,'OTSO004*4',271.99,'cnfaner','thiago_maga','thiago_magalhaes_83@yahoo.com.br','Thiago Magalhães','Av. Cidade Jardim, 2740 - Apto 184','São José dos Campos','São Paulo','BRAZIL','12233-002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 23:56:01',0,NULL,3,1,6,1,'EE495359622CN ','OTSO004*4 \r重量.818 控制在1000克以\r已收到，客户问起再回。'),(17804,656668598013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','astgabel','joerg.albert@gmx.de','Joerg Albert','Behaimstr. 4','Berlin','','GERMANY','13086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 00:21:38',0,NULL,3,1,11,1,NULL,'WLIN014 \r不挂号'),(17805,809834914002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','mmm0047','matrem@online.no','Magnus Matre','ordforer ingebrigtsens gt 13','Drammen','','NORWAY','3045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 00:30:14',0,NULL,3,1,11,1,'RA117765411CN\r ','BR3D009 '),(17806,810393257011,320730087169,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',6.99,'eastar4uk','westsiderudedog','rudolph.ressel@gmx.de','Rudolf Ressel','Ohmstr. 2','Bremen','','GERMANY','28357','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 00:30:34',0,NULL,3,1,11,1,' ','WLAT005\r不挂号 '),(17807,598223038003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','jenneyshop73','sunfun73@gmail.com','CYNTHIA JENNEY','PO BOX 391','MAPLE PLAIN','MN','UNITED STATES','55359-0391','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 00:58:40',0,NULL,3,1,1,1,'\\ ',NULL),(17808,898004476012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','b1sc1','bosco@carabo-it.com','Bosco Fernandes','332 Serpells Road','Doncaster East','Victoria','AUSTRALIA','3109','0398423206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 01:57:32',0,NULL,8,1,17,0,NULL,NULL),(17809,898005179012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','b1sc1','bosco@carabo-it.com','Bosco Fernandes','332 Serpells Road','Doncaster East','Victoria','AUSTRALIA','3109','0398423206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 01:59:29',0,NULL,3,1,11,1,NULL,' CASS003+CASS002\rCAB-6060\r再发两个CAB-SS-2660\r不挂号'),(17810,810427167011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','morford3288','morford12711@gmail.com','onsTravis morford','1131 Crawford ave','vandergrift','PA','UNITED STATES','15690','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 02:22:48',0,NULL,3,1,1,1,'\\ ',NULL),(17811,898019201012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','georgenapalm','george.zhygalko@gmail.com','Heorhi Zhyhalko','36 Central Street<br>Apt 1','Somerville','MA','UNITED STATES','02143','(617) 820-4615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 02:43:28',0,NULL,3,1,1,1,'\\ ',NULL),(17812,603650788004,140584762584,'New HP Atheros AR5BXB72 AR5008 MINI PCI-E card',1,'WLAT004',23.99,'cnfaner','wcheung168','wilson.cheung@rogers.com','Chi-Wah Cheung','22 Smoothwater Terrace','Markham','ON','CANADA','L6B0E5','(647) 280-3766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 03:56:21',0,NULL,3,1,3,1,'RA184541924CN\r ','wcheung168 '),(17813,603651821004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','austinpharman','jrb10@frontier.com','Jeff Buhmiller','2791 Cumberland Dr','Lake Havasu City','AZ','UNITED STATES','86406-8644','(928) 486-0773','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 04:02:52',0,NULL,3,1,1,1,' \\',NULL),(17814,898051254012,220806892088,'NEW Sunflower Bloom 3-section Folding umbrella',1,'UM00004',20.89,'eastar4','sunhei1991','lizzie4337@hotmail.com','Elizabeth Brown','1500 Witte Rd<br>Apt 87','Houston','TX','UNITED STATES','77080-7635','(832) 754-5872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 04:31:53',0,NULL,3,1,1,1,'、 ',NULL),(17815,810467444011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','ilikemybikemike','col_beth@hotmail.com','Colin Schofield','2/511 Woodville Rd<br>Guildford','Sydney','New South Wales','AUSTRALIA','2161','0439306354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 04:51:06',0,NULL,3,1,3,1,'RA184556892CN ','GLSG001 '),(17816,603666477004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',2,'MOMI001',109.6,'cnfaner','arcadenut','spammehere@arcaderestoration.com','Brien King','8902 N 64th Ln','Glendale','AZ','UNITED STATES','85302-4450','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 05:35:10',0,NULL,3,1,4,1,'YW867739634CN',NULL),(17817,603673878004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','cyberon1997','yofriend97@gmail.com','Ralph Markin','566 Chestnut St','Richland Center','WI','UNITED STATES','53581-1903','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 06:29:16',0,NULL,3,1,1,1,' \\',NULL),(17818,898078151012,220763380817,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',2,'HSSE005',27.8,'eastar4uk','kayptkd','kaytkd@hotmail.co.uk','Kayleigh Parker','91 Woodlands Road<br>Charfield','Wotton Under Edge','Gloucestershire','UNITED KINGDOM','GL12 8LT','07891403535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 06:30:46',0,NULL,3,1,3,1,'RA184541368CN ','HSSE005\r英标 '),(17819,898097805012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',18.99,'eastar4','lithium_angel','kelly@papercutsdesigns.com','Kelly Park','10 Jennings Rd','High Wycombe','Western Australia','AUSTRALIA','6057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 08:03:37',0,NULL,3,1,11,1,NULL,'UMTR001 \r最好要黑色如果没有黑色就要黄色\r不挂号'),(17820,898110089012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','kevcat0','kevindearden@btinternet.com','kevin dearden','112 high street<br>shafton','barnsley','South Yorkshire','UNITED KINGDOM','S728NJ','01226780354','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 08:44:38',0,NULL,3,1,3,1,'RA117765884CN ','HSJA010\r英标 '),(17821,656767770013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','richardnilsen2011','nils_karl@hotmail.com','richard nilsen karlsen','uenesveien 54','flekkefjord','vest agder','NORWAY','4400','90058571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 08:46:03',0,NULL,3,1,3,1,'RA117765306CN\r ','GLOT001*4 '),(17822,598319098003,130458358084,'New GENUINE NOKIA BH-102 BLUETOOTH HEADSET track#',1,'HSNO001',19.29,'cnfaner','kvkpls','kvkpls@yahoo.gr','Theodosis Kavakopoulos','Dimitriou Kalergi 11B<br>P.O. Box: A 2751 Triadi','Thermi','Thessaloniki','GREECE','57001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 10:02:33',0,NULL,3,1,3,1,'RA117765589CN ','HSNO001\r欧标（EUROPEAN charger )'),(17823,749197439008,180762085457,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring',1,'UM00021',26.99,'au-buy','gingertea007','kaz6457@yahoo.com.au','Karen@ Fraser','11 Randall St','Sandy Bay','Tasmania','AUSTRALIA','7005','0362236573','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-10 10:16:04',0,NULL,3,1,11,1,NULL,'UM00021\r不挂号 '),(17824,898143113012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','felipeardito','felipepavao@gmail.com','Felipe Pavão Ardito','Rua André Saraiva, 1267<br>Vila Sônia','São Paulo','São Paulo','BRAZIL','05626-001','(55) 11 37435784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 10:21:34',0,NULL,3,1,3,1,'RA117765408CN ','OTSO004*2 '),(17825,898147571012,220825062314,'New 3.0 Bluetooth BCM92070 Module+cable Asus N43 N73',1,'BTAS3001',19.98,'eastar4','reginald061','r.charont@yahoo.fr','reginald charont','centre haute energie<br>10 bd pasteur','nice','Provence-Alpes-Côte d\'Azur','FRANCE','06000','0603781436','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 10:34:35',0,NULL,3,1,11,1,NULL,'BTAS3001 \r3.0 ASUS 6pin 6CM  \r不挂号'),(17826,656805013013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','xxdearkyoxx','iluvdemon@live.com','Libor Turek','Stinygasse 6/57/4','Wien','','AUSTRIA','1100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 11:20:19',0,NULL,3,1,11,1,'RA117765941CN\r ','CACN004\r不挂号 '),(17827,598357745003,130592181875,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.9,'cnfaner','sweden_guy','rso@lavabit.com','Stefan Von straten','Lilla Emma Skola','Hjortkvarn','','SWEDEN','697 93','46 582 30360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 12:29:27',0,NULL,3,1,3,1,'RA117765473CN\r ','OTCN001 '),(17828,598362959003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','mathprod','mathieu.ocana@gmail.com','Mathieu Ocaña','CETIC<br>Rue des Frères Wright, 29/3','Charleroi','','BELGIUM','6041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 12:48:13',0,NULL,3,1,3,1,'RA184541283CN ','WLAT003 '),(17829,810602628011,320441946623,'2.1 HP NC6320 NC6400 Bluetooth Module EDR +cable',1,'BTHP2106',12.39,'eastar4','apollo17troy','langfordtroy@yahoo.com','troy langford','4906 Ingersoll ave. apt5','des moines','IA','UNITED STATES','50312','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 12:54:36',0,NULL,3,1,1,1,' \\','HP 8pin 1.0 20cm  '),(17830,598368640003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','mr.hemulin','hemulin@hotmail.com','Yotam Katznelson','119/10 Herzel st.','Jerusalem','','ISRAEL','96000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 13:09:08',0,NULL,3,1,3,1,'RA184556950CN ','HSPL005 '),(17831,898238292012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','hapkidoka66','hapkidoka66@hotmail.com','ANDRES GARCIA LOPEZ','Cl.  Isla Gomera nº 5 - 5º B','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14011','600204405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 14:10:18',0,NULL,3,1,3,1,'RA117765969CN ','HSPL013\r欧标 '),(17832,810105700002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','detectordfx','derrick.horner@talktalk.net','Derrick  Horner','83 Walden Close,  Ouston','County Durham','Tyne and Wear','UNITED KINGDOM','DH21TG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 14:21:56',0,NULL,3,1,11,1,'RA117765425CN\r ','BR3D009 '),(17833,809788956011,320678305956,'NewGenuine SonyEricsson HBH-PV705 705 Bluetooth Headset',1,'HSSE005',22.9,'eastar4','rhondawiggins57','rwiggins57@aol.com','Rhonda Wiggins','501 E Garrison Ave','Electra','TX','UNITED STATES','76360-2510','(940) 782-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 14:50:28',0,NULL,3,1,1,1,' \\',NULL),(17834,810662138011,320791295540,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking  TK103-2',1,'GPS0008',111.99,'eastar4','rochabarretos22','rochabarretos@uol.com.br','Guilherme  Rocha','Rua 06 nº 0446','Barretos','São Paulo','BRAZIL','14781-357','55 17 33225839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 15:11:31',0,NULL,3,1,3,1,'RA117765283CN ','GPS0008\r申报为gift申报价为10USD '),(17835,656880591013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','sdes7609','postdep@hotmail.com','Sébastien Despelteau','8337<br>Foucher','Montréal','QC','CANADA','H2P 2B9','(514) 729-5739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 15:16:20',0,NULL,3,1,3,1,'RA117765310CN ','MOSA004 '),(17836,898288717012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','betbet71','betbet.pearson@sky.com','paul martin','51 Watkinson street','Heanor','Derbyshire','UNITED KINGDOM','DE75 7FX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 15:43:11',0,NULL,3,1,3,1,'RA184556946CN ','HSJA010\r英标 '),(17837,810680905011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','-rr','robert_rudolph@web.de','Robert Rudolph','Klaus-Groth-Str. 47','Ahrensburg','','GERMANY','22926','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 15:44:13',0,NULL,3,1,11,1,'RA117765385CN\r ','ADAK002 '),(17838,603808517004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',3,'WLDE002',41.97,'cnfaner','dragonfly-red','highdaun@hotmail.com','Y Cheung','5 Shearwater Road','Sutton','Surrey','UNITED KINGDOM','SM1 2AR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 15:44:21',0,NULL,3,1,3,1,'RA117765218CN\r ','WLDE002 '),(17839,898310885012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT006*2',52.99,'eastar4uk','george7n','george7n@yahoo.co.uk','Juraj Nagy','58 Clifton Road','Tunbridge Wells','Kent','UNITED KINGDOM','TN2 3AT','07843729326','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 16:19:12',0,NULL,3,1,3,1,'RA117765323CN\r ','GLOT006*2 \r兼容眼镜 korea专用'),(17840,603823315004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','gravy1138','gravy604@gmail.com','Shawn Romack','27 East 60th ave','Vancouver','BC','CANADA','V5X1Z5','(604) 783-8716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 16:22:02',0,NULL,3,1,3,1,'RA117765487CN\r ','HBPH003 '),(17841,598441970003,130554587552,'New Atheros AR5B195 Wireless + Bluetooth Half CARD',1,'WLIN016',20.89,'cnfaner','order306','online@nwomail.com','Peter Akala','729 S SILVERSMITH LN','NEWARK','DE','UNITED STATES','19702','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 16:36:04',0,NULL,3,1,1,1,' \\',NULL),(17842,898325467012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','monigogi','zhelezov.georgi@gmail.com','Monika Banova','31 Avenue de Lardenne<br>rez de chausse gauche','Toulouse','Midi-Pyrénées','FRANCE','31100','0751406108','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 16:42:51',0,NULL,3,1,3,1,'RA117765354CN ','GLOT005 '),(17843,810747810011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',26.99,'eastar4uk','ibasst0','ramsayw@myhomnet.co.uk','Winston Ramsay','5 North Crockerford<br>Vange','Basildon','Essex','UNITED KINGDOM','SS16 4JF','07703746496','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 17:37:03',0,NULL,3,1,3,1,'RA117765875CN ','WWOT001\r '),(17844,593582846003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.24,'cnfaner','jwinchester169','jwinchester.169@gmail.com','Jered Winchester','5993 Longdin Rd','Ferndale','wa','UNITED STATES','98248-9417','(360) 223-8210','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-10 17:47:51',0,NULL,3,1,1,1,' \\',NULL),(17845,603857532004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',53.99,'cnfaner','cafcan9','cravenhilldavies@yahoo.co.uk','sharon ramsey','60 whitland close,','Ipswich','Suffolk','UNITED KINGDOM','ip2 9yt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 17:59:16',0,NULL,3,1,3,1,'RA184556889CN ','GLSG001 '),(17846,656997232013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','romoles','sla@mail.ru','Vyacheslav Almazov','Beloborodova, 2k2, 105','Mytishchi','Moscow','RUSSIAN FEDERATION','141006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 19:30:06',0,NULL,3,1,11,1,NULL,'WLIN014 '),(17847,810830072011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','glinbear','brownbm@pacbell.net','Barry Brown','5807 16th St','Lubbock','TX','UNITED STATES','79416-5125','(806) 577-4061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 19:47:47',0,NULL,3,1,1,1,'\\ ',NULL),(17848,651750775013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','saffetcilingir','saffet@cilingir.net','Saffet Cilingir','Cinar Mah. Yukari Tahsinbey Sokak<br>No:12/A Kucukyali - Maltepe','Istanbul','TR','TURKEY','34000','90 (216) 549 1772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 19:54:56',0,NULL,3,1,11,1,' ','WLAT008\r不挂号 '),(17849,810846095011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','fridrikfsk46','fridriksk@hive.is','Friðrik Kristinsson','Brúarflöt 1','Garðabær','','ICELAND','210','3548988543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 20:07:15',0,NULL,3,1,3,1,'RA117765249CN\r','GLOT001 \r兼容眼镜'),(17850,767059826001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','mrpalmetto','mrpalmetto1@msn.com','william szigety','822 Baytree Dr','harrells','NC','UNITED STATES','28444-8858','(910) 588-4906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 21:14:16',0,NULL,8,1,17,0,NULL,NULL),(17851,810352803002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','mrpalmetto','mrpalmetto1@msn.com','william szigety','822 Baytree Dr','harrells','NC','UNITED STATES','28444-8858','(910) 588-4906','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 21:35:57',0,NULL,3,1,1,1,'\\ ','Monster House  New sealed 3D Blu-ray ship \r一共2个'),(17852,603970911004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','219phy','crwcook@tx.rr.com','Chaurcley Cook','1528 Walnut Dr','Nacogdoches','TX','UNITED STATES','75965-2954','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 22:06:18',0,NULL,3,1,1,1,' \\',NULL),(17853,657061039013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','sibcat77','insur_job@mail.ru','Fedor Aksenov','Molodcova dom 29 korpus 2 kvartira 220','Moscow','','RUSSIAN FEDERATION','127081','79268771070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 22:38:28',0,NULL,3,1,11,1,NULL,'WLIN014 \r不挂号'),(17854,810941574011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','adamson4758','stephen_adamson@hotmail.com','stephen Adamson','2 Tagula place<br>Glenfield','sydney','New South Wales','AUSTRALIA','2167','0401178853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 22:56:25',0,NULL,3,1,11,1,'RA117765748CN\r ','MOLA001 \r不挂号'),(17855,598601426003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','three_boxers','burk_s@sbcglobal.net','Suzette Burk','11631 Inga Lane','Houston','TX','UNITED STATES','77064','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 23:03:28',0,NULL,3,1,1,1,'\\ ','OEM '),(17856,810405575002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','aldneal','albertdneal@gmail.com','albert d neal','24648 jamestowne rd','novi','MI','UNITED STATES','48375-2326','(248) 946-4660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 23:34:18',0,NULL,3,1,1,1,' ',NULL),(17857,603999882004,140626376987,'Sony Ericsson HBH-DS970 Bluetooth headset',1,'HSSE010',63.99,'cnfaner','displayman1397','bspeece@earthlink.net','Bryan Speece','18030 Chanticleer Ct','Auburn TWP','OH','UNITED STATES','44023-8803','(440) 537-4620','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-10 23:35:25',0,NULL,3,1,1,1,'\\ ',NULL),(17858,749593502008,180699062138,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',45,'au-buy','fredo-cocotte','fredococotte@free.fr','frederic corbeau','39 rue de compiegne','saint leger aux bois','Picardie','FRANCE','60170','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-10 23:45:01',0,NULL,3,1,3,1,'RA117765544CN ','OTPL001 '),(17859,898602962012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','brats_wiseguy','garrytobias@gmail.com','Garry Tobias','574 Boyd Ave.','Winnipeg','MB','CANADA','R2W1R1','(204) 589-0729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 23:59:54',0,NULL,3,1,11,1,NULL,'WLHP002\r不挂号 '),(17860,657118582013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',3,'HSNO019',113.94,'eastar4','0563061111','ahmedsr72@hotmail.com','ahmed alruwaili','38677 dhahran 31942 saudi arabia','dhahran','AR','SAUDI ARABIA','31942','+966563061111','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-12-11 00:41:17',0,NULL,3,1,3,1,'RA117765439CN\r ','HSNO019 '),(17861,657118855013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','char39256','jamesaileen95@hotmail.com','Chad Hartman','7650 Spurge Drive','Fayetteville','NC','UNITED STATES','28311','(910) 222-8159','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 00:42:18',0,NULL,3,1,6,1,'EE636828872CN ','GLOT001*4 '),(17862,898622076012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','vmolinap2009','vmperez26@yahoo.com','victor molina','1269 chalkstone ave<br>Fl 2','providence','RI','UNITED STATES','02908-3946','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 00:47:04',0,NULL,3,1,1,1,'\\ ','acer 5pin1.25 6cm    '),(17863,598632468003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','ciaragames','charlesfindit@comcast.net','Plawear Gear','9202 Clearwood Landing Blvd','Houston','TX','UNITED STATES','77075-5238','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-11 00:48:35',0,NULL,3,1,1,1,' \\','OEM '),(17864,598639009003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','jdie1944','hellonwheels141@comcast.net','Joseph Dienstag','9190 W State Road 54','Linton','IN','UNITED STATES','47441-5207','(812) 239-5531','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-11 01:17:43',0,NULL,3,1,1,1,' \\',NULL),(17865,657128237013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','mkod99_123','mkod99@gmail.com','mark odell','8615 e derby oaks dr','floral city','FL','UNITED STATES','34436-3878','(321) 431-8890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 01:18:52',0,NULL,3,1,1,1,'\\ ',NULL),(17866,811001639011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','sunny4275','sunny4275@hotmail.com','saundrina Jordan','1083 Tupelo Chase Ct','auburn','GA','UNITED STATES','30011-2386','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 01:38:54',0,NULL,3,1,1,1,'\\ ',NULL),(17867,598647765003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','dionmonaghan','gitaroman3@hotmail.com','Dion Monaghan','11 Utalong st','Deagon','Queensland','AUSTRALIA','4017','0731910807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 01:58:35',0,NULL,3,1,3,1,'RA117765796CN ','LGAD001 '),(17868,598649068003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','herb_tarlik','asillito@sympatico.ca','Al Sillito','16 Glenavy Ave','Toronto','ON','CANADA','M4P 2T6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 02:04:59',0,NULL,3,1,3,1,'RA117765178CN\r ','RCLO007+POLO001+RCLO008*4 '),(17869,749660453008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',25.99,'au-buy','dablur','proent@gmail.com','Randy Robbins','320 Broad St','Waverly','NY','UNITED STATES','14892-1358','(607) 767-7501','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 03:15:56',0,NULL,3,1,1,1,' \\',NULL),(17870,898676339012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','doug06981','doggteagle@erols.com','DOUGLAS TEAGLE','3500 Overlea Ct','JEFFERSON','MD','UNITED STATES','21755-7802','(301) 834-7839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 03:27:23',0,NULL,3,1,1,1,'\\ ','GLOT001*2 '),(17871,898677269012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','mb7of9','rfmiranti@aol.com','Richard Miranti','926 S Elm St','Palatine','IL','UNITED STATES','60067-7106','(847) 358-4590','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 03:27:41',0,NULL,3,1,1,1,' ','acer 6pin1.25 23cm  '),(17872,767201046001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','lfurnas74','casi.festus@gmail.com','Lisa Furnas','8440 Stevenson Ave','Sacramento','CA','UNITED STATES','95828-5302','(916) 842-9627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 03:38:07',0,NULL,3,1,1,1,' \\',NULL),(17873,810498949002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','cotsyshell','cotsy@alltel.net','Robert Cotsamire','319 Pinetree Dr','Granville','OH','UNITED STATES','43023-9548','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 04:17:43',0,NULL,3,1,1,1,' \\',' '),(17874,657173234013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','balvardo','im@balvardo.ru','Ilya Makarov','Boldov ruchey<br>korp. 1117, kv. 120','Zelenograd','Moscow','RUSSIAN FEDERATION','124460','+7 915 308 4121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 04:32:01',0,NULL,3,1,11,1,'、 ','不挂号\rCACN004 \r新地址\rIlya Makarov\rBoldov ruchey\rkorp. 1117, kv. 128\rZelenograd Moscow 124460\rRUSSIAN FEDERATION\r+7 915 308 4121'),(17875,810508554002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','paulrez','paulresnik60@gmail.com','Paul Resnik','1575 Canopy Ln<br>Apt 101','Orange City','FL','UNITED STATES','32763-1934','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 04:56:14',0,NULL,3,1,1,1,' \\',NULL),(17876,897534090012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','club_xtreme','neutyneu@gmail.com','Pimporn Siripiroon','13/49 Moo5 Bangduan<br>Pasichaoren','Bangkok','Bangkok','THAILAND','10160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 05:54:10',0,NULL,3,1,11,1,NULL,'不挂号\rHSJA001 '),(17877,767234452001,110773418749,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4',1,'GRUG001',179.99,'buysia','magicarpetridemn','thfreebird@aol.com','Ron Cooley','25738 Karly Dr','Picayune','MS','UNITED STATES','39466','(601) 798-6018','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 05:56:49',0,NULL,3,1,4,1,'YW867739645CN ',NULL),(17878,898729246012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','magicman48187','ral1950@comcast.net','Robert Leverton','46657 Gunnery Dr','Canton','MI','UNITED STATES','48187-1691','(734) 207-1861','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 06:44:17',0,NULL,3,1,1,1,'\\ ',NULL),(17879,757458865007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','lummock','lummock@gmail.com','ravi dhaliwal','108 Banning St','THUNDER BAY','ON','CANADA','p7b3h9','(807) 252-7284','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 06:47:05',0,NULL,3,1,11,1,NULL,'SCLO001 \r不挂号'),(17880,749737368008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.99,'au-buy','george6967','georgesideris69@yahoo.com.au','George Sideris','56 Gordon Street','Newport','Victoria','AUSTRALIA','3015','0412873049','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 08:43:33',0,NULL,3,1,3,1,'RA117765270CN\r ','GLOT001 \r兼容眼镜通用型'),(17881,604109090004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.59,'cnfaner','gurband211','gurband@bk.ru','Lada Gurevich','Hativat Yiftah 73/3','Karmiel','Israel','ISRAEL','21610','972527566010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 08:52:43',0,NULL,3,1,3,1,'RA184556875CN ','LGGL003 '),(17882,757504595007,170730545626,'New US Logitech Harmony AC Power Adapter',1,'POLO001',6.99,'au-buy','taimou','taimou@gmail.com','Richard Chuck','47 Hammond Av<br>Normanhurst','Sydney','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 09:30:36',0,NULL,3,1,11,1,NULL,'POLO001\r不挂号 '),(17883,898800403012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT006*2',52.99,'eastar4uk','patelrudra','patelrudra08@gmail.com','Rimpal Patel','17 Danes Court<br>North End Road','Wembley','London','UNITED KINGDOM','HA9 0AD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 10:07:49',0,NULL,3,1,3,1,'RA184541310CN ','GLOT006*2\r兼容眼镜 通用型'),(17884,898807889012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','joe_b_2','joe_b_2@hotmail.com','Joe Corrone','10 Petersfield Court','Boronia','Victoria','AUSTRALIA','3155','0400020583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 10:21:32',0,NULL,3,1,11,1,NULL,'OTCN005*10\r不挂号 \r白色的'),(17885,898818993012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','teeth-whitening','admin@allwhite.com.au','David Fry','13 Keith Avenue','North Plympton','South Australia','AUSTRALIA','5037','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 10:41:27',0,NULL,3,1,3,1,'RA117765822CN ','GLOT001*2 '),(17886,898837002012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','bigkgz','big_kgz@hotmail.co.uk','Asim Hussain','112 kingsway','luton','Bedfordshire','UNITED KINGDOM','lu11tt','07950543424','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 11:12:46',0,NULL,3,1,3,1,'RA117765972CN ','HSNO005\r英标 '),(17887,898839771012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',134.48,'eastar4uk','tinab19','tinabarber@hotmail.com','Tina Barber','Kalamazoo, Dalton Lane<br>Halsham','Hull','Humberside','UNITED KINGDOM','HU120DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 11:51:02',0,NULL,3,1,6,1,'EE495359636CN ','LGRM001\r再发4副兼容眼镜 LGGL002*4\r4 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110 '),(17888,898897649012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','jamesa1781','jamesaustin1@bigpond.com','james austin','20 wandewoi ave','san remo','New South Wales','AUSTRALIA','2262','0243902340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 12:56:36',0,NULL,3,1,3,1,'RA117765819CN ','GLOT001*2 \r兼容型3D眼镜 通用型'),(17889,811258265011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','anton-popov','antonpopo@gmail.com','Anton Popov','Maratovskaya 2, 12','Tambov','Tambovskaya obl','RUSSIAN FEDERATION','392036','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 13:28:14',0,NULL,3,1,11,1,NULL,'WLAP002\r不挂号 \rpple airport extreme 二代卡 旧'),(17890,657336376013,230675320923,'New in box Genuine Samsung 2 pair SSG-2100AB glasses+2010 FIFA world cup 3D disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','stefano998','cazzli@gmx.ch','Stefano Cazzato','Holzmattstrasse 38','Dietikon','','SWITZERLAND','8953','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 13:56:15',0,NULL,3,1,3,1,'RA184556861CN ','GLSG001*2+BR3D008 '),(17891,604220465004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','timsalabim1979','timtiel@gmail.com','Tim Tiel','Lijsterbes 13','HELLEVOETSLUIS','','NETHERLANDS','3224RD','0621179008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 14:00:00',0,NULL,3,1,3,1,'RA117765734CN ','OTHP004 '),(17892,598834504003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','rounders13','jftrembl@gmail.com','Jean-Francois Tremblay','1425 Boul. le Corbusier<br>Apt. 308','Laval','QC','CANADA','H7N6L1','(514) 561-6743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 14:01:23',0,NULL,3,1,3,1,'RA117765266CN ','MOOE003\rOEM '),(17893,811304666011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','shoeboxwine','sschupbach@yahoo.com','Pamela   Schupbach','11195 Stratford Pl','Belvidere','IL','UNITED STATES','61008','(815) 885-3682','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 14:41:27',0,NULL,3,1,1,1,'\\ ',NULL),(17894,811265558011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','vivaknievl89','tgselby@hotmail.co.uk','Tom Selby','344 Cowley Road','Oxford','Oxfordshire','UNITED KINGDOM','OX4 2AG','02083408422','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 15:03:27',0,NULL,3,1,3,1,'RA117765460CN\r ','RELO003 '),(17895,811324174011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','sotos83','psaltides@gmail.com','Sotiris Psaltidis','Grigoriou E\' 19','Drama','Greece','GREECE','66100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 15:09:17',0,NULL,3,1,11,1,NULL,'MOAP001\r不挂号 '),(17896,898990103012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',11.99,'eastar4uk','sjholmes18','gouldmark@sky.com','Suzanne Holmes','27 Royal Star close<br>Kitts Green','Birmingham','West Midlands','UNITED KINGDOM','B33 0YR','07738222127','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 15:10:54',0,NULL,3,1,3,1,'RA117765575CN ','MOHP001 '),(17897,898997151012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','rjpickard','rjpickard@lineone.net','Richard Pickard','Orchard House,','Kilmeston,','Hampshire','UNITED KINGDOM','SO24 0NL','01962793424','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 15:17:35',0,NULL,3,1,3,1,'RA117765399CN ','OTSO004*3 '),(17898,598875181003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','ckinchoi','beer99@gmail.com','Inchul Choi','Hanyang APT D-1205<br>Youdio-dong Youngdungpo-gu','Seoul','','KOREA,REPUBLIC OF','150-796','821042540505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 15:28:52',0,NULL,3,1,3,1,'RA184541297CN ','WLAT003 '),(17899,657421869013,230641257901,'New lady lace trim sun/rain stick Umbrella blue',1,'UM00011',24.99,'eastar4','minnyfan','dtriley@optonline.net','DOUGLAS RILEY','19 Winside Ln','coram','NY','UNITED STATES','11727-1134','(631) 642-3364','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 16:30:53',0,NULL,3,1,1,1,'、 ','蕾丝花边伞  '),(17900,899066345012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','jordisaskia','jordi1269@hotmail.com','Jordi Piñol Curto','Av.Generalitat 147 Baixos','Tortosa','Cataluña','SPAIN','43500','977441727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 16:36:29',0,NULL,3,1,3,1,'RA117765836CN ','GLOT001*2 \r兼容型3D眼镜 通用型'),(17901,657433386013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','bp10269','bjpaxton@charter.net','Bill Paxton','8060 Shady Ln','Traverse City','MI','UNITED STATES','49685-9035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 16:46:27',0,NULL,3,1,6,1,'EE495359605CN ','GLOT001*4\r兼容型3D眼镜 通用型 '),(17902,810740024011,320791705383,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',37.99,'eastar4uk','litsapanos','info@delis-sound.gr','panos delis','p.e.o. korinth - patron 224, lehaio','lehaio','korintias, pelloponissos','GREECE','20011','00306972723998','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 17:13:42',0,NULL,3,1,3,1,'RA117765345CN ','GPS0006 '),(17903,811435068011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','rjbfjb','barbini@verizon.net','Richard J. Barbini','4 Road To The Plns','Edgartown','MA','UNITED STATES','02539-7151','(508) 958-4329','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 17:17:27',0,NULL,3,1,1,1,' \\',NULL),(17904,657457187013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','sypheron','sypheron@hotmail.com','RWM van Mourik','Lisdodde 46','Tegelen','','NETHERLANDS','5931TG','0031639458156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 17:19:54',0,NULL,3,1,11,1,NULL,'OTCN001\r不挂号 '),(17905,748085601008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','peanut52553','klsuchar@shaw.ca','Karen Suchar','263093 Butte Hills Way','Rocky View County','AB','CANADA','T4A0N9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 17:53:09',0,NULL,3,1,3,1,'RA117765986CN\r ','HBPH007 '),(17906,811256421011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','267*barkleysboy','edwilliams00@hotmail.com','eric williams','1326 n percty st','philadelphia','PA','UNITED STATES','19122','(212) 313-4557','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 17:55:07',0,NULL,3,1,1,1,'\\ ',NULL),(17907,899176569012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','miketoy','mike.j.thomas@uwclub.net','Michael Thomas','8,Beech close<br>Highnam','Gloucester','Gloucestershire','UNITED KINGDOM','GL2 8EG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 18:10:57',0,NULL,3,1,11,1,NULL,'不挂号\rMOAP001 '),(17908,810911416002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','jbq9190','jbq919@aol.com','janice quinn','2782 Lansdowne Lane','Atlanta','GA','UNITED STATES','30339','(770) 434-0063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 17:56:52',0,NULL,3,1,1,1,' \\',NULL),(17909,811524153011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','1221andrews','richard.andrews04@googlemail.com','Richard Andrews','9 Anns Close','Tring','Hertfordshire','UNITED KINGDOM','HP23 4HA','01442825540','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 18:34:07',0,NULL,3,1,3,1,'RA117765500CN\r ','RELO003 '),(17910,604396511004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','mary4944','mjanke31@wi.rr.com','Mary Janke','6552 N 58th St','Milwaukee','WI','UNITED STATES','53223-5921','(414) 353-6155','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,0,17,0,' ',NULL),(17911,604396432004,140644120633,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones  long cable red',1,'HSPH002',37.6,'cnfaner','avi55300avi','avi55300@walla.com','gila koriat','harishonym 11','bat yaam','','ISRAEL','59313','0504022411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 18:37:52',0,NULL,3,1,3,1,'RA117765337CN ','HSPH002\rred 红色的 '),(17912,604399660004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','mary4944','mjanke31@wi.rr.com','Mary Janke','6552 N 58th St','Milwaukee','WI','UNITED STATES','53223-5921','(414) 353-6155','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,''),(17913,604430767004,140644120619,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip silver',1,'SHLO008',12.95,'cnfaner','krister55','krister.westin@bredband.net','Krister  Westin','Storg. 58','PITEÅ','','SWEDEN','941 32','0911-18154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 19:12:55',0,NULL,3,1,3,1,'RA117765990CN\r ','SHLO008 \rsilver 银色的'),(17914,604447417004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.59,'cnfaner','vvsk555','vadimus555@yandex.ru','Vadim Skosyrev','Novoyasenevskiy Prospect, 14/2, 24','Moscow','','RUSSIAN FEDERATION','117574','+79854111844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 19:25:09',0,NULL,3,1,3,1,'RA117765717CN ','LGGL003 '),(17915,757982939007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','ntanosperama','billmathioudakis@hotmail.com','VASILIOS MATHIOUDAKIS','NIKOLAOY PANTAZH 4','NAFPAKTOS','GREECE','GREECE','GR 30300','00306936503526','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 19:45:25',0,NULL,3,1,11,1,NULL,'SCLO001\r不挂号 '),(17916,811634500011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','lesia33','glenpoint@gmail.com','Elena Glushchenko','ul.Olhovaya, dom 5, kv.10','Leninskiy r-on, Sosenskoe s/p., pos. Dubrovka','Moskovskaya obl,','RUSSIAN FEDERATION','142770','+79161550200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 19:52:00',0,NULL,3,1,3,1,'RA117765495CN\r ','HBPH002 '),(17917,604493323004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',38.7,'cnfaner','seifer_ru','sokolovds@gmail.com','Dmitriy Sokolov','16 Timme str.<br>apt. 106','Arkhangelsk','Arkhangelsk','RUSSIAN FEDERATION','163061','(921) 296 - 7313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 20:19:01',0,NULL,3,1,3,1,'RA117765677CN\r ','CACN004 '),(17918,811684576011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','rootphish','wouter@sonneveldt.net','Wouter Sonneveldt','Rietgras 7','Den Haag','','NETHERLANDS','2498 EH','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 20:34:42',0,NULL,3,1,11,1,NULL,'OTHP005\r不挂号 '),(17919,657639288013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','uri.tal','t_uri@yahoo.com','Uri Tal','P.O. box 3286<br>Yahalom 10','Bet-Yehoshua','','ISRAEL','40591','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-12-11 20:36:59',0,NULL,3,1,11,1,NULL,'HSNO019\r不挂号 '),(17920,657627029013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','clguerrant11','clguerrant@ymail.com','christina guerrant','4936 W Point Loma Blvd<br>apt c','San Diego','CA','UNITED STATES','92107-1311','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 20:23:12',0,NULL,3,1,1,1,'\\ ',NULL),(17921,899385913012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','mpiotrowska','martaptrwsk@gmail.com','Marta Piotrowska','57 Stamford Street<br>Flat 13','London','London','UNITED KINGDOM','SE1 9DJ','07912107343','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 20:41:15',0,NULL,3,1,3,1,'RA117765456CN\r ','OTHP004 '),(17922,811704159011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',9.49,'eastar4','nick_s99','nick.sukonnik@gmail.com','Mukola Sukonnik','15 Kvitnya 29/23','Ternopil','Ternopil','UKRAINE','46000','380677500597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 20:52:56',0,NULL,3,1,11,1,NULL,'不挂号\rWLAT006 '),(17923,811150918002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','tstraubie','tastraubie@att.net','Teresa Walker','302 Cory Cv','Marion','AR','UNITED STATES','72364-2528','(870) 514-4107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 21:20:17',0,NULL,3,1,1,1,'\\ ',NULL),(17924,758116503007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','lesty69','clestone5@bigpond.com.au','jeffrey lestone','59 chelsea drive , condon','townsville','Queensland','AUSTRALIA','4815','0747239791','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 22:07:37',0,NULL,3,1,3,1,'RA184557005CN ','RCLO003 '),(17925,758120565007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','vwfann','jrmeo2@gmail.com','Martin D. Meo Jr.','130 Shewell Ave','Doylestown','PA','UNITED STATES','18901-3725','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 22:10:53',0,NULL,3,1,1,1,' \\',NULL),(17926,899474797012,220748695642,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',4.9,'eastar4uk','tiredpilot','omargharib@msn.com','Omar Durkin-Gharib','62 Riverside Wharf<br>Riverside','Bishops Stortford','Hertfordshire','UNITED KINGDOM','CM23 3GP','07967078713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 22:19:12',0,NULL,3,1,3,1,'RA117765181CN\r ','OTCA001 '),(17927,811777036011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3002',19.98,'eastar4','blackandmortimer','maitrejeantinou@yahoo.fr','Gérard Maitrejean','4, Onzieme avenue','Lamorlaye','Picardie','FRANCE','60260','0660748533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 22:21:43',0,NULL,3,1,11,1,NULL,'BTHP3002 \r不挂号\rHP 6pin1.0 3cm'),(17928,657699320013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','samoner10','samoshin.valentin@gmail.com','Валентин Самошин','пролетарский проспект, д. 1, кв. 124','Щелково','М О','RUSSIAN FEDERATION','141100','+7(926)3504407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 22:24:51',0,NULL,3,1,3,1,'RA117765853CN ','GLOT001*2 \r兼容型3D眼镜 通用型'),(17929,657723952013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','sell2u247$','mrucks@comcast.net','Michelle  Rucks','959 Blue Fox Way','Arnold','MD','UNITED STATES','21012-1872','(443) 995-9218','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 23:06:47',0,NULL,3,1,6,1,'EE495359619CN ','兼容型3D眼镜 通用型 '),(17930,599195287003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','volleyballer','earl.capps@sungard.com','Earl Capps','7499 E Paradise Ln<br>Sungard Availability Services Ste 108','Scottsdale','AZ','UNITED STATES','85260-1690','(480) 367-4102','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-11 23:21:26',0,NULL,3,1,1,1,' \\',NULL),(17931,811223286002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','john91480','explor@earthlink.net','John M  Iele','6247 Harcross Ct<br>null','Spring Hill','FL','UNITED STATES','34606-5613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 23:26:50',0,NULL,3,1,1,1,'\\ ',NULL),(17932,899521011012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',3,'WLAT009',29.94,'eastar4','gaetan3835595','gaetan@sogetel.net','gaetan chabot','475 rang 4','st-cyprien des etchemins','QC','CANADA','G0R1B0','(418) 383-5595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 23:39:37',0,NULL,3,1,11,1,NULL,'WLAT009\r不挂号 '),(17933,657739252013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','zhipeng2011','jasonxu1982@hotmail.com','Zhipeng xu','56 Cariglia Tr','markham','ON','CANADA','L3R 4W8','(647) 282-3332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 23:56:52',0,NULL,3,1,3,1,'RA117765297CN\r ','GLOT001*4 \r兼容型3D眼镜 通用型'),(17934,899531404012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','windfang11','windfang.ricardo@gmail.com','RICARDO Alves','Estrada do Guilherme, lote 12 n58','CALVARIA DE CIMA','LEIRIA','PORTUGAL','2480-057','0351 938143908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 00:20:38',0,NULL,3,1,3,1,'RA117765867CN\r ','HSPL013 \r欧标'),(17935,758211876007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','coutbry','couturebryan@gmail.com','Bryan Couture','1532 St-Calixte','Plessisville','QC','CANADA','G6L 1P6','(514) 467-1767','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 01:41:20',0,NULL,3,1,11,1,' ','RCLO007+POLO001+RCLO008*4\r不挂号 '),(17936,8881323654411705,111,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card',10,'WLIN015',139.9,'aliexpress','1005718859','engmaxalves@gmail.com','﻿Maximiliano ﻿ Alves','Rua Giuseppe Barbieri, 197','Sao Paulo','SP','BRAZIL','04850040','+55 11 55285009',NULL,NULL,NULL,'2011-12-12 01:46:51',0,NULL,3,1,3,1,'RA117765195CN\r ',' '),(17937,8881323655651583,111,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card',10,'WLIN015',139.9,'aliexpress','1005718859','engmaxalves@gmail.com','﻿Maximiliano ﻿ Alves','Rua Giuseppe Barbieri, 197','Sao Paulo','SP','BRAZIL','04850040','+55 11 55285009',NULL,NULL,NULL,'2011-12-12 01:46:51',0,NULL,7,0,18,0,NULL,NULL),(17938,657804990013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','scrotazmo','jrmyschrdr@yahoo.com','jeremy schroeder','10856 Hanson Blvd NW<br>Unit 4','coon rapids','MN','UNITED STATES','55433-4575','(612) 636-8993','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 03:06:20',0,NULL,3,1,1,1,'、 ',' '),(17939,8881323659575218,111,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',0,'au-buy','jan-haefliger','janputz@anthromedia.de','Jan Haefliger','Am Heidegraben 7','Vettweiß-Müddersheim','','GERMANY','52391','',NULL,NULL,NULL,'2011-12-12 03:12:55',0,NULL,3,1,3,1,'RA184541442CN ',' HBPH007\r测试电池能充满电 并且牙刷柄正常工作再发货'),(17940,657810817013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','dcwholesale','admin@dcwholesale.co.nz','Anthony Payne','PO BOX 40','KAIAPOI','','NEW ZEALAND','7644','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 03:13:20',0,NULL,3,1,11,1,NULL,'CASS003 \rCAB-6060'),(17941,657810276013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','8boomboom3','harterm4@juno.com','Mike  Harter','28911 NW 70th Ct','Ridgefield','WA','UNITED STATES','98642','(360) 608-2457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 03:15:11',0,NULL,3,1,6,1,'EE495359534CN ','兼容型3D眼镜 通用型 '),(17942,899121488012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',37.85,'eastar4','gene1085','gsinda@capac.k12.mi.us','Gene Sinda','1085 Capac Rd','Berlin','MI','UNITED STATES','48002-3005','(810) 395-7595','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 03:40:38',0,NULL,3,1,1,1,'、 ','AUI Transceiver  MX20T'),(17943,811923589011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','rwlangdale','rwlangdale@yahoo.com','ryan langdale','2133 N Brighton St','burbank','CA','UNITED STATES','91504-3315','(808) 497-6856','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 03:47:05',0,NULL,3,1,1,1,'、 ',NULL),(17944,811928262011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','gwidme01','giovanni.widmer@tufts.edu','Giovanni Widmer','325 Albemarle Rd','Newtonville','MA','UNITED STATES','02460-1358','(617) 796-9066','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 04:00:27',0,NULL,3,1,1,1,'、 ',NULL),(17945,758267009007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','ilyana08','pinky13blue@yahoo.com','Ilyana Zafirah Mohd Fauzy','10, Jalan Shahbandar 12/7','Shah Alam','Selangor','MALAYSIA','40100','0104640712','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 04:02:20',0,NULL,3,1,11,1,'RA117765685CN\r ','UM00033'),(17946,8881323663804413,111,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',0,'eastar4','basepickers','basepickersebay@gmail.com','Jesse Reynolds c/o Jim Wiegand','200 Forge Rd','Calverton','NY','UNITED STATES','11933-1604','(802) 355-3414',NULL,NULL,NULL,'2011-12-12 04:23:24',0,NULL,3,1,1,1,'LK047313240CN ','补发的 \r改个地址 \r'),(17947,758279040007,170737835667,'2 pairs LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'au-buy','jstoj110484','jstoj@hotmail.com','Julie Stojanovska','47 St Andrews Blvd','Casula, Sydney','New South Wales','AUSTRALIA','2170','0422311090','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(17948,811358405002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',32.98,'buysia','shaynono1','shaynox@hotmail.com','shane howarth','24 Gibbes street','regentville','New South Wales','AUSTRALIA','2745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 04:51:30',0,NULL,3,1,3,1,'RA117765915CN ','BR3D009\rAlice in Wonderland New sealed 3D Blu-ray Region: A,B,C\r一共两个 '),(17949,8881323666344217,111,'补发一个USB CABLE',1,'HSJA002',0,'eastar4','alrds724','aleros1224@yahoo.com','alex rodas','2115 powder mist ln','katy','TX','UNITED STATES','77449-3136','(832) 386-7621',NULL,NULL,NULL,'2011-12-12 05:05:44',0,NULL,3,0,1,1,'LK114277030CN ',' 补发一个USB CABLE\r改个地址'),(17950,604687168004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','gharrs0010','gharris0010@gmail.com','George Harris','1132 Rothwood Way','Apex','NC','UNITED STATES','27502-4309','(919) 720-2403','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-12 05:06:55',0,NULL,3,1,1,1,'、 ',NULL),(17951,657846595013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','shengjianlin','shengjianlin2009@yahoo.com','shenghui lin','1198 George Towne Dr','Pewaukee','WI','UNITED STATES','53072-2752','(347) 259-5536','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 05:39:56',0,NULL,3,1,1,1,'、 ','黑色的 '),(17952,811918235011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',18.4,'eastar4','jjk999-auctions','john@keyburn.net','John Keyburn','1449 Stuckert Rd','Warrington','PA','UNITED STATES','18976-1526','(267) 266-0147','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 06:03:48',0,NULL,3,1,1,1,'、 ','微软的 '),(17953,657855871013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',1,'UDAP004',22.99,'eastar4','lokostex2011','lokostex@gmail.com','Dmitry Simonov','4283 Express Ln<br>Ste R5620','Sarasota','FL','UNITED STATES','34238-2602','(941) 538-6941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 06:34:29',0,NULL,3,1,1,1,'、 ',NULL),(17954,899509497012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',159.99,'eastar4','tuliso','jbtuliso@gmail.com','Maria Dolores Perez Ugena','Calle de Francia 5 - 4º B','Fuenlabrada','Madrid','SPAIN','28943','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:13:43',0,NULL,3,1,3,1,'RA117765601CN ','GLSG001*3 '),(17955,599314777003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','ozipovart','olena.osipov@gmail.com','Ozipov Art','#1122-11497 236th St','Maple Ridge','BC','CANADA','V2W 2E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:22:33',0,NULL,3,1,3,1,'RA117765924CN\r ','MOAP001 '),(17956,604712248004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','cp0282','papasavva@bigpond.com','Chris Papasavva','22 Altair Street','Springvale South','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:34:51',0,NULL,5,1,3,1,'\\ ','RELO003 \r点不了，已发货'),(17957,657868622013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jiraw_mike','jiraw@msn.com','Jira Srikasatwanich','149 Rodrang-kao Rd.,<br>Sumrong-Tai,','Phrapradaeng','Samutprakarn','THAILAND','10130','66818231876','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:51:24',0,NULL,3,1,11,1,NULL,'不挂号\rCACN004 '),(17958,811986347011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','xdarrowx','shawndregan@gmail.com','Shawn Regan','7729 Adrian Dr','Rohnert Park','CA','UNITED STATES','94928-3933','(707) 326-5075','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 07:55:29',0,NULL,3,1,1,1,'、 ',NULL),(17959,811989744011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','vicbarr2953','victor@vicbarr2953.plus.com','victor barrera','4 tillett close','ormesby st. margaret','Norfolk','UNITED KINGDOM','NR29 3PW','01493733713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 08:08:09',0,NULL,3,1,3,1,'RA117765513CN ','GLSG001 '),(17960,8881323678976464,111,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',137.99,'eastar4','kay180668','kay1806@mail.ru','Yuriy Kalashnik','68, Pestelya str.','Kharkov','','UKRAINE','61161','',NULL,NULL,NULL,'2011-12-12 08:36:16',0,NULL,3,1,3,1,'RA117765527CN\r ','OTSO004 \r直接打款的'),(17961,899719032012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','geekfixnz','doughall@geekfix.co.nz','Douglas Hall','34 Campbells Road<br>Pine Hill','Dunedin','Otago','NEW ZEALAND','9010','021 775773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 08:40:38',0,NULL,3,1,11,1,'RA184541116CN ','HSJA010\r已入库\r发之前测试一下\r换发成 BT500\r客户补了差价 \r\r'),(17962,8881323680239950,111,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',0,'au-buy','jamie_baby77','jamie_mccloud@hotmail.com','James McCloud','Unit 1<br>15  Longueville Road','Lane Cove, Sydney','New South Wales','AUSTRALIA','2066','',NULL,NULL,NULL,'2011-12-12 08:57:19',0,NULL,5,1,18,0,NULL,'RELO003\r补发 在问兼容与否 '),(17963,899724544012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','wutangbiz','doru.anusca@gmail.com','Teodor Anusca','Str. Tineretului Nr.5 Ap.53','Floresti','Cluj','ROMANIA','407280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 08:57:34',0,NULL,3,1,3,1,'RA184541164CN ','WWOT001 \r通用版 全新'),(17964,899731601012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',63.99,'eastar4uk','undeground_07','alesxs@rambler.ru','Prokaev Alexander','Chkalova 3-2','Chernyakhovsk','RU','RUSSIAN FEDERATION','238152','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 09:27:08',0,NULL,3,1,3,1,'RA184541249CN ','Prokaev Alexander\rChkalova 3-2\rChernyakhovsk RU 238 152\rRussian Federation\r '),(17965,8881323687700991,111,'CAB-6060',60,'CASS003',810,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815',NULL,NULL,NULL,'2011-12-12 11:01:40',0,NULL,3,1,12,1,'2771128706\r ','CASS001+CASS002+CASS003\r一共买了 60条CAB-6060 \r40条CAB-2660 \r30条CAB-2626 \r申报30美金\r实重16.8  泡重9.7'),(17966,812045718011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.39,'eastar4','alekseydel','alex-sw@i.ua','Onanchenko Serhiy','Perekopskaya-str., 16<br>Apt. 2','Sumy','','UKRAINE','40000','+380 953111555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 11:12:29',0,NULL,3,1,11,1,'、 ','BTHP2107\rHP 8pin 1.0 23cm  '),(17967,604761983004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',50.99,'cnfaner','tsampoyras','ueotsa@yahoo.gr','THEOFANIS TSAMPOS','24 km  salonika - Kilkis<br>6938369256   2341075575-6','Kilkis','NSanta','GREECE','61100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 11:37:51',0,NULL,3,1,3,1,'RA184541204CN ','LGFI001 '),(17968,812057921011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',2,'GLOT001',89.78,'eastar4','caradriel73','bachris73@hotmail.com','Christelle BACH','13 rue Valery Larbaud','Saint-Germain des Fossés','Auvergne','FRANCE','03260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 11:48:29',0,NULL,3,1,3,1,'RA184541093CN ','GLOT001 \r兼容型3D眼镜 通用型'),(17969,812084456011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','wildune','dgeng@aol.com','Donna Gasper','59 Byam Rd','Chelmsford','MA','UNITED STATES','01824-3837','(978) 250-9581','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 13:01:10',0,NULL,3,1,1,1,'、  ',NULL),(17970,812084873011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',109.98,'eastar4','sandribm','sandribm@hotmail.com','Alexandra Blasco Más','Avd Jubalcoi, 36 - 3 p8','Elche','Comunidad Valenciana','SPAIN','03202','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 13:02:49',0,NULL,3,1,3,1,'RA184541218CN ','GLSG001 '),(17971,657940238013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','stebbins2','lbstebbins@gmail.com','linda stebbins','10 Labrie Ln','holyoke','MA','UNITED STATES','01040-9645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 13:11:13',0,NULL,3,1,1,1,'、  ',NULL),(17972,758426011007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','bfd1262','alisondavette@roadrunner.com','Michael Kamp','47 Creekledge Ln','Copley','OH','UNITED STATES','44321-3221','(330) 670-6420','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(17973,657945561013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',265.98,'eastar4','salkahusavik','jemils@mac.com','Jonas Emilsson','Heidargerdi 11','Husavik','S-Thing','ICELAND','0640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 13:41:04',0,NULL,3,1,3,1,'EE636828886CN\rRR938029975CN','EGLOT001*3 \r兼容型3D眼镜 通用型\r一共买了六副'),(17974,899842971012,220504387390,'2.1 Acer Timeline 4810 5810 Bluetooth Module EDR+ cable',1,'BTAC2101',12.39,'eastar4','arhi248','radkevich.ap@gmail.com','Artur Radkevich','ul. Moskovskoe shosse, d. 41, kv. 14','Serpukhov','Moskovskay oblast','RUSSIAN FEDERATION','142211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:11:14',0,NULL,3,1,11,1,'、 ','BTAC2101 \racer 4pin1.25 3cm '),(17975,899845519012,220816847779,'New Plantronics Voyager 520 Bluetooth Headset',1,'HSPL011',20.65,'eastar4uk','mitakhatri64','mitakhatri@hotmail.com','Dilipkumar Khatri','Atlantis Drycleaners<br>530 Harrow Road','Maida Vale','London','UNITED KINGDOM','W9 3QF','02089607190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 14:16:57',0,NULL,3,1,3,1,'RA184541195CN ','HSPL011 英标\r\r'),(17976,599406898003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','andonov09','andonovivan@hotmail.com','Ivan Andonov','Epimenonda Pop-Andonov 34','Strumica','','SLOVENIA','2400','340-179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:24:45',0,NULL,3,1,3,1,'RA184541178CN ','HSPL005\r欧标 '),(17977,657963300013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','balayalex','alexbalay@gmail.com','Alexander Balaev','Severnoe Chertanovo 4-403-243','Moscow','','RUSSIAN FEDERATION','117648','+79166174139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:24:54',0,NULL,3,1,11,1,'、 ','WLIN014 '),(17978,899872082012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','noesis01','alderson791@gmail.com','Douglas Alderson','791 Cameron Dr','Antioch','IL','UNITED STATES','60002-1102','(847) 838-0627','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 15:14:52',0,NULL,3,1,1,1,'、  ',NULL),(17979,899877178012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','javierg2631','javiergama464@hotmail.com','JAVIER GAMA','1812 Bluestem Cir','AURORA','IL','UNITED STATES','60504-4395','(630) 392-4743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 15:25:55',0,NULL,3,1,1,1,'、  ','兼容型3D眼镜 通用型 '),(17980,899895569012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','sadiemaec27577','sfcomeford@yahoo.com','Elizabeth Fair','20 Sallie Dr','Smithfield','NC','UNITED STATES','27577-7972','(919) 938-3777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 15:59:14',0,NULL,3,1,1,1,'、  ',NULL),(17981,811586801002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','dingulus','uwe.roeder@gmx.at','Uwe Roeder','Theodor Koernergasse 30 Top 24','Vienna','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 16:21:30',0,NULL,3,1,11,1,'、 ','BR3D005 '),(17982,599459959003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','gilrodsan-2008','gilrodsan@gmail.com','Gilberto Rodrigues santos','Rua Vina del Mar 85, apto 401, Cavaleiros','Macaé','Rio de Janeiro','BRAZIL','27920-190','+55-22-2761-7371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 16:49:37',0,NULL,3,1,3,1,'RA184541181CN ','LGRM001 '),(17983,812218176011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','electronicsa12010','sales@a-1electronics.net','osama shublaq','9930 S 86th Ct','palos hills','IL','UNITED STATES','60465-1102','(708) 612-8222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 17:41:53',0,NULL,3,1,1,1,'、  ','兼容型3D眼镜 通用型 '),(17984,604874054004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',53.99,'cnfaner','boxter100','boxter100@yandex.ru','Dmitriy Lepilkin','Kurskaya street 57, flat 47','Astrakhan','Astrakhanskaya oblast\'','RUSSIAN FEDERATION','414004','89608533361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 17:43:03',0,NULL,3,1,3,1,'RA184541221CN ','GLSG001 '),(17985,750780125008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',2,'GLOT006',89.98,'au-buy','10marc1958','marc.depriester@sfr.fr','marc depriester','7 rue Claude Gignoux','Nimes','Languedoc-Roussillon','FRANCE','30000','0618265229','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 17:56:11',0,NULL,3,1,3,1,'RA184541014CN ','GLOT006 '),(17986,812259127011,320786773873,'New Nokia HS-26W Bluetooch Headset HS 26W',2,'HSNO032',19.98,'eastar4uk','2017642','ken.mirza@btinternet.com','Andrea Mirza','17 The Hazels<br>Wigmore','Gillingham','Kent','UNITED KINGDOM','ME8 0SE','01634364931','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 18:44:08',0,NULL,3,1,3,1,'RA184541147CN ','HSNO032 \r英标'),(17987,812273568011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','jazi2134','jimazinger@hotmail.com','Jim Azinger','23303 NE 178th Street','Brush Prairie','WA','UNITED STATES','98606','(360) 907-5658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 19:02:22',0,NULL,3,1,1,1,'、  ',NULL),(17988,658085011013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','wardrobesecrets','irie2dae@aol.com','Karlee Hughes','9414 El Camino Ave','Fountain Valley','CA','UNITED STATES','92708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 19:15:11',0,NULL,3,1,1,1,'、  ',NULL),(17989,765439254001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','galmercad','galmerkado@gmail.com','Omri Levy','Ficus 17<br>Apt.2','Gadera','','ISRAEL','70700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 19:19:58',0,NULL,3,1,11,1,'、 ','galmercad '),(17990,758616520007,170737835667,'2 pairs LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'au-buy','amelielemieux','florida1967@hotmail.com','florida sonier','189 Goyer','st-eustache','QC','CANADA','J7P 5E6','(450) 473-2947','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 19:24:13',0,NULL,3,1,3,1,'RA184541252CN ','LGGL002*2 '),(17991,604925383004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 19:25:55',0,NULL,3,1,3,1,'RA184541155CN ','HSJA010\r欧标 '),(17992,658098651013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','cnt91','cnt91@yahoo.com','Carrie A Steele','1629 NE Daphne Ct','Bend','OR','UNITED STATES','97701-4185','(541) 306-4567','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-12 19:39:19',0,NULL,3,1,1,1,'、 ',NULL),(17993,900062278012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',159.99,'eastar4','laurentbastide30','alex.larry@free.fr','Laurent BASTIDE','80 Avenue Amédée Mercier','BOURG EN BRESSE','Rhône-Alpes','FRANCE','01000','04 90 23 34 92','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 19:58:56',0,NULL,3,1,3,1,'RA184541306CN ','GLSG001*3 '),(17994,599553212003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','perdan11','per-l@hotmail.com','per langkjær','østervænget 11<br>vonsild','kolding','standard','DENMARK','6000','+4540793973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:08:26',0,NULL,3,1,3,1,'RA184541235CN ','MOOE003 \rOEM'),(17995,812330760011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','stasbarmin','stas.barmin@gmail.com','Stanislav Barmin','Mendeleeva, 26, 114','Nizhny Novgorod','Nizhegorodskaya obl','RUSSIAN FEDERATION','603011','79036005742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:17:29',0,NULL,3,1,11,1,'、 ','BTAC2006 \racer 4pin1.25 15cm '),(17996,812332817011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','silverclash2011','silver_clash@mail.ru','Алексей Журавлев','Novomar\'inskaya st., 17-303','Moscow','','RUSSIAN FEDERATION','109451','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:19:07',0,NULL,3,1,11,1,'、 ','WLIN010+ANTY002 '),(17997,900082480012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','roastbeefs','bpfishback@mymail.aacc.edu','Bryan Fishback','904 MAGO VISTA RD','ARNOLD','MD','UNITED STATES','21012-1345','(443) 370-7616','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 20:23:10',0,NULL,3,1,1,1,'、  ','AUI Transceiver  MX20T '),(17998,812352594011,320394916388,'Acer Aspire 5570 5570Z Bluetooth Module EDR 2.0+cable',1,'BTAC2015',9.88,'eastar4','mursic4','marko@ursic.net','Marko Uršič','Linhartova 104','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:46:14',0,NULL,3,1,11,1,'、 ','BTAC2015\racer 6pin1.25 23cm  '),(17999,604969234004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','686475ad','ahmad_dell@hotmail.com','Ahmed Fatah Abdullah','Lindblomsvägen 79','Ronneby','Blekinge','SWEDEN','372 33','0731019062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:49:12',0,NULL,3,1,3,1,'RA184541120CN ','HSPL013\r欧标 '),(18000,900109780012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','graham07811','gp@grahamprice.co.uk','Graham Price','26 Dewlands','Godstone','Surrey','UNITED KINGDOM','RH98BS','07811110033','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 20:57:53',0,NULL,3,1,3,1,'RA184541133CN ','HSMO019 \r英标'),(18001,599584688003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','mondekk','mondeusz@interia.pl','DOMINIK DABEK','3 Longford Ct','Epsom','Surrey','UNITED KINGDOM','KT19 9PX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 21:12:38',0,NULL,3,1,3,1,'RA184541062CN ','MOLO006 '),(18002,812376080011,320812367902,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','gaate4','yiannismp@gmail.com','YIANNIS BALOUKAS','I.VASILIADI 34<br>GIANNITSA','PELLA','N PELLAS','GREECE','58100','6937301907','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 21:20:45',0,NULL,3,1,3,1,'RA184541371CN ','HSNO033 \r欧标'),(18003,658155422013,230552619227,'NEW ZAGG SPARQ 2.0 BATTERY USB CHARGER',3,'BAZA001',164.97,'eastar4','fmoraes1972','f_mor_r@yahoo.com.br','Fernando Moraes Rosa','Domingos Latorre 84','Sorocaba','Sâo Paulo','BRAZIL','18046-420','55-15-9771 7004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 21:25:25',0,NULL,3,1,3,1,'RA184541102CN ','BAZA001 '),(18004,900142971012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','tomjohnson34','tomj@omnicast.net','John D Thompson','3818 E. Frederick Ave.','Spokane','WA','UNITED STATES','99217','(509) 489-1312','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 21:42:00',0,NULL,3,1,1,1,'、  ','向日葵长柄伞 '),(18005,900149237012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','raymond3088','rayco@hotmail.ca','Raymond Cooke','4 Chemin de la Famille','RIPON','QC','CANADA','j0v1v0','(819) 428-2081','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 21:51:22',0,NULL,3,1,3,1,'RA184541080CN ','LGRM001 '),(18006,900172218012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','nickygstirrups','punk_nicky@hotmail.com','Nicky Geerse','Spaarndamseweg 236-903','Haarlem','','NETHERLANDS','2021KA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 22:27:52',0,NULL,3,1,11,1,'、 ','OTCR001 '),(18007,658194685013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','reusedpartsstore','ben_grutsch@hotmail.com','Grutsch Plumbing and Heating','PO Box 115<br>34127 County Rd 9 N','Avon','MN','UNITED STATES','56310-0115','(320) 761-1200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 22:57:12',0,NULL,3,1,1,1,'、  ','罗兰LOWRANCE finder H2OC  GPS 彩色  '),(18008,811868184002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','jnfeze','eric_persaud@hotmail.com','Eric Persaud','242 Gosford Blvd','Toronto','ON','CANADA','M3N2H1','(647) 465-7745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 00:08:49',0,NULL,3,1,11,1,'、 ','BR3D005 '),(18009,658217377013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','xhaon','xhaon@msn.com','Jose Javier Estrada Jimenez','Calle Platino Nº56','Huercal de Almería','Almeria','SPAIN','04230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 00:09:02',0,NULL,3,1,11,1,'、\r ','OTCN001 '),(18010,755269452007,170730545598,'NEW sealed Logitech Wireless Laser Mouse M505 plus unifying receiver',1,'MOLO008',35.5,'au-buy','ohnotthis','biznuz@adam.com.au','Paul Meier','159 Queen Street','Peterborough','South Australia','AUSTRALIA','5422','0886512398','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 00:16:27',0,NULL,3,1,3,1,'RA184541076CN ','MOLO008 '),(18011,755688548007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','amoeb4','yuliusrivan@gmail.com','yulius rivan','unit 6/37-39 Rosewood Ave','Prestons','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 00:21:12',0,NULL,3,1,11,1,'、\r ','UM00033 '),(18012,758786180007,170730544862,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse 90% like new',1,'MOLO003',37.99,'au-buy','zybch','zybch@hotmail.com','Mike Caddick','26 Jennings Street','Stawell','Victoria','AUSTRALIA','3380','0353582123','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 00:22:32',0,NULL,3,1,3,1,'RA184541399CN ','MOLO003 '),(18013,658222241013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','kaye0206','kayerees@optusnet.com.au','Kaye Rees','12 Carpenter Street','Brighton','Victoria','AUSTRALIA','3186','61439336795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 00:26:08',0,NULL,3,1,11,1,'、 ','WLIN010 '),(18014,811895621002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','iphonempls','justin.nordin@gmail.com','Justin Nordin','9 7th Pl W<br>Apt 324','Saint Paul','MN','UNITED STATES','55102-1172','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 01:24:02',0,NULL,3,1,1,1,'、  ',NULL),(18015,900252028012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','bobcrute','bob_and_holly_crute@hotmail.com','Robert L. Crute','4413 Kendal Ct','Suffolk','VA','UNITED STATES','23435-2834','(540) 341-0438','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 01:28:16',0,NULL,3,1,1,1,'、  ',NULL),(18016,8881323740625503,111,'LG 3D Active Shutter Glasses AG-S110',2,'LGGL002',91.98,'aliexpress','1005753163','rosich@uv.es','Paco ﻿Rosich	','General URRUTIA 65, 3-37','Valencia','Valencia','SPAIN','46013','+34 6 59484494',NULL,NULL,NULL,'2011-12-13 01:43:45',0,NULL,3,1,3,1,'RA184541796CN ',NULL),(18017,8881323740901652,111,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card',1,'WLIN015',14.99,'aliexpress','1005756989','igbzi2servs12yh@yahoo.co.jp','Hironori Ariyama','205,193-8,Otsuka,Hachioji-City','Hachioji-City','﻿Tokyo﻿','JAPAN','1920352','+810 090 54359573',NULL,NULL,NULL,'2011-12-13 01:48:21',0,NULL,3,1,3,1,'RA184541853CN\r ',NULL),(18018,8881323741170477,111,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',49.99,'aliexpress','1005758524','speedy.ebm@terra.com.br','edivaldo ﻿﻿mano','rua artur correia de toledo, 197','capivari﻿','brazil','BRAZIL','13360000','+55 19 34921457',NULL,NULL,NULL,'2011-12-13 01:52:50',0,NULL,3,1,3,1,'RA184541748CN\r ',NULL),(18019,812500869011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','rotorootie','rotorootie@cox.net','Douglas Roetman','11404 W Dodge Rd<br>Mcgill, Gotsdiner, Workman, Lepp Ste 500','Omaha','NE','UNITED STATES','68154-2584','(402) 492-9200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 01:58:06',0,NULL,3,1,1,1,'、  ','兼容型3D眼镜 通用型 '),(18020,746668467007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',12.99,'au-buy','arathorn14','lobocameron@yahoo.com','Cameron N Lobo','42-3400 Rhonda Valley','Mississauga','ON','CANADA','L5A3L9','(905) 275-1559','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 02:12:56',0,NULL,3,1,11,1,'、 ','HSPL002 '),(18021,812511373011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','jlarkin000','larkin@iit.edu','John W Larkin','366 Meadow Green Dr','Naperville','IL','UNITED STATES','60565-3210','(630) 305-9012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 02:25:06',0,NULL,3,1,1,1,'、  ',NULL),(18022,605078855004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','dantesparda2000','spardaforever@yahoo.com','Mun Hon Cheong','3/1,Boronia St,Kensington','Sydney','New South Wales','AUSTRALIA','2033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 02:26:29',0,NULL,3,1,3,1,'RA184541345CN ','OTHP005 '),(18023,900279688012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT006*3',132.99,'eastar4','sugacj','valerie_hamilton@att.net','valerie hamilton','23621 vera st','cleveland','OH','UNITED STATES','44128-5265','(216) 663-7843','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 02:39:56',0,NULL,3,1,1,1,'、 ','兼容型3D眼镜  Korea TV专用 '),(18024,751066749008,180757094376,'Original New Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',15.99,'au-buy','lg3o5','luis_g_305@hotmail.com','Luis Gonzalez','19800 NW 77th Pl','Hialeah','FL','UNITED STATES','33015-6408','(305) 767-0379','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 03:20:24',0,NULL,3,1,1,1,'、','SHLO005 '),(18025,812533803011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',57,'eastar4','pancir','candycarr@windstream.net','Candice S. Carr','3652 Shaffer Rd','Rock Creek','OH','UNITED STATES','44084-9728','(440) 478-2748','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 03:28:42',0,NULL,3,1,1,1,'、 ',NULL),(18026,8881323748661368,111,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',2,'BALO007',0,'eastar4uk','danlii','danlii@frozenbanana.net','Daniel Liikamaa','Jagaregatan 140','Lund','','SWEDEN','S-22653','',NULL,NULL,NULL,'2011-12-13 03:57:41',0,NULL,3,1,3,1,'RA184541323CN ','BALO007\r补货  \r新地址\rDaniel Liikamaa\rFralsevagen 9\rS-24465 Furulund\rSweden\r'),(18027,599705890003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',53.8,'cnfaner','thundercat607','ron.riddle@gmail.com','Ron S Riddle','235 Harvey Hill Rd','Ithaca','NY','UNITED STATES','14850','(607) 277-9779','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 04:00:44',0,NULL,3,1,1,1,'、 ',NULL),(18028,605103817004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','tuuf','tuufbiz@cox.net','Michael Wong','8515 S Willow Dr','Tempe','AZ','UNITED STATES','85284-2471','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 04:09:44',0,NULL,3,1,1,1,'、 ',NULL),(18029,8881323749518303,111,'philips travel charger  ',1,'HBPH003',16.5,'eastar4','metraa_01','dimitrea.hanley@gmail.com','Dimitrea A Hanley','1200 US Highway 22<br>U.s. Express #10136 Ste 2000','Bridgewater','NJ','UNITED STATES','08807-2943','',NULL,NULL,NULL,'2011-12-13 04:11:58',0,NULL,3,1,1,1,'LK108863194CN ','这是直接打的钱\r改个地址 '),(18030,8881323750479554,111,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',0,'cnfaner','disczones','albert@disczones.com','Albert  Kim','14841 WALNUT GROVE CT','TUSTIN','CA','UNITED STATES','92780-1603','(949) 829-3359',NULL,NULL,NULL,'2011-12-13 04:27:59',0,NULL,3,1,1,1,'LK108800971CN ','补发的 '),(18031,8881323750514406,111,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',0,'eastar4','scobarbr','pablo.marani@gmail.com','Fabiano Trambaioli','Rua Vigario Albernaz 785  - apt 12<br>- Vila Gumercindo','Sao Paulo','SP','BRAZIL','04134021','551182685280',NULL,NULL,NULL,'2011-12-13 04:28:34',0,NULL,3,1,11,1,'、 ','WLIN015 \r  无线蓝牙二合一'),(18032,598647900003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','jmatthey2000','mikemglee@gmail.com','Park Hojin(mp.010-3209-0034),','108-#401 SungHo shine hills apt.,<br>Bojeong-dong, Giheung-gu,','Yongin-si','Gyeonggi-do','KOREA,REPUBLIC OF','446-913','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 04:51:41',0,NULL,3,1,3,1,'RA184541354CN ','WLAT003 '),(18033,751099967008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'au-buy','dave_lh','daveij@internode.on.net','David Johnson','21 Montrose Avenue','Para Hills','South Australia','AUSTRALIA','5096','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 05:27:05',0,NULL,3,1,11,1,'、 ',' SCLO004'),(18034,605117455004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','gundurraga','otrobuzonmas@yahoo.com','marco montecino','7560 Eisenhower St','Ventura','CA','UNITED STATES','93003-2481','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 05:27:47',0,NULL,3,1,1,1,'\\ ',NULL),(18035,900336645012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','mgparq78','mgparquitectura@gmail.com','mgp arquitectura','circunvalacion pte 1208<br>col. jardines del moral','leon','guanajuato','MEXICO','37160','(52)477-1221558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 05:28:04',0,NULL,3,1,11,1,'、 ','OTCN005*10 \rVGA 转RJ45 white'),(18036,900339470012,220448682374,'Acer Aspire 4720 4720G 4720Z Bluetooth Module 2.0+cable',1,'BTAC2014',9.88,'eastar4','lancerguy73','joeyboy0673@msn.com','Jose L. Dominguez','5126 5th Way N','Saint Petersburg','FL','UNITED STATES','33703-2932','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 05:37:57',0,NULL,3,1,1,1,'、 ','acer 5pin1.25 20cm '),(18037,812575524011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'eastar4','89037894091','efrushka@list.ru','Efremova Irina','Lermontovskiy prospect, 16-27 (Лермонтовский проспект, 16-27)','Moscow','Moscow','RUSSIAN FEDERATION','109153','(903)7894091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 06:06:51',0,NULL,3,1,11,1,'、 ','UM00007 \r地图伞 '),(18038,599728856003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','sherrysb','roadking5071@sbcglobal.net','BRIAN L HOWARD','5071 State Route 204','GLENFORD','OH','UNITED STATES','43739-9736','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 06:17:56',0,NULL,3,1,1,1,'、 ',NULL),(18039,812580950011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','fnhalf','fred_n@hotmail.com','Fred Ngan','24525 133rd Ave SE','Kent','WA','UNITED STATES','98042-5178','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 06:30:28',0,NULL,3,1,1,1,'、 ',NULL),(18040,900353796012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',159.99,'eastar4','catbag1','anyajoss@hotmail.com','Anastasia Josselyn','2 Pope Rd','La Honda','CA','UNITED STATES','94020-9766','(650) 747-9536','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 06:42:49',0,NULL,3,1,1,1,'、',NULL),(18041,8881323759306179,111,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',0,'eastar4','kilempin','kimmolempinen@hotmail.com','Kimmo Lempinen','Matteuksenrinne 1','Karjaa','','FINLAND','10300','',NULL,NULL,NULL,'2011-12-13 06:55:06',0,NULL,3,1,11,1,'、 ','RELO002\r补发的 '),(18042,658320919013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','miguelgonzalez.cb','miguel.cb@terra.es','Miguel Angel Gonzalez Casado','Ezequiel Solana 82 4ºD','Madrid','Madrid','SPAIN','28017','659778180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 07:34:36',0,NULL,3,1,11,1,'、 ','WLIN014 '),(18043,900372459012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',2,'HSJA010',33.98,'eastar4uk','dwynne4854','david@agbag.co.uk','D Wynne','Glenrue<br>Bow','Crediton','Devon','UNITED KINGDOM','EX17 6EN','0136382677','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 07:57:39',0,NULL,3,1,3,1,'RA184541337CN ','HSJA010 '),(18044,599742448003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','philb1952','phil@baileys.com.au','Phil Bailey','8 Greenview Close','Lysterfield South','Victoria','AUSTRALIA','3156','0397005714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 07:57:58',0,NULL,3,1,3,1,'RA184541408CN ','MOOE003\rOEM '),(18045,900375747012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','rafishoel','rafi.shoel@gmail.com','RAFI SHOEL','Emek izrael 8','kfar saba','','ISRAEL','44621','+972525529097','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 08:10:39',0,NULL,3,1,11,1,'、 ','HSPH002 '),(18046,900375310012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','aviransason1','aviransason@gmail.com','aviran sason','ein hatchelet 6','nahariya','','ISRAEL','22324','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 08:13:59',0,NULL,3,1,11,1,'、 ','WLHP002 '),(18047,812606868011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','faris8646','prgord@yahoo.com','Faris Gloz','Hvozdikova 2576/9','Prague 10','','CZECH REPUBLIC','10600','7735621833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 08:28:06',0,NULL,3,1,11,1,'、 ','HBPH003 '),(18048,8881323766045155,111,'New genuine Intel WiMAX 6250 622AGXHRU wifi',2,'WLIN001',45.98,'eastar4',' mdengler   ','martin@martindengler.com','Martin Dengler','129 Repulse Bay RoadThe Lily, Tower 1, Apartment 12A','Hong Kong','','HONG KONG','','85291770733',NULL,NULL,NULL,'2011-12-13 08:47:25',0,NULL,3,1,3,1,'RA184541425CN ','WLIN001 '),(18049,758925363007,170739867756,'ew Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'au-buy','m_ghv_geo','m_ghv_geo@yahoo.com','GHVINIANIDZE MIKHEIL','163 Bay 31st St<br>Apt.1 E4','Brooklyn','NY','UNITED STATES','11214-5217','(347) 885-3053','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 08:56:49',0,NULL,3,1,1,1,'\\','WLIN014 '),(18050,8881323767080903,111,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',0,'eastar4','shirl2008.315','omashirley@yahoo.com','shirley vandewalker','7317 Dublin Street','Lima','NY','UNITED STATES','14485','(585) 519-1273',NULL,NULL,NULL,'2011-12-13 09:04:40',0,NULL,3,1,1,1,'LK113933030CN  ','补发的\r改个地址 '),(18051,658347085013,230657633130,'KODAK Wi-Fi Card 4 EasyShare Camera printer dock',1,'WLKO001',25.99,'eastar4','malc335','talisman@emlyn03.fsnet.co.uk','M J Westwood','Danllyn<br>Cwm Cou','NEWCASTLE EMLYN','Ceredigion','UNITED KINGDOM','SA389PP','01239710335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 09:56:26',0,NULL,3,1,11,1,'\\ ','WLKO001 '),(18052,599770659003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','solvertwins','webmaster@premaat.es','Jose Luis Rodriguez Fernandez','Ponzano 69 6º14','MADRID','Madrid','SPAIN','28003','679499912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 10:15:45',0,NULL,5,1,3,1,'RA184541717CN ','MOOE003\rOEM 顾客想要原装的。'),(18053,599775183003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','amguin','amamam@gmail.com','Akarawat Arthimokyothin','1291/1 Shinawatra Tower2(14) Phaholyothin Rd.,','phayathai','Bangkok','THAILAND','10400','+66813727733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 10:34:54',0,NULL,3,1,3,1,'RA184541734CN\r ','MOOE002'),(18054,812162757011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','jrajacinto','jrjacinto@gmail.com','Marco Monteiro','Rua José Magro<br>Lote 149 - 1 A','Unhos','Lisbon','PORTUGAL','2680-541','935171511','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 10:57:48',0,NULL,3,1,11,1,'\\ ','MOAP001 '),(18055,599783676003,130458644476,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET track#',1,'HSNO016',13.29,'cnfaner','javelkovi','javi_sound@abv.bg','Krasimir Dzhavelkov','kv. \"Elenovo\" bl. 104  A, et. 1 ap:2','Blagoevgrad','','BULGARIA','2700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 11:14:55',0,NULL,3,1,3,1,'RA184541663CN\r ','HSNO016\r欧标 '),(18056,658365706013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',2,'WWSI005',73.98,'eastar4','huszar.adam','oregonlogos@gmail.com','Ádám Huszár','István 41','Gyöngyöstarján','Heves','HUNGARY','3036','+36204474046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 11:21:49',0,NULL,3,1,3,1,'RA184541836CN\r ','WWSI005 '),(18057,900439724012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',36,'eastar4uk','foibos.gr','foibos.greece@yahoo.com','KONSTANTINOS ARVANITIS','NESTOROS 12','ATHENS','','GREECE','15351','(210) 665-5573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 11:37:29',0,NULL,3,1,3,1,'RA184541898CN\r ','WWSI006+ANCN001\rMC8790 '),(18058,812666345011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','tallax5','edugermis@googlemail.com','Eduard Germis','189 Donegall Avenue','Belfast','Antrim','UNITED KINGDOM','BT12 6LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 12:02:58',0,NULL,3,1,3,1,'RA184541765CN\r ','OTHP005 '),(18059,812671947011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','clusterfer78','clusterfer@hotmail.com','Christopher Boughton','1/93 Alexandra Ave','Toorak Gardens','South Australia','AUSTRALIA','5065','0434714825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 12:03:41',0,NULL,3,1,11,1,'\\ ','OTCN002 '),(18060,658375998013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',4,'HSSA002',63.6,'eastar4','kodezzzz','kodezzz@gmail.com','Ruslan Nechyporuk','str. Hvardeytsiv Shironiziv, 86 TZ \"Dinas\" \"Evropeyskaya prachechnaya\"','Kharkiv','Kharkivska oblast','UKRAINE','61183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 12:06:12',0,NULL,3,1,3,1,'RA184543633CN ','HSSA002 \r客户同意发两个白色的'),(18061,900465859012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','josemanuelm25','josema@pentabyte.es','José Manuel Muñoz','C/ Ronda de Sta. Eulàlia, 37, nave 15<br>Parque empresarial de Pallejà','Pallejà','Cataluña','SPAIN','08780','685915133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 12:46:22',0,NULL,3,1,3,1,'RA184541941CN ','GLOT001*2 \r兼容眼镜'),(18062,605203292004,140490658262,'UNLOCKED DELL HS2300 MC8775 WWAN 3G not HP+antenna',1,'WWSI001+ANCN001',33.99,'cnfaner','giangpoh','giangpoh@gmail.com','Ang Giang Poh','A-8-1, Dahlia Apartment<br>Jalan 1/27','Taman Setapak Jaya Baru','Kuala Lumpur','MALAYSIA','53300','0122895550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 13:06:19',0,NULL,3,1,3,1,'RA184541840CN\r ','WWSI001+ANCN001 '),(18063,605212436004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','cemma2005','cemma6103@hotmail.com','Christine Emma','125 Colonial Ave','Norristown','PA','UNITED STATES','19403','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 13:38:17',0,NULL,3,1,1,1,'、  ',''),(18064,658406648013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','mart171010','mart1710@yandex.ru','Elena Gorbova','pr.Mira 48 apr.196','Nikolaev','Nikolaevskaya','UKRAINE','54056','380675148700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 14:01:13',0,NULL,3,1,3,1,'RA184541867CN\r ','GLOT001*2\r兼容型3D眼镜 通用型 '),(18065,900523058012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',2,'SCLO002',6.78,'eastar4uk','kevy_lee','kevymy@yahoo.com.my','Kit Wai Lee','Lot 80, Taman Damai, <br>Batu 4, Jalan Utara,','Sandakan','Sabah','MALAYSIA','90000','0178979289','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 15:03:41',0,NULL,3,1,11,1,'\\ ','SCLO002 '),(18066,812742554011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','awbnet','ammadwb@hotmail.com','AMMAD BHATTI','House no 345/6, moo 10 Pratamnak rd,<br>soi 6 Nongprue','Banglamung','Chonburi','THAILAND','20260','(668) 299-9690 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:09:06',0,NULL,3,1,11,1,'\\ ','HBPH003 '),(18067,658326188013,230393147023,'2.1 Acer Aspire 9420 9423 9424  Bluetooth Module+cable',1,'BTAC2108',12.39,'eastar4','esykas','esykas@hotmail.com','Efstratios Sykas','Ithakis 19','Keratsini','Attica','GREECE','GR 18755','00306977527513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:19:49',0,NULL,3,1,11,1,'\\ ','BTAC2108 \racer 4pin1.25 18cm'),(18068,599848682003,130598387084,'2 pairs of New in box SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'cnfaner','alourencani2011','alourencani@gmail.com','Arnaldo Lourencani','Av. Rio Branco, 26<br>Centro','Varginha','MG','BRAZIL','37002-010','55-35-32214047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:26:30',0,NULL,3,1,3,1,'RA184541907CN ','OTSO004*2 '),(18069,605241894004,140644120633,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones  long cable red',1,'HSPH002',37.6,'cnfaner','srul.zucker','srulzucker@gmail.com','Israel Zucker','Yael Rom 20','Petah Tikva','','ISRAEL','49602','+972-52-6008422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:34:33',0,NULL,3,1,3,1,'RA184540787CN\r ','HSPH002\rred '),(18070,658441638013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','klemmyc','clement_anson@yahoo.com','Clement Anson','22 Vaudreuil','Gatineau','QC','CANADA','j8x2b4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:54:19',0,NULL,3,1,11,1,'\\ ','WLIN014 '),(18071,812762924011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ixia-2008','jclaude.girard@gmail.com','Jean-Claude GIRARD','res le vieux pont avenue du mont aigoual<br>log 20 bat B','ganges','Languedoc-Roussillon','FRANCE','34190','0661894736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 16:28:42',0,NULL,3,1,3,1,'RA184541805CN\r ','MOAP001 '),(18072,897900444012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','kristenkpop1','papp7103@comcast.net','Kathleen  Pappaterra','300 Forkwood Trl','Woodstock','GA','UNITED STATES','30189-2555','(770) 630-7706','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 16:52:18',0,NULL,3,1,1,1,'、  ','兼容型3D眼镜 通用型 '),(18073,900581202012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','smallstool','hansberg@blueyonder.co.uk','Hans Berg','Phaze 2 Hair Co<br>1681 High Street','Knowle','Solihull','UNITED KINGDOM','B93 0LL','01564773828','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 16:55:01',0,NULL,3,1,3,1,'RA184541779CN ',' OTHP004'),(18074,900578473012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','xxroger20xx','budw13@hotmail.com','Roger Whitley','57 Honeoye','Wyoming','MI','UNITED STATES','49548','(616) 293-4506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 16:56:59',0,NULL,3,1,1,1,'、  ','兼容型3D眼镜 通用型 '),(18075,751335224008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',25.99,'au-buy','rinkg123','ajax_rjm@hotmail.com','rink guiljam','guidogezellestraat 19','kesteren','','NETHERLANDS','4041 xt','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 17:35:54',0,NULL,3,1,11,1,'\\ ','MOLO006 '),(18076,599893921003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','bleacherbumb27','sanjaykurup@yahoo.com','Jay Kurup','2620 Grant Ave<br># A','Redondo Beach','CA','UNITED STATES','90278-3827','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 17:37:34',0,NULL,3,1,1,1,'、  ',NULL),(18077,812832140011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','lastybay','mikelast@mac.com','Mike Last','79 Upper Manor Road<br>Preston','PAIGNTON','Devon','UNITED KINGDOM','TQ3 2TH','07979813430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 18:08:11',0,NULL,3,1,3,1,'RA184541782CN\r ','MOAP001 '),(18078,759149129007,170728921906,'New Sony Ericsson HBH-DS970 Bluetooth headset HBH DS 970+AC adapter',1,'HSSE010',63.99,'au-buy','grisu_ii','lohmann.la@web.de','Jörg Lohmann','PostNummer 37557030<br>Packstation 101','Lampertheim','','GERMANY','68623','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 18:30:58',0,NULL,3,1,3,1,'RA184541955CN\r ','HSSE010 无人领取 退回'),(18079,759177681007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','e_f_sr','eddyfinn@gmail.com','Edward Finn Sr.','7325 Whitewood Dr','Fort Worth','TX','UNITED STATES','76137','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 19:17:31',0,NULL,3,1,1,1,'、  ',NULL),(18080,599940416003,130458644529,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+car charger',1,'HSNO019+CCNO001',42.69,'cnfaner','szogun80','szogun80@hotmail.com','SLAWOMIR SOKOLSKI','7307 W MONTROSE AVE<br>HSE','NORRIDGE','IL','UNITED STATES','60706-1157','(773) 627-9839','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 19:23:30',0,NULL,3,1,1,1,'、  ',NULL),(18081,602085505004,140630816480,'New Nokia HS-26W Bluetooch Headset HS 26W',1,'HSNO032',14.99,'cnfaner','creditczar','newacct21780@aol.com','AJ Allen','6161 El Cajon Blvd<br># 278','San Diego','CA','UNITED STATES','92115-3922','(619) 672-1201','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-13 19:36:23',0,NULL,3,1,1,1,'、  ',NULL),(18082,900581161012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','sumeriu','makalei@mail.ru','Sergejus Puc','Saulės g. 1-24','Elektrėnai','','LITHUANIA','26121','+37069835350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 19:45:34',0,NULL,3,1,3,1,'RA184541725CN ','LGRM001 '),(18083,900705574012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','annusi777','anna.zoida@hotmail.com','Anna Zoida','Knauslia 42','Larvik','','NORWAY','3261','004794269378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 19:59:14',0,NULL,3,1,11,1,'、 ','UM00006 \r蕾丝蝴蝶结伞 黑色'),(18084,811638084011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','rob_542','afnw35201@blueyonder.co.uk','Paul Abbott','25 Daffodil Gardens<br>Bold','St.Helens','Merseyside','UNITED KINGDOM','WA9 4LP','07738817903','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 20:38:24',0,NULL,3,1,3,1,'RA184541822CN ','LGGL002 '),(18085,812935428011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',2,'ANCN001',9.78,'eastar4','tjan-tjandra','only4tjan@yahoo.com','Tjan Tjandra Sugiyanto','Fajar Indah Permata II/18 (AD5-18)','Karanganyar','Central Java','INDONESIA','57171','+6281225828008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 20:42:58',0,NULL,3,1,11,1,'\\ ','ANCN001 '),(18086,658573103013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','koshy40','koshy35@gmail.com','shuki somech','emek haela 79, 6','modiin','israel','ISRAEL','71723',' 0576720067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 20:54:16',0,NULL,3,1,11,1,'、 ','OTGR005 '),(18087,658581270013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','keykoabe','salva@mira-lozano.net','J. Salvador Mira Gregori','C. Vall de Ceta 13-A','La Nucia','Comunidad Valenciana','SPAIN','03530','607781011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 21:08:09',0,NULL,3,1,11,1,'\\ ','CAB-6060\rCASS003 '),(18088,900763997012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','johnbrady1962','jbrady1962@yahoo.co.uk','john brady','21 pound lane','leamington spa','Warwickshire','UNITED KINGDOM','cv32 7rt','1926737215','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 21:18:21',0,NULL,3,1,3,1,'RA184541751CN\r ','HSSA002 \rblack version \r英标'),(18089,812964001011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',7.96,'eastar4','holly19770108','ajh77@hetnet.nl','Oane Hoeksma','Oane Binnesloane 8','Twijzelerheide','','NETHERLANDS','9287mz','0612202332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 21:23:53',0,NULL,3,1,11,1,'\\ ','OTCN002 '),(18090,812352635002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','marimitebr','srta.spitz@gmail.com','Maria Aline Tenorio dos Santos','Rua Tenente Aurelio 78<br>Caixa Postal 99','Parnamirim','Rio Grande do Norte','BRAZIL','59140-970','(84)99000548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 21:25:07',0,NULL,3,1,11,1,'\\ ','BR3D009 '),(18091,900775221012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.96,'eastar4','sokadik','lapa@lapanet.hu','lapanet LTD.','Alsóerdösor Str. 23.','Alsónémedi','Ungarn','HUNGARY','2351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 21:35:19',0,NULL,3,1,11,1,'\\ ','WLAT009 '),(18092,900804213012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','10donnarussell','donnabrookenboyz@yahoo.co.uk','donna russell','21 dinmore ave','blackpool','Lancashire','UNITED KINGDOM','fy3 7rr','01253314896','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 22:22:28',0,NULL,3,1,3,1,'RA184541677CN\r ','HSSA002\rblack version\r英标 '),(18093,813004996011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','thwa3229','tina.hwang@citi.com','Tina Hwang','388 Greenwich St<br>Fl 30','New York','NY','UNITED STATES','10013-2375','(212) 816-4379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 22:36:46',0,NULL,3,1,1,1,'、  ',NULL),(18094,658640607013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lukinbiglik','lukin.biglik@seznam.cz','Lukas Biegl','Karlovarska 299','Praha','Ceska Republika','CZECH REPUBLIC','16100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 23:55:20',0,NULL,3,1,11,1,'\\ ','CACN004 '),(18095,900853278012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','djdomhunting','xboxdom@hotmail.com','Domenic Monardo','26 Stone Palce Way','Woodbridge','ON','CANADA','L4H1M9','(905) 893-9588','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 00:10:20',0,NULL,3,1,3,1,'RA184541938CN ','GLOT001 \r兼容型3D眼镜 通用型'),(18096,812439992002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','mprubin','mprubin516@aol.com','Mark Rubin','717 Fallsgrove Dr<br>Apt 1013','Rockville','MD','UNITED STATES','20850-7782','(301) 309-6990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 00:40:15',0,NULL,3,1,1,1,'、  ',NULL),(18097,658659133013,230675318687,'New in box Genuine Samsung 2 pair SSG-2100AB + 3D blu-ray monster house disc',1,'GLSG001*2+BR3D004',114.99,'eastar4','margenprices','margenprice@gmail.com','ADEM KARATEPE','kazimdirik mh. gediz cd.  onur sitesi No:3 A Blok D:5<br>Tel:00905416900789','izmir','bornova','TURKEY','35041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 00:57:00',0,NULL,3,1,3,1,'RA184541875CN ','GLSG001*2+BR3D004 '),(18098,900895649012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','ctroeun','tancharles@hotmail.com','TAN Charles','13 Promenade de la source','Torcy','','FRANCE','77200','0646547879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 01:52:35',0,NULL,3,1,11,1,'\\ ','ANTY001 '),(18099,8881323828239518,111,' New genuine Microsoft Wired Optical Wheel Mouse',3,'MOMI002',41.37,'eastar4','alphatay','alpha_tay@hotmail.com','Alpha Tay','77, Jalan Berlian 1, Taman Berlian Biru,<br>86000 Kluang, Johor.','Kluang','Johor','MALAYSIA','86000','07-7722586',NULL,NULL,NULL,'2011-12-14 02:03:59',0,NULL,3,1,3,1,'RA184541819CN ','MOMI002 \r客户直接打得款'),(18100,658685448013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','apost2011','postabby1@gmail.com','abby post','6504 quaker ave<br>apt 306','lubbock','TX','UNITED STATES','79413-5132','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 02:38:50',0,NULL,3,1,1,1,'、  ',NULL),(18101,813107507011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','zalexz360','premeditatedx826@yahoo.com','Alex Backstrom','6709 Old Highway 410 SW','olympia','WA','UNITED STATES','98512-9424','(360) 481-9164','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 03:12:12',0,NULL,3,1,1,1,'、  ',NULL),(18102,769160546001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','marekdoskowski1971','amjvdoskowski@yahoo.pl','marek doskowski','8055 99th ave','vero beach','FL','UNITED STATES','32967-2840','(772) 581-8498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 03:48:13',0,NULL,3,1,1,1,'、  ',NULL),(18103,600118293003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','tiben105','hwyben105@hotmail.com','benoit soulieres','270 des gentianes','ste-sophie','QC','CANADA','J5J2X3','(450) 436-4389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 05:04:09',0,NULL,3,1,3,1,'RA184541884CN\r ','HSPL005 \r美标'),(18104,658722117013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','nicholas.taylor.perth','nickwontlose@gmail.com','Nicholas Taylor','123 Nanson St','Wembley','Western Australia','AUSTRALIA','6014','6142248083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 05:14:13',0,NULL,3,1,11,1,'\\ ','CASS003 '),(18105,759432853007,170730545626,'New US Logitech Harmony AC Power Adapter',1,'POLO001',6.99,'au-buy','corzaman92','corzaman@hotmail.com','Corey Wratten','26 Mapleton Crescent<br>Forest Lake','Brisbane','Queensland','AUSTRALIA','4078','0401242306','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 05:42:21',0,NULL,3,1,11,1,'、 ','POLO001 '),(18106,769195785001,110672308283,'New 3M Particulate Respirator with valve 9332 N99 FFP3',1,'OT3M001',8.99,'buysia','wcg981dddwwwhhh','wcg981@gmail.com','Zheng, Cheng','49 Fairway Rd<br>Apt 3D','Newark','DE','UNITED STATES','19711-5668','(302) 367-3167','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 06:26:36',0,NULL,3,1,1,1,'、 ',NULL),(18107,600129667003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','bbugno','bugn4335@bears.unco.edu','Derik Bugno','1950 Logan St<br>Apt 1110','Denver','CO','UNITED STATES','80203-1183','(719) 237-2700','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 06:26:54',0,NULL,3,1,1,1,'、  ',NULL),(18108,900989390012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','metaframe64','rspeed3fl@verizon.net','Richard Gardner','4453 6th Ave E','Bradenton','FL','UNITED STATES','34208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 06:45:14',0,NULL,3,1,1,1,'、  ','AUI Transceiver  MX20T '),(18109,769203375001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','emailoffice','postgate@web.de','Andreas Wilke','Zur Pfingstwiese 24','Gommern','','GERMANY','39245','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 07:05:58',0,NULL,3,1,11,1,'、 ','BR3D006 '),(18110,813172029011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','esterraiter','ester.raiter@gmail.com','Ester Raiter','Anna Frank 34/14','Bat-Yam','Bat-Yam','ISRAEL','59652','9722586634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 07:31:36',0,NULL,3,1,3,1,'RA184540345CN\r ','HBPH002 '),(18111,813170610011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',54.99,'eastar4','karish_x','karish666@yahoo.co.uk','Mohd Farish Md Zain','No 1,Lorong Jambu Bol 2,<br>Kawasan 6, Teluk Pulai.','Klang','Selangor','MALAYSIA','41100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 07:36:30',0,NULL,3,1,3,1,'RA184540376CN ','GLSG001 '),(18112,751679330008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','javmar52','javmar52@hotmail.com','Javier Martin','Sant Antoni,  70  03 02','Sant Cugat Del Valles','Cataluña','SPAIN','08172','639487649','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 08:28:42',0,NULL,3,1,3,1,'RA184540172CN\r ','HBPH001 '),(18113,900535661012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','marpemim','c033721@hotmail.com','Miguel Angel Marrero Pérez','C/ Mencey Beneharo 10','Santa Cruz de Tenerife','Santa Cruz de Tenerife','SPAIN','38008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 08:50:55',0,NULL,3,1,11,1,'\\ ','ANTY001 '),(18114,8881323854968973,111,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',0,'eastar4','pssandhu','parmsandhuin@yahoo.com','Parm Sandhu','Unit 2<br>34 Dublin Road','Ringwood East','Victoria','AUSTRALIA','3135','0421407545',NULL,NULL,NULL,'2011-12-14 09:29:28',0,NULL,3,1,3,1,'RA184540305CN\r ',' WWOT001\r补发的'),(18115,901034062012,220877932141,'New HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'eastar4','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 09:32:54',0,NULL,3,1,11,1,'、 ','RMSN003 '),(18116,605553400004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','felix850621','vasilev_mbal@abv.bg','Vladimir Vasilev','Belomorski No 53<br>MBAL Dr.Atanas Dafovski pk 71 et 5','Kardzhali','KARDZHALI','BULGARIA','6600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 09:37:34',0,NULL,3,1,3,1,'RA184540169CN\r ','OTHP004 '),(18117,813205608011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ixia-2008','jclaude.girard@gmail.com','Jean-Claude GIRARD','res le vieux pont avenue du mont aigoual<br>log 20 bat B','ganges','Languedoc-Roussillon','FRANCE','34190','0661894736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 09:43:19',0,NULL,3,1,3,1,'RA184540230CN\r ','MOAP001 '),(18118,901046135012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','miahoost','lhouston@live.co.uk','graham houston','23 four acres drive kilmaurs','kilmarnock','East Ayrshire','UNITED KINGDOM','ka3 2nd','07889122119','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 10:10:11',0,NULL,3,1,3,1,'RA184540138CN\r ','SAFI001 '),(18119,813214335011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','poesaccount','poesmailbox@yahoo.com','Napolian Stewart','8505 N Dwight Ave','Portland','OR','UNITED STATES','97203-3518','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 10:11:31',0,NULL,3,1,1,1,'\\ ',NULL),(18120,759500290007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','sarcory','sarahdhardie@hotmail.com','Sarah Hardie','1505/230 Marine Parade<br>Lumiere Apartments','Labrador','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 10:22:19',0,NULL,3,1,3,1,'RA184540257CN\r ','LGFI001 '),(18121,901050088012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.99,'eastar4uk','cahillmicky','cahillmickey@yahoo.com','Michael Cahill','The Farm','ballinrobe','Mayo','IRELAND','default','0868389229','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 10:23:10',0,NULL,3,1,3,1,'RA184540186CN\r ','OTGR002 '),(18122,901052016012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',257,'eastar4','iconic7677','accounts@iconinteriors.net.au','gavin morley','12 bodkin st','kyneton','Victoria','AUSTRALIA','3444','0354211300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 10:30:47',0,NULL,3,1,4,1,'YW867661164CN ','HSJA009 \r澳标'),(18123,813226685011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',2.99,'eastar4uk','snajd','bjhemm@gmail.com','Björn Hemmingsson','Blystigen 8b','Falun','Dalarna','SWEDEN','79156','46706660972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 10:53:34',0,NULL,3,1,11,1,'\\ ','ANTY002 '),(18124,813228973011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','amgua','a.m.g@i.ua','Andrii Gubin','Leningradska 17','Kharkiv','','UKRAINE','61016','+380507129080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 11:00:44',0,NULL,3,1,11,1,'\\ ','CC00002 '),(18125,658793730013,230452710244,'New GENUINE NOKIA HS-3W BLUETOOTH HEADSET HS 3W',1,'HSNO021',15.8,'eastar4','verakoun','kounvera@gmail.com','Vera Kountourioti','dionysou 19 ano melissia','ano melissia athina','attiki','GREECE','15127','6945877706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 11:48:11',0,NULL,3,1,11,1,'\\ ','HSNO021 \r欧标\r新地址\rMaria Nitsiou\rDionysou 18B, Ano Melissia\rAthens, Attiki, 15127\rGreece.\r'),(18126,901104320012,220905585248,'New GENUINE PLANTRONICS Calisto pro Bluetooth Headset only',1,'HSPL014',33.59,'eastar4uk','foreverpr','spiritofpr@yahoo.com','Alberto Quinones','HC 2 Box 5456','Penuelas','PR','UNITED STATES','00624-9601','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 12:54:58',0,NULL,3,1,1,1,'\\',''),(18127,813304923011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','almasba','almasba@hotmail.com','Miss A Ben-Aribia','481 Harborne Park Road<br>Harborne','Birmingham','West Midlands','UNITED KINGDOM','B17 0PS','07877753765','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 14:32:22',0,NULL,3,1,3,1,'RA184540226CN\r ','ANCN001 '),(18128,605626987004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','mratayevs11','mratayevs@mail.ru','Salman Atayev','Tebrizi.st ev.6 m.8','Baku','Baki','AZERBAIJAN','AZ1117','+994558524701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 14:55:42',0,NULL,3,1,3,1,'RA184540265CN\r ','OTTP001 '),(18129,813329335011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','1jane0','janecollister@hotmail.co.uk','JANE COLLISTER','31 FOUNTAINS RD','STOCKPORT','Cheshire','UNITED KINGDOM','SK87PY','01614394158','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 15:29:12',0,NULL,3,1,3,1,'RA184540393CN ','GLSG001 '),(18130,813332341011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',2,'HSNO007',27.96,'eastar4','hikmat68','kazimovhikmat@rambler.ru','Hikmat Kazimov','Nizami str. 114','Baku','Baku','AZERBAIJAN','AZ 1010','+994503471919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 15:36:15',0,NULL,3,1,11,1,'\\ ','HSNO007 '),(18131,658863980013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','k.erashevich','erashevich@gmail.com','Konstantin Erashevich','Oktyabrskaya, 104','Bruhovetskaya','Krasnodarskiy kray','RUSSIAN FEDERATION','352750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 15:54:49',0,NULL,3,1,11,1,'\\ ','WLAP008 '),(18132,901185111012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','rap04217','robin14@onetel.com','Robin Pyott','14 Millfield Close,<br>Sketty','Swansea','Swansea','UNITED KINGDOM','SA28BD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 15:56:18',0,NULL,3,1,3,1,'RA184540124CN\r ','HSMO019\r英标 '),(18133,900537906012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','irmantuksas','irmantas@lagunavicius.lt','Laime Anusaite','Didlaukio g. 70-10','Vilnius','','LITHUANIA','08327','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 16:56:35',0,NULL,3,1,3,1,'RA184540314CN ','HSPL013\r欧标\r申报为gift申报24$ \r电话为 +37063414089 '),(18134,813389758011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','jcarnosa','jarnosa@yahoo.es','Juan Cirilo Arnosa Casal','Doutor Malvar 2 - 4Izq','Fene','La Coruna','SPAIN','15500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 17:29:13',0,NULL,3,1,11,1,'\\ ','WLAP002 \r二代卡旧的'),(18135,605677703004,140662512092,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',88.99,'cnfaner','truong2860','minifamily3@gmail.com','peter truong','9497 n fort washington rd<br>suite 103','fresno','CA','UNITED STATES','93730','(559) 434-9497','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 17:30:12',0,NULL,3,1,3,1,'RA184540950CN\r ',NULL),(18136,901239780012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','goldenflight','tlhill@mac.com','Terry Hill','14101 Wingfoot Ct','Basehor','KS','UNITED STATES','66007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 17:33:28',0,NULL,3,1,1,1,'\\ ','HP 8pin 1.0 23cm  '),(18137,812775305002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','dmbgigharbor','davidb0990@aol.com','david blaisdell','2707 Jahn Ave NW<br>Ste B1','Gig Harbor','WA','UNITED STATES','98335-8901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 17:48:17',0,NULL,3,1,1,1,'\\ ',NULL),(18138,759679417007,170730545213,'New Logitech Digital IO Writing Pen',1,'NTLO002',39.99,'au-buy','doc_boe','boe_doc@online.de','Werner Boettcher','Röthleinsberg 4','Kulmbach','','GERMANY','95326','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 17:50:22',0,NULL,3,1,3,1,'RA184540362CN ','NTLO002 '),(18139,658916966013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','asusdrum2ahmed','asusdrum2@yahoo.com','Ahmed Jawad Sukkar','18221 150th Ave<br># AUH-6841','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 18:08:18',0,NULL,3,1,1,1,'\\ ',NULL),(18140,901275468012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','billz2011-us','bz2707@yahoo.com','Billy Zielinski','98 DeHaven Dr','Yonkers','NY','UNITED STATES','10703-1347','(914) 629-4948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 18:33:15',0,NULL,3,1,1,1,'\\ ',NULL),(18141,658930390013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',4,'HSSA002',63.6,'eastar4','autofilippos11','autofilippos@gmail.com','filippos tsakiridis','Thessalonikis 78','Katerini','','GREECE','GR-60100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 18:39:11',0,NULL,3,1,3,1,'RA184543514CN ','欧标\rHSSA002 '),(18142,605706453004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','odeon333','igercak@msn.com','Igor Gercak','6804 joliet rd 5J','Indian Head Park','IL','UNITED STATES','60525','(708) 655-3750','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 18:40:24',0,NULL,3,1,1,1,'\\ ',NULL),(18143,812811235002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','abearforannette','fletchtwo@live.com','Annette Fletcher','PO Box 121<br>18486 East Fletcher\'s Lakeside Drive','Maxwell','NE','UNITED STATES','69151-0121','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 18:49:28',0,NULL,3,1,1,1,'\\ ',NULL),(18144,813444610011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',71.98,'eastar4uk','edwardus58','eldexduda@interia.pl','Edward Duda','1 Station Way','Norton Malton','North Yorkshire','UNITED KINGDOM','YO17 9RE','01653228367','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 19:08:28',0,NULL,3,1,3,1,'RA184540455CN ','GLSG001 '),(18145,599307306003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','ig0th0es','doitbig7414@yahoo.com','Shimon Merriweather','300 Lake St<br>Apt 215','Waukegan','IL','UNITED STATES','60085-5551','(224) 730-9123','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 19:24:24',0,NULL,3,1,1,1,'\\ ',NULL),(18146,605729864004,140490658262,'UNLOCKED DELL HS2300 MC8775 WWAN 3G not HP+antenna',1,'WWSI001+ANCN001',33.99,'cnfaner','krasistoyanov','krasisilistra@abv.bg','Krasimir Stoyanov','26,Dobrudzha,Str.,enr.B,fl.9,ap.52','Silistra','','BULGARIA','7500','00359899823342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 19:30:34',0,NULL,3,1,3,1,'RA184540243CN\r ','WWSI001+ANCN001 '),(18147,901320116012,220525323769,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',16.3,'eastar4','pulsarrr','pulsar34@wp.pl','Andrzej Bystrzycki','4521 N Long Ave','Chicago','IL','UNITED STATES','60630-3514','(312) 218-5011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 19:32:22',0,NULL,3,1,1,1,'\\ ',NULL),(18148,901337634012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','10donnarussell','donnabrookenboyz@yahoo.co.uk','donna russell','21 dinmore ave','blackpool','Lancashire','UNITED KINGDOM','fy3 7rr','01253314896','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 19:58:08',0,NULL,3,1,3,1,'RA184540288CN\r ','HSJA010 \r英标'),(18149,605754303004,140515702613,'New GENUINE NOKIA BH-800 BLUETOOTH HEADSET track#',1,'HSNO017',19.49,'cnfaner','kauls862','muris171@gmail.com','Agris Keiselis','jauna iela 21-9','Viksna','Balvu novads','LATVIA','LV-4580','22440895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:22:51',0,NULL,3,1,3,1,'RA184540209CN\r ','HSNO017\r欧标 '),(18150,813501523011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',35.99,'eastar4','kauls862','muris171@gmail.com','Agris Keiselis','jauna iela 21-9','Viksna','Balvu novads','LATVIA','LV-4580','22440895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:22:53',0,NULL,3,1,11,1,'\\ ','HSNO015 '),(18151,901371375012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',63.99,'eastar4uk','lobezno6968','gismo6969@hotmail.com','Aide Villalobos Lopez','CBuenvista 13 2ºC','Portugalete','País Vasco','SPAIN','48920','663827396','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 20:40:06',0,NULL,3,1,3,1,'RA184540212CN\r ','LGGL002*2 '),(18152,605764992004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','tadzik991','klex.13@gmail.com','Tomasz Klechowicz','Parkowa 24/27','Świdwin','zachodniopomorskie','POLAND','78300','696 446152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:47:33',0,NULL,3,1,3,1,'RA184540190CN\r ','CACN004 '),(18153,658997085013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',3,'HSNO028',55.35,'eastar4','victorpimchenko','victornavolsky@yandex.ru','Victor Pimchenko','Traktorostroiteley ave.<br>h.152 f.54','Kharkiv','','UKRAINE','61121','(067)701-6613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:51:53',0,NULL,3,1,3,1,'RA184540331CN\r ','HSNO028 \r欧标'),(18154,605768714004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','martinvancl','mart.vancl@gmail.com','Martin Vancl','Bořivojova 106<br>Praha 3','Prague','Czech Republic','CZECH REPUBLIC','13000','+420773551407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:59:08',0,NULL,3,1,3,1,'RA184540115CN\r ','CACN004 '),(18155,759823107007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','anjinho11','natalia.vonrandow@msn.com','Natalia von Randow','Rua Treze de Maio, 220<br>ap 113 Centro','Curitiba','Parana','BRAZIL','80020270','554130495289','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 21:33:15',0,NULL,3,1,11,1,'\\ ',' UM00040'),(18156,813559827011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','jnor1371','jpndecs@yahoo.co.uk','jamie norris','83 broadway,greasby,wirral,','liverpool','Merseyside','UNITED KINGDOM','ch49 2nq','01516776020','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 21:55:54',0,NULL,3,1,3,1,'RA184540380CN ','GLSG001 '),(18157,813584769011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',35.99,'eastar4uk','tjrobbo123','traceyrobbo@aol.com','TRACEY ROBINSON','10 ANCASTER ROAD','BOURNE','Lincolnshire','UNITED KINGDOM','PE109HL','01778422297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 22:48:46',0,NULL,3,1,3,1,'RA184540402CN ','GLSG001 '),(18158,604396511004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','mary4944','mjanke31@wi.rr.com','Mary Janke','6552 N 58th St','Milwaukee','WI','UNITED STATES','53223-5921','(414) 353-6155','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 22:52:09',0,NULL,3,1,17,0,NULL,NULL),(18159,604399660004,140550602451,'New InBox Microsoft Wireless Laser Mouse 8000 Bluetooth',1,'MOMI001',54.8,'cnfaner','mary4944','mjanke31@wi.rr.com','Mary Janke','6552 N 58th St','Milwaukee','WI','UNITED STATES','53223-5921','(414) 353-6155','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-14 22:52:10',0,NULL,3,1,4,1,'YW867738794CN ','一共发2个 '),(18160,752079074008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',2,'BALO001',23.98,'au-buy','horto22','jhorton@bigpond.net.au','John Horton','9 Sydenham Street','Highett','Victoria','AUSTRALIA','3190','0395983080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 23:41:13',0,NULL,3,1,11,1,'\\ ','BALO001 '),(18161,813610190011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','pandux336','tavofg@hotmail.com','Gustavo Garcia Flores','905 King St','Burlington','NC','UNITED STATES','27217-6035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 23:50:25',0,NULL,3,1,1,1,' \\ ',NULL),(18162,812991627002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','elisabete_85','elisabete_c85@hotmail.com','elisabete honorato','flat 1 38 weston road','gloucester','Gloucestershire','UNITED KINGDOM','gl1 5ax','07831816069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 00:23:41',0,NULL,3,1,11,1,'\\ ','BR3D009 '),(18163,901492160012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','amber_liquid','amber05@bigpond.net.au','Amber Healey','30 Kelsall Street','Warracknabeal','Victoria','AUSTRALIA','3393','0353941554','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 00:24:20',0,NULL,3,1,3,1,'RA184540274CN\r ','GLOT001*3 '),(18164,813623023011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','bonella','marcelobonella@yahoo.com.br','Marcelo Bonella da Silva','Rua Helena Muller, 85<br>Jesus de Nazareth','Vitoria','Espirito Santo','BRAZIL','29052100','+55 27 81122622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 00:27:32',0,NULL,3,1,3,1,'RA184540359CN\r ','OTSA001 '),(18165,605843763004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.59,'cnfaner','bikerchicmichelle','michelle.reed@clear.net.nz','chris lester','29 gurnsey st','christurch','','NEW ZEALAND','8061','033881456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 01:02:10',0,NULL,3,1,3,1,'RA184540291CN\r ','LGGL003 '),(18166,659080980013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','doiluulac2003','doiluulac2003@yahoo.com','nghiem pham','PO Box 680<br>13936 H G Trueman Rd','solomons','MD','UNITED STATES','20688-0680','(240) 476-2320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 01:07:03',0,NULL,3,1,1,1,'\\ ','兼容型3D眼镜 通用型 '),(18167,659083868013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','jamti3','jamti3@yahoo.co.kr','Kim Taek Moo','883-1402<br>1129 Neung-Dong, Moa-miraedo Aps.','Hwasung','Kyung-ki-do','KOREA,REPUBLIC OF','445-320','(821) 031-9933 ext.: 00','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 01:26:51',0,NULL,3,1,11,1,'\\ ','WLIN014 '),(18168,659105543013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','igue4981','ikdaule@yahoo.com','IKDAULE GUERRERO','3762 Cedar Ave APT 211','fresno','CA','UNITED STATES','93726','(559) 761-1649','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 02:44:32',0,NULL,3,1,1,1,'\\ ',NULL),(18169,600487945003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','ehansenn','emilianohansenn@hotmail.com','Emiliano Hansenn','corinto, 543 ap 77c','São Paulo','São Paulo','BRAZIL','05586060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 03:08:08',0,NULL,3,1,3,1,'RA184540416CN ','HSPL005 \r美标'),(18170,600488333003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','g35mike6669','mikezack81@hotmail.com','Mike Zack','100 7260 12 Street SE','Calgary','AB','CANADA','T2H 2S5','(403) 333-1500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 03:12:51',0,NULL,3,1,3,1,'RA184540433CN ','RCLO007+POLO001+RCLO008*4 '),(18171,659117658013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','179paulg','p.garder@myactv.net','Paul Garder','8028 Stell Road','Sodus','NY','UNITED STATES','14551','(315) 483-6061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 03:38:16',0,NULL,3,1,1,1,'、','兼容型3D眼镜 通用型 '),(18172,813054104002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','scotty814','scott814@verizon.net','Scott Trantina','3886 W 230th St','Torrance','CA','UNITED STATES','90505','(310) 944-1543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 03:38:22',0,NULL,3,1,1,1,'LK158360291CN\r ',NULL),(18173,813056316002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','mpkelly1755','mkelly1266@yahoo.com','Mary Kelly','1755 Bilbao Dr','Santa Maria','CA','UNITED STATES','93454-3430','(805) 346-6057','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 03:48:20',0,NULL,3,1,1,1,'LK162140120CN\r ',NULL),(18174,659132973013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','kingbetters','kennydo36@yahoo.com','L.A.Nail Spa','3510 Wilkes Barre Township Cmns','Wilkes Barre','PA','UNITED STATES','18702-6847','(570) 829-2749','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 04:49:00',0,NULL,3,1,1,1,'\\ ',NULL),(18175,813702647011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','sculderredux','meganmotlagh1@gmail.com','Megan Motlagh','1832 Walthour Rd','Savannah','GA','UNITED STATES','31410-3212','(912) 897-7934','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 04:57:49',0,NULL,3,1,1,1,'\\ ',NULL),(18176,901589733012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','callumferonfarrell','cfero1@eq.edu.au','Callum Feron-Farrell','4 Shasta Crt','Cashmere','Queensland','AUSTRALIA','4500','0439818970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 05:25:07',0,NULL,3,1,3,1,'RA184540447CN ','WWOT001 '),(18177,901591322012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','ahh57','alanhhutchens@yahoo.com','Alan Hutchens','10557 Reseda Blvd','Northridge','CA','UNITED STATES','91326','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 05:31:23',0,NULL,3,1,1,1,'\\ ','HP 8pin 1.0 23cm  '),(18178,813712704011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT006*2',88.99,'eastar4','snt777','din77@tnsservice.kz','Dmitriy Nossikov','Manasa 61A','Almaty','','KAZAKHSTAN','050057','7 701 766 8881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 05:42:46',0,NULL,3,1,3,1,'RA184540420CN ','GLOT006*2 \r兼容型3D眼镜  Korea TV专用'),(18179,600521222003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','nar416','narish@gmail.com','Damodar Bisessar','7144 S Ridgeway Ave','Chicago','IL','UNITED STATES','60629-4329','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-15 06:34:32',0,NULL,3,1,1,1,'\\  ',NULL),(18180,759991407007,170728920954,'New Earloop wire Stereo sound replacement Plantronics Voyager 815/855 bluetooch',1,'HSPL018',14.99,'au-buy','robertdkatzmd1','rdkatzmd@rdkatzmd.com','ROBERT KATZ','1717 Comstock Ave','LOS ANGELES','CA','UNITED STATES','90024-5322','(310) 779-4741','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 06:43:06',0,NULL,3,1,1,1,'\\ ',NULL),(18181,600523625003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','robertdkatzmd1','rdkatzmd@rdkatzmd.com','ROBERT KATZ','1717 Comstock Ave','LOS ANGELES','CA','UNITED STATES','90024-5322','(310) 779-4741','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-15 06:46:32',0,NULL,3,1,1,1,'\\ ',NULL),(18182,605917067004,140626376683,'NEW Logitech Wireless Laser Mouse M505 plus receiver',1,'MOLO008',35.4,'cnfaner','nirtaub','taubnir@gmail.com','Nir Taub','Haneviim 71/4','Kiryat Ata','','ISRAEL','28000','972-4-8492598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 07:53:18',0,NULL,3,1,3,1,'RA184540742CN\r ','MOLO008\rRed Mouse Model Logitech 505'),(18183,659171474013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','mossyrj','rohan05@tpg.com.au','Rohan Moss','16 Stein Pl','Glenmore Park','New South Wales','AUSTRALIA','2745','0212355678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 08:53:49',0,NULL,3,1,11,1,'\\\r ','CASS003 \rCAB-6060'),(18184,752228397008,180764313016,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','judy-paco','judy@paco-studio.com','Miss Judy Moosmueller','31 MOORLAND ST','SCARBOROUGH','Western Australia','AUSTRALIA','6019','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-15 09:47:28',0,NULL,3,1,3,1,'RA184540623CN\r ','HBPH002 '),(18185,760038447007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','i-aaaah','fegnest@hotmail.com','Kerstin Bopp','Im Binz 1','Wettingen','','SWITZERLAND','5430','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 10:06:51',0,NULL,3,1,11,1,'、 ','UM00033 '),(18186,813775867011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.39,'eastar4','bluemanu1601','manuelrettig@gmx.net','Manuel Rettig','Berlinerstraße 7-9','Pforzheim','','GERMANY','75172','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 10:18:06',0,NULL,3,1,11,1,'\\ ','BTAC2104 \racer 4pin1.25 6cm '),(18187,760062372007,170728920954,'New Earloop wire Stereo sound replacement Plantronics Voyager 815/855 bluetooch',1,'HSPL018',14.99,'au-buy','onaira0707','onaira07@yahoo.com','chukwunenye onuoha','23824 walnut st','Torrance','CA','UNITED STATES','90501-6137','(310) 977-4566','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 11:29:17',0,NULL,3,1,1,1,'\\  ',NULL),(18188,813821128011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','erikfer','erikfer@gmail.com','Erik fernandes','Rua Bela Vista 824','Piracicaba','SP','BRAZIL','13418200','551983063090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 12:54:24',0,NULL,3,0,3,1,'RA184543647CN\r ','GPS0007 \r已入库'),(18189,605979532004,140626376379,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',17.4,'cnfaner','mvaleri1185','mike_valeri@yahoo.com','Mike Valeri','5 Keith Dr','Norton','MA','UNITED STATES','02766-1865','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-15 13:18:14',0,NULL,3,1,1,1,'\\  ',NULL),(18190,659232608013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','nhienhuong','quanghaihcm@gmail.com','Tran Quang Hai','201A No Trang Long. Phuong 12.  Quan Binh Thanh','Ho Chi Minh City','Viet Nam','VIET NAM','717066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 13:45:13',0,NULL,3,1,11,1,'\\ ','WLAT001 '),(18191,760100736007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','mikebro97','mike_breault@hotmail.com','Mike Breault','11-303 King St. North','Waterloo','ON','CANADA','N2J 2Z1','(519) 573-1665','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 13:31:50',0,NULL,3,1,11,1,'\\ ','RCLO007+POLO001+RCLO008*4 '),(18192,813848008011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','bigdog3030','amit_desai@yahoo.com','Amit Desai','7930 Jones Branch Dr<br>Hilton Worldwide','McLean','VA','UNITED STATES','22102-3388','(571) 233-3353','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 14:03:47',0,NULL,3,1,1,1,'\\  ',NULL),(18193,901748814012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','orxbetzalel','xexcelx@live.com','Or Betzalel','Laskov Haim 28A','Holon','','ISRAEL','58672','0528013813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 14:23:37',0,NULL,3,1,3,1,'RA184540861CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18194,760119554007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','anjinho11','natalia.vonrandow@msn.com','Natalia von Randow','Rua Treze de Maio, 220<br>ap 113 Centro','Curitiba','Parana','BRAZIL','80020270','554130495289','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 14:23:52',0,NULL,3,1,11,1,'、 ','UM00042 '),(18195,901749517012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',12.99,'eastar4uk','yellow_toybox','oz33oz38@hotmail.co.uk','Patricia Low','74 Burdyke Avenue<br>York','York','North Yorkshire','UNITED KINGDOM','YO306JW','01904655470','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 14:24:43',0,NULL,3,0,3,1,'RA184540699CN\r ','WLAP002 '),(18196,813856474011,320679610517,'New GENUINE NOKIA BH-106 BLUETOOTH HEADSET',1,'HSNO004',12.35,'eastar4uk','veisakisnektarios','veisakis@hotmail.com','Nektarios Veisakis','SEAP, STG 1011','Nea Alikarnassos','Crete','GREECE','STG 1011','6974014244','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 14:26:58',0,NULL,3,0,11,1,'\\ ','HSNO004\r欧标 '),(18197,901751991012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','chel_sea-200776','tracey_chick@hotmail.co.uk','tracey pettit','45 ashfeild road','wellingborough','Northamptonshire','UNITED KINGDOM','nn8 3jg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 14:30:43',0,NULL,3,0,3,1,'RA184540892CN\r ','OTSO004*3 '),(18198,600414426003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','tsouropaido','jtsouris@hotmail.com','IOANNIS TSOURIS','THEODOTOU 4','PATRA','ACHAIA','GREECE','26442','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 14:31:36',0,NULL,3,1,3,1,'RA184540739CN\r ','HSMO020 \r欧标'),(18199,758426011007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','bfd1262','alisondavette@roadrunner.com','Michael Kamp','47 Creekledge Ln','Copley','OH','UNITED STATES','44321-3221','(330) 670-6420','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 15:24:15',0,NULL,3,1,1,1,'\\  ',NULL),(18200,600629343003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',2,'HSNO005+CCNO001',31.58,'cnfaner','xixicoco2011','cadmothecarneiro@hotmail.com','Marcus Venicius mothe carneiro','R. Luis fernandes reis 359 Ed. Monte Viso apt 403 (próximo ao hotel Quality)<br>Praia da Costa - tel (27)81355757','Vila Velha','Espírito Santo','BRAZIL','29101-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 15:26:30',0,NULL,3,1,3,1,'RA184540685CN\r ','HSNO005+CCNO001\r美标 '),(18201,600634380003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',2,'WLAT003',29.6,'cnfaner','schocobongo','christoph.kernen@gmx.ch','Christoph Kernen','Hahnrainweg 6','Baden','','SWITZERLAND','5400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 15:42:59',0,NULL,3,1,3,1,'RA184540668CN\r ','WLAT003 '),(18202,659280304013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',5,'CACN004',64.7,'eastar4','jamnikzan10','jamnikzan@gmail.com','Mike Lojze Jamnik Stipič ASO d.o.o','Zaloška cesta 179','Ljubljana','Ljubljana','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 16:27:52',0,NULL,3,1,3,1,'RA184540756CN\r ','CACN004'),(18203,600655536003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','hawkeye1955','r_michael_hayden@hotmail.com','Mike Hayden','1611 Westlakes Pkwy<br>C/O Care Initiatives','West Des Moines','IA','UNITED STATES','50266-8212','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-15 16:50:46',0,NULL,3,1,1,1,'\\  ',NULL),(18204,659302442013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','erbernardino','ebay@dev2dev.com.br','Emerson Bernardino','Rua Dr Paulo Carvalho Ferreira,300 Casa 16','São Paulo','São Paulo','BRAZIL','05382040',' 82666671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 17:34:29',0,NULL,3,1,11,1,'\\ ','CACN004 '),(18205,901844598012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','mcrush0774','crush0774@gmail.com','Mikhail Ivanov','Profsoyuznaya 19 - 72','Moscow','','RUSSIAN FEDERATION','117218','9032017434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 17:41:10',0,NULL,3,1,11,1,'、 ','UM00008 \r24K 多色伞 '),(18206,760211173007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','simonrico1','simonrico1@hotmail.com','Simon Martin-Rico','3550 rue cabral','Brossard','QC','CANADA','J4Z3W4','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 17:55:19',0,NULL,3,1,11,1,'、 ','UM00040 '),(18207,600710741003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','meistertlow','meistertlow@gmx.de','Thilo Nordhoff','Vaalser Str. 150a<br>App. 2147','Aachen','','GERMANY','52074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 19:13:44',0,NULL,3,1,3,1,'RA184540671CN\r ','WLAT003 '),(18208,901918230012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','sebili155281011','155281011@mail.ru','Sebili Hesen','Azerbaijan<br>17 mkr./66/10','Sumqait','Absheron','AZERBAIJAN','AZE5009','+994556878327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 19:38:55',0,NULL,3,1,11,1,'\\ ','WLAT009 '),(18209,901935301012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','woodys44','sean.woodward@personainternet.com','sean woodward','188 mallard bay RD','omemee township','ON','CANADA','k0l2w0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 20:00:59',0,NULL,3,1,3,1,'RA184540725CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18210,659394663013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','lporter200','lee.kendrick.uk@googlemail.com','Lee Kendrick','3 Upper Weald<br>Calverton','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK196EL','01908262690','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 20:50:30',0,NULL,3,1,11,1,'\\ ','CASS003 \rCAB-6060'),(18211,813408008002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','karlb6232','krlbock@yahoo.com','karl  bock','11 hilltop park','east freetown','MA','UNITED STATES','02717-1247','(508) 998-0994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 20:50:42',0,NULL,3,1,1,1,'LK160523886CN\r\r ',NULL),(18212,901979771012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','gbr.1','george_black@sky.com','george black','9 blenheim court','york','North Yorkshire','UNITED KINGDOM','yo305wd','01904466814','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 21:07:24',0,NULL,3,0,3,1,'RA184540827CN\r','HSJA002 \r英标'),(18213,659401858013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','angelote30','angelcarmona4@hotmail.com','Angel Carmona Martinez','Avda. Al- Andalus, Bl. 17, 2ºC','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','616829264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 21:08:13',0,NULL,3,1,3,1,'RA184540795CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18214,600780817003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',3.99,'cnfaner','damirs','damir.susec@gmail.com','Damir Sušec','S. Pukljaka 18','Tuhelj','Tuhelj','CROATIA','49215','00385958930877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 22:00:48',0,NULL,3,1,3,1,'RA184540800CN\r ','ANTY002 '),(18215,659428544013,230695501261,'2 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*2',88.99,'eastar4','danit9','d_t9@walla.co.il','danit peretz','shimon avidan 85','rishon le zion','AL','ISRAEL','75339','0528024258','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 22:15:21',0,NULL,3,1,3,1,'RA184540711CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18216,814109907011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','maialize','tonypluta@cox.net','Seng Khamsopha','2282 Abarth St','Las Vegas','NV','UNITED STATES','89142-1812','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 22:26:04',0,NULL,3,1,1,1,'\\  ',NULL),(18217,902025882012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','tac99','tacurrie@embarqmail.com','Terrie A. Currie','414 S Warren St','Warrensburg','MO','UNITED STATES','64093','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 22:29:57',0,NULL,3,1,1,1,'\\  ',NULL),(18218,814118323011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','stretchsound','stretchsound@aol.com','RICHARD D. EDMONDS','131 Sullivan Pl','BROOKLYN','NY','UNITED STATES','11225-2708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 22:42:15',0,NULL,3,1,1,1,'\\ ',NULL),(18219,600797570003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','anticonartist','bryandbusiness@gmail.com','Bryan Derballa','625 Humboldt St<br>Apt 1L','Brooklyn','NY','UNITED STATES','11222-4166','(510) 684-9589','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-15 22:51:26',0,NULL,3,1,1,1,'\\  ',NULL),(18220,902039542012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','swadd-master','b_harp@hotmail.co.uk','Christopher swaddling','62 Crawley Crescent<br>Hampden Park','Eastbourne','East Sussex','UNITED KINGDOM','BN22 9RN','01323503514','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 22:58:06',0,NULL,3,1,3,1,'RA184540637CN\r ','HSNO019+CCNO001 '),(18221,814130218011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','broadack85','alexanderbroad@hotmail.co.uk','Alex Broad','28 kirklees road, birkdale','southport','Merseyside','UNITED KINGDOM','PR84RB','01704560835','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 23:11:08',0,NULL,3,1,3,1,'RA184540708CN\r ','OTHP005 '),(18222,814131772011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','olivia_glass','glass_joel@hotmail.com','JOEL GLASS','PO Box 202<br>196 SHADY HILL DRIVE','STAR','MS','UNITED STATES','39167-0202','(601) 906-8798','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 23:14:13',0,NULL,3,1,1,1,'\\  ',NULL),(18223,659455981013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','frap76','pfefferf@whitewms.com','Frances Pfeffer','2946 S 18th St','Philadelphia','PA','UNITED STATES','19145-4814','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 23:46:18',0,NULL,3,1,7,1,'EE636828890CN ','兼容型3D眼镜 通用型 '),(18224,659421866013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',3,'OTCN001',11.94,'eastar4','hi-tech_liquidation','uyen4liquidation@sbcglobal.net','Hi-Tech Liquidation, Inc.','2722 Teepee Dr','Stockton','CA','UNITED STATES','95205-2444','(209) 460-0554','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 23:49:43',0,NULL,3,1,1,1,'\\  ',NULL),(18225,758279040007,170737835667,'2 pairs LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'au-buy','jstoj110484','jstoj@hotmail.com','Julie Stojanovska','47 St Andrews Blvd','Casula, Sydney','New South Wales','AUSTRALIA','2170','0422311090','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 00:06:56',0,NULL,3,1,3,1,'RA184540773CN\r ','LGGL002*2 '),(18226,902068829012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','kurt75burt','ks_packer@yahoo.com','Kurt Packer','6798 Liza Ln','West Jordan','UT','UNITED STATES','84081-4208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 00:16:17',0,NULL,3,1,1,1,'\\  ',NULL),(18227,814156919011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',37.99,'eastar4uk','timtlc123','timmylong@hotmail.co.uk','Timothy Long','1 Jackson Close<br>Kesgrave','Ipswich','Suffolk','UNITED KINGDOM','IP5 2QL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 00:26:32',0,NULL,3,1,3,1,'RA184540760CN\r ','GLSG001 '),(18228,902077098012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','alternativegate-japan','alternativegate@gmail.com','Shinya Ohkawa','Robotics lab. Department of Computer Science<br>Hashirimizu 1-10-20 National Defense Academy','Yokosuka','Kanagawa','JAPAN','239-8686','090-6884-6863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 00:32:01',0,NULL,3,1,11,1,'\\ ','OTCR001 '),(18229,813516858002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','christinabrito','shortyrepn305@aol.com','christina brito','1895 NW 15th St','miami','FL','UNITED STATES','33125-2201','(786) 351-6002','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 01:14:22',0,NULL,3,1,1,1,'\\  ',NULL),(18230,902103412012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','eedott','jhill@kfg.com','John Hill','111 Hemingway Rd','Louisville','KY','UNITED STATES','40207-4018','(502) 451-0600 ext.: 217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 01:49:18',0,NULL,3,1,1,1,'\\  ',NULL),(18231,606222391004,140516085214,'New Logitech Harmony 628 Universal Remote Control',2,'RCLO006',91.98,'cnfaner','mdoy3211','mdoyle@integra.net','Michele Doyle','21645 Boulder Creek Dr','Lakeville','MN','UNITED STATES','55044-4800','(952) 843-3112','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 02:13:24',0,NULL,3,1,1,1,'\\  ',NULL),(18232,760443579007,170728921737,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',58.99,'au-buy','dany-lou_1','dany-lou@hotmail.com','Daniel Parent','50 rue claveau','st Lin laurentides','QC','CANADA','J5m 2A7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 02:27:51',0,NULL,3,1,3,1,'RA184540610CN\r ','HSSE011 '),(18233,902120515012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','datgirlkia1','hardworkerlakia@aol.com','Lakia Thomas','8998 Hickory Hill Rd','Oxford','PA','UNITED STATES','19363-2247','(267) 506-1255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 02:37:34',0,NULL,3,1,1,1,'\\  ',NULL),(18234,606238318004,140644120563,'New Genuine Motorola H721 Bluetooth Wireless Headset+AC adapter',2,'HSMO022',45.1,'cnfaner','hannibal811wj','hannibal8@aol.com','Dave Moore','747 Avenue A','Redondo Beach','CA','UNITED STATES','90277-4813','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 03:34:54',0,NULL,3,1,1,1,'\\  ',NULL),(18235,814217102011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',2,'HSNO004',37.98,'eastar4','jbah1200','bahia_harjot@hotmail.com','Jaswinder Bahia','59 Bach blvd','Brampton','ON','CANADA','L6Y2W5','(647) 218-4020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 03:38:02',0,NULL,3,1,11,1,'\\ ','HSNO004 '),(18236,813560183002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','teaguelions08','bradray@windstream.net','Brad Thompson','4901 Kinsey Dr<br>Apt 715','Tyler','TX','UNITED STATES','75703-3016','(903) 388-0976','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 03:42:27',0,NULL,3,1,1,1,'LK159660955CN\r ',NULL),(18237,813562250002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','ddom7111','easy_rider_boone@yahoo.com','daniel dominick','8 manhattan ave','batavia','NY','UNITED STATES','14020-2410','(716) 432-0086','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 03:45:37',0,NULL,3,1,1,1,'LK163528825CN\r\r ',NULL),(18238,752649900008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',46.99,'au-buy','islandera260','georg4@mac.com','Georg Bobbert','15 Moore St','Austinmer','New South Wales','AUSTRALIA','2515','0404091867','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 03:49:58',0,NULL,3,1,3,1,'RA184540813CN\r ','HBPH007 '),(18239,814221360011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',3,'CASS003',25.47,'eastar4','extreme0011','shannon@wulff.com.au','Shannon Wulff','14 Parkfield Rd','Kelmscott','Western Australia','AUSTRALIA','6111','0424935640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 03:54:34',0,NULL,3,1,11,1,'\\ ','CASS003\rCAB-6060 '),(18240,8881324007746493,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4uk','themaddog59','steveworsnop@btinternet.com','Steve Worsnop','65 Hailstone Drive','Northallerton','North Yorkshire','UNITED KINGDOM','DL6 1SP','01609773995',NULL,NULL,NULL,'2011-12-16 03:55:46',0,NULL,3,1,3,1,'RA184540901CN\r ','MOAP001\r补发的 测试一下 再发货'),(18241,902160846012,220864660846,'New Pretty Cat w/Lotus Leaves Trim 3-Section Umbrella',1,'UM00039',19.99,'eastar4','mhdc1512','love_bzvivi@yahoo.co.jp','Etsuko  Watanabe','3507 33rd St<br>#1FL','Astoria','NY','UNITED STATES','11106-2240','(917) 435-1630','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 04:46:25',0,NULL,3,1,1,1,'\\ ',NULL),(18242,814238422011,320730084062,'Dell 1510 PCI-E WIRELESS WLAN Half Mini Card + antenna',1,'WLDE002+ANTY001',10.6,'eastar4uk','gwad77','greg.wadleigh@cox.net','Gregory Wadleigh','9563 E Monument Dr','Scottsdale','AZ','UNITED STATES','85262','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 05:06:51',0,NULL,3,1,1,1,'\\  ',NULL),(18243,814239484011,320626169472,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',56.45,'eastar4','commsvc','ebay@allaw.com.au','Allaw Pty Ltd','unit 15<br>331 High Street','Chatswood','New South Wales','AUSTRALIA','2067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 05:12:10',0,NULL,3,1,3,1,'RA184543307CN\r ','WWSI006 '),(18244,760486709007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','0squared','virtualsnow@earthlink.net','Dan Timothy Owen','2905 Montrose Ave<br>Apt 519','Glendale','CA','UNITED STATES','91214','(818) 249-4055','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 05:25:26',0,NULL,3,1,1,1,'\\  ','RCLO003 '),(18245,752670843008,180757094346,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',3,'SCLO002',16.17,'au-buy','aaron.chapman','aaron@acce.com.au','AP and PA Chapman','57A Geddes Street','VICTORIA PARK','Western Australia','AUSTRALIA','6100','0893553313','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 05:32:22',0,NULL,3,1,11,1,'\\','SCLO002 '),(18246,902174325012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',15.14,'eastar4','mrhermm','mrhermanson@msn.com','Matt Hermanson','2532 N 88th St','Lincoln','NE','UNITED STATES','68507','(402) 570-2472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 05:44:41',0,NULL,3,1,1,1,'\\  ','AUI Transceiver  MX20T '),(18247,752681840008,180762085514,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.99,'au-buy','moutro13','giorgio_dim_@msn.com','georgios dimitriou','1 Agiou Panteleimonos str.','Athens','Pefki','GREECE','151 21','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 06:24:19',0,NULL,3,1,11,1,'\\\r ','GPS0010'),(18248,606265917004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','severforever2011','zvezda032@yahoo.com','Predrag Ilic','4050 Center Ave','Lyons','IL','UNITED STATES','60534-1316','(440) 864-1175','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 06:26:27',0,NULL,3,1,1,1,'\\  ',NULL),(18249,813598546002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','carlarose29-2009','carlarose29@yahoo.com','carla tumolo','932 Leslie Rd<br>Apt D','el cajon','CA','UNITED STATES','92020-6234','(619) 212-1270','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 06:32:47',0,NULL,3,1,1,1,'LK163183268CN\r ',NULL),(18250,606267088004,140630815793,'New iTech Clip II mini Multipoint Bluetooth Headset Blue',1,'HSIT004',38.9,'cnfaner','e.koumis','e.koumis@yahoo.gr','eftihis koumis','PARALIA_TELONEIOY/ KISSAMOS<br>KISSAMOS / HANIA /KRETE /GREECE','HANIA / KRETE / GREECE','','GREECE','73400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 06:35:57',0,NULL,3,1,3,1,'RA184540875CN\r ','HSIT004\r欧标 '),(18251,901755510012,220877932141,'New HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'eastar4','teachsys','teachsys1@hotmail.com','bader al-saadi','5170 Hudson Dr<br>Ste I # 62011588','Hudson','OH','UNITED STATES','44236-3797','440 399 2600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 06:59:12',0,NULL,3,1,1,1,'\\  ','SONY MCE 遥控  黑色   RM-MCE10E '),(18252,814262798011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','saisuperstar','saisuperstarinc@att.net','SAI LIU','1935 Santa Anita Ave','South El Monte','CA','UNITED STATES','91733-3415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 07:07:33',0,NULL,3,1,1,1,'\\  ','爱雨透明伞 '),(18253,659550290013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','fajarac','alfajardo@comcast.net','Al Fajardo','101 E 88th Ave<br>Apt A108','Thornton','CO','UNITED STATES','80229-4416','(720) 254-2289','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 07:24:02',0,NULL,3,1,1,1,'\\  ',NULL),(18254,600899178003,130466041506,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',58.45,'cnfaner','limgus','limroman@yandex.ru','Roman Lim','Russia, SPb, Butlerova st. 13-310','SPb','SPb','RUSSIAN FEDERATION','195256',' 79119379249','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 07:38:48',0,NULL,3,1,3,1,'BJ01601086\r ','WWSI006+ANCN001 '),(18255,659555133013,230595185557,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',36.99,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','Russia, Sankt-Peterburg, ulitsa Varshavskaya dom 19 korpus 1 kvartira 113','St.-Petersburg','','RUSSIAN FEDERATION','196128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 07:52:59',0,NULL,3,1,11,1,'\\ ','WWSI005 '),(18256,770238449001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','jdogden','joshluv07@yahoo.com','Josh','2930 E 110th Dr','Northglenn','CO','UNITED STATES','80233-4662','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 08:56:17',0,NULL,3,1,1,1,'\\  ',NULL),(18257,606288904004,140651987037,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 adult size',1,'LGGL002*2',104.99,'cnfaner','vvinterww','gvainter@mail.ru','Vadim Goncharenko','144, Chekhov street, flat 30 \"a\"','Stavropol','Stavropol Territory','RUSSIAN FEDERATION','355020','89034193833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:02:07',0,NULL,3,1,3,1,'RA184540946CN\r ','LGGL002*2 '),(18258,814296389011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',1,'CASS002',8.29,'eastar4','discountwebdeals','peterbell777@gmail.com','Peter Bell','3 Scurry Street','Dunlop','Australian Capital Territory','AUSTRALIA','2615','0487721111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:33:04',0,NULL,3,1,11,1,'BJ01601102\r ','CASS002 \rCAB-SS-2660'),(18259,902230825012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','sul.vendas','sulvendas@gmail.com','MICHAEL PEREIRA SILVA','RUA ESPÍRITO SANTO, Nº 105','CACHOEIRINHA','RIO GRANDE DO SUL','BRAZIL','94965-140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:41:45',0,NULL,3,1,11,1,'BJ01601117\r ','OTCN004*10 '),(18260,600923912003,130458357796,'New Genuine Motorola H700 Bluetooth Headset track#',1,'HSMO011',15.99,'cnfaner','anfo9','anthonyjfranklin@gmail.com','Anthony Franklin','29 Tolhurst Avenue','Boronia','Victoria','AUSTRALIA','3155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 10:04:44',0,NULL,3,1,3,1,'RA184543050CN\r ','HSMO011\r澳标 '),(18261,902244554012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','rabbitsnoopy','lorraine.jenkins@btopenworld.com','Lorraine Jenkins','1 Redwood Drive','Kingsbury','Staffordshire','UNITED KINGDOM','B78 2PP','01827875160','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 10:26:32',0,NULL,3,1,3,1,'RA184543094CN\r ','OTGR001 '),(18262,600928562003,130608487119,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',50.99,'cnfaner','dikl99','udi.azulay@intel.com','Udi Azulay','D.N Misgav','Kibutz Yasur','','ISRAEL','20150','972547886141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 10:27:48',0,NULL,3,1,3,1,'RA184543029CN\r ','SAFI001 '),(18263,600928884003,130617205109,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',176.99,'cnfaner','grim_kobolt','outrag3r@gmail.com','Andrew Kitsios','Neapolis 5','Nea Peramos','Attiki','GREECE','19006','+302296032966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 10:28:28',0,NULL,3,1,3,1,'RA184545841CN\r ','GLSG009*2 '),(18264,606302773004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',56.99,'cnfaner','hieronymus.kilius','wolfgang.striewski@kabelmail.de','Wolfgang Striewski','Tulpenweg 6','Flintbek','','GERMANY','24220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 10:16:34',0,NULL,3,1,3,1,'RA184543749CN\r ','GLSG001 '),(18265,814321440011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',19.98,'eastar4','sentin007','alex.shustikov@gmail.com','Alex Shustikov','Mahtra 64-31','Tallinn','','ESTONIA','13812','+3725102305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 11:00:44',0,NULL,3,1,11,1,'BJ01601084\r ','HSJA012 \r银色的\r欧标'),(18266,606314445004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',113.98,'cnfaner','algafarov2010','algafarov@mail.ru','Albert Gafarov','Lenina 28, 2','Oktyabrskiy','Bashkortostan','RUSSIAN FEDERATION','452600','9033544700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 11:15:48',0,NULL,3,1,3,1,'RA184543409CN\r ','GLSG001 '),(18267,902262768012,220759518767,'New Logitech Rechargeable battery L-LB2 1700mAh MX1000',1,'BALO007',10.94,'eastar4uk','darkknowledge','knowledge@netcabo.pt','Pedro Mota','Travessa da Presa Velha nº44','Porto','Porto','PORTUGAL','4300-446','(351)939436656','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 11:26:12',0,NULL,3,1,11,1,'BJ01601105\r ','BALO007 '),(18268,760572888007,170730545083,'New Genuine Logitech Harmony 628 Universal Remote Control',1,'RCLO006',46.99,'au-buy','aylaaa44','ben@brightmac.com.au','Bright IT','17 Johnston Street','Stratford','Queensland','AUSTRALIA','4870','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 11:39:04',0,NULL,3,1,3,1,'RA184543253CN\r ','RCLO006 '),(18269,760591215007,170728921737,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',58.99,'au-buy','sertanozdemir','sertan_ozdemir@hotmail.com','sertan özdemir','çaglayan mah levent sok 18-b','kagıthane/ istanbul','','TURKEY','34403','5324139371','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 12:40:17',0,NULL,3,1,3,1,'RA184543222CN\r ','HSSE011 '),(18270,902295763012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','acitasan','acitasan@hotmail.com','Alberto Cita','C/. Monteclaro, 40','Navalcarnero','Madrid','SPAIN','28600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 12:59:11',0,NULL,3,1,11,1,'BJ01601089\r ','TRMX003 \rAUI Transceiver  MX20T'),(18271,770321659001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','sunshine00720','sunshine00720@yahoo.com','trish pace','1236 mail route rd','bonneau','sc','UNITED STATES','29431-3300','(843) 300-5872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 13:17:53',0,NULL,3,1,1,1,'LK152210489CN\r ',NULL),(18272,606342644004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','laward01','lward82@comcast.net','Larry A Ward','12121 E 39th Ter S','Independence','MO','UNITED STATES','64052-2405','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 13:24:23',0,NULL,3,1,1,1,'LK165111856CN\r ',NULL),(18273,814366941011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','promythyus','brooksaar@gmail.com','Aaron Brooks','4A Mason Street','Thirlmere','New South Wales','AUSTRALIA','2572','0246819804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 13:21:25',0,NULL,3,1,11,1,'BJ01601111\r ','WLIN015 \r 无线蓝牙二合一'),(18274,600972537003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','omogbolahan','mutiu4real2003@yahoo.com','mutiu ahmed','9200 Bissonnet St<br>Apt 1316','houston','TX','UNITED STATES','77074-1417','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 13:48:02',0,NULL,3,1,1,1,' ',NULL),(18275,600979757003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','donelmobley','donelmobley@yahoo.com','Donel Mobley','671 Jann Ave','Opa Locka','FL','UNITED STATES','33054-3310','(305) 479-9210','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 14:14:37',0,NULL,3,1,1,1,'LK161514656CN\r ','Standard Delivery '),(18276,760635477007,170728978814,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',49.99,'au-buy','jacktwist2','joseluizmoura@ig.com.br','Jose Luiz','Rua Rubens Alves Tavares 43<br>Vale Dos Machados','Guarulhos','Sao Paulo','BRAZIL','07082650','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 14:42:15',0,NULL,3,1,3,1,'RA184543219CN\r ','LGRM001 '),(18277,770365293001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','cheahht','chtiong@gmail.com','Cheah Hooi Tiong','Blk 646, Pasir Ris Drive 10,<br>#09-08,','default','','SINGAPORE','510646','+(65)96341448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 15:16:08',0,NULL,3,1,11,1,'BJ01601087\r ','BR3D006 '),(18278,601004850003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','danybimba777','bimba77@hotmail.com','Daniel KOSTIC OBRADOVIC','39, Rue De Montreuil','PARIS','Île-de-France','FRANCE','75011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 15:43:17',0,NULL,3,1,3,1,'RA184543165CN\r ','MOOE002\rOEM '),(18279,902366958012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*2',177.98,'eastar4','jennwood1975','jennwood75@gmail.com','Jennifer Wood','7820 Next to Never Ln','SPOTSYLVANIA','VA','UNITED STATES','22551-5064','(540) 834-8239','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 15:46:55',0,NULL,3,1,7,1,'EE636829484CN ',' 兼容型3D眼镜 通用型'),(18280,606391761004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',56.99,'cnfaner','sif666','migella@gmail.com','Sini Tiihonen','Pellervonkatu 9 A 401','Tampere','','FINLAND','33540','+358414368315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 16:20:18',0,NULL,3,1,3,1,'RA184543678CN\r ','GLSG001 '),(18281,814450511011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','bradtoop','popsrocks@yahoo.com','Brad Opp','425 3rd St SE','Sidney','MT','UNITED STATES','59270-4611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 16:39:54',0,NULL,3,1,1,1,'LK165444814CN\r ',NULL),(18282,606400029004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',8,'WLAP002',159.6,'cnfaner','dcpartscom','dlutian@dcparts.com','Dan Lutian','16500 Detroit Ave','Lakewood','OH','UNITED STATES','44107-3628','(216) 228-4949','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 16:43:10',0,NULL,3,1,1,1,'LK165166996CN\r ',NULL),(18283,902402380012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','twil7668','tenasha@gmail.com','Tenasha Williams','423 Pine St','Darby','PA','UNITED STATES','19023-2836','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 16:59:32',0,NULL,3,1,1,1,'LK163796985CN\r ',NULL),(18284,770416701001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','atlantaraptors','atlanta.raptors@gmail.com','Jonathan Koo','27 Goldberry Sq','Toronto','ON','CANADA','M1C3H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 17:15:20',0,NULL,3,1,11,1,'BJ01601090\r ','BR3D008 '),(18285,601035645003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','mailsunitha2011','mailsunitha@gmail.com','sunitha suresh','1602 Crane Ct<br>Rm 121','San Jose','CA','UNITED STATES','95112-4201','(408) 504-8020','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 17:16:47',0,NULL,3,1,1,1,'LK164597014CN\r ',NULL),(18286,814473626011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','mmoney_123','rostislavm@optonline.net','rostislav mariyasin','36 Franklin St','Brentwood','NY','UNITED STATES','11717','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 17:26:10',0,NULL,3,1,1,1,'LK162292037CN\r ',NULL),(18287,814500565011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','kameelda','kameel_da1@hotmail.com','kameel dagaisha','11/13<br>po 68','maghar','','ISRAEL','20128','052-355-2343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:18:20',0,NULL,3,1,11,1,'BJ01601093\r ','HSJA002 '),(18288,760647198007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','duane10111','dwill101@yahoo.com','duane Williams','7521 Mansion Cir<br>Apt D','mason','OH','UNITED STATES','45040','(513) 237-5082','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 18:19:24',0,NULL,3,1,1,1,'LK156030831CN\r ',NULL),(18289,659723915013,230675318687,'New in box Genuine Samsung 2 pair SSG-2100AB + 3D blu-ray monster house disc',1,'GLSG001*2+BR3D004',120.99,'eastar4','stefanm1979','bobo_17192@live.de','stefan müller','lindenstr.32','Waren','','GERMANY','17192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:35:38',0,NULL,3,1,3,1,'RA184543284CN\r ','GLSG001*2+BR3D004 '),(18290,606440548004,140626376046,'New Genuine Motorola H710 Bluetooth Wireless Headset',1,'HSMO021',29.39,'cnfaner','coldruslan','mmxangel@gmail.com','ruslan koren','Kislev 17 / 13<br>Neve adarim','Ashqelon','','ISRAEL','78721','972523741571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:39:45',0,NULL,3,1,3,1,'RA184545577CN\r ','HSMO021 '),(18291,601067314003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','bpneufeld69','bpn1996@yahoo.com','Brian Neufeld','801 Santa Fe Trl','Keller','TX','UNITED STATES','76248-4911','(817) 658-2933','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 18:45:36',0,NULL,3,1,1,1,'\\ ',NULL),(18292,814518592011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','jpafa_lk','jpafa1981@hotmail.com','JOAO PAULO ANDRADE','Rua Anfrisio Lobão, 2481, apt.100, edf. Terra de Siena<br>Jóquei','Teresina','Piauí','BRAZIL','64049-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:54:54',0,NULL,3,1,3,1,'RA184543151CN\r ','LGRM001 '),(18293,902470153012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',168.99,'eastar4','ophiucius59','pat.petit59@wanadoo.fr','Patrick PETIT','3 rue Maurice BOUTON','WALLERS','Nord-Pas-de-Calais','FRANCE','59135','03.27.24.21.75.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:55:57',0,NULL,3,1,3,1,'RA184543338CN\r ','GLSG001*3 '),(18294,902471335012,220903895938,'4 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*4',125.99,'eastar4uk','diegomendes','diegoacmendes@gmail.com','Diego Mendes','Alameda dos Nhambiquaras, 1770, Cj 705<br>Indianopolis','Sao Paulo','SP','BRAZIL','04090004','(011) 8711-1140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 19:07:48',0,NULL,3,1,6,1,'EE636829440CN ','LGGL002*4\r申报为glasses申报40美金 '),(18295,814541170011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','lynnzal','l.branigan@ntlworld.com','Lynnden Branigan','CARDWELYN<br>35a Plough Hill','Cuffley','Hertfordshire','UNITED KINGDOM','EN6 4DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 19:28:49',0,NULL,3,1,3,1,'RA184545625CN\r ','WLDE002 '),(18296,814559999011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','samisayin1960','samisayin@gmail.com','Mehmet Sami Sayin','Bagdat Cad. No:317 Daire:1 Koksal Apt Erenkoy','Istanbul','-','TURKEY','34728','00905325743147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 20:03:37',0,NULL,3,1,11,1,'BJ01601108\r ','HSUE003 \r带麦的'),(18297,814567405011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','raematazz','rae_clarke@hotmail.com','Rae Clarke','28 Bucklebury<br>Stanhope Street','London','London','UNITED KINGDOM','NW1 3LB','07958529663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 20:16:06',0,NULL,3,1,3,1,'RA184545356CN\r ','LGGL002 '),(18298,902536982012,220748684477,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',2.99,'eastar4uk','ooomarduooo','wajdam@op.pl','Mikolaj Wajda','8 The Innings<br>Observatory Lane','Rathmines','Dublin','IRELAND','6','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 20:46:37',0,NULL,3,1,11,1,'BJ01601109\r ','OTCN001 '),(18299,601113748003,130489918804,'New Sony Ericsson HBH-PV703 BLUETOOTH HEADSET track#',1,'HSSE004',20.8,'cnfaner','janniche76','janniche@kranringen.no','Janniche Ekeland','V. Vardane 88','Erdal','Erdal','NORWAY','5306','90602354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 20:46:42',0,NULL,5,1,18,0,NULL,'HSSE004\r欧标 '),(18300,814570663011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','gatopulgoso2011','pacorro49@gmail.com','francisco paniagua','1064 rock church rd','dickson','TN','UNITED STATES','37055-6015','(615) 474-4173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 20:47:10',0,NULL,3,1,1,1,'\\ ',NULL),(18301,814600572011,320475111586,'2.0 New ASUS Bluetooth Module +cable for V1S E99 F8 N80',1,'BTHU2002',9.88,'eastar4','seanblox','sholz042@gmail.com','shawn holz','7229 Sealawn Dr','spring hill','FL','UNITED STATES','34606-2741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 21:19:10',0,NULL,3,1,1,1,'LK165373707CN\r\r ','华硕10pin 0.8 10cm  '),(18302,606516357004,140626376315,'New Grohe hand Shower holder made in Germany',1,'OTGR003',20.9,'cnfaner','palya58','liliyay61@yahoo.com','Pavel Yermakov','2217 Middleberry Rd','Sacramento','CA','UNITED STATES','95815-4118','(916) 922-2168','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-16 22:08:39',0,NULL,3,1,1,1,'LK165082284CN\r ',NULL),(18303,814648915011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',57.99,'eastar4','xaviportell','xavibest@gmail.com','Xavier Portell','Carretera Provincial, 172','Cassa de la Selva','Cataluña','SPAIN','17244','654228335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 23:14:29',0,NULL,3,1,3,1,'RA184543664CN\r ','GLSG001 '),(18304,601159611003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','itaimakmal','makmal@gmail.com','Itai Makmal','Mashaabim 32/2<br>Entrance B','Hod-Hasharon','','ISRAEL','45201','972-54-5771119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 23:17:02',0,NULL,3,1,3,1,'RA184545665CN\r ','RELO002 '),(18305,902631020012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','armandoc929','armando@acflooringcompany.com','armando chavez','1007 E Avenida De Las Flores','thousand oaks','CA','UNITED STATES','91360-4961','(805) 379-4151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 00:08:59',0,NULL,3,1,1,1,'\\\r ',NULL),(18306,902639213012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','cheezoid84','cheezoid@iinet.net.au','Philip Allen','Level 3, 14 Ventnor Av','West Perth','Western Australia','AUSTRALIA','6005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 00:35:53',0,NULL,3,1,3,1,'RA184545461CN\r ','HSPH002\r红色 '),(18307,601185496003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','sweetregina65','sweetregina@aol.com','Regina Payne','555 E 33rd Pl<br>Apt 1001','Chicago','IL','UNITED STATES','60616-4186','(708) 288-5750','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 01:20:59',0,NULL,3,1,1,1,'LK161114830CN\r ',NULL),(18308,770622305001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','ddive1','ddive@att.net','Howard Herman','12150 SW 50th St','Cooper City','FL','UNITED STATES','33330-4476','(954) 295-0722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 01:29:00',0,NULL,3,1,1,1,'\\ ',NULL),(18309,601186316003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','rajp30','rajp37.rp@gmail.com','Robert Prevost','10 Silverstone cres','Keswick','ON','CANADA','L4P4A5','(905) 989-2833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 01:31:01',0,NULL,3,1,3,1,'RA184543085CN\r ',NULL),(18310,814694166011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'eastar4','sue*n*ray','weber.sue@tpg.com.au','Sue Weber','9 Oakleaf Place','Narre Warren South','Victoria','AUSTRALIA','3805','0397058116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 01:34:41',0,NULL,3,1,11,1,'\\ ','HSNO003 \r澳标'),(18311,601191855003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','loup5687','aramrb49@msn.com','jim bolin','4404 S Hannibal Way<br>Ofc','Aurora','CO','UNITED STATES','80015-1510','(303) 503-6612','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 01:56:03',0,NULL,3,1,1,1,'LK163290488CN\r ',NULL),(18312,753095046008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.99,'au-buy','mrcnjohnson','mrcnjohnson@cox.net','Cedric N. Johnson','PO Box 52','Gray','GA','UNITED STATES','31032-0052','(478) 254-5522','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 01:58:44',0,NULL,3,1,1,1,'LK161625538CN\r ',NULL),(18313,659861973013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','vagabundo71','vagabu_ndo@hotmail.com','Francisco Tello','3325 5th Ave S','Minneapolis','MN','UNITED STATES','55408-3250','(612) 437-9576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 01:53:41',0,NULL,3,1,1,1,'、','兼容型3D眼镜 通用型 '),(18314,601202967003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','jwalkeraz','jwaz@q.com','Jason Walker','1972 W Olive Way','Chandler','AZ','UNITED STATES','85248-4255','(602) 214-1845','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 03:02:02',0,NULL,3,1,1,1,'LK165297206CN\r ','OEM '),(18315,814718621011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','bigg3814','ethomas7321@gmail.com','eric thomas','2210 island ave','philadelphia','PA','UNITED STATES','19142-1006','(267) 671-6902','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 03:09:38',0,NULL,3,1,1,1,'LK162394402CN\r ',NULL),(18316,812600972011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','stason_h-d','stanislavp@inbox.ru','Stanislav','Jalan Perum Pesraman Block D, №34B','Kampus Unud Bukit Jimbaran','Denpasar','INDONESIA','80361','+6285738566951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 03:32:55',0,NULL,3,1,11,1,'BJ01601088\r ','HBPH003 '),(18317,601211323003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.49,'cnfaner','marcelstf','marcelstf@gmail.com','Marcel Figueiredo','Rua Salvador Cardoso<br>N 33 AP 52','São Paulo','São Paulo','BRAZIL','04533-050','+55(11) 9608-8594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 03:50:22',0,NULL,3,1,17,0,' RA184545413CN\r',NULL),(18318,606587849004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.49,'cnfaner','marcelstf','marcelstf@gmail.com','Marcel Figueiredo','Rua Salvador Cardoso<br>N 33 AP 52','São Paulo','São Paulo','BRAZIL','04533-050','+55(11) 9608-8594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 03:51:57',0,NULL,3,1,3,1,'RA184545413CN\r ','MOMI004\rWhite and black\r '),(18319,902695148012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',168.99,'eastar4','adeptcompserv','shaynesaunders@hotmail.com','Tanya Mclean','2 Chelmsford Street','Boggabri','New South Wales','AUSTRALIA','2382','61407907764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 03:53:41',0,NULL,3,1,3,1,'RA184543315CN\r ','GLSG001*3 '),(18320,659886406013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','brea_rocks','brea_rocks_1@hotmail.com','Maria Ferrigno','2/50 High Street Road<br>Ashwood','Melbourne','Victoria','AUSTRALIA','3147','0424428218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 03:57:44',0,NULL,3,1,6,1,'EE495359551CN ','兼容型3D眼镜 通用型 '),(18321,902699279012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','hiflyn_1','ktmflyn@aol.com','Kevin May','10100 Viking Dr<br>C/O Tremendous Entertainment Ste 200','Eden Prairie','MN','UNITED STATES','55344-7256','(651) 260-3965','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 04:10:37',0,NULL,3,1,1,1,'LK165439638CN\r ',NULL),(18322,601215571003,130553375553,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',11.89,'cnfaner','arestii','aresti@bigpond.com','Aresti Tharapos','4 Grantham Street<br>West Brunswick','Melbourne','Victoria','AUSTRALIA','3055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 04:19:34',0,NULL,3,1,3,1,'RA184545458CN\r ','HSNO030\r澳标 '),(18323,600543734003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',31.5,'cnfaner','wow1136','chook9@hotmail.com','Mr. Somchai Tragulpirom','374/29 Soi. Ruam Naum Jai2<br>Ladprao 71 Wangthonglang','Bangkok','Bangkok','THAILAND','10310','6681-917-9955','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 05:00:47',0,NULL,3,1,3,1,'RA184545501CN\r ','HSPL008 '),(18324,601223059003,130458357813,'New  Motorola H700 Bluetooth  Headset + car charger',1,'HSMO011+CCMO001',17.99,'cnfaner','jaynangel2011','jaynangeljohns@yahoo.com','Jay Johns','848 9th Ave<br>Apt 2','longview','WA','UNITED STATES','98632-2138','(360) 430-1410','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 05:10:35',0,NULL,3,1,1,1,'LK162599689CN\r ',NULL),(18325,659908027013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','debby2436','dc4xf@virginia.edu','Aline So Ting Fong','8221 Hemlock Ridge Rd','Fairfax Station','VA','UNITED STATES','22039-3019','(434) 989-8263','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 06:22:02',0,NULL,3,1,1,1,'\\ ','接边蕾丝透明伞        '),(18326,814770378011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',2,'HSNO015',71.98,'eastar4','44557564','jianglin8888@yahoo.com.cn','lin jiang','6550 Jericho Turpike','Commack','NY','UNITED STATES','11725','(646) 267-6248','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 07:27:32',0,NULL,3,1,1,1,'\\ ',' '),(18327,814770906011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','ikyu3596san','ok-mail@mx2.avis.ne.jp','OSAMU KITAYAMA','2128-5 Yanagihara','Nagano-city','Nagano','JAPAN','381-0012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 07:31:51',0,NULL,3,1,11,1,'BJ01601114\r ','WLIN011 '),(18328,902740243012,220806892088,'NEW Sunflower Bloom 3-section Folding umbrella',1,'UM00004',21.99,'eastar4','rosellaorchids','allan@rosellaorchids.com.au','Janelle Bancroft','95 Woolwich Road','South Grafton','New South Wales','AUSTRALIA','2460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 07:31:54',0,NULL,3,1,11,1,'BJ01601096\r ','UM00004 \r向日葵三折叠伞 '),(18329,902113637012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',20,'TRMX003',151.4,'eastar4','fati_zee','actualtestking747@hotmail.com','ZSM Inc.','502 Shaw Rd<br>Ste 105','Sterling','VA','UNITED STATES','20166-9435','(440) 840-3343','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 07:37:44',0,NULL,3,1,4,1,'YW867738805CN ','AUI Transceiver  210T 或者210TS都行'),(18330,814776927011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','argiroydisb','fot.basilis@hotmail.com','Vasileios Argiroudis','prevezis<br>24','Metamorfosi','Attiki','GREECE','14451','+030 2102835785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 08:03:15',0,NULL,3,1,3,1,'RA184545492CN\r ','OTSA001 '),(18331,902750848012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','mannen55','rei-mannen@zeus.eonet.ne.jp','Rei Mannen','238A Thomson Road, #20-01<br>Novena Square Tower A','default','','SINGAPORE','307684','68183779','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 08:22:15',0,NULL,3,1,3,1,'RA184543077CN\r ','LGRM001 '),(18332,902753271012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','elkan2006','david@sandersonemail.com.au','David Sanderson','PO BOX 1189','Nairne','South Australia','AUSTRALIA','5252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 08:29:16',0,NULL,3,1,11,1,'BJ01601107\r ','OTTP001 '),(18333,814791251011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','revolution_adm','pridannikovd@gmail.com','Pridannikov Dmitriy','Bagrationa str. 1117','Kaliningrad','Kaliningrad','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 09:04:38',0,NULL,3,1,3,1,'RA184545974CN\r ','RCLO009 '),(18334,606643431004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','thesystemworks','tim@deadlyninja.com','Tim Valenzuela','825 E Sequoyah St','Tucson','AZ','UNITED STATES','85719-2950','(520) 762-6267','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 10:12:30',0,NULL,3,1,1,1,'LK161012328CN\r ','加一个IR emitte '),(18335,601270037003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','wjv6083','wjv6083@yahoo.com','Eric Lim','12, Jalan Angsana 9, Taman Bukit Angsana,<br>Cheras','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','56000','0178812688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 10:23:55',0,NULL,3,1,3,1,'RA184545395CN\r ','HSMO005 '),(18336,814814762011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','bassing-jersey','alanaubert@jerseymail.co.uk','alan Aubert','Clovercroft, Rue De Sergent','St.Martin','Jersey','UNITED KINGDOM','JE3 6HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 10:30:39',0,NULL,3,1,3,1,'RA184545271CN\r ','GLOT001 '),(18337,770742892001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','0400240878','abrahambanda@yahoo.com','abraham banda','12 Gandawara crescent','Newman','Western Australia','AUSTRALIA','6753','0891750184','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,11,1,'BJ01601104\r ','BR3D006 '),(18338,814833813011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','zecmario','mario.zec8@gmail.com','Mario Zec','Kamnikarjeva 31','Škofljica','','SLOVENIA','1291','+38651671722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 11:28:20',0,NULL,3,1,3,1,'RA184545360CN\r ','GLOT001 '),(18339,606662889004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32,'cnfaner','inotrobot','avg_2000@mail333.com','Andrey Gribanov','Serisheva str., 54-47','Khabarovsk','Khabarovskii krai','RUSSIAN FEDERATION','680038','+79145435856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 11:40:22',0,NULL,3,1,3,1,'RA184545339CN\r ','GPS0010 '),(18340,902817766012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','getbayer','phonboon@gmail.com','phonboon rattanarat','58/37 Muban Noble Geo-Rama 5,<br>Nakorn-in-Kanjanapisek Rd., Bangkhunkong,','Bangkruay','Nonthaburi','THAILAND','11130','(660) 5996637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 11:52:21',0,NULL,3,1,11,1,'BJ01601095\r ','MOAP001 '),(18341,902830429012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','zolton20','herrning@aol.com','John Herrning','29 Ardennes Dr','Ladera Ranch','CA','UNITED STATES','92694-0969','9493640509','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 12:27:50',0,NULL,3,1,3,1,'RA184545736CN\r ','合并的订单 一共买了两套'),(18342,753241756008,180755479508,'New Jabra BT250V FreeSpeak Bluetooth Headset  BT 250V+AC charger',1,'HSJA001',23.8,'au-buy','droopysss057','droopysss@yahoo.fr','claude COLIN','01 rue de belfast','CREHANGE','Lorraine','FRANCE','57690','0387907928','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 12:39:41',0,NULL,3,1,11,1,'BJ01601091\r ','HSJA001\r欧标 '),(18343,659986495013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','timaco76','timaco76ebay@laposte.net','Mathieu Colliard','80 rue Bernardin de Saint Pierre','Le Havre','Haute-Normandie','FRANCE','76600','0679756947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 13:01:43',0,NULL,3,1,11,1,'BJ01601110\r ','WLAP008 '),(18344,753253542008,180755479313,'New i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',45.99,'au-buy','obrandon8873','brandon8873@gmail.com','Soon Sharon','No.27, Jalan Api-Api 5,<br>Kepong Baru,','Kuala Lumpur','W Persekutuan','MALAYSIA','52100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 13:15:07',0,NULL,3,1,3,1,'RA184545373CN\r ','HSIT001 '),(18345,902852448012,220871869126,'Genuine Jabra BT250V Bluetooth Headset BT 250V',1,'HSJA001',16.9,'eastar4uk','grizedale','foj@hotmail.co.uk','Jim Johnson','12 Coppice Side<br>Anlaby Park','Hull','East Yorkshire','UNITED KINGDOM','HU4 6XJ','01482505487','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 13:22:47',0,NULL,3,1,3,1,'RA184545529CN\r ','HSJA001\r英标 '),(18346,902859438012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',12.28,'eastar4uk','cmille42','koichi.oki@talktalk.net','colin miller','62 Windward Way, Smiths Wood','Birmingham','West Midlands','UNITED KINGDOM','B360PP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 13:38:39',0,NULL,3,1,3,1,'RA184545546CN\r ','HSNO005+CCNO001\r英标 '),(18347,902861536012,220816384092,'2 pairs 3D Active TV Glasses for Sony Panasonic TV',1,'GLOT001*2',52.99,'eastar4uk','trevormemorial','trevormemorial@yahoo.com','Trevor Drury','68 Central Road','Cromer','Norfolk','UNITED KINGDOM','NR27 9BW','01263514562','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 13:44:58',0,NULL,3,1,3,1,'RA184545444CN ','GLOT001*2 '),(18348,902863890012,220825062340,'New 3.0 Bluetooth BCM92070 Module+cable Asus U36 UX50',1,'BTAS3001',19.98,'eastar4','flogi_12','flogi@gmx.net','Florian Emsenhuber','Maidengasse 8','Ruprechtshofen','','AUSTRIA','3244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 13:49:10',0,NULL,3,1,11,1,' BJ01601115\r','BTAS3001 \r3.0 ASUS 6pin 6CM  '),(18349,606695779004,140644120471,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.59,'cnfaner','mirando2008-30','bats_z@walla.com','Zvicka Bats','13 Hakukia st.<br>Neve hadarim','Rishon le zion','israel','ISRAEL','75548','972 50 7478788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 13:53:43',0,NULL,3,1,3,1,'RA184545775CN\r ','LGGL003 '),(18350,601324093003,130553375553,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',59.88,'cnfaner','kidureza','zbigboss@gmail.com','Arthur Gomide do Nascimento','Rua Guanabara cs 195<br>Entroncamento','Imperatriz','Maranhão','BRAZIL','65903-380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 14:07:24',0,NULL,3,1,3,1,'RA184545648CN\r ','HSNO030\r美标 '),(18351,902872781012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.88,'eastar4','javatar','d02b06l@gmail.com','David B. Lection','8008 Looking Glass Ct','Raleigh','NC','UNITED STATES','27612-7347','(919) 264-4497','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 14:09:53',0,NULL,3,1,1,1,'LK165377638CN\r ',' OEM '),(18352,606704465004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.8,'cnfaner','intamara','tmongkolwat@hotmail.com','Thianchai Mongkolwat','50 Soi Intamara 22,  Suttisan Road<br>Din-Deang','Bangkok','','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 14:24:33',0,NULL,3,1,3,1,'RA184545634CN\r ','WLAP008 '),(18353,809912045011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','pennyloop','pennnlynnn@yahoo.com','Penny Ackley','11 Elderberry Dr','North Easton','MA','UNITED STATES','02356-1380','(617) 875-7117','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 14:40:14',0,NULL,3,1,1,1,'LK151399718CN\r ',NULL),(18354,902889255012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',3.99,'eastar4uk','david1805','davidawilliams01@virginmedia.com','David Williams','13, West Bank Avenue','Mansfield','Nottinghamshire','UNITED KINGDOM','NG197DJ','07968890432','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 14:45:55',0,NULL,3,1,3,1,'RA184545651CN\r ','OTCN003 '),(18355,902896519012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','compugalny','susancooney@yahoo.com','compugalny','5790 Strickler Rd','Clarence','NY','UNITED STATES','14031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 15:01:57',0,NULL,3,1,1,1,'LK165363545CN\r ','兼容型3D眼镜 通用型 '),(18356,660022740013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','scal3659','calverley@frontier.com','Scott Calverley','6541 scotch pine rd.','Finlayson','MN','UNITED STATES','55735','(320) 233-7410','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 15:03:54',0,NULL,3,1,1,1,'LK164444234CN\r ','罗兰LOWRANCE finder H2OC  GPS 彩色  '),(18357,814936352011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','cochran2320','dcochran2320@sbcglobal.net','Deryl W Cochran','2320 McCutcheon Rd<br>columbus','columbus','OH','UNITED STATES','43219-3244','(614) 476-2049','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 15:50:12',0,NULL,3,1,1,1,'LK164506424CN\r\r ','兼容型3D眼镜 通用型 '),(18358,902936390012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','zolton20','herrning@aol.com','John Herrning','14 Eastbury Road','Northwood','Middlesex','UNITED KINGDOM','HA63AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 16:20:10',0,NULL,8,1,17,0,NULL,'要求修改地址 两个都发到美国 已合并订单'),(18359,601369982003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',2,'RCLO007+POLO001+RCLO008*4',65.8,'cnfaner','klwoods21','klwoods21@gmail.com','Houston Custom Installers','12518 millvan dr','houston','TX','UNITED STATES','77070-4849','(281) 854-9598','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 16:33:54',0,NULL,3,1,1,1,'LK160958891CN\r ',NULL),(18360,902950865012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','kckopycat1','kckopycat@cs.com','KEITH S CHALMERS','15711 Reasoner Drive','BRIGHTON','CO','UNITED STATES','80603','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 16:49:09',0,NULL,3,1,1,1,'LK160066228CN\r ','acer 6pin1.25 23cm '),(18361,902956557012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','chaplinuri','chaplin.u@gmail.com','Uri Chaplianka','HaDvir str. 21/B','Hadera','Israel','ISRAEL','38484','97246201039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 16:56:38',0,NULL,3,1,3,1,'RA184545515CN\r ','GLOT005 '),(18362,660064167013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','bar_san','an55den@gmail.com','Anton Denisov','Omskaya str., 115-12','Omsk','','RUSSIAN FEDERATION','644070','79139650407','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 17:05:14',0,NULL,3,1,3,1,'RA184543341CN\r ','GLOT001*3 \r兼容型3D眼镜 通用型'),(18363,761192158007,170728978842,'New LCD SCREEN FOR Logitech Harmony 880 890 REMOTE CONTROL',1,'SCLO001',18.4,'au-buy','hbcribbs3','brown.cribbs@att.net','H Brown Cribbs III','1901 W Desert Highlands Drive','Oro Valley','AZ','UNITED STATES','85737','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 17:27:06',0,NULL,3,1,1,1,'LK160974007CN\r ','SCLO001 '),(18364,601389608003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','fancyneil2009','chenxikristy@gmail.com','XI CHEN','1002 S Edmonds Ln<br>Apt 214','Lewisville','TX','UNITED STATES','75067-4454','(646) 918-0602','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 17:28:51',0,NULL,3,1,1,1,'\\ ','black '),(18365,814988250011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','jeanlo','jean.boluda@arcelormittal.com','Jean BOLUDA','8 allée des Fauvettes','MONTAGNY EN VEXIN','Picardie','FRANCE','60240','0614042208','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 17:29:58',0,NULL,3,1,3,1,'RA184543355CN\r ','GLOT001*3 '),(18366,902979173012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','chaplinuri','chaplin.u@gmail.com','Uri Chaplianka','HaDvir str. 21/B','Hadera','Israel','ISRAEL','38484','97246201039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 17:33:15',0,NULL,3,1,3,1,'RA184545435CN\r ','GLOT005 \r'),(18367,760487349007,170735485464,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',19.99,'au-buy','surfinminh','annetto12345@wmconnect.com','Michael Do','19461 Mauna Ln','Huntington Beach','CA','UNITED STATES','92646-2909','(714) 378-9714','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 17:52:47',0,NULL,3,1,1,1,'LK160629343CN\r ',NULL),(18368,902994324012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','miller403','gadbois@suscom-maine.net','Sandra Gadbois','2080 Augusta Rd','Bowdoin','ME','UNITED STATES','04287','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 17:57:12',0,NULL,3,1,1,1,'LK164994333CN\r ','兼容型3D眼镜 通用型 '),(18369,815007178011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','902marc16','wheelies16@btinternet.com','MARC MCSHANE','212 CANTERBURY LANE','FALL RIVER','NS','CANADA','B2T 1T3','(902) 574-2154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 18:00:01',0,NULL,3,1,11,1,'BJ01601116\r ','HSJA002 '),(18370,903007162012,220877879838,'New Genuine Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',27.99,'eastar4uk','rceccleston','rob@rceccleston.co.uk','Robert Eccleston','16 Henley Close','Oswestry','Shropshire','UNITED KINGDOM','SY112SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 18:27:01',0,NULL,3,1,3,1,'RA184543275CN\r ','HSPL013\r英标 \r申报为gift 申报20美金'),(18371,760956880007,170735485634,'New Blade Runner Saber LED Flash Light Umbrella Safety  5 colors availabe',1,'UM00031',25.99,'au-buy','asht_96','xaniableu@yahoo.com','Ashlynne Tessier','708 Maple Grove Ct','Hope Mills','NC','UNITED STATES','28348-9382','(910) 224-5593','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 19:26:58',0,NULL,3,1,1,1,'LK160707672CN\r ',NULL),(18372,606818295004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','bone6464','bags_98@msn.com','Brett Lind','PO Box 1472','Pine','AZ','UNITED STATES','85544','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 19:41:48',0,NULL,3,1,1,1,'\\ ',NULL),(18373,601451199003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','lpiczura','lukaszsp@o2.pl','Lukasz Piczura','9514 Lawrence Ave<br>Apt 2407','Schiller Park','IL','UNITED STATES','60176-1185','(773) 366-0632','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-17 20:03:19',0,NULL,3,1,1,1,'LK165089438CN\r ',''),(18374,814409600002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','fatguyinalittledress','big_vaughn420@yahoo.com','barbara vaughn','2 Well Tank Rd','Santa Fe','NM','UNITED STATES','87508-2138','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 21:15:12',0,NULL,3,1,1,1,'LK162629071CN\r ',NULL),(18375,903121091012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT006',26.99,'eastar4uk','eppoes','eppoes@aol.com','Gary Epstein','53 Woodland Drive','Hove','East Sussex','UNITED KINGDOM','BN3 6DH','01273708715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 21:16:58',0,NULL,3,1,3,1,'RA184545387CN\r ','GLOT006 '),(18376,761322148007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','2855cedric','cedric.perard@gmail.com','SARL PERARD','Cédric PERARD<br>ZI de Baleycourt','VERDUN','Lorraine','FRANCE','55100','0329737373','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 21:27:34',0,NULL,3,1,11,1,'BJ01601103\r ','RCLO007+POLO001+RCLO008*4\r欧标 '),(18377,660184141013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','moshe1111','halavi@013.net','Moshe Halavi','Hefer 5  P.O.B 280','Shoham','','ISRAEL','60850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 21:51:31',0,NULL,3,1,3,1,'RA184545532CN\r ','HBPH002 '),(18378,660194815013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','lglesquire','lglesquire@aol.com','LEWIS LORENZ','11706 Pintail Ct','NAPLES','FL','UNITED STATES','34119-8899','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 22:23:39',0,NULL,3,1,1,1,'LK156217085CN\r ','要圣诞节之前到 '),(18379,815155397011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','jonyellis','jony@hotmail.co.uk','Jonathan Ellis','3 Thurstaston Road','Irby','Merseyside','UNITED KINGDOM','CH610HA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 22:29:19',0,NULL,3,1,11,1,'BJ01601113\r ','WLAP002 '),(18380,753517409008,180699060534,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT006',44.99,'au-buy','dazza069','darryllong069@hotmail.com','DARRYL LONG','unit 2 111 KEW  ST<br>WELSHPOOL','PERTH','Western Australia','AUSTRALIA','6106','0893618316','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 22:29:31',0,NULL,3,1,3,1,'RA184545325CN\r ','GLOT006 \r'),(18381,606891436004,140583346877,'Plantronics Alteclansing Backbeat 903 Bluetooth Headset',1,'HSPL015',52.9,'cnfaner','igorek47','miv45@mail.ru','igor miranskiy','bar ilan 6/13<br>bat yam','bat yam','','ISRAEL','59581','+972542013007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 23:19:57',0,NULL,3,1,3,1,'RA184545886CN ','HSPL015 '),(18382,660217810013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','p.gillen','pgillen@telus.net','Pamela Palmer','32616 Kendale Place','Abbotsford','BC','CANADA','V2T 3X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 23:42:50',0,NULL,3,1,3,1,'RA184543602CN\r ','GLOT001*3 \r兼容型3D眼镜 通用型'),(18383,815186404011,320774352320,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT003',10.99,'eastar4uk','matsastrom','mats.ew.astrom@gmail.com','Mats Astrom','Hallstagatan 12','Solleftea','','SWEDEN','88130','0705850120','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 23:50:49',0,NULL,3,1,11,1,'BJ01601100\r ','WLAT003 '),(18384,903204455012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','deborah209','deborah.robertson@ymail.com','Deborah Robertson','1400 Yosemite Blvd','Modesto','CA','UNITED STATES','95354-2840','(209) 544-1067','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-18 00:28:06',0,NULL,3,1,1,1,'LK164626271CN\r ',NULL),(18385,814496297002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','cdunie','dunie@sbcglobal.net','charles dunie','1472 windsong pl','morgan hill','CA','UNITED STATES','95037-9062','(408) 776-0584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 01:06:19',0,NULL,3,1,1,1,'LK160802214CN\r ',NULL),(18386,660259766013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','sicotte56','lsicotte@avalancheskiwear.com','Louise Sicotte','77 Des Hirondelles','St-Ferreol Les Neiges','QC','CANADA','G0A 3R0','(418) 826-0265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 02:52:50',0,NULL,3,1,6,1,'EE495359565CN ','兼容型3D眼镜 通用型 '),(18387,815254404011,320787340708,'New Jabra JX10 Series II 2  Bluetooth headset black',1,'HSJA004',19.98,'eastar4','ibro2324','salako5050@yahoo.com','Ibrahim Salako','8515 Hearth Drive<br>Apt 21','Houston','TX','UNITED STATES','77054','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 03:56:58',0,NULL,3,1,1,1,'LK163480408CN\r ','黑色的 '),(18388,903269231012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','hatchingideas','dnapremium@bigpond.com','Dave Howard','4 tribulation close','narangba','Queensland','AUSTRALIA','4504','0418385305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 04:05:45',0,NULL,3,1,3,1,'RA184545400CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18389,606948236004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','stephen6038','lucillemarie318@yahoo.com','Stephen Wallace','6041 Winsome Lane<br>Apt# 248','Houston','TX','UNITED STATES','77057','(713) 569-4853','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-18 04:13:17',0,NULL,3,1,1,1,'LK164173899CN\r ',NULL),(18390,903299162012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','renatovysk11','renatovysk@hotmail.com','Renato Nascimento','Estrada marechal Mallet, 509, Magalhães Bastos','Rio de Janeiro','Rio de Janeiro','BRAZIL','5521745091','((21)3555-1995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 06:22:35',0,NULL,3,1,3,1,'RA184545427CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18391,815284482011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','pinheadkopf','pinhead@unitybox.de','Thomas Braun','Wörthstraße26','Duisburg','','GERMANY','47053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 06:26:59',0,NULL,3,1,11,1,'BJ01601099\r ','WLIN015 \r无线蓝牙二合一'),(18392,660261717013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','dayminner','danielle.patterson@gmail.com','Danielle Patterson or Geoffrey Conder','217 - 5550 Cambie Street','Vancouver','BC','CANADA','V5Z 3A2','(604) 653-8410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 07:16:38',0,NULL,3,1,11,1,'BJ01601121\r ','UM00041 \r接边斑马纹透明伞   '),(18393,601601362003,130608487119,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',50.99,'cnfaner','leroyjethrogibbs2010','geiasou78@windowslive.com','dimitrios katifoudis','karavaggeli 54<br>stavroupoli','Thessaloniki','','GREECE','56431','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 07:28:19',0,NULL,3,1,3,1,'RA184545489CN\r ','SAFI001 '),(18394,606976870004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',29.9,'cnfaner','andreyingineer','aprepelitsa@yandex.ru','Andrey Prepelitsa','16 Sirina Str','Hanty-Mansiysk','Tumen obl Hanty-Mansiysky AO','RUSSIAN FEDERATION','628012','890-282-838-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 07:48:57',0,NULL,3,1,3,1,'RA184545603CN\r ','MOAS001 '),(18395,761488279007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','luke_croker2009','luke_croker@health.qld.gov.au','Luke Croker','58 leonard Street<br>Kewarra Beach','Cairns','Queensland','AUSTRALIA','4879','0429405056','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-18 07:54:28',0,NULL,3,1,11,1,'\\ ','UM00042 '),(18396,660309913013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','0421goo','21goo@live.com.au','miguel','372 musgrave road<br>Coopers Plains','Brisbane','Queensland','AUSTRALIA','4108','0421914756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 08:11:44',0,NULL,3,1,6,1,'EE495359582CN ','GLOT001*4 \r兼容型3D眼镜 通用型'),(18397,601607052003,130553090501,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',96.08,'cnfaner','xdenvers','denvers.denvers@gmail.com','Serbes enver','36, rue Delbeque','Morlanwelz','','BELGIUM','7140','0494107777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 08:11:24',0,NULL,3,1,3,1,'RA184545855CN\r ','WWSI004 \rNIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power 1个\r10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white 1个\r\r\r'),(18398,761497674007,170737835682,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',1,'LGGL003',19.99,'au-buy','yeenar','yeenar69@hotmail.com','Jody Chester','18 Jean Street ','Wellington ','New South Wales','AUSTRALIA','2820','0268452458','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-18 08:37:09',0,NULL,3,1,11,1,'BJ01601118\r ','LGGL003 '),(18399,606990797004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','porschebeast','swiftporsche@yahoo.com','Lionel Tan','PO Box 223','ROYAL BRISBANE HOSPITAL','Queensland','AUSTRALIA','4029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 09:05:18',0,NULL,3,1,3,1,'RA184545585CN\r ','CACN004 '),(18400,601619156003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',2,'MOLO006',49.98,'cnfaner','gapwin','sherfin@ntlworld.com','martin rimington','47 sherfield ave','rickmansworth','Hertfordshire','UNITED KINGDOM','wd3 1nn','01923773268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 09:09:45',0,NULL,3,1,3,1,'RA184545594CN\r ','MOLO006 '),(18401,903347331012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','guelmi92','miglngl@hotmail.com','Miguel Angel Rodriguez Cantisano','Calle Alberola Nº 32 1er Piso B','Alicante','Alicante','SPAIN','03007','965111834','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 09:31:13',0,NULL,3,1,3,1,'RA184545311CN\r ','GLOT005 '),(18402,815332812011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','mataespesa1982','amart1@mapfre.com','Antonio Martinez de la Riva','Calle General Oraá 64,5º C','Madrid','Madrid','SPAIN','28006','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 09:51:55',0,NULL,3,1,3,1,'RA184545342CN\r ','LGGL002 '),(18403,815346873011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ixia-2008','jclaude.girard@gmail.com','Jean-Claude GIRARD','res le vieux pont avenue du mont aigoual<br>log 20 bat B','ganges','Languedoc-Roussillon','FRANCE','34190','0661894736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 10:17:20',0,NULL,3,1,3,1,'RA184545696CN\r ','MOAP001 '),(18404,8881324203776591,111,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',50,'ANTY002',150,'eastar4','saiajin77','saiajin3@gmail.com','soonkwun kim','407dong 304ho, Shindong-a Apt. Sadang 2-dong','seoul','Dongjak-gu, Seoul','KOREA,REPUBLIC OF','156-771','(82) 010-2725-8320',NULL,NULL,NULL,'2011-12-18 10:22:56',0,NULL,3,1,6,1,'EE495359579CN ','白线50条  黑线100条 \rANTY001\r客户上次买的是三对的  但这次是两对的  是不是错了呢\r和以前单子比，应该没错'),(18405,903382590012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','ardg46','ardg@live.co.uk','Adam Smith','27 Park Road<br>Eastham','Wirral','Merseyside','UNITED KINGDOM','CH62 8AH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 10:51:00',0,NULL,3,1,11,1,'BJ01601112\r ','WLAP004 '),(18406,903401549012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','martial.9489','didji50@hotmail.com','LAROSE MARTIAL','2<br>IMP JEAN FAYARD','VERNOUILLET','Centre','FRANCE','28500','0237469489','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 11:30:40',0,NULL,3,1,3,1,'RA184545617CN\r ','LGAD001 '),(18407,815386020011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',133.98,'eastar4uk','camaromorty','morten.grorud@cramo.com','morty grorud','Norneveien 4','Sandvika','Rykkinn','NORWAY','1349','97591024','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 11:51:06',0,NULL,3,1,4,1,'YW867738816CN ','两个'),(18408,815397722011,320787340708,'New Jabra JX10 Series II 2  Bluetooth headset black',1,'HSJA004',19.98,'eastar4','black.dragon.31','black.dragon.213@hotmail.com','David Chu','126/Unit 2 Rintoul Street Newtown','Wellington','North Island','NEW ZEALAND','6021','022 098 7363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 12:12:00',0,NULL,3,1,11,1,'BJ01601085\r\r ','HSJA004 \r黑色的'),(18409,660379012013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','darkside2380','darkside414@live.com','Alex Thomas','6703 NW 7th St<br>SVD -6081','Miami','FL','UNITED STATES','33126-6007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 12:16:34',0,NULL,3,1,1,1,' \\ ','黑色的 '),(18410,601679199003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','bccsergio','bcc_sergio@yahoo.com.br','Sergio Avila','Rua Caetés, 149. Ap. 1001','Canoas','RS','BRAZIL','92.010-150',' 555130327070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 12:38:09',0,NULL,3,1,3,1,'RA184543063CN\r ','LGRM001 '),(18411,815442392011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','nikeclorber','ervin.lorber@triera.net','Lorber erwin','svetelova 6','Maribor','','SLOVENIA','2000','0038641741562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:42:06',0,NULL,3,1,11,1,'BJ01601081\r ','BTAC2122 +BTAC2113\racer 8pin1.00 8cm\r再发一个2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable\racer 5pin1.25 6cm\r'),(18412,660415450013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.39,'eastar4','nikeclorber','ervin.lorber@triera.net','Lorber erwin','svetelova 6','Maribor','','SLOVENIA','2000','0038641741562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:53:30',0,NULL,3,1,17,0,NULL,NULL),(18413,601709691003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','roman.hacina2009','roman.hacina@mail.ru','Roman Hacina','Cuza-Voda str. 45 ap.3','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2072','+37379509609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:59:19',0,NULL,3,1,3,1,'RA184545753CN\r ','MOOE003\rOEM '),(18414,903478440012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','pualexey2011','alexey-pushkin@yandex.ru','Alexey Pushkin','Bibirevskaya street, 1-41','Moscow','Moscow','RUSSIAN FEDERATION','127549',' 79037904252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:59:34',0,NULL,3,1,11,1,'BJ01601082\r ','OTCR001 '),(18415,903514975012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','miska01','philip.potticary@googlemail.com','Philip Potticary','1 Crawley Avenue','Wellingborough','Northamptonshire','UNITED KINGDOM','NN85YH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 14:54:48',0,NULL,3,1,3,1,'RA184545268CN\r ','RCMA001 '),(18416,602862299004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','hidesser','kazseri@yahoo.fr','Hidekazu Serizawa','12-15-305 Nishisumiyoshi','Tokorozawa','Saitama','JAPAN','3591126','09022088871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 15:38:29',0,NULL,3,1,3,1,'RA184545679CN\r ','HBPH003 '),(18417,607126531004,140635369210,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',68.99,'cnfaner','petr_spb','petr80@inbox.ru','Petr Afanasjev','4-3-60 Iskrovsky ave.','St.Petersburg','','RUSSIAN FEDERATION','193318','+79217416030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 15:46:10',0,NULL,3,1,3,1,'RA184543721CN\r ','OTSO004 '),(18418,815377859011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',57.99,'eastar4','sovenok1981','sovenok13@bk.ru','Sergey Morgunov','Moskovskaya Oblast, Elektrostal<br>General Delivery, До Востребования','Elektrostal','','RUSSIAN FEDERATION','144000','8(926)2553205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 15:53:51',0,NULL,3,1,3,1,'RA184543752CN\r ','GLSG001 '),(18419,903566045012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','sancho_198686','sancho_4664@mail.ru','sanjar niyazov','14 Ampere House<br>Warple Way','Acton','London','UNITED KINGDOM','W3 7NY','07912138911','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 16:12:47',0,NULL,3,1,3,1,'RA184543681CN\r ','OTSO004*2 '),(18420,815539210011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','sylsim1','sylsim1@videotron.ca','Sylvain Simard','30 Place Mark-Bourque','Richelieu','QC','CANADA','J3L 0C2','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 16:24:44',0,NULL,3,1,6,1,'EE636829467CN ','GLOT001*4 \r'),(18421,815561145011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','stanfordwood22','katherine@kmi.uk.com','Katherine Meadows','Meadow Cottage<br>Stanford Dingley','Reading','Berkshire','UNITED KINGDOM','RG76LT','01189744108','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 16:49:50',0,NULL,3,1,3,1,'RA184545965CN ','RCLO009 '),(18422,903599410012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','darren1503','darrenandjo1@ntlworld.com','darren may','49 Cypress Avenue','worthing','West Sussex','UNITED KINGDOM','BN133PS','01903503370','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 16:52:54',0,NULL,3,1,3,1,'RA184543148CN\r ','LGRM001 '),(18423,761763227007,170728920954,'New Earloop wire Stereo sound replacement Plantronics Voyager 815/855 bluetooch',1,'HSPL018',14.99,'au-buy','alex6450','ayuknovsky@lenoxhill.net','Aleksandr Yukhnovskiy','224 Community Cir','Old Bridge','NJ','UNITED STATES','08857-1954','(732) 607-1176','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-18 17:23:19',0,NULL,3,1,1,1,'LK163631920CN\r ',NULL),(18424,903625356012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4uk','lali_from_austriaa','lali_from_austria@hotmail.com','Larisa Valea','Fichtenstraße 13','Knittelfeld','','AUSTRIA','8720','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 17:23:23',0,NULL,3,1,11,1,'\\ ','UM00031\r客户要黑色的 \r可以等到有黑色的再发货\r'),(18425,660304749013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','johnblahuta88','navystrng218@yahoo.com','PO3 Blahuta','2830 Falvy Ave','San Diego','CA','UNITED STATES','92111','(208) 250-9206','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 17:47:06',0,NULL,3,1,1,1,'LK164159129CN\r ',NULL),(18426,771477441001,110703668539,'Narnia The Voyage of the Dawn Treader 3D Blu-Ray NEW',1,'BR3D007',22.99,'buysia','topcat41','tconno1@bellsouth.net','Terry Connolly','2000 Rover Zetella Rd','Williamson','GA','UNITED STATES','30292-3700','(404) 376-5170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 17:50:30',0,NULL,3,1,1,1,'LK165152759CN\r ',NULL),(18427,607203263004,140651231605,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'HSPL013',47.99,'cnfaner','bayer123finnerik','finn-rust@hotmail.com','Finn Erik Rusten','Moen','default','Gjesåsen','NORWAY','2280','004791850558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 18:04:22',0,NULL,3,1,3,1,'RA184544165CN\r ','HSPL013\r欧标 '),(18428,601828546003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','romi1143','tuviaroth1@walla.com','Roth Tuvia','Nof Haemek 30/2','Migdal Haemek','','ISRAEL','23501','9720544718084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 18:05:55',0,NULL,5,1,18,1,NULL,'HSMO005 '),(18429,815647322011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','nepopchuk82','nepopchuk@mail.ru','Vladislav Nepopchuk','Chertanovskaya str 9, 3, 38','Moscow','','RUSSIAN FEDERATION','117208','7-926-576-05-96','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 18:25:33',0,NULL,3,1,11,1,'RA184545988CN\r ','MOLA001 '),(18430,660561121013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','x_ssdking_x','antonio.chaves@live.ca','Antonio Chaves','36 Sequoia Rd.','Woodbridge','ON','CANADA','L4H1W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 18:28:33',0,NULL,3,1,3,1,'RA184545285CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18431,815664234011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',3,'GLSG001',113.97,'eastar4uk','williamplantukwilliam','williamplantuk@yahoo.co.uk','William Plant','1 Barnard Court<br>Woodstone Village','Houghton le Spring','Tyne and Wear','UNITED KINGDOM','DH4 6TS','07714229938','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 18:38:12',0,NULL,3,1,3,1,'RA184543324CN\r ','GLSG001 '),(18432,660238364013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',4,'WLAT010+ANTY001',43.96,'eastar4','zig159','t5847007@yandex.ru','Mikhail Kornukhov','Prospect House 8 Solidarity Building 3 Apartment 123','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','193312','+79818968001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 18:42:10',0,NULL,3,1,3,1,'RA184542346CN\r ','WLAT010+ANTY001 '),(18433,902805181012,220816376663,'4 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',143.99,'eastar4uk','cecilwarrior','cecilwarrior@hotmail.co.uk','Cecil Jackson','117a Green Street','Enfield','Middlesex','UNITED KINGDOM','en3 7jf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 18:42:31',0,NULL,3,1,6,1,'EE495359596CN ',NULL),(18434,903735381012,220743499541,'New Plantronics Voyager 851/855 Bluetooth Headset',1,'HSPL009',38,'eastar4uk','sitelem2','sitelem2@yahoo.gr','meletis meletiadis','Neos mylotopos','default','Gianitsa','GREECE','58100','6973891135','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 19:01:04',0,NULL,3,1,3,1,'RA184543196CN\r ',' sitelem2\r欧标'),(18435,815710636011,320642404885,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','g33r7','mail@geertterharmsel.net','Geert ter Harmsel','Lindenlaan 27','rijssen','','NETHERLANDS','7461XL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 19:15:59',0,NULL,3,1,11,1,'BJ01601083\r ','WLAP002 \r 二代卡 旧'),(18436,660313883013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','jannat1984','jannat84@hotmail.com','Aisha Sheikh','6400 N Ridge Blvd<br>APT 406','Chicago','IL','UNITED STATES','60626-4817','(773) 885-2872','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 19:56:16',0,NULL,3,1,1,1,' \\ ',NULL),(18437,601916255003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','adi.adi.adi','mail@genwerk.de','Adrian Schomburg','Einsteinstrasse 26','Martinsried','','GERMANY','82152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 19:59:22',0,NULL,3,1,3,1,'RA184543236CN\r ','WLAT003 '),(18438,815756650011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','jwf1620','john_fisher_engr@btinternet.com','HEYFORDIAN COACHS. John Fisher.','380, WEST WYCOMBE ROAD,','HIGH WYCOMBE','Buckinghamshire','UNITED KINGDOM','HP12 4AH','07785302649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 20:02:12',0,NULL,3,1,3,1,'RA184543735CN\r ','OTSO004 '),(18439,815767169011,320801187144,'New Genuine Motorola H715 Bluetooth Wireless Headset   H 715+AC adaptor',2,'HSMO023',27.98,'eastar4uk','miau3003','vera.seitz@t-online.de','Vera Seitz','Speyerer Straße 47','Altrip','','GERMANY','67122','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 20:11:43',0,NULL,3,1,3,1,'RA184543179CN\r ','HSMO023\r欧标 '),(18440,607315242004,140635369210,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',3,'OTSO004',206.97,'cnfaner','britt-63','britt-dar@hotmail.com','Britt Darlington','Seterveien 19','Bergen','Rådal','NORWAY','5236','+4799247109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 20:31:07',0,NULL,3,1,3,1,'RA184545784CN\r ','OTSO004 '),(18441,903864049012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','marios346','mariosana10@hotmail.com','marios anastasiou','mixalaki karaoli 12','mathiatis','','CYPRUS','2568','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 20:58:11',0,NULL,3,1,11,1,'RA184545682CN\r ','HSSA002 \rblack version'),(18442,903877543012,220807244626,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AB',1,'GLOT006*2',88.99,'eastar4','roland2962','rached.roland@gmail.com','Rached Roland','19 rue Roger Verwaerde','Estaires','Nord-Pas-de-Calais','FRANCE','59940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 21:14:02',0,NULL,3,1,3,1,'RA184543015CN\r ','GLOT006*2 \r兼容型3D眼镜  Korea TV专用'),(18443,660687670013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','olegusmdh','olegmdh@gmail.com','Oleg Shlyakhtin','Kolpino,<br>Zavodskoy pr. 40-198','Saint - Petersburg','','RUSSIAN FEDERATION','196657','+79119380308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 21:22:42',0,NULL,3,1,3,1,'RA184543267CN\r ','GLOT001*3 \r兼容型3D眼镜 通用型'),(18444,903883105012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','dad1051','bevans1051@copper.net','bill evans','1051 County Road 201','liberty hill','TX','UNITED STATES','78642','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 21:24:56',0,NULL,3,1,1,1,'LK164561142CN\r ','acer 6pin1.25 23cm  '),(18445,660691274013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','w0lf485','wolf485@gmail.com','Dmitriy Lobkov','3, Birzhan-Sal str., kv 12','Astana','Akmolinskaya oblast','KAZAKHSTAN','010000','+77015443335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 21:30:46',0,NULL,3,1,11,1,'BJ01601106\r ','WLIN014 '),(18446,815842160011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','quickwhip','harryh@pobox.com','Harry Holzhauser','4842 Williamstown BLVD','Lakeland','FL','UNITED STATES','33810-3703','(972) 423-7184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 21:45:57',0,NULL,3,1,1,1,'LK164368524CN\r ','无线蓝牙二合一 '),(18447,815847844011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','avi_sito','avisander@hotmail.com','Avi Sander','Alexander Yanai 50 apt. 6','Haifa','','ISRAEL','34816','972-52-5908342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 21:59:25',0,NULL,3,1,11,1,'\\\r ',NULL),(18448,660707510013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','tagronning','thoreallan@gmail.com','Thore Allan Gronning','Bautavegen 3B<br>7033','Ranheim','-','NORWAY','7033','004795254036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 22:03:39',0,NULL,3,1,3,1,'RA184543103CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18449,601989446003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','zoran9763','zoran92@gmail.com','ZORAN KRSTIC','1476 Launay Ave.','Orleans - Ottawa','ON','CANADA','K4A 3R9','(613) 513-6366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 22:20:05',0,NULL,3,1,3,1,'RA184543032CN\r ','LGAD001 '),(18450,903930491012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.96,'eastar4','quangtram','acon1966@yahoo.com','Quang Nguyen','3120 Lawrenceville Hwy','Tucker','GA','UNITED STATES','30084','(404) 457-9930','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 22:32:48',0,NULL,3,1,1,1,'LK164150147CN\r ',NULL),(18451,607373678004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','mrazkov','tomas.mrazek@gmail.com','Tomáš Mrázek','Dr. Jana Malíka 841','Chrudim','','CZECH REPUBLIC','53701','00420775012555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 22:37:20',0,NULL,3,1,3,1,'RA184543046CN\r ','RELO003 '),(18452,903926352012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','edgebid','sony_dg@hotmail.com','Dave Gacek','2070 Camilla Apt 114','Mississauga','ON','CANADA','L5A2J7','(905) 756-4174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 22:39:29',0,NULL,3,1,11,1,'BJ01601094\r ','MOAP001 '),(18453,903933860012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','idaraosung','hetti2523@gmail.com','Idara Osung','4 Dyers Mews<br>Neath Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','Mk14 6ER','01908677674','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(18454,602002736003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','sprowsl','ssprout@yahoo.com','Steve Sprow','9430 Dover Dr','Wauseon','OH','UNITED STATES','43567-9216','(419) 335-9830','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-18 23:02:19',0,NULL,3,1,1,1,'LK162902590CN\r ',NULL),(18455,903712800012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',3,'GLOT006',80.97,'eastar4uk','flartley','steve_spleen@sky.com','stephen barker','4 codale avenue, bispham','blackpool','Lancashire','UNITED KINGDOM','FY20BA','01253311072','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 23:12:18',0,NULL,3,1,3,1,'RA184545740CN\r ','GLOT006 '),(18456,903946162012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',8,'GLOT001',359.12,'eastar4','randjkelley','jenni.kelley@ymail.com','Rob Kelley','24574 SW Ladd Hill Rd','Sherwood','OR','UNITED STATES','97140-5011','(503) 939-7140','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 23:16:40',0,NULL,3,1,7,1,'EE636829475CN ','兼容型3D眼镜 通用型 '),(18457,903955919012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',2,'HSMO019',21.9,'eastar4uk','idaraosung','hetti2523@gmail.com','Idara Osung','4 Dyers Mews<br>Neath Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','Mk14 6ER','01908677674','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','echeck '),(18458,815894881011,320812368138,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',7.99,'eastar4uk','budakovtattoo','alexbudakov@gmail.com','Alex Budakov','Uziel 22/4','Ramat Gan','','ISRAEL','52382','0525775051','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 23:35:20',0,NULL,3,1,11,1,'BJ01601119\r ','OT00002 '),(18459,814878570011,320753523732,'NIB Genuine Samsung SSG-2100AB 3D glasses + Blu-ruy ICE AGE 3 disc',3,'GLSG001*2+BR3D006',362.97,'eastar4','adib6adib','aedib@uol.com.br','ADIB EL DIB','RUA DOS ANDRADAS 322','SAO PAULO','SAO PAULO - SAO PAULO - SANTA EFIGENIA','BRAZIL','01208-000','(11)32248196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 23:42:06',0,NULL,3,1,6,1,'EE636829498CN ',NULL),(18460,602017467003,130613527106,'New 44 Pin Female to Female Mini IDE Cable for PC 30 cm',1,'OTCN002',3.9,'cnfaner','zzsoftlin','zz9999.fr@gmail.com','zhen zhang','91, Bvd de la libération<br>3ème, porte à droite','vincennes','Île-de-France','FRANCE','94300','01.43.65.55.60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 23:57:30',0,NULL,3,1,3,1,'RA184543182CN\r ','OTCN002 '),(18461,602020003003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','weaverboy34','mawcat2004@comcast.net','Matt Weaver','3 Westover Club Drive','Norristown','PA','UNITED STATES','19403','(717) 269-3519','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-19 00:07:23',0,NULL,3,1,1,1,'LK164469939CN\r ',NULL),(18462,903973673012,220872406392,'4 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT006*4',175.99,'eastar4','qualo0','clintcoelho@gmail.com','Clint Coelho','Cherry Oak Lodge<br>2 Highfield Road','West Purley','Surrey','UNITED KINGDOM','CR8 2JG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 00:09:41',0,NULL,3,1,6,1,'EE636829507CN ','兼容型3D眼镜  Korea TV专用 '),(18463,815936045011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','potato_chips','pchips@sbcglobal.net','Sandy Agbayani','736 Dona Ave','Sunnyvale','CA','UNITED STATES','94087-1607','(408) 737-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 01:27:19',0,NULL,3,1,1,1,'LK159191563CN\r ',NULL),(18464,607429841004,140630815652,'New iTech Clip II mini Multipoint Bluetooth Headset Black',1,'HSIT002',38.9,'cnfaner','christin1120','yahui616@yahoo.com','christin hui','2836 Maria Isabel Ave','ocoee','fl','UNITED STATES','34761-4625','(407) 721-3233','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-19 02:16:00',0,NULL,3,1,1,1,'LK165086811CN\r ','黑色的 '),(18465,8881324262738801,111,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOSA002',49.99,'aliexpress','1005834148','ae@xcel.no','Abizar Ebrahimji	','Stromsaethersvei 66B','Yven	','Ostfold','NORWAY','1715','+00 47 90601606',NULL,NULL,NULL,'2011-12-19 02:45:38',0,NULL,3,1,3,1,'RA184544174CN\r ','发OEM 的，申报$29.9'),(18466,8881324262954738,111,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',26.99,'aliexpress','1005840138','cciskoski@hotmail.com','carlos','rua madressilva, 455','londrina','parana','BRAZIL','86042270','+55 043 84111244',NULL,NULL,NULL,'2011-12-19 02:49:14',0,NULL,3,1,3,1,'RA184543240CN\r ','GPS0010 '),(18467,904039540012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','elzacateca','erickbaez_11@hotmail.com','Erick Baez','2861  DEWEY AVENUE APT 2','Bronx','NY','UNITED STATES','10465','(347) 293-6364','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 02:51:53',0,NULL,3,1,1,1,'LK164719375CN\r ','acer 8pin1.00 8cm  '),(18468,8881324263117258,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'aliexpress','1005863538','asoroko@torob.ru','Anton S.	','Leningradskiy prosp. 35-44','Moscow','Russia','RUSSIAN FEDERATION	','125284','+7 925 5074166',NULL,NULL,NULL,'2011-12-19 02:51:57',0,NULL,3,1,3,1,'RA158310278CN','WLIN014 '),(18469,607441879004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',33.67,'cnfaner','vitaliybik','vitalybik@gmail.com','Biktimirov Vitaliy','Mate Zalki 31, PlatCity office','Krasnoyarsk','','RUSSIAN FEDERATION','660127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 02:58:54',0,NULL,3,1,3,1,'RA184545798CN','WWSI002\r3G WWan antenna MC8775 MC8781 MC8780 MC8790  F3507G GTM380 GTM382 M250 DELL5530 1个\r'),(18470,602072001003,130617205109,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',176.99,'cnfaner','dmitry_mittov','mittov@gmail.com','Dmitry Mittov','Pushkina 117 - 52','Omsk','Omskaya oblast\'','RUSSIAN FEDERATION','644046','+79136116987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 03:34:39',0,NULL,3,1,3,1,'RA184545767CN\r ','GLSG009*2 '),(18471,754293010008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','proverbs22-1','torey.lam@live.com','Torey Lam','16289 Barlow Dr','Oregon City','OR','UNITED STATES','97045','(503) 387-5426','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-19 03:56:56',0,NULL,3,1,1,1,'LK164545754CN\r ',NULL),(18472,815989263011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',2,'OTSO004',139.98,'eastar4','telsecintellect','hilton@telsec.com.br','Hilton Pereira','Rua Visconde de Piraja, 487 - apt 1401<br>Ipanema','Rio de Janeiro','Rio de Janeiro','BRAZIL','22410003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 04:00:07',0,NULL,3,1,6,1,'EE636829436CN ','OTSO004 \r客户打了30美金\r给退回来了  等客户问起时再说吧3.2\r\r  '),(18473,754294828008,180761130667,'New Sharp AN-3DG20-B 3D USB Rechargeable Glasses+2nose pad USB cable case cloth',1,'SPGL001',119,'au-buy','jonathon.broughton','jonathon.broughton@hotmail.com','Jonathon Broughton','6/205 Station Street','Fairfield','Victoria','AUSTRALIA','3078','0403411545','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 04:02:57',0,NULL,3,1,3,1,'RA184545719CN\r ','SPGL001 '),(18474,816009254011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','doktor_disko','c.goers@gmx.de','Christoph Görs','Herbststraße 4','Schierling','','GERMANY','84069','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 05:26:34',0,NULL,3,1,3,1,'RA184545722CN\r ','OTSO004 '),(18475,660828781013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','dmarin1990','dmarin1009@yahoo.com','Donna Marin','PO Box 527','AMAGANSETT','NY','UNITED STATES','11930-0527','(631) 456-8428','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 05:34:32',0,NULL,3,1,1,1,'\\ ',NULL),(18476,816014603011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','ollie_kidd','ollie@imagestore.com.au','Oliver Kidd','1 Alpha Court, Moe','Moe','Victoria','AUSTRALIA','3825','04379900266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 05:57:10',0,NULL,3,1,11,1,'BJ01601097\r ','HSUE002 '),(18477,8881324275668249,111,'toothbrush HX6021',1,'',0,'eastar4','laihjkim','laihjkim@netscape.net','Kelin Lai','No 3~2, Lane 91, Ying-Tao Rd,','Ying Ko District,','New Taipei City,','TAIWAN','239','',NULL,NULL,NULL,'2011-12-19 06:21:08',0,NULL,3,0,14,1,'301208196965','送给客户  撤CASE 用的 \r中文地址\r賴怡如\r台北縣新北市鶯歌區鶯桃路91巷3~2號, 239 , 台灣\r02-26701695\r\r'),(18478,816026491011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.88,'eastar4','rabbitca','chyuca@yahoo.com','Cheng-han Yu','#10-01, T-Lab<br>5A Engineering Drive 1','default','','SINGAPORE','117411','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 07:07:29',0,NULL,3,1,11,1,'BJ01601101\r ','BTAC2010 \racer 5pin 1.25 3cm '),(18479,771861033001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','johnnyjiang88','johnnykarenjiang@yahoo.com','Johnny Jiang','190 Roswell Dr','Milpitas','CA','UNITED STATES','95035-5854','(408) 956-8834','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 07:13:15',0,NULL,3,1,1,1,'LK162795895CN\r ',NULL),(18480,600709960004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','kaywontv','shans123@naver.com','Hansu Shim','Multimedia Design, Kaywon School of Art and Design<br>66 Kaywonhaehangno','Uiwang-si','Gyeonggi-do','KOREA,REPUBLIC OF','437-712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 08:17:42',0,NULL,3,1,3,1,'RA184545807CN\r ','OTSO002 '),(18481,602132566003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','dbar4773','davidbarclay1955@gmail.com','David Barclay','1134 Briarwood Blvd','Naples','FL','UNITED STATES','34104-0832','(239) 643-5143','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-19 10:09:43',0,NULL,3,1,1,1,' \\ ','OEM '),(18482,754373080008,180764313016,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',60.99,'au-buy','di-johnson','di2di2000@yahoo.com','Diane Johnson','37 Wallace Drive<br>Greenvale','Melbourne','Victoria','AUSTRALIA','3059','0383330097','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:39:26',0,NULL,3,1,3,1,'RA184545815CN\r ','HBPH002 '),(18483,816104548011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT006*2',88.99,'eastar4','bobka_from_aktobe','vladimir.b@hermes.uk.com','Vladimir Baranov','Mares\'eva 95A-20','Aktobe','','KAZAKHSTAN','030019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 12:29:38',0,NULL,3,1,3,1,'RA184543576CN\r ','GLOT006*2 \r兼容型3D眼镜  Korea TV专用'),(18484,602161047003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','remcould','r.lodeweges@planet.nl','Remco Lodeweges','HendrikBoersenlaan 9','Hooglanderveen','','NETHERLANDS','3829cc','(06) 29420988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 12:43:22',0,NULL,3,1,3,1,'RA184543528CN ','MOOE003\rOEM '),(18485,816112168011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','jonasbr','jonasbry@gmail.com','Jonas Thor Brynjarsson','Storagerdi 3','Reykjavik','','ICELAND','108','(354) 865-1822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 12:53:58',0,NULL,3,1,3,1,'RA184542054CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18486,660905465013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','kmv2000','mkozhedub@gmail.com','Mikhail Kozhedub','Levitana str. 38/3-193','Ufa','','RUSSIAN FEDERATION','450095','+79177615057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 13:16:10',0,NULL,3,1,11,1,'/ ','WLAP008 '),(18487,816118716011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','dannykooy','danny_kooy@hotmail.com','P.v.d.Berg','Griendwerker 13','Oud-Beijerland','','NETHERLANDS','3263 CA','0031653267060','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 13:16:47',0,NULL,3,1,3,1,'RA184543562CN\r ','GLOT001 '),(18488,904205450012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','blackjakmax','joseph.garas@iinet.net.au','Joseph Garas','Level 19, Allendale Square, Francis Burt Chambers<br>77 St Georges Terrace, Perth','Perth','Western Australia','AUSTRALIA','6000','0892200559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 13:24:39',0,NULL,3,1,3,1,'RA184545926CN ','OTSO004*2 '),(18489,904210398012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','petros1182','piotr@piotr678.orangehome.co.uk','peter fidzinski','1 sewell close<br>deeping st james','peterborough','cambridgeshire','UNITED KINGDOM','pe6 8eu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 13:36:55',0,NULL,3,1,3,1,'RA184545930CN\r ','OTSO004*3 '),(18490,816133476011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','metinmengi','info@ucakkargo.com','Metin Mengi','Zümrütevler mahallesi hanımeli caddesi no:6 -c<br>maltepe','İstanbul','','TURKEY','34844','02163525862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 14:09:38',0,NULL,3,1,11,1,'/ ','HSJA002 '),(18491,607557586004,140630817542,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',58.99,'cnfaner','luiz_prado','luizpradogomes@gmail.com','Luiz Rosa','Estrada do Pau Ferro, 1032, Apto 103 A','Rio de Janeiro','Rio de Janeiro','BRAZIL','22743052','55 21 78505195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 14:25:46',0,NULL,3,1,3,1,'RA184545838CN\r ','HSSE011\r美标 '),(18492,816144290011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',5,'HSJA002',99.95,'eastar4','gogo-buyers','buyers@gogotech.com','Nathaniel Long','34 34th St<br>Ste 3','Brooklyn','NY','UNITED STATES','11232-2020','(212) 386-7193 ext.: 150','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 14:35:45',0,NULL,3,1,1,1,' \\ ',NULL),(18493,660930376013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','dmlion','lvov.alexander@gmail.com','Alexander Lvov','Komendantsky av.<br>21-2-475','St.-Petersburg','','RUSSIAN FEDERATION','197371','7-911-219-3151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 15:03:34',0,NULL,3,1,11,1,'/ ','WLIN014 '),(18494,904262476012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','unclehubby','ahuberty@comcast.net','Alan Huberty','6216 Hills Dr','Bloomfield Hills','MI','UNITED STATES','48301','(248) 642-4252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 15:59:20',0,NULL,3,1,1,1,' \\ ','兼容型3D眼镜 通用型 '),(18495,607021136004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','elmirche','kheironone@hotmail.com','Elmir Mehic','Armije BiH 21/9/35','Tuzla','TK','BOSNIA AND HERZEGOVINA','75000','0038761882469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 16:10:14',0,NULL,3,1,3,1,'RA184545824CN\r ','OTHP004 '),(18496,904280495012,220903895872,'3 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*3',94.99,'eastar4uk','maddinpreuss','maddinpreuss@web.de','Bärbel Jahn','Paul- Gerhardt- Str. 9','Grimma','','GERMANY','04668','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 16:37:14',0,NULL,3,1,3,1,'RA184545957cn\r ','LGGL002*3  货已经退回来了'),(18497,904287729012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.88,'eastar4','maksim.o','maximum.elektro@gmail.com','Maksim Ogorodov','Bogdana Hmelnickogo str. 130-48','Belgorod','Belgorodskaja obl','RUSSIAN FEDERATION','308023','8-910-327-34-83','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 16:55:13',0,NULL,3,1,11,1,'/ ','BTHU2001 \r华硕10pin 0.8 6cm '),(18498,602226758003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','slenzen1970','s.lenzen@online.nl','Sandra Lenzen','Duitslandlaan 9','Heerlen','','NETHERLANDS','6414 HN','06-41282300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 17:05:27',0,NULL,3,1,3,1,'RA184546008CN\r ','MOLO006 '),(18499,904320790012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','smmog46','smogstad@yahoo.com','Mogstad','5488 S Tierra Linda Dr','Fort Mohave','AZ','UNITED STATES','86426-9280','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 18:01:48',0,NULL,3,1,1,1,' \\ ',NULL),(18500,602249073003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','coragrr123','coragrr@hotmail.com','Cora Gonzalez','631 S Orchard Ave','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-19 18:12:18',0,NULL,3,1,1,1,' \\ ',NULL),(18501,602249526003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','padauziux','padauziux@gmail.com','Evaldas Uzkuras','Medvegalio g. 29-32','Kaunas','','LITHUANIA','44454','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 18:13:50',0,NULL,3,1,3,1,'RA184545890CN\r ','RELO002 '),(18502,607626142004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','victor.k2000','victor.vaio@yahoo.com.br','victor resende andrade','Est Adhemar Bebiano<br>4441 bl 04 ap 305','rio de janeiro','rio de janeiro','BRAZIL','20765171','25960923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 18:24:37',0,NULL,3,1,3,1,'RA184545869CN\r ','RELO003 '),(18503,607634546004,140482241347,'New Genuine Motorola RAZR H3 Bluetooth Headset track#',1,'HSMO003',11.99,'cnfaner','bate_emo','emil.chobanov@gmail.com','Emil Chobanov','Bl.37 B ap.26<br>bul. Gagarin','Pernik','Pernik','BULGARIA','2304','(0359)76673150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 18:47:31',0,NULL,3,1,3,1,'RA184545991CN\r ','HSMO003\r欧标 '),(18504,661002458013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','justinan7','justinan7+ebay@gmail.com','Justin Nunn','1701 Market Place Dr<br>Sofa Mart','great falls','MT','UNITED STATES','59404-3403','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 18:53:55',0,NULL,3,1,1,1,' \\','兼容型3D眼镜 通用型 '),(18505,816259455011,320753598425,'NIB Genuine Samsung 3D glasses+2010 FIFA world cup disc',1,'GLSG001*2+BR3D008',114.99,'eastar4','bobbyorr69','reednmweep@hotmail.com','Nigel Cole','40 Rockland Crescent','Whitby','ON','CANADA','L1M0B2','(905) 425-1506','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 18:57:57',0,NULL,3,1,3,1,'RA184543580CN\r ','GLSG001*2+BR3D008 '),(18506,815516163002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','atsarev','atsarev.personal@gmail.com','Alexander   Tsarev','33 Dolphin Drive','Scarborough','ON','CANADA','M1L 1N5','(416) 823-2503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 19:15:24',0,NULL,3,1,11,1,'/ ','BR3D005 '),(18507,602296939003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','geoliogas','gliogas@hotmail.com','George Lioga','Karnavia 12','Athens','','GREECE','17455','00306974433091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 20:12:30',0,NULL,3,1,3,1,'RA184545909CN\r ','RELO002 '),(18508,816305760011,320787442101,'Philips Sonicare Pro Results MINI HX6021 toothbrush head',2,'HBPH008',17.8,'eastar4uk','goth1970','greek1970@hotmail.com','Markella Ashby-Pickford','2 Meadow Way<br>Horsford','Norwich','Norfolk','UNITED KINGDOM','NR10 3SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 20:19:02',0,NULL,3,1,11,1,'/ ','HBPH008 '),(18509,661041219013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','c0ffecat','icoffecat@gmail.com','Irina Ostrouhova','Novinki 4-2-79','Moscow','RU','RUSSIAN FEDERATION','115487','7916-857-8590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 20:20:39',0,NULL,3,1,11,1,'/ ','WLIN014 '),(18510,762448783007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','frstpierre','spdf@videotron.ca','françois St-Pierre','927 rue Goyer','Repentigny','QC','CANADA','j5y1t9','(514) 444-8011','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-19 20:26:30',0,NULL,3,1,11,1,'\\ ','RCLO007 '),(18511,660612665013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','tazcam22','tazcam22@hotmail.com','Mark Regalado','4085 Lake Blvd','Oceanside','CA','UNITED STATES','92056-4604','(760) 798-2972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 20:35:46',0,NULL,3,1,1,1,' \\ ','HP 8pin 1.25 18cm  '),(18512,816320306011,320778755250,'New Motorola H350 Bluetooth Wireless Headset',1,'HSMO005',8.95,'eastar4uk','efotopoulo2011','efotopoulo@yahoo.gr','ELENI FOTOPOULOU','114 GENNIMATA GEORGIOU STR.','ATHENS','GLYFADA','GREECE','16561','00306972076330','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 20:55:04',0,NULL,3,1,11,1,'/','HSMO005\r欧标 '),(18513,904426645012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','hermesgirlmary','badgirlfriend68@yahoo.com','mary winkler','16 doe run ln','centralia','IL','UNITED STATES','62801-6186','(618) 367-3091','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 20:55:21',0,NULL,3,1,1,1,' \\ ',NULL),(18514,661064210013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','garysher-half','gary@lesalinteriors.com','Gary Sherwood','2407 San Pietro Cir','Palm Beach Gardens','FL','UNITED STATES','33410-2970','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 21:20:25',0,NULL,3,1,1,1,' \\ ',NULL),(18515,904446497012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',3,'WLAT005',29.67,'eastar4','ethuaudet','ethuaudet@free.fr','eric thuaudet','12, allée du cdt charcot','bourgbarre','Bretagne','FRANCE','35230','0680369922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 21:32:40',0,NULL,3,1,11,1,'/ ','WLAT005 '),(18516,661075198013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',25.47,'eastar4','urzali','urzali@hotmail.com','Saadat Bangash','3700 Preston Rd<br>Apt 1624','Plano','TX','UNITED STATES','75093-7438','(214) 853-1797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 21:50:43',0,NULL,3,1,1,1,' \\ ',NULL),(18517,899540688012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','zuca.sousa','zucabulazaca@gmail.com','Ernesto Sousa','Rua dos lameirões, n.º 726, 1.º esquerdo<br>São pedro da Cova','Gondomar','São pedro da cova','PORTUGAL','4510-302','00351962020586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 21:50:59',0,NULL,3,1,3,1,'RA184543655CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18518,816357079011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',10.99,'eastar4','marek65pl','stasiu15pl@o2.pl','Marek  Stezewski','133 Elam St','New Britain','CT','UNITED STATES','06053-2755','(860) 348-9835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 22:00:35',0,NULL,3,1,1,1,' \\ ',NULL),(18519,607716770004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',10,'OTHP005',138,'cnfaner','2109831657','mail@kasperjensen.dk','Kasper Jensen','Bavnehøj 55','Aalborg SØ','Nordjylland','DENMARK','9000',' 40726783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 22:45:59',0,NULL,3,1,3,1,'RA184545943CN ','OTHP005 '),(18520,772190220001,110773418749,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4',1,'GRUG001',189.99,'buysia','shasta864','sherrylyn864@yahoo.com','Sherry Stafford','405 W Valley View Rd<br># 58','Talent','OR','UNITED STATES','97540-9629','(541) 499-9417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 23:02:05',0,NULL,3,1,4,1,'YW868052545CN ','白色的 '),(18521,816416765011,320787441987,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',12.99,'eastar4uk','wishfour','matthewlowdon@gmail.com','Matthew Lowdon','28 Percheron Close<br>Impington','Cambridge','Cambridgeshire','UNITED KINGDOM','CB24 9YX','01223502100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 00:54:01',0,NULL,3,1,3,1,'RA184546294CN\r ','HBPH009 '),(18522,904524256012,220903895938,'4 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*4',125.99,'eastar4uk','wiliamgrr','wiliam@rueda321.jazztel.es','GERMAN RUEDA RUEDA','ARQUITECTE UBACH Nº20B XALET PARADIS','SALOU','Cataluña','SPAIN','43840','677370081','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 00:55:22',0,NULL,3,1,6,1,'EE636829405CN ','LGGL002*4 '),(18523,607755041004,140662512555,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.9,'cnfaner','trentd2','jlb61680@hotmail.com','Jennifer Dennis','3990 County Route 21','Cameron','NY','UNITED STATES','14819','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 01:43:31',0,NULL,3,1,1,1,' \\ ',NULL),(18524,8881324346703079,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'aliexpress','1005882679','nossster@gmail.com','Dmitry Pominov	','st. Odesska, 3, app 7','Moscow','Russia','RUSSIAN FEDERATION	','117638','+7 926 2624888',NULL,NULL,NULL,'2011-12-20 02:05:03',0,NULL,3,1,3,1,'RA184542200CN\r ',NULL),(18525,904548161012,220815932164,'NIB Logitech 2.4GHz Wireless Mouse M215 + Nano RECEIVER',2,'MOLO005',33.76,'eastar4uk','django-67','voelk67@aol.com','Thomas Völk','Ortsstr.8','Weimar-Allna','','GERMANY','35096','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 02:13:26',0,NULL,3,1,3,1,'RA184544112CN\r ','MOLO005 \r两个黑色的'),(18526,816444512011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',53,'eastar4','gaston8287','gaston_87@live.com','Gaston Bianchelli','5007 Carriage Drive Cir','Charlotte','NC','UNITED STATES','28205-4927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 02:43:15',0,NULL,3,1,1,1,'\\  ',NULL),(18527,602402344003,130553129170,'New Plantronics Voyager 851/855  Bluetooth headset',1,'HSPL009',59.9,'cnfaner','dracokylinprod','renaissancekylin@gmail.com','Billy Ray','606 Gateway Dr NE<br>Rm 133','East Grand Forks','MN','UNITED STATES','56721-2604','(931) 332-1786','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 03:15:19',0,NULL,3,1,1,1,' \\ ',NULL),(18528,661155510013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','yeonglong','yeonglong.kim@gmail.com','Yeonglong Kim','Hanbo Eunvit Maeul Apt. 102-406<br>Juyak-dong','Jinju-si','Gyungsangnamdo','KOREA,REPUBLIC OF','660-772','+82118393603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 03:38:12',0,NULL,3,1,11,1,'/ ','WLIN014 '),(18529,602413542003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','sebastian-mesa','sebastianecua@hotmail.com','DIEGO MESA','7801 NW 37th St<br># EC107Q1405','DORAL','FL','UNITED STATES','33166-6503','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 04:25:12',0,NULL,3,1,1,1,' \\ ','OEM '),(18530,602417814003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','mikefisher586','fisheramike@yahoo.com','Michael Fisher','29394 Little Mack Ave','Roseville','MI','UNITED STATES','48066-2235','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 04:52:46',0,NULL,3,1,1,1,' \\ ',NULL),(18531,602419061003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',20.99,'cnfaner','mrbingo','dear.bingo@gmail.com','Jae-Keun Kim','201-Ho, 200-9<br>Seongnae-dong, Gangdong-gu, Seoul, Korea','Seoul','','KOREA,REPUBLIC OF','134-030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 05:02:07',0,NULL,3,1,3,1,'RA184543531CN ','HSUE003\r新地址\rJae-Keun Kim\r203Ho, 160-25\rSeongnae-dong, Gangdong-gu, Seoul, Korea\rSeoul 134-030\rKorea, South\r '),(18532,772286628001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',20.9,'buysia','marshy1402','craigmarsh@bmpartners.com.au','Craig Marsh','24 Highland Drive','East Bowral','New South Wales','AUSTRALIA','2576','0280887502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 05:46:36',0,NULL,3,1,11,1,'/ ','BR3D006 '),(18533,602428620003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','therealnoxious','rollin.noxious@hotmail.com','Robert McGregor','130 17Ave. N.W.','Calgary','AB','CANADA','T2M 0M6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 06:21:57',0,NULL,3,1,3,1,'RA184543593CN\r ','HSMO005\r美标 '),(18534,661171494013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','drainfairy','jvpeart@mac.com','Jane Peart','4323 Murry Hill Ter','Medford','OR','UNITED STATES','97504-9092','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 06:22:48',0,NULL,3,1,1,1,' \\ ',NULL),(18535,602431309003,130617611559,'Logitech Harmony 890 remote control & wireless extender & AC adapters',1,'RCLO003',134.99,'cnfaner','rnat5479','ron.nations@atintegration.com','Ron Nations','7813 little deer trail','Georgetown','TX','UNITED STATES','78628','(713) 446-0159','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 06:45:20',0,NULL,3,1,4,1,'YW868052534CN ',' '),(18536,904618569012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','iliyaxp','sauronxp3@gmail.com','Sergey Shvedko','Marshala Fedorenko 8-2-130','Moscow','Russia','RUSSIAN FEDERATION','125599','+7(926)5820966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 07:18:09',0,NULL,3,1,3,1,'RA184545872CN ','OTSO004*2 '),(18537,904629829012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','s.shiran2','s_shiran2@walla.co.il','Shiran Costa','Ha pardes 20','Ramat Hasharon','','ISRAEL','47405','0524007008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 08:21:00',0,NULL,3,1,3,1,'RA184542037CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18538,816516370011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','harifisher','mile_cvetkovski@yahoo.com','Cvetkovski Mile','Dositej Obradovic 1-1','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 08:42:03',0,NULL,3,1,11,1,'\\ ','WLIN010+ANTY002 '),(18539,816522163011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','marian_luschnat','marian@luschnat.de','Marian Luschnat','Untertaxetweg 76','Gauting','Bayern','GERMANY','82131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 09:11:00',0,NULL,3,1,11,1,'\\ ','HSUE002 '),(18540,8881324372572504,111,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',0,'eastar4','romchikr8','romchik.r8@gmail.com','Roman Pfefer','Yehuda Burla 12/18','Haifa','','ISRAEL','32811','+972-0542111581',NULL,NULL,NULL,'2011-12-20 09:16:12',0,NULL,3,1,3,1,'RA184542045CN\r ','补发的\rUM00021\r24K超轻碳纤骨长柄伞   \r\r'),(18541,815765430002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','janhilka','jan.hilka@azet.sk','Jan Hilka','Dolne Zelenice 83','Siladice','Siladice','SLOVAK REPUBLIC','92052','00421905214325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 09:43:48',0,NULL,3,1,11,1,'\\ ','BR3D009 '),(18542,602461193003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','netanoa','gil.fisher@hp.com','Gil Fisher','Emek Ayalon 155','Shoham','','ISRAEL','60850','(039) 794-875','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(18543,602462351003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',2,'WLAT003',29.6,'cnfaner','jmatthey2000','mikemglee@gmail.com','Park Hojin(mp.010-3209-0034),','108-#401 SungHo shine hills apt.,<br>Bojeong-dong, Giheung-gu,','Yongin-si','Gyeonggi-do','KOREA,REPUBLIC OF','446-913','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 10:31:54',0,NULL,3,1,3,1,'RA184544143CN ','WLAT003 '),(18544,904661095012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','ralfij','rafekj@interia.pl','Rafal Jeske','94 West View','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE4 7RR','07857861905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 10:40:54',0,NULL,3,1,3,1,'RA184544086CN ','WLIN013 '),(18545,661217274013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23,'eastar4','legion_at_war','legion5@gmx.de','Daniel Chatzopoulos','Beethovenstr. 11','Aachen','','GERMANY','52064','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 10:58:17',0,NULL,3,1,11,1,'、 ','HSUE001 '),(18546,762675347007,170730545598,'NEW sealed Logitech Wireless Laser Mouse M505 plus unifying receiver',1,'MOLO008',35.5,'au-buy','deboz5','dshaw@iinet.net.au','Deb Kirman','18 Chiffley Crescent','Brassall','Queensland','AUSTRALIA','4305','0732940884','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-20 11:14:19',0,NULL,3,1,11,1,'、 ','MOLO008\r红色的  '),(18547,816561545011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',9.88,'eastar4','manjac78','manjac@rambler.ru','Danil Makarenkov','Veteranov 141-1-24','Saint-Petersburg','','RUSSIAN FEDERATION','198264','(921) 742-9707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 12:10:27',0,NULL,3,1,11,1,'、 ','BTHP2001 \rHP 8pin 1.0 3cm  '),(18548,904683171012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','wjood','salomtii2005_4@hotmail.com','wjood alborsheed','575 2911 929 east riffa','east rifa','','BAHRAIN','non','97339530966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 12:17:37',0,NULL,3,1,3,1,'RA184542195CN\r ','GPS0009 '),(18549,816574563011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','martin9017sbcglobalnet','martin9017@sbcglobal.net','Derek Martin','2119 6th St','peru','IL','UNITED STATES','61354-2514','(815) 830-1801','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 13:03:01',0,NULL,3,1,1,1,'\\  ',NULL),(18550,904712270012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','brauxer','brauxer@hotmail.fr','BRAUX ERIC','41 GRANDE RUE','BRAGELOGNE','AUBE','FRANCE','10340','03 25 29 10 13','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 13:52:37',0,NULL,3,1,3,1,'RA184544055CN\r ','HSNO019+CCNO001 '),(18551,904366383012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',140.99,'eastar4','sirlanlyra','sirlanalves@gmail.com','Sirlan Lyra','Lot. Carajás II, Rua C, nº 46, Serraria','Maceió','Alagoas','BRAZIL','57046-700','55-82-8812-5123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 14:17:17',0,NULL,3,1,3,1,'RA184542173CN ','OTSO004*2 '),(18552,607873523004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',6,'WLAP008',118.8,'cnfaner','artshaper','osx86@sixflow.net','won-taek seo','4f, 113-1, garak-dong,songpa-gu','seoul','','KOREA,REPUBLIC OF','137-060','82-10-7312-2154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 14:39:49',0,NULL,3,1,3,1,'RA184544069CN ','WLAP008 '),(18553,816604946011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','hrdwrhckr','ilostmyfiles@yahoo.com','Rob Couto c/o Community Chaplain Services','3200 Greenwich Rd<br>Rm 87','Norton','OH','UNITED STATES','44203-5728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 14:52:01',0,NULL,3,1,1,1,'\\  ',NULL),(18554,904734638012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','rick15658','mail.rick@chello.nl','Rick van der Lugt','Plattenburgstraat 218','Doetinchem','','NETHERLANDS','7006NB','+31644694400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 15:04:20',0,NULL,3,1,3,1,'RA184542125CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18555,904734822012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','gsm_42','gsm_42@tlen.pl','Adam Prot','170 Briarwood Close<br>Clonsilla','Dublin','Dublin','IRELAND','15','0851404105','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 15:04:23',0,NULL,3,1,3,1,'RA184544072CN ','OTCN002 '),(18556,607879597004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','domi7532','elizben@hotmail.fr','alexandre prat','9 hent lézernan','plougrescant','Bretagne','FRANCE','22820','0635227626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 15:11:13',0,NULL,3,1,3,1,'RA184544090CN ','WLDE002 '),(18557,661266187013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','lrus2255','russelllatasha@gmail.com','ALFREDO BECHET','1806 Veterans Memorial Hwy SW','AUSTELL','GA','UNITED STATES','30168-7975','(770) 944-9558','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 15:27:43',0,NULL,3,1,1,1,'\\ ',''),(18558,660216497013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','budnboo2003','pearl341@hotmail.com','Scott Gillespie','1124 6th St SW','Minot','ND','UNITED STATES','58701-5818','(701) 720-7527','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(18559,772409232001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',11.99,'buysia','djrnz','evgene.pozniak@gmail.com','Evgeniy Poznyak','1075 Sheepshead Bay Rd<br>apt 6J','Brooklyn','NY','UNITED STATES','11229-4279','(518) 772-8217','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 15:35:40',0,NULL,3,1,1,1,'\\  ',NULL),(18560,904761631012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',22.71,'eastar4','krawxon','rcote@imakecircuits.com','Régis Côté','461 Assomption','Sherbrooke','QC','CANADA','J1E 2L9','(819) 446-4610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 16:20:16',0,NULL,3,1,11,1,'、 ','TRMX003 \rAUI Transceiver  MX20T'),(18561,815862399002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','armegale','stantheman@grandecom.net','Stan English','605 Greer St','Waco','TX','UNITED STATES','76710-4625','(254) 772-9178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 16:10:39',0,NULL,3,1,1,1,'\\  ',NULL),(18562,816638041011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','larlis1110','diane1zimmerman@yahoo.com','Diane Zimmerman','105 Dogwood Dr','O Fallon','IL','UNITED STATES','62269-3511','(618) 304-7846','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 16:33:02',0,NULL,3,1,1,1,'\\  ',NULL),(18563,602533182003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','bbd2u','service@bestbuydirect2u.com','Gene Friedman','83 Courtland Ave<br>Apt 3','Stamford','CT','UNITED STATES','06902-3441','(203) 921-5917','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 16:33:24',0,NULL,3,1,1,1,'\\ ',NULL),(18564,607897154004,140644120563,'New Genuine Motorola H721 Bluetooth Wireless Headset+AC adapter',5,'HSMO022',112.75,'cnfaner','alnparadise2','alnparadise@gmail.com','Al Judson','2035 Turner Rd','Green Cove Springs','FL','UNITED STATES','32043-4800','(978) 621-3688','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 16:35:40',0,NULL,3,1,1,1,'\\  ',NULL),(18565,816640485011,320791295540,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking  TK103-2',1,'GPS0008',111.99,'eastar4','kaizer16','ngkougkousis@hotmail.com','Nikolaos Gkougkousis','Bouliagmenis 24','Glyfada, Athens','','GREECE','16675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 16:39:27',0,NULL,3,1,3,1,'RA184544188CN\r ','GPS0008 \r'),(18566,661292223013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','valleygramvintage','bettwoontwo@comcast.net','marylou ausbun','216 valley ave','sumner','WA','UNITED STATES','98390','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 17:01:51',0,NULL,3,1,1,1,'LK166421797CN\r ',NULL),(18567,661292746013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','poppajerry11','jerrybennett01@comcast.net','jerry bennett','1013 Gregory St','jacksonville','AR','UNITED STATES','72076-3016','(501) 983-4403','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 17:03:00',0,NULL,3,1,1,1,'\\  ',NULL),(18568,816660309011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',61.99,'eastar4','tano1310','tano1411@live.fr','Jonathan Saint-Georges','6 avenue de cambridge appt 19 immeuble L\'océane','Hérouville Saint-Clair','Basse-Normandie','FRANCE','14200','0676562906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 17:31:10',0,NULL,3,1,3,1,'RA184542329CN\r ','GLSG001 \r新地址\rMr Saint Georges Jonahan \rETAP HOTEL \rPlace Waldeck Rousseau 76140 \rPetit Quevilly \rFrance'),(18569,602560291003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','analistajava','analistapb@gmail.com','Marcelo Soares','Rua Leopoldino Bastos, 130 Apto 804 Bloco 1','Rio de Janeiro','Rio de Janeiro / RJ','BRAZIL','20715-200','+552178154579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 18:14:37',0,NULL,3,1,3,1,'RA184544041CN\r ','LGRM001 '),(18570,607923958004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','mbogart954','michaelbogart@hotmail.com','Michael Bogart','300 Three Islands Blvd<br>Apt 520','Hallandale Beach','FL','UNITED STATES','33009-2819','(954) 709-9500','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 18:18:52',0,NULL,3,1,1,1,'\\  ',NULL),(18571,607930168004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','kyleryan23','gvphone8@gmail.com','Kyle Han','744 Pinewood Dr','San Jose','CA','UNITED STATES','95129-2320','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 18:29:54',0,NULL,3,1,1,1,'\\  ',NULL),(18572,602564808003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','dr_rosy88','no1subjectrider@hotmail.com','rory walters','33 joe f stanley pl<br>otahuhu','auckland','new zealand','NEW ZEALAND','1062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 18:32:26',0,NULL,3,1,3,1,'RA184542187CN\r ','RCLO007+POLO001+RCLO008*4 '),(18573,904842793012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',89.78,'eastar4','deb688','dpacker688@aol.com','DEB PACKER','PO Box 155<br>901 East 11th','WOOD RIVER','NE','UNITED STATES','68883-0155','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 19:21:53',0,NULL,3,1,1,1,'\\  ','兼容型3D眼镜 通用型 '),(18574,904847341012,220747230885,'New PLANTRONICS EXPLORER 320 Bluetooth headset E320',1,'HSPL002',10.55,'eastar4uk','tautvilea','strelytea@auto.lt','Tautvile Avenauskiene','21 Nene way','St. Ives','Cambridgeshire','UNITED KINGDOM','PE27 3FJ','07545244564','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 19:28:54',0,NULL,3,1,3,1,'RA184544109CN\r ',' HSPL002\r英标'),(18575,661345319013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','bode_dnr','samirpiccolotto@gmail.com','Samir Piccolotto','Street: Luvercy Pereira de Souza, number 9<br>Barao Geraldo, Cidade Universitaria','Campinas','SP','BRAZIL','13083-725','+55 021 19 9292-0695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 19:50:20',0,NULL,3,1,11,1,'\\ ','WLIN014 \r'),(18576,904872677012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','peterchow338882011','peter_chow33888@yahoo.com','Peter Chow','34604 Pueblo Ter','Fremont','CA','UNITED STATES','94555-2865','(415) 990-0157','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 20:17:42',0,NULL,3,1,1,1,'\\  ',NULL),(18577,607966180004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','cooljet84','peter@familiesasburg.nl','Peter Sasburg','Industrieweg 35','Zoeterwoude','','NETHERLANDS','2382 NS','0638924451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 20:23:29',0,NULL,3,1,3,1,'RA184542258CN ','OTTP001 '),(18578,816743573011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','babycait4287','ladycait@gmail.com','Caitlin Spurlock','142 Wade Rd','Beckley','WV','UNITED STATES','25801-8876','(304) 712-1766','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 20:40:01',0,NULL,3,1,1,1,'\\  ',NULL),(18579,602619717003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','cphaire711','bigchak@aol.com','Chaka Phaire','241 Decatur St','Brooklyn','NY','UNITED STATES','11233-1704','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 21:19:46',0,NULL,3,1,1,1,'\\  ',NULL),(18580,904904580012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','abzc88','achoucair1988@optusnet.com.au','Abz Choucair','1 short st<br>Banksia','Sydney','New South Wales','AUSTRALIA','2205','0295977475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 21:41:43',0,NULL,3,1,11,1,'\\ ','WLAT009 '),(18581,607990584004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','batch*1','sandiped@hotmail.com','Sandra Batcheler','79 Dial Hill Road','Clevedon','Somerset','UNITED KINGDOM','BS21 7ER','07825179147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 21:48:29',0,NULL,3,1,3,1,'RA184544024CN ','HBPH003\r英标 '),(18582,816775878011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','rubber_ducky2003','gardner1@ntlworld.com','R Young','1 Harewood Hill','Darlington','Durham','UNITED KINGDOM','DL3 7HY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 21:51:03',0,NULL,3,1,3,1,'RA184542111CN\r ','GPS0010 '),(18583,602630900003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','cheapclaimer','bo_weavel@yahoo.com','gerard guagliardo','po box 254637','sacramento','CA','UNITED STATES','95825','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-20 22:01:17',0,NULL,3,1,1,1,'\\  ',NULL),(18584,904917949012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','oman001omran','oman.001@hotmail.com','Omran Al-A\'amri','Al-Sharqih Regon / Sinaw','Sinaw','POBox: 282 /  PC: 418 Sinaw, Sultanate of Oman/','OMAN','418','00968 92210252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 22:07:43',0,NULL,3,1,11,1,'\\ ','HSJA001 '),(18585,761499000007,170737835682,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',3,'LGGL003',59.97,'au-buy','yeenar','yeenar69@hotmail.com','Jody Chester','18 Jean Street ','Wellington ','New South Wales','AUSTRALIA','2820','0268452458','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-20 22:36:16',0,NULL,5,1,18,1,NULL,'LGGL003 \r问客户是否取消订单或者其他眼镜\r'),(18586,772575174001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','cristalight','cristy77@hotmail.com','Cristina Ramos','2734 W Canyon Ave','San Diego','CA','UNITED STATES','92123','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-20 22:54:05',0,NULL,3,1,1,1,'\\  ',NULL),(18587,755066525008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','emmamichellereeves','emmamreeves@gmail.com','Emma Colfelt','38 Queen Street','Berry','New South Wales','AUSTRALIA','2535','0407295963','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-20 23:48:52',0,NULL,3,1,3,1,'RA184544015CN\r ','HBPH001 '),(18588,904962302012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','fragsfof','scott.harris@blueyonder.co.uk','scott harris','85 old chapel rd , smethwick','birmingham','West Midlands','UNITED KINGDOM','B676HU','01216013812','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 00:02:43',0,NULL,3,1,3,1,'RA184544157CN\r ','OTCN002 '),(18589,602674696003,130596105523,'New Earloop wire Stereo sound replacement  Plantronics Voyager 815/855 Bluetooth',1,'HSPL018',14.99,'cnfaner','deveracaryl','carylmorante@yahoo.com.ph','Caryl Morante','345 Churchill Avenue','Kettleby City','ON','CANADA','L0G1J0','(905) 392-8870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 01:42:22',0,NULL,5,0,18,0,NULL,NULL),(18590,8881324433494947,111,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',26.99,'aliexpress','1005891667 ','avyboroff@mail.ru','Aleksandr Vyborov	','RUSSIA,Moscow,2-ya Volskaya d.24 kv.303 Moscow region','Moscow','Moscow region	','RUSSIAN FEDERATION	','111674','+7 926 2060780',NULL,NULL,NULL,'2011-12-21 02:11:34',0,NULL,3,1,3,1,'RA184544832CN\r ','GPS0010 \r提前发出单号：RA184544832CN'),(18591,8881324433711265,111,'(2 pairs/1 pack) FOR LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',89.99,'aliexpress','1005891691','sekam@pisem.net','Sergey Kamenev	','St. Chulman, 22, ap. 36','Naberezhnye Chelny	','Tatarstan	','RUSSIAN FEDERATION	','423822','+7 903 3180630',NULL,NULL,NULL,'2011-12-21 02:15:11',0,NULL,3,1,3,1,'RA184544687CN\r ','LGGL002*2 '),(18592,816851363011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','terri-gere','krilyaangela@gmail.com','Esther Angel','16 Galba Court<br>Augustus Close','Brentford','Middlesex','UNITED KINGDOM','TW8 8QT','02085680509','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 02:19:02',0,NULL,3,1,3,1,'RA184544038CN ','MOAP001 '),(18593,602682284003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','omihut','omihut@yahoo.com','Ovidiu Mihut','1803 Briarcliff Dr','Allen','TX','UNITED STATES','75013-3068','(214) 783-9346','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-21 02:23:07',0,NULL,3,1,1,1,'\\  ',NULL),(18594,8881324434463377,111,'New in box GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',79.99,'aliexpress','1005894085','mdowle@yahoo.co.uk','Mark Dowle	','16 Fishermans Wharf','Abingdon','Oxfordshire','UNITED KINGDOM	','OX14 5RX','+44 1235 200416',NULL,NULL,NULL,'2011-12-21 02:27:43',0,NULL,3,1,3,1,'RA184544951CN\r ','OTPH003 '),(18595,602686891003,130592181770,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.9,'cnfaner','rev_import','rev_import@hotmail.com','Stephane Veronneau','2645 Pierre-Boucher avenue','Quebec city','QC','CANADA','g1j3y2','(418) 934-8893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 02:50:50',0,NULL,3,1,3,1,'RA184542244CN ','OTCN003 '),(18601,816903092011,320789282298,'New Nokia LD-3W Bluetooth GPS Module Battery+Carcharger',1,'OTCR001',17.99,'eastar4uk','joe19701','joe_joe_1970@hotmail.com','камар жозеф самир','ул. ракетная   д. 32/82   кв.100','симферополь','','UKRAINE','95018','380505658206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 06:53:07',0,NULL,5,0,18,0,NULL,'OTCR001 '),(18596,8881324438277634,111,'New brand Logitech Digital IO Writing Pen',1,'NTLO002',0,'eastar4uk','schumisantreas','konstantinouads@hotmail.com','ANTREAS KONSTANTINOU','2, AIOLOY STREET POTAMOS GERMASOGEIAS','LIMASSOL','','CYPRUS','4041','',NULL,NULL,NULL,'2011-12-21 03:31:17',0,NULL,3,1,3,1,'RA184542315CN\r ','NTLO002\r补发 \r测试一下能充电再补发'),(18597,661466208013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','42447177','kingjoeblogg@hotmail.com','Tim Pugh','5A Dunvegan Rd<br>Applecross','Perth','Western Australia','AUSTRALIA','6153','0893161400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 04:38:33',0,NULL,3,1,11,1,'、 ','CASS003 \rCAB-6060'),(18598,602704354003,130596105578,'New GENUINE Plantronics Discovery 925 Bluetooth Headset',1,'HSPL008',31.5,'cnfaner','anothertone','tonytech@telus.net','Tony Stephen','13404 - 136 Ave. NW','Edmonton','AB','CANADA','T5L 4B3','(780) 484-8232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 04:45:02',0,NULL,3,1,3,1,'RA184542160CN\r ','HSPL008 \r已纳入黑名单'),(18599,602711083003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.89,'cnfaner','ubjayasinghe','ubjayasinghe@gmail.com','Buddhika Jayasinghe','33B, Kottawa Road<br>Siyabalagoda','Polgasowita','','SRI LANKA','10320','94773291482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 05:41:58',0,NULL,3,1,3,1,'RA184542235CN ','HSNO004 '),(18600,763004761007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','chongliu','gcliu@e-service.com.au','Chong Liu','2  Hillside  PL','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-21 06:12:40',0,NULL,3,1,3,1,'RA184544568CN ',' RCLO007+POLO001+RCLO008*4'),(18602,661483718013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','zechauve','nocomp@gmail.com','herve pellarin','172 chemin des pressouds','argonay','Rhône-Alpes','FRANCE','74370','06.27.89.79.91','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 06:58:24',0,NULL,3,1,6,1,'EE636828974CN ','兼容型3D眼镜 通用型 '),(18603,8881324452832338,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW - ',1,'WLIN014',18.99,'aliexpress','1005904200','freepooh@gmail.com','Sergey Makarov	','Kirova prospekt, 347-29','Samara','Samarskaya oblast	','RUSSIAN FEDERATION	','443114','+7 919 8027382',NULL,NULL,NULL,'2011-12-21 07:33:52',0,NULL,3,1,3,1,'RA184544695CN\r ','WLIN014 '),(18604,816910081011,320814060678,'New Double-Reinforced India Flower Transparent Dome Birdcage Stick Umbrella',1,'UM00051',24.99,'eastar4','2011radionov','er3167@gmail.com','evelin radionov','Svetoklarska 19','zagreb','','CROATIA','10020','0998058470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 07:37:56',0,NULL,3,1,11,1,'、 ','UM00051 \rCitymoon透明加厚面料印度花长柄伞  '),(18605,903509295012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','chicadown','chatina17@hotmail.com','Carolina Suárez','Via Augusta, 59 (planta 9)','barcelona','Cataluña','SPAIN','08006','660135923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 07:59:12',0,NULL,3,0,3,1,' RA184544259CN\r',NULL),(18606,661491111013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','jamesbauman','james.bauman@frontier.com','JAMES BAUMAN','5606 7th Ave S','SEATTLE','WA','UNITED STATES','98108','(206) 383-8395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-21 08:04:45',0,NULL,3,1,1,1,'\\ ','DLP 3D ready 投影仪兼容眼镜 '),(18607,8881324455007469,111,'3 pairs New in Box Genuine LG 3D Active Shutter Glasses AG-S110',1,'',0,'eastar4','niko28091973','botata1973@gmail.com','Nikolay Dvukrayev','Hahelmonit 2<br>apt.27','Rishon Lezion','','ISRAEL','75420','+972547757566',NULL,NULL,NULL,'2011-12-21 08:10:07',0,NULL,3,0,3,1,'RA184544191CN\r ','LGGL002*3 \r原装的\r已入库\r补发的 \r客户补了差价 \r把兼容的退回来了'),(18608,816918590011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','korpus666','yann.clement@online.fr','Yann CLEMENT','254 RUE ADOLPHE PAJEAUD<br>APPARTEMENT 144','ANTONY','Ile-de-France','FRANCE','92160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 08:27:10',0,NULL,3,1,3,1,'RA184544418CN ',' LGGL002'),(18609,905075783012,220747230747,'MOTOROLA H710 BLUETOOTH HEADSET BLUE TOOTH H 710 BLACK',1,'HSMO014',15.93,'eastar4uk','pechribo','pechri64@yahoo.de','Peter Christian Borcea','Moskauer Ring 56','Würzburg','','GERMANY','97084','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 08:34:20',0,NULL,3,1,11,1,'、 ','HSMO014 欧标头'),(18610,905071737012,220844128244,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',17.99,'eastar4','aburshaid129','m.aburshaid@gmail.com','Mohammad Aburshaid','Amman - Marj Alhamam<br>P.O.Box 914','Amman','','JORDAN','11732','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 08:11:46',0,NULL,5,0,18,0,NULL,NULL),(18611,8881324457432025,111,'Replacement LCD Screen Display + 8 Tools For Iphone 3GS',1,'',17.99,'eastar4',' aburshaid129  ','m.aburshaid@gmail.com','Mohammad Aburshaid','Amman - Marj Alhamam<br>P.O.Box 914','Amman','','JORDAN','11732 ','',NULL,NULL,NULL,'2011-12-21 08:50:32',0,NULL,3,0,11,1,'\\ ','这票没有下来 '),(18612,905079725012,220917856643,'2 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'eastar4','panjo75','tasioula@on.gr','Panagiotis Tasioulas','Pratinou 83','Athens','Greece','GREECE','11634','+306982913852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 08:54:02',0,NULL,3,1,3,1,'RA184544205CN\r ','LGGL002*2 '),(18613,816935604011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','lega*blacksea','leonid.lega@gmail.com','Leonid Gannel','Sha\'ar Yokneam, Bld.Tavor #2<br>Shemer NTS Motion','POB 599 Yokneam Illit','','ISRAEL','20692','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 09:58:58',0,NULL,3,1,3,1,'RA184544585CN\r ','LGAD001 '),(18614,608105955004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','avedov','dmitry@avedov.info','Dmitry Avedov','43 Gogolya str., apt.7','Sevastopol','Crimea','UKRAINE','99007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 10:38:05',0,NULL,3,1,3,1,'RA184544523CN\r ','CACN004 '),(18615,905099344012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',10,'WLAP004',468.9,'eastar4','camille92150','camille92@noos.fr','Gauthier Eric','10 avenue Alexandre Maistrasse','suresnes','Ile-de-France','FRANCE','92150','01 73 64 23 33','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 10:56:08',0,NULL,3,0,4,1,'YW868052593CN ','WLAP004+WLAP002\r已入库\r\r一共买了34个Original Apple Adapter for Airport Wireless WiFi Card\r20个Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026\r '),(18616,602751169003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','sodmore','sodmoria@netvision.net.il','Eran Sod-Moriah','Nahal Tzeelim 2','Gedera','Israel','ISRAEL','70700','+972-77-5620040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 11:07:04',0,NULL,3,1,3,1,'RA184546060CN\r ','HBPH009 '),(18617,816956227011,320812367902,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','petko_angelov','papetkov@postbank.bg','Petko Petkov','14 Tsar Osvoboditel Boulevard<br>3 floor','Sofia','Center','BULGARIA','1048','+359898661118','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 11:40:44',0,NULL,3,1,3,1,'RA184544639CN\r ','HSNO033\r欧标 '),(18618,816959069011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','pzx280','alancunningham@optushome.com.au','Alan Cunningham','114 Boundary Road<br>Camp Hill','Brisbane','Queensland','AUSTRALIA','4152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 11:53:27',0,NULL,3,1,3,1,'RA184544378CN\r ','LGRM001 '),(18619,816111772011,320791705383,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',37.99,'eastar4uk','ferreirassa','emporiumtechvendas@hotmail.com','ELIOMAR FERREIRA','RUA MANOEL CAETANO N11A<br>BARBALHO EM FRENTE POSTO BR','SALVADOR','BAHIA','BRAZIL','40301080','(55)71-3017-9583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 12:33:57',0,NULL,3,1,3,1,'RA184544656CN\r ','GPS0006 '),(18620,608122846004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','cmai09','christian_mai@hotmail.com','Christian Mai','Gabelsparken 22','Bramming','Jylland','DENMARK','6740','51741932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 12:38:42',0,NULL,3,1,3,1,'RA184544421CN\r ','OTHP005 '),(18621,816980437011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','fedya6699','h.farid@mail.ru','Ferid Huseynov','Ilqar Hebibov 46d','Baku','XETAI','AZERBAIJAN','1030','+994504096699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 13:27:33',0,NULL,3,1,11,1,'\\ ','UDAP001 '),(18622,608132616004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','grendelbox','grendel@grendelbox.de','Michael Nitsche','Weinbergring 9','Langenselbold','','GERMANY','63505','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 13:34:39',0,NULL,3,1,3,1,'RA184544466CN\r ','WLDE002 '),(18623,816976948011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','s21electrical','philipdungworth@hotmail.com','Philip Dungworth','27/29 bridge street<br>killamarsh','sheffield','South Yorkshire','UNITED KINGDOM','s21 1ah','01142485537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 13:11:48',0,NULL,3,1,3,1,'RA184544642CN ','GLSG001 '),(18624,602783304003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','blkcouga','jslimick@gmail.com','Jeff Slimick','1417 Sherborn Ct S','Minooka','IL','UNITED STATES','60447-4569','(630) 995-5538','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-21 14:25:59',0,NULL,3,1,1,1,'\\ ',NULL),(18625,905167151012,220816316678,'NEW Autopop 3-section Sun umbrella w/Paris Eiffel tower',1,'UM00015',24.99,'eastar4','olgaa182','poddub.them@gmail.com','Olga Poddubsky','Novorossiysk street, house number 182','Anapa','Krasnodar Region','RUSSIAN FEDERATION','353440','89183833798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 14:50:40',0,NULL,3,1,11,1,'\\ ','UM00015 \r银胶巴黎铁塔伞 '),(18626,661566957013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','y6astik','vitkovdm@gmail.com','Dima Vitkov','kukia 27/32','rishon lezion','israel','ISRAEL','75548','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 15:52:04',0,NULL,3,1,11,1,'、 ','HSNO019 '),(18627,817020198011,320787341155,'New Jabra JX10 II 2 Wireless Bluetooth headset black',1,'HSJA004',13.99,'eastar4uk','89103461127','vova_knish@mail.ru','Vladimir Knysh','Leninskii prospekt 11-118','Voronezh','','RUSSIAN FEDERATION','394029','89103461127','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 15:53:53',0,NULL,3,1,11,1,'\\ ','HSJA004\r黑色的 '),(18628,661414292013,230620420999,'NIB GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO029',30.9,'eastar4','alice.com.1987','alice.com@windowslive.com','Ειρηνη Χρυσοβαλαντου Βασιλειου','Ερωτος 7','Αττικη','Αχαρναι','GREECE','13671','6947222319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 16:33:45',0,NULL,3,1,11,1,'\\ ','HSNO029\r欧标 '),(18629,905203498012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','boss61','bossosaka@yahoo.co.jp','Masaaki Toribuchi','25-10, Sakuragaoka-Minamimachi','Takatsuki','Osaka','JAPAN','569-0818','072-690-0545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 16:38:54',0,NULL,3,1,3,1,'RA184544364CN\r ','HBPH007 '),(18630,602813567003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.49,'cnfaner','lakecoins','aristos@aristos.net','Aristos Vasiliou','Voullas 27, Mavros Court 137, Apartment 13','Larnaca','Cyprus','CYPRUS','6040','+35799435181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 16:47:52',0,NULL,3,1,3,1,'RA184544449CN\r ','MOMI002 '),(18631,905202046012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','eskalety','rafaesca@terra.es','Rafael Antonio Martin de la Escalera Hernández','Calle Ecuador Nº2, Piso 1ºD Izquierda','Cádiz','Andalucía Ceuta y Melilla','SPAIN','11007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 16:50:46',0,NULL,3,1,3,1,'RA184544435CN\r ','GPS0009 '),(18632,817042977011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','longle74','long74@sbcglobal.net','Long Le','HOME<br>407 E  Hellman Ave','ALHAMBRA','CA','UNITED STATES','91801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-21 17:01:43',0,NULL,3,1,1,1,'\\ ',NULL),(18633,608174135004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','beeversteve6789','stevemctralee@yahoo.co.uk','Peter McCarthy','45 Derrylea','Tralee','Kerry','IRELAND','default','0857213629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 17:05:07',0,NULL,3,1,3,1,'RA184544452CN\r ','HBPH003 '),(18634,905220621012,220793692081,'4 pair New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',239.99,'eastar4','erwanetnath66','longin.erwan@gmail.com','Erwan Longin','11 Rue Pierre Brune','Ceret','Languedoc-Roussillon','FRANCE','66400','0678646466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 17:24:28',0,NULL,3,1,6,1,'EE636828988CN ','GLSG001*4 '),(18635,772832623001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','jospat973','jospat@embarqmail.com','jose and patricia osorio','29 townsend st','newton','NJ','UNITED STATES','07860','(973) 579-5002','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-21 18:35:43',0,NULL,3,1,1,1,'\\ ',NULL),(18636,602849818003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','lenomer','omer.len@gmail.com','Omer Len','Moshe Sharet 7<br>Moshe Sharet 7','Ramat-Gan','Ramat-Gan','ISRAEL','52425','+972507301043','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 19:07:59',0,NULL,3,1,3,1,'RA184544497CN\r ','LGAD001 '),(18637,602855112003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','lippdinos','lippdinos@pobox.com','Louis Lipp','R. Cel Quirino 350, apt 104<br>Cambui','Campinas','SP','BRAZIL','13025000','(199) 293-2133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 19:38:32',0,NULL,3,1,3,1,'RA184544381CN\r ','LGRM001 '),(18638,905272633012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',24.9,'eastar4uk','mugen1590','paulelsy@bethere.co.uk','Paul Elsy','4 Daffodil Avenue','Peterlee','Durham','UNITED KINGDOM','SR84PW','07821145372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 19:23:41',0,NULL,3,1,3,1,'RA184544571CN\r ','mugen1590 '),(18639,817122222011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',1,'CASS003',8.49,'eastar4','deim0nd','a.churak@gmail.com','Alexey Churak','Suzdalskaya 18-2-570','Moscow','Moscow','RUSSIAN FEDERATION','111673','+79169801005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 20:23:18',0,NULL,3,1,11,1,'\\ ','CASS003 '),(18640,905303186012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','sfj1990','sarahjames90@hotmail.co.uk','Sarah James','62 Chestnut Springs<br>Lydiard Millicent','Swindon','Wiltshire','UNITED KINGDOM','sn5 3nb','01793770232','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 20:31:56',0,NULL,3,1,3,1,'RA184544545CN\r ','HBPH003 '),(18641,905304574012,220917856643,'2 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'eastar4','superso555','ainos555@hotmail.com','Sonia Alvarez','c/Madriguera 8-10 3º 2ª','Barcelona','Cataluña','SPAIN','08033','667344446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 20:35:12',0,NULL,3,1,3,1,'RA184544506CN ','LGGL002*2 '),(18642,905310702012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','h_lundqvist','h_kreiger@yahoo.co.uk','Harald Clark','Flat 1<br>6 Cromwell Terrace','Scarborough','North Yorkshire','UNITED KINGDOM','YO11 2DT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 20:49:24',0,NULL,3,1,11,1,'\\ ','BTAC2013 \racer 5pin1.25 15cm '),(18643,817137934011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','abuyanbatbuyanbat','abuyanbat@yahoo.com','AmericanMongols LLC','5321 Lincoln Ave','Skokie','IL','UNITED STATES','60077-2009','(993) 313-7777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-21 21:00:54',0,NULL,3,1,1,1,'\\ ',NULL),(18644,755373378008,180764312983,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET+AC adapter',1,'HSPL005',13.99,'au-buy','nelle33011bay','ebuterfly@aol.com','ELLEN ALLEYNE','11429 211th St','CAMBRIA HEIGHTS','NY','UNITED STATES','11411-1015','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-21 21:03:53',0,NULL,3,1,1,1,'\\ ','HSPL005 '),(18645,608241028004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','japee32','japee23@hotmail.com','Jarno Kulmala','Ylivieskantie 832','Jyrinki','sievi','FINLAND','85340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 21:13:50',0,NULL,3,1,3,1,'RA184544470CN\r ','WLDE002 '),(18646,817146350011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','kg4ess','jarrodwtaylorcrnp@yahoo.com','Jarrod Taylor','25678 West Limestone School Road','Elkmont','AL','UNITED STATES','35620','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-21 21:27:57',0,NULL,3,1,1,1,'\\ ','INOVA(爱诺华) T4 手电 光杯版电池 '),(18647,816329347011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',2,'HSIT002',43.98,'eastar4uk','georgeuoa1','georgeuoa@yahoo.com','George Konaxis','Erythrou Stavrou 87','Drapetsona','Greece','GREECE','18648','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 21:35:09',0,NULL,3,1,3,1,'RA184544599CN\r ','HSIT002\r黑色的 \r欧标'),(18648,602906382003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','billy-the-t','billtate@kbtate.com','William Tate','5000 Sawgrass Village Cir<br>Ste 4','Ponte Vedra Beach','FL','UNITED STATES','32082-5042','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-21 22:46:50',0,NULL,3,1,1,1,'\\ ',NULL),(18649,602909568003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','vtracsd','vtrac@slickdeals.net','Van Trac','6064 S Durango Dr','Las Vegas','NV','UNITED STATES','89113-1783','(702) 789-0503','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-21 23:02:25',0,NULL,3,1,1,1,'\\ ','OEM '),(18650,661685972013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',5,'HSNO019',189.9,'eastar4','jape324','jani324@hotmail.com','Jani Hassinen','Kulhontie 133','Joensuu','Kulho','FINLAND','80910','0503235742','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-12-21 23:20:44',0,NULL,3,1,3,1,'RA184544510CN ','HSNO019\r欧标 '),(18651,905373978012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','araujo49','lrcaraujo@uol.com.br','Leonardo Roberto Carvalho de Araujo','Av. Venancio Aires, 611/501','Porto Alegre','RS','BRAZIL','90040-193','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 23:50:28',0,NULL,3,1,3,1,'RA184544608CN\r ','LGRM001 '),(18652,817191696011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','kmdly66','myles129@btinternet.com','karen miles','the coachouse<br>bath old road','radstock','Somerset','UNITED KINGDOM','ba3 3he','01761431612','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 23:51:18',0,NULL,3,1,3,1,'RA184544554CN\r ','MOAP001 '),(18653,817192915011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','storribooks','kenny.storribooks@blueyonder.co.uk','Kenneth Storrie','2 Parkhead Street','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH114RL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 23:55:45',0,NULL,3,1,3,1,'RA184544537CN\r ','MOAP001 '),(18654,661698990013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','roseandmike','roseimp@optonline.net','Rosemary Impelluso','30 Reston Rd','Wayne','NJ','UNITED STATES','07470','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 00:35:41',0,NULL,3,1,1,1,'\\ ','兼容型3D眼镜 通用型 '),(18655,661700038013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','coachwylie','coachwylie@yahoo.com','randy wylie','4322 Pin Oak Ln','spring','TX','UNITED STATES','77389-4657','(832) 515-3424','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 00:40:14',0,NULL,3,1,1,1,'\\ ','兼容型3D眼镜 通用型 '),(18656,817209193011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',3,'WLAT008',17.67,'eastar4uk','vitaliok_p','vitaliok@gmail.com','Vitalij Porchunov','Apt 16 Rosehaven, Carpenterstown<br>Castleknock','Dublin','Dublin','IRELAND','D15','0851323637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 01:06:32',0,NULL,3,1,3,1,'RA184544483CN\r ','WLAT008 '),(18657,817212340011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','paramooner','jacquo@cyberbeach.net','Jacques E Collin','41 Melvyn Ave.','Lively','ON','CANADA','P3Y 1B1','(705) 692-5097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 01:26:46',0,NULL,3,1,3,1,'RA184544395CN\r ','LGRM001 '),(18658,8881324518398479,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'',0,'cnfaner','mmojowrkn','clearlightphoto@comcast.net','Doug  Brown','2531 Cherry St','Bellingham','WA','UNITED STATES','98225-2003','(360) 647-1657',NULL,NULL,NULL,'2011-12-22 01:46:38',0,NULL,3,1,1,1,'\\ ','补发的 \rLK102678472CN\rMOAP001'),(18659,816427460002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','cr47','ryer4247@comcast.net','Charles C. Ryer','142 Old Meadow Rd','Topton','NC','UNITED STATES','28781-7463','(828) 321-0578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 01:46:38',0,NULL,3,1,1,1,'\\ ',NULL),(18660,602942400003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','xguttercatx','pascal.boisvert@gmail.com','Serge Garceau','170 Av du parc','Grand-Mère','QC','CANADA','G9T 6R9','(819) 840-4011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 02:28:06',0,NULL,5,1,18,0,NULL,'RCLO007+POLO001+RCLO008*4 '),(18661,661718920013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','posto77','paul.arvanitis@gmail.com','Paul Arvanitis','16  Holt  St','Stanmore','New South Wales','AUSTRALIA','2048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 02:32:18',0,NULL,3,1,11,1,'\\ ','WLIN014 '),(18662,602943360003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',2,'HBPH009',37.98,'cnfaner','pappas0303','pappas@san-diego.net','andrew pappas','10545 Caminito Baywood','San Diego','CA','UNITED STATES','92126','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-22 02:34:12',0,NULL,3,1,1,1,'LK163761125CN\r ',NULL),(18663,661719557013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','makotek1','mary.kotronakis@gmail.com','Mary Kotronakis','PO Box 1527<br>Werribee Plaza','Werribee','Victoria','AUSTRALIA','3030','0406699300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 02:35:55',0,NULL,3,1,11,1,'\\ ','UM00041 \r接边斑马纹透明伞   '),(18664,763319299007,170751314487,'2 pairs LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'au-buy','ilivebyeverybpm','i_live_by_every_bpm@hotmail.com','Joshua O Jones','508 Mountian View Road','Maleny','Queensland','AUSTRALIA','4508','0406650812','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 02:32:59',0,NULL,3,1,3,1,'RA184544700CN\r ','LGGL002*2 '),(18665,661738057013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','denpolev','dnpolev@gmail.com','Denis Polev','Vilskogo str.7a apart.61','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660062','9130300470','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 04:31:09',0,NULL,3,1,3,1,'RA184544611CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18666,602967137003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','zevik10','4xcenter@gmail.com','zev laibman','17 Habrosh','oranit','','ISRAEL','44813','972543049054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 05:42:48',0,NULL,3,1,3,1,'RA184544625CN\r ','HSPL005 '),(18667,816482740002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','ultrod','www2001wwwus@yahoo.com','jeff davis','124 S Main St','lewisburg','OH','UNITED STATES','45338','(937) 248-1228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 06:45:43',0,NULL,3,1,1,1,'\\ ',NULL),(18668,816246399011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','jimjimsvenssonsvensson','jim820618@gmail.com','Jim Svensson','Tyringegatan 78','default','Helsingborg','SWEDEN','25276','0737726827','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 07:52:38',0,NULL,3,1,11,1,'\\ ','OTHP005 '),(18669,8881324543758974,111,'10benr',1,'HSJA010',0,'eastar4uk','10benr','benroper2907@gmail.com','ben roper','1, corndon close','kidderminster','Worcestershire','UNITED KINGDOM','dy11 7ef','01562638415',NULL,NULL,NULL,'2011-12-22 08:49:18',0,NULL,5,0,18,0,NULL,NULL),(18670,8881324543816839,111,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',0,'eastar4uk','10benr','benroper2907@gmail.com','ben roper','1, corndon close','kidderminster','Worcestershire','UNITED KINGDOM','dy11 7ef','01562638415',NULL,NULL,NULL,'2011-12-22 08:50:16',0,NULL,3,1,3,1,'RA184544660CN\r ','HSGA010\r英标 '),(18671,905487850012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','adoi5196','edoiron@comcast.net','Arthur Doiron','4007 I Ave','Anacortes','WA','UNITED STATES','98221','(360) 982-2454','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 09:14:09',0,NULL,3,1,1,1,'\\ ','兼容型3D眼镜 通用型 '),(18672,905494344012,220705174957,'New Genuine Motorola HS820 Bluetooth Wireless Headset',1,'HSMO018',9.9,'eastar4uk','anmoljyoti','anmoltamse@gmail.com','Amol Tamse','43<br>Woodside Avenue','Wembley','Middlesex','UNITED KINGDOM','HA0 1UN','02084260302','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 09:52:16',0,NULL,3,1,3,1,'RA184544965CN\r ','HSMO018 \r英标'),(18673,602997744003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','leopard_1uk','optimummechanic@yahoo.co.uk','michael spencer','27 Gainsborough Drive<br>Northfleet','Gravesend','Kent','UNITED KINGDOM','DA118NH','07939982435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 10:26:33',0,NULL,3,1,3,1,'RA184544979CN\r ','HSMO018\r英标 '),(18674,608353142004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','dougeriv29','dougrivas@hotmail.com','Doug Rivas','4410 Avenue F<br>Apt 304','Austin','TX','UNITED STATES','78751-3736','(985) 705-9342','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-22 10:47:58',0,NULL,3,1,1,1,'\\ ',NULL),(18675,816934886011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','mmmeue','paulomatias@portugalmail.pt','Paulo  Marques','R. de S. Gens, 3150','Senhora da Hora','Matosinhos','PORTUGAL','4460409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 11:13:49',0,NULL,3,1,3,1,'RA184544894CN\r ','GLOT001 '),(18676,817334464011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','delineator333a','roger_gaspar@hotmail.com','Roger Gaspar','1 Makeway Avenue<br>Newton Edge 10-02','default','','SINGAPORE','228598','(065) 978-8747 ext.: 2','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(18677,905533920012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',2,'UM00031',31.9,'eastar4uk','juancristian','juancristian@mixmail.com','Cristian  Santandreu Utermark','San Andres 16 2ºA','Madrid','Madrid','SPAIN','28004','699939697','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 13:04:10',0,NULL,3,1,3,1,'RA184542213CN\r ','UM00031\r一个红色一个黑色 '),(18678,602696864003,130617611588,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',136.99,'cnfaner','edmonde-bay','edmondlwd@hotmail.com','edmond lee','Blk 272, #07-234<br>Bishan St 24','default','','SINGAPORE','570272','97842938','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 13:07:40',0,NULL,3,1,3,1,'RA184542227CN\r ','RCLO009\r '),(18679,661800251013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','rana.ali82','rana_ali_zafar@hotmail.com','rana ZAFAR','93 justin avenue<br>GLENROY','melbourne','Victoria','AUSTRALIA','3046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 13:09:12',0,NULL,3,1,11,1,'\\ ','HSNO022\r澳标'),(18680,817339688011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','knucklecillo','the_knuckleduster@hotmail.com','Francisco Javier Sánchez de Cima','C Gasómetro nº6 2ºD','Madrid','Madrid','SPAIN','28005','616041651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 13:14:06',0,NULL,3,1,11,1,'\\ ','MOAP001 '),(18681,905540906012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','mpadair00','mpadair00@hotmail.com','Raunie Adair','806 Reynolds Ct','Grovetown','GA','UNITED STATES','30813-1254','(706) 951-0909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 13:33:21',0,NULL,3,1,1,1,'\\ ',NULL),(18682,763432204007,170730544780,'Logitech Harmony 890 LCD  remote control+RF  extender+battery+IR Emitter+cable',1,'RCLO003',135.99,'au-buy','tandsimports','tandsimporters@yahoo.com','TODD SECOR','1327 W Rogers Ave','Appleton','WI','UNITED STATES','54914-5068','(920) 858-3883','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-22 13:43:20',0,NULL,3,1,4,1,'YW868053013CN ',NULL),(18683,817352907011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','kilines12','emiliano_morales@hotmail.com','Emiliano Morales Muñoz','Zona Industrial JALI','Campo de Criptana','Castilla-La Mancha','SPAIN','13610','697864761','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 14:15:37',0,NULL,3,1,3,1,'RA184544877CN\r ','LGGL002 '),(18684,661813292013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','sneakers180','orders180@yahoo.com','Margo Blackwell','4801 W Fowler Rd','Bloomington','IN','UNITED STATES','47403-9584','(812) 824-4568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 14:25:22',0,NULL,3,1,1,1,'\\ ',NULL),(18685,817365590011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','jemma7767','jemjem86@hotmail.co.uk','Jemma Winwood','27 Westerham Road<br>Ruddington','Nottingham','Nottinghamshire','UNITED KINGDOM','ng11 6dp','07973118630','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 15:07:36',0,NULL,3,1,3,1,'RA184542301CN\r ','GLSG001 '),(18686,905568146012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','tipsbox','wiz1120@naver.com','Jisung Noh','310-404, Gangchon Maeul 3 Danji Apt., Madu 2-dong, Ilsandong-gu','Goyang-si','Gyeonggi-do','KOREA,REPUBLIC OF','410-716',' 82319034308','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 15:16:08',0,NULL,3,1,11,1,'\\ ','ANTY001 '),(18687,817369774011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sparker18','sparker18@hotmail.com','Derrick Parks','1502 E 26th St','Lynn Haven','FL','UNITED STATES','32444-5346','(850) 819-8523','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 15:21:51',0,NULL,3,1,1,1,'\\ ',NULL),(18688,608392380004,140630816480,'New Nokia HS-26W Bluetooch Headset HS 26W',1,'HSNO032',14.99,'cnfaner','papadakisxarxaralampos','utilitymanager@in.gr','MICHAILIDOU BAS.  PAPADAKIS XAR.','ISTRO - KALO XORIO T.TH. B9','AGIOS NIKOLAOS','CRETE','GREECE','72100','6985038682','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 15:25:05',0,NULL,3,1,3,1,'RA184544903CN\r ','HSNO032\r欧标 '),(18689,816577138002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','chrisvcope','bluedog3@comcast.net','chris cope','2106 N Tyler St','tacoma','WA','UNITED STATES','98406-4839','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 15:32:54',0,NULL,3,1,1,1,'\\ ',NULL),(18690,817369192011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','josemariajmsj2011','josemariajmsj@gmail.com','JOSE MARIA DOS SANTOS JUNIOR','Estrada da Vila Nova 09, 203J','ANANINDEUA','PA','BRAZIL','67130600',' 00559181324902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 15:34:17',0,NULL,3,1,3,1,'RA184545002CN\r ','LGRM001 '),(18691,905577912012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','knyazkoff','ksvoff@gmail.com','Knyazev Sergey Knyazev Sergey','dom 21, kvartira 51<br>Odintsovskiy raion','Noviy Gorodok','Moskovskaya oblast','RUSSIAN FEDERATION','143074','+7-916-603-71-37','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 15:50:32',0,NULL,3,1,3,1,'RA184542275CN\r ','GLSG009 '),(18692,817381518011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','fernandoauk','fernandoauk@gmail.com','Fernando Kursancew','Rua Dhalia, 353. Apto 1101.<br>Boa Viagem','Recife','Pernambuco','BRAZIL','51020290','8187572212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 16:05:05',0,NULL,3,1,11,1,'\\ ','HSUE002 '),(18693,661832204013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','dhn777','ducnguyen330@yahoo.com','Thao Nguyen','2072 S Military Trl<br>Ste 10','WEST PALM BEACH','FL','UNITED STATES','33415-6419','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 16:12:35',0,NULL,3,1,1,1,'\r\\ ','黑色的 '),(18694,905591367012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',9.19,'eastar4uk','hoppy550','goc3006@yahoo.co.uk','David Hopkins','22 Great Orchard Close<br>Plymstock','Plymouth','Devon','UNITED KINGDOM','PL9 9QW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 16:33:01',0,NULL,3,1,3,1,'RA184544934CN\r ','HSPL005\r英标 '),(18695,603058767003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','ignacio2452','acrebuilders@aol.com','Ignacio Arzate','179 San Lorenzo ST','Pomona','CA','UNITED STATES','91766','(909) 622-5695','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-22 16:56:33',0,NULL,3,1,1,1,'\\ ','OEM '),(18696,661716934013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','golsen2','bg6olsen@hotmail.com','Glenda Olsen','2190 Mailand Rd E','Saint Paul','MN','UNITED STATES','55119-5330','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 17:11:23',0,NULL,3,1,1,1,'\\ ','罗兰LOWRANCE finder H2OC  GPS 彩色  '),(18697,905605918012,220859193239,'100% New in box Genuine Samsung 2 pair SSG-2100AB + 3D Blu-ruy ICE AGE 3 disc',1,'GLSG001*2+BR3D006',0,'eastar4','alvanos1991','ni_eleuth@hotmail.com','Nick Eleftheropoulos','Ypolohagou Diakou 21 Panorama Voulas','Voula Attica','Athens','GREECE','16673','2108954220','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184542289CN\r ','钱收到了，只不过单子下来的这种形式很少见\r\rGLSG001*2+BR3D006+GLSG001\r再发一副New genuine Samsung 3D Active Glasses SSG-2100AB\r'),(18698,905615758012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','ranjan9','kranjan@ntlworld.com','KANNUTHURAI RANJAN','268 CHADWELL HEATH LANE','ROMFORD','Essex','UNITED KINGDOM','RM6 4YL','02085973579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 17:44:01',0,NULL,3,1,3,1,'RA184544982CN\r ','OTGR001 '),(18699,603077204003,130554636475,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',45.99,'cnfaner','lopiou92','ebay@lopiou.com','Laurent Ioualalen','4 rue Kleber Auquier','Avignon','Provence-Alpes-Côte d\'Azur','FRANCE','84000','0681184009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 18:33:18',0,NULL,3,1,3,1,'RA184544948CN\r ','HSIT001 \r欧标'),(18700,905641869012,220816379674,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT006*3',78.99,'eastar4uk','carobab13','mubab13@yahoo.fr','BARNEOUD Bernard','367 Chemin du BION','SAINT CHAMAS','Provence-Alpes-Côte d\'Azur','FRANCE','13250','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 19:05:37',0,NULL,3,1,3,1,'RA184544863CN\r ','GLOT006*3 '),(18701,817440415011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','almantas1','almantster@gmail.com','Almantas Balcetis','Pagojo 8A  +37069932817','Panevezys','LITAUEN','LITHUANIA','37162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 19:06:20',0,NULL,3,1,11,1,'\\ ','UDAP001 '),(18702,817444602011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','paquette450','andrepaquette60@videotron.ca','André Paquette','322 Clifton','Otterburn Park','QC','CANADA','J3H 1X3','(450) 467-7288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 19:17:42',0,NULL,3,1,11,1,'\\ ','HSJA002 '),(18703,608434724004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','loumarnama','mamoo53@hotmail.com','Carrie-Lou  Gray','115 N Eastwood Ave<br>Apt 12B','Inglewood','CA','UNITED STATES','90301-9223','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-22 19:23:33',0,NULL,3,1,1,1,'\\ ',NULL),(18704,905672992012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','doublenaughtspy','tracy.kahl@sbcglobal.net','Tracy Kahl','789 Carrywood Way','San Jose','CA','UNITED STATES','95120','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 20:14:24',0,NULL,3,1,1,1,'\\ ',NULL),(18705,661898718013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',18.4,'eastar4','vsmitka','vlada@smitka.org','Vladimir Smitka','Radynska 4','Plzen','','CZECH REPUBLIC','30100','+420721302808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 20:33:04',0,NULL,3,1,11,1,'\\ ','OTHP003 '),(18706,905682229012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','preston62','ror@nyc.rr.com','Charles Prestigiacomo','78-26 Cloverdale Blvd','Oakland Gardens','NY','UNITED STATES','11364-3124','(516) 236-3084','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 20:39:56',0,NULL,3,1,1,1,'\\ ','AUI Transceiver  MX20T '),(18707,905689562012,220705174934,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',9.9,'eastar4uk','spiderbid','shahanafzal@hotmail.com','Shahan Afzal','161 Queens Road','Walthamstow','London','UNITED KINGDOM','E17 8PJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 20:56:35',0,NULL,3,1,3,1,'RA184544996CN\r ','HSMO017\r英标 '),(18708,661906061013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','dwnundr1_2007','lyons.jd@bigpond.com','Jennifer Lyons','115 Honour Avenue<br>Chelmer','Brisbane','Queensland','AUSTRALIA','4068','0733795099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 21:02:00',0,NULL,3,1,6,1,'EE636828991CN ','兼容型3D眼镜 通用型 '),(18709,817490463011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',19.99,'eastar4','pascatl','ptomschi@tmsnet.de','Pascal Tomschi','Gugelstraße 7','Neunkirchen','','GERMANY','91077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 21:29:21',0,NULL,3,1,11,1,'BJ01601257\r ','UM00012 \r西瓜伞 '),(18710,661914635013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','estevaojrr1','estevaojrr@ig.com.br','Carlos Allan de Lima Rosendo','Cond. Vert Paradiso Quadra J Lote 12','Maceió','Alagoas','BRAZIL','57048375','558299999510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 21:40:53',0,NULL,3,1,11,1,'\\ ','HSNO022'),(18711,905707413012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',2,'BTDE2001',19.76,'eastar4','4v3n1','aveni@comcast.net','John Aveni','452 Livingston Dr','East Windsor','NJ','UNITED STATES','08520-5322','(609) 426-9839','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 21:45:33',0,NULL,3,1,1,1,'\\ ',NULL),(18712,603135584003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','bidkarishma','mail_karishma@hotmail.com','Karishma Singh','4002 Hooch Lndg','Duluth','GA','UNITED STATES','30097-8675','(770) 656-4534','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-22 22:23:30',0,NULL,3,1,1,1,'\\ ','OEM '),(18713,817517920011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','joyfullnoise99','mike.smart@hotmail.co.uk','Mike Smart','11 Pear Tree Road','Ashford','Middlesex','UNITED KINGDOM','TW15 1PW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 22:59:38',0,NULL,3,1,3,1,'RA184544885CN\r ','GLOT001 '),(18714,817523111011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','lewis25lewis','lewishal25@hotmail.co.uk','Lewis Halliday','Eastergate Cottage<br>Redlingfield Road','Occold','Suffolk','UNITED KINGDOM','IP23 7PG','01379672948','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 23:19:35',0,NULL,3,1,3,1,'RA184542292CN\r ','GLSG001 '),(18715,603158397003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','purboiler85','reagan52892@earthlink.net','wayne koenig','5610 Cedar Pine Dr','orlando','FL','UNITED STATES','32819-7115','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-23 00:44:10',0,NULL,3,1,1,1,'LK161094295CN\r ',NULL),(18716,661950318013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','dm4766','donovanmorris@verizon.net','donovan morris','4313 Rockport Ln','Bowie','MD','UNITED STATES','20720-3409','(240) 393-9671','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 00:43:49',0,NULL,3,1,1,1,'\\ ','兼容型3D眼镜 通用型 '),(18717,817545444011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','basementparts','steveal@ubersystems.co.uk','steven allen','155 high street','sutton','Surrey','UNITED KINGDOM','sm1 1jh','07931381036','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 01:04:21',0,NULL,3,1,3,1,'RA184544925CN\r ','OTHP005 '),(18718,755754300008,180762085457,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring',1,'UM00021',26.99,'au-buy','just.the.doctor','shop@lukem.org','Luke Macpherson','Google Australia<br>48 Pirrama Rd','Pyrmont','New South Wales','AUSTRALIA','2009','0405372773','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-23 01:06:05',0,NULL,3,1,11,1,'\\ ','UM00021\r红色的 '),(18719,817558323011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',3,'OTHP004',59.55,'eastar4','wok55','glenn.pickens@comcast.net','Glenn D Pickens','3030 Abbottswell Dr','Alpharetta','GA','UNITED STATES','30022-7703','(770) 641-7709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 02:04:07',0,NULL,3,1,1,1,'\\ ',NULL),(18720,8881324607934365,111,'只补发一条线Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'',0,'eastar4','pedro_eloy','peizpe@gmail.com','Pedro Izquierdo Pereda','Venezuela Nº 6 8º B','Vigo','Pontevedra','SPAIN','36203','',NULL,NULL,NULL,'2011-12-23 02:38:54',0,NULL,3,0,11,1,'\\ ','acer 8pin1.00 15cm  \r只补发一条线'),(18721,8881324608129992,111,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',0,'eastar4','vladimir72vladimir','vladimir.u6@gmail.com','vladimir ushakov','eliyahu ben-hur st. 4/7','beer-sheva','darom','ISRAEL','84276','+972508454950',NULL,NULL,NULL,'2011-12-23 02:42:09',0,NULL,3,1,3,1,'RA184542261CN\r ','HSJA002\r补货，由于40天过后还没有收到 '),(18722,817574348011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','snowball713','tjcafeo@aol.com','tracie tobin','15017 S Bartlett Ave','plainfield','IL','UNITED STATES','60544-1911','(815) 436-6548','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 03:21:44',0,NULL,3,1,1,1,'\\ ',NULL),(18723,661979875013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','paultav929','paul_tav9@yahoo.com','Paul Tavernese','1509 Littlehill Rd<br>null','Point Pleasant Boro','NJ','UNITED STATES','08742-3431','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 03:50:28',0,NULL,3,1,1,1,'\\ ',NULL),(18724,661982143013,230649255567,'New Japan Cute Tadpole w/lace trim Sun stick Umbrella',1,'UM00019',24.99,'eastar4','juli8282','starblue_7@hotmail.com','juli whittington','1713 Evelyn St','San Angelo','TX','UNITED STATES','76905','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 03:57:50',0,NULL,3,1,1,1,'\\ ','小蝌蚪长柄伞   '),(18725,763655619007,170728914832,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',26.98,'au-buy','jatiapowell','jatiapowell@aol.com','jatiapowell','5324 Avenue M','brooklyn','NY','UNITED STATES','11234','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-23 04:00:11',0,NULL,3,1,1,1,'\\ ','买了两个 一个320 一个330 '),(18726,8881324614871733,111,'New GENUINE Plantronics Explorer 220 BLUETOOTH HEADSET',1,'HSPL001',0,'au-buy','asad.zeeshan','qamchaudhry@yahoo.ca','Asad Bilal','16 polar Bear Place','Brampton','ON','CANADA','L6R 3L7','(647) 802-6475',NULL,NULL,NULL,'2011-12-23 04:34:31',0,NULL,3,1,3,1,'RA184546189CN\r ','补发 只补发耳机  测试一下能充满电并且正常工作再发\rHSPL001\r'),(18727,602438668003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','bestbuykg2','bestbuykg3@gmail.com','ACI #5851','17252 S Main St<br>Aci Express La Br','Gardena','CA','UNITED STATES','90248-3101','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-23 04:43:12',0,NULL,3,1,1,1,'LK162226951CN\r ','确认新地址\rACI #5851\r17252 S Main St\rAci Express La Br\rGardena CA 90248-3101\rUNITED STATES\r(562) 304 2593\r '),(18728,905823267012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',49.98,'eastar4uk','parkker11','tapiohimberg@gmail.com','tapio himberg','alakorkalontie 395','Rovaniemi','','FINLAND','96700','+358-400-694171','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 06:18:42',0,NULL,3,1,3,1,'RA184542350CN\r ','HSNO019\r欧标 '),(18729,817615637011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','aphrodite_macbst10*2010','aphrodite_macbst10@yahoo.com','Mary Ann Catada','Flat 1 5/7<br>Head street','halstead','Essex','UNITED KINGDOM','CO9 2AT','01787479244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 08:16:55',0,NULL,3,1,3,1,'RA184542403CN\r ','RELO003 '),(18730,817617948011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','amritpal007','aschera@rogers.com','AMRITPAL CHERA','26 DUFFIELD RD','BRAMPTON','ON','CANADA','L7A2P8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 08:33:56',0,NULL,3,1,11,1,'\\ ','acer 4pin1.25 15cm \rBTAC2006 '),(18731,905842113012,220448674413,'Acer Travelmate 5110 5610 Bluetooth Module2.0 EDR+cable',1,'BTAC2008',9.88,'eastar4','anatcher','anat@smd.ru','Anatoly Chernyavskiy','flat 621 build1121<br>Zelenograd','Moscow','RU','RUSSIAN FEDERATION','124460','+79166349612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 08:37:13',0,NULL,3,1,11,1,'\\ ','BTAC2008 \racer 4pin1.25 18cm '),(18732,608558436004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','speeddai','speeddai@hotmail.com','Haydn Dai','Level 2, 4 Dawn Fraser Avenue','Sydney Olympic Park','New South Wales','AUSTRALIA','2127','0291156855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 08:47:10',0,NULL,3,1,3,1,'RA184542394CN\r ','OTSO002 '),(18733,817622629011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dzhumaniazov','mataomusic@gmail.com','Marat Dzhumaniazov','Solyanka vill.<br>Zapadnaya str. 3','Astrakhan','Astrakhan','RUSSIAN FEDERATION','416130','+79047281007','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 09:06:44',0,NULL,3,1,11,1,'BJ01601262\r ','MOAP001 '),(18734,662015695013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','haremakiapple','haremaki@violin.ocn.ne.jp','Yoshikatsu Haremaki','6-12,2jyo-1<br>Akitsuki','Asahikawa-City','Hokkaido','JAPAN','079-8402','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 09:07:58',0,NULL,3,1,11,1,'BJ01601276\r ','WLAP008 '),(18735,817626994011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',4,'CASS003',33.96,'eastar4','pskram81','pmarks@pskram.com.au','Peter Marks','Po Box 1097','Dundas','New South Wales','AUSTRALIA','2117','610403239142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 09:43:11',0,NULL,3,1,11,1,'BJ01601284\r ','CASS003 '),(18736,905856774012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','blackrazorr','0blackrazor@gmail.com','Edgars Kalnins','Nameja 14 - 68','Jekabpils','Jekabpils','LATVIA','LV-5201','(371) 26666952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:02:13',0,NULL,3,1,11,1,'BJ01601278\r ','WLAT009 '),(18737,905856737012,220763389232,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',24.9,'eastar4uk','disco99man','ianmbishop@hotmail.com','Ian Bishop','The Stables<br>Washinghall Lane','Eastoft','Humberside','UNITED KINGDOM','DN17 4PY','01724798756','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 10:02:33',0,NULL,3,1,3,1,'RA184546246CN\r ','WWSI005+ANCN001 '),(18738,662027501013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','peters9925','sapj@chevron.com','Peter Sampson','75 TARBENIAN WAY, BRIGADOON','PERTH','Western Australia','AUSTRALIA','6069','0892964847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:46:36',0,NULL,3,1,6,1,'EE636829039CN ','兼容型3D眼镜 通用型 '),(18739,608570963004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','ereia','polyakova.lubov@euroset.ru','Lubov Polyakova','Leningradskoe shosse, 100-78','Moscow','Moscow','RUSSIAN FEDERATION','125195','9260234000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:48:03',0,NULL,3,1,3,1,'RA184546158CN\r ','HSJA002\r欧标\r '),(18740,662031283013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','parmax.kiev.ua','psma@parmax.kiev.ua','Maxim Parkhomenko','Geroev Stalingrada<br>59A/69','Kiev','UA','UKRAINE','04213','(068)530-4049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 11:32:45',0,NULL,3,1,11,1,'BJ01601277\r ','WLIN014 '),(18741,662032797013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','tosick4','antkras@yandex.ru','Антон Краснов','Moskovskoe shosse, d.30a, kv.18<br>Moskovskoe shosse, d.30a, kv.18','Sergiev Posad','Moskovskaja oblast\'','RUSSIAN FEDERATION','141315','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 11:32:52',0,NULL,3,1,11,1,'BJ01601288\r ','UM00033 \r韩版透明伞'),(18742,905881356012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',20,'WLAP004',99,'eastar4','camille92150','camille92@noos.fr','Gauthier Eric','10 avenue Alexandre Maistrasse','suresnes','Ile-de-France','FRANCE','92150','01 73 64 23 33','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 12:12:54',0,NULL,8,1,17,0,NULL,'WLAP004 '),(18743,662044414013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',1,'UDAP004',22.99,'eastar4','keana3','asukaone@gmail.com','James Munro','41 Clewley St','Corinda','Queensland','AUSTRALIA','4075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 12:58:24',0,NULL,3,1,11,1,'BJ01601267\r ','UDAP004 '),(18744,662052100013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.45,'eastar4','meijinnokori13','faris.kori13@gmail.com','Faris Mohd Nasir','33, Jalan Damai Bakti 5','Cheras','Kuala Lumpur','MALAYSIA','56000','0172461885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 13:48:42',0,NULL,3,1,11,1,'BJ01601275\r ','HSNO028 '),(18745,662052286013,230721079075,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',99.99,'eastar4','scari8410','scari84@hotmail.com','Serge Carignan','920 SW 11th Ave<br>Bldg D-16','Hallandale Beach','FL','UNITED STATES','33009-6786','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 13:49:48',0,NULL,3,1,1,1,'LK162747475CN\r ',NULL),(18746,903955919012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',2,'HSMO019',21.9,'eastar4uk','idaraosung','hetti2523@gmail.com','Idara Osung','4 Dyers Mews<br>Neath Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','Mk14 6ER','01908677674','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 13:51:03',0,NULL,3,1,3,1,'RA184546100CN\r ','HSMO019\r英标\r（合并订单）\r一共买了三个 \r'),(18747,903933860012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','idaraosung','hetti2523@gmail.com','Idara Osung','4 Dyers Mews<br>Neath Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','Mk14 6ER','01908677674','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 13:53:27',0,NULL,3,1,17,0,'RA184546100CN\r ',NULL),(18748,905906553012,220901458172,'New SAMSUNG Magic Water Filter WSF-100 for Samsung Refrigerator',1,'SAFI002',33.99,'eastar4uk','evangelos2009','trasanis@yahoo.gr','TRASANIS EVANGELOS','P.O. BOX 25 - KRATIGOS','MYTILINI','LESVOS','GREECE','81100','6974405009','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 14:07:42',0,NULL,3,1,3,1,'RA184546127CN\r ','SAFI002 '),(18749,905906842012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','art106boom','106boom@gmail.com','Eli Wasserman','HaNurit 102','Hagor','Drom HaSharon','ISRAEL','45870','+972-77-4506656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 14:24:56',0,NULL,3,1,3,1,'RA184546351CN\r ','MOAP001 '),(18750,602461193003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','netanoa','gil.fisher@hp.com','Gil Fisher','Emek Ayalon 155','Shoham','','ISRAEL','60850','(039) 794-875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 14:44:12',0,NULL,3,1,3,1,'RA184549636CN\r ','HSMO023 '),(18751,603260625003,130596581579,'New genuine LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',53.99,'cnfaner','nadilo','inlo65@web.de','Helga Wegner','Oeserstr.40','Berlin','','GERMANY','13509','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 14:44:47',0,NULL,3,1,3,1,'RA184546113CN\r ','LGGL002 '),(18752,660216497013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','budnboo2003','pearl341@hotmail.com','Scott Gillespie','1124 6th St SW','Minot','ND','UNITED STATES','58701-5818','(701) 720-7527','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 14:47:10',0,NULL,3,1,1,1,'LK167870315CN ',NULL),(18753,905918245012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','teresareddy10','teresareddy@eircom.net','Teresa Reddy','194 Woodfield<br>Scholarstown Road','Knocklyon','Dublin','IRELAND','16','014937085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 14:54:51',0,NULL,3,1,3,1,'RA184546285CN\r ','OTSO004*2 '),(18754,662063036013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','mac-n-tac','domestichousegodess@yahoo.com','Tessa Ann Chase','10707 W Rhoby Rd','Manton','MI','UNITED STATES','49663-9041','(231) 824-9050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 14:59:32',0,NULL,3,1,1,1,'LK167689721CN ',NULL),(18755,905920259012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',4,'TRMX003',30.28,'eastar4','shark762','jbanks@lunabase.com','joshua banks','2613 Huntsville St NW','Huntsville','AL','UNITED STATES','35811-1714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 15:03:28',0,NULL,3,1,1,1,'LK164924638CN ','AUI Transceiver  MX20T '),(18756,905920557012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','grand_uberfooser','foosbiker@gmail.com','Benjamin Cole','158 Torry Dr<br>left','Hamburg','NY','UNITED STATES','14075-3842','(716) 560-3624','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 15:03:38',0,NULL,3,1,1,1,'LK167129157CN ','兼容型3D眼镜 通用型 '),(18757,603271382003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15.79,'cnfaner','crysisantem','crysantiem@hotmail.com','Alper KURUCAY','Akpınar Mah. Kavakli Cd. Burak Apt.<br>No:11/1','Bursa','','TURKEY','16160','905302054592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 15:45:28',0,NULL,3,1,3,1,'RA184546144CN\r ','HSNO005+CCNO001 \r欧标'),(18758,662073987013,230721079091,'New UINEA Fish Hook lure Bait yellow Sharp&high penetration hooks',4,'OT00006',19.8,'eastar4','rodney2831','rodfish1322@hotmail.com','rodney dervis','10 springdale ave','naugatuck','ct','UNITED STATES','06770','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 15:50:02',0,NULL,3,1,1,1,'LK159750205CN\r ',NULL),(18759,608613429004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',4,'GLSG001',243.96,'cnfaner','danilovisk','bertipaglia.danilo@terra.com.br','Danilo Bertipaglia','Rua Tangará, 500 - Casa 6A<br>Vila Avaí','Indaiatuba','São Paulo','BRAZIL','13333-230','(5519) 7812-4620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 15:57:06',0,NULL,3,1,3,1,'RA184546379CN\r ','GLSG001 \r低于＄50，避关税'),(18760,905935957012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','itzikr','reichitzik@yahoo.com','Izhak Reich','MOR 23C','Kefar Saba','','ISRAEL','44242','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 15:59:12',0,NULL,3,1,3,1,'RA184546087CN\r ','GLOT001 \r兼容型3D眼镜 通用型'),(18761,773415916001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','ubducted1','berrydata@gmail.com','david wesley ferris','369 alberta st','new westminster','BC','CANADA','v3l3j4','(604) 771-4869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 16:04:28',0,NULL,3,1,11,1,'BJ01601260\r ','BR3D004 '),(18762,600673821003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','chernyshevgen','msotnikova@gmail.com','Mariay Sotnikova','chokolovskiy 18 fl.149','kiev','kiev obl','UKRAINE','03186',' 380672346388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 16:09:18',0,NULL,3,1,3,1,'RA184546263CN\r ','HSPL005\r欧标 '),(18763,817721529011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',85.98,'eastar4uk','5589jeffrey','jeffreydebono69@gmail.com','Jeffrey Debono','Epix House. Maestro Giuseppe camilleri<br>street.','B\'Kara','','MALTA','BKR 4212','21445772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 17:04:10',0,NULL,3,1,3,1,'RA184546277CN\r ','OTSO004 '),(18764,817729634011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',3.5,'eastar4uk','story1461','richard@richardvaughan.com','richard vaughan','14 chase close','benfleet','Essex','UNITED KINGDOM','SS73BU','01268752331','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 17:33:38',0,NULL,3,1,3,1,'RA184546250CN\r ','WLAP004 '),(18765,905979826012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','tmbullis','tmb1854@lausd.net','Thomas Bullis','15108 Romero Place','North Hills','CA','UNITED STATES','91343','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 18:18:51',0,NULL,3,1,1,1,'LK167350023CN ','PAYPAL付款有问题 '),(18766,662109243013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',11,'CASS003',93.39,'eastar4','jadouking','jadlahraoua@gmail.com','Jad Lahraoua - Tomtom','Oosterdoksstraat 114','Amsterdam','','NETHERLANDS','1011DK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 18:30:27',0,NULL,3,1,3,1,'RA184546161CN\r ','CASS003 '),(18767,662110766013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','cac.1990','cac1990@live.co.uk','charlotte cornelius','the princess of wales<br>20 tivoli road','margate','Kent','UNITED KINGDOM','ct9 5se','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 18:35:31',0,NULL,3,1,11,1,'BJ01601280\r ','WLAT010 '),(18768,662114923013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','omiada16','usajv@yahoo.com','Janette Vendrell','2745 W Okeechobee Rd<br>Apt 62','Hialeah','FL','UNITED STATES','33010-1088','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 18:55:57',0,NULL,3,1,7,1,'EE636829011CN ','兼容型3D眼镜 通用型 '),(18769,817754916011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','psychodaly','respect.g@gmail.com','Jonathan Gamliel','Harav kook  25','Netanya','Israel','ISRAEL','42260','0542199559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 18:58:06',0,NULL,3,1,11,1,'BJ01601266\r ','CCZG001 '),(18770,817760259011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','chairboymariner','darryllkeasden@hotmail.co.uk','Darryll Easden','30 The Furlongs','Market Rasen','Lincolnshire','UNITED KINGDOM','ln8 3df','01673849756','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 19:13:13',0,NULL,3,1,3,1,'RA184542788CN\r ','GLOT001 '),(18771,906003328012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','contract-surveyor','jmw.css@btinternet.com','John Michael Wood','The Nook, 4 Elm Court<br>Wilsden','Bradford','West Yorkshire','UNITED KINGDOM','BD15 0NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 19:27:20',0,NULL,3,1,3,1,'RA184542712CN\r ','HSJA002\r英标 '),(18772,816949454002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','longscavaliers1','longsbulldog@yahoo.com','sarah long','48849 pattyn dr','chesterfield','MI','UNITED STATES','48051-2968','(586) 943-1361','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 19:29:16',0,NULL,3,1,1,1,'LK164290864CN ',NULL),(18773,817774083011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',61.99,'eastar4','isbenu','ismael_beato@hotmail.com','Ismael Beato Nuñez','C/ Del Duque Nº 82','Valverde Del Camino','Andalucía Ceuta y Melilla','SPAIN','21600','959553695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 20:00:07',0,NULL,3,1,3,1,'RA184546396CN\r ','GLSG001 '),(18774,817781919011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','maco6416','mjanahacosta@gmail.com','Megan Acosta','231 Walnut St.','Dunellen','NJ','UNITED STATES','08812','(732) 688-8743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 20:21:01',0,NULL,3,1,1,1,'LK167087514CN\r ','爱雨透明伞           '),(18775,817778040011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',36.99,'eastar4','gosi-at','ebay@gosi.at','Daniel Urstoeger','Obere Donaustrasse 69/20','Wien','','AUSTRIA','1020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 20:23:24',0,NULL,3,1,11,1,'BJ01601261\r ','WWSI004 '),(18776,817786137011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','bartzasapostolos','bartzas_apostolos@yahoo.com','Apostolos Bartzas','meandrou 24','Thessaloniki','Greece','GREECE','56224','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 20:36:27',0,NULL,3,1,3,1,'RA184542876CN\r ','GLOT001 '),(18777,817719042011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','buyandresell','brian.sloan@ntlworld.com','Brian Sloan','8 Loughgall Gardens<br>Monkstown','Newtownabbey','Antrim','UNITED KINGDOM','BT37 0JY','02890589181','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 20:47:45',0,NULL,3,1,3,1,'RA184542765CN\r ','GLOT001 '),(18778,906029555012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','balbajr','balba_30@yahoo.com','benny alba','600 brookstone way','watertown','WI','UNITED STATES','53094-6094','(920) 261-3035','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 20:49:44',0,NULL,3,1,1,1,'LK160472362CN ','兼容型3D眼镜 通用型 '),(18779,603336747003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','pimp.0910','pimp0910@hotmail.com','itay amzaleg','rabi akiva 7A, apt.4<br>7 alef, dira 4','holon','ID','ISRAEL','58824','0547305654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 21:01:18',0,NULL,3,1,3,1,'RA184542757CN\r ','BALO007 '),(18780,603337406003,130596581579,'New genuine LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',53.99,'cnfaner','kandras83','kandras1983@freemail.hu','Kovárczi András','Pf.: 36.','Debrecen','','HUNGARY','4003','(36)30-9208255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 21:05:09',0,NULL,3,1,3,1,'RA184542774CN\r ','LGGL002 '),(18781,906039892012,220815931710,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\" TV',1,'MOSA004',43.99,'eastar4uk','wilburt38','wb1234567@chello.nl','Wilburt Bax','Langstraat 11','Leende','','NETHERLANDS','5595 AA','06-12167708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 21:15:53',0,NULL,3,1,3,1,'RA184546056CN\r ','MOSA004 '),(18782,906041812012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','manzi2k7','manzi_2k5@hotmail.co.uk','Marianne Carr','1, Scremerston Town Farm,','Berwick Upon Tweed','Northumberland','UNITED KINGDOM','TD15 2SY','01289387217','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 21:20:24',0,NULL,3,1,7,1,'EE63682905CN ',NULL),(18783,603341749003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',40.8,'cnfaner','edmichel','eduardo@casaalberto.com','Eduardo Michelsohn','Av. Pref. Dulcidio Cardoso 1300/ap.2101','Rio de Janeiro','Rio de Janeiro','BRAZIL','22620-311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 21:28:59',0,NULL,3,1,3,1,'RA184542730CN\r ','WWOT001+ANCN001 '),(18784,906051165012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','orange0796','jenniferchenry@hotmail.co.uk','Jenny Henry','30 Dewfalls Drive<br>Bradley Stoke','BRISTOL','Gloucestershire','UNITED KINGDOM','BS32 9BT','07968345744','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 21:50:17',0,NULL,3,1,3,1,'RA184542672CN\r ','HSMO019\r英标 '),(18785,662154325013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','cd182182','cd182@rambler.ru','Boris Smirnov','Mitinskaya st, 26, apt. 86','Moscow','','RUSSIAN FEDERATION','125430','7-9262107233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 21:52:30',0,NULL,3,1,11,1,'BJ01601270\r ','WLIN014 '),(18786,817813088011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.39,'eastar4','jcb8-78','jasonclark78@aol.com','Jason Burch','444 S Flower St<br>STE 800','Los Angeles','CA','UNITED STATES','90071-2962','(714) 348-6399','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 22:10:12',0,NULL,3,1,1,1,'LK164684671CN ','acer 6pin1.25 23cm '),(18787,906057397012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','fliasagardia','sagardia87@gmail.com','Cristina Sagardía Niño','C/ Santiago Maganto, 15','Pozuelo de Alarcón  (Madrid)','Madrid','SPAIN','28224','691149255','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 22:12:57',0,NULL,3,1,3,1,'RA184542726CN\r ','LGAD001 '),(18788,906075934012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','dgood1400','dgood1400@msn.com','Douglas I Good','1019 Trafford Ln','Savannah','GA','UNITED STATES','31410-5115','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 23:27:54',0,NULL,3,1,1,1,'LK165677765CN ',NULL),(18789,603365557003,130620866731,'New in sealed box Kensington Expert Mouse Optical USB Trackball K64325',1,'OTKE001',94.99,'cnfaner','nachonz','nachomoraga@yahoo.com','Jose Moraga','169 Totman road<br>RD1','Tirau','Waikato','NEW ZEALAND','3484','64-7-8831471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 23:51:17',0,NULL,3,1,3,1,'RA184542978CN ','OTKE001 '),(18790,817838270011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','2010junicorn','joeyunicorn@hotmail.com','Joey Rusmitut','30/222-228<br>Sussex st','Sydney','New South Wales','AUSTRALIA','2000','0433013034','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 00:02:37',0,NULL,3,1,11,1,'BJ01601256\r ','HSJA002\r澳标 '),(18791,603368022003,130603400095,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'HSMO023',22.55,'cnfaner','10-914','ambsting@gmail.com','Shawn McElhinney','23828 23rd Ave W','Bothell','WA','UNITED STATES','98021-9207','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-24 00:15:56',0,NULL,3,1,1,1,'LK168166686CN\r ',NULL),(18792,608709967004,140626376046,'New Genuine Motorola H710 Bluetooth Wireless Headset',2,'HSMO021',58.78,'cnfaner','royg1101','royg1101@msn.com','Alice senior','2687 N Ocean Blvd<br>Yacht And Racquet Club Apt G106','Boca raton','FL','UNITED STATES','33431-7101','(201) 774-3959','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-24 01:01:44',0,NULL,3,1,1,1,'LK164391810CN ',NULL),(18793,603378368003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA012',37.96,'cnfaner','jugbag88','suzyyeo88@gmail.com','LEE GON','610-ho<br>812-1 Apt-type Factory,Hyomundong Buk-gu','ULSAN','South Korea','KOREA,REPUBLIC OF','683-360','(821) 952-0195 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 01:33:45',0,NULL,3,1,3,1,'RA184546073CN\r ','HSJA012 '),(18794,662193727013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','bowie3238','dbowie2009@hotmail.com','DANIEL BOWIE','12 FORD RD','GRUYERE','Victoria','AUSTRALIA','3770','0414635350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 02:02:41',0,NULL,3,1,6,1,'EE636829073CN ','兼容型3D眼镜 通用型 '),(18795,756056795008,180755479508,'New Jabra BT250V FreeSpeak Bluetooth Headset  BT 250V+AC charger',1,'HSJA001',23.8,'au-buy','getoutman','jporterfields321@insightbb.com','william Porterfield','1124 Euclid Ave','Louisville','KY','UNITED STATES','40208-1071','(502) 938-7781','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-24 02:12:59',0,NULL,3,1,1,1,'LK167708482CN ',NULL),(18796,906111444012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','rder6423','rderrera@msn.com','Robert Derrera','3730 S Oak St','Denver','CO','UNITED STATES','80235-1003','(303) 324-2178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 02:22:32',0,NULL,3,1,1,1,'LK165831668CN ',NULL),(18797,756067877008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','madam_mushroom','sureallizm@hotmail.com','LIZ','718 Glenelg Hwy','Smythes Creek','Victoria','AUSTRALIA','3351','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-24 03:23:57',0,NULL,3,1,11,1,'BJ01601290\r ','UM00043 '),(18798,603401423003,130603400151,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver2',1,'SHLO010',12.95,'cnfaner','electr0bit','stefenkeen@gmail.com','stefen keen','7606 great plains blvd','chanhassen','MN','UNITED STATES','55317','(952) 934-3846','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-24 04:59:17',0,NULL,3,1,1,1,'LK164968982CN\r ','黑色的 '),(18799,603409297003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','pchrist1929','pchrist@jps.net','Pamela Christensen','601 Tamarindo Way','Roseville','CA','UNITED STATES','95678','(916) 791-6586','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-24 06:27:47',0,NULL,3,1,1,1,'LK166651645CN\r ',NULL),(18800,817899087011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','stratisd','stratisd@yahoo.com','Eustratios Dafermos','7 Kallergi st','Agioi Anargiroi','Athens','GREECE','13561','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-24 06:36:49',0,NULL,3,1,3,1,'RA184542845CN\r ','GLOT001*2\r申报25美金申报为gift '),(18801,662229142013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','junarva','jjuanpilar@verizon.net','Juan Narvaez','5950 Imperial Hwy<br>Unit 19','South gate','CA','UNITED STATES','90280','(562) 862-0265','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 07:25:24',0,NULL,3,1,1,1,'LK166697868CN ','兼容型3D眼镜 通用型 '),(18802,906160637012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','metalblader666','metalblader666@aol.com','Frank Ruez','Andreasmarkt 5','Krefeld','','GERMANY','47809','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 07:56:19',0,NULL,3,1,11,1,'BJ01601281\r ','WLIN016 '),(18803,662231679013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','chebbess','chebbess@hotmail.com','vincent alexander','Oldewierde 123','almere','','NETHERLANDS','1353 hp','06-12632500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 07:57:10',0,NULL,3,1,3,1,'RA184546348CN\r ','OTES001 '),(18804,608753743004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','calain276','calain276@wanadoo.fr','Clément ALAIN','9, rue d\'Elbeuf','Saint Didier des bois','Haute-Normandie','FRANCE','27370','0232506843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 08:38:08',0,NULL,3,1,3,1,'RA184542743CN\r ','RELO003 '),(18805,906171901012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','zftenista','tenistazf@ymail.com','fernando Furquimz','Rua Prisciliana Soares 43 ap 201','Campinas','SP','BRAZIL','13025080','1988150166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 09:17:07',0,NULL,3,1,3,1,'RA184546436CN\r ','OTSO004*2 '),(18806,817932845011,320394934550,'Acer Aspire 6920 6920G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',9.88,'eastar4','luccataban','lunast7@aol.com','Eleanor Stevens','40970 179th St E','Lancaster','CA','UNITED STATES','93535-7521','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 10:48:27',0,NULL,3,1,1,1,'LK168885529CN ','acer 8pin0.8 16cm   '),(18807,906195485012,220903895938,'4 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*4',125.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','Agustin Manuel Almagro Rojas','C/DE ARAGONITO 7A','MÁLAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-24 11:29:39',0,NULL,3,1,6,1,'EE636829100CN ',NULL),(18808,608771443004,140667903478,'New 3DConnexion SpacePilot USB Intelligent 3D Motion Controller mouse',1,'MOLO010',218.99,'cnfaner','misycl','mika.esteve@sfr.fr','Mickael ESTEVE','7, lieu-dit Le Petit Malonze','La Souterraine','Limousin','FRANCE','23300','05 55 63 35 99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 11:29:44',0,NULL,3,1,4,1,'YW868052604CN ',NULL),(18809,817939923011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','amrefes1','elsherifster@gmail.com','Ahmed Elsherif','13 Kingfisher Close<br>Cove','Farnborough','Hampshire','UNITED KINGDOM','GU14 9QX','07878157021','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-24 11:30:38',0,NULL,3,1,3,1,'RA184542686CN\r ','OTHP005 '),(18810,662253690013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','markwood789','mark_wu789@hotmail.com','Mark Wu','8  Reeve  Pl','Rowville','Victoria','AUSTRALIA','3178','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 11:38:04',0,NULL,3,1,6,1,'EE636829095CN ','兼容型3D眼镜 通用型 '),(18811,817946753011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','reparamobil','jcarlosg@gmail.com','Juan Carlos Gomez Lema','Lgar. Alon de Abaixo, 7','Santa Comba','Galicia','SPAIN','15846','636727857','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-24 12:14:18',0,NULL,3,1,3,1,'RA184546229CN\r ','OTES001 '),(18812,817954553011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',61.99,'eastar4','photomicf','robert.krul@kpnmail.nl','Robert Krul','Hoog Soeren 30B','Hoog Soeren','','NETHERLANDS','7346AB','0555191417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 12:51:56',0,NULL,3,1,3,1,'RA184546405CN\r ','GLSG001'),(18813,906230095012,220620860324,'NEW GENUINE NOKIA BH-207 BLUETOOTH HEADSET BH 207',1,'HSNO010',24.9,'eastar4','pujithaabeysundera','pujithabey@gmail.com','Pujitha Abeysundera','320/6-1,parana kotawa road,embuldeniya Nugegoda,Sri Lanka','Nugegoda','Western Province','SRI LANKA','10250','0772928340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 14:13:39',0,NULL,3,1,11,1,'BJ01601283\r ','HSNO010 \r全套 盒装'),(18814,817971946011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',8,'CASS003',67.92,'eastar4','bbertelsons','info@bertelsons.de','IT Beratung Bertelsons, Boris Bertelsons','Hellweg 26a','Bad Sassendorf','','GERMANY','59505','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 14:14:16',0,NULL,3,1,3,1,'RA184542690CN\r ','CASS003 '),(18815,817990256011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','haubaus','bauhaus@sympatico.ca','Kai Bein','128 Peel Street','Brantford','ON','CANADA','N3S 5M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 15:36:29',0,NULL,3,1,3,1,'RA184542902CN\r ','GLOT001*2 \r兼容型3D眼镜 通用型'),(18816,603477986003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','belmondif','georgianaok@yahoo.com','Belmondi Fridman','Hativat harel 129','Karmiel','','ISRAEL','21991','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 16:08:03',0,NULL,3,1,3,1,'RA184542916CN ','LGAD001 '),(18817,773692942001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',2,'BR3D008',29.98,'buysia','vikosan1982','victor_valdes@gsintershop.com','GS INTERNET SHOPPING','8409 NW 68th St<br># PTY-5505','Miami','FL','UNITED STATES','33166-2639','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 16:52:18',0,NULL,3,1,1,1,'LK168644046CN ','put the item number outside the package \r 把商品号写在包装上'),(18818,603488291003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','lvil9247','luisvilmar@gmail.com','LUIS VILLAR MARTINEZ','C/ NORAY, 11.<br>4ºB','MADRID','Madrid','SPAIN','28042','655125982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 17:13:24',0,NULL,3,1,3,1,'RA184546095CN\r ','MOOE003\rOEM '),(18819,818035424011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','kailash920','kailash_920@hotmail.com','Kailash Mahabier','kaapstraat<br>153','Den Haag','','NETHERLANDS','2572HH','+3100000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 18:50:27',0,NULL,3,1,11,1,'BJ01601258\r ','WLIN015 \r无线蓝牙二合一'),(18820,906333732012,220917856643,'2 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'eastar4','yass.the.lioness','yaska216@gmail.com','Yasmine Kettas','1269 Hébert','Lasalle','QC','CANADA','H8N 2L7','(514) 806-0848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 21:06:45',0,NULL,5,0,18,0,NULL,'LGGL002*2 \r型号与客户电视的不符，所以客户要求撤单\r\r已退款\r\r'),(18821,603525345003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','gul_nihalakgul2011','gul_nihalakgul@hotmail.com','ismail ataman','dikilitaş mh.karanfil sk.n:19','beşitaş','İSTANBUL','TURKEY','34810',' 05307802808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 21:21:25',0,NULL,3,1,3,1,'RA184546334CN\r ','MOOE003\rQEM '),(18822,906340096012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','w23jrh','cool_call89@hotmail.com','Callum Henry','23 Heugh Rise','Portpatrick','Dumfries and Galloway','UNITED KINGDOM','DG98UA','07814715575','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-24 21:33:24',0,NULL,3,1,3,1,'RA184542995CN ','OTHP004 '),(18823,817257219002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','sergio40sergio','carriosergio@yahoo.com','sergio carrio','1620 Oak Ln','reading','PA','UNITED STATES','19604-1639','(267) 978-1972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 21:53:55',0,NULL,3,1,1,1,'LK168712934CN ',NULL),(18824,818082170011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.39,'eastar4','sarasotasales1234','sarasotasales1234@gmail.com','Resident','3265 Austin Cir','Sarasota','FL','UNITED STATES','34231-8500','(941) 320-9245','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 22:25:24',0,NULL,3,1,1,1,'LK165726191CN ',NULL),(18825,764149560007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','swans4life2011','emma_wisdom@hotmail.com','Emma Wisdom','2 Valli Place','Chapman','Australian Capital Territory','AUSTRALIA','2611','0262889499','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-24 22:55:15',0,NULL,3,1,11,1,'BJ01601272\r ','RELO003 '),(18826,603543453003,130554636475,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',45.99,'cnfaner','cherryi11','cherryira2@yahoo.com','ira cherry','15104 Park Side Dr<br>Apt 4','Fort Myers','FL','UNITED STATES','33908-5188','(786) 327-2978','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-24 23:38:28',0,NULL,3,1,1,1,'LK169162751CN ',NULL),(18827,906366142012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',3,'CASS001',17.97,'eastar4uk','zero_kewl','chrisgroove@gmail.com','Cristian Stoica','11 Dunford Place<br>Binfield','BRACKNELL','Berkshire','UNITED KINGDOM','RG42 4UJ','07728032243','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-24 23:38:39',0,NULL,3,1,3,1,'RA184542893CN\r ','CASS001 '),(18828,773779547001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','benafab','abdoub@hotmail.com','Abdou Benafghoul','3870 Collins St','West Sacramento','CA','UNITED STATES','95691-5474','(916) 798-8986','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 00:15:37',0,NULL,3,1,1,1,'LK168960321CN ',NULL),(18829,906374404012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','angela2811green','blakey02@westnet.com.au','Angela Blakemore','11 Rogers Street','Emerald','Queensland','AUSTRALIA','4720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 00:26:54',0,NULL,3,1,3,1,'RA184549653CN\r ','SPGL001 '),(18830,608881268004,140482633357,'New genuine NOKIA HS-12W BLUETOOTH HEADSET track#',2,'HSNO025',111.9,'cnfaner','augustus1955','wintleyphipps@yahoo.com','Wintley Phipps','50 Southampton Ter','Vero Beach','FL','UNITED STATES','32963-3418','(772) 492-4175','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-25 00:39:20',0,NULL,3,1,1,1,'LK169266527CN ',NULL),(18831,906378466012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','dholaria2011','dholaria08@yahoo.co.uk','ash shafi','8 jubilee gardens','leicester','Leicestershire','UNITED KINGDOM','le4 9tj','7774663321','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 00:49:54',0,NULL,3,1,3,1,'RA184542814CN\r ','HSJA010\r英标 '),(18832,906380091012,220872406174,'4 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT006*4',175.99,'eastar4','msimon5','msbrowneyes99_99@yahoo.com','Melissa Wines','401 Mulberry St','Pioneer','OH','UNITED STATES','43554-7959','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(18833,662378567013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','zdanek68','zdanek.andrzej@gmail.com','andrew zdanowicz','226 E Hillcrest Ave','WOOD DALE','IL','UNITED STATES','60191-1424','(630) 261-5220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 00:49:40',0,NULL,3,1,1,1,'LK162794881CN ',NULL),(18834,817295731002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','firehawkjim','jime@crosslink.net','James E Eberhart','15609 Broadfording Rd','Clear Spring','MD','UNITED STATES','21722-1506','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 01:44:37',0,NULL,3,1,17,0,'LK165052225CN ',NULL),(18835,817297854002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','firehawkjim','jime@crosslink.net','James E Eberhart','15609 Broadfording Rd','Clear Spring','MD','UNITED STATES','21722-1506','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 02:01:40',0,NULL,3,1,1,1,'LK165052225CN ','买了2个\rNew Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides 1个\rAlice in Wonderland New sealed 3D Blu-ray  Region: A,B,C  1个\r\r'),(18836,906394671012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','hunterian1701','steve.hunter@supernaturalsociety.com','Mr S Hunter','229 ludlow road<br>itchen','southampton','Hampshire','UNITED KINGDOM','so192el','07764853245','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 02:38:23',0,NULL,3,1,3,1,'RA184542955CN\r ','GLOT005 '),(18837,662395929013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','maher.alkalbani12','maher.alkalbani@hotmail.com','Maher Alkalbani','18221 150th Ave<br>Box # MCT 1330','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 03:51:55',0,NULL,3,1,1,1,'LK161975043CN ',NULL),(18838,906405675012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','adam1066','harrys443@hotmail.com','m hussain','2 green court (off green avenue)','heckmondwike','West Yorkshire','UNITED KINGDOM','wf169ld','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 03:58:58',0,NULL,3,1,3,1,'RA184543001CN\r ','WLAP008 '),(18839,818142975011,320787483241,'LG AG-F210 3D Cinema Series Glasses 2 Pack',2,'LGGL001',43.98,'eastar4','harishshah','sid_h_shah@hotmail.com','Harish Shah','35 Milady rd.','North York','ON','CANADA','M9L 2H9','(416) 744-3238 ext.: 4167443238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 05:35:27',0,NULL,3,1,3,1,'RA184542981CN ','LGGL001 \r（2 pairs in box bundle）'),(18840,773426634001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','magicgates1','magicgates@live.com.my','Ong Chong Tek','37 ,Jalan 4M ,Ampang Jaya','Ampang','Selangor','MALAYSIA','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 06:58:01',0,NULL,3,1,11,1,'BJ01601265\r ','BR3D004 '),(18841,906435930012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','22152269','bacielkoubi@gmail.com','BAT-SHEVA ELKOUBI','6 EIN GEDI ST.<br>RAMAT HASHARON','ISRAEL','','ISRAEL','47288','0548184397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 08:15:28',0,NULL,3,1,3,1,'RA184542947CN\r ','SAFI001 '),(18842,818165459011,320395390620,'Samsung Q1 Q1U Bluetooth Module 2.0 EDR+cable',1,'BTSA2005',9.88,'eastar4','maldinitq','tanq1@lopers.unk.edu','Qing Tan','2117 15th Ave<br>Apt 7','Kearney','NE','UNITED STATES','68845-0503','(308) 224-9790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 08:59:33',0,NULL,3,1,1,1,'LK168132166CN ',NULL),(18843,603591585003,130553375979,'NEW Motorola Bluetooth Stereo S705 SoundPilot headset',1,'HSMO020',28.99,'cnfaner','naorpeeri','naorrp@walla.com','naor peeri','shmuel hanatziv 35/2','natanya','','ISRAEL','42285','0509503995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 09:04:08',0,NULL,3,1,3,1,'RA184542920CN\r ','HSMO020 '),(18844,662431456013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','arsunt_odr','arsunt@mail.ru','Michael Chaban','Aviatorov st.73 fl.59','Novokuznetsk','Kemerovo region','RUSSIAN FEDERATION','654067','+79049952777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 10:06:01',0,NULL,3,1,11,1,'BJ01601274\r ','WLAP008 '),(18845,818179679011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','gadimodan','gadi.modan@gmail.com','Gadi Modan','6 Hagolan St.<br>P.O. Box: 4024','Kadima','','ISRAEL','60920','+972-(0)54-4468246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 10:21:24',0,NULL,3,1,3,1,'RA184542859CN\r ','LGAD001 '),(18846,818184363011,320735056853,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',18.99,'eastar4uk','ranjan9','kranjan@ntlworld.com','KANNUTHURAI RANJAN','268 CHADWELL HEATH LANE','ROMFORD','Essex','UNITED KINGDOM','RM6 4YL','02085973579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 10:41:56',0,NULL,3,1,3,1,'RA184546325CN\r ','OTGR006 '),(18847,662443414013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','zhiv307','dimazhiv@rambler.ru','Dmitriy Zhivoglotov','isaeva st. 2 276','Korolev','Korolev','RUSSIAN FEDERATION','141075','79150917958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 11:26:13',0,NULL,3,1,11,1,'BJ01601273\r ','WLIN014 '),(18848,662446536013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','miro_y','sales@kagami.bg','Miroslav Yonev','General Gurko 84','Varna','Varna','BULGARIA','9002','(0359)52606842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 11:50:38',0,NULL,3,1,11,1,'BJ01601286\r ','UM00042 \r接边蕾丝透明伞       '),(18849,906485276012,220908829691,'4 pairs of New 3D Active Shutter TV Glasses compatible 4 3D TV Sony  LG samsung',1,'GLOT001*4',103.99,'eastar4uk','legg1966','barbaralegg2@googlemail.com','David Legg','320 Robin Hood Lane<br>Blue Bell Hill Village','Chatham','Kent','UNITED KINGDOM','ME5 9GR','01634682030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 12:30:14',0,NULL,3,1,7,1,'EE636829042CN ','GLOT001*4 '),(18850,662452899013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','hose789blue','n_burke@bellsouth.net','Bob Burke','410 Royal Oak Dr','Paris','TN','UNITED STATES','38242-7667','(731) 642-4349','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 12:36:33',0,NULL,3,1,1,1,'LK168762343CN ',NULL),(18851,818205780011,320781439714,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',2,'HSSA004',31.98,'eastar4','toliscamaro','tolistzel@yahoo.gr','apostolos tzelepopoulos','margaritas 20','argiroupoli','athens','GREECE','16452','6936992374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 12:36:51',0,NULL,3,1,11,1,'BJ01601259\r ','HSSA004 \r欧标'),(18852,906489920012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','ianofsteel','pamelacresswell@btinternet.com','IAN MARSH','104 SHEFFIELD ROAD<br>CONISBROUGH','DONCASTER','South Yorkshire','UNITED KINGDOM','DN12 2AU','01709861043','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 12:51:19',0,NULL,3,1,3,1,'RA184542933CN\r ','SAFI001 '),(18853,906507507012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.99,'eastar4uk','greenangelnos00','leoniag@hotmail.co.uk','Leonia Green','Queen Mary\'s Hospital c/o Sodexo<br>Roehampton Lane','Roehampton','London','UNITED KINGDOM','SW15 5PN','07788597070','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 14:06:56',0,NULL,3,1,3,1,'RA184542880CN\r ','OTGR002 '),(18854,906512182012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','juansutattoo','compras@juansu.com','Juan Jesus Gonzalez','c/ Luis Morote, Num. 4','Las Palmas de G.C.','Canarias','SPAIN','35007','828021636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 14:28:19',0,NULL,3,1,11,1,'BJ01601263\r ','WLAP004 '),(18855,608968798004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','morgel88','eriksson.johan88@gmail.com','Elinor Eriksson','Fiskja 288','Kramfors','Västernorrlands län','SWEDEN','87292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 15:17:27',0,NULL,3,1,3,1,'RA184542828CN\r ','OTHP005 '),(18856,906543595012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','peerke1','peter@midro.net','Peter Roosenboom','Vluttersven 15','EINDHOVEN','','NETHERLANDS','5646HX','0402861062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 16:22:04',0,NULL,3,1,11,1,'BJ01601268\r ','BTAC2022 \racer 8pin1.00 15cm'),(18857,818261449011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',5,'CC00002',179.95,'eastar4','dmitriy110370','dmitriy.levchenko2011@yandex.ru','Dmitriy Levchenko','Atarbekova 23-24','Krasnodar','Krasnodar territory','RUSSIAN FEDERATION','350062','+7(988)24-42-900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 16:36:59',0,NULL,3,1,3,1,'RA184547269CN\r ','CC00002 \rRA184547357CN\r'),(18858,906549096012,220769088331,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',2,'GLSG001*2',243.98,'eastar4','thomasevjuk','thomasevjuk@hotmail.com','thomas kleveland','saxe viks veg 27','hundhamaren','','NORWAY','7562','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 16:37:18',0,NULL,3,1,6,1,'EE636829127CN ',NULL),(18859,818265748011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','sn0wcr4sh00','coldenlight@yahoo.com','Andrew Wong','138 Berlioz, Nuns\' Island<br>Verdun','Montreal','QC','CANADA','H3E 1K5','(514) 761-3663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 16:50:20',0,NULL,3,1,11,1,'BJ01601271\r ','HSUE003 \r带麦的'),(18860,603660021003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','twinsmasterp','yannick.jette@live.ca','Yannick Jetté','326 29e Avenue','Sainte-Marthe-Sur-Le-Lac','QC','CANADA','J0N 1P0','(514) 554-9619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 16:56:22',0,NULL,3,1,3,1,'RA184546232CN\r ','MOOE003\rOEM '),(18861,603662712003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','trueno!','ycshing2k@gmail.com','Yiu-Choy Shing','27 Flintham Drive<br>Sherwood','Nottingham','Nottinghamshire','UNITED KINGDOM','NG53DS','07776177099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 17:09:13',0,NULL,3,1,3,1,'RA184542831CN\r ','MOLO006\r送快递的人敲门能大声点'),(18862,906560447012,220705197691,'New Genuine Motorola H550 Bluetooth Wireless Headset',2,'HSMO007',15.98,'eastar4uk','rflrojas646','rflrojas@yahoo.com','Rafael Rojas','506 W 178th St<br>Apt 5C','new york','NY','UNITED STATES','10033-6562','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 17:30:05',0,NULL,3,1,1,1,'LK163926249CN ',NULL),(18863,662517181013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','erezge','erez_ge@hotmail.com','Erez Geva','Moshe Sne 33','Petach Tikva','','ISRAEL','49223','+972-52-3860417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 18:12:36',0,NULL,3,1,3,1,'RA184546042CN\r ','MOSA004 '),(18864,906582604012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','alexpogorelov','alex.pogorelov@gmail.com','Alexander Pogorelov','ul. Priborostroitelnaya<br>dom 10, kv 9','Oryol','Orlovskaya Oblast','RUSSIAN FEDERATION','302040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 18:07:26',0,NULL,3,1,11,1,'BJ01601255\r ','WLAT007 '),(18865,603680867003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','gtv1950','gtvg@uol.com.br','Gerson Vendramin','Avenida Manoel Ribas, 6519<br>Santa Felicidade','Curitiba','Parana','BRAZIL','82025-160','554188030911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 18:28:16',0,NULL,3,1,3,1,'RA184542791CN\r ','LGAD001 '),(18866,906614556012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','nosa11','nstyl@hol.gr','NIKOLAOS STILIANIDIS','LORETZU MAVILI 20','HERAKLION','KRETE','GREECE','71306','+306972303154','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 19:22:15',0,NULL,3,1,3,1,'RA184542862CN\r ','nosa11 '),(18867,607794897004,140644120563,'New Genuine Motorola H721 Bluetooth Wireless Headset+AC adapter',2,'HSMO022',45.1,'cnfaner','rjp-usa','rpye735@gmail.com','RJ Pye','4070 Conway Cir','Valdosta','GA','UNITED STATES','31605-4413','(229) 300-2691','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-25 19:23:59',0,NULL,3,1,1,1,'LK167209371CN ',NULL),(18868,603703230003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','waverunner70','richard@eroles.us','Teresa Eroles','3745 W. Valley Blvd<br>Spc 43','Walnut','CA','UNITED STATES','91789-1512','(909) 869-6056','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-25 19:53:54',0,NULL,3,1,1,1,'LK168526818CN\r ',NULL),(18869,818339693011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','music400','heavymetal@videotron.ca','Emmanuel Arseneault','66 C Ave Dubé','Montréal-Est','QC','CANADA','h1b 4x1','(514) 777-4925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 20:13:12',0,NULL,3,1,3,1,'RA184542805CN\r ','LGAD001 '),(18870,906638283012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','arlekino6561','nosovandrey@rambler.ru','Andrey Nosov','54 gen.Mehmandarov str .app 1','Baku','Ahmedli','AZERBAIJAN','AZ 1015','+994505155144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 20:26:04',0,NULL,3,1,11,1,'BJ01601287\r ','UM00008 '),(18871,764399767007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','ben_shan','bennya28@gmail.com','Benny Elikam','Veber Moshe street<br>8/33','Ashkelon','Israel','ISRAEL','78697','972526888839','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-25 20:42:30',0,NULL,3,1,11,1,'BJ01601289\r ',NULL),(18872,906647200012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',16.58,'eastar4','stefanundnicole','snbasten@t-online.de','Stefan Basten','Bielweg 9','Idar-Oberstein','','GERMANY','55743','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 20:49:04',0,NULL,3,1,11,1,'BJ01601269\r ','CASS002 \rCAB-SS-2660'),(18873,906654706012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','foremancr','carlrforeman@comcast.net','Carl Foreman','4050 Donatello Ave','North Port','FL','UNITED STATES','34286-6091','(941) 423-3025','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 21:10:11',0,NULL,3,1,1,1,'LK167641556CN ','AUI Transceiver  MX20T '),(18874,818358416011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','jessie741luke','lukec1010@hotmail.co.uk','luke clark','154 littlecroft<br>south woodham ferrers','chelmsford','Essex','UNITED KINGDOM','cm35gf','01245328811','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-25 21:11:20',0,NULL,3,1,3,1,'RA184542669CN\r ','ANCN001 '),(18875,662564823013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',8.49,'eastar4','sdicky2006','sdicky2006@gmail.com','Dicky Sean','9001 Markville Dr<br>Apt 1623','Dallas','TX','UNITED STATES','75243-9374','(214) 753-7576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 21:16:57',0,NULL,3,1,1,1,'LK168835394CN ','CAB-6060 '),(18876,818366284011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','chrisnabinger','chris.nabinger@gmail.com','Chris Nabinger','2608 2nd Ave<br># 340','Seattle','WA','UNITED STATES','98121-1212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 21:37:49',0,NULL,3,1,1,1,'LK165496388CN ','新地址\rChris Nabinger\r4322 Wallingford Ave North\rSeattle, WA 98103\rUNITED STATES\r\r'),(18877,818375031011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jwhall10','jameswh42@gmail.com','James W Hall','8408 La Paloma Ct NW','Albuquerque','NM','UNITED STATES','87120','(505) 899-4420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 22:16:10',0,NULL,3,1,1,1,'LK166877771CN ',NULL),(18878,603736420003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','thepredator55','mikebishop3@cox.net','Mike Bishop','9644 Comiskey Ct','Las Vegas','Nv','UNITED STATES','89148-4604','(702) 595-5047','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-25 22:42:53',0,NULL,3,1,1,1,'LK167489708CN ',NULL),(18879,906683220012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','sm4474','nevadasol@hotmail.com','John Lewis','280 Wagon Wheel Way','Dayton','NV','UNITED STATES','89403-9766','(775) 230-8139','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 22:49:25',0,NULL,3,1,1,1,'LK169170917CN ',NULL),(18880,756549641008,180741215278,'2 pair 3D TV Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*2',87.99,'au-buy','pobeda1004','harley.harley2012@yandex.ru','Ирина Харламова','улица Кольцевая<br>д. 48 \"А\" кв. 48','Магадан','Магаданская область','RUSSIAN FEDERATION','685000','964-459-65-77','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-25 23:08:53',0,NULL,3,1,3,1,'RA184546135CN\r ','GLOT001*2 '),(18881,817557881002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','wes_tn_band','ihear_u2@yahoo.com','Tony Valdes','32 Grace Cv','Jackson','TN','UNITED STATES','38305-4701','(731) 554-2023','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 23:18:47',0,NULL,3,1,1,1,'LK168244145CN ',NULL),(18882,818390665011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','mpa61','mickpacker@gmail.com','Mick Packer','9 Bonus Court','Werribee','Victoria','AUSTRALIA','3030','0421288900','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 23:17:27',0,NULL,3,1,11,1,'BJ01601264\r ','RELO003 '),(18883,662592163013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','soonersurburban','realsooner4life@aol.com','Harold L Holman','13875 Ella blvd #1508','Houston','tx','UNITED STATES','77014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 23:47:45',0,NULL,3,1,1,1,'LK168512345CN ',NULL),(18884,764451752007,170728921205,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'au-buy','knubbers24','knubbers@msn.com','Ryan Van Riper','107 Victory Ln','BELTON','SC','UNITED STATES','29627','(732) 688-8813','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-25 23:50:24',0,NULL,3,1,1,1,'LK168985782CN ',NULL),(18885,906699233012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',42.05,'eastar4','plkm141','zahidyasin1@yahoo.co.uk','zahid yasin','73 holland road, east ham','london','London','UNITED KINGDOM','E62EP','02085523102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 00:04:45',0,NULL,3,1,3,1,'RA184546303CN\r ','CASS002 +CASS003\r两条CAB-SS-2660\r三条CAB-6060'),(18886,818402379011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','arsarm2010','arsarm@mail.ru','Arsen Sargsyan','Bagratunyats 10 street 40 apt.','Yerevan','AK','ARMENIA','0039','37493555559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 00:11:50',0,NULL,3,1,3,1,'RA184546215CN\r ','GPS0007 '),(18887,817568695002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','smholman299','shelley3369@gmail.com','Shelley Holman','135 GROVE ST','Putnam','CT','UNITED STATES','06260-2124','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 00:13:03',0,NULL,3,1,1,1,'LK168168951CN ',NULL),(18888,818418272011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',2,'HSNO003',47.8,'eastar4','yaslamtaher','yaslamhaimed@yahoo.com','yaslam taher','960 N Van Ness Ave','fresno','CA','UNITED STATES','93728-3428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 01:37:16',0,NULL,3,1,1,1,'LK161120282CN ',NULL),(18889,8881324863540313,111,'New Atheros AR5B195 Wireless + Bluetooth Half Mini PCI-E Card',1,'WLIN016	',20.99,'aliexpress','1005970384','frank@sarnstrom.se','Frank Sarnstrom','Vangavagen 5 ','Laholm','Sweden','SWEDEN','31297','+0046 708 532563',NULL,NULL,NULL,'2011-12-26 01:39:00',0,NULL,3,1,3,1,'RA184546201CN\r ','WLIN016 '),(18890,8881324864240996,111,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card - ',1,'WLIN015',14.99,'aliexpress','1005962245','hermes@netvision.com.br','hermes hilbert junior','rua indaial 914 ','joinville','santa catarina','BRAZIL','89221-400','+55 47 34252798',NULL,NULL,NULL,'2011-12-26 01:50:40',0,NULL,3,1,3,1,'RA184546175CN\r ','WLIN015 '),(18891,662610361013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','akinimod_86','dominika.malinowski@gmail.com','Dominika Malinowski','1 Francis Street','Dandenong','Victoria','AUSTRALIA','3175','0397131209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 01:54:40',0,NULL,3,1,11,1,'BJ01601252\r ','UM00013 \r草莓伞 '),(18892,662616717013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','joshuadon1992','scienceandorigins@hotmail.com','Joshua Donaldson','8 Josephine St','Ulverstone','Tasmania','AUSTRALIA','7315','0364252998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 02:37:10',0,NULL,3,1,6,1,'EE636829113CN ',NULL),(18893,8881324869311996,111,'Brand NIB 2011 Korea LG 3D Cinema TV Glasses Family Pack AG-F214',1,'LGGL004',33.99,'aliexpress','1005871705','wafing@hotmail.com','William Araujo de Freitas	','Rua 111, n 141, Conjunto Esperanca','Fortaleza','Ceara','BRAZIL','60763600','+55 85 32962001',NULL,NULL,NULL,'2011-12-26 03:15:11',0,NULL,3,1,3,1,'RA184546317CN\r ','LGGL004 \r（新地址）\rwaf chico pezao\rrua 111, nº 141, conjunto esperança\rfortaleza  - ceara\r60763600\rBrazil\r+55 85 32962001'),(18894,818445854011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',57,'eastar4','tgoo8536','tashannagoodwin@gmail.com','Rashaun Thomas','3062 South Wood Avenue<br>Suite 1','Linden','NJ','UNITED STATES','07036','(908) 862-1013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 04:01:11',0,NULL,3,1,1,1,'LK168702251CN\r ',NULL),(18895,8881324874626403,111,'Logitech RF Wireless Extender for Harmony 890 Pro 1000',1,'RCLO007',18.8,'eastar4uk','andyleungkaon','andyleungkaon@netvigator.com','Leung Ka On Andy','2407 Ming Yan House, Ming Ngar Court, Tai Po','hong kong','','CHINA','','',NULL,NULL,NULL,'2011-12-26 04:43:46',0,NULL,3,1,14,1,'301208196983','RCLO007 \r可以发货了，发拿过去拍照的那一个\r中文地址和电话：\r香港大埔明雅苑, 明欣閣, 24樓7號.\r\r流動電話: 9196 2392\r\r\r'),(18896,818455374011,320766059071,'New la petty a loup Ultra light w/Carbon Fiber ribs 3-Section Umbrella',1,'UM00037',21.99,'eastar4','metallichouse','vbrothers@gmail.com','Vanessa Brothers','115 E 9th St<br>Apt 2F','New York','NY','UNITED STATES','10003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 05:05:39',0,NULL,3,1,1,1,'LK166944860CN\r ',NULL),(18897,818458109011,320730088537,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',2.99,'eastar4uk','stef0470','stef-@arcor.de','Meusinger Stefan','Bizetstr. 95','Berlin','','GERMANY','13088','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 05:28:17',0,NULL,3,1,11,1,'BJ01601282\r ','ANTY002 '),(18898,756621888008,180699062138,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',45,'au-buy','kundababy','brayleyg@tpg.com.au','Greg Brayley','210 Rodeo Drive','Kundabung','New South Wales','AUSTRALIA','2441','0265615204','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 05:43:46',0,NULL,3,1,3,1,'RA184546192CN\r ','OTPL001 '),(18899,756625376008,180761130667,'New Sharp AN-3DG20-B 3D USB Rechargeable Glasses+2nose pad USB cable case cloth',2,'SPGL001',238,'au-buy','plouffer905','wayne_plouffe@hotmail.com','Wayne Plouffe','181 east 12th street','hamilton','ON','CANADA','l9A3X5','(905) 385-5692','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 06:14:15',0,NULL,3,1,3,1,'RA184549596CN\r ','SPGL001 '),(18900,662645669013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','zmrleealex','izmirleealex@hotmail.com','Emre Akoglu','kılınc is merkezi kat:2 no:226<br>urla','Izmir','IL','TURKEY','35430','+905553439101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 06:50:33',0,NULL,3,1,3,1,'RA184546025CN\r ','OTES001 '),(18901,906780748012,220917856643,'2 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',105.99,'eastar4','purple_butterfly_kisses','melly_conroy@mac.com','Melita Conroy','38 Taunton Street','Carseldine','Queensland','AUSTRALIA','4034','61407635482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 07:33:47',0,NULL,3,1,3,1,'RA184546011CN\r ','LGGL002*2 '),(18902,906781800012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','lethal_weapon3','lindsay_yates12@yahoo.com.au','Lindsay Yates','38 Clegg Road<br>Mount Evelyn','Melbourne','Victoria','AUSTRALIA','3796','0397364056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 07:38:59',0,NULL,3,1,11,1,'BJ01601285\r ','WLIN016 '),(19060,604271253003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','boliver38','boliver@billoliver.me','William Oliver','95 Horatio St<br>Apt 10B','New York','NY','UNITED STATES','10014-1552','(212) 767-9043','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-28 02:54:50',0,NULL,3,1,1,1,'LK169782959CN\r ',NULL),(18903,906780441012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','rerb250960','rerb@optusnet.com.au','Robert Erb','20 Dwyer Street','Cook','Australian Capital Territory','AUSTRALIA','2614','0262514942','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 07:57:23',0,NULL,3,1,3,1,'RA184546453CN\r ','GLOT001 '),(18904,603800310003,130498755181,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',8.89,'cnfaner','251shay','skt@017.net.il','shay  tamam','tel nof','gedera','israel','ISRAEL','70710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 08:11:16',0,NULL,3,1,3,1,'RA184546365CN\r ','POLO001 '),(18905,603802581003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','jordanseveryday','juicebiscuits@gmail.com','JC Beck','9031 Quarry Stone Way','Sandy','UT','UNITED STATES','84094-7708','(801) 440-5727','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-26 08:35:32',0,NULL,3,1,1,1,'LK164870767CN\r ','OEM '),(18906,755803035008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.99,'au-buy','thirdgearau','sales@thirdgear.com.au','Adrian Larocque','Third Gear<br>4 Eames Ave','Brooklyn','Victoria','AUSTRALIA','3012','0411567386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 08:45:31',0,NULL,3,1,11,1,'\\ ','SHLO009 \rblack ver1'),(18907,817648567002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','sydney4sandy','sandytherapy@verizon.net','Sandra Morrison','118 Pine St<br>lower level','Cliffside Park','NJ','UNITED STATES','07010','(201) 282-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 08:51:16',0,NULL,3,1,1,1,'LK166340237CN\r ',NULL),(18908,818483411011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',3,'HSJA002',59.97,'eastar4','ingenieur_boeblingen','andreas.heintze@o2online.de','Andreas Heintze','Schwabstraße 10','Böblingen','','GERMANY','71032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 08:51:19',0,NULL,3,1,3,1,'RA184546382CN\r ','HSJA002 \r欧标'),(18909,756649682008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','sergey.ka','sklator@gmail.com','Sergey Katznelson','Shivta 21','Dimona','','ISRAEL','86097','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 09:27:21',0,NULL,3,1,11,1,'\\ ','RELO001 '),(18910,818493152011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',32.99,'eastar4uk','johnaurore','johnthiry@msn.com','Jonathan Thiry','3 avenue du clos bertin','l\'épine','Champagne-Ardenne','FRANCE','51 460','0326698245','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 09:46:24',0,NULL,3,1,3,1,'RA184549619CN\r ','LGGL002 '),(18911,906803700012,220704730352,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET',1,'HSPL005',9.19,'eastar4uk','maxior1972','maxi41@wp.pl','Mariusz Jonca','Cumberland Avenue 16<br>Intake','Doncaster','Yorkshire','UNITED KINGDOM','dn2 6lu','07872907715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 09:47:49',0,NULL,3,1,3,1,'RA184546688CN\r ','HSPL005\r英标 '),(18912,818494150011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','vocalmail','charles@thewainers.com','Charles Wainer','12405 NE 6TH AVE','NORTH MIAMI','FL','UNITED STATES','33161','(305) 892-7377','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 09:52:33',0,NULL,3,1,3,1,'RA184546855CN\r ','新地址\rCharles Wainer\rNer Halayla 17-A\rRamat Poleg, Netanya 42209\rISRAEL\r'),(18913,818500356011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',81.98,'eastar4uk','alverpor','aliceverdon@yahoo.es','ALICE VERDON','PESCADORS-1, 3','CASTELLDEFELS','Barcelona','SPAIN','08860','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 10:22:39',0,NULL,3,1,3,1,'RA184549429CN\r ','GLSG001 '),(18914,603816649003,130620867283,'New Philips SHB6102 Bluetooth Stereo Headset',1,'HSPH001',72.89,'cnfaner','colincleck','ceb2@uk2.net','Eclectic Energy Ltd.','Unit 22 Sherwood Networkcentre<br>Sherwood Energy Village, Newton Hill','Ollerton','Nottinghamshire','UNITED KINGDOM','NG22 9FD','01623835400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 10:28:00',0,NULL,5,1,18,0,NULL,'HSPH001 \r英标'),(18915,8881324897403455,111,'New GENUINE Plantronics Explorer 320 BLUETOOTH HEADSET',1,'HSPL002',0,'au-buy','kyawsannlwin09','kyawsannlwin@gmail.com','Kyaw Lwin','13 Bush Close<br>Beckenham','Perth','Western Australia','AUSTRALIA','6107','61423402716',NULL,NULL,NULL,'2011-12-26 11:03:23',0,NULL,3,1,3,1,'RA184546728CN\r ','HSPL002 \r补发 挑最好的'),(18916,764561175007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','bonhamsdink','spencer.loh@mail.mcgill.ca','Spencer Loh','1168 West 42nd Ave','Vancouver','BC','CANADA','V6M 2A8','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 11:21:33',0,NULL,5,0,18,0,NULL,'客户想7天到达 '),(18917,603826783003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','dseltenrijch','donseltenrijch@xs4all.nl','Don Seltenrijch','Pascalweg 8a','Spijkenisse','','NETHERLANDS','3208 KL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 11:38:39',0,NULL,3,1,3,1,'RA184546895CN\r ','RCLO007 '),(18918,609153330004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','cmywings','cmywings50@yahoo.com','Jeff Conner','3706 Brophy Blvd','Cocoa','FL','UNITED STATES','32926-4005','(321) 636-7106','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-26 11:45:38',0,NULL,3,1,1,1,'LK169157014CN\r ',NULL),(18919,662684635013,230720746376,'Apple PowerBook G4 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','andycoco','coco2872@aol.com','andrew cole','16 cayley way,kings tamerton','plymouth','Devon','UNITED KINGDOM','pl5 2ua','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 12:11:58',0,NULL,3,1,11,1,'\\ ','WLAP002 \r二代卡 旧'),(18920,906838957012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','corrine456','tekfloor@hotmail.com','TERRY  Kane','1 Avery Court, Narre Warren','Melbourne','Victoria','AUSTRALIA','3805','0387901456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 12:19:22',0,NULL,3,1,3,1,'RA184549477CN\r\r ','GLSG009 '),(18921,603836164003,130620867962,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube upload',1,'PHVE001',34.99,'cnfaner','ze.bbra','corneliu.nechifor@yahoo.com','Nechifor Corneliu Bogdan','Valea Ialomitei 7<br>Bl.D20 Sc.F Ap. 54 Sect.6','Bucharest','Romania','ROMANIA','061962','+40726013000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 12:44:18',0,NULL,3,1,3,1,'RA184549358CN\r ','PHVE001 '),(18922,662404280013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','serragli11','guliano11@gmail.com','Guliano Serragli','74 Canopus Drive','Doncaster East','Victoria','AUSTRALIA','3109','0398427791','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 13:27:02',0,NULL,3,1,3,1,'RA184546847CN\r ','GLOT001*2 '),(18923,764596005007,170739867756,'ew Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'au-buy','xwhale1978','xwhale@gmail.com','Victor Chuchupal','16/2-309, Belorusskaya st.','St.-Petersburg','Russia','RUSSIAN FEDERATION','195298','+7-911-9993616','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 14:00:05',0,NULL,3,1,11,1,'\\ ','WLIN014 '),(18924,662704031013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',2,'HSNO016',27.88,'eastar4','yourgen_russia','yourgen@mail.ru','Yury Maslennikov','K. Marksa 14-34','Nevyansk','Sverdlovskaya oblast','RUSSIAN FEDERATION','624190','+7 9022543131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 14:12:59',0,NULL,3,1,11,1,'\\ ','HSNO016\r欧标 '),(18925,818551823011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','murilo.pinh','murilopinh@yahoo.com.br','Murilo do Rosario Pinheiro','Rua Poeta Faria Junior 19<br>Parque Nova Brasilia','Campos dos Goytacazes','Rio de Janeiro','BRAZIL','28055260','(55)2227315060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 14:14:47',0,NULL,3,1,3,1,'RA184546904CN\r ','GPS0007 '),(18926,818553242011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','tivrick','tivrick@googlemail.com','Rick Turner','40 Ratcliff Lawns<br>Southam','Cheltenham','Gloucestershire','UNITED KINGDOM','GL52 3NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 14:18:01',0,NULL,3,1,3,1,'RA184546705CN\r ','MOAP001 '),(18927,609177757004,140644120563,'New Genuine Motorola H721 Bluetooth Wireless Headset+AC adapter',3,'HSMO022',67.65,'cnfaner','wajsman26','wajsman@skynet.be','Wajsman Isaac','Helenalei 22','Antwerpen','','BELGIUM','2018','0477353512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 14:23:45',0,NULL,3,1,3,1,'RA184549548CN\r ','HSMO022 \r欧标'),(18928,906871807012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','madisonmoonshine','nicnacnic@btinternet.com','Nicola-Jane Wilson','25 Ferguson Avenue','Prestwick','South Ayrshire','UNITED KINGDOM','KA182JB','07979796764','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 14:26:29',0,NULL,3,1,11,1,'BJ01670228\r ','UM00006 \r蕾丝蝴蝶结伞 黑色'),(18929,818556936011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','kesgreen','kes.green@ntlworld.com','Kes Green','14<br>Sterry Drive','Ewell','Surrey','UNITED KINGDOM','KT19 0TG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 14:35:38',0,NULL,3,1,3,1,'RA184546759CN\r ','WLIN010+ANTY002 '),(18930,756719299008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','castrange56','candersons@aol.com','Cheryl Strange','6308 N Capitol St NW','Washington','DC','UNITED STATES','20011-1410','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 14:53:36',0,NULL,3,1,1,1,'LK166357042CN\r ',NULL),(18931,609193346004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',54.7,'cnfaner','bendenoz','benjamin@denoziere.nu','Benjamin Denoziere','PHILEOG - Bat 264<br>45 avenue Victor Hugo','Aubervilliers','Ile-de-France','FRANCE','93300','0660284466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 15:54:08',0,NULL,3,1,3,1,'RA184546762CN\r ','GLOT005 '),(18932,906900578012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','simon-future','simon-future@talk21.com','Simon Heaps','Future Display Ltd<br>Unit B8 Winchester Av','Blaby','LEICESTER, ENGLAND','UNITED KINGDOM','LE8 4GZ','01162778808','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 15:57:55',0,NULL,3,1,3,1,'RA184546714CN ','OTSO004*3 '),(18933,818584223011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','chad6666','gpchad@gmail.com','Graham Chadwick','Symetrica<br>Phi House, Enterprise Road','Southampton','Hampshire','UNITED KINGDOM','SO16 7NS','07968034890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 16:09:59',0,NULL,3,1,3,1,'RA184546665CN\r ','RELO003 '),(18934,818592405011,320742961625,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube',1,'PHVE001',35.99,'eastar4','ze.bbra','corneliu.nechifor@yahoo.com','Nechifor Corneliu Bogdan','Valea Ialomitei 7<br>Bl.D20 Sc.F Ap. 54 Sect.6','Bucharest','Romania','ROMANIA','061962','+40726013000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 16:36:03',0,NULL,3,1,11,1,'BJ01670201\r ','PHVE001 '),(18935,818593385011,320742963659,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube',1,'PHVE001',21.99,'eastar4uk','ze.bbra','corneliu.nechifor@yahoo.com','Nechifor Corneliu Bogdan','Valea Ialomitei 7<br>Bl.D20 Sc.F Ap. 54 Sect.6','Bucharest','Romania','ROMANIA','061962','+40726013000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 16:39:49',0,NULL,3,1,11,1,'BJ01601330\r\r ','PHVE001 '),(18936,818595106011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','jgiord111','jgiord@verizon.net','jeffrey giordano','927 2ND Street Pike','Southampton','PA','UNITED STATES','18966-3952','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 16:45:11',0,NULL,3,1,1,1,'LK170145367CN\r ',NULL),(18937,818609436011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','ebm_kramer','krille74@gmail.com','Kristian Reskow','Elektrongatan 2G','Västra Frölunda','Västra Götaland','SWEDEN','421 33','+46734444320','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-12-26 17:24:25',0,NULL,3,1,11,1,'\\ ','HSNO019\r欧标 ');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (18938,906934089012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','davewturner','dave.turner@live.com','Johnny Turner','1840 N Sheridan St','Wichita','KS','UNITED STATES','67203-1456','(316) 640-6477','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 17:27:56',0,NULL,3,1,1,1,'LK169760145CN\r ','acer 6pin1.25 23cm  '),(18939,818611302011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','rodsato2011','rod.sato@yahoo.com.br','Rodrigo Sato','Avenida Miguel Damha 2001<br>Damha 3 - Qd9 Lt19','São José do Rio Preto','São Paulo','BRAZIL','15061-800','551732244941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 17:38:01',0,NULL,3,1,3,1,'RA184546674CN ','LGRM001 '),(18940,603806464003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','apada','apada@comcast.net','Nick Konstanti','11 Bruce Ave','San Francisco','CA','UNITED STATES','94112-2321','(650) 800-1234','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-26 17:25:16',0,NULL,3,1,1,1,'LK166171564CN\r ',NULL),(18941,903026140012,220888924452,'New genuine Nokia LD-3W Bluetooth GPS wireless Module',1,'OTCR001',27.68,'eastar4','olegzvyagin','danone_zvyagin@mail.ru','Oleg Zvyagin','Оренбург. пр. Победы 162 кв. 65<br>Оренбург. пр. Победы 162 кв. 65','Orenburg','Оренбургская обл','RUSSIAN FEDERATION','460048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 19:00:41',0,NULL,5,1,18,0,NULL,'OTCR001 \r由于没货了  需要给客户退款  撤单   已退款'),(18942,818647643011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','trebor_elbon','robert.noble@me.com','Robert J Noble','2 Queen Street<br>Wordsley','Stourbridge','West Midlands','UNITED KINGDOM','DY8 5QW','07709575976','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 19:02:03',0,NULL,3,1,3,1,'RA184549313CN\r ','UDAP001 '),(18943,603433510003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','martin20023','marcink@emagserwis.pl','Marcin Kołodziejczyk','Al. Bielska<br>135/16','Tychy','śląskie','POLAND','43100','509 804246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 19:16:27',0,NULL,3,1,3,1,'RA184546780CN ','MOOE003\rOEM '),(18944,817816766002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','homero001green','intrepid007_1@msn.com','Adrian Castillo','2352 Bagdad Ave','Orlando','FL','UNITED STATES','32833-3813','(321) 804-7033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 19:28:38',0,NULL,3,1,1,1,'LK168624996CN\r ',NULL),(18945,906992375012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','imi316','imranmansha@hotmail.com','imran mansha','191 Leicester Causeway','Coventry','West Midlands','UNITED KINGDOM','CV14HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 19:37:10',0,NULL,3,1,3,1,'RA184546691CN\r ','SAFI001 '),(18946,906988754012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',3,'CASS002',24.87,'eastar4','zielonasi1','maluch74@hotmail.com','Slawomir Dabrowski','300 N Elizabeth St<br>Ste 510C','Chicago','IL','UNITED STATES','60607-1142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 19:28:38',0,NULL,3,1,1,1,'LK169843984CN\r ','CAB-SS-2660 '),(18947,906997026012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','carmelvalleygirl','s_tescher@hotmail.com','Susan L. Tescher','6310 Brookdale Dr','Carmel','CA','UNITED STATES','93923','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 19:47:42',0,NULL,3,1,1,1,'LK169104780CN\r ',NULL),(18948,608954297004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','pjrampolla','pedro.j.rampolla@gmail.com','Pedro J Rampolla','918 Crowell Ranch Rd','Cheyenne','WY','UNITED STATES','82007-9674','(307) 635-8475','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-26 19:48:49',0,NULL,3,1,1,1,'LK167060423CN\r ',NULL),(18949,907000623012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','microlet','keith.holliday@ntlworld.com','Keith C Holliday','12 Merrow Chase','Guildford','Surrey','UNITED KINGDOM','GU1 2RY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 19:55:27',0,NULL,3,1,3,1,'RA184546745CN\r ','HBPH007 '),(18950,603750590003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','luperella','shopmkwithme@yahoo.com','lupe tabar','7001 Sunne Ln<br>Apt 502','Walnut Creek','CA','UNITED STATES','94597-3618','(925) 400-3328','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-26 20:02:04',0,NULL,3,1,1,1,'LK168895472CN\r ',''),(18951,662792335013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','aarose863','arose863@hotmail.com','Amy Rosen','420 Shore Rd<br>Apt 3F','Long Beach','NY','UNITED STATES','11561-5307','(516) 889-1044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 20:03:19',0,NULL,3,1,1,1,'LK168636393CN\r ',NULL),(18952,907011945012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','nealharker','nbharker@shaw.ca','Neal Harker','255 Shawcliffe Circle SW','Calgary','AB','CANADA','T2Y 1E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 20:22:47',0,NULL,3,1,3,1,'RA184546820CN\r ','GLOT001*2 '),(18953,818682692011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','cincija','jallenson@cinci.rr.com','John Allenson','7 Grandin Ter','Cincinnati','OH','UNITED STATES','45208-3405','(513) 321-0775','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 20:29:56',0,NULL,3,1,1,1,'LK169314205CN\r ',NULL),(18954,818685539011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','sandfuehr','stefan@sandfuehr.de','Stefan Sandführ','Ruinenstr. 8','Dortmund','','GERMANY','44287','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 20:34:54',0,NULL,3,1,11,1,'\\ ','ANCN001 '),(18955,817850845002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','mtnbkr2000','swu5966@gmail.com','Steve Wu','917 Woods Dr.','Ypsilanti','MI','UNITED STATES','48197','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 20:59:37',0,NULL,3,1,1,1,'LK169521560CN\r ',NULL),(18956,818694332011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','granny-x-pack','c2lkr@aol.com','lisa rice','4 berkeley lane','canvey island','essex','UNITED KINGDOM','ss8 0bt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 21:03:05',0,NULL,3,1,3,1,'RA184549605CN\r ','GLSG001 '),(18957,818698161011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'eastar4','erezk9','el11695@walla.com','Erez Keinan','Ha\'Kuzari 3','Rishon Le-zion','','ISRAEL','75326','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 21:11:15',0,NULL,3,1,11,1,'\\ ','HSNO003 '),(18958,603959723003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','alhub2','alexandrehubert42@hotmail.com','Alexandre Hubert','8160 Louisbourg apt#4','Brossard','QC','CANADA','J4Y0H6','(438) 869-5251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 22:10:10',0,NULL,3,1,3,1,'RA184546793CN ','MOOE003\rOEM '),(18959,817875221002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','beasterejtc','ejthomasco@aol.com','Randy Bradberry','4383 Back Trail Ct','Liberty Twp','OH','UNITED STATES','45011-7339','(513) 383-0258','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 22:12:03',0,NULL,3,1,1,1,'LK168374091CN\r ',NULL),(18960,818724027011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',4,'GLOT001',107.96,'eastar4uk','kjellua666','kjellua_666@hotmail.com','Kjell-Åke Lormén','Töringe 418','Falkenberg','Halland','SWEDEN','31195','0708369534','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 22:30:58',0,NULL,3,1,3,1,'RA184549335CN\r','GLOT001 '),(18961,907062931012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',79.99,'eastar4uk','craig489','strandy2007@sky.com','craig strand','41 east lancshire road<br>swinton','manchester','Greater Manchester','UNITED KINGDOM','m27 5ly','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 22:38:38',0,NULL,3,1,3,1,'RA184549415CN\r ','GLSG001*2 '),(18962,603969706003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','samwan1','samwan13@free.fr','Cyril Benabderrahmane','31 Bd Maire','Marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13008','04-91-73-48-85','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 22:45:07',0,NULL,3,1,3,1,'RA184546612CN ','MOOE002\rOEM '),(18963,756680576008,180755522339,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'au-buy','hows.your.father','srbartlett@ozemail.com.au','Stephen Bartlett','25 Peate Avenue','Glen Iris','Victoria','AUSTRALIA','3146','0424104264','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 22:47:18',0,NULL,3,1,11,1,'\\ ','HBPH009 '),(18964,907073498012,220769088331,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',1,'GLSG001*2',121.99,'eastar4','lazydoodo','jondegooyer@hotmail.com','jon degooyer','825 brooks ave','venice','CA','UNITED STATES','90291-3426','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 23:09:57',0,NULL,3,1,1,1,'LK169741818CN\r ',NULL),(18965,662840877013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','sharanvlad','vlad.sharanhovich@gmail.com','Uladzislau Sharanhovich','3628 Warner Dr','San Jose','CA','UNITED STATES','95127-4440','(408) 480-7493','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 23:25:17',0,NULL,3,1,1,1,'LK169203884CN\r ',' acer 5pin1.25 20cm '),(18966,609301648004,140651314802,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses+2 nose pad +USB cable',1,'SPGL001',118,'cnfaner','rogdug','rogerdugre@cgocable.ca','Roger Dugré','3015 95 ieme rue','Shawinigan','QC','CANADA','G9N 8A2','(819) 731-0216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 23:27:13',0,NULL,3,1,3,1,'RA184549225CN\r ','SPGL001 '),(18967,907088750012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','jenben0_5','jenny_burnell@hotmail.com','Jennifer Burnell','1 Stillorgan Grove<br>Stillorgan','Blackrock','Co Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 00:05:46',0,NULL,3,1,3,1,'RA184549018CN\r ','HBPH003 \r英标'),(18968,818755688011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','lvnvrgnia','djohnson76@cox.net','Dianna Johnson','29 Allison Sutton Dr','Hampton','VA','UNITED STATES','23669-4673','(757) 723-5181','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 00:26:10',0,NULL,3,1,1,1,'LK168810769CN\r ',NULL),(18969,764807938007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'au-buy','flying_superman','flying_superman@hotmail.com','Nasir Ghiasi','1811-390 Dixon Road','Etobicoke','ON','CANADA','M9R1T4','(416) 276-2616','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-27 00:54:56',0,NULL,3,1,11,1,'\\ ','HSUE003 '),(18970,603997674003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','dspchia','mark.chiacchiari.wh98@wharton.upenn.edu','Mark Chiacchiari','16135 Wake Robin Dr','Newbury','OH','UNITED STATES','44065-9161','(440) 564-5233','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 01:28:46',0,NULL,3,1,1,1,'LK169071137CN\r ',NULL),(18971,603388112003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',40.8,'cnfaner','bestbuykg2','bestbuykg3@gmail.com','ACI #9828','17252 S Main St<br>Aci Express La Br','Gardena','CA','UNITED STATES','90248-3101','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 01:34:19',0,NULL,3,1,1,1,'LK166046535CN\r ','地址中加入号码\r(562) 304 2593\r '),(18972,907114818012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','ds.carvalho','dsc068@gmail.com','Daniel Carvalho','Rua Colina, 71, Apt. 102 - Jardim Guanabara','Rio de Janeiro','Rio de Janeiro','BRAZIL','21931-380','552187060007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 01:37:23',0,NULL,3,1,3,1,'RA184546802CN\r ','OTPL001 '),(18973,907115466012,220816384329,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',26.99,'eastar4uk','adder_is_black','black69@tpg.com.au','Paul Taylor','17  Currajong  Ave','Mount Evelyn','Victoria','AUSTRALIA','3796','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 01:40:39',0,NULL,3,1,3,1,'RA184546816CN\r ','GLOT001 '),(18974,662869672013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','123lancelot','lancelot.iphone@yahoo.com','BACHIRI-BORIE Lancelot','10 rue de L\'ARCHEVECHE<br>( DIGICODE= 1831 ) - Bat B - 1er Etage - Porte Droite','CHARENTON','Ile-de-France','FRANCE','94220','0633969412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 01:56:15',0,NULL,3,1,11,1,'\\ ','WLAT008 '),(18975,756923847008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.99,'au-buy','viper66viper66','tdu_85@hotmail.com','Troy Urquhart','3 Joyce crt<br>Wellington Point','Brisbane','Queensland','AUSTRALIA','4160','0433090550','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-27 01:59:53',0,NULL,3,1,11,1,'BJ01601312\r ','SHLO009 \rblack ver1'),(18976,818778371011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','nicebnice','rngnice@gmail.com','Robert Nice','12405 Mount Olive Cohoke Rd','West Point','VA','UNITED STATES','23181-3320','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 02:02:44',0,NULL,3,1,1,1,'LK170078574CN\r ',' HP 8pin 1.25 18cm'),(18977,818779387011,320786773657,'New Genuine Motorola H670 Bluetooth Wireless Headset',1,'HSMO010',9.99,'eastar4uk','ge2469','garyedwards2469@yahoo.com.au','Gary EDWARDS','20 Allinga Close','BENTLEY PARK','Queensland','AUSTRALIA','4869','0740456369','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 02:11:43',0,NULL,3,1,11,1,'BJ01601314\r ','HSMO010\r澳标 '),(18978,604005970003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',2,'HSPL005',25.98,'cnfaner','cklinvestmentsco','cklinvestments@att.net','JOHN LE','1018 OAK HILL PARK','KENNEDALE','TX','UNITED STATES','76060-5619','(817) 673-3014','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 02:16:38',0,NULL,3,1,1,1,'LK168016165CN\r ',NULL),(18979,818784467011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','cawesterman','cawesterman@hotmail.com','Amy Westerman','60 Woodridge Pl','Newnan','GA','UNITED STATES','30265-1284','(770) 253-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 02:30:41',0,NULL,3,1,1,1,'LK168273827CN\r ',NULL),(18980,818781723011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','mr_seductive','markv7773@hotmail.com','Mark VanLiew','521 Garfield Ave','Jersey City','NJ','UNITED STATES','07305','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 02:55:44',0,NULL,3,1,1,1,'LK169218932CN\r ',NULL),(18981,609336551004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','ar4409472j','adityaredd@gmail.com','Aditya R. Reddy','4409 N Landmark Dr','Orlando','FL','UNITED STATES','32817-1234','(407) 657-0888','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 03:05:47',0,NULL,3,1,1,1,'LK160105814CN\r ',NULL),(19073,907601868012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','luvwyf','kckchai@gmail.com','Ching Kiong Chai','1/5  Camelia Street<br>Box Hill','Melbourne','Victoria','AUSTRALIA','3128','0398974347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 06:25:40',0,NULL,3,1,11,1,'BJ01670225\r ','OTGR001 '),(18982,662889875013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'eastar4','nalrarius','birumpak@gmail.com','HwanChun Yeo','711-1402 Sambu Apt. Hanul Maul 7 DanJi<br>DongPae Dong','Paju','Gyunggi','KOREA,REPUBLIC OF','413-100','82-10-4938-3719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 03:48:53',0,NULL,3,1,11,1,'BJ01670234\r ','WLIN014 '),(18983,818804422011,320753523732,'NIB Genuine Samsung SSG-2100AB 3D glasses + Blu-ruy ICE AGE 3 disc',1,'GLSG001*2+BR3D006',131.99,'eastar4','lan_michel','lan_michel@hotmail.com','Michel Langlois','788 rue des Draveurs','Saguenay','QC','CANADA','G7J5A3','(418) 820-7365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 04:04:27',0,NULL,3,1,3,1,'RA184549432CN\r ','GLSG001*2+BR3D006 '),(18984,907159924012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','kev-wa','kevin.bloch.wa@gmail.com','Kevin Bloch','31 Avignon Way<br>Beechboro','Perth','Western Australia','AUSTRALIA','6063','0413177765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 04:45:53',0,NULL,3,1,11,1,'BJ01670239\r ','TRMX003\rAUI Transceiver  MX20T '),(18985,8881324961628922,111,'sony Ericsson HBH-DS220  ',1,'HSSE006',66,'eastar4','Transerve Technologies Corporation ','Transerve Orders<order@transerve.com.ph>','Ms. Agnes Wong','Flat D, 7th Flr., Bold Win Ind. Bldg.16-18 Wah Sing St.','Kwai Chung ','N.T. HK','HONG KONG','','852-2424-6635',NULL,NULL,NULL,'2011-12-27 04:53:48',0,NULL,3,1,14,1,'301243540606 ','HSSE006 \r索爱 HBH-DS220 \r客户直接打款'),(18986,907163190012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',39.84,'eastar4','rasp_e','raspe81@gmail.com','Евгений Зацепилов','Ногинское шоссе д. 10 кв. 109','Электросталь','Московская область','RUSSIAN FEDERATION','144005','+79261549182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 05:11:15',0,NULL,3,1,11,1,'\\ ','RMSN002+OTHP004\r再发一个New HP MCE Media Center Remote Control big+ IR RECEVE\r '),(18987,818817900011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','beebloke','steve.sheridan2@gmail.com','steve  sheridan','60a northbranch rd','lorne','New South Wales','AUSTRALIA','2439','0265594587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 05:22:59',0,NULL,3,1,3,1,'RA184549097CN\r ','LGRM001 '),(18988,818820601011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','charlesleong2011','chleong70@yahoo.com.sg','Charles Leong','P.O. Box 18A,<br>Kapcheong','Surin','Surin','THAILAND','32210','+66870185528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 05:39:51',0,NULL,3,1,11,1,'BJ01601333\r ','HSJA002 '),(18989,817977908002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',0,'buysia','samir47','samir47@msn.com','Mohamed Hantour','8446 Dana Ct<br>Fl 2','Middle Village','NY','UNITED STATES','11379-1955','(917) 767-6163','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'LK169007519CN\r ','已付款，买了2个\rNew Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides  1个\rAlice in Wonderland New sealed 3D Blu-ray Region: A,B,C  1个\r\r '),(18990,818824223011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','itchybum101','sissanchon@hotmail.com','Steve','34 Cornelia Rd','Toongabbie','New South Wales','AUSTRALIA','2146','0424166454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 06:03:54',0,NULL,3,1,11,1,'BJ01670229\r ','UM00021 \rProLee24K超轻碳纤骨长柄伞'),(18991,603453270003,130619555687,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','botshark2010','botshark@gmail.com','Yakov Vladimirovich Vdovin','Stroitelej<br>the house 55 apartment 25','Apatity','Murmansk area','RUSSIAN FEDERATION','184207','+79095648015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 06:21:21',0,NULL,3,1,3,1,'RA184549066CN\r ','HBPH001 '),(18992,907176478012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','jeff_df','jeffersonlsribeiro@gmail.com','Jefferson Luis Ribeiro','SHIN QI 03 Conjunto 12 casa 03','BRASILIA','DISTRITO FEDERAL','BRAZIL','71505-320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 06:35:53',0,NULL,3,1,3,1,'RA184549123CN\r ','OTSO004*2 '),(18993,907179244012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','iemills','ianmills@shaw.ca','Ian Mills','408 - 1021 Harwood st.','Vancouver','BC','CANADA','v6e3n3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 06:43:48',0,NULL,3,1,3,1,'RA184549239CN\r ','GLOT001 '),(18994,907182913012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','sdmathams86','stewy39@hotmail.com','Stuart Mathams','161 Queens Parade','Brighton, Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:11:17',0,NULL,3,1,3,1,'RA184549168CN\r ','OTSO004*2 '),(18995,662915714013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','mrali_2011','mrali@inbox.ru','Andrey Istranov','Guriyanova str. 43-270','Moscow','','RUSSIAN FEDERATION','109388','+7-916-6578062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:19:36',0,NULL,3,1,11,1,'BJ01670236\r ','WLIN014 '),(18996,907184963012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','esmira77','audalia@hotmail.com','Esmira Nurmammadova','Neftchilar avenue 91','Baku','','AZERBAIJAN','az1000','994502457333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:22:05',0,NULL,3,1,3,1,'RA184549211CN\r ','GLOT001 '),(18997,907187409012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','eddynk','eandj23@jazi.net','Eddy Keyser','23 coyrecup gardens<br>Swan View','Perth','Western Australia','AUSTRALIA','6056','0893740051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:41:07',0,NULL,3,1,3,1,'RA184549401CN\r ','SPGL001 '),(18998,907187337012,220913327489,'3 pair NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses 3300 GR',1,'GLSG009*3',159.99,'eastar4uk','anatoliimatroskin','anatolii.fineev@gmail.com','Anatolii Fineev','The prospect of Marshal Zhukov<br>d. 3 kv.70','Moscow','Moscow','RUSSIAN FEDERATION','123308','89854112939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 07:42:30',0,NULL,3,1,3,1,'RA184549551CN\r ','GLSG009*3 '),(18999,818840999011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','rudyna6104','9m2ody@gmail.com','Mohd Nasruddin Md Kisom','AMPMSB, Level 4, North Wing, Bangunan Sultan Iskandar,<br>Jalan Lingkaran Dalam, Johor','Johor Bahru','JHB','MALAYSIA','80300','0177128276','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 08:17:32',0,NULL,3,1,3,1,'RA184547255CN\r ','OTES001 '),(19000,604049009003,130460438575,'New Plantronics Explorer 330 BLUETOOTH HEADSET track#',1,'HSPL005',12.99,'cnfaner','amirx19','amirx19@gmail.com','amir ben maman','degania 2 appartment 6','or yehuda','israel','ISRAEL','60306','0506371357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 08:27:04',0,NULL,3,1,3,1,'RA184549446CN\r ','HSPL005 '),(19001,818849385011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','imani_is_2_cute','maryhamilton7@comcast.net','Mary Hamilton','5864 Pikes Peak Way','Sacramento','CA','UNITED STATES','95842-2200','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 09:09:04',0,NULL,3,1,1,1,'LK165916641CN\r ',NULL),(19002,609384064004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','9851tim','tim@hall2311.fsnet.co.uk','tim hall','6peover lane snelson<br>chelford','chelford','Cheshire','UNITED KINGDOM','sk119br','01625861743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 10:16:24',0,NULL,3,1,3,1,'RA184549137CN\r ','HSJA011\r英标 '),(19003,907227049012,220806848943,'Transparent Dome Rain Sun Umbrella with purple trim',1,'UMTR001',19.99,'eastar4','lynnradiohead','mikroba17@hotmail.com','lynn Ebejer','83, Main Street','B\'kara','','MALTA','BKR 2106','99229229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 11:06:58',0,NULL,3,0,11,1,'BJ01670230\r ','UMTR001 \r已入库\r紫色边的'),(19004,757015017008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.99,'au-buy','markel64','markgopies@optusnet.com.au','mark colangelo','16 Crowe Court','Eltham','Victoria','AUSTRALIA','3095','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-27 11:08:46',0,NULL,3,1,3,1,'RA184549344CN\r ','GLOT001 '),(19005,818875238011,320730084946,'Intel 5300 AGN MIMO Wireless Network +antenna*3',1,'WLIN010+ANTY002',14.5,'eastar4uk','dragunoff','tomekj@gmail.com','Tomasz Janiszewski','35 Nichollfield','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH6 4SY','13163548734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 11:25:13',0,NULL,3,1,3,1,'RA184549110CN\r ','WLIN010+ANTY002 '),(19006,609394104004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',2,'RELO003',23.9,'cnfaner','izbruhenergijezarja','izbruhenergije@gmail.com','Primož Trček','Tržaška c. 107a','Logatec','','SLOVENIA','1370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 11:30:44',0,NULL,3,1,3,1,'RA184549273CN\r ','RELO003 '),(19007,818040018002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','rusti_burnett','rusti_burnett@hotmail.com','Wade Burnett','303 Rolling Green Dr','Lakeway','TX','UNITED STATES','78734','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 12:11:19',0,NULL,3,1,1,1,'LK169876832CN\r ',NULL),(19008,609402780004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','29660065','rikines1@walla.com','sharon shlomi','mahal 23','tel-aviv','israel','ISRAEL','67655','0523864433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 12:30:59',0,NULL,3,1,3,1,'RA184549070CN\r ','HSJA010 '),(19009,907253890012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','peslac','drago.peslac@st.htnet.hr','Drago Peslac','Kupreska 90','Split','Croatia','CROATIA','21000','98801249','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 12:57:26',0,NULL,3,1,11,1,'BJ01670231\r ','SCLO002 '),(19010,907255198012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','santaedwiges','centralsantaedwiges@uol.com.br','RAPHAEL COUTINHO','ESTRADA FRANCISCO DA CRUZ NUNES 3003<br>CASA 58 - PIRATININGA','NITEROI','RIO DE JANEIRO','BRAZIL','24350310','(552) 126-0988 ext.: 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 13:04:07',0,NULL,3,1,3,1,'RA184549375CN\r ','GPS0009 '),(19011,818898631011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','khar28983','kathryn@harrisconsultants.co.uk','Kathryn Harris','2 Naseby Close<br>Pontprennau','Cardiff','Cardiff','UNITED KINGDOM','CF23 8LS','02920731169','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 13:11:33',0,NULL,3,1,3,1,'RA184549622CN\r ','GLSG001 '),(19012,907261500012,220915101992,'New in box genuine Philips SHQ4000 Sports Sweat Proof Headphones',1,'HSPH002',37.9,'eastar4','doz_il','david.oz.il@gmail.com','David Oz','54 Jabotinsky st.<br>apartment 24','Ramat Gan','','ISRAEL','52462','+972-54-2566587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 13:27:21',0,NULL,3,1,11,1,'BJ01601336\r ','HSPH002 '),(19013,907264568012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','fsgcougar1024','fsgcougar@northstate.net','Forrest Gentry','422 Edgedale Dr','High Point','NC','UNITED STATES','27262','(336) 687-7684','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 13:35:59',0,NULL,3,1,1,1,'LK168673793CN\r ','GLOT001*2 '),(19014,818907728011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','larsk6683','lars.k@kristensen.mail.dk','Lars Kristensen','Haestrupvej 88','Hjoerring','','DENMARK','9800','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 13:50:16',0,NULL,3,1,3,1,'RA184549389CN\r ','RCLO007+POLO001+RCLO008*4 '),(19015,818908886011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','langbout1954','langbout@hotmail.com','Mario Langevin','2332 des Lilas','La Baie','QC','CANADA','G7B 4E1','(418) 544-2708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 13:58:34',0,NULL,3,1,3,1,'RA184549295CN\r ','LGAD001 '),(19016,907271801012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','salez2012','salez12@hotmail.co.uk','K Endean','30 Hambledon Close','Wolverhampton','West Midlands','UNITED KINGDOM','WV9 5PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 14:02:53',0,NULL,3,1,3,1,'RA184549185CN\r ','HSPH002 '),(19017,907278604012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','zormacs','zorma@zorma.hu','Árpád Gere (Com.unique Kft.)','Hegedűs Gyula u. 83-87','Budapest','BUDAPEST','HUNGARY','1133','0036306066450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 14:26:40',0,NULL,3,1,3,1,'RA184549450CN\r ','GLOT005 '),(19018,662980483013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','jensjensen2222','jensjensen222@gmail.com','Jan Erik Kallerud','Sinsenvn 5A','OSLO','','NORWAY','0572','+4798257166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:41:58',0,NULL,3,1,3,1,'RA184549327CN\r ','GLOT001*2 '),(19019,907283967012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','jren5d','rendonj@bellatlantic.net','Jose Rendon','481 Wales Ave<br>Apt 5D','Bronx','NY','UNITED STATES','10455-4839','(646) 765-4407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 14:43:21',0,NULL,3,1,1,1,'LK164642345CN\r ',NULL),(19020,818896410011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','winnerr111','terentew@mail.ru','Alexandr Terentyev','Isakovskogo st. 24, ap/36','Moscow','','RUSSIAN FEDERATION','123631','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:48:09',0,NULL,3,1,11,1,'RA184549154CN\r ','HSNO019\r欧标 '),(19021,818930121011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','erik3556','volk_stepni@yahoo.co.uk','Erik Mrak','Krozna pot 22','Prelog','','SLOVENIA','1230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 15:14:48',0,NULL,3,1,3,1,'RA184549361CN\r ','OTSA001 '),(19022,818936870011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','brebi01','ed-gra@hotmail.com','Edmond Busuttil','\'Jaona\' N/S Imqabba str.','Zurrieq','Zurrieq','MALTA','ZRQ 1077','0035699454287','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 15:41:01',0,NULL,3,1,3,1,'RA184549260CN\r ','GLOT001 '),(19023,818942956011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','taekwondo-star','geoffpage1@yahoo.co.uk','Geoff Page','19 Millers Road<br>Toft','Cambridge','Cambridgeshire','UNITED KINGDOM','CB23 2RX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 15:56:17',0,NULL,3,1,3,1,'RA184549199CN\r ','MOAP001 '),(19024,818945970011,320781439714,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',3,'HSSA004',47.97,'eastar4','notismih1985','notismih@hotmail.com','nondas mixailidis','loudias1','loudias,thessaloniki','-','GREECE','57007','6973551662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 16:07:23',0,NULL,3,1,3,1,'RA184547224CN\r ','HSSA004\r欧标 \r客户就要一个，退其他两个的钱\r'),(19025,818952698011,320441946443,'2.1 HP DV9000 DV9000Z DV9100 Bluetooth Module EDR+cable',2,'BTHP2111',24.78,'eastar4','r1964oleg','r1964@gala.net','OLEG RUSAKOV','SVETLANOVSKI<br>62-1-367','S PETERBURG','s peterburg','RUSSIAN FEDERATION','195269','89052506990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 16:25:59',0,NULL,3,1,11,1,'BJ01670242\r ','BTHP2111 \rHP 8pin 1.25 25cm '),(19026,818960295011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','zaporekolcia','jaco1966@yahoo.co.uk','Jacek Zaporowski','110 Avenue Rd','Gosport','Hants','UNITED KINGDOM','PO12 1LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 16:47:53',0,NULL,3,1,17,0,'RA184549145CN\r ',NULL),(19027,907329000012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','fabricio_33','newsptz@ig.com.br','Fabrício Costa','Rua José Getúlio, 442, apto 72','São Paulo','São Paulo','BRAZIL','01509000','55 (011) 7808-2322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 16:49:31',0,NULL,3,1,11,1,'BJ01670238\r ','GPS0010 '),(19028,907328608012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','jojo1968','brianandjoanne@hotmail.co.uk','joanne wilkinson','24 salisbury road','lowestoft','Suffolk','UNITED KINGDOM','nr33 0he','01502538307','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 16:49:52',0,NULL,3,1,3,1,'RA184549083CN\r ','LGAD001 '),(19029,818961117011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','zaporekolcia','jaco1966@yahoo.co.uk','Jacek Zaporowski','110 Avenue Rd','Gosport','Hants','UNITED KINGDOM','PO12 1LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 16:50:15',0,NULL,3,1,3,1,'RA184549145CN\r ','OTSO004\r一共买了两个（订单合并） '),(19030,907336958012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','bro_allison','broallison@madisonbaptist.com','Michael Allsion','26812 Elkins Rd','Athens','AL','UNITED STATES','35613','(256) 830-6224','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 17:09:41',0,NULL,3,1,1,1,'LK170546921CN\r ',NULL),(19031,818984658011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',40.99,'eastar4uk','c_finnigan2000','c_finnigan2000@yahoo.co.uk','Suz Bowen-Thompson','307 Chemin De Touars','Callian','Provence-Alpes-Côte d\'Azur','FRANCE','83440','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 17:57:32',0,NULL,3,1,3,1,'RA184549582CN\r ','GLSG001 '),(19032,907358207012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','humadinki','simonjwagner@gmail.com','Simon Wagner','20a Cookham Rd','Lathlain','Western Australia','AUSTRALIA','6100','0448716447','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 18:01:02',0,NULL,3,1,3,1,'RA184549392CN\r ','WLIN013 '),(19033,907365566012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','badger0141','b.mcgrath@sky.com','bernard mcgrath','2 hawthorn gardens drumsagard village<br>cambuslang','glasgow','south lanarkshire','UNITED KINGDOM','g72 7gp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 18:15:44',0,NULL,3,1,3,1,'RA184549242CN\r ','LGRM001 '),(19034,818999772011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ittensa','ginim@geomix.at','Regina Mittermayr','Ittensam 27/1','Eberstalzell','','AUSTRIA','4653','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 18:30:43',0,NULL,3,1,11,1,'BJ01670232\r ','RELO003 '),(19035,609484218004,140515710247,'New Plantronics Explorer 320 BLUETOOTH HEADSET track#',1,'HSPL002',12.98,'cnfaner','jhahn','jhahn@columbus.rr.com','Joe Hahn','268 Pat Haven Dr','Pataskala','OH','UNITED STATES','43062','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 18:51:27',0,NULL,3,1,1,1,'LK170054269CN\r ',NULL),(19036,604177091003,130617611588,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',136.99,'cnfaner','gorgobacsi','madaraszg@gmail.com','Gergely Madarász','Lechner Ödön fasor 8.<br>Morgan Stanley','Budapest','','HUNGARY','1095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 19:43:57',0,NULL,3,1,3,1,'RA184547167CN\r ','RCLO009 '),(19037,774642760001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','mm6678','mikemai@lcshipping.com','Mike Mai','2075 S Atlantic Blvd<br>Ste H','Monterey Park','CA','UNITED STATES','91754','(323) 712-3898','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 19:44:13',0,NULL,3,1,1,1,'LK170025789CN\r ',NULL),(19038,907401586012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','avoky','fadvas66@gmail.com','Vasiliy Fadin','Zvezdnaya Street 25\"A\", Apr. 24','Kaliningrad','Kaliningrad Region','RUSSIAN FEDERATION','236006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 19:30:39',0,NULL,3,1,11,1,'BJ01601334\r ','OTGR001+OTGR002 '),(19039,907410083012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','sunojee8','wshah77@hotmail.com','SYED SHAH','7,WESTMEDE<br>CHIGWELL','LONDON','London','UNITED KINGDOM','IG7 5LR','07723331478','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 19:51:52',0,NULL,3,1,3,1,'RA184549171CN\r ','HSSA002\rblack wersion \r英标 '),(19040,819034003011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','rangerrick.2007','rihewett@kern.org','Rick Hewett','1272 Locust St','Willits','CA','UNITED STATES','95490-4643','(707) 459-1338','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19041,818191711002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','buyfrombando','heavylifting@earthlink.net','Nick Bandouveris','124 Pioneer St','Brooklyn','NY','UNITED STATES','11231-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 20:09:25',0,NULL,3,1,1,1,'LK168035310CN\r ',NULL),(19042,765091324007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','septa351','gcopas@snet.net','Gary C. Copas Jr','394 E Main St','Wallingford','CT','UNITED STATES','06492-2553','(203) 269-9124','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-27 20:23:16',0,NULL,3,1,1,1,'LK166676315CN\r ','BALO007 '),(19043,819071044011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','davidnmfarrell','davidnmfarrell@hotmail.com','David Farrell','119 D Commercial Road','London','London','UNITED KINGDOM','E1 1RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 21:19:19',0,NULL,3,1,3,1,'RA184549300CN\r ','MOAP001 '),(19044,819077303011,320679553967,'New Battery for Genuine INOVA T4 LED Flashlight Torch',1,'BAIN001',4.98,'eastar4uk','jumpinjackatom','pchallinor1@optusnet.com.au','Peter Challinor','32 estramina road','regents park','Queensland','AUSTRALIA','4118','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 21:35:37',0,NULL,3,1,11,1,'BJ01601337\r ','BAIN001 '),(19045,757211829008,180764312983,'New GENUINE Plantronics Explorer 330 BLUETOOTH HEADSET+AC adapter',1,'HSPL005',13.99,'au-buy','dr_dodi2002','dr_dodi2002@hotmail.com','Edmon Michael','11 ELM street','Acacia Gardens','New South Wales','AUSTRALIA','2763','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-27 21:39:02',0,NULL,3,1,11,1,'BJ01601338\r ','HSPL005\r澳标 '),(19046,907463050012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',4,'TRMX003',30.28,'eastar4','rehsd','rich@hintzworld.com','Rich Hintz','3409 S Saguaro Ave','Sioux Falls','SD','UNITED STATES','57110-4429','(605) 371-2252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 21:50:09',0,NULL,3,1,1,1,'LK169777724CN\r ',NULL),(19047,609535831004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','emz888','e.collcott@live.co.uk','Emma Collcott','1 sewardstone close<br>sewardstone rd','walthom abbey','Hertfordshire','UNITED KINGDOM','E4 7RG','01525370441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 21:57:50',0,NULL,3,1,3,1,'RA184549106CN\r ','HBPH003 '),(19048,907468251012,220789174394,'New Genuine Motorola HS850 Bluetooth Wireless Headset',1,'HSMO019',10.95,'eastar4uk','stephen5000','frost52@yahoo.com','stephen frost','22 lock place','reading','Berkshire','UNITED KINGDOM','RG13HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 22:02:31',0,NULL,3,1,3,1,'RA184549208CN\r ','HSMO019\r英标 '),(19049,754367538008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','ikakashii','keitarokido@hotmail.com','Hector Manriquez','1906 Gentilly cir','Austin','TX','UNITED STATES','78727-4420','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-27 22:14:18',0,NULL,3,1,1,1,'LK164374431CN\r ','RELO001 '),(19050,604220189003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','usa123mar','belbady@hotmail.com','Abdelouahed Zaraf','365 Montrose Dr<br>Apt. D','Greensboro','NC','UNITED STATES','27407','(336) 292-7190','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-27 22:24:44',0,NULL,3,1,1,1,'LK169713777CN\r ',NULL),(19051,818251185002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','eric493','eric@ericnelson.net','Eric Nelson','1951 Broadsmore Dr','Algonquin','IL','UNITED STATES','60102','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 22:47:59',0,NULL,3,1,1,1,'LK168892065CN\r ',NULL),(19052,663121695013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','ivy_sapphire','k2sloap@yahoo.com','Emilymae H','3824 W Pine Square Rd','Tomahawk','WI','UNITED STATES','54487-8833','(715) 614-2044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 23:02:48',0,NULL,3,1,1,1,'LK167492724CN\r ',NULL),(19053,663128307013,230503848087,'Bluetooth 2.1 Module BCM92046NMD HP/Dell/Acer BCM2046',1,'BTDE2100',8.99,'eastar4','entrebahn','reg.charney@entrebahn.com','Reg Charney','706-71 Charles St. E','Toronto','ON','CANADA','M4Y2T3','(416) 960-3531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 23:31:22',0,NULL,3,1,11,1,'BJ01670240\r ','BTDE2100 '),(19054,819120311011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','kcb001kcb','kbaussi@gmail.com','Kurt Beck','32, Spinnaker Rise','Point Cook','Victoria','AUSTRALIA','3030','0420779252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 23:47:52',0,NULL,3,1,11,1,'RA184549287CN\r ','HBPH003 \r澳标'),(19055,819122460011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','swain747','andyswain@aol.com','Andy Swain','6 Abbots Grove','Belper','Derbyshire','UNITED KINGDOM','DE56 1BX','01773826582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 23:59:19',0,NULL,3,0,11,1,'BJ01670235\r ','TRMX002 \r已入库'),(19056,819123733011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ck6835','rbbcc2@peoplepc.com','robert cook','450 e bluff dr','port angeles','WA','UNITED STATES','98362-9192','(253) 235-2760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 00:00:27',0,NULL,3,1,1,1,'LK169308743CN\r ',NULL),(19057,765168601007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','cathers321','cathers_@hotmail.com','Catherine Nguyen','8 South Creek Rd','Dee Why','New South Wales','AUSTRALIA','2099','0433216197','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-28 00:18:30',0,NULL,3,1,11,1,'BJ01670233\r ','RELO003 '),(19058,604257660003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','ziga182','vidmarz@gmail.com','Ziga Vidmar','Kalinskova ul. 20','4000,','','SLOVENIA','Kranj','38640808252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 01:35:37',0,NULL,3,1,3,1,'RA184549256CN\r ','HBPH009 '),(19059,609581728004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',29.9,'cnfaner','kk673-2008','klfoo673@gmail.com','Foo Kiah Lien','Lot 3722B<br>Jalan Gates','Kuala Belait','Belait','BRUNEI DARUSSALAM','KB','3330656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 02:00:50',0,NULL,3,1,3,1,'RA184549534CN\r ','MOAS001 '),(19061,8881325041627935,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',0,'eastar4','silvarg17','serebriakov.oleg@gmail.com','Oleg Serebryakov','Zakharinskiye dvoriki, 3, 303','Moscow','','RUSSIAN FEDERATION','117148','',NULL,NULL,NULL,'2011-12-28 03:07:07',0,NULL,3,1,11,1,'BJ01670227\r ','WLIN014\r补发的 '),(19062,8881325042219559,111,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',33,'au-buy','brm_85kongen','brm_85@hotmail.com','Brian Madsen','Grønlandsparken 94c','Esbjerg','','DENMARK','6715','',NULL,NULL,NULL,'2011-12-28 03:16:59',0,NULL,3,1,3,1,'RA184546776CN\r ','GPS0010\r申报为11美金 发货时带上发票 '),(19063,907072033012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','marysaerie','marysaerie@stny.rr.com','Mary Sayman','721 Delano Ave','Vestal','NY','UNITED STATES','13850-3111','(607) 748-7679','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 03:45:30',0,NULL,3,1,1,1,'LK168374247CN\r ',NULL),(19064,819178187011,320730085738,'New Atheros AR9281 802.11N Wireles WiFi Mini PCI-E Card',1,'WLAT010',6.5,'eastar4uk','christi-s','christi@coraline.org','Christi Scarborough','77b, Wilkins Road<br>Cowley','Oxford','Oxfordshire','UNITED KINGDOM','OX4 2JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 03:46:32',0,NULL,3,1,3,1,'RA184549525CN\r ','WLAT010 '),(19065,604280757003,130598387084,'2 pairs of New in box SONY 3D Active Glasses TDG-BR250',2,'OTSO004*2',271.98,'cnfaner','vitsp','vitorpetroni@hotmail.com','vitor petroni','Rua josé domingos de figueiredo Q.04 N.07<br>Bairro Coophamil','Cuiabá','Mato Grosso','BRAZIL','78028-140','+556581155158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 03:55:00',0,NULL,3,1,3,1,'RA184549463CN\r ','OTSO004*2 \r申报价值＄50以内'),(19066,818322459002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','tekcome0','tekcome@hotmail.com','kevin engineer','14 farmers ave','ajax','ON','CANADA','l1t3s9','(905) 435-2911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 03:58:21',0,NULL,3,1,11,1,'BJ01670223\r ','BR3D009 '),(19067,609601389004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',2,'GLSG001',121.98,'cnfaner','santhosh.therakam','santhosh_tk65@yahoo.com','Santhosh Therakam','Unit 1 <br>35 Sammells Drive ','Chermside','Queensland','AUSTRALIA','4032','0733503939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 04:23:19',0,NULL,3,1,3,1,'RA184549503CN\r ','GLSG001 '),(19068,8881325047379373,111,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',0,'eastar4','vahik611','vahik002@yahoo.com','Vahram Jalalyan','Davitashen distr. IV block, build. 15, apt. 10','Yerevan','Yerevan','ARMENIA','0054','+37491477369',NULL,NULL,NULL,'2011-12-28 04:42:59',0,NULL,3,0,3,1,'RA184537244CN\r ','UMTR001\r补发的 \r蓝色边的 \r已入库\r'),(19069,819193579011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','pajah1961','paulhyam@hotmail.com','Paul Hyam','61 Halifax Street','Adelaide','South Australia','AUSTRALIA','5000','0421376857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 05:07:21',0,NULL,3,1,3,1,'RA184549640CN\r ','GLOT001 '),(19070,663190953013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','vectrex.com-net-org','cromero@romero.org','Chris Romero','211 Monterey Rd<br>Apt 1','Pacifica','CA','UNITED STATES','94044-1462','(650) 651-1529','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 05:22:58',0,NULL,3,1,1,1,'LK169935102CN\r ',NULL),(19071,663193564013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sandro-volkmann','sandrovolkmann@yahoo.de','Thomas Metzger','Mauritiusstraße 6','Medebach','','GERMANY','59964','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 05:37:00',0,NULL,3,1,11,1,'BJ01670224\r ','HSNO019\r欧标 '),(19072,907601071012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','chemyakyn','tenchem@gmail.com','Andrew Chemyakyn','10-47, Melnichnaya str.','Tyumen','Tyumen','RUSSIAN FEDERATION','625048','+7 9088 749337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 06:24:27',0,NULL,3,1,3,1,'RA184549517CN\r ','GLOT001 '),(19074,8881325055320219,111,'补发一个JABRA BT500的充电器',1,'',0,'eastar4','pancir','candycarr@windstream.net','Candice S. Carr','3652 Shaffer Rd','Rock Creek','OH','UNITED STATES','44084-9728','(440) 478-2748',NULL,NULL,NULL,'2011-12-28 06:55:20',0,NULL,3,0,1,1,'LK084740661CN ','只补发一个 充器\r\rE邮宝改个地址'),(19075,8881325057103200,111,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',0,'eastar4','kay180668','kay1806@mail.ru','Yuriy Kalashnik','68, Pestelya str.','Kharkov','','UKRAINE','61161','',NULL,NULL,NULL,'2011-12-28 07:25:03',0,NULL,3,1,3,1,'RA184549579CN\r ','OTSO004\r由于直接打得款\r少发了一副眼镜 \r这次是补发的'),(19076,8881325057855369,111,'Brand_new_HP_MCE_Media_Center+IR_emitte',1,'',0,'eastar4','yahek01','jperezguio@gmail.com','Joaquin Perez Guio','C/ Real, 5','Yuncos(Toledo)','Castilla-La Mancha','SPAIN','45210','649952960',NULL,NULL,NULL,'2011-12-28 07:37:35',0,NULL,3,0,11,1,'BJ01670226\r ','OTHP005 \r补货'),(19077,609623238004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','azmiyati','imansyaqil@yahoo.com.sg','Noor Hayati Mohd Selamat','Blk 31 Elias Road<br>#06-22 Ris Grandeur','default','','SINGAPORE','519934','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 07:38:25',0,NULL,3,1,3,1,'RA184549565CN\r ','OTGR001+OTGR002 '),(19078,604306592003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','xtremep4','travisweston@comcast.net','Travis P. Weston','1005 Fulton Ave<br>Apt 104','Sacramento','CA','UNITED STATES','95825','(916) 768-0716','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-28 07:55:14',0,NULL,3,1,1,1,'LK169846994CN\r ','OEM '),(19079,819219826011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','walshmjm','walshmjm@aol.com','Michael Walsh','2841 Bardy Rd','Santa Rosa','CA','UNITED STATES','95404-8478','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 08:02:18',0,NULL,3,1,1,1,'LK168549310CN\r ',NULL),(19080,774824663001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',0,'buysia','businsspec','jonleupold@gmail.com','Jonathan B. Leupold','693 Twin Crest Dr','Lehighton','PA','UNITED STATES','18235-9151','(610) 577-5502','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'LK170400691CN\r ','买了2个 已付款＄38.89\r ICE AGE 3  New Panasonic sealed 3D Blu-ray   1个\rNew Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides  1个\r\r\r'),(19081,907631709012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','ozcanozyurt','ozcanozyurt40@yahoo.com','Ozcan Ozyurt','Delta Ins.A.S. Atakoy 6.Kisim Atakoy Konaklari A-9 Blok Daire :4<br>Bakirkoy','Istanbul','TURKEY','TURKEY','34158','02126618751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 09:34:59',0,NULL,3,1,3,1,'RA184549993CN ','OTSO004*2 '),(19082,907639349012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','4038kouklos','tp@harlypetersen.dk','Thomas Pedersen','Østre Landevej 41','Maribo','','DENMARK','4930','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 09:59:59',0,NULL,3,1,3,1,'RA184547048CN ','RCMA001 '),(19083,907642184012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','vk2qq-brad','bgranger@exemail.com.au','Brad Granger','8 Gordon Street','Thirlmere','New South Wales','AUSTRALIA','2572','0246810338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:12:27',0,NULL,3,1,3,1,'RA184547079CN\r ','GLOT001*2 '),(19084,663226722013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','syberpupy','syberpuppy@gmail.com','Omri Cohen','Uruguay 21, apartment 4','default','Israel','ISRAEL','96701','0544590585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:21:24',0,NULL,3,1,3,1,'RA184547136CN ','GLOT005 \r一共买了两个'),(19085,817294998011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','researcher-heart-beat','mohammadowaisrajput@live.co.uk','Owais Rajput','430 Great Horton Road','Bradford','West Yorkshire','UNITED KINGDOM','BD7 3HS','07588486483','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 10:23:43',0,NULL,3,1,3,1,'RA184547017CN ','GLOT001 '),(19086,663228625013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','syberpupy','syberpuppy@gmail.com','Omri Cohen','Uruguay 21, apartment 4','default','Israel','ISRAEL','96701','0544590585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:26:31',0,NULL,3,1,17,0,'RA184547136CN ',NULL),(19087,907637337012,220807300008,'3 pcs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',210.99,'eastar4','kateeastough','kate.eastough@hotmail.com','Kate Eastough','10 Hackett Close','Karratha','Western Australia','AUSTRALIA','6714','0408215747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:32:06',0,NULL,3,1,3,1,'RA184547175CN\r ','GLSG001*3 '),(19088,907645809012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','deim0nd','a.churak@gmail.com','Alexey Churak','Suzdalskaya 18-2-570','Moscow','Moscow','RUSSIAN FEDERATION','111673','+79169801005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:28:28',0,NULL,3,1,3,1,'RA184549980CN ','OTIN005 '),(19089,907652832012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','jhj2000','jhj2000@ntlworld.com','John James','5, Wynstay<br>Stockcroft Road','Balcombe','West Sussex','UNITED KINGDOM','RH17 6LH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 10:57:46',0,NULL,3,1,3,1,'RA184549962CN\r ','LGRM001'),(19090,604338133003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','schtirlitzzz','a-0279@yandex.ru','Kartsev Alexandr','21-70 Bashilowskaya ul.','Moscow','','RUSSIAN FEDERATION','127287','+79262440994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 11:56:54',0,NULL,3,1,3,1,'RA184549945CN ','MOOE003\rOEM '),(19091,907670779012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','ramimualem0804','ramimualem@hotmail.com','Rami Mualem','70 Dov Hoz Blv.','Holon','Isarel','ISRAEL','58235','+97236241489','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 12:15:01',0,NULL,3,1,11,1,'BJ01670209 ','GPS0010 '),(19092,907672905012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT006',26.99,'eastar4uk','defom','defom@ebuyclub.com','PERLOT CINDY','16 bis rue des Brasseries','Chalons en Champagne','Champagne-Ardenne','FRANCE','51000','0676183231','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 12:23:48',0,NULL,3,1,3,1,'RA184547096CN\r ','GLOT006 '),(19093,663250179013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','george6967','georgesideris69@yahoo.com.au','George Sideris','56 Gordon Street','Newport','Victoria','AUSTRALIA','3015','0412873049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 12:42:17',0,NULL,3,1,3,1,'RA184547051CN\r ','GLOT001*4 '),(19094,818975534011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.39,'eastar4','dreambox99','aday1@gmx.de','Aday Aydin','Marderstrasse 8','Rheda-Wiedenbrück','','GERMANY','33378','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 12:50:02',0,NULL,3,1,11,1,'BJ01670211 ','BTAC2124 \racer 8pin1.00 15cm '),(19095,609665799004,140667905525,'New Replaceable Shell for logitech Mouse MX518',1,'SHLO004',12.99,'cnfaner','neopre','neopre@yahoo.com','Eloi Bartolomé','Rossello 351<br>3o 1a','Barcelona','Cataluña','SPAIN','08037','619166629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 13:03:09',0,NULL,3,1,3,1,'RA184547238CN\r ','SHLO004 '),(19096,907684844012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','monigogi','zhelezov.georgi@gmail.com','Monika Banova','31 Avenue de Lardenne<br>rez de chausse gauche','Toulouse','Midi-Pyrénées','FRANCE','31100','0751406108','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 13:10:10',0,NULL,3,1,3,1,'RA184547241CN\r ','GLOT005 '),(19097,907687300012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','lastleafimaging','cheuserbarr@gmail.com','C. Heuser Barr','48 LONGFELLOW DR','FLORENCE','MA','UNITED STATES','01062-9772','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 13:17:42',0,NULL,3,1,1,1,'\\ ',NULL),(19098,907688742012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','arnicoo','arnico@gmail.com','Arnis Puskeiris','Rigas 43-6','Livani','','LATVIA','LV5316','(371) 29804032','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 13:24:21',0,NULL,3,1,11,1,'\\ ','OTHP004 '),(19099,663261851013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',19.99,'eastar4','ni*sa','vanessa@riegraf.de','Vanessa Riegraf','Ensingerstr.35','Illingen','','GERMANY','75428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 13:43:33',0,NULL,3,1,11,1,'BJ01670202\r ','UM00013 \r草莓伞 '),(19100,818441316002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','phillyd360','philip597@btinternet.com','Philip Sutton','3 Southfield Fold<br>Horbury','Wakefield','West Yorkshire','UNITED KINGDOM','WF4 5LA','01924265822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 13:54:34',0,NULL,3,1,11,1,'BJ01670210\r ','BR3D009 '),(19101,609674922004,140635369039,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',70.99,'cnfaner','$$$mrtom','ts.koenig@t-online.de','Thomas','Reilinger Str. 10','Altlußheim','','GERMANY','68804','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 13:57:21',0,NULL,3,1,3,1,'RA184547184CN\r ','GLSG001 '),(19102,757421258008,180699060860,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',39.99,'au-buy','rlhoneycutt2011','rlhoneycutt@fuse.net','robert honeycutt','26158 E Rolling Dr','West Harrison','IN','UNITED STATES','47060-9574','(513) 484-2441','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-28 14:09:37',0,NULL,3,0,1,1,'\\ ',NULL),(19103,603954020003,130617611559,'Logitech Harmony 890 remote control & wireless extender & AC adapters',1,'RCLO003',134.99,'cnfaner','morganc0623','morgan0623@rogers.com','christopher morgan','2059 bough beeches blvd','misssissauga','ON','CANADA','l4w 2j9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 14:44:30',0,NULL,3,1,3,1,'RA184547286CN\r ','RCLO003 '),(19104,817334464011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','delineator333a','roger_gaspar@hotmail.com','Roger Gaspar','1 Makeway Avenue<br>Newton Edge 10-02','default','','SINGAPORE','228598','(065) 978-8747 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 14:54:04',0,NULL,3,1,3,1,'RA184547122CN ','HBPH002 '),(19105,815632091011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT006*2',88.99,'eastar4','xycomguy','pderbyshire@derbyshire.ca','Paul Derbyshire','121 Erie Ave South','Fisherville','ON','CANADA','N0A1G0','(905) 779-0754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 15:01:21',0,NULL,3,1,3,1,'RA184549959CN ','GLOT006*2 \r兼容型3D眼镜  Korea TV专用'),(19106,907721448012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','andmarie85','andmarie85@hotmail.com','Andrea Cooper','Ladybird Fitness Club<br>55 Albert Street','WIGAN','Lancashire','UNITED KINGDOM','WN5 0TR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 15:08:52',0,NULL,3,1,3,1,'RA184537743CN\r ','HSPH002 '),(19107,819317444011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','m111gcw','wcg@talk21.com','G Ward','16 Bleadon Hill','Weston Super Mare','Avon','UNITED KINGDOM','BS24 9JD','07977360585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 15:15:30',0,NULL,3,1,3,1,'RA184547119CN ','HBPH002 '),(19108,819318132011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','cmercier1962','cmercier62@comcast.net','CLAUDE Mercier','8790 SPRING MOUNTAIN WAY','Fort Myers','FL','UNITED STATES','33908-9677','(239) 689-4743','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 15:21:03',0,NULL,3,1,1,1,'\\ ',NULL),(19109,907736039012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','gofartski','glenk@mts.net','H. Glen Kolansky','115 Whiteway Road','Winnipeg','MB','CANADA','R2C4C5','(204) 222-5403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 15:49:41',0,NULL,3,1,3,1,'RA184549928CN ','GLOT001*2 '),(19110,818488665002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','ademirjose','ademirjose007@aol.com','ADEMIR JOSE','6800 JOHNSON ST','HOLLYWOOD','FL','UNITED STATES','33024-5760','(954) 295-7940','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 16:32:04',0,NULL,3,1,1,1,'\\ ',NULL),(19111,609708448004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','darkequinox','darkequinoxx@gmail.com','Raoul Akakpo','31 Porchester Drive','Scarborough','ON','CANADA','M1J 2R4','(905) 903-4447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 16:40:16',0,NULL,3,1,3,1,'RA184549874CN\r ','HSJA011 '),(19112,819352050011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','trwitknee','witknee@midco.net','Toni R Whitney','9615 Foxcroft Rd NW','Bemidji','MN','UNITED STATES','56601-9768','(218) 209-6818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 17:01:23',0,NULL,3,1,1,1,'\\ ',NULL),(19113,818508821002,120817143685,'Alice in Wonderland New sealed 3D Blu-ray  Region: A,B,C',1,'BR3D005',14.99,'buysia','lascruces','jcarsey3602@msn.com','Jean Carsey','2913 Karen Pl','Las Cruces','NM','UNITED STATES','88001-7585','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 17:25:19',0,NULL,3,1,1,1,'\\ ',NULL),(19114,818524217002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','sarahmayd342011','sarahmayd34@yahoo.com','sara door','9501 S Bullet Prairie Rd','Tishomingo','OK','UNITED STATES','73460-4438','(580) 257-0511','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 18:05:31',0,NULL,3,1,1,1,'\\ ',NULL),(19115,819389046011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','tudorthomas1','tudor.t@ntlworld.com','Tudor Thomas','Merrywood<br>31 Deepdene Wood','Dorking','Surrey','UNITED KINGDOM','RH54BE','01306882482','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 18:29:04',0,NULL,3,1,3,1,'RA184550002CN ','GLOT001 '),(19116,604338248003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','nagyi73','nagyi1973@gmail.com','Sándor Nagy','Tamási Áron u.10 sz.','Balmazújváros','Hajdú-Bihar megye','HUNGARY','4060','+36703893777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 18:56:34',0,NULL,3,1,3,1,'RA184547105CN ','MOLO006 '),(19117,604430376003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','garrett141','garrett141us@yahoo.com','Garrett Mowrey','3851 Industrial Pkwy','Nashville','TN','UNITED STATES','37218-3629','(615) 320-7292 ext.: 254','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-28 19:01:12',0,NULL,3,1,1,1,'\\ ',NULL),(19118,907820536012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','oscar2899','oscar_2899@yahoo.com','Oscar Jimenez Hernandez','Plaza Bonampack 343<br>CTM Culhuacan Seccion 5','Ciudad de Mexico','Mexico','MEXICO','04440','525556916582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:01:23',0,NULL,3,1,3,1,'RA184549976CN ','GLOT001*4 '),(19119,663348726013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','etomoinick','ndvikulov@gmail.com','Andrey Vikulov','Bulvar Molodeji, d. 7, kv. 100','Ufa','','RUSSIAN FEDERATION','450071','+79373330323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:10:06',0,NULL,3,1,11,1,'BJ01670207 ','WLAP008 '),(19120,907828144012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','kingkhan2005','khantradiction@hotmail.com','Sadi Khan','83 Borough Drive<br>Suite 2610','Toronto','ON','CANADA','M1P5E4','(416) 420-9457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:23:22',0,NULL,3,1,3,1,'RA184547065CN ','OTSO004*2 '),(19121,775009951001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','rtrillo52','rtrillom@prodigy.net.mx','Ricardo trillo','aldama 33-A','penjamo','Guanajuato','MEXICO','36900','014696920050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:45:54',0,NULL,3,1,11,1,'BJ01670208 ','BR3D008 '),(19122,819425182011,320635323172,'New Intel IBM lenovo 5300 AGN  Mini PCI-E Card+antenna',1,'WLIN011+ANTY002',18.99,'eastar4','intrad80','intrad1@yahoo.es','Sergio Aguaviva','Tuset 20-24, 8º 6ª','Barcelona','Cataluña','SPAIN','08006','620722455','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:50:03',0,NULL,3,1,11,1,' BJ01670206','WLIN011+ANTY002 '),(19123,663364669013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*4',351.98,'eastar4','sgb17','sbadach@shaw.ca','Sheldon Badach','444 Dunluce Road','Edmonton','AB','CANADA','T5X4K9','(780) 475-3334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 20:01:43',0,NULL,3,1,6,1,'EE636829144CN ',NULL),(19124,907851594012,220915092758,'3 pairs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','alexandre_scharis','alexandre_scharis@hotmail.com','alexandre scharis','rue des villas 24','trois-ponts','','BELGIUM','4980','080730048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 20:10:09',0,NULL,3,1,3,1,'RA184547082CN\r ','SAFI001*3\r新地址\rAlexandre Scharis\rBrume 30\r4980 Trois-Ponts\rBelgium\r '),(19125,907858073012,220913328219,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',2,'OT00004',9.98,'eastar4uk','prachinho','hans_hermann_weber@web.de','Tiago Weber dos Santos','Caixa Postal 59','Areia','Paraiba','BRAZIL','58.397-000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 20:30:07',0,NULL,3,1,3,1,' RA184531581CN','OT00004\r暂停发货了十多天，所以选择挂号\r'),(19126,907886440012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',2,'HSPH002',45.98,'eastar4uk','ohadfogel','aaaohad@gmail.com','Ohad Fogel','Hagdud Haivri 71a<br>Kiryat Haim','Haifa','ISRAEL','ISRAEL','26305','+972525544474','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 21:22:03',0,NULL,3,1,3,1,'RA184537757CN\r ','HSPH002 '),(19127,663392283013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','philblack70','philip.blackwell@live.ie','philip blackwell','ballinaclough','nenagh','Tipperary','IRELAND','','06732737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 21:34:51',0,NULL,3,1,3,1,'RA184547207CN ','HBPH002 '),(19128,609793268004,140662512555,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.9,'cnfaner','**hemi44','44hemi@speedconnect.com','robert hemingway','4760 washburn rd','vassar','MI','UNITED STATES','48768-9538','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-28 21:46:38',0,NULL,3,1,1,1,'\\ ',NULL),(19129,907898413012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',3,'OTCN004*10',50.1,'eastar4','avextra--uk','support@lcd-plasma-tv-brackets.co.uk','John Durkin','85 Captains Lane','Liverpool','Merseyside','UNITED KINGDOM','L30 9SU','07807079866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 21:50:39',0,NULL,3,1,3,1,'RA184547025CN ','OTCN004*10 '),(19130,819476631011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','jurjavcic','nofeardh@gmail.com','Aljosa Jurjavcic','Soncni log 2A','Logatec','Slovenia','SLOVENIA','1370','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 21:53:06',0,NULL,3,1,11,1,'BJ01670212\r ','OTHP005 '),(19131,819476735011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','rajsek','pushpraj@yahoo.com','Pushparaja Parthasarathy','13 St.Johns Close','Enfield','London','UNITED KINGDOM','N14 4LF','07973511798','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 21:54:48',0,NULL,3,1,3,1,'RA184549914CN ','GLOT001 '),(19132,907900465012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',10,'MOAP001',279.9,'eastar4','dvmacmart','carol@dvwarehouse.com','DV Warehouse, Inc.','747 Seward St','Los Angeles','CA','UNITED STATES','90038-3503','(323) 463-5005','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 21:55:49',0,NULL,3,1,4,1,'YW867738820CN ','重量.1.2之内 '),(19133,819478610011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','amandasarm','amanda_mitchell@sbcglobal.net','Amanda Cedrone','7 Colony Rd','Seymour','CT','UNITED STATES','06483-3247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 21:58:17',0,NULL,3,1,1,1,'\\ ',NULL),(19134,604484651003,130598387084,'2 pairs of New in box SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'cnfaner','grzes09','grzesluton@onet.eu','GRZEGORZ BRONIECKI','6 MEYRICK COURT<br>MEYRICK AVENUE','LUTON','Bedfordshire','UNITED KINGDOM','LU1 5JP','07737802595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 22:22:52',0,NULL,3,1,3,1,'RA184549865CN ','OTSO004*2 '),(19135,819495954011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','fernygm12010','fernygm1@yahoo.com','fernando llamas','11367 pope ave','lynwood','CA','UNITED STATES','90262-3019','(323) 864-8433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 22:50:10',0,NULL,3,1,1,1,'\\ ',NULL),(19136,819496481011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',85.98,'eastar4uk','bhuvanesh.sankaran','bhuvanesh.sankaran@gmail.com','Bhuvanesh','10 Durham House<br>Redcliffe Road','Nottingham','Nottinghamshire','UNITED KINGDOM','NG3 5AU','01159857255','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 22:51:20',0,NULL,3,1,3,1,'RA184547153CN ','OTSO004 '),(19137,819499121011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','stevetheporter','stevehislop@hotmail.com','Christine Hislop','18 taunton close','bedford','Bedfordshire','UNITED KINGDOM','mk418nn','01234926244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 23:04:41',0,NULL,3,1,3,1,'RA184547140CN ','OTSO004 '),(19138,907947666012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','yarlev','y104395@gmail.com','Viacheslav Nazarov','urb. Parque de las Naciones, 143 B','(Alicante) Torrevieja','Comunidad Valenciana','SPAIN','03184','649517908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 00:13:01',0,NULL,3,1,3,1,'RA184549931CN ','GLOT001 '),(19139,819520761011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','cjbigott','cbigott@yahoo.com','Carlos Bigott','900 Bay Dr<br>Apt 507','Miami Beach','FL','UNITED STATES','33141-5654','(305) 868-4237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 00:21:19',0,NULL,3,1,1,1,'\\ ',NULL),(19140,604523327003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','m.a.s.e','meir.miyara@gmail.com','Meir Miyara','14700 Marsh Ln<br>apt 629','addison','TX','UNITED STATES','75001-8060','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 01:41:21',0,NULL,3,1,1,1,'\\ ',NULL),(19141,609843168004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','bcousens','bcousens@hotmail.com','Bradley Cousens','1300 N Astor St<br>Unit 9D','Chicago','IL','UNITED STATES','60610-6144','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 02:03:17',0,NULL,3,1,1,1,'\\ ',NULL),(19142,819550257011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',19.85,'eastar4','flaminga','evolwun@yahoo.com','Aaron Flaming','21856 SW Mandan Ct','Tualatin','OR','UNITED STATES','97062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 02:14:01',0,NULL,3,1,1,1,'\\   ',NULL),(19143,819558474011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','travel57','travel57@fastmail.fm','Eric Dinehart','381 Cambridge Dr','Ramsey','NJ','UNITED STATES','07446-1233','(201) 857-2037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 02:49:36',0,NULL,3,1,1,1,'\\ ',' '),(19144,907996007012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','gerardog84','gerardog84@hotmail.com','Nikos Giannopoulos','Charilaou Trikoupi 15<br>Marousi','Athens','','GREECE','151 22','0030-2108060034','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 03:13:19',0,NULL,3,1,3,1,'RA184547215CN\r ','LGAD001 '),(19145,663467322013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',2,'GLOT001*2',177.98,'eastar4','iv-5413','tristan647@mail.ru','Ivan Zatylnyi','Baitursynova st.<br>H33 P6','Almaty','','KAZAKHSTAN','050012','(727) 233-08-75','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 03:32:19',0,NULL,3,1,3,1,'RA184547290CN\r ','GLOT001*2 '),(19146,775067349001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',30.89,'buysia','hottiew5','nahgemlw48@aol.com','Meghan Walker','9901 Taylor Rd','chesterfield','VA','UNITED STATES','23838-1323','(804) 739-3045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 04:00:53',0,NULL,3,1,1,1,'\\ ','买了2个\rMonster House  New sealed 3D Blu-ray ship 1个\rAlice in Wonderland New sealed 3D Blu-ray Region: A,B,C\r1个'),(19147,609863357004,140482241347,'New Genuine Motorola RAZR H3 Bluetooth Headset track#',1,'HSMO003',11.99,'cnfaner','thread1213','gilbert26@sbcglobal.net','gilbert castillo','1350 S Union Ave','los angeles','CA','UNITED STATES','90015-2712','(213) 500-4407','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 04:11:37',0,NULL,3,1,1,1,'\\ ',NULL),(19148,819582359011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','brett0004','marshallmail@bigpond.com','Brett Marshall','935 Minha Street','Tom Price','Western Australia','AUSTRALIA','6751','0407441594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 04:42:19',0,NULL,3,1,3,1,'RA184547309CN\r ','GLOT001 '),(19149,8881325140096752,111,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',36.7,'eastar4','pablo_amar ','alabaladi2003@yahoo.com','Ahmad Omar Zawawi','No 1525 2nd FloorJalan Sultan Zainal Abidin','Kuala Krai','Kelantan','MALAYSIA','18000','017-9374737',NULL,NULL,NULL,'2011-12-29 06:28:16',0,NULL,3,1,6,1,'EE636829365CN ','客户打了20美金作为快递的运费 \r这个如果不能测试的话就挑出呈色好的发\r\r'),(19150,819605154011,320812367902,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','ruaway','urban71@optusnet.com.au','richard hsu','71 pittwater road','hunters hill','New South Wales','AUSTRALIA','2110','0417776231','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 07:11:34',0,NULL,3,1,3,1,'RA184537160CN\r ','HSNO033 '),(19151,819606666011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','wings_m84','wings_m84@hotmail.com','Daniel Cheong Chee Weng','BLK 230H TAMPINES ST21 #02-681','default','','SINGAPORE','522230','94574113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 07:22:15',0,NULL,3,1,11,1,'\\ ','HSUE004 '),(19152,819614019011,320814026548,'NIB genuine Philips SHS4843 Flexible Earhook Headphones ( Blue )',1,'HSPH005',22.9,'eastar4','syehudai','yehuda.ilan@gmail.com','yehuda ilan','44 Haagana St.','Kiryat Mozkin','','ISRAEL','26372','+972549996895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 08:14:55',0,NULL,3,1,11,1,'\\ ','HSPH005 '),(19153,757722397008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','bestguccishop','parfymshop@hotmail.com','Veton Usejni','Vikingavägen 28 C','Lund','Sweden','SWEDEN','22477','+46709560386','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-29 08:54:10',0,NULL,3,1,11,1,'\\ ','RELO001 '),(19154,819628240011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',6,'CASS003',50.94,'eastar4','g0m1','gumis@vidmo.net','Slawomir Kunach','14 Powdermill Mews','Waltham Abbey','Essex','UNITED KINGDOM','EN91JG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 09:37:52',0,NULL,3,1,3,1,'RA184547480CN\r ','CASS003 +CASS002\r再发三个NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T '),(19155,908070020012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','guanajo','canarioalpoder@hotmail.com','Carlos Javier RAMOS DARIAS DNI:54043386X','Ctra. Tabares nº72, La Cuesta','La Laguna','Santa Cruz deTenerife Islas Canarias','SPAIN','CP:38320','626056045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 09:38:35',0,NULL,3,1,11,1,'\\ ','GPS0010 '),(19156,908078674012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','bargain_collectables','tombright@talk21.com','Tom Bright','4 Lodgeside Gardens<br>Kingswood','Bristol','Bristol','UNITED KINGDOM','BS15 1NY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 10:19:27',0,NULL,3,1,3,1,'RA184547493CN\r ','LGAD001 '),(19157,609904598004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','jwilcox163','jontxlawdog@gmail.com','Jon Wilcox','6018 Scenic Links','Cibolo','TX','UNITED STATES','78108-2378','(210) 412-1115','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 10:24:50',0,NULL,3,1,1,1,'\\   ',NULL),(19158,908087115012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','teheternal0ne','cdykes222@hotmail.com','Chris Dykes','106 Blue Ridge Dr','Berea','KY','UNITED STATES','40403-9728','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 10:56:12',0,NULL,3,1,1,1,'LK167960719CN','GLOT001*2 '),(19159,819647893011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','elias123410','ilias6970@gmail.com','elias valantasis','lelas karagiani 59','likobrisi /athens','greece','GREECE','14123','6932736898','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 11:13:12',0,NULL,3,1,11,1,'\\ ','OTHP005 '),(19160,908093778012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','porisa2','aldesavi@hotmail.com','Larissa De Savi','2 Fairview Road','Crafers','South Australia','AUSTRALIA','5152','0883394228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 11:21:34',0,NULL,3,1,3,1,'RA184547666CN\r ','OTSO004*2 '),(19161,663529505013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','benkin88','auztraveler@hotmail.com','errol thomas','30A loffs road<br>jamboree heights','brisbane','Queensland','AUSTRALIA','4074','0732797056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 11:31:45',0,NULL,3,1,3,1,'RA184547462CN\r ','HBPH002 '),(19162,908095365012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','havingworld','bigsinner@ya.ru','Vladimir Teterin','Ladigina 2 - 370','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690037','89241310232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 11:33:16',0,NULL,3,0,11,1,'\\ ','LGGL005 '),(19163,775240309001,110715650982,'New 2010 FIFA World Cup Film 3D Blu-ray BD  Region Free',1,'BR3D008',14.99,'buysia','waggychillo','geoff.brown@cmi-plc.com','Geoff Brown','2a The Woodlands, Elizabeth Park','Wokingham','Berkshire','UNITED KINGDOM','RG414UY','01189774761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 12:56:39',0,NULL,3,1,3,1,'RA184547618CN\r ','BR3D008 '),(19164,908111733012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','fcalove','prinzpoldi@unitybox.de','Peter Kohlmaier','Im Bökel 46 N','wuppertal','','GERMANY','42369','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 12:31:44',0,NULL,3,1,3,1,'RA184547683CN\r ','GLOT001*2 '),(19165,819678413011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',3,'CASS002',24.87,'eastar4','g0m1','gumis@vidmo.net','Slawomir Kunach','14 Powdermill Mews','Waltham Abbey','Essex','UNITED KINGDOM','EN91JG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 13:20:39',0,NULL,3,1,17,0,NULL,'CASS002 '),(19166,609931960004,140626376379,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',17.4,'cnfaner','mschuurman1983','martijnschuurman@gmail.com','Martijn Schuurman','Alexanderplein 14','Nieuwleusen','','NETHERLANDS','7711 JX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 13:22:42',0,NULL,3,1,3,1,'RA184547578CN\r ','OTHP006 '),(19167,604621702003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',4,'RCLO007+POLO001+RCLO008*4',131.6,'cnfaner','bbd2u','service@bestbuydirect2u.com','Gene Friedman','83 Courtland Ave<br>Apt 3','Stamford','CT','UNITED STATES','06902-3441','(203) 921-5917','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 13:48:08',0,NULL,3,1,1,1,'LK166944136CN\r ',NULL),(19168,908140489012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','sachingopalgautam','sachin.gautam@y7mail.com','sachin gautam','unit no -3 ,177 Daws Road<br>St Marys','Adelaide','South Australia','AUSTRALIA','5042','0433587933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 14:12:02',0,NULL,3,1,3,1,'RA184547856CN\r ','GLOT001 '),(19169,908140980012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','jim4865','jim.martindale@yahoo.co.uk','james martindale','188 Boothferry road','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU4 6EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 14:13:04',0,NULL,3,1,3,1,'RA184547649CN\r ','LGAD001 '),(19170,819699802011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',9.88,'eastar4','kd7kxw','dsalexan@amazon.com','David Alexander','4810 W Lattin Rd','West Richland','WA','UNITED STATES','99353-6009','(509) 378-4851','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 14:35:36',0,NULL,3,1,1,1,'\\   ','acer 4pin1.25 6cm '),(19171,818842305002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','glmsugai','glmsugai@yahoo.com','Steven V Sugai','3116 Copper Creek Rd','Bloomington','IL','UNITED STATES','61704','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 15:02:12',0,NULL,3,1,1,1,'\\   ',NULL),(19172,908158202012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','gutejr','gutejr@gmail.com','Gutemberg Silva Braga Jr','Av,01 Qd,11 C,31 Habitacional Turu','São Luís','Maranhão','BRAZIL','65066680','559832261381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 15:06:34',0,NULL,3,1,3,1,'RA184547706CN\r ','OTSO004*2 '),(19173,908160243012,220815930507,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',32.9,'eastar4uk','blacksuv61','terenceyonghw@gmail.com','Yong Terence','117A Rivervale Drive #13-74<br>Singapore','Singapore','','SINGAPORE','541117','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 15:11:37',0,NULL,3,1,3,1,'RA184547737CN\r ','OTGR001+OTGR002+OTGR003 '),(19174,663573773013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','redmondcw617','redmondcw@aol.com','Redmond Walsh Jr','30 Gerrish St','Brighton','MA','UNITED STATES','02135-1705','(617) 254-2893','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 15:21:46',0,NULL,3,1,1,1,'\\   ',NULL),(19175,819717157011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','monthoj','james@fromyoufor.me','James Monthony','93 Meadowbank Rd<br>Suite 1149','Cornwall','PE','CANADA','C0A 1H0','(902) 566-3987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 15:31:20',0,NULL,3,1,11,1,'\\ ','ADAK002 '),(19176,908170323012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','amb3842','philippenadeau@hotmail.com','philippe nadeau','118 moisan','donnacona','QC','CANADA','g3m 0c5','(418) 999-8897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 15:39:39',0,NULL,3,1,11,1,'\\ ','BTAC2012 \racer 5pin1.25 6cm'),(19177,604650784003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.89,'cnfaner','charliechuckles1','grajan.mild@virgin.net','Graham Symonds','Winterbourne lodge44 Warren Drive','LEWES','East Sussex','UNITED KINGDOM','BN71HD','01273478804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 16:04:02',0,NULL,3,1,3,1,'RA184547581CN\r ','LGAD001 '),(19178,908182698012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','fusilier1241','mumblesmakin@yahoo.co.uk','christopher makin','128 stoneleigh st<br>derker','olldham','Lancashire','UNITED KINGDOM','ol1 4lf','01616522642','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 16:12:49',0,NULL,3,1,3,1,'RA184547799CN\r ','HSJA002\r英标 '),(19179,908184091012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','bretao07','andreiabretao@gmail.com','Andreia Silveira','Canada dos Calços, 56 - São Mateus da Calheta','Angra do Heroísmo','Açores','PORTUGAL','9700-565','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 16:16:40',0,NULL,3,1,3,1,'RA184547754CN\r ','OTSO004*2 '),(19180,819736219011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','beto4312','reidossucos@ig.com.br','adalberto rodrigues','rua marques de leão, 32 , ap. 106','RIO DE JANEIRO','RIO DE JANEIRO','BRAZIL','20780140','(021)9781-8128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 16:27:39',0,NULL,3,1,3,1,'RA184547710CN\r ','GLOT001 '),(19181,819740631011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','mbenshitrit2011','ebayaba@walla.com','moris ben shitrit','weizman 37','Tirat Carmel','zafon','ISRAEL','30200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 16:37:55',0,NULL,3,1,11,1,'\\ ','CC00002 '),(19182,663595371013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','garys2001','garyrogers45@hotmail.com','Gary S. Rogers','13591 SE Scenic Ridge Dr','Clackamas','OR','UNITED STATES','97015-7536','(702) 610-5891','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 16:42:55',0,NULL,3,1,1,1,'\\   ',NULL),(19183,908198371012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','goldy1308','nathangoldsworthy@hotmail.com','nathan goldsworthy','59<br>higher park close','plympton','Devon','UNITED KINGDOM','pl71xg','07429112314','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 16:52:40',0,NULL,3,1,3,1,'RA184547555CN\r ','LGAD001 '),(19184,908200278012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','shadowsgift','shadows.gift@gmail.com','David Woods','5 Carroll Gardens','Wickford','Essex','UNITED KINGDOM','SS129DL','07876782068','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 16:57:04',0,NULL,3,1,3,1,'RA184547595CN\r ','LGAD001 '),(19185,663601587013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','evgeniy.r','romanenko.evgeniy@gmail.com','Evgeniy Romanenko','5 Admiralskiy Str. App. 12','Odessa','','UKRAINE','65049','(093)4700905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 17:05:21',0,NULL,3,1,3,1,'RA184547476CN\r ','GPS0004 '),(19186,908203522012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','monica01969','monica.husby@hotmail.com','Monica Husby Moen','Rabben','Ekne','','NORWAY','7624','+4745205310','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 17:05:37',0,NULL,3,1,3,1,'RA184547825CN\r ','GLOT001 '),(19187,908205312012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','umpihanki','jouni__@hotmail.com','Jouni Kemppainen','Puolangantie 121','Ristijarvi','','FINLAND','88400','358405107857','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 17:20:34',0,NULL,3,1,3,1,'RA184547635CN\r ','LGRM001 '),(19188,818890890002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',11.98,'buysia','patricia11961','simonsez11961@aol.com','patricia simonton','4 Centerview Trl','ridge','NY','UNITED STATES','11961-1815','(631) 929-8540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 17:26:34',0,NULL,3,1,1,1,'\\   ',NULL),(19189,819762176011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','dunlap4travel','dcdunlap@sbcglobal.net','cliff dunlap','3501 s church st','visalia','CA','UNITED STATES','93277-7698','(559) 734-7151','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 17:36:30',0,NULL,3,1,1,1,'\\   ',NULL),(19190,775330993001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',33.89,'buysia','km-gm4u','kathygarymcquate@yahoo.com','Kathy McQuate','1331 State Route 603','Ashland','OH','UNITED STATES','44805-9720','(419) 903-0445','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 17:54:53',0,NULL,3,1,1,1,'\\   ','买了2个\rMonster House  New sealed 3D Blu-ray ship   1个\rNew Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides    1个\r\r\r'),(19191,908230344012,220747230973,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',14.9,'eastar4uk','jakk53','jakk53@live.co.uk','Jack Rogers','Flat D401, Newarke Point<br>8 Newarke Close','Leicester','Leicestershire','UNITED KINGDOM','LE2 7GZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 18:07:14',0,NULL,3,1,3,1,'RA184547533CN\r ','HSUE002 '),(19192,908236741012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','gabesthablade','m1286102@qub.ac.uk','Gabriel McErlean','3 Ardenlee Rise','Belfast','Antrim','UNITED KINGDOM','BT6 8QD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 18:21:37',0,NULL,3,1,11,1,'\\ ','BTAC2000 '),(19193,819780920011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','slush_puppie81','neil_crispin@hotmail.com','Neil Crispin','18 salisbury road','worcester park','Surrey','UNITED KINGDOM','KT47DG','02083376170','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 18:22:23',0,NULL,3,1,3,1,'RA184547670CN\r ','OTSO004 '),(19194,908239645012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','craig8902','craig.burn@btconnect.com','Craig Burn','15 Glendinning Road','Kirkliston','West Lothian','UNITED KINGDOM','EH29 9HE','07951051876','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 18:29:04',0,NULL,3,1,3,1,'RA184547516CN\r ','LGAD001 '),(19195,908252400012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','kaban978','osorokin978@gmail.com','Oleg Sorokin','5272  Pandora Str','Burnaby','BC','CANADA','V5B 1L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 18:55:15',0,NULL,3,1,3,1,'RA184547564CN\r ','OTIN005 '),(19196,908253451012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','tseklinet','nmantis@star.gr','mantis nikos','EFKLIDI 20','ATHENS','ELEFSINA','GREECE','19200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 18:57:26',0,NULL,3,1,3,1,'RA184547502CN\r ','LGRM001 '),(19197,819798562011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',4,'OTSO004',171.96,'eastar4uk','lkreth','liz@ellengowan.com','ELIZABETH FERGIE','Ellengowan House, almondbank','Perth','Perthshire and Kinross','UNITED KINGDOM','PH13NG','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(19198,663638476013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','oster66daniel','osterdaniel@hotmail.com','daniel oster','2796 mackay','st-hubert','QC','CANADA','j4t2m9','(450) 466-6608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 19:11:21',0,NULL,3,1,3,1,'RA184547808CN\r ','GLOT001*3 '),(19199,906380091012,220872406174,'4 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT006*4',175.99,'eastar4','msimon5','msbrowneyes99_99@yahoo.com','Melissa Wines','401 Mulberry St','Pioneer','OH','UNITED STATES','43554-7959','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 19:21:00',0,NULL,3,1,4,1,'YW865589562CN','兼容型3D眼镜  Korea TV专用 '),(19200,908274373012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','ameliaandjoesdad','philip.moore@homecall.co.uk','Adrian moore','Great wood cottage<br>Grimston','Tadcaster','North Yorkshire','UNITED KINGDOM','Ls24 9da','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 19:44:14',0,NULL,3,1,3,1,'RA184547771CN\r ','HSJA002\r英标 '),(19201,819826590011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','biggred0830','sparkey215@hotmail.com','robert janiszewski','2859 HEDLEY ST','PHILADELPHIA','PA','UNITED STATES','19137-1924','(215) 475-0068','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 20:10:33',0,NULL,3,1,1,1,'\\   ',NULL),(19202,908285253012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','honey2b16','honey.2.b@hotmail.co.uk','lynda smith','62 prole street<br>park vllage','wolverhampton','West Midlands','UNITED KINGDOM','wv10 9ad','07958686387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 20:02:47',0,NULL,3,1,3,1,'RA184547652CN\r ','LGAD001 '),(19203,908308287012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','siobhanmac028','maccers3789@hotmail.com','Siobhan MacNamara','54 Teconnaght Road','Ballynahinch','Down','UNITED KINGDOM','BT24 8ST','02844830839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 20:54:31',0,NULL,3,1,3,1,'RA184547547CN\r ','LGAD001 '),(19204,908314087012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','panasonic0','clivepearcey@hotmail.com','clive Pearcey','58 Waverley Road','Exmouth','Devon','UNITED KINGDOM','EX83HJ','01395277654','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 21:05:56',0,NULL,3,1,3,1,'RA184547745CN\r ','OTGR001+OTGR002 '),(19205,908314536012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','erskineblue5','davy.donaldson@btinternet.com','David Donaldson','65 Torran Drive','Erskine','Renfrewshire','UNITED KINGDOM','PA87EB','01418128084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 21:07:20',0,NULL,3,1,3,1,'RA184547785CN\r ','OTSO004*2 '),(19206,604733153003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','central1960','barbaraal@knology.net','Barbara C Curry','416 Cumberland Dr SE','Huntsville','AL','UNITED STATES','35803-1028','(256) 881-6643','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 20:55:54',0,NULL,3,1,1,1,'\\   ',NULL),(19207,908311553012,220826630299,'Kodak WiFi Card 4 Easyshare Digital Camera Printer dock',1,'WLKO001',16.99,'eastar4uk','10tenmen','thomasfamily3@sky.com','Gary Thomas','110 farm view road<br>kimberworth','Rotherham','South Yorkshire','UNITED KINGDOM','S61 2AP','07766441429','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 21:00:30',0,NULL,3,1,3,1,'RA184547768CN\r ','WLKO001 '),(19208,819856662011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'eastar4','hiki38b','fclair@fclair.eu','Franck CLAIR','Pessinges 142 ch Molire','Cervens','Rhône-Alpes','FRANCE','74550','0645815958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 21:24:28',0,NULL,3,1,11,1,'BJ01670169\r ','TRSN001 '),(19209,818989179002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','donhomer0','bishi11@yahoo.co.uk','Renato Thomas','3 Winchester Close<br>Hampton Street','Walworth','London','UNITED KINGDOM','SE17 3DQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 21:38:26',0,NULL,3,1,11,1,'\\ ','BR3D009 '),(19210,819866671011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','uroshu_1','uros.76@gmail.com','Uros Huzjak','Cepelnikova 22','Ljubljana','','SLOVENIA','1000','+38631347228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 21:51:04',0,NULL,3,1,11,1,'\\ ','RCLO007+POLO001+RCLO008*4 '),(19211,908333010012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','katil002','mech.sohail21925@gmail.com','Sohail Ahmed','102 Hamilton Road<br>Handsworth','Birmingham','West Midlands','UNITED KINGDOM','B21 8AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 21:52:16',0,NULL,3,1,3,1,'RA184547723CN\r ','OTSO004*3 '),(19212,908330110012,220747230995,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',15.9,'eastar4uk','trofin87','trofinlucian@ymail.com','trofin ionel','great north way 76','london','London','UNITED KINGDOM','nw4 1hs ','07741612471','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 21:54:14',0,NULL,3,1,3,1,'RA184547520CN\r ','HSUE003 '),(19213,908333686012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',60.48,'eastar4uk','martintye','martintye@hotmail.co.uk','Mr & Mrs Tye','42 O\'Connor Road','Aldershot','Hampshire','UNITED KINGDOM','GU11 2EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 22:01:36',0,NULL,3,1,3,1,'RA184547839CN\r ','一共买了两种东西LGAD001和LGRM001\r还有 LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV\r '),(19214,819871532011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','ylot8288','haimlotem@yahoo.com','Haim Lotem','129 Tall Ruff Dr.','Las Vegas','NV','UNITED STATES','89148','(702) 227-1991','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 22:03:41',0,NULL,3,1,1,1,'\\   ',NULL),(19215,663693034013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sunilsd','sunilshenoy@gmail.com','Sunil Dasanagadde','4336 Fairlands Dr','Pleasanton','CA','UNITED STATES','94588-3428','(408) 891-8860','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 22:16:47',0,NULL,3,1,1,1,'\\   ',NULL),(19216,819876772011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','5483ellice','ellice.miller@sbcglobal.net','Ellice Miller','2241 W 15th St<br>Apt 7','Los Angeles','CA','UNITED STATES','90006-4763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 22:18:21',0,NULL,3,1,1,1,'\\   ',NULL),(19217,908345081012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','acd1026','acd1026@yahoo.com','g andi','66<br>kemsley house','london','London','UNITED KINGDOM','se136qw','07985404288','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 22:19:28',0,NULL,3,1,3,1,'RA184547621CN\r ','OTHP004 '),(19218,765893696007,170751862088,'2 pairs New LG Premium Water Filter Gen11042FR-08 4 Kenmore and LG refrigertors',1,'LGFI001*2',99.99,'au-buy','mudsandberg','dbergin@westnet.com.au','Marica Bergin','31 Marinula Road','Geraldton','Western Australia','AUSTRALIA','6530','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-29 22:21:44',0,NULL,3,1,3,1,'RA184547842CN\r ','LGFI001*2 '),(19219,663696994013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','aaravsuhani06','paragbshah77@yahoo.com','PARAG SHAH','1108 CAMPHOR GLEN CT','VALRICO','FL','UNITED STATES','33594','(813) 857-6286','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 22:23:49',0,NULL,3,1,3,1,'RA184547811CN',NULL),(19220,819890985011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','atechatl','scott@adaptingtech.com','Scott Reiser','980 Nawench Drive','Atlanta','GA','UNITED STATES','30327','(404) 890-5525','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 23:00:55',0,NULL,3,1,1,1,'\\   ',NULL),(19221,819894044011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','ronjeri8','ronjeris@ida.net','Ronald Brown','2875 Lois Ln','Pocatello','ID','UNITED STATES','83201-1922','(208) 238-0233','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 23:10:26',0,NULL,3,1,1,1,'\\   ',NULL),(19222,609892415004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','greenenvironment','greenenv@hotmail.com','Gwan Choi','5133 Bellerive Bend Dr','College Station','TX','UNITED STATES','77845-4478','(979) 446-1010','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-29 23:32:43',0,NULL,3,1,1,1,'\\   ',NULL),(19223,908380486012,220886977173,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'eastar4uk','sup2149','paulkemp@email.com','Paul Kemp','53 Cherry Orchard Road<br>Lisvane','Cardiff','Cardiff','UNITED KINGDOM','CF140UD','02920755823','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 00:06:09',0,NULL,3,1,3,1,'RA184547887CN\r ','LGAD001\r'),(19224,663720322013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','s.m.mashud','smmashud@yahoo.com','S. MASHUD','77hoprtune, avenue.<br>kilburn','ADELAIDE','South Australia','AUSTRALIA','5084','0468990596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 00:12:28',0,NULL,3,1,3,1,'RA184547697CN\r ','GLOT001*2 '),(19225,819924087011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.95,'eastar4','mcroby63','marc_robillard2002@hotmail.com','Marc Robillard','4490, rue Forget','Terrebonne','QC','CANADA','J6X1Z4','(450) 492-9844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 01:01:39',0,NULL,3,1,3,1,'RA184547604CN\r ','LGAD001 '),(19226,663735534013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',48.99,'eastar4','misifuso25','ed_ortega25@hotmail.com','Eduardo Ortega Ruiz','7979 NW 21st ST<br>#SJO-50170','Doral','FL','UNITED STATES','33122','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 01:22:27',0,NULL,3,1,1,1,'\\   ','新地址\rEduardo Ortega Ruiz\r6703 NW 7th St\r# SJO-50170\rDoral FL 33126-6007\rUnited States\r '),(19227,819069461002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','gggood1','ebay.cash@yahoo.com','Kimberly Good','1053 Holly Ave','williamstown','NJ','UNITED STATES','08094-4380','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 02:17:12',0,NULL,3,1,1,1,'\\   ',NULL),(19228,760438757007,170728921737,'Original New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',58.99,'au-buy','dany-lou_1','dany-lou@hotmail.com','Daniel Parent','50 rue claveau','st Lin laurentides','QC','CANADA','J5m 2A7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 02:45:49',0,NULL,3,1,3,1,'RA184547958CN\r ','HSSE011 '),(19229,663753284013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','natandannie','ohlssons@bellsouth.net','Scott Ohlsson','5958 Snow Hill rd<br>Ste 144 PMB 117','Ooltewah','TN','UNITED STATES','37363-7834','(662) 202-7348','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 03:02:40',0,NULL,3,1,1,1,'、 ',NULL),(19230,663756382013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','5726stephaniev','ravj21083@yahoo.com','Bobby Vandeven','31261 Willow Ct','Foristell','MO','UNITED STATES','63348-2556','(314) 713-2381','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 03:09:31',0,NULL,3,1,3,1,'RA184547900CN',NULL),(19231,775507890001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',11.99,'buysia','kirillzhura','zhurankou@hotmail.com','Aliaksei Zhurankou','4836 147TH PL NE','MARYSVILLE','WA','UNITED STATES','98271-3422','(360) 320-9055','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'没付款 '),(19232,908438741012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','2005dickman','shyboi2@btinternet.com','Henry Dickman','18 William Morris Terrace<br>Shotton Colliery','Durham','Durham','UNITED KINGDOM','DH6 2PL','07771813201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 03:32:22',0,NULL,3,1,3,1,'RA184547873CN\r ','SCLO002 '),(19233,908439194012,220872406174,'4 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT006*4',175.99,'eastar4','brenzee101','bewhittaker@hotmail.com','brenzee whittaker','7311nw 12th sreet suit #12<br>gcm 11016','miami','FL','UNITED STATES','33126','(345) 917-6636','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 03:35:56',0,NULL,3,1,3,1,'RA184547895CN\r',NULL),(19234,819965291011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','hkeem1285','hkeem1285@yahoo.com','hakeem raheem','15 carver blvd','bellport','NY','UNITED STATES','11713-2110','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 04:00:59',0,NULL,3,1,1,1,'\\   ',NULL),(19246,663794047013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','k4reshk','nullhat@gmail.com','ByungKil Lee','112-2004 SamsungRiverHill-APT<br>Sanchon-Dong YongSan-Gu','Seoul','Seoul','KOREA,REPUBLIC OF','140-764','010-3460-3808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 07:45:54',0,NULL,3,1,11,1,'BJ01670168\r ','WLIN014 '),(19235,819967064011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','musicpro815','devilsbane@juno.com','Peter Rische','1192 W McConnell Rd','Freeport','IL','UNITED STATES','61032-9074','(815) 789-4069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 04:06:39',0,NULL,3,1,1,1,'\\   ',NULL),(19236,663766319013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','teacher200708','jan.seaman@duluth.k12.mn.us','Jan Seaman','4601 W 6th St','Duluth','MN','UNITED STATES','55807-2014','(218) 340-3861','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19237,819968235011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','dolav689','dolav6@msn.com','Olav Opstad','Tonstadbrinken 257','Trondheim','sør-trøndelag','NORWAY','7091','90509542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 04:13:24',0,NULL,3,1,3,1,'RA184547935CN\r ','GLOT001 '),(19238,908454542012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','benthedigikid','benowen@jasonhurley.net','Ben Owen','3004 Tanglewood Dr','Tyler','TX','UNITED STATES','75701-5016','(903) 372-4725','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 04:40:54',0,NULL,3,1,1,1,'\\   ',' 向日葵长柄伞 '),(19239,819974220011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','gwcbay','gw.builders@yahoo.co.uk','Dawn Wilson','1,Sandygate Mews,Marley Hill','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE165EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 04:45:13',0,NULL,3,1,3,1,'RA184547927CN\r ','RCLO007+POLO001+RCLO008*4 '),(19240,819976063011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','brittaniej030206','bjacobs030206@yahoo.com','Brittanie Jacobs','1007 Henckley Ave','Mobile','AL','UNITED STATES','36609-3061','(251) 895-6612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 04:55:02',0,NULL,3,1,1,1,'\\   ',NULL),(19241,819977862011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',3,'LGAD001',146.85,'eastar4','wallyball444','amigos444@aol.com','sergio s sarmiento','3704 Root Dr','troy','MI','UNITED STATES','48083','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 05:12:19',0,NULL,3,1,1,1,'\\   ',NULL),(19242,8881325222965710,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW ',1,'WLIN014',18.99,'aliexpress','1006042645','19672301@mail.ru','Sergey Lebedev	','Kashirskoe shosse, 140-175','Moscow','Moscow','RUSSIAN FEDERATION	','115561','+7 495 3997797',NULL,NULL,NULL,'2011-12-30 05:29:25',0,NULL,3,1,3,1,'RA184547860CN\r ','WLIN014 '),(19243,775537233001,110703651166,'ICE AGE 3  New Panasonic sealed 3D Blu-ray tracking#',1,'BR3D006',0,'buysia','john91480','explor@earthlink.net','John M  Iele','6247 Harcross Ct<br>null','Spring Hill','FL','UNITED STATES','34606-5613','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,1,1,'\\   ','2个已付款35.89USD \rICE AGE 3  New Panasonic sealed 3D Blu-ray   1个\rAlice in Wonderland New sealed 3D Blu-ray Region: A,B,C  1个\r\r'),(19244,610139605004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.88,'cnfaner','kayman-terran','kayman_terran@mail.ru','Roman Abramov','Pogranichnaya 42, App. 40','Petropavlovsk-Kamchatsky','Kamchatsky Kray','RUSSIAN FEDERATION','683032','+79248947327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 05:55:31',0,NULL,3,1,3,1,'RA184547944CN\r ','HSNO022\r欧标 '),(19245,818967785002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','charles35','claytonccarroll@yahoo.com','Clayton Carroll','2876 Highway 160','Bonifay','FL','UNITED STATES','32425-6451','(850) 547-2889','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 05:54:14',0,NULL,3,1,1,1,'\\   ',NULL),(19247,663795490013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.98,'eastar4','harleyfaye4000','faye.mahoney@bigpond.com','Faye Mahoney','8 Tasman Street','Surf Beach','New South Wales','AUSTRALIA','2536','0244713084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 07:59:53',0,NULL,3,1,11,1,'BJ01670165\r ','WLAT009+ANTY001 '),(19248,820007388011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','lostsoulforever','c.j.pritchard@btinternet.com','Conrad J. Pritchard','Redfield Cottage,77 Turnpike Road','Newbury','Berkshire','UNITED KINGDOM','RG14 2QR','07771797886','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 08:23:05',0,NULL,3,1,3,1,'RA184547989CN\r ','WLAT008 '),(19249,908496314012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','mattattack62','matthew.maunder@hotmail.com','Matthew Maunder','21 Dalrymple street','edge hill','Queensland','AUSTRALIA','4869','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 08:45:42',0,NULL,3,1,3,1,'RA184548009CN\r ','OTSO004*2 '),(19250,758095841008,180781265262,'New Grohe Multi Function hand Shower Head made in Germany+ 59\" Grohe hose',1,'OTGR001+OTGR002',39.9,'au-buy','jasonhass0','jasonhassard@optusnet.com.au','Jason Hassard','42 Inveray Av','Benowa','Queensland','AUSTRALIA','4217','0756791687','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-30 08:50:27',0,NULL,3,1,3,1,'RA184547992CN\r ','OTGR001+OTGR002 '),(19251,820012837011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',35.99,'eastar4','44557564','jianglin8888@yahoo.com.cn','lin jiang','6550 Jericho Turpike','Commack','NY','UNITED STATES','11725','(646) 267-6248','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-30 08:54:40',0,NULL,3,1,1,1,'LK166819283CN\r ',NULL),(19252,604852703003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15.79,'cnfaner','sh00reg','shooreg@gmail.com','Alexander Golenshin','Pushkin<br>Shishkova 14 - 112','Saint Petersburg','Saint Petersburg','RUSSIAN FEDERATION','196605','+7 921 981-9871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 09:11:05',0,NULL,3,1,3,1,'RA184547961CN\r ','HSNO005+CCNO001\r欧标 '),(19253,820017500011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','jmar66238','rmmao@aol.com','Jean-Yves MARCHISIO','6 Lotissement Les ALBIZZIAS<br>Chemin de SADURAN','BAGNOLS SUR CEZE','Languedoc-Roussillon','FRANCE','30200','0620203492','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 09:18:19',0,NULL,3,1,3,1,'RA184547975CN\r ','LGAD001 '),(19254,908502366012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','michelleath2008','michelle.atherton44@three.com.au','Michelle Atherton','19 Kalmaine Court','Diamond Creek','Victoria','AUSTRALIA','3089','0394383421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 09:17:05',0,NULL,3,1,3,1,'RA184548057CN ','GLOT005*2 '),(19255,8881325242047611,111,'New News Paper 3-Section Rain Sun Floding Umbrella   newspaper',1,'UM00038',0,'au-buy','sasirmisbunlar','mehmetcankomurcu@hotmail.com','Mehmet Can Komurcu','Yahyakaptan mahallesi C21 D16<br>Izmit','Kocaeli','Kocaeli','TURKEY','41000','00905377318610',NULL,NULL,NULL,'2011-12-30 10:47:27',0,NULL,3,1,3,1,'RA184539695CN\r ','UM00038\r白色的 \r为改差评赠的  '),(19256,8881325242868594,111,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','vagias8470','jvassilakis@gmail.com','yannis vassilakis','ikaroy 14a iraklio crete','iraklio ','','GREECE','','',NULL,NULL,NULL,'2011-12-30 11:01:08',0,NULL,3,1,3,1,'RA184539801CN\r ','HSNO033 '),(19257,908529678012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',2,'OTIN005',168,'eastar4','odinrox-br','odinrox@gmail.com','Leonardo Oliveira','Avenida Gales, 259','Franco da Rocha','Sao Paulo','BRAZIL','07847070',' 551196646269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 11:17:58',0,NULL,3,1,3,1,'RA184539885CN\r ','OTIN005\r'),(19258,908556418012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.95,'eastar4uk','snaker_shaker','janphilipp.schulz@gmx.de','Jan-Philipp Schulz','Dorfstr. 73a','Sassenburg','','GERMANY','38524','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 13:06:20',0,NULL,3,1,22,1,'BJ01670102\r ','UM00043 '),(19259,908559050012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.95,'eastar4uk','nanniejan2009','jan.hurley1@tesco.net','Jan Hurley','52 The Avenue','Newton Abbot','Devon','UNITED KINGDOM','TQ12 2BY','01626352212','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 13:10:51',0,NULL,3,1,3,1,'RA184537187CN\r ','UM00043 '),(19260,775617302001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','ugwoolar','jwoolar@earthlink.net','John E. Woolard','216 Millbrook Village Dr','Goldsboro','NC','UNITED STATES','27530','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 13:22:08',0,NULL,3,1,1,1,NULL,NULL),(19261,758168244008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','kipuff','kispalv@yahoo.com','Viktor Kispál','Munkácsy M.u. 6/a.','Bicske','','HUNGARY','H-2060','0036203426717','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 14:21:48',0,NULL,3,1,23,1,'bp04081201040010 ','BALO009 '),(19262,820093033011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','ich-bekomme-es','ich-bekomme-es@sven-becker.net','Sven Becker','2738083<br>Packstation 125','Berlin','','GERMANY','12277','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 14:38:43',0,NULL,3,1,21,1,'RA184537099CN\r ','RCLO009 \r邮局给退回来了\r没有到客户那'),(19263,819034003011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','rangerrick.2007','rihewett@kern.org','Rick Hewett','1272 Locust St','Willits','CA','UNITED STATES','95490-4643','(707) 459-1338','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 14:44:29',0,NULL,3,1,1,1,NULL,NULL),(19264,604906981003,130620867310,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','tjbkuop','jbkuop@gmail.com','John Baptist Ku','487 Michigan Ave NE','Washington','DC','UNITED STATES','20017-1518','(202) 529-5300 ext.: 172','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-30 14:44:40',0,NULL,3,1,1,1,'、 ',NULL),(19265,604909083003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','jeremyjohnson00','jeremyjohnson00@hotmail.com','Jeremy Johnson','8690 176th St W','Lakeville','MN','UNITED STATES','55044-6608','(952) 953-9366','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-30 14:58:49',0,NULL,3,1,1,1,NULL,NULL),(19266,908590227012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','wyatt1945','neil.wyatt2@ntlworld.com','neil wyatt','22 hazelmere road<br>petts wood','bromley','Kent','UNITED KINGDOM','br51pb','01689608834','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 14:59:54',0,NULL,3,1,3,1,'RA184527180CN\r ','OTSO004*3 '),(19267,820101004011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','gowrypirapa','jeyagowry@hotmail.co.uk','gowry pirapa','8 Sutherland Road','southall','Middlesex','UNITED KINGDOM','ub1 2dh','02035569550','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 15:07:35',0,NULL,3,1,3,1,'RA184527220CN\r ','GLOT001 '),(19268,908602452012,220448702976,'Acer Aspire 6935 6935G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',9.88,'eastar4','leo9561','leopan@gmx.de','Leonid Panasenko-Rein','Wiedenbrückerstr. 8','Bielefeld','','GERMANY','33647','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 15:26:51',0,NULL,3,1,2,1,'30110924281\r ','BTAC2016\racer 8pin0.8 16cm \r'),(19269,604916644003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','igor_888','igor@mazgan.com','Igor Perelman','Haim Shirman 36','Beer Sheva','Negev','ISRAEL','84833','525405940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 15:29:42',0,NULL,3,0,3,1,'RA184539545CN\r ',NULL),(19270,908605789012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','private.dancer','andrewbirtles@live.co.uk','Andrew Birtles','91 Ridling Lane ','Hyde ','Cheshire','UNITED KINGDOM','SK14 1PF','01613517966','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 15:38:37',0,NULL,3,1,3,1,'RA184537125CN\r ','OTSO004*4 '),(19271,820123116011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','dx89182','duoweixu@yahoo.com','Duowei Xu','4150 Murray Hill cres.','Mississauga','ON','CANADA','L5C 4H8','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19272,663882418013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','pr_vora','pr_vora@yahoo.com','Paras Vora','35 Copperdale Dr','Simpsonville','SC','UNITED STATES','29681-8168','(864) 990-5431','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 16:12:53',0,NULL,3,1,1,1,'LK168460285CN\r ','GLOT001*4\r'),(19273,908622193012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','kim23077011','kim230770@btinternet.com','Kim Turner','56, Washington Crescent','Newton Aycliffe','Durham','UNITED KINGDOM','DL5 4AS','07879883536','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 16:20:53',0,NULL,3,1,3,1,'RA184537831CN\r ','HSJA002\r英标 '),(19274,610232534004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','puddle_duck','gemma_mcclelland@hotmail.com','Gemma McClelland','61 Twydall Lane<br>Twydall','Gillingham','Kent','UNITED KINGDOM','ME8 6JF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 16:23:46',0,NULL,3,1,3,1,'RA184539713CN\r ','\r新地址\rAndy Mariner\r59\rCedar Court\rEpping\rEssex\rCM16 4HL\rUnited Kingdom\r '),(19275,610240971004,140671481128,'New Genious LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack)',1,'LGGL005',19.59,'cnfaner','vcdronen','rhacco1@gmail.com','ronen hacco','Moshe Sharett 16 a','haifa','','ISRAEL','26260','0524873206','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 16:44:43',0,NULL,3,0,3,1,'RA184537200CN\r ',NULL),(19276,610239058004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','traceur15','devil_servant@msn.com','Thierry Lavoie-Lamarre','3540 Loiselle','Longueuil','QC','CANADA','J3Y7X4','(450) 676-7315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 16:44:45',0,NULL,3,1,3,1,'RA184539435CN\r ','RCLO006\r中国航空小包挂号 '),(19277,758213035008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',11.8,'au-buy','oleg.vip','oleg.vpa@gmail.com','Oleg Paseka','yl.Zakrevskogo 35a, kv.180','Kyiv','','UKRAINE','02217','+380673289320','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 16:47:55',0,NULL,3,1,22,1,'BJ01670134 ','SCLO004 '),(19278,908634359012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','johnifanx98','xfan.ncsu@gmail.com','xiang fan','210 Slate Blue Pl','Cary','NC','UNITED STATES','27519','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 16:51:24',0,NULL,3,1,1,1,NULL,NULL),(19279,820146231011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','levi_stubby','tony@stubbington.demon.co.uk','Tony J Beckett','17 Leviathan Close<br>Stubbington','Fareham','Hampshire','UNITED KINGDOM','PO14 2SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 17:15:44',0,NULL,3,1,3,1,'RA184539452CN\r ','OTHP005 '),(19280,820152515011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN MANUEL ALMAGRO ROJAS','C/ ARAGONITO 7A','MALAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 17:33:29',0,NULL,3,1,21,1,'RA184537828CN ','GLOT001*4 '),(19281,820159239011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','greeka1','timothy.grivanos@utoledo.edu','tim grivanos','5437 Seaman Rd','oregon','OH','UNITED STATES','43616-2609','(419) 691-4524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 17:49:49',0,NULL,3,1,1,1,NULL,NULL),(19282,604954726003,130458358038,'New Genuine Motorola HS820 Bluetooth Headset  track#',1,'HSMO018',13.99,'cnfaner','broadsmithosbourne','broadsmith@hotmail.com','Osbourne  Smith','39 Howard Road<br>South Norwood','London','London','UNITED KINGDOM','SE25 5BU','02086569006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 18:02:56',0,NULL,3,1,23,1,'\\ ','欧洲小包 \rHSMO018\r英标'),(19283,663912611013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','cap.dave','dave.clark@dot.state.mn.us','david b clark','9291 Highway 53','cotton','MN','UNITED STATES','55724-8016','(218) 725-2769','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 18:05:43',0,NULL,3,1,1,1,NULL,NULL),(19284,908663129012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','carolbrynn','stuff@electricquill.com','Carol Larimer','30402 Penrod Dr','Agoura Hills','CA','UNITED STATES','91301-2067','(818) 879-7373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 18:10:44',0,NULL,3,1,1,1,'LK175110767CN\r ',NULL),(19285,604961753003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','mtnwayne','wlamay@swva.net','wayne lamay','PO Box 1<br>6604 Floyd Hwy N','Check','VA','UNITED STATES','24072-0001','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-30 18:28:47',0,NULL,3,1,1,1,'\\ ',NULL),(19286,663920860013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','ernestohamm','ernesto.hamm@ilglogistics.com','Ernesto Hamm Jimenez','6703 Nw 7th St<br># SJO-67494','Miami','FL','UNITED STATES','33126-6007','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 18:35:19',0,NULL,3,1,1,1,'LK172191470CN\r ','GLOT001*2\r'),(19287,820180907011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','tstucker','tstucker430@msn.com','Tracey Tucker','430 Kestrel Ln','Palmyra','VA','UNITED STATES','22963-4047','(434) 589-5835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 18:42:27',0,NULL,3,1,1,1,NULL,NULL),(19288,820183303011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','pnzrchimera','brownchimera@yahoo.com','Matt Brown','5027 Bradley Cir','Colorado Springs','CO','UNITED STATES','80911-1205','(361) 343-3344','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 18:48:26',0,NULL,3,1,1,1,'LK170879147CN\r ',NULL),(19289,663928381013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','sandysandman2323','sandman2323@live.ca','Sandy Andrade','355 ave de la pommeraie<br>j6y1w2','Terrebonne','QC','CANADA','j6y 1v6','(450) 508-3595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 18:59:08',0,NULL,3,1,3,1,'RA184537947CN ','GLOT001*4\r'),(19290,663933711013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','albertogemal','albertogemal@yahoo.co.uk','Alberto Gemal','Travessa Desembargador Luiz Paiva<br>No. 11 apto. 601','Niteroi','Rio de Janeiro','BRAZIL','24220-160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 19:16:28',0,NULL,3,1,3,1,'RA184527295CN\r ','GLOT001*2\r'),(19291,820197342011,320721848689,'3 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*3',205.99,'eastar4','stoneaa2011','kamensky_alex@mail.ru','Alexey Kamensky','Panfilov street 54-50','Almaty','KZ','KAZAKHSTAN','050004','7272376803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 19:24:22',0,NULL,3,1,3,1,'RA184527193CN\r ','OTSO004*3\r'),(19292,908701467012,220886922259,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',15.95,'eastar4uk','popspops84','olliebolliesooopa@gmail.com','Piotr Plocica','87A Northcote St','Northampton','Northamptonshire','UNITED KINGDOM','NN2 6BE','07760663346','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 19:33:09',0,NULL,3,1,3,1,'RA184537235CN\r ','UM00006 '),(19293,820211389011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','joni_80','joni_80@abv.bg','valeri valkov','5 Poulton Road flat 1','Fleetwood','Lancashire','UNITED KINGDOM','FY7 6TE','01253932885','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 19:58:16',0,NULL,3,1,3,1,'RA184527247CN\r ','GLOT001 '),(19294,820225141011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','diroosma','machadoroos@gmail.com','Diego machado','santa paula 100','Porto Alegre','rio grande do sul','BRAZIL','91540442','555199017160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 20:34:32',0,NULL,3,1,3,1,'RA184539815CN\r ','GPS0007\r'),(19295,610301883004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','urnotsorry','calvin_616@hotmail.com','Calvin Cheng','27-5840 Dover Crescent','Richmond','BC','CANADA','V7C 5P4','(604) 312-8081','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,NULL),(19296,908749821012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','admwalsh','myandigirl@gmail.com','Charlie Floyd','3600 College Park Dr<br>Apt 9303','Conroe','TX','UNITED STATES','77384-4812','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 21:21:43',0,NULL,3,1,1,1,NULL,NULL),(19297,605010973003,130490601932,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',15.99,'cnfaner','bobbeh89','bobbie89@googlemail.com','Bobbie Ruijzenaars','Kramatweg 91 1','AMSTERDAM','','NETHERLANDS','1095KD','0615648795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 21:38:05',0,NULL,3,1,23,1,'bp04081201040009 ','欧洲小包专线 \rWLDE002+ANTY001'),(19298,908313325012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004*2',167.98,'eastar4uk','skullaz','miguel_salim@hotmail.com','Miguel Salim','R. Almirante Indio do Brasil, 27','Porto Alegre','Rio Grande Do Sul','BRAZIL','91920490','5197129700','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 21:38:12',0,NULL,3,1,3,1,'RA184539735CN\r ','OTSO004*2 '),(19299,908757464012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',11.49,'eastar4uk','mato_sk_nm','grackom@gmail.com','Martin Gracko','1.maja 311/8','Nove Mesto nad Vahom','Slovakia','SLOVAK REPUBLIC','91501','+421904831404','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 21:38:54',0,NULL,3,1,22,1,'BJ01670131\r ','OTHP003 '),(19300,908762167012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','jillshomes86d5','jillshomes@aol.com','Jill Oldham','624 Country Club Dr','Prescott','AZ','UNITED STATES','86303-4060','(928) 273-1799','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 21:51:03',0,NULL,3,1,1,1,NULL,NULL),(19301,908762077012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',2,'HSJA002',27.2,'eastar4uk','barry6264','brbs@btinternet.com','Barry Roberts','5 Wellman Avenue','Brymbo','Wrexham','UNITED KINGDOM','LL11 5HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 21:51:24',0,NULL,3,1,3,1,'RA184537774CN\r ','HSJA002\r英标 '),(19302,820256165011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','m0nt11','avnaymov@gmail.com','Alexander Naymov','Budapeshtskaya st. 77-124','Saint-Petersburg','','RUSSIAN FEDERATION','192281','79213443403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 21:58:37',0,NULL,3,1,11,1,'BJ01670086\r ','HSJA002\r欧标\r'),(19303,820263441011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','cytye','stedaly@hotmail.com','stephen daly','81 johnswood drive','ashbourne','Meath','IRELAND','default','018350603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 22:22:00',0,NULL,3,1,3,1,'RA184539355CN ','OTSA001\r'),(19304,908778701012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','kittysxk','stevenkitson@hotmail.co.uk','steven kitson','31 upper hatfield place<br>havercroft','wakefield','West Yorkshire','UNITED KINGDOM','wf4 2hl','01977614031','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 22:38:55',0,NULL,3,1,3,1,'RA184537845CN\r ','HSJA002\r英标 '),(19305,820277857011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','jaypozx9r','jaypozx9r@yahoo.com','jason potenziani','931 Lyons Rd<br>Apt 4205','coconut creek','FL','UNITED STATES','33063-6764','(954) 324-6830','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 23:05:37',0,NULL,3,1,1,1,NULL,NULL),(19306,663994201013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','riverboat4410','carter4410@mchsi.com','Greg Carter','4410 Coachman Ln NE','prior lake','MN','UNITED STATES','55372-4108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 23:07:01',0,NULL,3,1,1,1,'、 ',NULL),(19307,820278633011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','keyboard104','andy3623@googlemail.com','Andy Bracey','Sevenoaks District Council<br>Argyle Road','Sevenoaks','Kent','UNITED KINGDOM','TN13 1HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 23:08:23',0,NULL,3,1,3,1,'RA184539378CN\r ','keyboard104 '),(19308,820286198011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','chrisaubury','chrisaubury@hotmail.co.uk','chris aubury','10 Seyton Park','Dollingstown','Down','UNITED KINGDOM','bt66 7hy','02838326546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 23:37:26',0,NULL,3,1,3,1,'RA184527321CN\r ','GLOT001 '),(19309,605049923003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','jovani971','apharel.thierry@gmail.com','thierry apharel','5 bis rue bebian','pointe a pitre','Guadeloupe','GUADELOUPE','97110','0590932567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 00:47:51',0,NULL,3,1,3,1,'RA184527658CN\r ','中国航空小包挂号 \rMOOE003'),(19310,820305897011,320394916388,'Acer Aspire 5570 5570Z Bluetooth Module EDR 2.0+cable',1,'BTAC2015',9.88,'eastar4','zbg_1492','zbg_1492@yahoo.com','Zuri Bustos','2551 W Cermak Rd<br>Star Locks Suite w29','Chicago','IL','UNITED STATES','60608-3719','(773) 216-3479','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 00:55:52',0,NULL,3,1,1,1,NULL,'acer 6pin1.25 23cm '),(19311,664017491013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','jershelt','jershelt@aol.com','jerry  shelton','1535 holyoak ln','lucas','TX','UNITED STATES','75002-7819','(972) 727-8535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 01:06:06',0,NULL,3,1,1,1,NULL,NULL),(19312,908830241012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','dimitecon','dimitecon@aol.com','Dimitrios Economides','605 Burcham Dr','East Lansing','MI','UNITED STATES','48823-2746','(517) 351-3605','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 01:43:19',0,NULL,3,1,1,1,'LK174402809CN\r\r ','GLOT001*4\r'),(19313,605059251003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.59,'cnfaner','mizerak','mizerakpool@yahoo.com','Kevin Wiley','8917 N HWS Cleveland BLVD','Bennington','NE','UNITED STATES','68007-2208','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-31 01:46:33',0,NULL,3,1,1,1,'\\ ',NULL),(19314,908834350012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','psalteryschool','kratcliffe7@bigpond.com','Susanne J Ratcliffe','12a Robert St.','Tenambit','New South Wales','AUSTRALIA','2323','0249333582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 01:59:59',0,NULL,3,1,11,1,'BJ01670098\r ',''),(19315,820327097011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',2,'OT00002',25.98,'eastar4','blbaughdesigns','sales@blbaughdesigns.com','bobby baugh','606 n grand ave','doniphan','MO','UNITED STATES','63935-1408','(573) 429-2732','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 02:32:04',0,NULL,3,1,1,1,'\\ ',NULL),(19316,908845587012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','pierce.macmillan','pierce.macmillan@gmail.com','Pierce MacMillan','1101 Chatham Pkwy<br>Ste E-2','Savannah','GA','UNITED STATES','31408-3047','(912) 844-0583','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 02:46:52',0,NULL,3,1,1,1,NULL,NULL),(19317,664040515013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','darthmyr','jesus.dacal@gmail.com','Encore Int\'l Trading, Inc.','6829 College Ct','Davie','FL','UNITED STATES','33317-7172','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 03:23:12',0,NULL,3,1,1,1,'LK170298592CN\r ','GLOT001*2\r'),(19318,664038717013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','macgyyvver','k_o_r@msn.com','Kjell Ove Raphaug','Bruaplassen 4','Ler','','NORWAY','7234','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 03:24:57',0,NULL,3,1,22,1,'BJ01670127\r ','\r\r'),(19319,605075681003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','unotice2','linus588@hotmail.com','linus king','54 dumfries ave','brampton','ON','CANADA','L6Z 2Y3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 03:34:33',0,NULL,3,1,3,1,'RA184539347CN\r ',' 中国航空小包挂号\rRCLO007+POLO001+RCLO008*4'),(19320,758407547008,180766381393,'New Genuine Motorola H700 Bluetooth Wireless Headset+ Car Charger',1,'HSMO011+CCMO001',17.99,'au-buy','gabby-14','nical1@virginbroadband.com.au','Alan Peckham','3 Humberstone    Ave, Hayborough','Adelaide','South Australia','AUSTRALIA','5211','0885522008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-31 03:46:27',0,NULL,3,1,11,1,'BJ01670139 ','HSMO011+CCMO001 '),(19321,766340725007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','tomcatpat','patmcd@san.rr.com','Pat McDonnell','8729 Edulis Ct','San Diego','CA','UNITED STATES','92129','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-31 03:52:35',0,NULL,3,1,1,1,NULL,'RCLO007+POLO001+RCLO008*4 '),(19322,820308096011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','nighthawk264','jamrhodes@suddenlink.net','James Rhodes','524 Barrington Dr','Bossier City','LA','UNITED STATES','71112-3186','(318) 573-6329','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-31 03:56:20',0,NULL,3,1,1,1,NULL,NULL),(19323,664050819013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','templarbooks','author@stephendafoe.com','Templar Books','Stephen Dafoe<br>PO Box 3135','Morinville','AB','CANADA','T8R 1S1','(780) 939-1016','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 04:31:08',0,NULL,3,1,3,1,'RA184527335CN\r ','GLOT001*2\r'),(19324,605088432003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','martinmor9','martin23mm@gmail.com','martin morales','10946 S Van Ness Ave','Los Angeles','CA','UNITED STATES','90047-4613','(424) 205-8252','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-31 05:17:36',0,NULL,3,1,1,1,'\\ ','在E邮包中找不到\r不知道是否打印 '),(19325,664065467013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','tad-jbl-sa-deqx','uma-tad-jbl.86@mail.ru','aleksey vladimirovich','Krasnoarmeyskaya 18','Mytishchi','','RUSSIAN FEDERATION','141014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 06:38:24',0,NULL,3,1,11,1,'BJ01670145 ','CASS003\rCAB-6060\r'),(19326,908900252012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','jpilling64','jlpill@yahoo.com','John Pilling','13 Kurrajong Place','Greenwood','Western Australia','AUSTRALIA','6024','0894475162','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19327,664077438013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','beaubarre','np@newtale.com','Nguyen Phi','48 boulevard Murat','Paris','Île-de-France','FRANCE','75016','06.76.16.19.99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 08:39:58',0,NULL,3,1,11,1,'BJ01670142 ',NULL),(19328,758454775008,180699062186,'Plantronics Altec lansing Backbeat 903 Bluetooth Headse',1,'HSPL015',50.26,'au-buy','bnr32gav','gtrgav@yahoo.com.au','Gavin Beer','Arafura Resources<br>Level 5, 16 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','0862107620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-31 09:16:54',0,NULL,3,1,3,1,'RA184539877CN\r ','HSPL015\r澳标 '),(19329,820392771011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT006',44.89,'eastar4','irenaperusko','tomislav.hodak@yahoo.com','tomislav hodak','vinkuran kucine 62','Pula','istarska zupanija','CROATIA','52100','0038598637535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 09:28:36',0,NULL,3,1,21,1,'RA184527216CN\r ','GLOT006\r兼容型3D眼镜  Korea TV专用\r'),(19330,664088958013,230721079075,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',99.99,'eastar4','0357serty','stratosvarkaris@hotmail.com','STRATOS VARKARIS','NOTARA 7','KAVALA','','GREECE','65201','2510226563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 10:12:01',0,NULL,3,1,21,1,'RA184539660CN\r ','GPS0011\r'),(19331,820408898011,320814026443,'NIB Genuine LG Premium Water Filter Gen11042FR-08 for Kenmore LG refrigerators',1,'LGFI001',51.99,'eastar4','hangle00','vegaboutique@yahoo.com','hang le','Shop 4/24-32 Hughes St','Cabramatta','New South Wales','AUSTRALIA','2166','0450749375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 10:50:06',0,NULL,3,1,3,1,'RA184539466CN\r ','LGFI001\r'),(19332,664102159013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','zivac87','dzivoder@gmx.com','Dejan Zivoder','Ul. Jaglaca 5','Popovaca','Sisacko-Moslavacka','CROATIA','44317','+38598437868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 11:39:20',0,NULL,3,1,22,1,'BJ01670128\r ','\r'),(19333,906469916012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','millimetronyj','millimetrony@yandex.ru','Anthony Poverinov','Zvezdnaya','Lipetsk','Lipetsk','RUSSIAN FEDERATION','398035',' 89042190708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 13:22:52',0,NULL,3,1,11,1,'BJ01670146 ','MOMI002\r黑色的\r'),(19334,664127108013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','rihad10','rihaddehaini@hotmail.com','Rihad Dehaini','Rua Victor do amaral, 1660<br>Rihad Palace hotel','araucaria','parana','BRAZIL','83702040','55 41-99531553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 13:59:49',0,NULL,3,1,3,1,'RA184539948CN\r ','GPS0006\r'),(19335,766451776007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'au-buy','yhac_pcd130mm','mk2trance@m4.dion.ne.jp','Masayoshi Kanada','Nakagawa-ku Housei-chou 1-3-513','Nagoya-shi','Aichi','JAPAN','454-0803','81-080-5111-9446','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-31 14:17:17',0,NULL,3,1,11,1,'BJ01670143 ','HSUE003 '),(19336,820465820011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','calbri03','shaggydus@sbcglobal.net','David Lenius','4755 N Kewanee Ave','chicago','IL','UNITED STATES','60630-4323','(312) 860-5862','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 14:40:52',0,NULL,3,1,1,1,'LK164129921CN\r ',NULL),(19337,766458550007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.99,'au-buy','inkubik','opl23akkw@mail.ru','Benjamin Kublanov','Suvorovsky av., 37, kv. 18','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','191144','79219411493','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-31 14:41:21',0,NULL,3,1,11,1,'BJ01670092\r ','UM00053 '),(19338,820470776011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','gromerop','grp.correo@gmail.com','Gonzalo Romero','Juan Florez 36 19-d','A Coruña','A Coruña','SPAIN','15004','639656441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 14:56:36',0,NULL,3,1,2,1,'30110923242\r ',NULL),(19339,820474207011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT006*2',88.99,'eastar4','brunothoiry','bfaure@ford.com','FAURE Bruno','Fmc Automobiles division Ford Service Marchés Publics<br>34 RUE DE LA CROIX DE FER','SAINT GERMAIN EN LAYE CEDEX','Ile-de-France','FRANCE','78122','0664406387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 15:07:26',0,NULL,3,1,3,1,'RA184527281CN\r ','GLOT006*2\r\r'),(19340,664148080013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','pine004','z004@aol.com','ROBERT ZELKO','W236S4630 Whispering Hills Ct<br>null','waukesha','WI','UNITED STATES','53189-9774','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 15:32:13',0,NULL,3,1,1,1,'LK172221110CN\r ','GLOT001*2\r'),(19341,909017225012,220682405866,'2.1 HP DV6500 DV6800 DV6900 Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','jmassimilla','jfmass830@verizon.net','Joseph Massimilla','337 Spruce Ave','Maple Shade','NJ','UNITED STATES','08052-1846','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 15:39:03',0,NULL,3,1,1,1,NULL,'HP 8pin 1.25 18cm  '),(19520,821567020011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','arcade135757','arcade1357@msn.com','mark reets','4661 Calamity Ln NW','bremerton','WA','UNITED STATES','98312-9445','(360) 377-0310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 08:02:12',0,NULL,3,1,1,1,'LK173319963CN\r ',NULL),(19342,664162393013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','tinkerer03','tinkerer4@yahoo.co.uk','William H. Vincent Jr.','3103 Knob Creek Rd','Shepherdsville','KY','UNITED STATES','40165-5869','(502) 922-3466','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 16:27:43',0,NULL,3,1,1,1,NULL,NULL),(19343,820520792011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','mhh1978','mhawk1978@yahoo.com','Michael Hawkins','5734 Yarborough Ln','Lakeland','FL','UNITED STATES','33812-4169','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 17:28:33',0,NULL,3,1,1,1,'LK169907194CN\r ',NULL),(19344,909071201012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','donbga','donsbryant@gmail.com','Don Bryant','3270 Old Oaks Rd','Buford','GA','UNITED STATES','30519-4079','(770) 932-5501','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 18:02:10',0,NULL,3,1,1,1,'、 ',NULL),(19345,820561574011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'eastar4','darkvol','darkvol@swbell.net','Jay Hickman','1912 Fairfax Dr','Corsicana','TX','UNITED STATES','75110-2090','(903) 872-3339','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-31 19:45:49',0,NULL,3,1,1,1,'\\ ',NULL),(19346,663436668013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',5,'CASS003',42.45,'eastar4','kracksmith4ejm','kracksmith@gmail.com','alex yuan','3900 hamner ave','mira loma','CA','UNITED STATES','91752-1017','(714) 932-8820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 20:08:19',0,NULL,3,1,1,1,NULL,'CASS003  '),(19347,909111239012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',7.57,'eastar4','ccie14745','ccie14745@gmail.com','Justin White','3136 Round Tree Ln','Frisco','TX','UNITED STATES','75034-4589','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 20:12:18',0,NULL,3,1,1,1,NULL,NULL),(19348,664213209013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','scrubik','9596761@gmail.com','Anatoly Smirnov','50-let oktyabrya h.19 app.36','pos. Pesochnoe','Leningradskaya oblost','RUSSIAN FEDERATION','188852','(921)9596761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 20:20:04',0,NULL,3,1,11,1,'BJ01670140 ','HSNO019 \r欧标'),(19349,909118842012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','arthurzico69','arthurdamasceno@globo.com','Arthur Damasceno','Rua Babilônia 21 / Apto. 403','Rio de Janeiro','RJ','BRAZIL','20511150',' 2181076445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 20:45:44',0,NULL,3,1,3,1,'RA184537023CN\r ','OTSO004*2 '),(19350,909131562012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','nickferrugia','ferrugia.1@gmail.com','Nick Ferrugia','1215 Polaris Parkway142','Columbus','OH','UNITED STATES','43240','(614) 560-5531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 21:29:05',0,NULL,3,1,1,1,'LK170858632CN\r ',NULL),(19351,909138950012,220917833039,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',177.99,'eastar4','paulbates_88','paulbates88@hotmail.com','Paul Bates','P.O. Box 511','Grande Cache','AB','CANADA','t0e 0y0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 21:58:07',0,NULL,3,1,3,1,'RA184527975CN\r ','GLSG009*2 '),(19352,820604880011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','rrus1112','robert.c.russell@jci.com','Robert Russell','6016 Glenbarr Place','Dublin','OH','UNITED STATES','43017','(614) 766-2637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 22:43:51',0,NULL,3,1,1,1,NULL,NULL),(19491,909687463012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','janespiano','gjjn@iprimus.com.au','jane hunt','22 lilyfield close','Catherine Field','New South Wales','AUSTRALIA','2557','0296067452','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 23:12:04',0,NULL,3,1,3,1,'RA184537156CN\r ','OTSO004*2 '),(19509,605905007003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','rockvegasriverroadrat','tanya.marsh@yahoo.com','Tanya E Marsh','8905 PENNY HILL DR','HUNTERSVILLE','NC','UNITED STATES','28078','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-03 04:52:45',0,NULL,3,1,1,1,'LK171844100CN\r ',NULL),(19353,909158036012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','yasawa_croft','lchung@bigpond.net.au','Lawrence Chung','26 Albert Road','Beecroft','New South Wales','AUSTRALIA','2119','0419804100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 23:20:13',0,NULL,3,1,3,1,'RA184537010CN\r ','OTSO004*2 '),(19354,820615505011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','gilesdr','gilesdr@verizon.net','Daryl Giles','1035 San Bernardino Blvd','Ridgecrest','CA','UNITED STATES','93555-8204','(760) 939-3023','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 23:39:22',0,NULL,3,1,1,1,NULL,NULL),(19355,909168994012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','lms5000','shawlisa@comcast.net','Lisa Shaw','56 Marshal St<br># 3','Brookline','MA','UNITED STATES','02446-5423','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 00:12:40',0,NULL,3,1,1,1,NULL,NULL),(19356,664257832013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','tigrtom10','tshansen1@gmail.com','Thomas Hansen','3106 White Daisy Pl','Fairfax','VA','UNITED STATES','22031-1454','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 00:56:25',0,NULL,3,1,1,1,NULL,NULL),(19357,820630321011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','rettq','rettq@hotmail.com','Rett Quattlebaum','135 Clarendon St<br>Apt 8R','Boston','MA','UNITED STATES','02116-5280','(843) 670-0786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 01:00:41',0,NULL,3,1,1,1,NULL,NULL),(19358,909190981012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','marceloptirus','ptirus@bol.com.br','Marcelo Soares','Av. Oceânica 1803/104','Guarapari','Espirito Santo/Guarapari/Praia do Morro','BRAZIL','29216080','+55 28 88018206','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 01:57:50',0,NULL,3,1,3,1,'RA184539421CN\r ','GLOT001 '),(19359,664270966013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','vinaymote1','vinaymote1@yahoo.com','Vinay Mote','2106/28<br>Wills Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 02:31:42',0,NULL,3,1,3,1,'RA184539599CN\r ','GLOT005\r DLP 3D ready 投影仪兼容眼镜'),(19360,664064502013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','malnuaimi-2009','mohamed1967moh@yahoo.com','Mohammed.A.AL-Nuaimi','9401 Tanager St<br>Apt 3815','Houston','TX','UNITED STATES','77036-6708','(510) 239-6573','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 02:44:27',0,NULL,3,1,1,1,'LK174165132CN\r ',NULL),(19361,820652953011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','rickyhktg','rickyhktg@yahoo.com.au','Ricky Pietrobon','6 First Ave','Payneham Sth','South Australia','AUSTRALIA','5070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 03:07:28',0,NULL,3,1,11,1,'RA184539568CN\r ','MOLA001 '),(19362,909205002012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','emma24481','ems.marshall@googlemail.com','Emma Marshall','268A Hector Street','Tuart Hill','Western Australia','AUSTRALIA','6060','0451829837','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 03:18:23',0,NULL,3,1,3,1,'RA184527255CN\r ','GLOT001*2 '),(19363,664279713013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','mikeg410_0','gray2016@sbcglobal.net','Andrea Thune','3044 GALLOPING HILLS RD','Chino Hills','CA','UNITED STATES','91709-4366','(818) 645-3730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 03:44:47',0,NULL,3,1,1,1,'LK174849888CN\r ','GLOT001*3 '),(19364,909221875012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','tigaars_freunde','tigaar@gmx.de','Lucas Eisenzimmer','115 Gore Street','Fitzroy','Victoria','AUSTRALIA','3065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 05:10:24',0,NULL,3,1,3,1,'RA184539611CN\r ','WWOT001 '),(19365,664291129013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','doogs290780','doogs80@adam.com.au','Paul Dugar','2 Morris Street','Paralowie','South Australia','AUSTRALIA','5108','610402344763','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 05:44:25',0,NULL,3,1,3,1,'RA184539497CN\r ','GLOT001*3 '),(19366,819837223011,320679565914,'New Jabra BT320s Stereo Bluetooth ClipOn Earbud Headset',1,'HSJA003',14.99,'eastar4uk','auction2b','cav@ptc.co.il','Cav systems Eli Smadar','haeshel 7 pob 3101<br>Cesaria Industry park','Cesaria','israel','ISRAEL','38900','+972-52-3255581','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 07:29:43',0,NULL,3,1,3,1,'RA184539832CN\r ',NULL),(19367,766667423007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','kelly5510','andrewkw@bigpond.com','Andrew K Williams','152 East Terrace','Henley Beach','South Australia','AUSTRALIA','5022','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-01 07:34:40',0,NULL,3,1,11,1,'BJ01670103\r ','RELO002 '),(19368,664303990013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','kgilbert93','k.gilbert93@live.com','Peter Gilbert','281 Railway Tce','Taperoo','South Australia','AUSTRALIA','5017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 08:35:53',0,NULL,3,1,3,1,'RA184527278CN\r ','GLOT001*2 '),(19369,820442568011,320801187531,'NIB genuine Philips SHS4800 Flexible Earhook Headphones 5-position adjustable',1,'HSPH003',13.99,'eastar4uk','davidg7594','david@dege.karoo.co.uk','David Gay','31Ascott Close','Hull','Yorkshire','UNITED KINGDOM','hu4 6eq','01482569254','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 08:46:28',0,NULL,3,1,3,1,'RA184539625CN\r ','HSPH003 '),(19370,820695304011,320762413525,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','telstar5564','chrishadkiss@gmail.com','Christopher Hadkiss','21 Broad Lane Wilmington','Dartford, Kent','Kent','UNITED KINGDOM','DA27AQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 09:16:12',0,NULL,3,1,3,1,'RA184539863CN\r ','HBPH001 '),(19371,909064897012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','alboatblue','lighthome@hotmail.co.uk','Mr A. B. Light','8 Lunty Mead<br>Backwell','Nr. Bristol','Avon','UNITED KINGDOM','BS48 3LG','07754982794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 09:48:40',0,NULL,3,1,3,1,'RA184537142CN\r ','OTSO004*4 '),(19372,909259318012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',17.5,'eastar4','prophetin','info@prophetin.de','Thomas Eichelroth','Alter Oßweiler Weg 53','Ludwigsburg','','GERMANY','71638','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 10:04:45',0,NULL,3,1,2,1,'30110910955\r ',' '),(19373,818347880011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','philthydrums','phillarnold.thedrummer@googlemail.com','Phillip Arnold','21 Tower Avenue<br>Upton','Pontefract','West Yorkshire','UNITED KINGDOM','WF9 1EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 10:24:54',0,NULL,3,1,3,1,'RA184539951CN\r ','MOAP001 '),(19374,820555833011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','ksh4002','healeykris40@hotmail.com','Mr K Carroll','9 River Way','Larkfield','Kent','UNITED KINGDOM','me20 6rs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 10:41:48',0,NULL,3,1,3,1,'RA184539418CN\r ','GLOT001 '),(19375,908920305012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','44190_0','ds0033g7823@btinternet.com','De Elmo  Santana','5 Lenham Road, Thornton Heath','Surrey','Surrey','UNITED KINGDOM','CR78QT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 10:33:45',0,NULL,3,1,3,1,'RA184527091CN\r ','ANCN001 '),(19376,908971323012,220871869126,'Genuine Jabra BT250V Bluetooth Headset BT 250V',1,'HSJA001',16.9,'eastar4uk','geoffrey7837','geofcannon@msn.com','Geoffrey Cannon','19 Wicks Crescent, Formby','Liverpool','Lancashire','UNITED KINGDOM','L37 1PD','01704830389','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 11:40:18',0,NULL,3,1,3,1,'RA184539656CN\r ','HSJA001\r英标 '),(19377,820422489011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',17.99,'eastar4uk','chris_ellis_01376','chris_ellis_01376@hotmail.com','Chris Ellis','129 Colne Road','Halstead','Essex','UNITED KINGDOM','CO9 2HL','07725347510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 11:43:52',0,NULL,3,1,3,1,'RA184539758CN\r ','TRSN001 '),(19378,908999331012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','mariot935','mariot200@hotmail.com','mario tax','fahrenheitstraat 28','nijmegen','','NETHERLANDS','6533jp','0642305964','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 11:54:22',0,NULL,3,1,21,1,'RA184539293CN ','GLOT005 '),(19379,909291511012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','cbjr21','cbjr21@hotmail.com','André Martins','Av. Penetração 3, Nº 1856 Japiim II','Manaus','Amazonas','BRAZIL','69076-810','55 (92) 9142-5662','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 12:21:41',0,NULL,3,1,3,1,'RA184537071CN\r ','OTSO004*2 '),(19380,908961915012,220913327376,'NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses  3300 GR',2,'GLSG009',109.98,'eastar4uk','sadie-8356','dave.tompsett@hotmail.co.uk','dave tompsett','17 cloverbank view','chatham','Kent','UNITED KINGDOM','me5 7jq','01634863867','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 12:28:50',0,NULL,3,1,3,1,'RA184537068CN\r ','GLSG009 '),(19381,820407471011,320812367902,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','assarson','philip_assarson_@hotmail.com','Philip Assarson','Rahagsvagen38','Vallda','none','SWEDEN','43494','+46768882005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 13:14:13',0,NULL,3,1,3,1,'RA184537213CN\r ','HSNO033\r欧标 \r不要写申报价值，只申报为gift '),(19382,820753388011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','andy123daley','suzanne.daley1@btinternet.com','andrew daley','26 st cuthbert avenue<br>marton','middlesbrough','Cleveland','UNITED KINGDOM','ts7 8rg','01642311815','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 13:50:01',0,NULL,3,1,3,1,'RA184539894CN\r ','LGAD001 '),(19383,909316864012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','pacomacman','paulbarnard@btinternet.com','Paul Barnard','3 Mill Road, Keadby','Scunthorpe','Lincolnshire','UNITED KINGDOM','DN173DS','01724783205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 13:50:04',0,NULL,3,1,3,1,'RA184539934CN\r ','LGRM001 '),(19384,820756418011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','pianoelaine34','elaine@jupp3.fsworld.co.uk','Elaine Jupp','91 High Street<br>Blyton','Gainsborough','Lincolnshire','UNITED KINGDOM','DN21 3JX','01427629418','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 14:01:53',0,NULL,3,1,3,1,'RA184537108CN\r ','OTSO004 '),(19385,820766736011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','sappycamper','cabin11@sccoast.net','Waymon Edmonds','460 Holly View Ln','Loris','SC','UNITED STATES','29569-4921','(843) 756-0096','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 14:36:25',0,NULL,3,1,1,1,'LK174157374CN\r ',NULL),(19386,909346445012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',12.99,'eastar4uk','west7979','ian@west7979.fsbusiness.co.uk','ian west','23 Lucerne Gardens<br>Hedge End','southampton','Hampshire','UNITED KINGDOM','SO304SD','01489785140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 15:17:24',0,NULL,3,1,3,1,'RA184539829CN\r ','WLAP002 '),(19387,909358379012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','hollykatie2010','jane.e.barber@hotmail.co.uk','Jane Barber','Abdy Farm<br>2 The Green','Rotherham','South Yorkshire','UNITED KINGDOM','S60 4JD','01709365053','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 15:48:16',0,NULL,3,1,3,1,'RA184539903CN\r ','SAFI001 '),(19388,820792174011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','yasin1974','dvdcity2005@yahoo.com','Yasin Khalafov','shahbazi str.104a 45','Baku','','AZERBAIJAN','AZ1065','+994-50-320-17-53','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 15:57:23',0,NULL,3,1,21,1,'RA184527233CN\r ','GLOT001 '),(19389,909368276012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','ricacun','ricardo-nascimento.cunha@itau-unibanco.com.br','Ricardo Cunha','Av Mazzei, 879 apto 63','São Paulo','São Paulo','BRAZIL','02310-001','+55 11 78892408','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 16:11:27',0,NULL,3,1,3,1,'RA184539506CN\r ','GLOT001 '),(19390,909374679012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','robleech9999','r_leech@hotmail.com','Robert Leech','18 Nicholls Avenue<br>Leuchars','St. Andrews','Fife','UNITED KINGDOM','KY16 0LQ','01334834383','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 16:26:15',0,NULL,3,1,2,1,'30110923754\r ','acer 5pin1.25 15cm '),(19391,909391309012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','steve-cooper','steve@steve-cooper.co.uk','Steve Cooper','London Metal Exchange<br>56 Leadenhall Street','London','London','UNITED KINGDOM','EC3A 2DX','07512370760','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 17:02:07',0,NULL,3,1,3,1,'RA184539846CN\r ','OTHP004 '),(19392,820833250011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.98,'eastar4','ancsianya','banhidi.aniko@gmail.com','Anikó Bánhidi','Honvéd utca 17/a','Szekszárd','Tolna','HUNGARY','7100','36 30 612 37 15','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 17:35:29',0,NULL,3,1,22,1,'BJ01670132 ','OTCN002 '),(19393,820837989011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','footballpaul1999','the.coulson@gmail.com','Mr Nick Coulson','Ivy Lodge, 25 Southwaite Green Mill<br>Eamont Bridge','PENRITH','Cumbria','UNITED KINGDOM','CA10 2BY','07790029790','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 17:38:54',0,NULL,3,1,3,1,'RA184539510CN\r ','RELO003 '),(19394,820843776011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',3,'OTHP005',25.62,'eastar4uk','mich130179','michelle.leniston@hotmail.co.uk','Michelle Leniston','61 Whitton View','Rothbury','Northumberland','UNITED KINGDOM','NE65 7QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 17:50:24',0,NULL,3,1,3,1,'RA184539608CN\r ','OTHP005 '),(19395,820849071011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','johnl8483','hardtotrot@hotmail.com','John Landon','121 NE 52nd St<br>Ste 150','Oklahoma City','OK','UNITED STATES','73105-1803','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 18:01:48',0,NULL,3,1,1,1,'LK172270305CN\r ',NULL),(19396,909441653012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','npure_uk','rob156@gmail.com','Robert Thomas','17a Manor Court<br>Station Approach, Hinchley Wood','Esher','Surrey','UNITED KINGDOM','KT10 0SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 18:38:25',0,NULL,3,1,3,1,'RA184539333CN\r ','OTHP004 '),(19397,664429743013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','tanov_v','tvp87@yandex.ru','Valerii Tanov','Novaya 104','Sanamer','Stavropolskiy kray','RUSSIAN FEDERATION','357360','8796167296','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 18:29:55',0,NULL,3,1,3,1,'RA184537876CN ','GLOT001*4 '),(19398,820876596011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','wggl727','traistera@aol.com','Andrew Traister','119 E Fairview Ave','Glendale','CA','UNITED STATES','91207-1905','(818) 415-8778','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 18:53:23',0,NULL,3,1,1,1,'LK173761147CN\r ',NULL),(19399,820882922011,320730544219,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT006*2',52.99,'eastar4uk','cresan2000','magi-pili@ono.com','MAGI SANTACANA HERNANDEZ','ENTENÇA,101 -1-D','BARCELONA','Cataluña','SPAIN','08015','934254754','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 19:03:10',0,NULL,3,1,21,1,'RA184527304CN\r ','GLOT006*2 '),(19400,820882541011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT006',44.89,'eastar4','canelaverde','walaces@uol.com.br','Walace Soares','Av. Copacabana, 708<br>casa 5, Vila dos Passaros, Morada de Laranjeiras','Serra','ES','BRAZIL','29166-820','+552733490292','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 19:03:26',0,NULL,3,1,3,1,'RA184539395CN\r ','GLOT006 \r'),(19401,820897441011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','7109johnson','happypauly@sky.com','Mr P N Johnson','Mitsubishi Electric<br>Unit 8 Electra Park, Bidder Street','Canning Town','London','UNITED KINGDOM','E16 4ES','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19402,820897301011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','p_redshaw','paul.redshaw@telent.com','Mr P Redshaw','Trotters End, Four Elms Farm<br>The Slough','Studley','Warwickshire','UNITED KINGDOM','B80 7EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 19:29:43',0,NULL,3,1,3,1,'RA184537085CN\r ','RCLO009 '),(19403,664454012013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',3.98,'eastar4','etooso','oystein.solbakken@gmail.com','Oystein Solbakken','Elvevegen 6','Hegra','','NORWAY','7520','+4797555177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 19:30:00',0,NULL,3,1,22,1,'BJ01670130\r ','OTCN001 \r'),(19404,820924312011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','wondilla','wondilla@clearmail.com.au','Robert Davis','5 Kinchant Street','Marsden','Queensland','AUSTRALIA','4132','0412755620','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 20:24:29',0,NULL,3,1,11,1,'BJ01670064\r ','\r澳标 '),(19405,909511648012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','steve19761','mansyno1@hotmail.com','steven manns','Flat 1 Fairfield court<br>50 Fairfield','Christchurch','Dorset','UNITED KINGDOM','BH23 1QX','07737158283','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 21:16:02',0,NULL,3,1,3,1,'RA184537859CN\r ','HSJA002\r英标 '),(19406,909530050012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','philipgreen99','piratez_99@hotmail.com','Matthew Green','7 Fairmont Terrace<br>North Road','Sherborne','Dorset','UNITED KINGDOM','DT9 3JS','07835401168','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 21:18:22',0,NULL,3,1,3,1,'RA184539996CN\r ','MOMI002 黑色 '),(19407,820955207011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','turbin_powah','personin@hotmail.com','David Arenas Romero','C/Pardo Nº 63 2º2ª','Barcelona','Barcelona','SPAIN','08016','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 21:32:49',0,NULL,3,1,21,1,'RA184527397CN\r ','GLOT001 '),(19408,820963464011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','fstbkgt','joe_dominic2002@yahoo.com','Joe Dominic','11458 Hesperian Cir','Gold River','CA','UNITED STATES','95670-7653','(916) 859-0911','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 21:54:42',0,NULL,3,1,1,1,'LK171454458CN\r ',NULL),(19409,820963325011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','davidc5077','david.chisem@gmail.com','David Chisem','Casablanca<br>Caixa Postal Z-110','Loule','Algarve','PORTUGAL','8100-228','00351918905595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 21:59:41',0,NULL,3,1,3,1,'RA184539982CN\r ','HBPH002 '),(19410,820981190011,320812367902,'New genuine Nokia Bluetooth Headset BH-806 BH 806',1,'HSNO033',46.99,'eastar4uk','shaqx_uk','sh4qx@hotmail.com','Shakeel Islam','44 Millais Road','Leytonstone','London','UNITED KINGDOM','E11 4HD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 22:42:34',0,NULL,3,1,3,1,'RA184539792CN\r ','HSNO033\r英标 '),(19411,909573970012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',12.98,'eastar4uk','tmstedall','tstedall@gmail.com','Teresa Stedall','38 Hilltop Ave','Newcastle','Staffordshire','UNITED KINGDOM','ST5 0QF','01782614160','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 23:09:46',0,NULL,3,1,3,1,'RA184539965CN\r ','OTHP004 '),(19412,909577649012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',2.99,'eastar4uk','trek-olivia','craigmclean84@me.com','Craig Mclean','6 Barmpton Road','Billingham','Cleveland','UNITED KINGDOM','TS23 3SN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 23:19:34',0,NULL,3,1,3,1,'RA184539554CN\r ','OTCN002 '),(19413,664523024013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jitter6ug','tony.ormsby@gmail.com','Tony Ormsby','Floor 14<br>Windsor Hse Bedford Street','Belfast','Antrim','UNITED KINGDOM','BT1 7EL','02890223912','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 23:43:01',0,NULL,3,1,11,1,'BJ01670119\r ',NULL),(19414,821000943011,320730085617,'New Atheros AR5008 802.11N Wireles WiFi Mini PCI-E Card',1,'WLAT001',8.99,'eastar4uk','freeselller','chrisgunnar@gmx.com','Christopher Paul','Pelzerstraße 19','Emden','','GERMANY','26721','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 23:45:25',0,NULL,3,1,2,1,'30110926300\r ','WLAT001 '),(19415,909591512012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',2,'LGGL005',39.98,'eastar4','lana1968','lanefarm@shockware.com','Lana Lane','Box 164','Burdett','AB','CANADA','T0K0J0','(403) 833-3883','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 00:03:07',0,NULL,3,1,3,1,'RA184537111CN\r ',NULL),(19416,759043569008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','vkgroupa3','tdark@bigpond.net.au','Tyrone Dark','P O Box 1040','Kalgoorlie','Western Australia','AUSTRALIA','6433','61428917340','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-02 00:07:42',0,NULL,3,1,11,1,'RA184539537CN\r ','BALO001 '),(19417,664534706013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','jodene651','jlmillner@hotmail.com','jodene millner','11796 harbor lane','Crosslake','MN','UNITED STATES','56442','(612) 310-6230','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 00:13:52',0,NULL,3,1,1,1,'LK174418582CN\r ',NULL),(19418,909616237012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','nsborg','info@n-sb.org','Jeremy Wilder','16015 Cleveland St<br>Apt 515','Redmond','WA','UNITED STATES','98052-1546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 01:22:45',0,NULL,3,1,1,1,'LK164216210CN\r ',' '),(19419,821031848011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','alinaramona2006','alybibi2000@yahoo.com','Alina Ramona Bangala','413 Lodge Dr','Lafayette','LA','UNITED STATES','70506-2840','(225) 802-0527','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 01:34:13',0,NULL,3,1,1,1,'LK174305489CN\r ',' '),(19420,767014534007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','mastergot','thehotmonky@hotmail.com','hugo dubuc carriere','52 place richelieu app.5','lemoyne','QC','CANADA','j4r 2h7','(450) 812-6056','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-02 02:11:16',0,NULL,3,1,11,1,'BJ01670104\r ','RELO002 '),(19421,821051397011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','baldrak','fredkesler@gmail.com','Frederick Kesler','1985 Tate Blvd SE<br>Ste 529','Hickory','NC','UNITED STATES','28602-1433','(828) 325-4685','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 02:44:09',0,NULL,3,1,1,1,'LK172465908CN\r ',NULL),(19422,664562123013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','nakita333','jrieu@hotmail.com','Janice Rieu','10 Wendon Bay','Winnipeg','MB','CANADA','R2R 1W9','(204) 632-7221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 02:28:28',0,NULL,3,1,3,1,'RA184539381CN\r ','GLOT001*3 '),(19423,664573473013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','soundandlights','benjaminyoung8@me.com','Ben Young','44 Le Page run','South morang','Victoria','AUSTRALIA','3752','0404317342','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 03:20:03',0,NULL,3,1,11,1,'BJ01670120\r\r ',NULL),(19424,821065225011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','yeyo1013','wamater@comcast.net','WALTER LLOP','18754 NW 84 PASAGE # 1803','HIALEAH','FL','UNITED STATES','33015','(786) 352-0114','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 03:39:04',0,NULL,3,1,1,1,'LK171767575CN\r ',NULL),(19425,909673733012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','bruce6628','brucekvellestad@gmail.com','Bruce Kvellestad','3802 3rd St. N.W.','Calgary','AB','CANADA','T2K 0Z7','(403) 230-9044','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 04:53:46',0,NULL,3,1,11,1,'BJ01670115\r ',NULL),(19426,821082102011,320791295540,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking  TK103-2',1,'GPS0008',111.99,'eastar4','canada.c','quebec_calderon@hotmail.com','Eddy Calderon','2300 George Dieter Dr','El Paso','TX','UNITED STATES','79936-3963','(915) 538-2400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 05:00:30',0,NULL,3,1,4,1,'YW868052873CN ','GPS0008 +GPS0006\r再发一个Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102'),(19427,610648995004,140630817200,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',34.99,'cnfaner','steptoechris','denovans@bigpond.net.au','Christopher Denovan','7 Larissa Avenue','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 05:06:22',0,NULL,3,1,3,1,'RA184539917CN\r ','CC00002\r中国航空小包挂号 '),(19428,605567608003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','tankthecrank','gcoatsworth@coolgoose.com','Greg Coatsworth','6867 Wing Lake Rd','Bloomfield Hills','MI','UNITED STATES','48301-2959','(248) 626-1652','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-02 05:09:05',0,NULL,3,1,1,1,'LK169504368CN\r ',NULL),(19429,664590174013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','canada.c','quebec_calderon@hotmail.com','Eddy Calderon','2300 George Dieter Dr','El Paso','TX','UNITED STATES','79936-3963','(915) 538-2400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 04:54:50',0,NULL,3,1,17,0,'YW868052873CN\r ',' '),(19430,759116792008,180781265262,'New Grohe Multi Function hand Shower Head made in Germany+ 59\" Grohe hose',1,'OTGR001+OTGR002',39.9,'au-buy','tthomson38','tthomson38@hotmail.com','Teresa  Thomson','38 Amphitheatre Circuit<br>Baulkham Hills','Sydney','New South Wales','AUSTRALIA','2153','0298384946','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-02 05:17:10',0,NULL,3,1,3,1,'RA184537037CN\r ','OTGR001+OTGR002 '),(19431,821085119011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',17.99,'eastar4uk','jimmy3141','jimmy1472@bellsouth.net','James Piloto','5896 NW Dowse St','port saint lucie','FL','UNITED STATES','34986-3922','(772) 528-3141','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 05:17:24',0,NULL,3,0,1,1,'LK172313482CN\r\r ',NULL),(19432,767058044007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','dee_mini','domenic@minieri.com.au','Domenic Minieri','Hoyne Design<br>102 Chapel Street','St. Kilda','Victoria','AUSTRALIA','3182','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-02 05:40:45',0,NULL,3,1,11,1,'BJ01670118\r ','RCLO007 '),(19433,664597439013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','crydeexxx','menayas618@gmail.com','Alex Menayas','10026 Lazy Oaks St','Houston','TX','UNITED STATES','77080-7510','(602) 819-2302','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 05:45:51',0,NULL,3,1,1,1,'LK173799227CN\r ',NULL),(19434,610908392004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','sotile13','tannucci@yahoo.com','Christina Annucci','37 Leamington Cir','Rochester','NY','UNITED STATES','14626-4473','(585) 723-0058','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-02 06:44:42',0,NULL,3,1,1,1,'LK173751255CN\r ',NULL),(19435,909695330012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','starlighteventsluke','lukehockett@btinternet.com','luke hockett','198 bath road<br>longwell green','bristol','Bristol','UNITED KINGDOM','bs30 9db','01179328942','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 07:00:18',0,NULL,3,1,3,1,'RA184539302CN ','OTCN004*10 '),(19436,909698867012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','hugaseka','hubsi@gmx.info','Hubert Wallner','c/o Stadtgemeinde Mödling<br>Pfarrgasse 9','Mödling','','AUSTRIA','2340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 07:24:47',0,NULL,3,1,21,1,'RA184527162CN\r ','GLOT001*2 '),(19437,767074197007,170735464248,'New Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',21.99,'au-buy','aglmdb02','original510@hotmail.com','B SANTOS(AMATOS L MART)','SHOP 2 267/277 NORTON<br>STREET LEICHHARDT','sydney','New South Wales','AUSTRALIA','2040','0295607628','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-02 07:34:19',0,NULL,3,1,11,1,'BJ01670101\r ','UM00004 '),(19438,610914807004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',28.88,'cnfaner','rollmastr','t.seizov@gmail.com','Thomas Seizov','Soldanellenweg 25/7','Wien','','AUSTRIA','1220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 07:38:59',0,NULL,3,1,21,1,'RA184539276CN ','WWSI002\r'),(19439,664618604013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','fingerzzzz','david_t_ingram@yahoo.co.uk','David Ingram','124 Felstead Road','Orpington','Kent','UNITED KINGDOM','BR6 9AF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 08:49:40',0,NULL,3,1,3,1,'RA184539320CN\r ','一共买了四条 CAB-6060'),(19440,664619100013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',16.98,'eastar4','fingerzzzz','david_t_ingram@yahoo.co.uk','David Ingram','124 Felstead Road','Orpington','Kent','UNITED KINGDOM','BR6 9AF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 08:53:03',0,NULL,3,1,17,0,'RA184539320CN\r ',NULL),(19441,821126074011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','queenie954','jack1tic@btinternet.com','JACKIE QUEEN','FLAT 02 187C KNIGHTSWOOD RD','GLASGOW','Glasgow (City of)','UNITED KINGDOM','G132EX','01419549424','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 09:37:37',0,NULL,3,1,3,1,'RA184537054CN\r ','OTSO004 '),(19442,909725301012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','ibrindas2012','ibrindas@gmail.com','anca brindas','30-95 34th street, apt. 5C','Astoria','NY','UNITED STATES','11103','(347) 738-5354','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 09:43:11',0,NULL,3,1,1,1,'LK173080308CN\r ',NULL),(19443,905796080012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','whitney*whitney09','willowise@hotmail.com','Whitney Duff','12/158 Wiliams Rd<br>Prahan','Melbourne','Victoria','AUSTRALIA','3181','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 11:11:51',0,NULL,3,1,11,1,'BJ01670099\r ',NULL),(19444,909747015012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','startrekeagle','startrekeagle@cimtel.net','Steve Shields','4455 S 289th West Ave','Mannford','OK','UNITED STATES','74044','(918) 645-3801','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 11:11:59',0,NULL,3,1,1,1,'LK169581475CN\r ',NULL),(19445,821157412011,320394929435,'Acer TM 4210 4270 4670 Bluetooth Module 2.0 EDR+cable',1,'BTAC2024',9.88,'eastar4','christoslands','christosvarveris@gmail.com','CHRISTOS VARVERIS','Poseidonos 22','Melissia','Athens','GREECE','15127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 11:52:09',0,NULL,3,1,22,1,'BJ01670125\r ','acer 8pin1.25 10cm  '),(19446,610962593004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','mixalhs123m','mixalhs123@yahoo.com','MIHALIS MALIATSOS','AGIAS TRIADOS 12','PAIANIA','ATHENS','GREECE','19002','6975660026','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 12:59:39',0,NULL,3,1,21,1,'RA184539280CN ','HSJA010\r中国SAL小包挂号 '),(19447,909783790012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',6,'TRMX003',45.42,'eastar4','wimhudepohl','wimhudepohl@hccnet.nl','wim Hudepohl','De Marke van Leusen 32','NIEUWLEUSEN','','NETHERLANDS','7711HH','0529480880','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 13:22:00',0,NULL,3,1,23,1,'BP04081201040008','TRMX003 '),(19448,818121903011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',3,'HSJA002',59.97,'eastar4','kenny389','kenyildirim@optusnet.com.au','Ken Yildirim','39 Gordon Road','Auburn','New South Wales','AUSTRALIA','2144','0297020731','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 13:23:16',0,NULL,3,1,3,1,'RA184527176CN\r ','HSJA002\r澳标 '),(19449,909791568012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','tye8247','e92ebay592@aol.com','Richard Tye','Rosmeda, Squire Lane<br>Carharrack','Redruth','Cornwall','UNITED KINGDOM','TR16 5SQ','01209821458','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 13:48:16',0,NULL,3,0,3,1,'RA184539404CN\r ','GLOT005 '),(19450,767160178007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'au-buy','rezakos','rezakos.mail@gmail.com','Ákos Rézmány','Columbus street 56/b','Budapest','Pest','HUNGARY','1145','0036304663544','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-02 13:55:24',0,NULL,3,1,22,1,'BJ01670129 ','HSUE003 '),(19451,605281161003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','jpv9266','jvoyles66@gmail.com','Jon Voyles','8811 19th Street Rd','Greeley','CO','UNITED STATES','80634-5727','(970) 310-6673','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-02 14:13:17',0,NULL,3,1,1,1,'LK171718509CN\r ',NULL),(19452,610978099004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','cj1138','cjn@post1.dansknet.dk','Christian Engelsted Joergensen','Anders Nielsens Vej 5, st. tv.','Noerresundby','','DENMARK','9400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 14:17:33',0,NULL,3,1,21,1,'RA184539214CN ','OTHP005\r中国SAL小包挂号 '),(19453,909806572012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','zaqen','christophe.mailhebuau@gmail.com','Christophe Mailhebuau','Résidence Les Cèdres de Cauderan<br>18 rue Delmestre','Bordeaux Cauderan','Aquitaine','FRANCE','33200','0630110977','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 14:29:38',0,NULL,3,1,2,1,'30110921886\r ','acer 5pin1.25 15cm '),(19454,605449181003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','nakiawhite','nakia_w@hotmail.com','Nakia White','12420 Oak Alley Dr','Geismar','LA','UNITED STATES','70734-3155','(225) 364-9365','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-02 15:25:39',0,NULL,3,1,1,1,'LK171121265CN\r ',NULL),(19455,909840435012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',166.99,'eastar4uk','logiebear69','gerrylogan@orange.net','Gerald Logan','15  Castle Drive','Berwick Upon Tweed','Northumberland','UNITED KINGDOM','TD15 1NS','01289331580','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 15:56:46',0,NULL,3,1,3,1,'RA184527202CN\r ','OTSO004*4 '),(19456,664704142013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','intu0m','intuom@inbox.ru','Pavel Konstantinovich','Very Solominoj, d. 3, kv. 107','Novokuznetsk','Kemerovskaja oblast\'','RUSSIAN FEDERATION','654063','9133146258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 16:04:27',0,NULL,3,1,11,1,'BJ01670123\r ','CACN004 '),(19457,664708210013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','wjsdkdudwhgusdn','hs77cho@gmail.com','HanSeok Cho','101-1509, Woosung Apt.,<br>Mapyeong-dong, Cheoin-gu,','Yongin-si','Gyeonggi-do','KOREA,REPUBLIC OF','449-787','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 16:15:55',0,NULL,3,1,11,1,'BJ01670121\r ',NULL),(19458,664710690013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','sneakers180','orders180@yahoo.com','Margo Blackwell','4801 W Fowler Rd','Bloomington','IN','UNITED STATES','47403-9584','(812) 824-4568','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 16:25:29',0,NULL,3,1,1,1,'LK173543297CN\r ',NULL),(19459,909877692012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','whispersan','gregorylawton@gmail.com','Ernest Lawton','21 Greenacres<br>Ripponden','Halifax','West Yorkshire','UNITED KINGDOM','HX6 4AL','07904494751','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:13:54',0,NULL,3,1,3,1,'RA184539925CN\r ','SAFI001 '),(19460,664725379013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','kkuznet42','kkuznet@gmail.com','Konstantin  Kuznetsov','Shornikova, 1, 39','Kemerovo','Kemerovskaya obl','RUSSIAN FEDERATION','650036','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 17:21:36',0,NULL,3,1,3,1,'RA184539483CN\r ','GLOT001*3 '),(19461,664368899013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','shredquest','shredquest@yahoo.com','Carl Braidt','139 North Rd','Bloomingburg','NY','UNITED STATES','12721-4656','(845) 733-4925','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 17:38:26',0,NULL,3,1,1,1,'LK174925417CN\r ',NULL),(19462,821280172011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','psarafin-us','psarafin@earthlink.net','Peter Sarafin','5 Silverside Ln','Latham','NY','UNITED STATES','12110-5119','(518) 783-7931','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 17:39:55',0,NULL,3,1,1,1,'LK169555890CN\r ',NULL),(19463,909893178012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',24.99,'eastar4','lucineia2011','bernardes.lucineia@gmail.com','lucineia lima','herculano de freitas, 1526 apt.101','belo horizonte','minas gerais','BRAZIL','30431080','55 31 33714690','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 17:44:17',0,NULL,3,1,11,1,'BJ01670095\r ','UM00008 '),(19464,664737627013,230717820546,'Brand New in box 2011 Korea LG 3D Cinema TV Glasses Family Pack AG-F214',1,'LGGL004',29.99,'eastar4','jpllacerda','jplacerda@gmail.com','João Paulo Lacerda','Av. Gonçalo Romlemberg Leite, 2143<br>Edf Itabira, Ap 601','Aracaju','SE','BRAZIL','49045-280','+55 79 88139618','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 17:46:13',0,NULL,3,1,11,1,'BJ01670116\r ','LGGL004 '),(19465,610823588004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.88,'cnfaner','deltafiresys','deltafirecomm@yahoo.com','Delta Fire','33585 SE Francis Rd','gresham','OR','UNITED STATES','97080-8917','(503) 663-5940','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-02 17:49:24',0,NULL,3,1,1,1,'LK170327170CN\r ',NULL),(19466,821287852011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','ssmith9008','stefan.smith1@googlemail.com','Mr Stefan Smith','74 The Green<br>Lydd','Romney Marsh','Kent','UNITED KINGDOM','TN29 9HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:54:34',0,NULL,3,1,3,1,'RA184539316CN\r ','OTHP005 '),(19467,909902551012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',8,'OTCN004*10',133.6,'eastar4','lerzimdama','leonardo@damaceno.com.br','TEREZINHA O;IVEIRA','74 Greenleaf Cir','FRAMINGHAM','MA','UNITED STATES','01701-4532','(508) 820-0576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 18:04:32',0,NULL,3,1,4,1,'YW868052884CN ',NULL),(19468,821317599011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','benx419','ben.pashley@gmail.com','Ben Pashley','17 Byne Road<br>Sydenham','London','London','UNITED KINGDOM','se26 5jf','07590771752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 18:51:37',0,NULL,8,1,17,0,NULL,NULL),(19469,821319133011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','benx419','ben.pashley@gmail.com','Ben Pashley','17 Byne Road<br>Sydenham','London','London','UNITED KINGDOM','se26 5jf','07590771752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 18:53:55',0,NULL,5,1,18,1,NULL,'RCLO007+POLO001+RCLO008*4  加英标\r还买了Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display \rRCLO009\r在询问要不要\r'),(19470,909944889012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',6.8,'eastar4uk','opi86','markus.opitz@gmx.at','Markus Opitz','Schweinz 69','Ottendorf','','AUSTRIA','8312','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 19:15:09',0,NULL,3,1,23,1,'bp04081201040012 ','SCLO004 '),(19471,605761714003,130620865369,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',87.99,'cnfaner','virgis21','virgis21@gmail.com','Virgilijus Rudinskas','Liepu 2-6<br>Pagyne km.','Kauno raj.','Kauno raj','LITHUANIA','LT-54323','+37068241542','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 19:19:03',0,NULL,3,1,21,1,'RA184539470CN\r ','GPS0007 '),(19472,664772223013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','abrwhite','brian.r.white@gmail.com','Brian White','5044 Thalia Drive','El Dorado Hills','CA','UNITED STATES','95762','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 19:20:41',0,NULL,3,1,1,1,'LK174243118CN\r ',NULL),(19473,821341824011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','bpmueller72','bmueller@comcast.net','Brian P. Mueller','2721 Rosedale Pl','Nashville','TN','UNITED STATES','37211','(615) 254-9347','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 19:37:14',0,NULL,3,1,1,1,'LK173468358CN\r ',NULL),(19474,909961203012,220785812343,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',39.9,'eastar4','nosiusinc','info@carrosserie-petrovic.ch','petrovic nenad','grenzweg 6<br>carrosserie-spritzwerk','schöftland','','SWITZERLAND','5040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 19:43:05',0,NULL,3,1,22,1,'BJ01670136 ','MOAS001 '),(19475,664787420013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','paul935','pep@appsyn.com','Paul Perrone','1973 Merriman Way Rd','Moneta','VA','UNITED STATES','24121-3159','(540) 721-5312','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 20:00:01',0,NULL,3,1,1,1,'LK170089356CN\r ',NULL),(19476,605779681003,130620864611,'3 pairs of new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005*3',162.99,'cnfaner','coconybh','marconybh@hotmail.com','Marcony Moyses','rua João XXIII, 123 - Eldorado','Contagem','Minas Gerais','BRAZIL','32310-420','55 31 2565-5544','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 20:02:58',0,NULL,3,1,3,1,'RA184527825CN\r ','GLOT005*3\r中国航空小包挂号 '),(19477,909992005012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',2,'OTCN002',5.98,'eastar4uk','store_moore','katie@katiemoore.co.uk','Expidas Limited','7 Fontwell Close<br>Llwyn Onn Park','Wrexham','Wrexham','UNITED KINGDOM','LL130QH','01978355779','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 20:34:45',0,NULL,3,1,3,1,'RA184539364CN\r ','OTCN002 '),(19478,611098012004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',18.85,'cnfaner','stannijmegen','stan.antonides@home.nl','Stan Antonides','Boshoek 45','Vroomshoop','','NETHERLANDS','7681GT','0546646629','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 20:36:50',0,NULL,3,1,23,1,'\\ ','OTHP004 '),(19479,821374948011,320441564486,'2.1 Acer Aspire 5550 5551 5552 Bluetooth Module +cable',1,'BTAC2106',12.39,'eastar4','limras','resulbayrambey1985@hotmail.co.uk','Resul BAYRAMBEY','49 winchcombe street','cheltenham','Gloucestershire','UNITED KINGDOM','GL52 2NE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 20:41:03',0,NULL,3,1,2,1,'30110920243\r ','acer 4pin1.25 15cm  '),(19480,909998473012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.39,'eastar4','jasonojordan','jason.o.jordan88@gmail.com','Jason Jordan','800 Evergreen Dr<br>#308','Burnsville','MN','UNITED STATES','55337','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 20:54:51',0,NULL,3,1,1,1,'LK169970149CN\r ','acer 8pin1.00 18cm '),(19481,910003131012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','fifox10','fifox@spray.se','Miguel Inzunza','Kärnvägen 171','Umeå','','SWEDEN','90627','46 (0(734 0370 32','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 20:55:15',0,NULL,3,1,22,1,'BJ01670137 ','RELO002 '),(19482,664813942013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',3,'GPS0006',179.97,'eastar4','yogles1954','gabriel.netto@bol.com.br','Jose Gabriel Marques Neto','Rua Maranhão, 1440 - Ap 44<br>Santa Paula','São Cetano do Sul','São Paulo','BRAZIL','09541-001','55 11 7885-2343','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 21:12:22',0,NULL,3,1,3,1,'RA184539700CN\r ','GPS0006 '),(19483,664817943013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','ken-shi_kun','kenshi.kun@gmail.com','Ádám Huszka','Damjanich str. 1.','Százhalombatta','Pest','HUNGARY','2440','0036202622693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 21:26:13',0,NULL,3,1,22,1,'BJ01670133 ','WLAT010 \r新的'),(19484,611110771004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','kuzyanov2011','agroprom-tex@bk.ru','Kuzyanov Nickolay','Sovnarkomovskay 26-39','Nizhny Novgorod','Nizhegorotskaya','RUSSIAN FEDERATION','603086','+79036037677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 21:18:25',0,NULL,3,1,3,1,'RA184537765CN\r ','HSJA002\r中国航空小包挂号 \r欧标'),(19485,664826967013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','deblater','gruijthuijzen@hotmail.com','Robert-Jan Gruijthuijzen','Kollenberg 49','Esch','Noord-Brabant','NETHERLANDS','5296LC','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 21:51:51',0,NULL,3,1,3,1,'RA184537955CN ','GLOT001*4 '),(19486,664829650013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','smile_angel2000','ilovecherry18020@yahoo.com','van quach','86 beaupre bay','winnipeg','MB','CANADA','R3X 1C9','(204) 960-4898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 22:05:19',0,NULL,3,1,3,1,'RA184527383CN\r ','GLOT001*2 '),(19487,821419050011,320774352320,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireles CARD',1,'WLAT003',10.99,'eastar4uk','johey81','ebay.js@crypt.se','Johan Svensson','Imatragatan 210','Kista','','SWEDEN','16478','+46705955621','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 22:13:20',0,NULL,3,1,22,1,'BJ01670135 ','WLAT003 '),(19488,910049508012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','geffree','geffrardm@gmail.com','Geffrard Morinvil','7950 La Fontaine','Montreal','QC','CANADA','H1L 3H7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 22:30:38',0,NULL,3,1,11,1,'BJ01670122\r ',NULL),(19489,821422714011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',17.99,'eastar4uk','harleywud','martinharley@sky.com','Martin Harley','1 Woodside cottage, Woodside<br>Baldwins Gate','Newcastle Under Lyme','Staffordshire','UNITED KINGDOM','ST5 5EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 22:35:32',0,NULL,3,1,3,1,'RA184537173CN\r ','TRSN001 \r合并订单 \r还发一个New in box SONY 3D Active Glasses TDG-BR250 rechargeabl\rOTSO004'),(19490,821423776011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','harleywud','martinharley@sky.com','Martin Harley','1 Woodside cottage, Woodside<br>Baldwins Gate','Newcastle Under Lyme','Staffordshire','UNITED KINGDOM','ST5 5EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 22:36:40',0,NULL,3,1,3,1,'RA184537173CN\r ',''),(19492,821473304011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','grevengoed','b.grevengoed@frontier.com','Barbara Grevengoed','Hintzsche Fertilizer, Inc.<br>2s181 County Line Road','Maple Park','IL','UNITED STATES','60151','(630) 557-2406 ext.: 247','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 00:47:33',0,NULL,3,1,1,1,'LK172192974CN\r ',NULL),(19493,605420869003,130596106061,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',84.9,'cnfaner','bowker_bob','bowker@inetwebinc.com','Robert Bowker','2811 La Cuesta Dr','Los Angeles','CA','UNITED STATES','90046','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-03 00:48:36',0,NULL,3,1,1,1,'LK169260935CN\r ',NULL),(19494,821475484011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','gamr74','maxair74@yahoo.com','George W Stroud jr','5113 n 71st ln','glendale','AZ','UNITED STATES','85303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 00:55:37',0,NULL,3,1,1,1,'LK171480501CN\r ',NULL),(19495,910111522012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','badgerenterprise','justin.badger@gmail.com','Justin Badger','PO Box 1304','Ferndale','CA','UNITED STATES','95536-1304','(707) 502-5992','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-01-03 01:19:51',0,NULL,3,1,1,1,'LK172843556CN\r ',NULL),(19496,664882840013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','34411319','johnallenatf@comcast.net','John L Allen','6262 Fairbourne Ct','Hanover','MD','UNITED STATES','21076-1052','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 01:34:00',0,NULL,3,1,1,1,'LK173182443CN\r ',NULL),(19497,910116902012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','gabrielsesana','passosgabriel@hotmail.com','Gabriel Passos Sesana','SQS 104 Bloco C Apartamento 406','Brasilia','Distrito Federal','BRAZIL','70343-030',' 556181795275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 01:35:50',0,NULL,3,1,3,1,'RA184539775CN\r ','MOLO001 '),(19498,605874468003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.59,'cnfaner','lanz123','lanzillotta@gmail.com','Lucio Lanzillotta','48 SUMMERWOOD CRT','Woodbridge','ON','CANADA','L4L 9A3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 01:57:49',0,NULL,3,0,3,1,'RA184537045CN\r ','TRSN001 '),(19499,821493815011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','dosar111','jaehoonyu@uta.edu','Kelly Yu','2309 Bay Lakes Ct','Arlington','TX','UNITED STATES','76016-1176','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 01:59:25',0,NULL,3,1,1,1,'LK173148685CN\r ',NULL),(19500,910128775012,220885745410,'New genuine Microsoft Wired Optical Wheel Mouse white',1,'MOMI004',13.79,'eastar4','sellingstuff_27','sellingstuff27@hotmail.com','BSD Multimedia, LLC','1441 Lakeview Dr','Schererville','IN','UNITED STATES','46375-3004','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 02:12:28',0,NULL,3,0,1,1,'LK173440828CN\r ',NULL),(19501,767460133007,170747521410,'New Philips Sonicare Flexcare Toothbrush Handle HX6950 HX 6950 + travel charger',3,'HBPH001+HBPH003',260.7,'au-buy','ayu1968','meadowheights.dentist@yahoo.com.au','AYU ABDULLAH','1 Berringa Court','Meadow Heights','Victoria','AUSTRALIA','3048','0393023140','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-03 02:33:27',0,NULL,3,0,4,1,'YW867738831CN ',NULL),(19502,664901519013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','woodiewoodwacker','lesbont38@aol.com','Lester L Bontrager','65903 County Road 1','Wakarusa','IN','UNITED STATES','46573-9507','(574) 862-2517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 02:59:42',0,NULL,3,1,1,1,'LK172810005CN\r ',' '),(19504,821517092011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','8047derrick','sydknee_love@yahoo.com','Derrick Montgomery','230 fryer ct','Fairborn','OH','UNITED STATES','45324-2184','(937) 260-5273','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 03:27:06',0,NULL,3,1,1,1,'LK174462440CN\r ',''),(19505,8881325561291497,111,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',0,'eastar4uk','bohb100173','parvis73@gmail.com','Bo Hauglund Boisen','skipper clement alle 13, 204','københavn s','standard','DENMARK','2300','004541546773',NULL,NULL,NULL,'2012-01-03 03:28:11',0,NULL,3,0,3,1,'RA184537258CN\r ','GLSG001*2\r未签收退回后补发 '),(19506,8881325561711125,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'aliexpress','1006056359','dragon88hj@gmail.com','Hyunjae Jang	','225-1005, Munjeong2-dong, Songpa-gu','Seoul','Seoul','SOUTH KOREA	','138767','+82 10 98808517',NULL,NULL,NULL,'2012-01-03 03:35:11',0,NULL,3,1,3,1,'RA184539262CN ','WLIN014 '),(19507,821523153011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ochoad75','ochoad04@aol.com','david ochoa','1006 N J St','Lake worth','FL','UNITED STATES','33460-2263','(561) 201-7347','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 03:47:04',0,NULL,3,1,1,1,'LK172935005CN\r ',NULL),(19508,821531241011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','stokes192','sunnybmass@yahoo.com','shawn stokes','12 wilkins pl','brockton','MA','UNITED STATES','02301-6849','(774) 274-9204','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 04:22:11',0,NULL,3,1,1,1,'LK174154143CN\r ',NULL),(19510,8881325567201758,111,'New FOR Nokia Bluetooth Headset BH-806',1,'HSNO033',69.99,'aliexpress','1006081023','sinegore@gmail.com','Vlad Rodionov	','ulica Milashenkova dom 22 kvartira 28','MOSCOW','MOSCOW','RUSSIAN FEDERATION	','127322','+7 916 9007596',NULL,NULL,NULL,'2012-01-03 05:06:41',0,NULL,3,1,3,1,'RA184539789CN\r ',NULL),(19511,8881325568470602,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'aliexpress','1006091825','ra9lam@yandex.ru','Pavel Koksharov	','ul. Osipenko, dom. 41, kv. 4','Tyumen','Russia','RUSSIAN FEDERATION	','625002','89058247513',NULL,NULL,NULL,'2012-01-03 05:27:50',0,NULL,3,1,3,1,'RA184540005CN\r ',NULL),(19512,776052646001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','forzaroma2004','italia2006@gmail.com','Alexander Rayes','54 Jeanette Pl.','Brampton','ON','CANADA','L6S 3H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 05:35:11',0,NULL,3,1,11,1,'BJ01670114\r ','BR3D008 '),(19513,605454455003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','sea9162011','sea916@yandex.ru','Eduard Subhangulov','Rossiyskaya<br>the house 57\"b\" apartment 5','Chelyabinsk','','RUSSIAN FEDERATION','454006','89026106687','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 05:51:59',0,NULL,3,1,3,1,'RA184539727CN\r ','GPS0006 '),(19514,821548079011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','sandhu_1234','sandhu_terry2009@hotmail.com','terry sandhu','7745 hurd st','mission','BC','CANADA','v2v 3j5','(604) 615-5614 ext.: 604','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 05:57:42',0,NULL,3,1,11,1,'BJ01670063\r ','HSJA002 '),(19515,759558606008,180762085457,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring',1,'UM00021',26.99,'au-buy','svick5','a.svickerman@gmail.com','sally vickerman','14 parkview street<br>milton','brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-03 06:14:44',0,NULL,3,1,11,1,'RA184537227CN\r ','UM00021\r蓝色的  '),(19516,820204298002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','jchudo1975','jchudnovsky@gmail.com','Yuliya Viktorovskyy','57 Laurelhurst cres.','Woodbridge','ON','CANADA','L4H 2M9','(416) 457-9404','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 06:17:41',0,NULL,3,0,11,1,'BJ01670117\r ',NULL),(19517,910189682012,220806897605,'New lady lace trim sun/rain stick Umbrella black',1,'UM00011',24.99,'eastar4','sailorcelaeno','e.gillham@hotmail.com','Emma-Louise Lovell','50-52 Carara Ave','Thagoona','Queensland','AUSTRALIA','4306','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 06:28:21',0,NULL,3,1,11,1,'\rBJ01670094\r ','UM00011 \r蕾丝花边伞 '),(19518,910192287012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','angela*bebe','bebedkny@gmail.com','Angela','216 centre street S','Calgary','AB','CANADA','T2g2b6','(403) 295-3318','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 06:42:20',0,NULL,3,1,11,1,'BJ01670100\r ','MOMI002 \r极动鲨 mouse black'),(19519,8881325576727923,111,'New Genuine Motorola HS810 Bluetooth Wireless Headset',1,'HSMO017',0,'eastar4uk','spiderbid','shahanafzal@hotmail.com','Shahan Afzal','161 Queens Road','Walthamstow','London','UNITED KINGDOM','E17 8PJ','',NULL,NULL,NULL,'2012-01-03 07:45:27',0,NULL,3,1,3,1,'RA184539687CN\r ','HSMO017\r补发 '),(19521,776057559001,110701366255,'Monster House  New sealed 3D Blu-ray ship tracking#',1,'BR3D004',15.9,'buysia','alipradhan','alipradhan100@aol.com','NAUSHAD PRADHAN','1800 Austin Pkwy<br>Apt 1201','Sugar Land','TX','UNITED STATES','77479','(832) 512-4786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 08:14:41',0,NULL,3,1,1,1,NULL,NULL),(19522,664952003013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','dishlevoy','sonyaleks@gmail.com','ALEKSANDR DYSHLEVOI','18-A, UBOREVICHA STR., APP. 49','KHARKIV','','UKRAINE','61144','+380673063077','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 08:53:10',0,NULL,3,1,3,1,'RA184537862CN ','GLOT001*4 '),(19523,820651671002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','c2003447','mike@youroutdoor.com','Michael Brown','Unit 55<br>30 Bishops Row','East Perth','Western Australia','AUSTRALIA','6004','04222444555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 08:56:27',0,NULL,3,1,6,1,'EE636829189CN ',NULL),(19524,910221348012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','nicman8446','nic@woolletts.net','Nic Woollett','83 Pioneer Crescent','Bellbowrie','Queensland','AUSTRALIA','4070','0408880415','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 09:24:29',0,NULL,3,1,3,1,'RA184527349CN\r ','GLOT001*2 '),(19525,910221639012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','jimpecht','jpecht@att.net','James Pecht','1126 Hampton Dr','Allen','TX','UNITED STATES','75013-3632','(214) 504-8825','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-01-03 09:27:05',0,NULL,3,1,1,1,'\\ ',NULL),(19526,776900521001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','bigred7784','bigredgarcia77@yahoo.com','james garcia','9027 Knox Ave<br>Apt C1','skokie','IL','UNITED STATES','60076-1580','(773) 766-4843','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 09:48:38',0,NULL,3,1,1,1,'、 ',NULL),(19527,821587745011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','richard300356','richard_keirle@tiscali.co.uk','Richard Keirle','73 Broadway<br>Chilton Polden','Bridgwater','Somerset','UNITED KINGDOM','TA7 9EQ','07855102903','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 09:53:52',0,NULL,3,1,3,1,'RA184527074CN\r ','RELO003 '),(19528,664960394013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','it-tony92','tonymoody@iinet.net.au','tony p moody','1 tassell way<br>Riverland Ramble','Ravenswood','Western Australia','AUSTRALIA','6208','0895378287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 09:54:05',0,NULL,3,1,3,1,'RA184537893CN ','GLOT001*3 '),(19606,664325378013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','sourith','sourith.kayasith@gmail.com','sourith Kayasith','5 Emanuel Place','CONDER','Australian Capital Territory','AUSTRALIA','2906','0262949175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 07:45:24',0,NULL,3,1,3,1,'RA184527777CN\r ','GLOT001*3 '),(19529,759603477008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','hidesign2009','maitqho@yahoo.com.au','Mai Ho','4 Moore Street','Footscray','Victoria','AUSTRALIA','3011','0425789778','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-03 10:30:31',0,NULL,3,1,3,1,'RA184527088CN\r ','HBPH001 '),(19530,910242500012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','therugretailer','sales@thecarpetretailer.co.uk','the rug shop','Unit 1 Prestwood Court<br>Birchwood','Warrington','Cheshire','UNITED KINGDOM','wa3 6sb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 10:54:35',0,NULL,3,1,3,1,'RA184537788CN\r ','OTSO004*2 '),(19531,819891353002,120809397658,'New Sealed 3D Blu-ray Pirates of the Caribbean 4 On Stranger Tides',1,'BR3D009',17.99,'buysia','francoisheulio','hull309@btinternet.com','frank hull','15 cabinet close','dereham','Norfolk','UNITED KINGDOM','nr19 1gb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 11:58:08',0,NULL,3,1,11,1,'BJ01670111\r ','BR3D009 '),(19532,821618757011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','sanchitkhandelwal','mailsanny@yahoo.co.in','Sanchit Khandelwal','Flat 2, Blenheim Court<br>52 Kenton road, Harrow','London','Middlsex','UNITED KINGDOM','HA3 8AP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 12:08:39',0,NULL,3,1,3,1,'RA184537920CN\r ','OTSO004 '),(19533,910264511012,220816370106,'3 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*3',123.99,'eastar4uk','micktheblade69','micktheblade@hotmail.co.uk','michael howard','50','wirral','Cheshire','UNITED KINGDOM','ch631js','07792564283','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 12:17:46',0,NULL,3,1,3,1,'RA184537902CN ','OTSO004*3 '),(19534,821624107011,320441564362,'2.1 Acer Aspire 5100 5110 3100  Bluetooth Module+cable',1,'BTAC2122',12.4,'eastar4','comtrade1','shop@brinn-computer.de','Hans Joachim Brinn','Brinn Computer<br>Ricklinger Stadtweg 13','Hannover','','GERMANY','30459','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 12:28:01',0,NULL,3,1,2,1,'30110920125\r ','acer 8pin1.00 8cm  '),(19535,664984343013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','mfaabrantes','marcus.abrantes@hotmail.com','Tatiana Lima','Servidão Emilio Vieira Cristo, 101A - Cascatinha','Petrópolis','Rio de Janeiro','BRAZIL','25716-105','+55 (24) 8808-5459','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 12:29:59',0,NULL,3,1,11,1,'BJ01670109\r ',NULL),(19536,821630932011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','zeljko1692','zeljko.resovac@bredband.net','Zeljko Resovac','Reginavagen 72','Malmo','','SWEDEN','21363','+46706944713','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 12:52:51',0,NULL,3,1,21,1,'RA184527352CN\r ',NULL),(19537,821643783011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','sadieri1975','stompygrl@gmail.com','Seychelle Ricard','171A Queens River Dr','West Kingston','RI','UNITED STATES','02892-1726','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 13:39:30',0,NULL,3,1,1,1,NULL,NULL),(19538,821123100011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','s.m.mashud','smmashud@yahoo.com','S. MASHUD','77hoprtune, avenue.<br>kilburn','ADELAIDE','South Australia','AUSTRALIA','5084','0468990596','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19539,776842725001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','bbshirou','fastmga@hotmail.com','Bryan Bejarano','5418 NW 79th Ave<br>Webbox # 1361','Doral','FL','UNITED STATES','33166-4122','(506) 890-1499','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 14:25:41',0,NULL,3,1,1,1,NULL,NULL),(19540,821663010011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','kill_the_griffin','griffin@griffinshome.com','Kalin Tsankov','2 RUE DE L\'ABBE LONGER','Chatellerault','','FRANCE','86100','+33677772218','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 14:41:14',0,NULL,3,1,2,1,'30110922811\r ',NULL),(19541,910318143012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','savoyexpress','swiftairports@orange.net','a.majeed','179<br>tooting high street','london','London','UNITED KINGDOM','sw17 0sz','07970868786','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 15:02:05',0,NULL,3,1,3,1,'RA184527159CN\r ','HSJA010\r英标 '),(19542,821682032011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','lindaneutral111','reneweigelt@web.de','Rene Weigelt','Würschnitzaue 3','Neukichen','','GERMANY','09221','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 15:37:46',0,NULL,3,1,21,1,'RA184527406CN\r ','GLOT001 '),(19543,910338701012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','tayrona11','jonathancabarcas@aol.com','Jonathan Cabarcas','247 SW 8th St<br># 411','Miami','FL','UNITED STATES','33130-3529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 16:11:10',0,NULL,3,1,4,1,'YW867738842CN ',NULL),(19544,662278231013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','emica333','ema333ema@hotmail.com','VANJA DOBRIC , NAKIT ONA - MERCATOR','LJUBLJANSKA 36<br>id: si98994824','SLOVENSKA BISTRICA','','SLOVENIA','2310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 16:30:19',0,NULL,3,1,22,1,'BJ01670107\r ',NULL),(19545,821702917011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','779adrian123','adecooke@hotmail.co.uk','779ADRIAN COOKE','14 DALBEATTIE CLOSE','NOTTINGHAM','Nottinghamshire','UNITED KINGDOM','NG5 8QX','07791400909','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 16:31:49',0,NULL,3,1,3,1,'RA184537726CN\r ','OTSO004'),(19546,821717860011,320787340708,'New Jabra JX10 Series II 2  Bluetooth headset black',1,'HSJA004',19.98,'eastar4','brisk84','brisk@inbox.ru','Marat Gumyarov','Lomonosova st.<br>100-58','Severodvinsk','Arkhangelsk region','RUSSIAN FEDERATION','164512','+79210878500','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 17:05:35',0,NULL,5,0,18,1,NULL,'HSJA004\r 黑色的\r\r客户回信说只要黑色的  已退钱了'),(19547,664291187013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','electromecanik','kini.mod@hotmail.com','Michel Roberge','2580 ernest camiré','st denis de brompton','QC','CANADA','j0b 2p0','(819) 846-2944','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 17:13:54',0,NULL,3,1,3,1,'RA184527026CN\r ','GPS0006 '),(19548,910383803012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','sokoffdmitry','sokoff@inbox.ru','Dmitry Sokovyh','DZERZHINSKOGO 3-40','Samara','','RUSSIAN FEDERATION','443093','(902)292-9256','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 17:34:38',0,NULL,3,1,3,1,'RA184527370CN\r ','GLOT001 '),(19549,819919625002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','louisb7730','chasbusch5@aol.com','louis boucher','12135 Fox Chase Dr<br>Apt A2','hudson','FL','UNITED STATES','34669-2870','(860) 985-6844','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 18:08:15',0,NULL,3,1,1,1,NULL,NULL),(19550,767031500007,170728921582,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA004',20.98,'au-buy','rowe5546','scuba862@yahoo.com','andrew rowe','241 Maynard Ter SE<br>Apt 33','Atlanta','GA','UNITED STATES','30316-1778','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-03 18:10:02',0,NULL,3,1,1,1,'、 ','黑色 '),(19551,820818735002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','tuffie1233','mary_forga@hotmail.com','Mary Forga','810 N 6th St','Lakeview','OR','UNITED STATES','97630-1105','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 18:15:19',0,NULL,3,1,1,1,NULL,NULL),(19552,821752193011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','bestech_uk','jeff@woolf.com','Jeff Woolf','35 Mayfield Court<br>London Road','Bushey','Hertfordshire','UNITED KINGDOM','WD23 2NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 18:25:53',0,NULL,3,1,3,1,'RA184537791CN\r ','OTSO004 '),(19553,821771658011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','paulthomas21','paulthomashaslam@gmail.com','Paul Haslam','Farriers Cottage<br>Blacksmith Lane','Harmston','Lincoln','UNITED KINGDOM','LN5 9SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 19:03:42',0,NULL,3,1,3,1,'RA184527318CN\r ','GLOT001 '),(19554,605356375003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','ifeau74','ivo.kurniawan@yahoo.co.id','Ivo Kurniawan','Burg W Kooimanstraat 20','KOEDIJK','','NETHERLANDS','1831CB','+31725619856','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 18:48:02',0,NULL,3,1,23,1,'bp04081201040004 ','BALO007 '),(19555,776095397001,110714301716,'New 3D Blu-ray The offical 2010 FIFA World Cup Film',1,'BR3D008',14.99,'buysia','st.andrew-2007','greatscot06@sbcglobal.net','Brad Morrison','2115 Wisteria Rd','Rockford','IL','UNITED STATES','61107-1525','(815) 312-1621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 19:09:45',0,NULL,3,1,1,1,NULL,NULL),(19556,820492165011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','maybreck1','jamesjones100@gmail.com','james jones','27 burnthwaite road','Liverpool','Merseyside','UNITED KINGDOM','l14 1py','01512811358','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 19:26:58',0,NULL,3,1,3,1,'RA184537916CN ','GLOT001*4 '),(19557,910449280012,220455488077,'HP TX2500 TX2500z TX2z Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',9.88,'eastar4','retasys','dan@retasys.com','Dan Sofer','Arimu str. 8<br>Nemezio k.','Vilnius','','LITHUANIA','LT-13262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 19:39:11',0,NULL,3,1,23,1,'bp04081201040005 ','BTHP2012 \rHP 8pin 0.8 3cm'),(19558,821792920011,320814097984,'Double-Reinforced India Flower Transparent Dome Birdcage Stick Umbrella',1,'UM00051',15.95,'eastar4uk','teebs-1964','starburst2603@gmail.com','Tracy Brown','65 Firmstone Rd<br>Winnall','Winchester','Hampshire','UNITED KINGDOM','SO23 0PA','01962864490','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 19:46:05',0,NULL,3,1,3,1,'RA184537434CN\r ','UM00051 \r紫罗兰色 如果没有就要黑色'),(19559,910472355012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','jarogroman','jgroman@centrum.cz','Jaroslav Groman','Bezrucova 479','Studenka','','CZECH REPUBLIC','74213','+420602607684','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 20:21:05',0,NULL,3,1,11,1,'BJ01670112\r ','WLAT005 '),(19560,767767060007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'au-buy','3li205','edgar.cochet@hotmail.fr','Edgar Cochet','165 rue Maurice Arnoux','Montrouge','Ile-de-France','FRANCE','92120','06.42.60.68.22','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-03 20:36:05',0,NULL,3,1,11,1,'BJ01670108\r ','HSUE003 '),(19561,665131049013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','tfredster','twf@psfc.mit.edu','Tom Fredian','106 Pine Hill Rd','littleton','NH','UNITED STATES','03561-4506','(781) 718-8456','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 20:45:58',0,NULL,3,1,1,1,'LK165504932CN\r ',NULL),(19562,910487056012,220663940722,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card dell acer',1,'WLIN012',32.99,'eastar4','rd3bl','admin@cyberdom.ru','LEONID BELETSKI','Sudostroitelnaia 31-3-133','MOSCOW','','RUSSIAN FEDERATION','115407','(495)922-4712','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 20:46:49',0,NULL,3,1,11,1,'BJ01670006\r ','WLIN012 '),(19563,909575604012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','fundza','rosiematt@hotmail.com','Matthew Rose','2/84 Heatherdale Road','Mitcham','Victoria','AUSTRALIA','3132','0398748789','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 21:09:35',0,NULL,3,0,3,1,'RA184537730CN\r ','OTSO004*2 '),(19564,665141954013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','andre34540','andregillard@yahoo.com','andre gillard','82 indian pond drive,seal cove','conception bay south','NL','CANADA','A1x6p4','(709) 764-3224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 21:16:09',0,NULL,3,1,3,1,'RA184527012CN\r ',NULL),(19565,665150508013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',19.98,'eastar4','carohenr-03','henrymuellers@aol.com','Carola  Müller','Klingerstraße 1','Dresden','','GERMANY','01139','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 21:41:23',0,NULL,3,1,2,1,'30110922903\r ','CAB-SS-2626 '),(19566,767809706007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','timathan','drakat@ath.forthnet.gr','Athanasios Drakopoulos','26 Papaflessa St.','Nea Philadelphia','ATTIKI','GREECE','143 42','2102317692','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-03 22:02:57',0,NULL,3,1,22,1,'BJ01670105\r ','RELO003 '),(19567,611431441004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','joe35230','ronanebay35230@gmail.com','Ronan PAIN','Le Cormier','BOURGBARRE','Bretagne','FRANCE','35230','0952324109','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 22:10:02',0,NULL,3,1,3,1,'RA184527131CN\r ','OTHP005\r换地址了\rRonan PAIN\rLe Cormier\r35230 BOURGBARRE\rFRANCE\r '),(19568,910532391012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','haatatitla','moravecmilos@yahoo.com','Milos Moravec','A. Hlinku 451/3','Teplicka nad Vahom','','SLOVAK REPUBLIC','013 01','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 22:16:15',0,NULL,3,1,22,1,'BJ01670106\r ','RELO002 '),(19569,910550603012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',2,'HSSA002',21.98,'eastar4uk','belczebu','forsakenwing@hotmail.com','Jorge Garcia','PO Box 375070','CAYEY','PR','PUERTO RICO','00737-5070','787-356-1419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 22:58:24',0,NULL,3,1,1,1,NULL,'HSSA002\rblack version '),(19570,910554434012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','angalo79','angalo79@hotmail.com','antonio garrido lopez','avenida los derechos humanos, 12, 2-b','arganda del rey','Madrid','SPAIN','28500','646070155','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 23:07:40',0,NULL,3,1,2,1,'30110916205\r ',NULL),(19571,910560376012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4uk','danib3cam','danib3@msn.com','daniele allen','3, Cambridge House<br>Bumpstead Road','Haverhill','Suffolk','UNITED KINGDOM','cb9 8qe','01440763149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 23:21:15',0,NULL,3,1,3,1,'RA184537451CN\r ','UM00031 \rpink 粉色的'),(19572,611453916004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','verkaz','marcin.verkaz@gmail.com','Marcin Sacharuk','Dalaneveien 10','Kristiansand','','NORWAY','4617','004740052654','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 23:36:01',0,NULL,3,1,3,1,'RA184527057CN\r ','OTSO002'),(19573,821902416011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','wozlord','wozlord@gmail.com','Warren Lord','26 Victoria Street','Lytham','Lancashire','UNITED KINGDOM','FY8 5EA','07535688938','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 23:51:04',0,NULL,3,1,3,1,'RA184527065CN\r ','LGAD001 '),(19574,767849664007,170728978814,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',49.99,'au-buy','serix','l.serg.n@gmail.com','Sergey Lebedev','st. Odintsova 36-1-701','Minsk','By','BELARUS','220136','+375297565764','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-03 23:53:58',0,NULL,3,1,21,1,'RA184527114CN\r\r ','LGRM001 '),(19575,910572841012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','dave32145','djhutchie@gmail.com','David Hutchinson','180 St Kilda Road','St Kilda','Victoria','AUSTRALIA','3182','0413308999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 23:57:20',0,NULL,3,1,2,1,'30111203091 ',NULL),(19576,606165454003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','anti-mouro','barrosgmr@gmail.com','Miguel Barros','Rua do Pombal, Nº920 Azurem','Guimarães','','PORTUGAL','4800-023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 00:25:11',0,NULL,3,1,23,1,'bp04081201040003 ','BALO007 '),(19577,821913650011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','alanleite2008','alanleite@hotmail.com','Alan Leite Nascimento','Qng 15 Casa 36','Taguatinga','Brasília','BRAZIL','72130150','556181266970','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 00:28:18',0,NULL,3,1,3,1,'RA184527851CN ','WLIN015 +MOCN001\r再发两个半高卡架子\r送螺丝\r客户打了3美金挂号\r可以发了'),(19578,664510183013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','walterbosmans2009','walterbosmans@hotmail.com','Decoster Elisabeth','Merelstraat 42','Haacht','','BELGIUM','3150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 00:15:32',0,NULL,3,1,22,1,'BJ01670113\r ','ADAK001 '),(19579,821924992011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','hardcore287069','stanley_feciaszko@hotmail.com','Stanley Feciaszko','2 Saw Mill River Road','Yonkers','NY','UNITED STATES','10701','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 01:03:43',0,NULL,3,1,1,1,'、 ',NULL),(19580,910597954012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','$$wolfgary','garymwolf@hotmail.com','Gary Wolf','Flagstar Bank<br>23636 West','Brownstown','MI','UNITED STATES','48183','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 01:07:50',0,NULL,3,1,1,1,NULL,NULL),(19581,611478943004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.49,'cnfaner','craigblumus','craig@chivers.org','Craig 2012 Blum','46 Cherry Tree Road','Rainham','Kent','UNITED KINGDOM','ME8 8JZ','01634231031','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 01:26:34',0,NULL,3,1,23,1,'bp04081201040002 ','MOMI004\r白色的 '),(19582,665201483013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','ban2011benedito','noalii@hotmail.com','Benedito Noale','Rua Pedro Sovierzoski, 401 <br>Bloco A, Apt.101A','Campo Largo','Parana PR','BRAZIL','83601360','41 33934705','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 01:34:15',0,NULL,3,1,3,1,'RA184537933CN ','GLOT001*2 '),(19583,821940751011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT001*2',88.99,'eastar4','deniway73','deniway27@gmail.com','Tibor Gyorgy','Flat 302,Argyrokastrou street 4, Essex apts, B - block','Limassol','Pyrgos','CYPRUS','4534','+35 9 774-9658','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 01:56:38',0,NULL,3,1,21,1,'RA184527264CN\r ','GLOT001*2 '),(19584,821940057011,320762413525,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','cannaspace','cannaspace@hotmail.com','Matthew Clarke','15 highfieled drive<br>bilsthorpe','Nottingham','Nottinghamshire','UNITED KINGDOM','ng22 8sn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 02:03:09',0,NULL,3,1,3,1,'RA184527145CN\r ','HBPH001 '),(19585,611226432004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','mean_dragon225','bigalexc75@gmail.com','Alessandro Colella','368 Whitby Shores Greenway','Whitby','ON','CANADA','L1N9R8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 02:12:55',0,NULL,3,1,3,1,'RA184527043CN\r ','OTHP005 '),(19586,821956571011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','jplazas65','jaime.plazas@ecopetrol.com.co','Adriana Latham','24979 Constitution Ave Apto #711','Stevenson Ranch Ca 91381','CA','UNITED STATES','91381','562 225 7267','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 02:59:04',0,NULL,3,1,1,1,' ',NULL),(19587,910640846012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',83.99,'eastar4uk','coheen004','stormsuns@msn.com','atizar kalbi','apartment 59 columbia place<br>77 fornham street','sheffield','south yorkshire','UNITED KINGDOM','S2 4AR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 03:14:41',0,NULL,3,1,3,1,'RA184537712CN\r ','OTSO004*2 \r申报为gift'),(19588,606201839003,130617205109,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',176.99,'cnfaner','spidie69','almcrae@netspace.net.au','Anthony McRae','54 Jezabel Drive','Springfield Lakes','Queensland','AUSTRALIA','4300','0438133726','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 03:19:31',0,NULL,3,1,3,1,'RA184537448CN\r ','GLSG009*2 '),(19589,8881325647245233,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW - ',1,'WLIN014',18.99,'aliexpress','1006104744 ','thinklab@yandex.ru','Anton Alekseev	','Ryazansky prospekt 70-1-75','Moscow','Moscow','RUSSIAN FEDERATION	','109542','79169577305',NULL,NULL,NULL,'2012-01-04 03:20:45',0,NULL,3,1,3,1,'RA184527105CN\r ','WLIN014 '),(19590,759954883008,180755522339,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'au-buy','sierrared','sierrared1447@yahoo.com','lori pelcher','1447 birchim ln','bishop','ca','UNITED STATES','93514-7627','(760) 937-7919','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-04 03:29:24',0,NULL,3,1,1,1,'LK171511067CN\r ',NULL),(19591,665240308013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','pop_sheth','pop_sheth@yahoo.com','Divyang Sheth','1744 - 61 street S.W','Edmonton','AB','CANADA','t6x0w3','(780) 757-4816','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 03:33:02',0,NULL,3,1,3,1,'RA184538001CN ','GLOT001*4 '),(19592,910646534012,220816384245,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',78.99,'eastar4uk','micgirard','micgirard@hotmail.com','Michael Girard','551 chemin du Pont -Taché Nord','Alma','QC','CANADA','G8B6T4','(418) 480-4409 ext.: 2420','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 03:36:05',0,NULL,3,1,3,1,'RA184537814CN ','GLOT001*3 '),(19593,910648356012,220886921872,'Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',12.95,'eastar4uk','74anki','majusk@hotmail.com','anki karlsson','bangårdsgatan 31','torsby','none','SWEDEN','68533','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 03:41:10',0,NULL,3,1,22,1,'BJ01670059\r ','UM00001 \ryellow黄色的'),(19594,910653070012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',137.99,'eastar4','urbanfire123','rajhiahmed_gta@hotmail.com','Rajhi Ahmed','11 Helston St Stanhope Gardens','Sydney','New South Wales','AUSTRALIA','2768','0288834024','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 04:00:29',0,NULL,3,1,3,1,'RA184537805CN\r ','OTSO004*2 '),(19595,910661686012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','neil_xiong','neilxiong@gmail.com','Neil Xiong','Datacom, 1 Julius Ave','North Ryde','New South Wales','AUSTRALIA','2113','0434866363','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 04:32:40',0,NULL,3,1,3,1,'RA184537425CN\r ','OTIN005 '),(19596,821985517011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.88,'eastar4','raderator','jconrad607@hotmail.com','Gerald A Conrad','47 Woodcrest Way','Conklin','NY','UNITED STATES','13748-1252','(607) 763-1609','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 04:38:00',0,NULL,3,1,1,1,'LK172592115CN\r ','acer 5pin 1.25 3cm  '),(19597,611518607004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','mccarter9211','jmccarter08@hotmail.com','James Mccarter','158 Sapalo Dr','Saint Marys','GA','UNITED STATES','31558-3709','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-04 04:48:31',0,NULL,3,1,1,1,'LK171998327CN\r ',NULL),(19598,821993523011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','bambleweeny57','woodleadoe@gmail.com','Logan Doe','Po Box 747','Woodend','Victoria','AUSTRALIA','3442','0354272092','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 05:17:51',0,NULL,3,1,2,1,'30111003893\r ',' '),(19599,821996050011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','netstuff-sf','netstuff3@ekahuna.com','Phil Koenig','912 Cole St<br># 152','San Francisco','CA','UNITED STATES','94117-4316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 05:27:30',0,NULL,3,1,1,1,'LK170893373CN\r ',NULL),(19600,611526274004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',54.7,'cnfaner','gummcgay','gabrielskchung@gmail.com','Gabriel Chung','Suite 210-3602 Gilmore Way','Burnaby','BC','CANADA','V5G4W9','(778) 322-5656','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 05:45:37',0,NULL,3,1,3,1,'RA184527613CN\r ','GLOT005 '),(19601,611526412004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','wbodnarchuk','wayne_bodnarchuk@hotmail.com','Wayne Bodnarchuk','111 Dearman Road','West St. Paul','MB','CANADA','R4A9A1','(204) 414-8482','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 05:46:27',0,NULL,3,1,3,1,'RA184527128CN\r ','BALO007 '),(19602,910682779012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','maxvansarker','ricscorg@hotmail.com','richard scorgie','8 Seymour st','Broadmeadows','Victoria','AUSTRALIA','3047','0393096738','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 06:15:04',0,NULL,3,1,3,1,'RA184527644CN\r ','GLOT001 '),(19603,910689343012,220913327376,'NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses  3300 GR',1,'GLSG009',54.99,'eastar4uk','levinvoelz','lev89@gmx.de','Levin Völz','Stoevernstr.27','Castrop-Rauxel','','GERMANY','44581','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 06:53:25',0,NULL,3,1,21,1,'RA184527732CN\r ','GLSG009 '),(19604,910696239012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','tonikton','expanius@gmail.com','ALEXEY SERGIENKO','Komsomolskaya st. 65/12','Komsomolsk-on-Amure','RU','RUSSIAN FEDERATION','681024','79142016054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 07:33:56',0,NULL,3,1,3,1,'RA184527715CN\r ','一共买了两副'),(19605,910696770012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','tonikton','expanius@gmail.com','ALEXEY SERGIENKO','Komsomolskaya st. 65/12','Komsomolsk-on-Amure','RU','RUSSIAN FEDERATION','681024','79142016054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 07:35:38',0,NULL,3,1,17,0,'RA184527715CN\r ',NULL),(19607,665277649013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','jgamster','jessgammie91@hotmail.com','Jessica Gammie','24 Silvara cct<br>Capalaba','brisbane','Queensland','AUSTRALIA','4157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 07:48:00',0,NULL,3,1,11,1,'BJ01670085\r ','UM00041 \r接边斑马纹透明伞   '),(19608,910705293012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','livthrume','san.pr.business@gmail.com','San Holder','30 Old Clayton Ct','Columbia','SC','UNITED STATES','29205-4539','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 08:23:30',0,NULL,3,1,1,1,'LK172889632CN\r ',' '),(19609,8881325671984548,111,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card ',1,'WLIN015',0,'eastar4','sergeiest159356','sergeiest@mail.ru','Sergei Zarikov','Ida Aalbergin tie 5f63','Helsinki','','FINLAND','00400','+358465446104',NULL,NULL,NULL,'2012-01-04 10:13:04',0,NULL,3,1,22,1,'BJ01670083\r ',NULL),(19610,665298791013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','mel_harry','pridec@adam.com.au','Melissa Harrison','62 Ninth Ave<br>Woodville North','Adelaide','South Australia','AUSTRALIA','5012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 10:15:52',0,NULL,3,1,3,1,'RA184527661CN\r ','GLOT001*2 '),(19611,8881325672414272,111,'Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',0,'eastar4','cvetozar123','zari_nikolov@yahoo.com','Mariana Kosmopulu','4-6 Folegandrou str.<br>Glyfada','Athens','Attiki','GREECE','16561','(697) 270 - 4573',NULL,NULL,NULL,'2012-01-04 10:20:14',0,NULL,3,1,22,1,'BJ01670074\r ','HSNO019\r欧标\r补发的\r发之前测试一下是否充电效果好 也就是电量是否能持久'),(19612,910736317012,220901458172,'New SAMSUNG Magic Water Filter WSF-100 for Samsung Refrigerator',1,'SAFI002',33.99,'eastar4uk','chrisetmag3','chrisetmag3@hotmail.fr','barth','7 impasse las combes','carlus','Midi-Pyrénées','FRANCE','81990','0685742418','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 10:36:37',0,NULL,3,1,3,1,'RA184527573CN\r ','SAFI002 '),(19613,910737401012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','mrjhappy','mrjhappyman@hotmail.com','Martin Jeffels','7 St Johns Park<br>Stillington','Stockton on tees','Cleveland','UNITED KINGDOM','TS21 1NT','01740630634','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 10:40:33',0,NULL,3,1,3,1,'RA184527499CN\r ','RELO002 '),(19614,910741796012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','italianoz','loredanaeze@hotmail.com','Loredana Eze','Lot 39 Windsor Road','Kellyville','New South Wales','AUSTRALIA','2155','0288145353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 11:00:08',0,NULL,3,1,3,1,'RA184527689CN\r ','GLOT001*2 '),(19615,822063865011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tursen75','turkansener@hotmail.com','Turkan Sener','Blaastjerneveien 30','Finstadjordet','','NORWAY','1475','004767974728','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 11:19:47',0,NULL,3,1,22,1,'BJ01670082\r ','HSJA002 \r欧标'),(19616,606270794003,130620867310,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','dinobarsaleau','dbarsaleau@gmail.com','Dean A Barsaleau','150 Brandywine Dr','Summerville','SC','UNITED STATES','29485-8001','(843) 879-3134','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-04 11:32:47',0,NULL,3,1,1,1,'LK173608452CN\r ',NULL),(19617,822073312011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','brotherodd','i.munden@btinternet.com','Ian Munden','Aston Scott Ltd<br>41 The Broadway','Cheam VIllage','Surrey','UNITED KINGDOM','SM3 8BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 11:57:10',0,NULL,3,1,3,1,'RA184527445CN\r ','OTHP005 '),(19618,910759302012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','sul.vendas','sulvendas@gmail.com','Michael Pereira Silva','Rua Osório Correia 813','Cachoeirinha','Rio Grande do Sul','BRAZIL','94935-460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 12:01:37',0,NULL,3,1,11,1,'BJ01670081\r ','OTCN004*10 '),(19619,822079920011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','dreggnal','hg.lang@gmx.de','Gerd Lang','Landstr. 20/1','Barsinghausen','','GERMANY','30890','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 12:23:04',0,NULL,3,1,21,1,'RA184527437CN\r ','HBPH002 \r\r'),(19620,822087608011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',17.99,'eastar4uk','bravoonezero','geraldhayes1@btinternet.com','Gerald Hayes','23 Ballyloughan Park','Ballymena','Antrim','UNITED KINGDOM','BT43 5HW','07894238018','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 12:48:01',0,NULL,3,1,3,1,'RA184527803CN\r ','TRSN001 '),(19621,910777861012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','asheshpatel2004','asheshpatel2004@yahoo.com','ASHESH PATEL','13 WALLIS STREET ,<br>EAST SIDE','ALICE SPRINGS','Northern Territory','AUSTRALIA','0870','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 13:04:50',0,NULL,3,1,3,1,'RA184527750CN\r ','GLOT001 '),(19622,606291839003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',13.88,'cnfaner','slava-teacher','ivaschuk99@mail.ru','Vyacheslav Ivaschuk','Alma-Atinskaja<br>22a/2','Kiev','Kiev','UKRAINE','02092','+380979500013','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 13:25:13',0,NULL,3,1,21,1,'RA184527410CN\r ','HSNO007 \r欧标'),(19623,8881325687238418,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'aliexpress','1006122057','norkorn@gmail.com','Nickolay Davidenko	','Kashirskoe shosse, 128/1, ap.78','Moscow','Moscow','RUSSIAN FEDERATION	','115582','+7 909 9422689',NULL,NULL,NULL,'2012-01-04 14:27:18',0,NULL,3,1,3,1,'RA184527468CN\r\r ','WLIN014 '),(19624,611612423004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.49,'cnfaner','roboredo123','pedro.roboredo@gmail.com','Pedro Roboredo','Rua Nuno Tristão, 105 2º Centro','Valongo','Valongo','PORTUGAL','4440-823','(351)931151533','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 14:50:48',0,NULL,3,1,23,1,'BP04081201050001 ','MOMI004 \r白色的'),(19625,822137250011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','wigley50','wigley_50@hotmail.com','Colin Weeks','4 St Albans Close','Kettering','Northants','UNITED KINGDOM','NN15 5EB','01536358532','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 15:24:56',0,NULL,3,1,3,1,'RA184527454CN\r ','LGAD001 '),(19626,822143203011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','gabberer1','ebay@darkraver.de','Jörg Träger','Obertorstraße 5','Münstermaifeld','','GERMANY','56294','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 15:40:35',0,NULL,3,1,21,1,'RA184537686CN\r ','GLOT001*4 '),(19627,910838884012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Linda Cantwell','24 Harlem St','Worcester','MA','UNITED STATES','01610-2106','(503) 309-6418','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19628,822149059011,320730481375,'New Lady wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'eastar4','frojds','frederic.bonchoux@gmail.com','Frédéric Bonchoux','Rue du vingt-quatre août 4 b','Tournai','','BELGIUM','7500','069/234373','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 15:56:20',0,NULL,3,1,22,1,'BJ01670054\r ','UM00022 \r正红色长柄婚庆伞 '),(19629,910847324012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',115.98,'eastar4uk','ruffcolly','wrinkleys@tesco.net','Frederic Charles Wright','22 Parkhouse Road','Minehead','Somerset','UNITED KINGDOM','TA24 8AD','01643703180','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 16:12:27',0,NULL,3,1,3,1,'RA184527785CN\r ','OTSO004*2 '),(19630,910840034012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Ron Ryel','417 Main St','East Hartford','CT','UNITED STATES','06118-1410','(503) 309-6418','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19631,606334230003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',53.8,'cnfaner','education_channel','scott@tecc.tv','Scott Maiden','703 N Willow Ave<br>The Education Channel','Tampa','FL','UNITED STATES','33606','(813) 254-2253 ext.: 212','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-04 16:25:30',0,NULL,3,1,1,1,'LK171020275CN\r ',NULL),(19632,611639264004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',39.6,'cnfaner','artshaper','osx86@sixflow.net','won-taek seo','4f, 113-1, garak-dong,songpa-gu','seoul','','KOREA,REPUBLIC OF','137-060','82-10-7312-2154','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 16:34:24',0,NULL,3,1,3,1,'RA184527600CN\r ','WLAP008 \r一个补发 一共3个'),(19633,665387368013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','966boyer','durango.kid7@hotmail.com','TAMA Canada Ltd. (Robert Faithfull)','581 Plains Road East<br>2nd Floor','Burlington','ON','CANADA','L7T 2E6','(905) 639-4555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 16:52:16',0,NULL,3,1,3,1,'RA184527675CN\r ','GLOT001*2 '),(19634,910871407012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','alpp2001','alpp2001@hotmail.com','ANTONIO L. PEREZ PIÑERO','\"Don Euro\"<br>C/. CLARA CAMPOAMOR, 3.','UBRIQUE','Andalucía Ceuta y Melilla','SPAIN','11600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 17:07:38',0,NULL,3,1,21,1,'RA184527542CN\r ','LGRM001 '),(19635,821243836002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',1,'OTAM001',5.99,'buysia','ssfein','ssfein@midmaine.com','steven fein','208 bluff rd','northport','ME','UNITED STATES','04849','(207) 338-4316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 17:25:14',0,NULL,3,1,1,1,'LK170871041CN\r ',NULL),(19636,775507890001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',11.99,'buysia','kirillzhura','zhurankou@hotmail.com','Aliaksei Zhurankou','4836 147TH PL NE','MARYSVILLE','WA','UNITED STATES','98271-3422','(360) 320-9055','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 17:31:54',0,NULL,3,1,1,1,'LK169259818CN\r ',NULL),(19637,611654720004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','eliaszoghbi','eliaszoghbi@ig.com.br','Antonio E Z Castro','Rua dos Artistas, 355 / 102','rio de janeiro','rj','BRAZIL','20511130','(552) 192-2394 ext.: 46','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 17:36:09',0,NULL,3,1,3,1,'RA184527366CN\r ','MOOE001\rOEM '),(19638,910895865012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',13.98,'eastar4uk','vvn-fi','vilsku.viljanen@gmail.com','Ville Viljanen','Korkeakoskentie 23 B 6','Jyväskylä','','FINLAND','40500','+358440299997','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 17:59:04',0,NULL,3,1,21,1,'RA184527485CN\r ','OTHP004 '),(19639,665418710013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','pimpsins666','acerna6@ymail.com','Alfonso Cerna','14747 Maplecreek Dr','Orland Park','IL','UNITED STATES','60467','(708) 969-0453','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 18:21:26',0,NULL,3,1,1,1,'LK174952545CN\r ',NULL),(19640,665422543013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','alexey.belousov','alexey@beliy.pro','Alexey Belousov','ul. Hrustalnaya, dom 40, kv. 10','Tver\'','Tverskaya obl','RUSSIAN FEDERATION','170021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 18:33:21',0,NULL,3,1,11,1,'BJ01670079\r ','WLAP008 '),(19641,611692421004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','guayama77','joel_el_cangri4444@hotmail.com','Hector J. Lugo','420 Snell St<br>Apt 1','Fall River','MA','UNITED STATES','02721-3953','(508) 617-6048','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-04 19:20:58',0,NULL,3,1,1,1,'LK176099895CN\r ',NULL),(19642,822262571011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',49.99,'eastar4uk','ashleymangham','ashle7@hotmail.co.uk','ashley mangham','22 winney hill harthill','sheffield','South Yorkshire','UNITED KINGDOM','s26 7yn','01909771669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 20:00:42',0,NULL,3,1,3,1,'RA184535243CN\r ','OTSO004 '),(19643,822260936011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',2,'UDAP001',68.98,'eastar4','kcun2878','cundykelly@gmail.com','Kelly Cundy','P.O. Box 11975','Fort Lauderdale','FL','UNITED STATES','33339','(954) 294-2188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 19:54:47',0,NULL,3,1,1,1,'LK176163179CN\r ',NULL),(19644,910972183012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','The Goddard School','12818 E 116th St','Fishers','IN','UNITED STATES','46037-9718','(503) 515-6054','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19645,822272695011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','lisandra-2009','srajerova1@seznam.cz','Michaela Šrajerová','Liberecká 598','Hrádek nad Nisou','Liberecký kraj','CZECH REPUBLIC','46334','+420723719181','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 20:18:39',0,NULL,3,1,11,1,'BJ01670056\r ','UM00040 \r'),(19646,910984295012,220915102085,'New In Box SAMSUNG Magic Water Filter WSF-100 for Samsung Refrigerator',1,'SAFI002',55.99,'eastar4','agar1244','antoniogarrido58@me.com','Antonio Garrido','11 Bevington Rd','Brampton','ON','CANADA','L7A0R9','(647) 523-0557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 20:32:36',0,NULL,3,1,3,1,'RA184527560CN\r ','SAFI002 '),(19647,910986872012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',17.5,'eastar4','butrascz','bock.ondrej@gmail.com','Ondrej Bock','Na Vejiri 1','Svitavy','Czech Republic','CZECH REPUBLIC','56802','420736764591','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 20:40:15',0,NULL,3,1,11,1,'BJ01670075\r ','ANCN002 '),(19648,910996192012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','bowlweavil','bowlweavil@mindspring.com','JB Fung - John Aaroe Group','8560 W Sunset Blvd<br>3rd Floor','West Hollywood','CA','UNITED STATES','90069','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19649,910995386012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','super_visor','meleshko.sa@gmail.com','SIARHEI MIALESHKA','Burdeynogo street 16-75','Minsk, Belarus','','RUSSIAN FEDERATION','220018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 20:57:13',0,NULL,3,1,3,1,'RA184527746CN\r ','GLOT001 '),(19650,822295852011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','andrius-ska','k.andrius@gmail.com','Andrius Kvasas','Alksnynės 4-14','Klaipėda','','LITHUANIA','93158','370 67020445','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 21:07:47',0,NULL,3,1,21,1,'RA184527635CN\r ','GLOT001 '),(19651,911021367012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',194.99,'eastar4uk','2187stevenc','clarksonsteven@googlemail.com','Steven Clarkson','31 Carson Mount','Sheffield','South Yorkshire','UNITED KINGDOM','S12 3GA','01142397326','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 21:44:52',0,NULL,3,1,3,1,'RA184527729CN\r ','OTSO004*4 '),(19652,911038524012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','angeldlr1950','adlr@tx.rr.com','Angel De La Rosa','2600 Timberhaven Dr','Flower Mound','TX','UNITED STATES','75028-2238','(972) 691-4415','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 22:17:55',0,NULL,3,1,1,1,'LK174318434CN\r ',NULL),(19653,911041557012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',12.99,'eastar4uk','johndrjwrg','jwrgreenhorn@gmail.com','John Greenhorn','23 Balcomie Road','Kirkcaldy','Fife','UNITED KINGDOM','KY2 6JB','01592596546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 22:25:45',0,NULL,3,1,3,1,'RA184527423CN\r ','WLAP002 '),(19654,911048517012,220908829691,'4 pairs of New 3D Active Shutter TV Glasses compatible 4 3D TV Sony  LG samsung',1,'GLOT001*4',103.99,'eastar4uk','chandrae123','ekada@optusnet.com.au','Chandra Ethakada','22 Horne Street','Brunswick','Victoria','AUSTRALIA','3056','0393875868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 22:40:49',0,NULL,3,1,3,1,'RA184527794CN\r ','GLOT001*4 '),(19655,822344792011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','goppyb','fub@mac.com','Fulvio Urso-Baiarda','5 Norfolk Place<br>Chapel Allerton','Leeds','West Yorkshire','UNITED KINGDOM','LS7 4PT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 22:53:24',0,NULL,3,1,3,1,'RA184527556CN\r ','MOAP001 '),(19656,911059417012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','tracy_doe','mdoherty@shaw.ca','tracy doherty','5148 chute lake rd','kelowna','BC','CANADA','v1w 4l6','(250) 979-8979','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 23:10:30',0,NULL,3,1,3,1,'RA184527539CN\r ','HBPH001 '),(19657,910578401012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','joaopedropinheiro','jppinheir@gmail.com','João Pedro Pinheiro','Rua Campos Monteiro, 35-A<br>Mem Martins','Sintra','','PORTUGAL','2725-481','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 23:20:01',0,NULL,3,1,22,1,'BJ01670066\r ','HSPH002 '),(19658,776432511001,110694692559,'New JBL Reference 220 Headphone for iPod MP3 MP4 Player',1,'HSJB001',11.99,'buysia','kujo4pm','kurtjohn@gmail.com','Kurt Johnson','142 Mitchell Rd','Alexandria','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 23:59:58',0,NULL,3,1,11,1,'BJ01670077\r ','HSJB001 \r澳标'),(19659,822369170011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',52.99,'eastar4uk','frangm91','fran_g_m_91@hotmail.com','Francisco Gil Muñoz','Gual Villalbi 6-17','Valencia','Comunidad Valenciana','SPAIN','46009','963389311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 00:05:24',0,NULL,3,1,21,1,'RA184527701CN\r ','GLOT001*2 '),(19660,760341313008,180699061836,'New Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',29.99,'au-buy','dima_bnt','dbrennon@gmail.com','Dmitriy Sheremet','Kirova str 1-2-24','Kharkov','','UKRAINE','61001','+380503231539','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-05 00:23:50',0,NULL,3,1,22,1,'BJ01670080\r ','HSJA010 '),(19661,911092194012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',2,'LGGL005',39.98,'eastar4','alantunes','alainformatica@yahoo.com.br','Marilia','Av Meriti 190','Rio de Janeiro','Rio de Janeiro','BRAZIL','21220203','(021) 3459-5760','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 00:39:40',0,NULL,3,1,11,1,'BJ01670067\r ','LGGL005 '),(19662,606488110003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','ja_owen','jamesrowen@hotmail.com','James Owen','60 Main','Hudson','QC','CANADA','j0p1h0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 01:04:58',0,NULL,3,1,3,1,'RA184527508CN\r ','RCLO007+POLO001+RCLO008*4 '),(19663,822389874011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','prateeksharma000prateek','prateeksharma000@gmail.com','prateek sharma','unit-104/82 alfred street<br>Fortitude valley','brisbane','Queensland','AUSTRALIA','4006','0425236634','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 01:21:04',0,NULL,3,1,3,1,'RA184527525CN\r',' HSNO019\r澳标'),(19664,911107271012,220502333404,'2.1 HP 8710w nw9440 nx9420 Bluetooth Module EDR +cable',1,'BTHP2105',12.39,'eastar4','j-henderson-817','henderson1600@sbcglobal.net','joseph henderson','1000 Irene St','burleson','TX','UNITED STATES','76028-6412','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 01:24:48',0,NULL,3,1,1,1,'LK176212952CN\r ','HP 8pin 1.0 20cm '),(19665,665552778013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','mariominoru','mariominoru@gmail.com','MARIO MINORU SHIMUTA','R BENTO VIEIRA 101 APT 83 ED TOKIO<br>IPIRANGA','SAO PAULO','SAO PAULO','BRAZIL','04202030','(55) 11 7765-1159','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 01:34:40',0,NULL,3,1,11,1,'BJ01670072\r ','CACN004 '),(19666,606502398003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','241tonsyl','tpinsonneault@videotron.ca','Pinsonneault Tony','33 Place de Sauternes','Terrebonne','QC','CANADA','J6W 6L3','(514) 774-6925','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 02:22:06',0,NULL,3,1,3,1,'RA184527595CN\r ','RCLO007+POLO001+RCLO008*4 '),(19667,911148592012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','zaccaroatc2012','zaccaro_atc@hotmail.com','Luiz Gustavo de F. Zaccaro','R: Prof. José B. Salgado, 518 Beira Rio 1','Guaratinguetá','São Paulo','BRAZIL','12517430',' 551231253723','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 03:36:23',0,NULL,3,1,11,1,'BJ01670069\r ','WLIN016 '),(19668,768355005007,170756059402,'2 pairs New LG Premium Water Filter Gen11042FR-08 4 Kenmore and LG refrigertors',1,'LGFI001*2',99.99,'au-buy','smithglg','gmsmithy@bigpond.com','Michelle Smith','93 Karall Street','Ormea','Queensland','AUSTRALIA','4208','0755407559','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-05 03:38:20',0,NULL,3,1,3,1,'RA184527587CN\r ','LGFI001*2 '),(19669,606145332003,130592182650,'New Genuine DENON RC-970 Remote Control',1,'RCDE002',77.9,'cnfaner','gunhogeezer','sarabagan@cox.net','Servando Rosario','8342 Rumson Dr','Santee','CA','UNITED STATES','92071-2251','(858) 583-2973','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-05 03:47:30',0,NULL,3,1,1,1,'LK172976036CN ',NULL),(19670,8881325735628774,111,'New Genuine Motorola H715 Bluetooth Wireless Headset+AC adapter',1,'',0,'cnfaner','bleacherbumb27','sanjaykurup@yahoo.com','Jay Kurup','2620 Grant Ave<br># A','Redondo Beach','CA','UNITED STATES','90278-3827','',NULL,NULL,NULL,'2012-01-05 03:53:48',0,NULL,3,0,1,1,'LK109000796CN\r ','补发的 \rHSMO023'),(19671,665589689013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','prorab55','staspsv@mail.ru','Petrov Stanislav','Torgovaya str., 20-89\"A\"','Omsk','','RUSSIAN FEDERATION','644082','(913) 9743140','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 04:17:50',0,NULL,3,1,3,1,'RA184527692CN\r ','GLOT001*2 '),(19672,8881325738848580,111,'24K多色伞',1,'UM00008',0,'eastar4','jhewinbaldwin','duaneandjulie@gmail.com','Julie Hewin Baldwin','8117 Virginia Ave','West Point','VA','UNITED STATES','23181','(804) 843-7370',NULL,NULL,NULL,'2012-01-05 04:47:28',0,NULL,5,0,18,0,NULL,'不补发了   退款比较划算'),(19673,8881325739332933,111,' CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',13,'TRTS001',97.5,'eastar4','cvanbeek7','cvanbeek7b@aol.com','Chris Van Beek','10025 De Soto Avenue, Apt. #121','Chatsworth','CA ','USA','91311','',NULL,NULL,NULL,'2012-01-05 04:55:32',0,NULL,3,1,4,1,'YW867738516CN ','TRTS001 '),(19674,611834846004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','wereheredear','cdh13@pitt.edu','Crystal D Hollinger','472 Ohio Ave<br>Apt 2','Rochester','PA','UNITED STATES','15074-2059','(717) 917-0335','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-05 04:55:32',0,NULL,5,1,18,0,NULL,''),(19675,665597645013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','idong1234','ian_991@hotmail.com','Ian Dong','PO BOX 111','MOONEE PONDS','Victoria','AUSTRALIA','3039','0403585554','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 05:08:01',0,NULL,3,1,11,1,'BJ01670073\r ','HSNO023\r澳标 '),(19676,611839005004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','tomecekr','rtomecek@atlas.cz','Tomecek Richard','Polackova 1828','Sokolov','Sokolov','CZECH REPUBLIC','35601','420604308229','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 05:27:51',0,NULL,3,1,23,1,'BP04081201050003 ','BALO007 '),(19677,911176807012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','ge_7','grgodoy@usp.br','Geraldo Reis de Godoy','R. General Brasilio Taborda, 271','São Paulo','SP','BRAZIL','05591-100','0551172190214','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 05:28:13',0,NULL,3,1,3,1,'RA184527511CN\r ','LGRM001 '),(19678,822457173011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','bubblemansjunk','cturner20111@hotmail.com','Carole Turner','218 W Avenue L','Calimesa','CA','UNITED STATES','92320-1224','(909) 253-3835','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 05:35:36',0,NULL,3,1,1,1,'LK175755498CN\r ',NULL),(19679,665613690013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','dipesh276','eternal_pooja@yahoo.com','Pooja Sinha','30 E Division St<br>Apt 5C','Chicago','IL','UNITED STATES','60610-5289','(224) 829-5595','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 07:13:50',0,NULL,3,1,1,1,'LK171509151CN\r ',NULL),(19680,911200041012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','chris_9961','cammeh@hotmail.com','Cam Callus','33 Hatton Court','Bassendean','Western Australia','AUSTRALIA','6054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 07:43:54',0,NULL,3,1,3,1,'RA184527627CN\r ','GLOT001 '),(19681,665624447013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','katsanosm87','katsanosm@hotmail.com','Dimitrios Katsanos','Flaboura','Preveza','','GREECE','48100','302682052414','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 08:33:41',0,NULL,3,1,21,1,'RA184527848CN\r ','GLOT001*2 '),(19682,911211240012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','trwroe','twroe@activ8.net.au','Tony Wroe','12 Reinaerhoff Crescent<br>Gecko Valley','Gladstone','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 08:36:39',0,NULL,3,1,11,1,'\\ ','LGGL005 '),(19683,822491810011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',2,'MOCN001',7.96,'eastar4','alanleite2008','alanleite@hotmail.com','Alan Leite Nascimento','Qng 15 Casa 36','Taguatinga','Brasília','BRAZIL','72130150','556181266970','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 08:58:00',0,NULL,8,1,17,0,' ',NULL),(19684,8881325754192266,111,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',10.49,'aliexpress','1006135225 ','shevonalli@hotmail.com','naroce vignarajah	','17 hyacinth crecent','scarborough	','Ontario','CANADA','m1x1w6','+1 647 998-4399',NULL,NULL,NULL,'2012-01-05 09:03:12',0,NULL,5,0,18,0,NULL,NULL),(19685,822505644011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','gurkhaan','arturogp@post.cz','Arturo Gutiérrez Pérez','Calle Pirra 7, 2ºB','Madrid','Madrid','SPAIN','28022','654087572','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 10:06:02',0,NULL,3,1,21,1,'RA184535075CN\r ','GLOT001 '),(19686,911239725012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','juvens11','juvens1@naver.com','Dongho Lee','32115 105th PL SE<br>Apt H302','Auburn','WA','UNITED STATES','98092-4783','(253) 732-8823','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 10:38:14',0,NULL,3,1,21,1,'RA184535124CN\r ','UM00010\r钢琴美女伞  '),(19687,822519832011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',3,'UDAP001',103.47,'eastar4','abadajoz','angeloti@gmail.com','ROCHE FARMA','(Reception 4th floor - Att. Angel Camacho)<br>Calle Josefa Valcarcel 40','Madrid','Madrid','SPAIN','28027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 11:00:32',0,NULL,3,1,3,1,'RA184535190CN\r','UDAP001 '),(19688,822520381011,320801186995,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',13.95,'eastar4uk','bigredjo','demonlittle@live.com.au','Jo Curram','19 boronga crescent','Berkely','New South Wales','AUSTRALIA','2506','0242714153','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 11:02:20',0,NULL,3,1,11,1,'BJ01670048\r ',' UM00040'),(19689,822524936011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRMX002',7.57,'eastar4','snhstq','h.j.stegeman@hccnet.nl','Henk Stegeman','Iroko 128','Dordrecht','','NETHERLANDS','3315 PM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 11:20:57',0,NULL,3,0,23,1,'BP04081201060002 ','TRMX002 \r已入库'),(19690,822525171011,320766024936,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',35.99,'eastar4uk','acre1426','alanctela@dsl.pipex.com','Alan Cremer','Tela<br>Station Road','Eynsford','Kent','UNITED KINGDOM','DA4 0EJ','01322863732','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-05 11:24:57',0,NULL,3,1,3,1,'RA184535067CN\r ','HBPH007 '),(19691,665659331013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','kitty870327','mirang870327@naver.com','Dongjoo Eum','Koaroo Apartment 107-101<br>PyeongsanDong','Yangsan','Kyeongnam','KOREA,REPUBLIC OF','626-736','010-6806-8086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 12:07:20',0,NULL,3,1,11,1,'BJ01670035\r ','CASS003 \rCAB-6060'),(19692,665663840013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','andreykadyrov','andrewich19745@yahoo.com','Andrey Kadyrov','Marshala Katukova st, 25/1 - 158','Moscow','','RUSSIAN FEDERATION','123181','905-517-1919','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 12:28:48',0,NULL,3,1,3,1,'RA184535098CN\r ','OTES001 '),(19693,611905603004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','apostoli2004','paul_laspas@hotmail.com','Paul Laspas','26 Weeroona Rd, Murrumbeena','Melbourne','Victoria','AUSTRALIA','3163','0395684180','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 13:08:43',0,NULL,3,1,3,1,'RA184535107CN\r ','BALO007 '),(19694,911298117012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','walthj2','waltj52@verizon.net','Walt Johnson','76 E Browning Rd','Bellmawr','NJ','UNITED STATES','08031-2316','(856) 673-6246','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 13:51:16',0,NULL,3,1,1,1,'\\  ',NULL),(19695,665699289013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','floneo','floneo@gmx.net','Florian Kleiner','Kirchstr. 22','Wernersberg','','GERMANY','76857','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 15:02:40',0,NULL,3,1,2,1,'\\  ',NULL),(19696,911332998012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',2,'CASS002',19.98,'eastar4','carohenr-03','henrymuellers@aol.com','Carola  Müller','Klingerstraße 1','Dresden','','GERMANY','01139','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 15:25:29',0,NULL,3,1,2,1,'\\ ','CAB-SS-2660 '),(19697,665715564013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','yukon347','jason.marien@yahoo.ca','Jason Marien','347 Armstrong Way','Saskatoon','SK','CANADA','S7N 3N1','(306) 249-0108','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 16:00:44',0,NULL,3,1,3,1,'RA184535040CN\r ','GLOT001*2 '),(19698,910974291012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','David E. Hintz','1150 K St NW<br>Apt 209','Washington','DC','UNITED STATES','20005-6801','(503) 309-6418','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(19699,665737121013,230717844304,'New Super Light Bubble Pattern Windproof Rain/Sun Umbrella w/24 Skeleton',1,'UM00049',24.99,'eastar4','minadaya2012','minadaya@gmail.com','Sue Graves','1765 Saddler Dr','Bedford','IN','UNITED STATES','47421-3444','(773) 544-2126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 17:21:23',0,NULL,3,1,21,1,'RA184535115CN\r ','UM00049\r24骨轻量长柄雨伞 泡泡款     3色 '),(19700,663766319013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','teacher200708','jan.seaman@duluth.k12.mn.us','Jan Seaman','4601 W 6th St','Duluth','MN','UNITED STATES','55807-2014','(218) 340-3861','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 17:43:16',0,NULL,3,1,1,1,'\\  ',NULL),(19701,911397132012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','ganzmavag1','tataidaniel@gmail.com','Daniel Tatai','Dees utca 7.','Budapest','Pest','HUNGARY','1147','0036702623548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 17:47:25',0,NULL,3,1,23,1,'BP04081201060001 ','SCLO004 '),(19702,822661349011,320394908928,'Acer Aspire 7730 7730G 7730Z Bluetooth Module 2.0+cable',1,'BTAC2011',9.88,'eastar4','christhesailerman','christoph_brems@hotmail.com','christoph brems','Kapelleveldstraat 4','Boechout','','BELGIUM','2530','0499170963','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 17:52:13',0,NULL,3,1,22,1,'BJ01670047\r ','BTAC2011 \racer 5pin1.25 4cm'),(19703,822672902011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','gremsoux','rossiphilippe@neuf.fr','Rossi philippe','quartier Bompart<br>Rue des bleuets','Plan de cuques','Provence-Alpes-Côte d\'Azur','FRANCE','13380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 18:18:19',0,NULL,3,1,11,1,'BJ01670052\r ','OTCN002 '),(19704,822564538011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','andreypopov','andrey.popov@computersystemsltd.com','Andrey E. Popov','50/8 Komsomolskaya st.','Dniepropetrovsk','','UKRAINE','49070','+380 562 343333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 18:23:02',0,NULL,3,1,22,1,'BJ01670049\r ','WLIN015 '),(19705,911419536012,220913328002,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',7.99,'eastar4uk','beltel007','beltel@yahoo.co.uk','Terry Lines','22 Ville Road<br>Ashby','Scunthorpe','Lincolnshire','UNITED KINGDOM','DN16 2NW','07931804342','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-05 18:29:45',0,NULL,3,1,3,1,'RA184535138CN\r ','MOHP002 '),(19706,612011620004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','3338dennis','heinrichholz@live.de','Dennis Heinrich','Hirsenstraße 13','Hohenstein OT Holzhausen über Aar','','GERMANY','65329','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 19:28:22',0,NULL,3,1,21,1,'RA184535169CN\r ','BALO007 '),(19707,911462394012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','427gearjammer','kmcc141@hotmail.com','Kevin McCarthy','#49 Rutherford Drive','Red Deer','AB','CANADA','T4P 3H3','(403) 358-3176','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 19:45:31',0,NULL,3,1,3,1,'RA184535022CN\r ','GLOT001*2 '),(19708,822774803011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','fc.asset','fc2206@pacbell.net','Marshall Fleitman','2206 32nd Ave','San Francisco','CA','UNITED STATES','94116-1625','(408) 823-9955','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 21:37:09',0,NULL,3,1,1,1,'\\  ',NULL),(19709,911528336012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Cort Beckman','38 Bonanza Rd','Farmington','UT','UNITED STATES','84025-5013','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 21:47:00',0,NULL,3,1,1,1,'\\  ',NULL),(19710,911530062012,220915185398,'New 3-section Auto on/off Cute penguin Sun/Rain Umbrella w/Enlarged Surface',1,'UM00046',13.95,'eastar4uk','fluffy-buddha','glazedtongue@hotmail.com','Mrs A Young','skinner street school<br>skinner street','gillingham','Kent','UNITED KINGDOM','ME7 1LG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-05 21:49:28',0,NULL,3,1,3,1,'RA184535141CN\r ','UM00046 '),(19711,665840668013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','dolphin-coder','jay@corra.com.au','Jamadji Rafferty','158 Bower Rd','Semaphore Park','South Australia','AUSTRALIA','5019','0884640161','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 21:59:30',0,NULL,3,1,11,1,'BJ01670050\r ','CACN004 '),(19712,822804037011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','baxter2417','dgusola@shaw.ca','Dino Gusola','18244 57a ave','Surrey','BC','CANADA','v3s6g3','(604) 575-2417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 22:45:38',0,NULL,3,1,11,1,'BJ01670044\r ','RCLO007+POLO001+RCLO008*4 '),(19713,822803751011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','simone130987','simonekhanna88@hotmail.com','simone parmar','12 beech avenue<br>groby','leicester','Leicestershire','UNITED KINGDOM','le6 0ej','07849796070','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-05 22:46:36',0,NULL,3,1,3,1,'RA184535155CN\r ','LGAD001 '),(19714,768725171007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',2,'CC00002',71.98,'au-buy','123rahimov','anna.rahimov@yahoo.com','Anar Azizov','Hasan Salmani 5A men.38.  TEL;0124904800<br>25 sayli poct sobesi TELEB OLUNANA QEDER','Baku','Azerbaijan','AZERBAIJAN','Az1025','+994124904800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-05 22:55:27',0,NULL,3,1,21,1,'RA184535084CN\r ','CC00002 '),(19715,768735131007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','tahitibob987','avatea@hotmail.fr','georget lionel','5 rue lafontaine','villeurbanne','Rhône-Alpes','FRANCE','69100','0620376818','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-05 23:22:21',0,NULL,3,1,11,1,'BJ01670046\r ','RCLO007 '),(19716,911572964012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','glaucemaria','glauce.gama@hotmail.com','Glauce Maria Santos Gama','Av. Guilherme Morisson Nº 295, Caxias de Tocos','Campos dos Goytacazes','Rio de Janeiro','BRAZIL','28148000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 23:28:11',0,NULL,3,1,3,1,'RA184535019CN\r ','LGGL005 \r一共买了两幅'),(19717,911573914012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','glaucemaria','glauce.gama@hotmail.com','Glauce Maria Santos Gama','Av. Guilherme Morisson Nº 295, Caxias de Tocos','Campos dos Goytacazes','Rio de Janeiro','BRAZIL','28148000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 23:30:23',0,NULL,3,1,17,0,NULL,NULL),(19718,665864250013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sabakinaz','dariawaz@gmail.com','Darius Saulinskas','Mokyklos 5-1','Vilnius','','LITHUANIA','LT-08413','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 23:21:34',0,NULL,3,1,23,1,'BP04081201060004 ','CACN004 '),(19719,822833364011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','t0n1t','tony.trost@gmail.com','Anthony Trost','Level 4  44 Martin Place<br>(Anthony Trost IT )','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 00:04:47',0,NULL,3,1,2,1,'\\ ',NULL),(19720,911587326012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','krisbids','krz.petr@interia.eu','Krzysztof Petrynko','90 Fieldstone Dr<br>Apt 1211','Wisconsin Dells','WI','UNITED STATES','53965-9685','(608) 448-9457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 00:04:51',0,NULL,3,1,1,1,'\\  ','AUI Transceiver  MX20T '),(19721,665872431013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','rj83758','randalldonnajean@bellsouth.net','Randall Jean','625 Center St','Lewisburg','TN','UNITED STATES','37091-3490','(931) 270-5155','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 00:06:49',0,NULL,3,1,1,1,'\\  ',NULL),(19722,911600571012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','gedgr','gedgr@email.com','GEORGIOS DEDEOGLOU','DIMITRIOU DIGKA 18','THESSALONIKI','','GREECE','54249','+302310953953','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 00:44:07',0,NULL,3,1,21,1,'RA184535209CN\r ','GLOT001 '),(19723,908900252012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','jpilling64','jlpill@yahoo.com','John Pilling','13 Kurrajong Place','Greenwood','Western Australia','AUSTRALIA','6024','0894475162','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 01:21:09',0,NULL,3,1,3,1,'RA184535230CN\r ','SPGL001 '),(19724,911632917012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','aus140','mathew.blair.robertson@gmail.com','Mathew Robertson','PO Box 294','Chelsea','Victoria','AUSTRALIA','3196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 02:22:55',0,NULL,3,1,3,1,'RA184535053CN\r ','GLOT001 '),(19725,822885444011,320737991989,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',132.99,'eastar4','steve15647','sjmeyers@hotmail.com','Stephen Meyers','1 Arrol St','Carine','Western Australia','AUSTRALIA','6020','0893458646','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 02:55:37',0,NULL,3,1,3,1,'RA184535036CN\r ','GLOT001*3 '),(19726,821913049002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','clarkandrewm72imz','andrewm72imz@yahoo.co.uk','Andrew Clark','114A The Lane','Maryville','New South Wales','AUSTRALIA','2293','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 02:25:31',0,NULL,3,1,4,1,'YW867738853CN ',NULL),(19727,612135541004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','eagle_223','dickspellman@verizon.net','Richard Spellman','5770 S Boatman Rd','Underwood','IN','UNITED STATES','47177','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-06 03:12:45',0,NULL,3,1,1,1,'\\  ',NULL),(19728,911662768012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Jack Leach','125 Prospect Ave','Hamburg','NY','UNITED STATES','14075-4815','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 04:00:07',0,NULL,3,1,1,1,'\\  ',NULL),(19729,8881325824027383,111,'210TS',2,'TRTS001',39.98,'eastar4','wimhudepohl','wimhudepohl@hccnet.nl','wim Hudepohl','De Marke van Leusen 32','NIEUWLEUSEN','','NETHERLANDS','7711HH','0529480880',NULL,NULL,NULL,'2012-01-06 04:27:07',0,NULL,3,1,4,1,'YW867738864CN ','AUI Transceiver  210TS\r多打20美金   发快递'),(19730,822916933011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','bhfurn','dkny0@aol.com','David Kopstein','200 E 15th St<br>Apt 8m','New York','NY','UNITED STATES','10003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 05:10:05',0,NULL,3,1,1,1,'\\  ',NULL),(19731,760859330008,180762085472,'New Lady Wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',19.99,'au-buy','haworth8648','pugnutty@gmail.com','David Haworth','267 Box Rd, Sylvania NSW 2224','Sydney','New South Wales','AUSTRALIA','2224','0295228158','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 05:22:07',0,NULL,3,1,11,1,'BJ01670032\r ',' UM00022'),(19732,665960928013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','stigoe','stig@oestvang.no','Stig Østvang','Storløkkaveien 21A','Hønefoss','Buskerud','NORWAY','3515','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 07:43:21',0,NULL,3,1,21,1,'RA184535172CN\r ','GPS0006 '),(19733,612178696004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',28.88,'cnfaner','bumhee34kr','bumhee34@kaist.ac.kr','Bumhee Cho','Room 2417, Dept. of Nucl & Quantum Eng., KAIST, 335 Gwahak-ro, Yuseong-gu','Daejeon','_UAES_NULL_','KOREA,REPUBLIC OF','305-701',' 821033219541','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 08:30:07',0,NULL,3,1,3,1,'RA184535186CN\r','WWSI002 '),(19734,8881325844776322,111,'New Philips Sonicare toothbrush Handle HX6930+charger',1,'HBPH002+HBPH003',86.99,'eastar4','dman12','dman12_hrsb5195tcfa@members.ebay.com','Guy Davidovich','Harav Norok 10/26','Ashkelon','','ISRAEL','78355','',NULL,NULL,NULL,'2012-01-06 10:12:56',0,NULL,3,1,3,1,'RA184558085CN\r ','HBPH002+HBPH003\r客户打了7美金作为运费\r\r'),(19735,606889672003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','2002wingin_it','rusaner@hotmail.com','Debbie H Soehner','242A Woodhaven Road','Kitchener','ON','CANADA','N2C 1V5','(519) 893-6224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:17:16',0,NULL,3,1,3,1,'RA184558200CN\r ','LGAD001 '),(19736,911741739012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','topps31380','seb.toppan@gmail.com','Sebastien TOPPAN','Lieu dit Labrante','Montastruc','Midi-Pyrénées','FRANCE','31380','06.18.82.31.84','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 10:31:44',0,NULL,3,0,3,1,'RA184558451CN\r ','GLOT001 '),(19737,911285343012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','d4rko','trolles@gmail.com','Andres Fernandez','Paseo da Amaia 18<br>Vidan','Santiago de Compostela','A Coruña','SPAIN','15897','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:39:28',0,NULL,3,1,22,1,'BJ01670013\r ','MOMI002 '),(19738,819798562011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',4,'OTSO004',171.96,'eastar4uk','lkreth','liz@ellengowan.com','ELIZABETH FERGIE','Ellengowan House, almondbank','Perth','Perthshire and Kinross','UNITED KINGDOM','PH13NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 11:04:14',0,NULL,3,1,6,1,'EE651292009CN ','OTSO004 '),(19739,822992419011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','golfandhunt','anthony.moon@med.ge.com','Tony Moon','8646 Nash Ct','Saranac','MI','UNITED STATES','48881-8629','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 11:30:12',0,NULL,3,1,1,1,'LK176705095CN ',NULL),(19740,665998609013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',5,'WLIN014',94.95,'eastar4','pupulusfictor','alexander_belyaev@alexander-belyaev.com','ALEXANDER BELYAEV','Lesnaya st. 10/62','Dzerzhinsky','RU','RUSSIAN FEDERATION','140093 ','(916)3492606','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 11:39:32',0,NULL,3,1,3,1,'RA184558108CN\r ','WLIN014 '),(19741,822997542011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','freelandergs','ian.m.hill@ntlworld.com','Ian   Hill','1 Thistlebank','Loughborough','Leicestershire','UNITED KINGDOM','LE126RS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 11:48:29',0,NULL,3,1,11,1,'BJ01670003\r ','OTCN002 '),(19742,822999940011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','jesdw2','jacksondimigliowood@me.com','Jackson Dimiglio-Wood','122 Crofton Road','London','London','UNITED KINGDOM','SE5 8NA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 11:58:28',0,NULL,3,1,3,1,'RA184548255CN\r ',NULL),(19743,606914824003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','jml_typhoon','jml_72@live.se','Jesper Lagergren','nockebyvägen 41','Bromma','none','SWEDEN','16771','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 12:31:53',0,NULL,3,1,21,1,'RA184558329CN\r ','BALO007 '),(19744,666016207013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','scorpio_mario','marios_everything.else_inbox@live.com','Mario De Matos','14 - 2075 Asta Drive','Mississauga','ON','CANADA','L5A 2T5','(905) 281-2288','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 13:07:20',0,NULL,3,1,11,1,'BJ01670016\r ','HSSA002 '),(19745,823027415011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',2,'GPS0010',39.98,'eastar4uk','wizardone2000','gtaylory2k@hotmail.com','Greg Taylor','431 Ditchling Road','Brighton','East Sussex','UNITED KINGDOM','BN1 6XB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 13:37:34',0,NULL,3,1,3,1,'RA184558505CN\r ','GPS0010 '),(19746,911808108012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','jon64344','herblifee@btinternet.com','john michie','11 Prospect Avenue<br>Cambuslang','Glasgow','South Lanarkshire','UNITED KINGDOM','G728BW','01416411887','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 13:56:38',0,NULL,3,1,2,1,'30111592464\r ',NULL),(19747,911813342012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','20ret04','crawfordsharp@sympatico.ca','Crawford Sharp','190 Barrow Crescent','Ottawa','ON','CANADA','K2L 2C7','(613) 592-4171','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 14:13:15',0,NULL,3,1,3,1,'RA184558099CN\r ','HBPH007 '),(19748,823072172011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','stealth*bomber','hookman1981@hotmail.com','Paul Hooker','Proctor And Gamble<br>The Heights, Brooklands','Weybridge','Surrey','UNITED KINGDOM','KT13 0XP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 15:36:26',0,NULL,3,1,3,1,'RA184558045CN\r ','LGAD001 '),(19749,822971007011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','headtechscout2011','headtechscout@gmail.com','george graham','unit 4<br>newbridge road','newbridge','Midlothian','UNITED KINGDOM','eh28 8yq','07771973283','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 16:09:19',0,NULL,3,1,3,1,'RA184558010CN\r ','GPS0007 '),(19750,823093883011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',17.99,'eastar4uk','5589jeffrey','jeffreydebono69@gmail.com','Jeffrey Debono','Epix House. Maestro Giuseppe camilleri<br>street.','B\'Kara','','MALTA','BKR 4212','21445772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 16:42:32',0,NULL,3,1,22,1,'BJ01670037\r ','TRSN001 '),(19751,911882422012,220816384329,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',26.99,'eastar4uk','jachym64','kumhala@quick.cz','Josef Kumhala','M. Pujmanové 1123/26','Havířov-Šumbark','výchozí','CZECH REPUBLIC','736 01','(420) 606090821 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 16:54:56',0,NULL,3,1,3,1,'RA184558448CN\r ','GLOT001 '),(19752,911799979012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','ylexx2006','marcos.e.maciel@gmail.com','Marcos Maciel','Travessa Pinheiro Machado, 100. Apto 603','Pato Branco','Parana','BRAZIL','85505-060','4630252098','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 17:00:17',0,NULL,3,1,11,1,'BJ01670014\r ','LGGL005 '),(19753,606980876003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','geoffrydeous','onlythelonely@sky.com','Geoff Strutt','Green lane Farm Kennels<br>Green lane','Chessington','Surrey','UNITED KINGDOM','KT92DS','02083911251','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 17:01:33',0,NULL,3,1,3,1,'RA184558125CN\r ',' '),(19754,769022613007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','happyman1108','koroivos1108@yahoo.gr','KOSMAS KOSMAS','KONSTANTINOUPOLEOS 105','ATHENS','ATTICA','GREECE','18345','030 6947702467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 17:23:17',0,NULL,3,1,22,1,'BJ01669980\r ','UM00001 '),(19755,911897311012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','jackabuto','jackabuto.1@gmail.com','John Curtis','15 Baya Rd','Santa Fe','NM','UNITED STATES','87508-8321','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 17:25:07',0,NULL,3,1,1,1,'LK178076693CN\r ',NULL),(19756,607012843003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','bennygurendal','bennyg@flaskehals.net','Benny Gurendal','YTERHEIA 13','MO I','RANA','NORWAY','8614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 18:42:08',0,NULL,3,1,21,1,'RA184558315CN\r ','MOOE003\rOEM '),(19757,911938551012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4uk','kitten2077','becca_pritchard@hotmail.com','Rebecca Pritchard','The Mecca, 72 Market Hall<br>Tenants Street','Derby','Derbyshire','UNITED KINGDOM','DE1 2DB','07933989973','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 18:46:50',0,NULL,3,1,3,1,'RA184548247CN\r ','UM00031\r红色的 \r退回来了  等客户问起时再说吧3.2'),(19758,823165900011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','beefy.bunny','colinem@hotmail.com','Colin George','Enterprise Motors<br>Dean Street','Bedford','Bedfordshire','UNITED KINGDOM','MK40 3EQ','01234302230','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 19:03:10',0,NULL,3,1,3,1,'RA184558540CN\r ','MOAP001 '),(19759,612331087004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','trysharu','tryshupton@yahoo.com','Trysha Upton','5122 Marlin Ct','Waldorf','MD','UNITED STATES','20603','(301) 638-0619','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-06 19:17:47',0,NULL,3,1,1,1,'LK173377966CN\r ',NULL),(19760,911961835012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','herbal47','patti_potvin@hc-sc.gc.ca','Patricia Potvin','P.O. Box 301<br>5636 Marlene Crescent','Osgoode','ON','CANADA','K0A 2W0','(613) 957-1486','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 19:27:47',0,NULL,3,1,11,1,'BJ01670019\r ','LGGL005 '),(19761,822807873011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','travelamysdad','stecoop@earthlink.net','stephen cooper','6688 Foxtree Ave','woodridge','IL','UNITED STATES','60517-1729','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 19:45:12',0,NULL,3,1,1,1,'LK177001985CN ',NULL),(19762,761119550008,180757094477,'Original New Replaceable Shell for logitech Performance MX Mouse M950',1,'SHLO002',17.99,'au-buy','cuong5858','synical2106@gmail.com','Quoc Tang','15/29 Hayburn Ave','Rockdale','New South Wales','AUSTRALIA','2216','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 19:50:52',0,NULL,3,1,11,1,'BJ01670007\r ','SHLO002 '),(19763,911978625012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',12.49,'eastar4uk','crazybumblebee','crazybumblebee@gmx.net','Michael Betz','Erfurter Str. 10','Coburg','','GERMANY','96450','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 20:01:39',0,NULL,3,1,22,1,'BJ01670038\r ','OTHP003 '),(19764,911986095012,220893596881,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',159.99,'eastar4','tomlavecchia','toml@eclipse-sw.com','Bob Meyer','101 Hay Bale Trl','Ormond Beach','FL','UNITED STATES','32174-8212','(386) 673-2061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 20:21:41',0,NULL,5,1,4,1,'YW867738993CN\r ','已发货 但点不了 已发货,所以订单取消'),(19765,823210968011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','k44veh','gazerouni@yahoo.co.uk','fatemeh GAZEROUNI-N-REZAEE','23 LYNMOUTH CRESCENT<br>FURZTON','MILTON KEYNES','Buckinghamshire','UNITED KINGDOM','MK4 1HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 20:34:42',0,NULL,3,1,3,1,'RA184558417CN\r ','GLOT001 '),(19766,607053044003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.89,'cnfaner','konteokon1','konteokon@yahoo.gr','Theothoros konstantinou','P.Mela 14-16 Evosmos','Thessaloniki','THESSALONIKI','GREECE','56224','00306972661082','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 20:40:10',0,NULL,3,1,21,1,'RA184558346CN\r ','HSNO004\r欧标 '),(19767,607066422003,130592182172,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'cnfaner','dale2306','dale.ebay@gotgeek.ca','Dale Conn','RR4','Prince Albert','SK','CANADA','S6V 5R2','(306) 929-4742','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 21:22:28',0,NULL,3,1,3,1,'RA184558142CN\r ','OTHP003 '),(19768,823225113011,320730088816,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',159.99,'eastar4uk','hhufthammer','harald@hufthammer.no','Harald Hufthammer','Molltveitleitet 33','Kolltveit','Hordaland','NORWAY','5360','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 21:05:22',0,NULL,5,1,4,1,'YW867739004CN\r ','已发货但点不了  '),(19769,607074071003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','nukem4','andy_helen@verizon.net','Andrew Handley','23048 Sky Mesa Rd','Homeland','CA','UNITED STATES','92548-9486','(951) 225-5145','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-06 21:48:06',0,NULL,3,1,1,1,'LK177606770CN ',NULL),(19770,666179781013,230720746376,'Apple PowerBook G4 AirPort Extreme WiFi Card A1026',29,'WLAP002',579.42,'eastar4','camille92150','camille92@noos.fr','Gauthier Eric','10 avenue Alexandre Maistrasse','suresnes','Ile-de-France','FRANCE','92150','01 73 64 23 33','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 21:56:13',0,NULL,5,1,4,1,'YW867739015CN\r ','已发货但点不了 '),(19771,666195002013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','savcarter1','sharon_vomhof@yahoo.com','Sharon Vomhof','3716 43rd Ave N','Robbinsdale','MN','UNITED STATES','55422-1536','(651) 969-2293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 22:50:45',0,NULL,3,1,1,1,'LK173699250CN ',NULL),(19772,823263232011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','megamoog','lawrence.prinner@sbcglobal.net','Lawrence Prinner','46W980 Allen Rd','Hampshire','IL','UNITED STATES','60140-9701','(847) 683-2574','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 22:42:31',0,NULL,3,1,1,1,'LK157618354CN ',NULL),(19773,768902180007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.99,'au-buy','cute_thingss','n_ig@ukr.net','Natalia Ignatovskaya','Pervomaiskaya st.20 ap.18','Simferopol','Crimea','UKRAINE','95007','634019 (0652)','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 23:10:01',0,NULL,3,1,22,1,'BJ01669981\r ','UM00053 '),(19774,912093438012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',9.39,'eastar4uk','wneranjan','w_neranjan@hotmail.com','Neranjan Wickramasinghe','2 Black Road Close','Hayes','Middlesex','UNITED KINGDOM','UB3 4QJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 00:27:17',0,NULL,3,1,3,1,'RA184558482CN\r ','HSNO022 '),(19775,761231039008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','mavic00','mavic00@hotmail.com','Alexis Desjardins','6760 rue des Bouleaux','st-hyacinthe','QC','CANADA','J2R 1C4','(450) 253-9629','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','2012-01-07 00:55:05',0,NULL,5,0,18,0,NULL,NULL),(19776,666226913013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','paulh_26','paulh_26@bigpond.net.au','Paul Hunt','18 Bangaroo Street<br>North Balgowlah','Sydney','New South Wales','AUSTRALIA','2093','0403014490','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 01:19:34',0,NULL,3,1,3,1,'RA184558037CN\r ','GLOT001*4 '),(19777,823312470011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','barryradio','bzsimages@comcast.net','Barry L. Zimmerman','5825 Woodwinds Cir','Frederick','MD','UNITED STATES','21703-7579','(301) 676-6863','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 01:20:03',0,NULL,3,1,1,1,'LK177476902CN\r ',NULL),(19778,823304728011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','jideola','jidesomi@yahoo.com','Jacob  Adesomi','518 shadowmoore dr','riverdale','GA','UNITED STATES','30274','(404) 399-4214','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 01:32:46',0,NULL,3,1,1,1,'LK175678252CN ',NULL),(19779,666238013013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','janosch400','ebay@jansiebke.eu','Jan Siebke','Hittfelder Strasse 18','Rosengarten','','GERMANY','21224','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 02:21:22',0,NULL,3,1,2,1,'30111594505\r ','华硕 8pin 1.0 6cm  '),(19780,823337616011,320820766166,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',15.99,'eastar4uk','hermeticglyph','colin.mowat.gosnell@gmail.com','Colin Mowat-Gosnell','8 Park Crescent','Twickenham','Middlesex','UNITED KINGDOM','TW2 6NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 03:04:17',0,NULL,3,1,3,1,'RA184548162CN\r ','HSAL001 '),(19781,666253685013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','sqeak','anstene@optusnet.com.au','R & D Carroll','P O Box 7070','Upper Ferntree Gully','Victoria','AUSTRALIA','3156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 03:47:55',0,NULL,3,1,3,1,'RA184558023CN\r ','GLOT001*4 '),(19782,666256539013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','nieltete','maria.callejas@exel.com','MARIA CALLEJAS','155 Highpoint Dr<br>Apt 103','ROMEOVILLE','IL','UNITED STATES','60446-3828','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 04:06:33',0,NULL,3,1,1,1,'LK177965392CN ',NULL),(19783,823352465011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','integrityelectric7','dave@integrityelectric.us','David Fernandes','3381 Gold Country Dr','El Dorado','CA','UNITED STATES','95623-4516','(123) 456-7890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 04:09:31',0,NULL,5,1,18,1,' ','由于缺货  已给客户退款了 '),(19784,612455726004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','eerhard','bbboelens@yahoo.com','Boelens B.B.','Neptunus 64','Hoogezand','','NETHERLANDS','9602 LM','+31598380592','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 04:13:04',0,NULL,3,1,21,1,'RA184558332CN\r ','BALO007 '),(19785,912154759012,220872377067,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',69.99,'eastar4uk','savcarter1','sharon_vomhof@yahoo.com','Sharon Vomhof','3716 43rd Ave N','Robbinsdale','MN','UNITED STATES','55422-1536','(651) 969-2293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 04:25:45',0,NULL,3,1,1,1,'LK177351434CN ','GPS0004 '),(19786,607151394003,130617205129,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',262.99,'cnfaner','kguy212','kguy@live.com.au','Kelvin Guy','38 Springhill Drive','Cranbourne','Victoria','AUSTRALIA','3977','0359914555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 04:17:35',0,NULL,5,1,4,1,'YW867739026CN\r ','GLSG009*3 \r已发货 但点不了 已发货,所以订单取消'),(19787,912175546012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','ve 54630 vladimir brito','8536 NW 66th St','Miami','FL','UNITED STATES','33166-2635','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 06:02:56',0,NULL,3,1,1,1,'LK177116144CN ',NULL),(19788,912176050012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Devon Chung','13715 Frankton St','Rosedale','NY','UNITED STATES','11422-3335','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 06:05:29',0,NULL,3,1,1,1,'LK177726358CN ',NULL),(19789,666280788013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','bingxlu','sunnylu215@yahoo.com','sunny','18766 E Mauna Loa Ave','azusa','CA','UNITED STATES','91702-4074','(415) 335-2687','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 07:14:43',0,NULL,3,1,1,1,'LK177165998CN ',NULL),(19790,823383704011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','fifthwheel44','cheriegutekunst@wmconnect.com','Cherie Lynn Gutekunst','11501 S Old Nogales Hwy','Tucson','AZ','UNITED STATES','85756','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 07:20:07',0,NULL,3,1,1,1,'LK173886323CN\r ',NULL),(19791,666286843013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','emilymayftw','emilymay_x@hotmail.com','Emily Frongin','13 Raphael St Lidcombe','Sydney','New South Wales','AUSTRALIA','2141','0296438549','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 08:06:07',0,NULL,3,1,11,1,'BJ01669979\r ','UM00042 \r接边蕾丝透明伞  '),(19792,612485067004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','tchieu1961','jonnguyencu@gmail.com','Jonathan Nguyen','4851 Robin Hill Dr','Omaha','NE','UNITED STATES','68106','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-07 08:29:11',0,NULL,3,1,1,1,'LK175842475CN ',' '),(19793,823407189011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','cperricos','katherine_perricos@hotmail.com','Costi Perricos','18 Trebor Avenue','Farnham','Surrey','UNITED KINGDOM','GU9 8JH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 09:24:27',0,NULL,3,1,3,1,'RA184558434CN\r ','GLOT001 '),(19794,912040049012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','igor.smagin','smagin.iv@gmail.com','Igor Smagin','42 Gagareen st.<br>60 ap.','Simferopol','Crimea','UKRAINE','95043','+380990504033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 09:28:32',0,NULL,3,1,22,1,'BJ01670010\r ','LGGL005 '),(19795,607198617003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','sebastianolaussen','zebbaztian@hotmail.com','Sebastian Olussen','KIRKEVEIEN 104B','OSLO','OSLO','NORWAY','0361','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 10:30:30',0,NULL,3,1,21,1,'RA184558275CN\r ','MOLO006 '),(19796,607200038003,130617205284,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',98.99,'cnfaner','posidwnas','posidwnas@gmail.com','Athanasios Vavouras','Kountouriotou 25<br>Triandria','Thessaloniki','','GREECE','55337','6974310825','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 10:30:59',0,NULL,3,1,21,1,'RA184558350CN\r ','SAFI001*2 '),(19797,823426610011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.39,'eastar4','s_wtnb','wtnb@mac.com','Shinichi WATANABE','1-7-21-301, Shin-Yoshida-Higashi<br>Kouhoku-ku','Yokohama-city','Kanagawa','JAPAN','223-0058','090-6498-6729','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 10:41:32',0,NULL,3,1,2,1,'30111598801\r ',NULL),(19798,607202590003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','danoveolsen1965','post@nettkompis.no','Dan Ove Olsen','Postboks 5','Grua','NORWAY','NORWAY','2717','92065988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 10:42:41',0,NULL,3,1,21,1,'RA184558292CN\r ','GPS0006 '),(19799,823431227011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',19.98,'eastar4','tuan_ny24','tuan_ny@yahoo.com','Huong Trang Vu','70/313 Harris St','Pyrmont, Sydney','New South Wales','AUSTRALIA','2009','61425566063','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 11:00:34',0,NULL,3,1,11,1,'RA184558624CN\r ','CASS002 '),(19800,607209811003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',1,'WLAT003',14.8,'cnfaner','herbert1555','martin.goette@t-online.de','Martin  Goette','Erpmannstieg 2B','Hamburg','','GERMANY','22159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 11:22:04',0,NULL,3,1,21,1,'RA184558213CN\r ','WLAT003 '),(19801,912258506012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','swampmonster99','pgroke@gmx.net','Paul Groke','Garnisonstr. 21','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 11:56:13',0,NULL,3,1,22,1,'BJ01669984\r ','RMSN002 '),(19802,912258469012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',26.99,'eastar4uk','darrenpecka','darrenjwood1970@aol.com','Darren Wood','19<br>Cotterills Road','Tipton','West Midlands','UNITED KINGDOM','DY40LA','01215578295','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 11:56:35',0,NULL,3,1,3,1,'RA184558425CN\r ','GLOT001 '),(19803,607229356003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',87.99,'cnfaner','lera1995','slavadim@gmail.com','vyacheslav dimitryuk','245 poinciana dr','sunny isles beach','FL','UNITED STATES','33160-4520','(305) 919-0344','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-07 12:58:35',0,NULL,3,1,1,1,'LK176378841CN\r ',NULL),(19804,823464095011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','jk1950-ru','jk1950@mail.ru','Yury Kolesnikov','ul. Krupskoy, dom 10, kv. 19','Balashikha','Moskovskaya obl','RUSSIAN FEDERATION','143900','(926)818-4344','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 13:21:13',0,NULL,3,1,11,1,'BJ01670004\r ','HBPH003 '),(19805,666357476013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.39,'eastar4','danielohs','d.ohanesian@uol.com.br','Daniel Ohanesian Silva','Rua Sebastiao Tirador Fernandes, 176','Osasco','Sao Paulo','BRAZIL','06216-170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 14:00:51',0,NULL,3,1,11,1,'BJ01670025\r ','BTAC2123 \racer 8pin1.00 10cm '),(19806,823494653011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','waveyduk','waveyduk@gmail.com','Mr David Hancock','1 Digby Close<br>Duston','Northampton','Northamptonshire','UNITED KINGDOM','NN5 6GU','07811264721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 14:09:11',0,NULL,3,1,3,1,'RA184558385CN\r ','LGAD001 '),(19807,912321084012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','bobounicorn','seanmodonovan@gmail.com','Sean O\'Donovan','Pinetrees<br>Elton Park, Hadleigh Road','Ipswich','Suffolk','UNITED KINGDOM','IP2 0DG','01473257327','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 14:43:28',0,NULL,3,1,3,1,'RA184558553CN\r ','WLIN014 '),(19808,666366632013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','dasampson2011','rodeoriver@yahoo.com','DARRELL SAMPSON','1955 Isleview Rd','Grand Rapids','MN','UNITED STATES','55744-9786','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 14:41:58',0,NULL,3,1,1,1,'LK175705752CN ',NULL),(19809,612564054004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','bcneal50','barry.neal@comcast.net','Barry Neal','9317 Toledo Ave S','Bloomington','MN','UNITED STATES','55437-2080','(952) 831-6953','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-07 15:00:24',0,NULL,3,1,1,1,'LK176516313CN ',NULL),(19810,612572052004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','kimplex72','kimmo.vaherio@pp.inet.fi','Kimmo Vaherio','Pähkinätie 6 C 42','Vantaa','','FINLAND','01710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 15:26:52',0,NULL,3,1,21,1,'RA184558139CN\r ','BALO007 '),(19811,823530692011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','kybele14','kybele49@gmail.com','Ufuk Yavuz','Spångavägen 28, 2tr<br>16875 Bromma','Stockholm','Bromma','SWEDEN','16875','0468388606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 15:39:06',0,NULL,3,1,22,1,'BJ01670040\r ','OTHP005 '),(19812,912356638012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','burleyj123','julia_burley@hotmail.com','Mrs J Burley','The Cairn<br>1 Leigh Court Close','Cobham','Surrey','UNITED KINGDOM','KT11 2HT','01932867492','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 16:00:38',0,NULL,3,1,3,1,'RA184558536CN\r ','SAFI001 '),(19813,666401369013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','magicalakrus','akrus@flygroup.st','Maria Kalinina','Staromar\'yinskoe shosse, 16-7','Moscow','Moscow','RUSSIAN FEDERATION','127521','+79264446353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 16:24:05',0,NULL,3,1,11,1,'BJ01669983\r ',NULL),(19814,823555659011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','ipllewellyn1','llewelllynian547@btinternet.com','ian llewellyn','160 ty gwyn drive<br>brackla','bridgend','Bridgend','UNITED KINGDOM','cf312qj','01656668737','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 16:33:11',0,NULL,3,1,3,1,'RA184558363CN\r ','GLOT001 '),(19815,912375549012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','123venona','nonaschrant@embarqmail.com','Venona Schrant','416 E Hubert St','Richmond','KS','UNITED STATES','66080','(785) 835-6514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 16:38:33',0,NULL,3,1,1,1,'LK175054098CN ',NULL),(19816,912390176012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','dazzzydarren','darrenphillips68@googlemail.com','DARREN PHILLIPS','1 LLEWELLYN STREET','MERTHYR TYDFIL','Merthyr Tydfil','UNITED KINGDOM','CF47 8SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 17:03:18',0,NULL,3,1,3,1,'RA184558479CN\r ','HSJA002\r英标 '),(19817,607304812003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','jmnapier','jimandbrittany@gmail.com','James M. Napier','5457 Oak Crest Ln','Buford','GA','UNITED STATES','30518-9029','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-07 17:26:18',0,NULL,3,1,1,1,'LK175759319CN ',NULL),(19818,612615807004,140671481128,'New Genious LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack)',1,'LGGL005',19.59,'cnfaner','a.lebedev','a.lebedev.md@gmail.com','Lebedev Andrey','Pestovskaya, 1, 16','Velikiy Novgorod','Novgorodskaya oblast`','RUSSIAN FEDERATION','173014','+7 908 2929559','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 17:43:47',0,NULL,3,1,3,1,'RA184558173CN\r ','LGGL005'),(19819,823590429011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','anvieg','lanceg@list.ru','Andrey Egorov','30 let pobedi, 148 korpus 2, kv 69','Tyumen','Tyumenskaya','RUSSIAN FEDERATION','625028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 17:43:47',0,NULL,3,1,11,1,'BJ01670041\r ','HSJA011\r欧标 '),(19820,666433703013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','xxbakerxx32','rhsdude20@aol.com','Cody Baker','717 Highway 51','Phil Campbell','AL','UNITED STATES','35581-4055','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 17:55:24',0,NULL,3,1,1,1,'LK177299924CN ',NULL),(19821,912422435012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','queen_lillie','hez.simkiss@hotmail.co.uk','Heather Simkiss','92 Rhys St.<br>Trealaw','Tonyopandy','Rhondda Cynon Taf','UNITED KINGDOM','CF40 2QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 18:03:18',0,NULL,3,1,3,1,'RA184558465CN\r ','HSJA002\r英标 '),(19822,823602438011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','krrasc','acarrascoteixido@hotmail.com','Andrés Carrasco','Molí del comte N-31, 4o, 1a','Balaguer','Cataluña','SPAIN','25600','973448763','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 18:06:23',0,NULL,3,1,21,1,'RA184558160CN\r ','GLOT001 '),(19823,612625016004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','faeky','ebay@e-xyn.com','Jeremy Hodge','23 Trailbrook Lane','Guelph','ON','CANADA','N1E 7B6','(519) 837-5749','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 18:09:01',0,NULL,3,1,3,1,'RA184558187CN\r ','WLDE002 '),(19824,769500557007,170759125969,'New LG AG-F200 Cinema 3D glasses4 2011 LG 3D LED HDTVs (2 pairs pack) Adult Size',1,'LGGL005',19.99,'au-buy','pgmemere','pgallagher9@cogeco.ca','Paulette I. Gallagher','8 Mueller Crescent','Petawawa','ON','CANADA','K8H 3E9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-07 18:19:03',0,NULL,3,1,11,1,'BJ01670023\r ','LGGL005 '),(19825,607326603003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','nobabylone','clement.dattee@wanadoo.fr','Clément Dattée','30 Ter rue de Ballainvilliers','Longjumeau','Ile-de-France','FRANCE','91160','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184558111CN\r ','RCLO007+POLO001+RCLO008*4 '),(19826,912438892012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','pollosqui','pollosqui@hotmail.com','Julio Zamora','42 Mechanic St','Absecon','NJ','UNITED STATES','08201-2028','(609) 674-8159','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 18:30:02',0,NULL,3,1,1,1,'LK176523889CN ',NULL),(19827,912461701012,220643668310,'Bluetooth 2.0 Module BCM92045NMD HP/Compaq/Acer BCM2045',1,'BTAC2000',4.99,'eastar4','hirsaeki','hirsaeki@gmail.com','Hiroshi SAEKI','2-3-B9-405<br>MIDORICHO','MUSASHINO-SI','Tokyo','JAPAN','180-0012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 19:10:49',0,NULL,3,1,2,1,'30111587516\r ',NULL),(19828,912475126012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',67.4,'eastar4uk','karimsei','lk3rim@gmail.com','Lajbara KArim','95 rue Henry Terryn','Mouvaux','Nord-Pas-de-Calais','FRANCE','59420','03.20.35.39.08','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 19:30:42',0,NULL,3,1,3,1,'RA184558522CN\r ',' GLOT005'),(19829,823657145011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','bondcars555','ehfrinton@aol.com','Emmett Harrington','105<br>witton wood','frinton on sea','Essex','UNITED KINGDOM','co139ld','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 19:50:48',0,NULL,3,1,3,1,'RA184558394CN\r ','LGAD001'),(19830,823677631011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','matthewmufc2006','matthewmufc@hotmail.com','Abdulkadir Mahmud','108 Littleton Road<br>Lower Kersal','Salford','Lancashire','UNITED KINGDOM','M7 3TW','01617089959','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 20:31:49',0,NULL,3,1,3,1,'RA184558377CN\r ','LGAD001'),(19831,823685729011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','rafaelasius','asius@hotmail.com','rafael pomar asius','ctrestaix Nº 12 1º piso','sa pobla','Baleares','SPAIN','07420','638304116','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 20:49:37',0,NULL,3,1,21,1,'RA184558068CN\r ','LGAD001 '),(19832,769596893007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','abdnur2009','dna062010@hotmail.com','Dewi Nur Alifia','3/8-12 Station Street<br>Arncliffe','Sydney','New South Wales','AUSTRALIA','2205','0295923295','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 21:36:07',0,NULL,3,1,11,1,'BJ01670070\r ','UM00001\r蓝色的 '),(19833,769600200007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',2,'HSUE003',42.7,'au-buy','neleh321','helenwoodward@optushome.com.au','Helen Woodward','12 Derby Parade','Caulfield North','Victoria','AUSTRALIA','3161','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 21:41:05',0,NULL,3,1,3,1,'RA184558156CN\r ','HSUE003 '),(19834,912553774012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','fullthrottlepaul','paul.d.magowan@btinternet.com','Paul Magowan','100 Princetown Road','Bangor','Down','UNITED KINGDOM','BT203TG','02891271054','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 22:06:21',0,NULL,3,1,3,1,'RA184558519CN\r ','HSPH002 '),(19835,912580453012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','a1234coco','a1234coco@aol.com','Angel Padilla','808 Lynn Ave','Bethlehem','PA','UNITED STATES','18015-2256','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 23:09:09',0,NULL,3,1,1,1,'LK174892444CN ',NULL),(19836,823753259011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','captainblueowl','mikelumley@sky.com','Mike Lumley','9 Lindup Road<br>Dronfield Woodhouse','Sheffield','Derbyshire','UNITED KINGDOM','S18 8NR','07740354526','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 23:30:34',0,NULL,3,1,3,1,'RA184558054CN\r ','LGAD001 '),(19837,912604902012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','kb1db','kb4db@rcn.com','Kurt  Hahn','1518 Tanyard Hill Rd','Gaithersburg','MD','UNITED STATES','20879-3255','(301) 963-8320','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 00:14:21',0,NULL,3,1,1,1,'LK178045254CN ',NULL),(19838,612739191004,140675756939,'3 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*3',131.99,'cnfaner','kaidenkieanna','donjones@shaw.ca','donald jones','3602 17th.,Ave.,','Vernon','BC','CANADA','V1T 1B8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 00:25:57',0,NULL,3,1,3,1,'RA184558227CN\r ','GLOT001*3 '),(19839,823789457011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','robdressler','roberthhdressler@hotmail.com','Rob Dressler','A0207 325 3rd ST SE','Calgary','AB','CANADA','T2G0T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 01:29:04',0,NULL,3,1,3,1,'RA184558615CN\r ','HBPH002 '),(19840,912643833012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','zilvur','zilvur@hotmail.com','Leslie Ty','88 East Pender Street<br>Unit 428','Vancouver','BC','CANADA','V6A 1S9','(604) 631-3053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 02:22:29',0,NULL,3,1,11,1,'BJ01670071\r ','UM00010 \r钢琴美女伞 '),(19841,666607594013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','natoe1','n.albrighton@gmail.com','nathan Albrighton','PO Box 7094','Greenway','Australian Capital Territory','AUSTRALIA','2900','0439366437','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 04:15:03',0,NULL,3,1,11,1,'BJ01670036\r ','CACN004 '),(19842,823832578011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',6,'GLOT001',269.34,'eastar4','jolljoan','mitosrule@hotmail.com','jo jolley','2979 Mesquite Dr','Idaho Falls','ID','UNITED STATES','83404','(208) 339-1768','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 04:22:50',0,NULL,5,1,7,1,'EE651291992CN\r ','已发货 但点不了 已发货,所以订单取消'),(19843,823840295011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','blazinshadow','cjpearce87@live.com','Caleb Pearce','15/35 Central Coast Hwy','West Gosford','New South Wales','AUSTRALIA','2250','0243511942','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 05:01:52',0,NULL,3,1,2,1,'30111596454\r ',NULL),(19844,912718339012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',19.98,'eastar4','alex_strozzi','alexstrozzi@gmail.com','Alexey potapov','11/15Holurood St.<br>Hampton','Melbourne','Victoria','AUSTRALIA','3188','0431926854','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 08:35:47',0,NULL,3,1,11,1,'BJ01670008\r ','CASS003+TRMX003 \r再发一条CAB-6060'),(19845,666644071013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','alex_strozzi','alexstrozzi@gmail.com','Alexey potapov','11/15Holurood St.<br>Hampton','Melbourne','Victoria','AUSTRALIA','3188','0431926854','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 08:45:29',0,NULL,8,1,17,0,NULL,NULL),(19846,823894410011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',3,'HSNO019',113.94,'eastar4','sapan1602','sapan24@gmail.com','Sapan Shah','Lvl 1,141 Robertson Street<br>Fortitude Valley','Brisbane','Queensland','AUSTRALIA','4006','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-01-08 09:43:15',0,NULL,3,1,3,1,'RA184558709CN\r ','HSNO019\r澳标 '),(19847,912755711012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',8,'CASS002',0,'eastar4','crysty3002','crysty3001@gmail.com','Constantin Oprea','Iordache Golescu, nr. 10, bl. 29, ap. 22<br>sector 1','Bucharest','Bucharest','ROMANIA','011303','+04723610458','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,21,1,'RA184548176CN\r ','CASS001+CASS002\r再发三条CAB-2626 '),(19848,666667243013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','is200vtr','heijden.r@gmail.com','Ronnie v.d. Heijden','m.r. T.J. verschuurstraat 3','best','','NETHERLANDS','5684xa','06-50506278','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 10:36:24',0,NULL,3,1,23,1,'BP04081201090003 ','WLAP002 '),(19849,912770466012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','fprl92','fponetouch@gmail.com','PIERRELLE Fabrice','33 rue de Neuilly','CLICHY la GARENNE','Ile-de-France','FRANCE','92110','0650674512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 10:55:16',0,NULL,3,1,2,1,'30111599291\r ',NULL),(19850,612611980004,140676421848,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',71.99,'cnfaner','erlend_henden','erlend_henden@hotmail.com','Vegard Henden','Liabø','Vågland','','NORWAY','6683','90513039','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 11:17:22',0,NULL,3,1,21,1,'RA184548202CN\r ','HSNO035 '),(19851,666678676013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','burgman75013','kwesmidi@free.fr','Le snack de la place (nono)','48 avenue Henri barbusse','SAINT DENIS','Ile-de-France','FRANCE','93200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 11:24:21',0,NULL,3,1,11,1,'BJ01670024\r ','HSSA002\r '),(19852,912812942012,220815931372,'New Replaceable Shell 4 logitech remote control 890 pro',1,'SHLO007',18.99,'eastar4uk','mattstolton','matt@earlyriser.co.uk','Matthew Stolton','Early Riser Disco Centre<br>50-52 Beulah Road','Walthamstow','London','UNITED KINGDOM','E17 9LQ','02085203401','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 12:39:44',0,NULL,3,1,3,1,'RA184548193CN\r ','SHLO007 '),(19853,823964391011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','robertoakley75','robertoakley@bigpond.com','Rob Oakley','28 dunham wy','heathridge','Western Australia','AUSTRALIA','6027','0427122141','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 12:53:41',0,NULL,3,1,3,1,'RA184558655CN\r ','GLOT001 '),(19854,823967573011,320786773728,'New iTech Clip II mini Multipoint Bluetooth Headset blue',1,'HSIT004',21.99,'eastar4uk','colin4116','colin_4116@yahoo.co.uk','COLIN J HANDS','16 MAPLE GROVE<br>KINGSHURST','BIRMINGHAM','United Kingdom','UNITED KINGDOM','B37 6AP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 13:01:55',0,NULL,3,1,3,1,'RA184558638CN\r ','HSIT004\r英标 蓝色的 '),(19855,912830582012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','cefalwell','charles.falwell@russellvillearkansas.org','C. E. Falwell','2335 Skyline Dr','Russellville','AR','UNITED STATES','72802-8658','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 13:23:17',0,NULL,3,1,1,1,'LK177693751CN ',NULL),(19856,824011903011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','darknightz0117','bladeofthedragons0117@yahoo.com','Filmer Yu','81 Yale Street','San Francisco','CA','UNITED STATES','94134','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 14:45:11',0,NULL,3,1,1,1,'LK175735405CN\r ',NULL),(19857,607600699003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','astmon','rootboard@gmail.com','Egor Fedosenko','Petrohradska 3112','Kladno','','CZECH REPUBLIC','24207','420774427338','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 14:50:48',0,NULL,3,1,3,1,'RA184558195CN\r ','MOAP001 '),(19858,607607250003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','zfry','zak.p.fry@gmail.com','Zak Fry','2504 Westerly Ave','Charlottesville','VA','UNITED STATES','22903-2939','(717) 669-1231','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-08 15:10:02',0,NULL,3,1,1,1,'LK176795255CN ',NULL),(19859,612925135004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','mad.snowman','jan.svercl@gmail.com','Jan Svercl','Krib 1804','Ceska Trebova','','CZECH REPUBLIC','56002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 15:43:20',0,NULL,3,1,3,1,'RA184558071CN\r ','BALO007 '),(19860,912911686012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',111.96,'eastar4','vinylwall','jimi@vinylwall.com','James Humphreys','286 Hedcor St','Holland','MI','UNITED STATES','49423-9364','(616) 820-3117','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 15:57:00',0,NULL,3,1,1,1,'LK178509173CN\r ',NULL),(19861,912916367012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','sswoozooss1','sswoozooss@yahoo.com','Sean Schmit','27W023 Cooley Ave','WINFIELD','IL','UNITED STATES','60190-1392','(630) 923-9249','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-08 16:03:12',0,NULL,3,1,1,1,'LK178686567CN ',NULL),(19862,912918548012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','juhacusti','juha.custi@gmail.com','Juha/Satu Ojala','Karjaluodonpolku 3 B 3','PATTIJOKI','','FINLAND','92140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 16:08:02',0,NULL,3,1,21,1,'RA184558258CN\r ','HSNO019+CCNO001 '),(19863,912923290012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','riggins1947','mg006c5437@blueyonder.co.uk','Martyn Green','16 Grovelands Way','Grays','Essex','UNITED KINGDOM','RM175YG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 16:15:06',0,NULL,3,1,3,1,'BJ01669986\r ','OTGR001 '),(19864,912921620012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','why123bikes','e15ware@aol.com','EDWARD WARE','1909 Vanessa Leigh Dr','el paso','TX','UNITED STATES','79936-4169','(915) 241-6780','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 16:17:47',0,NULL,3,1,1,1,'LK177652584CN ',NULL),(19865,912927138012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',6.78,'eastar4uk','****tobi****','zauscher@gmx.net','Tobias Zauscher','Dietenhausenerstr.10','Odelzhausen','','GERMANY','85235','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 16:20:38',0,NULL,3,1,22,1,'BJ01670018\r ','CALO001 \r买了两个usb线\r'),(19866,912936329012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','andrey_yalymov','lemon.pg@gmail.com','Andrey Yalymov','Kabanbay Batyra, 75<br>appt. # 13','Almaty','','KAZAKHSTAN','050010','+77772100327','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 16:54:33',0,NULL,3,1,3,1,'RA184558641CN\r ','GLOT001 \r贴航空签'),(19867,824092919011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','yvelponken','erik@yvel.se','Erik Tidestrom','Gruvlyckevagen 31','Karlstad','','SWEDEN','65343','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 16:59:50',0,NULL,3,1,22,1,'BJ01670020\r ','OTHP005 '),(19868,824094643011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','dungeonmaster9','floodwood9@hotmail.com','Marc Halperin','334 E 26th St<br># 11H-1','New York','NY','UNITED STATES','10010-1915','(201) 264-7611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 17:01:25',0,NULL,3,1,1,1,'LK178220611CN ',NULL),(19869,612977789004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','ibelgica','bertrandisme@gmail.com','Pierre Bertrand','Rue closière du fhy, 15','Écaussinnes-Lalaing','','BELGIUM','7191','067555555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 17:39:04',0,NULL,3,1,21,1,'RA184558261CN\r ','WLDE002 '),(19870,666883251013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','mbreda2010','maxrbreda@uol.com.br','Max Rubens Breda','Av Eng. Carlos Reinaldo Mendes 2.235<br>Alto da Boa Vista','Sorocaba','São Paulo','BRAZIL','18013280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 19:29:15',0,NULL,3,1,3,1,'RA184558575CN\r ','GLOT001*2 '),(19871,824236767011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','gproph0','graeme.prophet@btinternet.com','Graeme Prophet','30 Shepherd\'s Loan','Dundee','Angus','UNITED KINGDOM','DD2 1AZ','01382302010','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 19:47:23',0,NULL,3,1,3,1,'RA184558584CN\r ','SAFI001*3 '),(19872,769755675007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','kuroganeichigo','hisokuj2002@gmail.com','Jon Lee','4557 Guava Ave','Seal Beach','CA','UNITED STATES','90740-2939','(562) 716-8988','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-08 19:54:42',0,NULL,3,1,1,1,'LK175218375CN ',NULL),(19873,824246443011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','stinger0070','stingray1971@hotmail.co.uk','ray newland','24 park avenue<br>eastbourne','eastbourne','East Sussex','UNITED KINGDOM','bn212xs','01273381711','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 19:59:13',0,NULL,3,1,3,1,'RA184558607CN\r ','LGAD001 '),(19874,913149601012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',63.98,'eastar4uk','louwycats','daisymay390@hotmail.com','barbara willis','390 chester road north','birmingham','West Midlands','UNITED KINGDOM','B736RH','01213552161','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 20:35:08',0,NULL,3,1,3,1,'RA184548180CN\r ','LGRM001\r还买了 Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100\rLGAD001\r'),(19875,666921389013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','d0men','domem@hotmail.com','FRANCISCO JESUS MARQUEZ GOMEZ','Lugo 11 3 10','Roquetas de Mar','Andalucía Ceuta y Melilla','SPAIN','04740','627538826','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 20:42:24',0,NULL,3,1,2,1,'30111593035\r ',NULL),(19876,666915426013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','xtremevisionbulbs','nportill@tampabay.rr.com','Miguel Portillo','804 E 128th Ave','Tampa','FL','UNITED STATES','33612-4413','(813) 866-4582','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 20:26:48',0,NULL,3,1,1,1,'LK175457809CN ',NULL),(19877,913173928012,220501842449,'2.1 Acer Extensa 5420 5420G  Bluetooth Module +cable',1,'BTAC2106',12.39,'eastar4','macysnut','mod7265@gmail.com','Logan Thompson','10615 Gilbert Rd','Newton Falls','OH','UNITED STATES','44444','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 21:05:12',0,NULL,3,1,1,1,'LK171991638CN ','acer 4pin1.25 15cm  '),(19878,824315198011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','bossebogserbat','anonymizer84@hotmail.com','Fredrik Eklund','Blåklintsgatan 26','Enköping','Uppland','SWEDEN','74536','+46736473570','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 21:37:51',0,NULL,3,0,22,1,'BJ01670011\r ','OTHP005 '),(19879,666956831013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','shellza','shell1234@hotmail.com','Michelle Cavaleri','8 Figtree Drive','Sydney Olympic Park','New South Wales','AUSTRALIA','2127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 21:55:30',0,NULL,3,1,11,1,'BJ01669976\r ','UM00042 \r接边蕾丝透明伞    '),(19880,770196302007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','pemberduke','debbie.farmery@unisys.com','Debbie Farmery','2501 / 77 Berry Street','North Sydney','New South Wales','AUSTRALIA','2060','0296477787','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 22:05:17',0,NULL,3,1,11,1,'BJ01669985\r ','OTGR001 \r'),(19881,913098793012,220785809688,'PLANTRONICS ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',47,'eastar4','the_father_of_liberty','stewarthart@mac.com','Stewart Hart','19484 Lost Creek Dr','Fort Myers','FL','UNITED STATES','33967-5507','(859) 492-2401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 22:42:58',0,NULL,3,1,1,1,' LK178178352CN',NULL),(19882,613132678004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',21.9,'cnfaner','petbre','peter@breitholtz.com','Peter Breitholtz','Narvavagen 67','VASTERAS','.','SWEDEN','SE-724 68','46-73-9193996','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 22:44:31',0,NULL,3,1,21,1,'RA184558289CN\r ','OTGR005 '),(19883,824350900011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','andrecpa','moshe007@aol.com','sassoon, andre','18425 Grand Central Pkwy','Jamaica','NY','UNITED STATES','11432-5824','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 22:48:46',0,NULL,3,1,1,1,'LK178493907CN ',NULL),(19884,607831137003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','dejiwilliams','deji66@googlemail.com','Ayodeji Ajayi','195 Arnold Estate,druid street','london','London','UNITED KINGDOM','se1 2xr','02034904285','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 23:00:29',0,NULL,3,1,3,1,'RA184558301CN\r ','LGAD001 '),(19885,666984365013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','kdr25','kkddr25@gmail.com','Kaitlyn Reilly','9621 Golden Given Rd E','Tacoma','WA','UNITED STATES','98445-3198','(253) 677-5296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 23:13:45',0,NULL,3,1,1,1,'LK173221751CN\r ','接边蕾丝透明伞        '),(19886,824375684011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','theserious','joshjoshchia@yahoo.com.au','KayWee Chia','5B Wentworth Rd','Eastwood','New South Wales','AUSTRALIA','2122','0298654573','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 23:49:32',0,NULL,3,1,11,1,'BJ01670005\r ','HSNO017\r澳标 \r银色的'),(19887,607707576003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','8103179141','folcom@mail.ru','Petr Sosnov','Podolskaya dom 41 kvartira 12','Sankt-Peterburg','Leningradskaya oblast','RUSSIAN FEDERATION','190013','89117345869','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 23:55:26',0,NULL,3,1,3,1,'RA184558403CN\r ','HSJA012 银色的'),(19888,666996008013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','bryant5435','jbryantdrywall@aol.com','Sarah Bryant','790 Tobesofkee Point Trail','Macon','GA','UNITED STATES','31220','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 23:56:14',0,NULL,3,1,1,1,'LK177922919CN ',NULL),(19889,913262808012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','oconner7','chesus7@go2.pl','Robert Zaleski','6 Slade Hill<br>Riches Street','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 23:56:57',0,NULL,3,1,3,1,'RA184558244CN\r ','MOMI002\r黑色 '),(19890,821123100011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',69.99,'eastar4','s.m.mashud','smmashud@yahoo.com','S. MASHUD','77hoprtune, avenue.<br>kilburn','ADELAIDE','South Australia','AUSTRALIA','5084','0468990596','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 00:06:32',0,NULL,3,1,3,1,'RA184558598CN\r ','OTSO004 '),(19891,667012138013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','tipere46','clairichard71@videotron.ca','Bibeau Richard','61 Avenue Tuilerie','East Angus','QC','CANADA','J0B1R0','(819) 832-1277','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 00:53:28',0,NULL,3,1,3,1,'RA184558567CN\r ','GLOT001*2 '),(19892,770263973007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','gillsimple','gilliansurman@bigpond.com','Gill Surman','2/510 Landsborough St','Ballarat','Victoria','AUSTRALIA','3350','0353318290','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-09 01:03:40',0,NULL,3,1,11,1,'BJ01669982\r ','UM00001 '),(19893,913293246012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','orr2911','auvid1@optusnet.com.au','DAVID ORR','5 WESLEY COURT','CROYDON','Victoria','AUSTRALIA','3136','0397330225','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 01:18:17',0,NULL,3,1,3,1,'RA184558235CN\r ','RCMA001 '),(19894,824404065011,320630954155,'New Inova T4 LED Flashlight Li-ion Rechargeable Battery',1,'BAIN001',7.98,'eastar4','evaniser','evaniser@yahoo.com','Evan Calhoun','6751 5th St','Stock Island','FL','UNITED STATES','33040-5840','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 01:07:32',0,NULL,3,1,1,1,'LK175299475CN ',NULL),(19895,824416387011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','thebluthco','rgreco2@gmail.com','Robert Greco','PO Box 270565','Tampa','FL','UNITED STATES','33688-0565','(941) 780-8909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 01:42:30',0,NULL,3,1,1,1,'LK178147488CN ',NULL),(19896,8881326074399540,111,'3D Active shutter Glasses for Sony TDG-BR250',5,'GLOT001',127,'eastar4uk','georgewayne_123','garywayneagain@yahoo.co.uk','gary wayne','58 breamore road','hove','East Sussex ','UNITED KINGDOM','bn34hb','',NULL,NULL,NULL,'2012-01-09 01:59:59',0,NULL,3,1,3,1,'RA184558496CN\r ','GLOT001\r一共买了5副兼容眼镜 \r'),(19897,762292135008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',25.99,'au-buy','cheese_n_bacon','fi.xeer@gmail.com','Corey Lenertz','1105 S 1st St<br>Apt D1','Hermiston','OR','UNITED STATES','97838-2381','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-09 02:23:50',0,NULL,3,1,1,1,'LK177186247CN ','MOLO006 '),(19898,824449727011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','tedlegrand','eric.demers@mail.mcgill.ca','Eric Demers','6071 Briand','Montreal','QC','CANADA','H4E 3K3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 03:17:17',0,NULL,3,1,3,1,'RA184558672CN\r ','GLOT001 '),(19899,8881326081912918,111,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card + A pair of Tyco 2.4/5.0GHz Antenna - ',1,'WLAT009+ ANTY001',11.99,'aliexpress','1006176417','rogercon@versanet.de','Roger Connelly	','Zur Wieden 42','Guetersloh','NRW','GERMANY','33334','+0049 176 41215521',NULL,NULL,NULL,'2012-01-09 04:05:12',0,NULL,8,1,17,0,NULL,''),(19901,8881326082446052,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'aliexpress','1006188270','h.zangger@swissonline.ch','Hans Zangger	','Tannenstrasse 12','Embrach','ZH','SWITZERLAND','8424','+41 44 8651119',NULL,NULL,NULL,'2012-01-09 04:14:06',0,NULL,3,1,21,1,'RA184535875CN ','AR5B93 半高 新 * 1 '),(19900,8881326082189335,111,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card',1,'WLAT009',9.99,'aliexpress','1006176418','rogercon@versanet.de','Roger Connelly	','Zur Wieden 42','Guetersloh','NRW','GERMANY','33334','+0049 176 41215521',NULL,NULL,NULL,'2012-01-09 04:09:49',0,NULL,3,1,21,1,'RA184558964CN\r ','AR5B95 半高 新 AR9285 *2\rtyco antenna *2'),(19902,607907471003,130617205109,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',176.99,'cnfaner','casper_wjt','topptrader@bigpond.com','Wade Topp','65 Martins Ck Rd','Buderim','Queensland','AUSTRALIA','4556','0754085588','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 04:19:38',0,NULL,3,1,3,1,'RA184558743CN\r ','GLSG009*2 '),(19903,824466350011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','koi92nagaevo','nagaevo92@gmail.com','Igor Kaumov','Bilibina 26 - 97','Magadan','Magadanskaya','RUSSIAN FEDERATION','685000','7(4132)63-42-49','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 04:21:01',0,NULL,3,1,11,1,'BJ01669987\r ','TRSN001 '),(19904,667067633013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','bpd7','doyle_bp@yahoo.com','Brian Doyle','National Energy Board<br>444 - 7th AVE SW','CALGARY','AB','CANADA','T2P 0X8','(403) 519-9458','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 04:29:53',0,NULL,3,1,11,1,'BJ01670015\r ','WLAP002 '),(19905,607910479003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','basheesh','bhajjar@ilfc.com','Bashir Hajjar','10250 Constellation Blvd<br>ILFC Ste 3400','Los Angeles','CA','UNITED STATES','90067-6254','(310) 557-4912','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-09 04:38:46',0,NULL,3,1,1,1,'LK177738299CN ',NULL),(19906,607910735003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','ylstpie','yvanl1212@hotmail.com','Yvan Lamarche','2917-4<br>Rte 112','Shefford','QC','CANADA','J2M 1C6','(650) 488-7888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 04:38:55',0,NULL,3,1,3,1,'RA184558690CN\r ','RCLO007+POLO001+RCLO008*4 '),(19907,762335821008,180790438381,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook  BH 104',1,'HSNO034',14.99,'au-buy','charouram','charou@gmail.com','Adrien CHARANGAN','11/367-371 Wentworth Avenue','Toongabbie','New South Wales','AUSTRALIA','2146','610466696618','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-09 05:01:05',0,NULL,3,1,11,1,'BJ01670017\r ','HSNO034\r澳标 '),(19908,822560483011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','davexw1234','davexw@gmail.com','wei xia','12542 granite ridge dr','North Potomac','MD','UNITED STATES','20878-3484','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 05:07:26',0,NULL,3,1,1,1,'LK175923315CN ','GLOT001 '),(19909,667077390013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',1,'HBPH002',61.99,'eastar4','amblergroupltd','priceambler@mac.com','Price Ambler','4 Waterway Square Pl<br>Oppenheimer Ste 525','The Woodlands','TX','UNITED STATES','77380-2664','(713) 650-2100','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 05:28:58',0,NULL,3,1,1,1,'LK178453911CN ','包装上注明no signature required on delivery and please on top of gate brick post (not on top of gate motor) if gate closed and no answer to gate bell '),(19910,913383500012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lazarminator','brkljavko@yahoo.com','Velibor Savic','14-12-106','Aktau','Mangystau','KAZAKHSTAN','130000','+77011619865','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:12:51',0,NULL,3,1,11,1,'BJ01670012\r ','贴航空签\rHSJA001 '),(19911,913386836012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','glticktock','think2box@gmail.com','Abhinav  Chawade','4212 LORREN DR<br>APT 148','FREMONT','CA','UNITED STATES','94536-6868','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 06:28:16',0,NULL,3,1,1,1,'LK175529369CN ',NULL),(19912,667078059013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',1,'CASS001',145.86,'eastar4','carbo7777','carbo77@hotmail.com','Wahib Bohsain Navarro','1819 14 Ave NE  Apt 1.','Calgary','AB','CANADA','T2E 1G7','(587) 891-1454','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:30:38',0,NULL,3,1,5,1,'CP244548445CN ','一共买了\r一条2626\r一个210T\r六条2660\r六条6060'),(19913,770351915007,170751862026,'3 pcs New LG Premium Water Filter Gen11042FR-08 4 Kenmore and LG refrigertors',1,'LGFI001*3',146.99,'au-buy','homersimpson04','paul.simpson67@yahoo.com.au','paul simpson','17 manra way<br>pacific pines','gold coast','Queensland','AUSTRALIA','4211','0450209709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-09 06:51:03',0,NULL,3,1,3,1,'RA184558757CN\r ','LGFI001*3 '),(19914,8881326094045980,111,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',0,'au-buy','brm_85kongen','brm_85@hotmail.com','Brian Madsen','Grønlandsparken 94c','Esbjerg','','DENMARK','6715','',NULL,NULL,NULL,'2012-01-09 07:27:25',0,NULL,3,1,3,1,'RA184558686CN\r ','GPS0010 \r补发 带发票 申请11美金'),(19915,824509126011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',4,'GPS0010',79.96,'eastar4uk','dipolino','dipolino@gmx.net','Michael Schaffner','Eibenweg 10','Nauheim','','GERMANY','64569','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 07:58:25',0,NULL,3,1,21,1,'RA184558669CN\r ','GPS0010 '),(19916,824530460011,320768314214,'NEW SAMSUNG WIS09ABGNX Samsung WIS09ABGN Wi-Fi Adapter',1,'OTSA001',58.9,'eastar4','businesssupplies2011','my_nu_address@hotmail.co.uk','james bolingbroke','31 Ponds Road','Chelmsford','Essex','UNITED KINGDOM','CM2 8QP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 09:41:00',0,NULL,5,1,18,1,NULL,'OTSA001 \r没货给客户退钱了'),(19917,667113412013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','mathiasvh','mathiasvalsgaardfoto@gmail.com','Karen Petersen','Nordmarksvej 14','Solrød','','DENMARK','2680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 09:51:15',0,NULL,3,1,22,1,'BJ01670068\r ','WLAP002 \r申报10美金'),(19918,8881326105831313,111,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',0,'eastar4','pitisifu','ptitlaurent@hotmail.com','Laurent Van Den Berghe','KARDEX SA<br>Rue Saint-Denis 155','Bruxelles','','BELGIUM','1190','',NULL,NULL,NULL,'2012-01-09 10:43:51',0,NULL,5,0,18,0,' ','不补发了\rHSSA002\r客户同意退款   \r已经退款了'),(19919,667120964013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','marcellops3','marcello.os@live.com','Marcello Oliveira Silva','Rua Tiradentes, 210 - Ap 502 - Inga','Niteroi','Rio de Janeiro','BRAZIL','24210-510','+552127042866','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 10:36:50',0,NULL,3,1,11,1,NULL,'CACN004 '),(19920,667128943013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','trz1114','hunnybeaarz@yahoo.com','tammy rodriguez','1013 cedar break ct','Cleburne','TX','UNITED STATES','76033-8260','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 11:19:19',0,NULL,3,0,1,1,' LK178917875CN',NULL),(19921,762410870008,180762085457,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring',1,'UM00021',26.99,'au-buy','rp2780','rebecca_phibbs@yahoo.com.au','Rebecca Phibbs','Level 19<br>88 Phillip Street','SYDNEY','New South Wales','AUSTRALIA','2000','0423433536','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-09 11:17:08',0,NULL,3,1,11,1,NULL,'UM00021\r红色的 '),(19978,608247448003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','laundryslave09','elvic415@gmail.com','victor venezzio','6030 Bania Wood Cir','lantana','FL','UNITED STATES','33462-2105','(561) 429-6316','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 04:14:46',0,NULL,3,1,1,1,' LK178318620CN',NULL),(19922,667139034013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','12marki','marki3@laposte.net','Karim Bernoussi','3 rue Notre Dame','Joigny','Bourgogne','FRANCE','89300','0663909906','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 12:06:09',0,NULL,3,0,11,1,NULL,'HSSA002\r欧标 '),(19923,913476554012,220913327376,'NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses  3300 GR',1,'GLSG009',54.99,'eastar4uk','dantanfig','mark.figgins@morganplc.com','MARK FIGGINS','38 PENTRE ROAD, PONTARDULAIS','SWANSEA','Swansea','UNITED KINGDOM','SA48HT','01792763014','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 12:27:55',0,NULL,3,1,3,1,'RA184548318CN ','GLSG009 '),(19924,824580518011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','docapro_br','docapro@hotmail.com','Ricardo Silva Cardoso','Rua Santo Amaro,36/605 - Glória','Rio de Janeiro','Rio de Janeiro','BRAZIL','22211-230','21-94775092','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 12:44:19',0,NULL,3,1,3,1,'RA184535994CN ','GLOT001 \r这票不知道是发还是没发       但单子打了也送去了'),(19925,913491520012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',89.99,'eastar4','alex_7211','a.otsyk@gmail.com','Alexey Otsyk','Mihalkovskaya 15k1 kv.48','Moscow','','RUSSIAN FEDERATION','125239','7(916)652-2467','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 13:11:13',0,NULL,3,1,3,1,' RA184548264CN','GLSG009 '),(19926,824602402011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','beatka1ch1','bchapinska@op.pl','BEATA CHAPINSKA','65 PARSONAGE STREET','STOKE-ON-TRENT','Staffordshire','UNITED KINGDOM','ST6 5HL','07871250765','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 13:50:03',0,NULL,3,1,3,1,' RA184548397CN','LGAD001 '),(19927,824604857011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','firebrd44','firebrd44@hotmail.com','Michael Baker','1304 Stanwick Dr','San Dimas','CA','UNITED STATES','91773','(909) 592-9514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 13:54:43',0,NULL,3,1,1,1,' ',''),(19928,824606146011,320786339943,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',44.89,'eastar4','olimpioa','olimpioa@uol.com.br','Olimpio de Melo Alvares Junior','Rua Gustav Hainz 196H','Cotia','SP','BRAZIL','06710765','11 82826059','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 13:59:28',0,NULL,3,1,3,1,' RA184548278CN','GLOT001 '),(19929,824609287011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','twigymil','twigymil@blueyonder.co.uk','Brian Miller','76/78 Brenkley Ave<br>Shiremoor','Newcastle Upon Tyne','Tyne & Wear','UNITED KINGDOM','NE27 0PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 14:07:16',0,NULL,3,1,3,1,'RA184548370CN ','GLOT001 '),(19930,824615983011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','ttul5184','taratula@verizon.net','Tara Tula','355 Brooks St','Worcester','MA','UNITED STATES','01606-1328','(508) 769-2691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 14:31:04',0,NULL,3,1,1,1,'LK174523016CN\r ',' '),(19931,913524083012,220816384329,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',26.99,'eastar4uk','dunx1000','duncan.thompson@bskyb.com','Duncan Thompson','Unit 8, BSkyB<br>Grant Way','Isleworth','Middlesex','UNITED KINGDOM','TW7 5QD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 14:38:50',0,NULL,3,1,3,1,'RA184548321CN ','GLOT001 '),(19932,613330398004,140671481128,'New Genious LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack)',1,'LGGL005',19.59,'cnfaner','edermw','edermaciel@gmail.com','Eder Maciel Wanderley','CNB 12 Lote 21 Ed. Via Verona<br>Apto. 104','Taguatinga Norte','DF','BRAZIL','72115-946','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 15:27:41',0,NULL,3,1,3,1,' RA184548352CN','LGGL005 '),(19933,824646914011,320610182890,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61+antenna',1,'WWSI002+ANCN001',33.88,'eastar4','eraser212','hendrikgroove@googlemail.com','Hendrik Groove','Zur Eichenbitze 41','Hennef','','GERMANY','53773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 15:46:42',0,NULL,3,1,2,1,'30111812931\r ',NULL),(19934,910973739012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',11.99,'eastar4uk','dentarum74','dentarum@yandex.ru','Karen Stepanyan','Moldovakan, 46/1,22','Erevan','','ARMENIA','0062','644113','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 15:47:08',0,NULL,3,1,22,1,NULL,'MOHP001 '),(19935,913550627012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',11.99,'eastar4uk','vitorgmp','vitormattosgmp@gmail.com','vitor medeiro','rua dos biólogos<br>q 13 l 22','rio de janeiro','rio de janeiro','BRAZIL','22723510','(2155) 71278027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 15:48:46',0,NULL,3,1,3,1,'RA184530405CN\r ','MOHP001 '),(19936,913564416012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','iadoretoys','mauri311@gmail.com','Mauricio Villalobos','743 NW 104th Ave<br>apt 204','Pembroke Pines','FL','UNITED STATES','33026-5989','(954) 701-5645','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 16:19:47',0,NULL,3,1,1,1,' LK177376630CN',' '),(19937,608040812003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',40.8,'cnfaner','henrique4402','henriquemariano@onda.com.br','Henrique Mariano','OTAVIO GOMES  Nº80<br>apt. 303','Vassouras','Rio de Janeiro','BRAZIL','27700-000','43 3252 1881','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 16:27:47',0,NULL,3,1,3,1,' RA184548281CN','WWOT001+ANCN001 '),(19938,824666678011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','latari042009','latarimccown@yahoo.com','latari mccown','425 a easten','new haven','CT','UNITED STATES','06513','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 16:36:10',0,NULL,3,1,1,1,' LK178145266CN',NULL),(19939,820897441011,320814097454,'Logitech Harmony 895 Advanced Universal Remote Control W/Color Screen Display',1,'RCLO009',84.99,'eastar4uk','7109johnson','happypauly@sky.com','Mr P N Johnson','Mitsubishi Electric<br>Unit 8 Electra Park, Bidder Street','Canning Town','London','UNITED KINGDOM','E16 4ES','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 17:01:22',0,NULL,5,0,18,0,NULL,'RCLO009 \r已退款'),(19940,913598531012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','me61ic','me61ic@hotmail.com','Ignacio Jose Martin-Candido Moreno','HISPABADGE<br>C / YEDRA LOCAL F URB.JARDIN REINA','GRANADA','Andalucía Ceuta y Melilla','SPAIN','18006','958815729','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 17:20:31',0,NULL,3,1,22,1,NULL,'RMSN002 '),(19941,824718712011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','kemikable','kemotion@bk.ru','Kamran Agayev','Tofik Mammedov,21/7 flat 41','Baku','Badamdar','AZERBAIJAN','1021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 18:14:59',0,NULL,3,1,22,1,NULL,'HSUE004 '),(19942,913629194012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','cox3570','coxfamily@usa.com','David Cox','513 Palisade Mountain Dr','Windsor','CO','UNITED STATES','80550-4903','(970) 310-9394','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 18:31:06',0,NULL,3,1,1,1,' LK168506535CN',NULL),(19943,913653781012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','tkbrew','sauvden@sympatico.ca','Denis Sauve','6236 St Albans Court','Orleans','ON','CANADA','K1C 3C4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 18:52:10',0,NULL,3,1,3,1,' RA184548220CN','GLOT001*2 '),(19944,824761112011,320730540615,'3 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',126.99,'eastar4uk','dito6979','dkaladelfos@yahoo.gr','dimitrios kaladelfos','kapsali 6, kifisia, kifisia<br>kifisia','athens','athens','GREECE','14562','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 19:25:43',0,NULL,3,1,3,1,' RA184548454CN','GLSG001*3 \r贴确认签'),(19945,824776678011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','salted_feet','danielsalthouse@hotmail.com','Daniel Salthouse','4 Nairn Street','Sheffield','South Yorkshire','UNITED KINGDOM','s10 1ul','01142662502','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 19:48:38',0,NULL,3,1,3,1,' RA184548406CN','LGAD001 '),(19946,608116888003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','karpovan','karpovan3@gmail.com','Anatoly Karpov','Shchukinskaya 8,77','Moscow','Moscow','RUSSIAN FEDERATION','123182','+74991903617','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 20:00:34',0,NULL,3,1,3,1,' RA184548366CN','HSJA012 \r欧标\r'),(19947,824789622011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','bzucatelli','bdrt09@hotmail.com','Bruno Alvarenga Zucateli','Rua 03, Quadra 07, Casa 10, Cohama','São Luis','Maranhão','BRAZIL','65073460','5509832366531','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 20:09:14',0,NULL,3,1,3,1,' RA184548295CN','GPS0007 '),(19948,824813792011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','fouzi34shakil','doli@hotmail.co.uk','shakil ahmad','34 southdown close','rochdale','Lancashire','UNITED KINGDOM','ol11 4pp','01706527626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 20:49:58',0,NULL,3,1,11,1,NULL,'英标 \rHSJA002'),(19949,913737398012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','hornby1900','hsk1701@hotmail.com','Harbans Kainth','25 Firsvale Road<br>Wednesfield','Wolverhampton','West Midlands','UNITED KINGDOM','WV11 3LN','01902563895','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 20:59:07',0,NULL,3,1,3,1,' RA184548383CN','MOMI002 '),(19950,667350245013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','ccosme01','ccosme01@gmail.com','Carlos Cosme','406 Eagle Dr','Kissimmee','FL','UNITED STATES','34759-4431','(407) 680-5343','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 22:19:44',0,NULL,3,1,1,1,' LK176132914CN',NULL),(19951,613484754004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','mlp1158','mlp@ntelos.net','Mike Perdue','887 British Woods Dr','Roanoke','VA','UNITED STATES','24019-8256','(540) 966-1073','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-09 22:38:08',0,NULL,3,1,1,1,'LK177637635CN ',''),(19952,667359335013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','terryinwales','terry@pantypwll.co.uk','Terry O\'Brien','Pant y Pwll','KIDWELLY','Carmarthenshire','UNITED KINGDOM','SA17 5LW','01269860746','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 22:51:20',0,NULL,3,1,2,1,'30111807316\r ',NULL),(19953,913803041012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',3,'GLOT001',134.67,'eastar4','imodding','patenteux99@hotmail.com','Frederic Morin','11 Ave 364','Sherbrooke','QC','CANADA','J1G 2T5','(819) 564-7143','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 23:00:34',0,NULL,3,1,3,1,' RA184548233CN','GLOT001 '),(19954,667377226013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',2,'HSNO023',27.98,'eastar4','lecogif','lecogif@yahoo.com.br','Alexandre Gianotti de Freitas','R.Conselheiro Brotero,686 ap-64','São Paulo','São Paulo','BRAZIL','01232-010','551170298165','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 23:59:46',0,NULL,3,1,11,1,NULL,'HSNO023 '),(19955,913820739012,220707277666,'New Genuine Cisco PVDM2-16 16 Channel Voice DSP Module',1,'OTIN005',84,'eastar4','seinale','provision@seinale.com','Andoni Sáenz de Santamaría Zabala','Calle Egia 19, Local:3','Donostia - San Sebastian','País Vasco','SPAIN','20012','677525881','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 23:47:25',0,NULL,3,1,3,1,'RA184548349CN ','OTIN005 \r贴航空签'),(19956,770744405007,170730545023,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'au-buy','wayneaspden','wcwa64@aim.com','Wayne Aspden','PO Box 6314','Fort Mcmurray','AB','CANADA','T9H5N3','(780) 907-8513','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 00:04:50',0,NULL,3,1,11,1,NULL,'RCLO007 '),(19957,910838884012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Linda Cantwell','24 Harlem St','Worcester','MA','UNITED STATES','01610-2106','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:19:18',0,NULL,3,1,1,1,' LK179324365CN',NULL),(19958,910840034012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Ron Ryel','417 Main St','East Hartford','CT','UNITED STATES','06118-1410','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:21:11',0,NULL,3,1,1,1,' LK177504648CN',NULL),(19959,768558891007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','fruetschi90','dominik0012@gmx.net','Dominik Frühwirt','Laimbach 153','Laimbach','','AUSTRIA','3663','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 00:25:59',0,NULL,3,1,11,1,NULL,'RELO003 '),(19960,913833112012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Too Creative Media Inc.','113 Biltmore Pl','Panama City Beach','FL','UNITED STATES','32413-2834','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:29:05',0,NULL,3,1,1,1,' LK177060414CN',NULL),(19961,910996192012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','bowlweavil','bowlweavil@mindspring.com','JB Fung - John Aaroe Group','8560 W Sunset Blvd<br>3rd Floor','West Hollywood','CA','UNITED STATES','90069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:33:39',0,NULL,3,1,1,1,' LK177754481CN',NULL),(19962,913837357012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',5,'OTGR001',99.5,'eastar4','muadotool','pcgci@yahoo.com','phu chung','6434 overlook dr','alexandria','VA','UNITED STATES','22312-1327','(703) 625-7945','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:36:21',0,NULL,3,1,4,1,'YW867739155CN ','OTGR001 '),(19963,910972183012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','The Goddard School','12818 E 116th St','Fishers','IN','UNITED STATES','46037-9718','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 00:36:26',0,NULL,3,1,1,1,' LK179229492CN',' '),(19964,913837662012,220872413982,'4 pairs 3D Active Shutter TV Glasses for SHARP LC-40LE835U',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','AGUSTIN MANUEL ALMAGRO ROJAS','C/ ARAGONITO 7A','MALAGA','Malaga','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 00:39:03',0,NULL,3,1,3,1,'RA184548335CN ','GLOT001*4\r申报为gift 小于20美金 \r贴确认签'),(19965,667396623013,230641257901,'New lady lace trim sun/rain stick Umbrella blue',1,'UM00011',24.99,'eastar4','sonofmackie','jmackies@bigpond.net.au','John Mackieson','50 Wills Street<br>Westmeadows','Melbourne','Victoria','AUSTRALIA','3049','61393021668','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 01:19:09',0,NULL,3,1,11,1,NULL,'UM00011 \r蕾丝花边伞 '),(19966,824928055011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','cyberguy23','andrei.siamenau@gmail.com','Galina Semenova','Logoisky trakt 1-1-302','Minsk','','BELARUS','220113','(375) 296-5886 ext.: 06','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 01:32:37',0,NULL,3,1,22,1,NULL,'HSNO019\r欧标'),(19967,8881326161246368,111,'3D blu-ray FIFA World CUP 2010 ',1,'',14,'buysia','jeffboom71','jeffboom@hotmail.com','Jeff Vuillin (Matco Lt?e)','10833 avenue Moisan suite 200','Montreal-Nord ','QC','CANADA','H1G 4N6','',NULL,NULL,NULL,'2012-01-10 02:07:26',0,NULL,7,0,18,0,NULL,NULL),(19968,8881326161258047,111,'3D blu-ray FIFA World CUP 2010 ',1,'',14,'buysia','jeffboom71','jeffboom@hotmail.com','Jeff Vuillin (Matco Lt?e)','10833 avenue Moisan suite 200','Montreal-Nord ','QC','CANADA','H1G 4N6','',NULL,NULL,NULL,'2012-01-10 02:07:26',0,NULL,3,1,11,1,NULL,'BR3D008 \r新地址\rJeff Vuillin (Matco Ltée)\r10833 avenue Moisan suite 200\rMontreal-Nord QC  H1G 4N6\rCanada\r'),(19969,667409642013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','425samb','boyces@svsd410.org','Sam  Boyce','42530 SE 102nd St','North Bend','WA','UNITED STATES','98045-9449','(425) 888-9386','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 02:13:47',0,NULL,3,1,1,1,' LK174673744CN',NULL),(19970,824942218011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','foyz08','foyzur_06@hotmail.co.uk','Foyzur Rahman','324 entwistle Road','Rochdale','Lancashire','UNITED KINGDOM','OL16 2LH','07999316716','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 02:18:55',0,NULL,3,1,3,1,' RA184548304CN','LGAD001 '),(19971,8881326162439157,111,'New Nokia HS-26W Bluetooch Headset HS 26W',1,'',0,'cnfaner','creditczar','newacct21780@aol.com','AJ Allen','6161 El Cajon Blvd<br># 278','San Diego','CA','UNITED STATES','92115-3922','(619) 672-1201',NULL,NULL,NULL,'2012-01-10 02:27:19',0,NULL,3,1,1,1,'LK098258216CN ','补发的 \rHSNO032\r只补发耳机'),(19972,762780301008,180699061836,'New Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',29.99,'au-buy','xsnutz','seanmcerlain_82@hotmail.com','Sean McErlain','8  Bimbadeen  Dr','Mooroolbark','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 02:42:13',0,NULL,3,1,11,1,NULL,'HSJA010\r澳标 '),(19973,608232947003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','jaco7450','acosta041475@yahoo.com','joan acosta','8870 fontainebleau blvd # 506','miami','FL','UNITED STATES','33172','(305) 746-0638','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 02:45:25',0,NULL,3,1,1,1,' LK177764492CN',NULL),(19974,608233974003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','aurimasvin','vinaur@gmail.com','Aurimas Vinckevicius','400 E. Randolph St.<br>Apt. 2616','Chicago','IL','UNITED STATES','60601','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 02:50:53',0,NULL,3,1,1,1,' LK177274176CN',NULL),(19975,770788462007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','dexter_140','tim@jacksons.net.au','Tim Jackson','Yodel / Fulfilnet 36 - 42 Waterloo Rd<br>Macquarie Park','Sydney','New South Wales','AUSTRALIA','2113','0288703322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 02:51:45',0,NULL,3,1,11,1,NULL,'BALO007 '),(19976,762790480008,180790438381,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook  BH 104',1,'HSNO034',14.99,'au-buy','sinewave44','miketeague6@yahoo.com.au','Mike Teague','PO Box 568','Dianella','Western Australia','AUSTRALIA','6059','0410509757','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 03:17:24',0,NULL,3,1,11,1,NULL,'HSNO034\r澳标 '),(19977,913895673012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.98,'eastar4','dennisjm','dennisjm508@gmail.com','Dennis J Mizdail Jr','40 Wales St','Abington','MA','UNITED STATES','02351-1828','(781) 982-1702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 03:33:44',0,NULL,3,1,1,1,' LK178182652CN',NULL),(19979,608249584003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','rpsnook','roger_snook@hotmail.com','Roger Snook','11 Reichers Place','Gander','NL','CANADA','A1V 2V7','(709) 256-6185','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 04:24:18',0,NULL,3,1,3,1,' RA184548445CN','RCLO007+POLO001+RCLO008*4 '),(19980,8881326171674091,111,'NEW NOKIA BH-900',1,'HSNO019',0,'eastar4','marks749','mbsilvey@marserv.com','Mark Silvey','177 Riverside Ave<br>Ste F','Newport Beach','CA','UNITED STATES','92663-4080','(949) 642-6229',NULL,NULL,NULL,'2012-01-10 05:01:14',0,NULL,3,1,1,1,'LK081261410CN ','补发的\r\r客户补了差价 发个新的\r'),(19981,762817837008,180757094165,'New Replaceable Shell for logitech Mouse MX518  MX 518',2,'SHLO004',25.98,'au-buy','the.elwood','lloydg@olp.net','lloyd s ganus','13945 Hectorville Rd','mounds','OK','UNITED STATES','74047','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 05:27:06',0,NULL,3,1,1,1,' LK178781470CN',NULL),(19982,608262620003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','drski4','drski4@gmail.com','David Abramyan','1044 Marion Dr.','Glendale','CA','UNITED STATES','91205','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 05:52:37',0,NULL,3,1,1,1,' LK179449895CN',NULL),(19983,824994413011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','amigadreamer','mr_doig@optusnet.com.au','Mark Doig','19 Carlos street<br>Hillcrest','Brisbane','Queensland','AUSTRALIA','4118','0734022655','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 06:01:49',0,NULL,3,1,11,1,NULL,'OTCN002 '),(19984,823836328011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','kevinsmith1000','vke3@hotmail.com','Kevin Smith c/o Bank of the West','500 capitol mall<br>12th Floor','Sacramento','CA','UNITED STATES','95814','(916) 552-4449','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 06:16:04',0,NULL,3,1,1,1,' LK174161317CN',NULL),(19985,913625757012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','zappeastusa3','zappusa3@gmail.com','Andrei Third','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 07:23:20',0,NULL,3,1,1,1,' LK179326830CN','客户要求把物品编号写在包装上220806889802 '),(19986,825025787011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',69.9,'eastar4','1stuyvesant','phpierce@earthlink.net','Philip Pierce','1772 N Fairfax Ave','Los Angeles','CA','UNITED STATES','90046-2144','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 08:50:56',0,NULL,3,1,1,1,' LK175978521CN',NULL),(19987,825031808011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','audra0427','audra.kneese@yahoo.com','audra KNEESE','401 mirike dr','ft worth','TX','UNITED STATES','76108-2702','(817) 296-9796','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 09:22:26',0,NULL,3,1,1,1,'、  ',NULL),(19988,913990985012,220691756846,'NEW GENUINE NOKIA BH-202 BLUETOOTH HEADSET+car charger',1,'HSNO006+CCNO001',16.98,'eastar4','nazarin88','nazar88@mail.ru','Vladimir Nazarin','pr. Elizarova, d.8, kor.1, kv. 12','Saint-Petersburg','','RUSSIAN FEDERATION','192029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 10:39:26',0,NULL,3,1,11,1,'、 ','HSNO006+CCNO001 '),(19989,825077995011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',38.99,'eastar4uk','john2525john','dou_dou95@hotmail.fr','john coré','zone industrielle saint memain','voves','Centre','FRANCE','28150','0615775294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 12:26:31',0,NULL,3,1,3,1,'RA184558902CN ','LGGL002 '),(19990,608323327003,130553090501,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',35.99,'cnfaner','swl-remedios','swl@dl5.dk','Remedios Pena Mateo de Meereis','Eibenweg 10','Meschede-Frenkhausen','','GERMANY','59872','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 12:40:23',0,NULL,3,1,21,1,'RA184558831CN ','WWSI004 '),(19991,770925209007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',1,'CC00002',35.99,'au-buy','bello290756','bernhard_neuwirth@gmx.at','neuwirth bernhard','pyhrnstrasse 18','schlierbach','','AUSTRIA','4553','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 13:06:22',0,NULL,3,1,22,1,NULL,'CC00002 \r'),(19992,770937561007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','david.t.chan','david.t.chan@gmail.com','David Chan','10 McGhee Avenue','Mitcham','Victoria','AUSTRALIA','3132','61412632562','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 13:42:37',0,NULL,3,1,11,1,'、 ','RELO002 '),(19993,825104350011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','flaberdeco','flabermartins@gmail.com','Flaber Deco','rua marechal deodoro, 2863','sao jose do rio preto','sao paulo','BRAZIL','15010070',' 1733531050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 13:54:37',0,NULL,3,1,3,1,'RA184558726CN ','LGRM001 '),(19994,825115476011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','caw33','caroline_walker@btopenworld.com','Caroline Walker','3 Hennessey Court<br>736 Lea Bridge Road','Leyton','London','UNITED KINGDOM','E10 6AW','07973481006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 14:30:12',0,NULL,3,1,3,1,'RA184558859CN ','OTHP005 '),(19995,667544441013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','dimkost','dimkostoulas@hotmail.com','Dimitris Kostoulas','Filikis Etairias 9','Ioannina','Ioannina','GREECE','45444','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 14:52:52',0,NULL,3,1,22,1,'BJ01669943 ','HSSA002 \r欧标'),(19996,910974291012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','David E. Hintz','1150 K St NW<br>Apt 209','Washington','DC','UNITED STATES','20005-6801','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 15:32:25',0,NULL,3,1,1,1,'、  ',NULL),(19997,611834846004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','wereheredear','cdh13@pitt.edu','Crystal D Hollinger','472 Ohio Ave<br>Apt 2','Rochester','PA','UNITED STATES','15074-2059','(717) 917-0335','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 15:33:36',0,NULL,3,1,1,1,'、  ',NULL),(19998,613670825004,140667904553,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card +a pair of Antenna',1,'WLAT005+ANTY001',11.8,'cnfaner','mr.lustr','01072018@karneval.cz','Jiri Hruban','Miksickova 2','Brno','Czech Republic','CZECH REPUBLIC','615 00','+420 604 359583','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 15:47:11',0,NULL,3,1,23,1,'BP04081201110004','WLAT005+ANTY001 '),(19999,914093120012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',31.39,'eastar4uk','alsheper','alex.shafranov@gmail.com','Alexey Shafranov','Gagarina bvd. 17-37','Ust-Kamenogorsk','East Kazakhstan','KAZAKHSTAN','070010',' 87079778840','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 15:52:04',0,NULL,3,1,3,1,'RA184558805CN ','LGFI001 '),(20000,914045478012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.39,'eastar4','zappeastusa3','zappusa3@gmail.com','Andrei Third','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 16:25:33',0,NULL,3,1,1,1,'、  ','8pin 1.0 8cm 五线连接 \r客户要求把物品编号写在包装上220695326722'),(20001,613694189004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','buggel01','g40st@gmx.de','Ritzalis Electronic','Z.h. Olaf Ruth<br>Liebigstrasse 15','Nidderau','','GERMANY','61130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 17:09:43',0,NULL,3,1,21,1,'RA184558828CN ','WLDE002 '),(20002,825179967011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','crownlands_garage','andrew.talmage@tiscali.co.uk','Andrew Talmage','Wayside<br>Crownlands garage','High Ongar','Essex','UNITED KINGDOM','cm5 9nw','01277363166','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 17:13:40',0,NULL,3,1,3,1,'RA184558730CN ','LGAD001 '),(20003,613706475004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',4,'WLAP008',79.2,'cnfaner','lametal410','bukhakin13@gmail.com','Hyeon-sik Yoon','No.311, Living Castle, 27-11, Noryangjin 2-dong, Dongjak-gu','Seoul','','KOREA,REPUBLIC OF','156-052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 17:49:08',0,NULL,3,1,3,1,'RA184558788CN ','WLAP008 '),(20004,667597837013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','slm68430','swansonv@live.com','Vincent Swanson','1315 Lewis Ave','Billings','MT','UNITED STATES','59102-4237','(406) 237-6731','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 17:50:45',0,NULL,3,1,1,1,'、  ',NULL),(20005,914153676012,220763418811,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',5.49,'eastar4uk','arias.1982','scm_spion@hotmail.com','Nacho Arias','PARQUE PICOS DE URBION 28 4ºA','Logroño','La Rioja','SPAIN','26008','622331982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 17:57:48',0,NULL,3,1,23,1,'BP04081201110001 ','POLO001 '),(20006,914169177012,220917833326,'New 8 pcs Professional Piano Tuning Tool Kit Musical Instruments',1,'OT00001',62.99,'eastar4','adiosc33755','adiosc33755@gmail.com','Timothy Ostrander','1445 admiral woodson ln','clearwater','FL','UNITED STATES','33755-3404','(727) 447-7462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 18:26:30',0,NULL,3,1,1,1,'、  ',NULL),(20007,914177287012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','tonyto210','tonyto@lyse.net','Bjørnar Totland','Terneveien 13','Stavanger','Hafrsfjord','NORWAY','4049','004740627290','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 18:40:28',0,NULL,3,1,21,1,'RA184558765CN ','GLOT001 '),(20008,914216480012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','migmac06','lara.miguel@gmail.com','Miguel Lara García','Alonso Cano 2, Esc Izq, Bajo A','Móstoles','Madrid','SPAIN','28933','676857426','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 19:48:21',0,NULL,3,1,2,1,'、  ',NULL),(20009,667642565013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jorje222','jorje2@gmail.com','Georgiy Kalishkin','Rijskaya 18, 122','Kiev','UA','UKRAINE','04060','(38068) 125 - 2308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 19:49:56',0,NULL,3,1,22,1,'、\r ','CACN004 '),(20010,914222312012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Jean M. crosby','2522 N 52nd St','Phoenix','AZ','UNITED STATES','85008-2641','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 19:55:23',0,NULL,3,1,1,1,'、  ',NULL),(20011,914240963012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','pbre7916','paullbrewer@aol.com','paul brewer','15 Meadow Gardens, Hopeman','Elgin','Moray','UNITED KINGDOM','iv30 5pn','01343831053','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 20:27:00',0,NULL,3,1,3,1,'RA184535950CN ','GLSG001*2 '),(20012,613769492004,140667903886,'New Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card + Antenna*2',1,'WLAT010+ANTY001',10.9,'cnfaner','dextervip','jrtadf@gmail.com','Felipy Tavares Amorim','Caixa Postal 3252<br>Guará','Brasília','DF','BRAZIL','71010-970','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 20:43:50',0,NULL,3,1,3,1,'RA184558845CN ','WLAT010+ANTY001 '),(20013,763124116008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',25.99,'au-buy','mikebro97','mike_breault@hotmail.com','Mike Breault','11-303 King St. North','Waterloo','ON','CANADA','N2J 2Z1','(519) 573-1665','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 21:14:52',0,NULL,3,1,3,1,'RA184558712CN ','MOLO006\r挑个最好的 这个客户很龟毛 '),(20014,824911655011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','ffmac.capt','mcook2687@hotmail.com','Mark Cook','395 1/2 W Main St','Waldo','OH','UNITED STATES','43356-9113','(740) 505-7582','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 21:26:44',0,NULL,3,1,1,1,'、  ',NULL),(20015,667682263013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','arxontas7','yiannisvou@hotmail.com','GIANNIS VOUGIOUKLAKIS','DARDANELION 38','PIRAEUS','KERATSINI','GREECE','18757','+0306945821468','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 21:27:43',0,NULL,3,1,22,1,'、 ','HSSA002\r欧标\r\r'),(20016,825329235011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','nadia.robertson','nadia@young-firm.com','Nadia Robertson','399a Bethnal Green Road','London','London','UNITED KINGDOM','E2 0AN','07967808110','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 22:00:58',0,NULL,3,1,3,1,'RA184558791CN ','MOAP001 '),(20017,667696370013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','cintiaobscure10','cintiaobscure@hotmail.com','Cíntia Amaral Pereira','Praça dos Andradas, centro<br>Número 32, apartamento 102','Barbacena','Minas Gerais','BRAZIL','36200-008','+55 (32) 8888 - 4003','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 22:10:22',0,NULL,3,1,11,1,'、 ','UM00041 \r接边斑马纹透明伞   '),(20018,914308646012,220816376663,'4 pairs New genuin Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*4',166.99,'eastar4uk','166760139','anilvelji@yahoo.co.uk','ANIL VELJI','5 BERWYN CLOSE','OLDHAM','Greater Manchester','UNITED KINGDOM','OL83WB','07958923918','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 22:31:01',0,NULL,3,1,3,1,'RA184535861CN ','GLSG001*4 '),(20019,914308926012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','gwba71957','gwbarnett1@cox.net','Gary Barnett','1387 15TH TER','BARLING','AR','UNITED STATES','72923-1879','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 22:31:08',0,NULL,3,1,1,1,'、 ',NULL),(20020,771178342007,170758647866,'New Genuine Sturdy Samsung WMN2050C Ultra Slim Wall Mount for 2011 LED TV 65\"',2,'MOSA010',139.98,'au-buy','liverpool*2010','mehmet64@ovi.com','mehmet cileli','11 holmes way<br>caroline springs','melbourne','Victoria','AUSTRALIA','3023','0394495874','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 22:39:26',0,NULL,3,1,4,1,'YW867739170CN ',NULL),(20021,825352047011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','drzuzic','drazen.zuzic@bj.t-com.hr','Drazen Zuzic','29. Rujan 85','Predavac','','CROATIA','43211','0038543880066','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 22:51:34',0,NULL,3,1,22,1,NULL,'HSJA002 '),(20022,914326633012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','lfc_johnny','lfcjohnny@hotmail.co.uk','Johnny Webster','11 Redmarsh Avenue<br>Rawmarsh','Rotherham','South Yorkshire','UNITED KINGDOM','S62 7LG','01709306196','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 23:14:08',0,NULL,3,1,3,1,'RA184558814CN ','MOMI002\r黑色 '),(20023,608513408003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','rabbani07','fatgurrabbani@hotmail.com','Fatgur Rabbani Muzzammil','43579 McKay Ter','CHANTILLY','VA','UNITED STATES','20152-5790','(313) 510-8277','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-10 23:28:13',0,NULL,3,1,1,1,'、  ',NULL),(20024,667721145013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','4purplepenguins','bennettj7.5@gmail.com','jacob bennett','5702 Virginia St','camp lejeune','NC','UNITED STATES','28547-1238','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 23:40:58',0,NULL,3,1,1,1,'、  ',NULL),(20025,667517403013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','wahyuijangman','ijangman@yahoo.com','Wahyu Priyono','H. Kurdi Baru 1 No. 36','Bandung','West Java','INDONESIA','40243','+62225208172','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 00:00:27',0,NULL,3,1,2,1,'、  ',NULL),(20033,825474551011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','kamran.asad','watc1987@gmail.com','Kamran Esedullayev','Yeni Guneshli qesebesi, Massiv AB. Bina 50A. menzil 44','Baku','Azerbaijan','AZERBAIJAN','AZ1133','+994518191446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:49:45',0,NULL,3,1,22,1,'BJ01669935 ','HSSA003 '),(20026,914385224012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Meloney H quady','9800 Highway 238','Jacksonville','OR','UNITED STATES','97530-9557','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 02:12:37',0,NULL,3,1,1,1,'、  ',NULL),(20027,8881326251930861,111,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',0,'eastar4uk','eppoes','eppoes@aol.com','Gary Epstein','53 Woodland Drive','Hove','East Sussex','UNITED KINGDOM','BN3 6DH','01273708715',NULL,NULL,NULL,'2012-01-11 03:18:50',0,NULL,3,1,3,1,'RA184535889CN ','GLOT001\r补货 '),(20028,825432380011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','flexusahoses','sales@flexusa.net','Antonio Vargas','2233 Broderick Ave','Duarte','CA','UNITED STATES','91010-3510','(626) 531-6172','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 03:21:09',0,NULL,3,1,1,1,'、  ',' '),(20029,608566341003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','jon442','maddogjh@shaw.ca','jon haycock','4411 106 ave','Edmonton','AB','CANADA','T6A 1E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 03:52:05',0,NULL,3,1,3,1,'RA184536005CN ','RCLO007+POLO001+RCLO008*4 '),(20030,8881326254247480,111,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',0,'au-buy','tookie_ding','mcoler@nycap.rr.com','Marsha L Coler','12 Arbor View Dr','Ballston Lake','NY','UNITED STATES','12019','',NULL,NULL,NULL,'2012-01-11 03:57:27',0,NULL,3,1,1,1,'LK135673795CN  ',' '),(20031,608576484003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','hai_final.2009','hai_final@yahoo.com','Hai nguyen','2740 Utah Ave','sacramento','CA','UNITED STATES','95822-5418','(916) 548-3576','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-11 05:02:09',0,NULL,3,1,1,1,'/ ',NULL),(20032,608587301003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','joewhoever','roywahab@gmail.com','Roy D Wahab','3115 Innisdale Rd','Mississauga','ON','CANADA','L5N6P2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:29:10',0,NULL,3,1,3,1,'RA184535915CN ','HSJA012 '),(20034,914458576012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','zolvik','zavornicin@mail.ru','Олег Заворницын','Курганская область, Далматовский район,<br>с.Песчаноколедино, ул.Калинина 11-2','село Песчаноколедино','Курганская область','RUSSIAN FEDERATION','641751','89129798829','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 07:17:16',0,NULL,3,1,3,1,'RA184530100CN ','GLOT005*2 '),(20035,914487709012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','ford1923t','steam@iprimus.com.au','Greg Bilson','EAST COAST STEAM P/L<br>17~19 MICA STREET','CAROLE PARK','Queensland','AUSTRALIA','4300','0732713688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 09:32:20',0,NULL,3,1,3,1,'RA184530229CN\r ','GLOT001 '),(20036,825508710011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','kjm6995','kevin.morrill@csmlimited.co.uk','Kevin Morrill','Sunnybank Farm<br>Venns Green','Hereford','Herefordshire','UNITED KINGDOM','HR1 3DD','01568797899','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 09:39:08',0,NULL,3,1,3,1,'RA184530135CN\r ','LGAD001 '),(20037,820739465011,320812367533,'4 pair NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses 3300 GR',1,'GLSG009*4',211.99,'eastar4uk','aviskh','alex_is@sakhalin.ru','Aleksandr Isaev','Purkaeva 74, 20','Yuzhno-Sakhalinsk','','RUSSIAN FEDERATION','693013','+7(914) 743-5894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 09:40:11',0,NULL,3,1,6,1,'EE651291989CN ','GLSG009*4 \r'),(20038,914492969012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','jonno4885','jonbaker85@gmail.com','Jon Baker','20/482 pacific highway<br>Lane Cove North','Sydney','New South Wales','AUSTRALIA','2066','0415126033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 09:51:36',0,NULL,3,1,11,1,'BJ01669922 ','CASS003\rCAB-6060 '),(20039,8881326278449807,111,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',0,'eastar4','greatpasta','greatpasta@telus.net','Deanna W Barrett','5879 Somerset Avenue','Peachland','BC','CANADA','V0H1X4','(250) 767-3133',NULL,NULL,NULL,'2012-01-11 10:40:49',0,NULL,3,1,11,1,'BJ01669908\r ','MOLO001\r只补发一个鼠标新的\r挑个成色好的\r'),(20040,608622801003,130489926046,'New Ultimate Ears METRO.FI 170vi UE 170VI voice track#',1,'HSUE001',22,'cnfaner','emankayker','e@producson.ch','Emmanuel Hungrecker','ch auguste-vilbert, 50','le grand-saconnex','genève','SWITZERLAND','1218','0041794401148','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 10:44:14',0,NULL,3,1,3,1,'RA184530113CN\r ','HSUE001 '),(20041,608004677003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','marouf2007','marouf@eram.com.sa','Ahmed Maarof','P.O. Box 126099<br>TELL:+966555411233','Jeddah','','SAUDI ARABIA','21352','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 10:48:18',0,NULL,3,1,25,1,'RT125215257HK ',' GPS0006'),(20042,914512031012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','sabpolicia77','sabpolicia@hotmail.com','Sérgio Avelino Branco Pinto','Rua do Rosmaninho lote 11 1ºEsquerdo<br>Porto Alto','Porto Alto','Samora Correia','PORTUGAL','2135-083','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 11:07:42',0,NULL,3,1,22,1,'BJ01669925 ','HSJA010 \r欧标'),(20043,825538081011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','hargushie','joelisnot@rogers.com','Joel Mandelbaum','7 Bishop Ave<br>Suite 506','Toronto','ON','CANADA','m2m 4j4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 11:36:29',0,NULL,3,1,11,1,'BJ01669924 ','HSNO007 '),(20044,825538829011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','simonskiii','simon.frampton@gmail.com','Simon Frampton','Octavia House, Interchange Business Park<br>Bostock\'s Lane, Sandiacre','Nottingham','Nottinghamshire','UNITED KINGDOM','NG10 5QG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 11:37:43',0,NULL,3,1,3,1,'RA184530215CN\r ','GLOT001 '),(20045,914551203012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','mr_vanilla_bean','railray@aei.ca','Andre Buchanan','1455 MacDonald','Saint-Laurent','QC','CANADA','h4l2a8','(514) 334-3906','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:19:37',0,NULL,3,1,3,1,'RA184530285CN\r ','GLOT001*2 '),(20046,825568614011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.98,'eastar4','jcel5427','gwarbaby1@hotmail.com','James Celaya','1212 Colonial Ave','Bloomington','IL','UNITED STATES','61701','(309) 310-2142','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 13:19:44',0,NULL,3,1,1,1,'LK175120937CN ','HP 5pin1.0 20cm  '),(20047,608652762003,130596581579,'New genuine LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',62.99,'cnfaner','ernandofilho','ernandojunior@gmail.com','Ernando Filho','Rua: 17 / Casa 1601','Fortaleza','Ceará','BRAZIL','60348270','85 8838-8595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:27:34',0,NULL,3,1,3,1,'RA184530250CN ','LGGL002 '),(20048,824509176002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','paul_dascalu','paul.dascalu@gmail.com','Paul-Ovidiu Dascalu','Sg. Maj. Samoila Dumitru, Nr. 5, Bl. 117, Sc. 1<br>Et. 3, Ap. 21, Sect.4','Bucuresti','Bucuresti','ROMANIA','041983','0744487252','PayPalPaymentInProcess','CheckoutComplete','CA_StandardInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,'RA184530127CN ','LGAD001 '),(20049,825566992011,320735039422,'New HP Media Center receiver+microsoft Remote Control',2,'OTHP006',41.8,'eastar4','rbrohman','r.brohman@rogers.com','Ryan Brohman','30 Charlotte Cres','Kitchener','ON','CANADA','N2B 2K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:15:50',0,NULL,3,1,3,1,'RA184530095CN\r ','OTHP006 '),(20050,914048637012,220825062356,'New 3.0 Bluetooth BCM92070 Module+cable Asus U80 N61',1,'BTAS3001',19.98,'eastar4','sehmetsvd','sehmet@xaker.ru','Valeriy Sizyakin','Matsestinskaya 5, kv. 55','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354024','+79528112221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:48:47',0,NULL,3,1,11,1,'BJ01669919 ','BTAS3001 \r3.0 ASUS 6pin 6CM  '),(20051,825589984011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT001',89.78,'eastar4','am0rph1s','lynx_fw@mail.ru','Andrey Lugovoy','Zoya and Alexander Kosmodemyanskih str. d. 14/10, kv. 74','Moscow','','RUSSIAN FEDERATION','125130','+7-926-879-5850 ','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 14:26:04',0,NULL,3,1,3,1,'RA184530351CN\r ','GLOT001 '),(20052,825038063011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',66.99,'eastar4uk','ibemagnus','dr.sparkyfabulos4uall@yahoo.com','Magnus Ibe','38 stalevarov<br>room 69','zaporozhye','zaporozhye','UKRAINE','69035','+380634195347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 14:39:35',0,NULL,3,1,21,1,' RA184531621CN','HSPH008\r欧标 '),(20053,610301883004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',13.99,'cnfaner','urnotsorry','calvin_616@hotmail.com','Calvin Cheng','27-5840 Dover Crescent','Richmond','BC','CANADA','V7C 5P4','(604) 312-8081','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 15:25:23',0,NULL,3,1,3,1,'RA184530161CN\r ','WLDE002 '),(20054,914603390012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','marco.lopes-2009','urbanux@pop.com.br','Ana Paula Lopes Silva','RUA 1040, QD 82, LT 2/4, N 285, APT 1303, RES. ROYAL PARK, SETOR PEDRO LUDOVICO','GOIANIA','GOIAS','BRAZIL','74823250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 15:31:22',0,NULL,3,1,11,1,'BJ01669917 ','BTAC2015 \racer 6pin1.25 23cm'),(20055,613990376004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','trainsplanesandautomobiles1','carobenem@aol.com','Mary Carobene','129 Bluebell Dr','Magnolia','DE','UNITED STATES','19962-9318','(302) 335-4515','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-11 15:32:46',0,NULL,3,1,1,1,'LK175762043CN\r ',NULL),(20056,820123116011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','dx89182','duoweixu@yahoo.com','Duowei Xu','4150 Murray Hill cres.','Mississauga','ON','CANADA','L5C 4H8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 15:22:47',0,NULL,3,1,11,1,'BJ01669923\r ','HSJA011 '),(20057,825616580011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',71.99,'eastar4','guydom62','guy.domain@hotmail.fr','guy domain','235rue de la chapelle','recques sur hem','Nord-Pas-de-Calais','FRANCE','62890','0321823434','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 15:42:12',0,NULL,3,1,3,1,'RA184530317CN\r ','GLSG001 '),(20058,608688798003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','tonyb29763','pamela.badkin@sky.com','Tony Badkin','157 Broomhill Avenue','Knottingley','West Yorkshire','UNITED KINGDOM','WF11 0DZ','01977678559','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 16:02:02',0,NULL,3,1,3,1,'RA184530201CN\r ','LGAD001 '),(20059,825630426011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','lokiduncan','robin.chiang@gmail.com','Robin Chiang','1880 Hollyhock Ln','Gilroy','CA','UNITED STATES','95020-7950','(408) 842-5566','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 16:12:51',0,NULL,3,1,1,1,'LK174091390CN\r ',NULL),(20060,608692839003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','30pp0666','belyaev_@mail.ru','Evgeny Belyaev','Generala Ermolova<br>14 kv 19','Moscow','Moscow','RUSSIAN FEDERATION','121170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 16:13:52',0,NULL,3,1,3,1,'RA184530087CN ','MOOE002\rOEM '),(20061,914629432012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*2',52.99,'eastar4uk','sbedi1122','sbedi@btclick.com','Sarabjit    Bedi','kjb electronics services ltd<br>218 Burges Road (T.V. Shop)','Eastham','London','UNITED KINGDOM','E6 2BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 16:30:06',0,NULL,3,1,3,1,'RA184530263CN\r ','GLOT001*2 '),(20062,825644557011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','kazybabe1','atkinhome123@btinternet.com','Karen Atkin','48 Clarendon Road<br>Little Canfield','Dunmow','Essex','UNITED KINGDOM','CM6 1GA','01279874891','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 16:45:13',0,NULL,3,1,3,1,'RA184530189CN ','LGAD001 '),(20063,824083337002,120841235348,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','smcknuck09','ataxiride@gmail.com','Ernest Thomas','1646 Maclean Rd','Jackson','MS','UNITED STATES','39209-9543','(601) 362-2000','PayPalPaymentInProcess','CheckoutComplete','CA_StandardInternational','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,NULL),(20064,614015837004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','zomby0723','zombory.tibor@gmail.com','Tibor Zombory','Árpád u. 16. 2/3','Tiszaújváros','','HUNGARY','3580','+36303826756','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 17:00:21',0,NULL,3,1,21,1,'RA184530144CN ','BALO007 '),(20065,825661416011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',2,'LGAD001',66.98,'eastar4uk','adrianajbs','adrian_maclaughlin@ajbs-ltd.com','Adrian MacLaughlin - AJ Business Solutions Ltd','Barn 2b, South Courtyard<br>Dunston Business Village','Dunston','Staffordshire','UNITED KINGDOM','ST18 9AB','01785711600','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 17:22:33',0,NULL,3,1,3,1,'RA184530175CN ','LGAD001 '),(20066,914669416012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','caffin123','jerome.caffin@wanadoo.fr','caffin jerome','9 rue des pierrelais','fontenay aux roses','Île-de-France','FRANCE','92260','0664767928','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 17:50:36',0,NULL,3,1,2,1,'30112091715\r ','WLAT009 '),(20067,914670772012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','denisa2892','denisa289@gmail.com','Denis Obychaiko','bulvar Dmitriya Donskogo, 12, 233','Moscow','','RUSSIAN FEDERATION','117216','8(963)978-44-03','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 17:52:57',0,NULL,3,1,3,1,'RA184530382CN\r ','UM00010 +UM00014\r一共买了一把象牙色的钢琴美女伞 和一把美女涂鸦伞 '),(20068,914671766012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','denisa2892','denisa289@gmail.com','Denis Obychaiko','bulvar Dmitriya Donskogo, 12, 233','Moscow','','RUSSIAN FEDERATION','117216','8(963)978-44-03','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 17:54:44',0,NULL,3,1,17,0,'RA184530382CN\r ',NULL),(20069,608124762003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.59,'cnfaner','entwash','jbrigham@e3ra.com','James Brigham','19392 128th Ave SE','Yelm','WA','UNITED STATES','98597','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-11 18:12:18',0,NULL,3,1,1,1,'LK178774805CN\r ',NULL),(20070,667963420013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','jorgejaques','jaquesferrao@sapo.pt','JORGE FERRÃO','Rua Combatentes do Ultramar nº5<br>FORTIOS','PORTALEGRE','PORTALEGRE','PORTUGAL','7300-690','00351962362522','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 18:43:47',0,NULL,3,1,21,1,'RA184530325CN\r ','GLOT001*4 '),(20071,771280158007,170746939505,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'au-buy','ecnav67','vancecrofoot@gmail.com','Vance Crofoot','1861 N Van Ness Ave<br>Apt 305','Los Angeles','CA','UNITED STATES','90028-5680','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(20072,825730728011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','astroulis','sdfmld@hotmail.com','Andrew Vikatos','Dragoumi 3','Patra','Patras','GREECE','26443','(0030) 2610425517','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 19:31:09',0,NULL,3,1,22,1,'BJ01669921 ',' 欧标\rHSSA003'),(20073,825751823011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','krazyrunner86','krazyrunner86@gmail.com','Ryan Brunner','2005 Parmenter Blvd<br>Apt 120','Royal Oak','MI','UNITED STATES','48073-4302','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 20:06:29',0,NULL,3,1,1,1,'LK179515189CN\r ',NULL),(20074,825756298011,320730928543,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',1,'MOLO010',134.99,'eastar4uk','radimprokes','orkan74@post.cz','Radim Prokeš','Pražská 2892','Havlíčkův Brod','výchozí','CZECH REPUBLIC','58001','(00420) 604232530','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 20:15:30',0,NULL,3,1,3,1,'RA184530334CN\r ','MOLO010 '),(20075,914764327012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','kjac4376','kdjacobson@gmail.com','Keith Jacobson','1641 W. Farragut Ave.','Chicago','IL','UNITED STATES','60640','(312) 533-4758','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 20:24:15',0,NULL,3,1,1,1,'LK180471145CN ','acer 8pin1.00 8cm  '),(20076,780884646001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'buysia','mystermatt15','mystermatt15@hotmail.com','Mathew C Bombardier','20 1/2 Lawrence Ave','Cornwall','ON','CANADA','K6h 4h2','(613) 577-5085','PayPalPaymentInProcess','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'已退款 '),(20077,914770573012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','juliuscesars','cesar_j_gonzalez@hotmail.com','cesar gonzalez','2231 NW 79th Ave<br>Ste PTY-3374','Doral','FL','UNITED STATES','33122-1618','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 20:35:23',0,NULL,3,1,1,1,'LK174184437CN ',NULL),(20078,614095750004,140676421848,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',71.99,'cnfaner','uzalordenes','uzalordenes@gmail.com','carlos martinez uzal','a cruz nº11,ardemil,ordes','a coruña','Galicia','SPAIN','15689','650667934','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 20:38:55',0,NULL,3,1,21,1,'RA184530348CN\r ','HSNO035 \r欧标\r\r'),(20079,825780537011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',44.89,'eastar4','olimpioa','olimpioa@uol.com.br','Olimpio de Melo Alvares Junior','Rua Gustav Hainz 196H','Cotia','SP','BRAZIL','06710765','11 82826059','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 20:55:36',0,NULL,3,1,3,1,'RA184530232CN\r ','GLOT001 '),(20080,668030608013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','lilmicky','michael.ermakov@gmail.com','Michael Ermakov','Nosovihinskoe shosse, dom 21, kv 98','Reutov-5','Moscow region','RUSSIAN FEDERATION','143965','+7 985 7 726 726','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 21:29:40',0,NULL,3,1,11,1,'BJ01669916 ','WLIN014 '),(20081,914805461012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','seba_g','sebastien@gaudel.fr','SEBASTIEN GAUDEL','8 RUE NEUVE','WINTZENHEIM','Alsace','FRANCE','68920','0687244607','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 21:35:24',0,NULL,3,1,3,1,'RA184530246CN ','GLSG001*2 '),(20082,914811578012,220769088331,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',2,'GLSG001*2',283.98,'eastar4','theadimac','bdubb010@yahoo.com','Brian Woods','PO Box 74','Forbestown','CA','UNITED STATES','95941-0074','(530) 370-3162','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 21:49:52',0,NULL,3,1,1,1,'LK180073554CN\r ',NULL),(20083,825814201011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','kpm18356','kpmatheson@yahoo.co.uk','kenneth matheson','35 mortonhall park crescent','edinburgh','Edinburgh (City of)','UNITED KINGDOM','eh17 8sy','07595158043','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 22:01:07',0,NULL,3,1,3,1,'RA184530294CN\r ','GLOT001 '),(20084,824752184002,120841176368,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',263.99,'buysia','wayne3600','wayneashman3600@msn.com','WAYNE ASHMAN','13 SPARROW CLOSE, SIBLE HEDINGHAM','HALSTEAD','Essex','UNITED KINGDOM','CO93JU','01787469482','PayPalPaymentInProcess','CheckoutComplete','CA_StandardInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'GLSG009*3 '),(20085,668059260013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','storani1973','storani@hotmail.com','José Clemente Schwartz Neto','Rua Padre Ildefonso Penalba, 90, Bl 2 Apto 604<br>Méier','Rio de Janeiro','Rio de Janeiro','BRAZIL','20775-020','55 92 88164863','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 22:59:09',0,NULL,3,1,3,1,'RA184530277CN\r ','GLOT001*2 '),(20086,668060630013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','storani1973','storani@hotmail.com','Fábio Storani de Oliveira','rua getulio, 29 casa 8 ou 10<br>Méier','rio de janeiro','Rio de Janeiro','BRAZIL','20775-000','+55 92088164863','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 23:07:51',0,NULL,3,1,3,1,'RA184530303CN\r ','GLOT001*2 '),(20087,771658196007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','einsteiny0','einsteiny@gmail.com','Wayne Steinhardt','PO Box 827, Springwood','Brisbane','Queensland','AUSTRALIA','4127','0422339591','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-11 23:22:37',0,NULL,3,1,11,1,'BJ01669918\r ','RELO002 '),(20088,825854257011,320691198675,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',14.8,'eastar4','t542974','sandbakk@gmail.com','Andree Sandbakk','General Fleischers gt. 50B','HARSTAD','','NORWAY','9405','+4790883233','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 23:41:33',0,NULL,3,1,22,1,'BJ01669927 ','OTHP005'),(20089,914856574012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','ejeyleo777','ejeyleo@yahoo.com','Syed Eitizaz','5 Ruskin Avenue<br>Rusholme','Manchester','Greater Manchester','UNITED KINGDOM','M14 4DP','07400444444','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 23:25:42',0,NULL,5,0,18,0,NULL,'客户要取消订单 \r已退款 '),(20090,608848601003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','henryie34','henryie34@yahoo.com','Simon Law','Atlassian<br>173-185 Sussex Street','Sydney','New South Wales','AUSTRALIA','2000','0422986923','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 00:16:05',0,NULL,3,1,3,1,'RA184530158CN\r ','HBPH009 '),(20091,913980734012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','swadd-master','b_harp@hotmail.co.uk','Christopher swaddling','62 Crawley Crescent<br>Hampden Park','Eastbourne','East Sussex','UNITED KINGDOM','BN22 9RN','01323503514','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 01:12:38',0,NULL,3,1,3,1,'RA184530073CN ','HSNO019+CCNO001 '),(20092,824752184002,120841176368,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',263.99,'buysia','wayne3600','wayneashman3600@msn.com','WAYNE ASHMAN','13 SPARROW CLOSE, SIBLE HEDINGHAM','HALSTEAD','Essex','UNITED KINGDOM','CO93JU','01787469482','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-12 01:57:51',0,NULL,3,1,4,1,'YW868898173CN ','GLSG009*3 '),(20093,824083337002,120841235348,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','smcknuck09','ataxiride@gmail.com','Ernest Thomas','1646 Maclean Rd','Jackson','MS','UNITED STATES','39209-9543','(601) 362-2000','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-12 01:57:53',0,NULL,3,1,1,1,'LK179432175CN\r ',NULL),(20094,824509176002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','paul_dascalu','paul.dascalu@gmail.com','Paul-Ovidiu Dascalu','Sg. Maj. Samoila Dumitru, Nr. 5, Bl. 117, Sc. 1<br>Et. 3, Ap. 21, Sect.4','Bucuresti','Bucuresti','ROMANIA','041983','0744487252','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-12 01:57:55',0,NULL,3,1,21,1,'RA184530127CN ','LGAD001 '),(20095,780884646001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'buysia','mystermatt15','mystermatt15@hotmail.com','Mathew C Bombardier','20 1/2 Lawrence Ave','Cornwall','ON','CANADA','K6h 4h2','(613) 577-5085','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-01-12 01:57:56',0,NULL,5,0,18,0,' ',NULL),(20096,914907681012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','aquagirl626','iich714@yahoo.com','Martha Gross','610 Hawks Bill Pl','Simi Valley','CA','UNITED STATES','93065-7040','(805) 584-2170','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 02:05:46',0,NULL,3,1,1,1,'LK177021605CN ',NULL),(20097,825898331011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.39,'eastar4','bdashley','briandashley0@gmail.com','Brian Ashley','Box 14<br>10 MEADOWVIEW DRIVE','Stewiacke','NS','CANADA','b0n2j0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 02:11:35',0,NULL,3,1,2,1,'30112095403\r ','BTAC2116 \racer 6pin1.25 23cm '),(20098,914927748012,220901458596,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',6.99,'eastar4uk','fm.wuppertal','fm-wuppertal@gmx.de','Frank Müller','Langobardenstr. 17','Wuppertal','','GERMANY','42277','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 03:04:31',0,NULL,3,1,11,1,'BJ01669920\r ','BALO001 '),(20099,825920776011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','balicity','greyareaisme@yahoo.com','Grey Manlin','Jl. Tepekong 2 no.71 RT012 - RW011<br>Kebayoran Lama - 08170809966','Jakarta Selatan','DKI Jakarta','INDONESIA','12220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 03:30:59',0,NULL,3,1,2,1,'\\ ','ANCN001 '),(20100,825917791011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',21.9,'eastar4','sharlinda.yusof','sharlindayusof@gmail.com','Sharlinda Yusof','No 2-5-11, Putra Intan Condo','Dengkil','Selangor','MALAYSIA','43800','0136377226','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 03:32:34',0,NULL,3,1,2,1,'\\ ',NULL),(20101,8881326341370071,111,'2.1 Acer Aspire 5100 5110 3100 Bluetooth Module+cable',1,'BTAC2122',0,'eastar4','kaoss6911','mattykaoss@gmail.com','Vicki McKee','Second Foundation<br>45 Washburn Drive','Kitchener','ON','CANADA','N2R 1S1','(226) 989-0972',NULL,NULL,NULL,'2012-01-12 04:09:30',0,NULL,3,1,2,1,'30112187663\r ','客户没收到  补发的 \racer 8pin1.00 8cm'),(20102,668126454013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',3,'CACN004',38.82,'eastar4','pommylump','nick@crane.id.au','Nick Crane','Macworx  Joondalup<br>10/7 Delage St','Joondalup','Western Australia','AUSTRALIA','6027','0893015333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 04:12:21',0,NULL,3,1,11,1,'BJ01669913\r ','CACN004 '),(20103,825940462011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','davisdy3chen','dy3chen@yahoo.com','Davis Chen','23120 SE Black Nugget Rd<br>Unit U1','Issaquah','WA','UNITED STATES','98029-7325','(425) 557-2082','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-12 05:00:54',0,NULL,3,1,1,1,'LK177059932CN\r ',NULL),(20104,668136616013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',2,'HSSA002',31.8,'eastar4','mononcle911','mononcle911@sympatico.ca','daniel masse','950 36e rue app 5','laval ouest','QC','CANADA','H7R 2C5','(514) 234-4011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 05:08:46',0,NULL,3,1,11,1,'BJ01669914\r ','HSSA002 '),(20105,914965017012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','miguelcaldas','miguel.caldas@microsoft.com','Miguel Caldas','Rua. Prof. Cavaco Silva<br>Ed. Qualidade C1','Porto Salvo','','PORTUGAL','2744-010','+351 961624201','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 05:36:59',0,NULL,3,1,22,1,'BJ01669910\r ','WLIN014 '),(20106,608912152003,130458926995,'New Ultimate Ears METRO.FI 220vi UE 220VI voice track#',1,'HSUE003',20.99,'cnfaner','vladimirz1962','zvladimir1962@gmail.com','Vladimir Zaikin','Plehanova 87-80','Ussuriysk','Primorskyj kray','RUSSIAN FEDERATION','692519','(4234)336672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 06:16:50',0,NULL,3,1,3,1,'RA184530365CN\r ','HSUE003 '),(20107,825969164011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','markandjill123','wickedmetalgear@netspace.net.au','mark miller','14 singer place','ingleburn','New South Wales','AUSTRALIA','2565','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 07:38:11',0,NULL,3,1,3,1,'RA184530422CN\r ','GLOT001 '),(20108,8881326354132939,111,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',0,'eastar4','brummiee','ebay@hines.at','Peter R. Hines','Eichenstraße 18','Unna','','GERMANY','59423','',NULL,NULL,NULL,'2012-01-12 07:42:12',0,NULL,3,1,2,1,'\\ ','补发的 \r欧标'),(20109,613620536004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','kajjak33','janko.kandric@gmail.com','HYPHEN GMBH','Neureutherstrasse 26','MUNCHEN','','GERMANY','80799','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 07:42:21',0,NULL,3,1,21,1,'RA184530379CN\r ','BALO007 '),(20110,763758521008,180789713918,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',27.99,'au-buy','the0ne7','chenglou@hotmail.com','Cheng Lou','10/209 Penshurst Street','Beverly Hills','New South Wales','AUSTRALIA','2209','0295336686','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-12 08:22:46',0,NULL,3,1,11,1,'BJ01669911\r ',NULL),(20111,614235817004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','wanderer7814','camyshpay@gmail.com','Dziarhun Vadzim','Katunina street, 24/44','Gomel','','BELARUS','246052','375447247241','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 08:31:40',0,NULL,3,1,21,1,'RA184530507CN','BALO007 '),(20112,668166479013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','foagra2you','foagra@hotmail.com','Takayuki Unno','uchimaki993','Shizuoka City','Shizuoka','JAPAN','421-2118','090-3935-7662','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 08:54:01',0,NULL,3,1,3,1,'RA184530436CN\r ','GLOT001*2 '),(20113,614246096004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','plannet3739','ebay3739@plan-net.lu','Plan-Net SA','8 rue des Martyrs','Rumelange','','LUXEMBOURG','3739','+35226560222','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 09:34:33',0,NULL,3,1,21,1,'RA184530419CN\r\r ','RELO003 '),(20114,914853631012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','partmastermarion','jimmygatsos@hotmail.com','JIMMY GATSOS','Level 3, 100 Chalmers st<br>Surry Hills','sydney','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 09:37:04',0,NULL,3,1,11,1,'BJ01669901\r ','MOMI002 \r黑色的'),(20115,825997607011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',38.99,'eastar4uk','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 09:51:30',0,NULL,3,1,3,1,'RA184530864CN ','LGGL002\r贴确认签 '),(20116,825998771011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','heatherstokes','hstokes434@gmail.com','Heather Stokes','Hanchurch Christian Centre<br>Hanchurch','Stoke on Trent','Staffs','UNITED KINGDOM','ST4 8RY','01782642000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 09:56:32',0,NULL,3,1,3,1,'RA184530538CN\r ','LGAD001 '),(20117,668193458013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','big.freddy80','chris.clarke@internode.on.net','Chris Clarke','60 Galway Ave','Broadview','South Australia','AUSTRALIA','5083','0883444821','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 11:32:57',0,NULL,3,1,11,1,'BJ01669894 ','WLAP008 '),(20118,771826763007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','engine_ad_oz','engine_ad_oz@hotmail.com','Adam Smith','Ford Research<br>North Shore Road','Norlane','Victoria','AUSTRALIA','3214','0407652353','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-12 11:31:33',0,NULL,3,1,11,1,'BJ01669891 ','RELO002 '),(20119,915060358012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','brett0004','marshallmail@bigpond.com','Brett Marshall','935 Minha Street','Tom Price','Western Australia','AUSTRALIA','6751','0407441594','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 12:19:59',0,NULL,3,1,3,1,'RA184530935CN ','GLOT001 '),(20120,826037519011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','mushuntgrrumble','wilso20@hotmail.com','Michael Wilson','2 Charlecote Grange<br>Galileo Gardens','Cheltenham','Gloucestershire','UNITED KINGDOM','GL510GA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 12:25:05',0,NULL,3,1,3,1,'RA184530609CN\r ','LGAD001 '),(20121,826043646011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','leytherp','leytherpete@fsmail.net','peter hardman','42 pennine grove','leigh','Lancashire','UNITED KINGDOM','WN75HU','07814251415','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 12:46:17',0,NULL,3,1,3,1,'RA184530467CN\r ','LGAD001 '),(20122,826048208011,320781439714,'New SAMSUNG WEP300 Bluetooth Headset WEP 300',2,'HSSA004',31.98,'eastar4','autotechnew','autotechacc@gmail.com','peter frangos','n.plastira 33','likovrissi','athens','GREECE','14123','2102832767','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 13:08:40',0,NULL,5,1,18,1,NULL,'HSSA004\r欧标 \r没有货了   给客户退钱了'),(20123,914211189012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','kristina_pavlova','kristina_reklama@mail.ru','Pavlova Kristina','197 Stachki Ave., apt. 58','Rostov-on-Don','Russian Federation','RUSSIAN FEDERATION','344058','+79081822887','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 13:42:10',0,NULL,3,1,11,1,'BJ01669877 ','UM00008 '),(20124,668219159013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','gthv2005','ventura.valderrabano@gmail.com','Ventura Valderrábano Ornedo','Pg San Jerónimo, Prc. 17','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','670805808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 13:42:26',0,NULL,3,1,2,1,'30112243965\r ',NULL),(20125,826068460011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','hutzenlutz','up@store-multimedia.de','Uwe Peise','Amselweg 9','Sprockhövel','','GERMANY','45549','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 14:05:01',0,NULL,3,1,21,1,'RA184530498CN\r ','LGAD001 '),(20126,826072829011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','nickmulligan','nick_mulligan@hotmail.com','Nick Mulligan','58 Frederick Street','Dundee','Dundee (City of)','UNITED KINGDOM','dd3 9df','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 14:19:12',0,NULL,3,1,3,1,'RA184530524CN\r ','LGAD001 '),(20127,826081322011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','batruk73','onesb@rambler.ru','Сергей Батруков','ул. Планерная, дом 52, кв.61','Орел','','RUSSIAN FEDERATION','302042','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 14:51:01',0,NULL,3,1,3,1,'RA184530878CN ','GLOT001 '),(20128,608733911003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.59,'cnfaner','foosmaster1000','jwinter1000@gmail.com','jason winter','688 Humbert St','Folsom','CA','UNITED STATES','95630-5452','(916) 768-9999','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-12 14:56:38',0,NULL,3,1,1,1,'LK179717932CN ',NULL),(20129,915122543012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',26.99,'eastar4uk','vr_zhorzh','vr_zhorzh@inbox.lv','Jevgenijs Koskejevs','84 shortlands road','Sittingbourne','Kent','UNITED KINGDOM','me103ju','07846982840','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 15:16:20',0,NULL,3,1,3,1,'RA184530881CN ','GLOT001 '),(20130,915132986012,220448689432,'Acer Aspire 4730Z 4930Z Bluetooth Module EDR 2.0+cable',1,'BTAC2019',9.88,'eastar4','htbtofam','htbtofam@aol.com','John Polan','889 Mildred Ave','Baltimore','MD','UNITED STATES','21222','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 15:41:25',0,NULL,3,1,1,1,'LK181274521CN ','acer 8pin1.00 6cm  '),(20131,826106073011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','keedo13','imperialsports@videotron.ca','Scott Dorfman','18674 Poitiers','Pierrefonds','QC','CANADA','H9K1P8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 15:51:52',0,NULL,3,1,2,1,'30112251400\r ','HBPH009 '),(20132,668255691013,230729621562,'Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n  BlueToo',1,'ANTY002',3.99,'eastar4','viper780','daniel.eggerstorfer@gmail.com','Daniel Eggerstorfer','Salierigasse 34/8','Wien','','AUSTRIA','1180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 15:59:21',0,NULL,3,1,22,1,'BJ01669895 ','ANTY002 '),(20133,826114152011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','hekki_hekki','hekkite@yahoo.co.uk','Aneta Juszczak','52 High Street Chesterton','Cambridge','Cambridgeshire','UNITED KINGDOM','CB4 1NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 16:12:54',0,NULL,3,1,3,1,'RA184530759CN ','MOAP001 '),(20134,826124372011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','simonliv','simonliv@blueyonder.co.uk','Simon Lively','132 warren wood road','rochester','Kent','UNITED KINGDOM','me1 2uj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 16:35:49',0,NULL,3,1,3,1,'RA184530515CN\r ',' LGAD001'),(20135,763910302008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','tomvilmer','tom@porten.dk','Tom pp Paamand','Sportsvej 30C','Bryrup','Jylland','DENMARK','DK-8654','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-12 17:01:44',0,NULL,3,1,22,1,'BJ01669878 ','BALO009 '),(20136,668279383013,230614780239,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.99,'eastar4','clarinetdude','email@davidclarinette.com','David Groulx','Northern College Residence Rm 301<br>PO Box 3211','Timmins','ON','CANADA','P4N 8R6','(705) 477-2573','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:15:26',0,NULL,3,1,2,1,'30112247830\r ','WLIN013 '),(20137,614342165004,140667903666,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Antenna *3',1,'WLAT001+ANTY002',15.89,'cnfaner','heinrich-der-8te','b.rawe@arcor.de','Bernhard  Rawe','Rodenbecker Str. 100','Minden','','GERMANY','32427','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:03:56',0,NULL,3,1,21,1,'RA184530966CN ','WLAT001+ANTY002 '),(20138,609044672003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.49,'cnfaner','kpecteg','krest123@hotmail.com','Вадим Ерохов','Лесной проспект дом 19 квартира 31','Петрозаводск','Республика Карелия','RUSSIAN FEDERATION','185014','79095680556','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:30:03',0,NULL,3,1,3,1,'RA184530674CN ','MOMI002 '),(20139,614351432004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','blaning305','gp305bl@gmail.com','Meisel - Betsy Laning','2019 McKenzie Dr','Carrollton','TX','UNITED STATES','75006-8345','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-12 17:30:48',0,NULL,3,1,1,1,'LK179912097CN ',NULL),(20140,614324885004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','clarion905','dima.vlad@yahoo.com','Vlad Dima','str.Grigore Gafencu,78-84,vila E2,sec.1<br>CNP 1830201450029','Bucuresti','Bucharest','ROMANIA','014132','0040724786597','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:54:26',0,NULL,3,1,21,1,'RA184530918CN ','MOOE001 \rOEM'),(20141,609079931003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','rag327','rcbeilfuss@msn.com','Richard Beilfuss','2517 E Espada Trl','Casa Grande','AZ','UNITED STATES','85194-8571','(231) 750-6785','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-12 19:08:41',0,NULL,3,1,1,1,'LK179986979CN ','OEM '),(20142,668328156013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','bbra4464','clarson@gondtc.com','Brad Larson','208 15th Avenue NE','Devils Lake','ND','UNITED STATES','58301','(701) 662-3032','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 19:20:43',0,NULL,3,1,1,1,'LK180584751CN ',' naterbrad'),(20143,668333527013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','fidrili10mux','fidrili1@hotmail.com','Vassilios Fidrilis','1173 Emerson Crescent','Laval','QC','CANADA','H7W 1H6','(450) 688-3161','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 19:35:15',0,NULL,3,1,3,1,'RA184530952CN ','GLOT001*3 '),(20144,826231001011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','2007allanj','jonesycont@hotmail.co.uk','allan jones','bryn menai<br>belmont road','bangor','Gwynedd','UNITED KINGDOM','ll572ll','01248353379','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 20:00:40',0,NULL,3,1,3,1,'RA184530484CN\r ','LGAD001 '),(20145,826232202011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','admfspb','admf.spb@gmail.com','Sergei Raituzov',' ul. Puteshestvenika Kozlova,dom 12, kv. 40','Saint-Petersburg','Petrodvorzovi raion','RUSSIAN FEDERATION','198510','79219262711','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 20:01:42',0,NULL,3,1,11,1,'BJ01669888 ','BTAC2006 \racer 4pin1.25 15cm '),(20146,826233730011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','mjtilta','mj.tarkiainen@gmail.com','Mikko Tarkiainen','Karkonmäenkatu 7b','Tampere','','FINLAND','33580','+358405399384','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 20:04:36',0,NULL,3,1,21,1,'RA184530949CN ','GLOT001 '),(20147,614416823004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','duckfeet55','dee.cee@live.co.uk','Deborah Carpenter','9 forest way','mildenhall','Suffolk','UNITED KINGDOM','ip28 7ld','01638711648','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 20:30:56',0,NULL,3,1,3,1,'RA184530731CN ','HBPH007 '),(20148,826254764011,320730088581,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',33.9,'eastar4uk','ksul1020','krychus@wp.pl','KRZYSZTOF SULEJ','KOPERNIKA  31 / 6','GLIWICE','śląskie','POLAND','44-117','48 5042963','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 20:38:50',0,NULL,3,1,21,1,'RA184531003CN ','ANWI001 '),(20149,772058558007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'au-buy','carlsen79','sgcarlsen@gmail.com','Svein Gisle Carlsen','Professor Dahls Gate 16','Oslo','Oslo','NORWAY','0355','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-12 20:50:16',0,NULL,3,1,22,1,'BJ01669892 ','HSUE003 '),(20150,826266763011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','pucmeloun1','jirkasykora@klikni.cz','Jiri Sykora','Sokolovska 425','Cesky Brod','','CZECH REPUBLIC','28201','00420724061784','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 21:04:01',0,NULL,3,1,11,1,'BJ01669893 ','WLDE002 '),(20151,826273616011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','baldheadedthug','baldheadedthug@yahoo.com','robert claydon','29 retford close<br>harold hill','romford','Essex','UNITED KINGDOM','rm39na','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 21:14:56',0,NULL,3,1,3,1,'RA184530475CN\r ','LGAD001 '),(20152,609134718003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','nenuquin2vicente','nenuquin2@gmail.com','vicente sanchis tolosa','Crta.de Madrid nº63','Llanera de Ranes','Comunidad Valenciana','SPAIN','46814','692690626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 21:29:51',0,NULL,3,1,21,1,'RA184530970CN ','MOOE003\rOEM '),(20153,826295603011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','testerjd','testerj@mail.com','John Tester','1 James Street','Balhannah','South Australia','AUSTRALIA','5242','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 21:56:59',0,NULL,3,1,11,1,'RA184530665CN ','HSJA002 \r澳标'),(20154,826297382011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','ravintrucker','chris.perry67@hotmail.co.uk','chris perry','35 warner place','loughborough','Leicestershire','UNITED KINGDOM','le111sj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 22:01:03',0,NULL,3,1,3,1,'RA184530555CN\r ','LGAD001 '),(20155,914269453012,220815927515,'10 pcs AUI Ethernet 10Base-T RJ45 CentreCOM 210TS',2,'TRTS001*10',101.98,'eastar4uk','bethwhale','balti@comcast.net','Diamond Communications','11706 Garrison Forest Rd','Owings Mills','MD','UNITED STATES','21117-2214','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 22:08:23',0,NULL,3,1,20,0,' 9101785091401466112983',' '),(20156,826314967011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',33.49,'eastar4uk','mkrobinson2010','mk_tiger@hotmail.co.uk','makala robinson','38 holland rise hse<br>clapham rd','london','London','UNITED KINGDOM','sw90hs','07508048828','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 22:42:32',0,NULL,3,1,3,1,'RA184530541CN\r ','LGAD001 '),(20157,668405298013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','twin.818','patricia_desantiago@yahoo.com','PATRICIA  DE SANTIAGO','443 Sanpan Ln','LAKE HAVASU CITY','AZ','UNITED STATES','86403-4951','(928) 412-7111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 22:48:30',0,NULL,3,1,1,1,'LK178761135CN ',NULL),(20158,915368757012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','globalspan2012','globalispan@gmail.com','Henrietta Ricks','10866 Wilshire Blvd<br>Ste 1400','Los Angeles','CA','UNITED STATES','90024-4338','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 22:57:39',0,NULL,3,1,1,1,'LK179093295CN ',NULL),(20159,915371274012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Kate Walsh','37 Barnard Rd','Osterville','MA','UNITED STATES','02655-2202','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 23:03:39',0,NULL,3,1,1,1,'LK178362416CN ',NULL),(20160,668420225013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',29.97,'eastar4','davidj226554','dj33ebay@exemail.com.au','David Jackson','13/153 Narara Valley Drive','Narara','New South Wales','AUSTRALIA','2250','0243291370','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:44:40',0,NULL,3,1,11,1,'BJ01669882 ','CASS001 '),(20161,826339555011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','furious-unlocker','crazymobilez@live.co.uk','muhibur rahman','375 RODING LANE NORTH<br>WOODFORD GREEN','ESSEX','Essex','UNITED KINGDOM','IG88LH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 23:52:48',0,NULL,3,1,3,1,'RA184530895CN ','TRSN001 '),(20162,826345917011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','petertiernan','tiernan.peter@gmail.com','Peter Tiernan','Ballindooley','Galway','','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 00:17:50',0,NULL,3,1,22,1,'BJ01669890 ','WLAT003 '),(20163,915390776012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Patricia Briden','900 Douglas Pike<br>Honeywell Safety Products','Smithfield','RI','UNITED STATES','02917-1879','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 23:58:07',0,NULL,3,1,1,1,'LK177383091CN ',NULL),(20164,826369764011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ck6835','rbbcc2@peoplepc.com','robert cook','450 e bluff dr','port angeles','WA','UNITED STATES','98362-9192','(253) 235-2760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 01:35:03',0,NULL,3,1,1,1,'LK179416795CN ',NULL),(20165,609196082003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','jab_joe','si12volt1@cox.net','Alfred Gray','130 Avenida De La Grulla<br>Apt A','San Clemente','CA','UNITED STATES','92672-9110','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-13 01:38:58',0,NULL,3,1,1,1,'LK180270395CN ',NULL),(20166,609195856003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','patricefortin','patricefortinmtl@gmail.com','Patrice Fortin','6620 Booker','Brossard','QC','CANADA','J4Z3S1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 01:39:39',0,NULL,3,1,3,1,'RA184530745CN ','CRLO001+POLO001 '),(20167,915414249012,220915102581,'NIB Sharp AN-3DG20-B 3D USB Rechargeable Glasses use with Sharp AQUOS LCD TVs',1,'SPGL001',119,'eastar4','dannunzio81','wog_81@hotmail.com','Daniel DAnnunzio','24 caribbean place<br>mt.colah','sydney','New South Wales','AUSTRALIA','2079','0294578645','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 01:41:20',0,NULL,3,1,3,1,'RA184530904CN ','SPGL001 '),(20168,8881326421791762,111,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking TK103-2',1,'GPS0008',111.99,'eastar4','jspisak2011','dieliving@hotmail.ca','joel spisak','#105 3521 carrington rd.','west kelowna,','BC','CANADA','v4t 2z8','(250) 899-3299 ',NULL,NULL,NULL,'2012-01-13 02:29:51',0,NULL,3,1,3,1,'RA184530997CN ','GPS0008\r客户直接打得款 '),(20169,668457775013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','famous0429','famous429@gmail.com','JL Hall','179 Waxberry Ct','Boiling Springs','SC','UNITED STATES','29316-9617','(864) 906-7005','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 02:32:40',0,NULL,3,1,1,1,'LK179875791CN ',NULL),(20170,915441852012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Brad Sanders','1307 Prairie St','Conway','AR','UNITED STATES','72034-5344','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 02:39:04',0,NULL,3,1,1,1,'LK176816105CN ',NULL),(20171,915449734012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','viluu123','vituongluu@optusnet.com.au','Dac Luu','66 Glengala Road','Sunshine west','Victoria','AUSTRALIA','3020','0393116085','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 03:05:38',0,NULL,3,1,3,1,'RA184530921CN ','GLOT001*2 '),(20172,8881326428433248,111,'Acer Aspire One 751 AO751h Bluetooth Module EDR 2.0',1,'BTAC2014',0,'eastar4','sharanvlad','vlad.sharanhovich@gmail.com','Uladzislau Sharanhovich','3628 Warner Dr','San Jose','CA','UNITED STATES','95127-4440','(408) 480-7493',NULL,NULL,NULL,'2012-01-13 04:20:33',0,NULL,3,1,1,1,'LK030760654CN ','只补发一个模块 \rLK030760654CN'),(20173,668487704013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','ly_alot','simpson_91204@yahoo.com','Carolyn Ly','727 Patterson Ave','Glendale','CA','UNITED STATES','91202-2161','(818) 246-5755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 05:15:16',0,NULL,3,1,1,1,'LK181570229CN\r ',NULL),(20174,826429959011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','javed2588','javedth@hotmail.com','malik javed iqbal','kita ku tarodai 776-22','Niigata  city','Niigata','JAPAN','950-3101','0252552533','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 05:58:17',0,NULL,3,1,3,1,'RA184530983CN ','GPS0007 '),(20175,668494621013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','petr1923','pvg@it4navi.cz','Petr Vagera','Prazska 1','Braskov-Toskanka','','CZECH REPUBLIC','27351','+420777087140','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 05:59:02',0,NULL,3,1,11,1,'BJ01669885 ','HSNO023 '),(20176,915495248012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ackermaj','jeff.ackermann@yahoo.com','Jeffrey Ackermann','229 1/2 35th St','Manhattan Beach','CA','UNITED STATES','90266','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 06:16:41',0,NULL,3,1,1,1,'LK175180065CN ',NULL),(20177,826449015011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','andrey_bayer','andykz@mail.ru','Andrey Vassilyev','Svobodnaya, 23','Petropavlovsk','SKO','KAZAKHSTAN','150000','8 (7152) 52-38-70','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 07:33:59',0,NULL,3,1,3,1,'RA184530728CN ','OTES001 '),(20178,824995179011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',96.99,'eastar4uk','kisszoli','kisszoli0707@freemail.hu','Zoltán Kiss','Kőrösi Csoma Sándor utca 2.','Kunszentmárton','alapértelmezés','HUNGARY','5440','+36706273609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 08:19:15',0,NULL,3,1,21,1,'RA184530714CN ','GLOT005*3 '),(20179,915532842012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',2,'MOMI002',17.98,'eastar4uk','olofbailey','richard.bailey@techex.co.uk','Techex Limited','2 The Braccans<br>London Road','Bracknell','Berkshire','UNITED KINGDOM','RG12 2XH','03300882787','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 09:14:46',0,NULL,3,1,3,1,'RA184530802CN ','MOMI002 \r黑色'),(20180,826476845011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','benkin88','auztraveler@hotmail.com','errol thomas','30A loffs road<br>jamboree heights','brisbane','Queensland','AUSTRALIA','4074','0732797056','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 09:39:47',0,NULL,3,1,11,1,'BJ01669886 ','HBPH003\r一共买了两个 \r澳标'),(20181,826478436011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','martinepittaway','martinpittaway@mac.com','Martin Pittaway','6 Hawthorn Close<br>Little Paxton','St Neots','Cambridgeshire','UNITED KINGDOM','PE19 6QQ','07717896871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 09:45:35',0,NULL,3,1,3,1,' RA184531595CN','MOAP001 '),(20182,826477238011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','benkin88','auztraveler@hotmail.com','errol thomas','30A loffs road<br>jamboree heights','brisbane','Queensland','AUSTRALIA','4074','0732797056','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 09:41:05',0,NULL,8,1,17,0,NULL,NULL),(20183,826488103011,320730083345,'10 bulk AUI Ethernet 10Base-T 210T Transceiver RJ45',1,'TRTT002*10',50.99,'eastar4uk','simplac','simplac.tecno@gmail.com','SIMPLAC, Lda. NIF Nº PT508705908 Tecnologia Mecânica','Rua dos 5 Caminhos Lote nº13<br>Zona Industrial do Freixieiro','Santo Tirso','Santo Tirso','PORTUGAL','4780-382','939637801','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 10:25:19',0,NULL,3,1,21,1,' RA184531564CN','TRTT002*10 '),(20184,826501255011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','vipshopper88','rowenyap@gmail.com','Rowen Yap','58  Pollard  St<br>Unit 5','Glendalough','Western Australia','AUSTRALIA','6016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 11:17:24',0,NULL,3,1,11,1,NULL,'澳标\rHSJA002 '),(20185,614587122004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',19.95,'cnfaner','strinadkin','astru61@gmail.com','Aleksandr Strinadkin','Gastello Street, 27b -80','Kopeisk','Chelyabinsk','RUSSIAN FEDERATION','456620','(912)793-8780','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 11:17:37',0,NULL,3,1,3,1,' RA184531431CN','WLAP002 '),(20186,826502593011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','heeby-jeeby','jon_laughton@mac.com','Jon Laughton','35 Warwick Terrace<br>East Street','Olney','Buckinghamshire','UNITED KINGDOM','MK46 4BU','07775935422','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 11:20:47',0,NULL,3,1,3,1,' RA184531153CN','MOAP001 '),(20187,614597612004,140671481128,'New Genious LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack)',1,'LGGL005',19.59,'cnfaner','davebar89','dands.barnard@talktalk.net','david barnard','19 Valkyrie Avenue','Whitstable','Kent','UNITED KINGDOM','CT5 4DL','01227264847','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 12:12:36',0,NULL,3,1,3,1,' RA184531391CN','LGGL005 '),(20188,826523589011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','xtrimal','xtrimal@gmail.com','Vladimir Khalamovskiy','Butlerova 40/124','Sankt-Peterburg','Sankt-Peterburg','RUSSIAN FEDERATION','195220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 12:38:36',0,NULL,3,1,11,1,NULL,' ANCN001'),(20189,614607286004,140626375805,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',6.3,'cnfaner','taejnik','ferninio@list.ru','Andrey Tseboev','ul. Volynskaya, d. 8, kv. 170','Moscow','','RUSSIAN FEDERATION','119620','+7-910-448-54-08','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 12:59:56',0,NULL,3,1,3,1,' RA184531520CN','MOFP001 '),(20190,668565770013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','pyotri','alexander565@mail.ru','Aleksandr Artemenok','Savushkina 118; ap.218','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','197374','+7(921)9462428','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 13:06:54',0,NULL,3,1,11,1,NULL,'WLIN014 '),(20191,826541008011,320554375061,'2.1 Bluetooth Module cablefor DELL mini 10 10v1010 1011',1,'BTDE2102',12.39,'eastar4','jdk_1967','jkeightley@gmail.com','John Keightley','101A Hampton Road','Hampton Hill','Middlesex','UNITED KINGDOM','TW12 1JQ','02089431455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 13:29:25',0,NULL,3,1,2,1,'30112630284\r ',NULL),(20192,614611709004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','kp-pd','yavnick@gmail.com','4Nicholas Yavtsev','43 Mitchell st','Glebe','New South Wales','AUSTRALIA','2037','0296603449','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 13:26:06',0,NULL,3,1,3,1,'RA184531547CN','HSNO005\r澳标 '),(20193,915616597012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','kingsales2000','r_chami80@hotmail.com','Richard Chami','34 Mandoo Drive','Doonside','New South Wales','AUSTRALIA','2767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 13:49:19',0,NULL,3,1,11,1,NULL,'HSNO005\r澳标 '),(20194,915616564012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','lechucksky','lechucks@gmail.com','jose maria calvillo gallardo','marques del nervion 24 2ºa','sevilla','Sevilla','SPAIN','41005','954582022','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 13:50:56',0,NULL,3,1,2,1,'30112636934\r ',NULL),(20195,614619460004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','protech441','protechinspsvs@yahoo.com','William H Prough','5707 E 122nd St','Perkins','OK','UNITED STATES','74059-3755','(918) 223-6418','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-13 13:56:26',0,NULL,3,1,1,1,' LK172585826CN',NULL),(20196,668591432013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','mrenglishman','constantinose@gmail.com','Konstantinos Englezos','101 N Dithridge St<br>Apt 1007','Pittsburgh','PA','UNITED STATES','15213-2653','412 979 2820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 14:38:56',0,NULL,3,1,1,1,' LK182338665CN',NULL),(20197,825470506002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',15.98,'buysia','katlws69','katlewis69@yahoo.com','Kathy Moore','1208 N Tower Ave','Centralia','WA','UNITED STATES','98531-5046','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 14:49:24',0,NULL,3,1,1,1,' LK179903841CN',NULL),(20198,614635136004,140675756643,'3 pairs of New 3D Active Shutter TV Glasses Compatible for  Samsung SSG -2200AR',1,'GLOT001*3',131.99,'cnfaner','sandram9450','distasio@snet.net','Sandra DiStasio','9 Halsey Dr','Wallingford','CT','UNITED STATES','06492-5313','(203) 915-4183','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-13 15:00:21',0,NULL,3,1,1,1,' LK180766224CN',NULL),(20199,915652149012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','sgad2469','sgadeau@libertysurf.fr','Stephane Gadeau','27 rue des bleuets','la chapelle la reine','Ile-de-France','FRANCE','77760','0631439354','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 15:22:19',0,NULL,3,1,2,1,'30112642792\r ',NULL),(20200,826602954011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.39,'eastar4','gamecockfreak','reggievjames@gmail.com','reggie james','1285 kings pointe drive','sumter','SC','UNITED STATES','29154','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 16:13:21',0,NULL,3,1,1,1,' LK176623520CN','acer 4pin1.25 6cm '),(20201,826614915011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','arrymartin','martin-rimmer@lineone.net','MARTIN RIMMER','54 Elswick Road','Southport','Merseyside','UNITED KINGDOM','PR9 9NR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 16:38:37',0,NULL,3,1,2,1,'30112640235\r ',NULL),(20202,915716045012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','methosthebest','methos@b1tv.ro','piscati ion','aleea vergului 4 bl.15 sc.A et.10 ap.40<br>sector2 interfon 50','bucharest','bucharest','ROMANIA','7000','0040723551536','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 17:26:28',0,NULL,3,1,22,1,NULL,'WLDE002 '),(20203,915724916012,220763389064,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61+antenna',3,'WWSI002+ANCN001',62.97,'eastar4uk','max044fr','al.lombard@free.fr','A.LOMBARD ALTRONICS','8 rue de la grange','LYON','Rhône-Alpes','FRANCE','69009','0826626909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 17:43:31',0,NULL,3,1,3,1,' RA184531140CN','WWSI002+ANCN001 '),(20204,915724926012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','tompirlet','tompirlet@hotmail.com','Tom Pirlet','Kerkstraat 330','Blankenberge','','BELGIUM','8370','0486981061','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 17:43:38',0,NULL,3,1,22,1,NULL,'WLDE002 '),(20205,614688797004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','kipperafc','p-markham@sky.com','Mr Paul Markham','10 Iris Close<br>Burbage','Hinckley','Leicestershire','UNITED KINGDOM','LE10 2QU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 17:55:22',0,NULL,3,1,3,1,'RA184531555CN ','HSNO005\r英标 '),(20206,614701144004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.8,'cnfaner','yerkanian','vahan@yerkanian.com','Vahan Yerkanyan','32/9 Babayan st.','Yerevan','','ARMENIA','0037','+37455650413','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 18:29:38',0,NULL,3,1,21,1,' RA184531374CN','WLAP008 '),(20207,668683047013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','ms.bheyvn','sammiebrown@sbcglobal.net','Samuella Dauphine','2587 E Washington Blvd','Pasadena','CA','UNITED STATES','91107-6205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 19:06:57',0,NULL,3,1,1,1,' LK182804101CN',NULL),(20208,915811385012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','manelfar','sek750i@netvisao.pt','Manuel Joao Fardilha','Rua Nicolau Coelho nº126','Esmoriz','Aveiro','PORTUGAL','3885-596','(00351)919869638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 20:08:33',0,NULL,3,1,22,1,' BJ01669814','WLAP008 '),(20209,668700367013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','rpv720','rpv@sympatico.ca','robert-pierre venne','1001 rue Lenoir<br>Suite # A-402  /  #A-404','montreal','QC','CANADA','H4C 2Z6','(514) 993-6260','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-01-13 20:13:16',0,NULL,3,1,11,1,' BJ01669841','HSNO019 '),(20210,915816098012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','jvan5747','ebay.zaniwoob@spamgourmet.com','Jeroen Visser','Dag Hammarskjöld borg 1','Schiedam','','NETHERLANDS','3124 TL','+31 6 51561320','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 20:16:45',0,NULL,3,1,22,1,' BJ01669815','WLIN013 '),(20211,915831916012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Jeewon Lee','333 N Michigan Ave<br>Fl 27th','Chicago','IL','UNITED STATES','60601-3901','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 20:47:09',0,NULL,3,1,1,1,' LK171230000CN',NULL),(20212,825647136002,120840744734,'NEW genuine LG 3D Active Shutter Glasses AG-S110 S110',2,'LGGL002',127.98,'buysia','megaspb','megav@mail.ru','Malkov Mikhail','Marshala Zaharova 18-1-93','Sankt-Petersburg','','RUSSIAN FEDERATION','198328','7(921)9061078','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-13 21:09:21',0,NULL,3,1,3,1,' RA184531343CN','LGGL002 '),(20213,668735179013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','nikizg','rajakovic.nikica@gmail.com','Nikica Rajakovic','Kozjacka 51a','Zagreb','Croatia','CROATIA','10000','+38513463007','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-01-13 21:25:42',0,NULL,3,1,22,1,NULL,'HSNO019\r 欧标'),(20214,614763972004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',30.6,'cnfaner','sergirver','sergira@inbox.ru','Sergey Zeydel','Zarayskaya 19,60','Moscow','','RUSSIAN FEDERATION','109428','(926)563-0141','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 22:04:59',0,NULL,3,0,3,1,' BJ01669809','OTCN004'),(20215,609488020003,130620866731,'New in sealed box Kensington Expert Mouse Optical USB Trackball K64325',1,'OTKE001',94.99,'cnfaner','milfaer','milfaer@online.no','Haakon Svendsen','Vanglivegen 48','Ridabu','Hedmark','NORWAY','2322','+47 97003045','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 23:04:29',0,NULL,3,1,21,1,' RA184531405CN','OTKE001 '),(20216,915883531012,220871869126,'Genuine Jabra BT250V Bluetooth Headset BT 250V',1,'HSJA001',16.9,'eastar4uk','julieandrew2010','andrewpiller@talktalk.net','Andrew  Piller','3 Calvados Park<br>Kingsteignton','Newton Abbot','Devon','UNITED KINGDOM','TQ123EE','01626356848','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 23:11:25',0,NULL,3,1,3,1,' RA184531184CN','HSJA001\r英标 '),(20217,614793413004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','hendersontm','tedhenderson@juno.com','Theodore Henderson','2916 Cross Creek Ct','Tallahassee','FL','UNITED STATES','32301-8000','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-13 23:15:36',0,NULL,3,1,1,1,'\rLK182962181CN',NULL),(20218,826809335011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','garyfwebb','mel-gary@hotmail.co.uk','gary webb','98 the vista','eltham','london','UNITED KINGDOM','se95rj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 23:16:00',0,NULL,3,1,3,1,' RA184531096CN','LGAD001 '),(20219,913981007012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ehrhardt73','beingfab@sbcglobal.net','Christine Ehrhardt','7157 Cornflower Ct','Corona','CA','UNITED STATES','92880-8923','(951) 898-3635','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 23:16:33',0,NULL,3,1,1,1,' LK179265954CN',NULL),(20220,826813017011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','konsolen-reparatur','konsolen-reparatur@web.de','Fabian Frost','Elisabethenstraße 13/3','Rödermark','','GERMANY','63322','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 23:26:04',0,NULL,3,1,22,1,' BJ01669846','RCLO007+POLO001+RCLO008*4\r欧标 '),(20221,915913558012,220880695871,'New GENUINE NOKIA HS-26W BLUETOOTH HEADSET HS 26W',2,'HSNO032',31.98,'eastar4','gut-d','gutodantas22@hotmail.com','Gutemberg Dantas do Nascimento Dantas do Nascimento','R Bernado coutinho,Denaza, 3guarita, N10351,lt60, araras','Petropolis','Rio de janeiro','BRAZIL','25725022','2492318125','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 23:45:23',0,NULL,3,1,11,1,' ','HSNO032 '),(20222,668776298013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',0,'eastar4','sergey.nikitin','digital.san@gmail.com','Sergey Nikitin','Plesheeva st.<br>1-20','Moscow','','RUSSIAN FEDERATION','127560','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,11,1,' BJ01669804','WLIN014+ MOCN001\r再发一个\rBracket of half intel 5300 6250 wireless card to pci-e'),(20223,826828705011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','keycol28','keycol@aol.com','keely collis','28 Shakespeare Drive','Maldon','Essex','UNITED KINGDOM','cM9 6DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 00:12:08',0,NULL,3,1,3,1,' RA184531079CN','LGAD001 '),(20224,915923119012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','cuttyspark2000','captcutlas@msn.com','Dan c. Dowodzenka','8859 W Friend Ave','littleton','CO','UNITED STATES','80128-5366','(303) 972-0505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 00:13:52',0,NULL,3,1,1,1,'/ ','MOLO001 '),(20225,609514519003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',87.99,'cnfaner','b0075960','stephane_benoit@sympatico.ca','stephane benoit','2760 des sarcelles','laval','QC','CANADA','h7l3r3','(450) 963-3110','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 01:15:42',0,NULL,3,1,3,1,' RA184531365CN','GLOT001*2 '),(20226,772627897007,170746939505,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'au-buy','barbaralee18','dvan81@frontier.com','Dan Van Slyke','1926 Grant St','North Bend','OR','UNITED STATES','97459-1717','(541) 756-2673','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-14 01:36:58',0,NULL,3,1,1,1,'\rLK181890090CN',NULL),(20227,826851002011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','rarebird47','sheree_kinlyside@hotmail.com','Sheree Kinlyside','27 Framara Drive','Kelso','Queensland','AUSTRALIA','4815','0747740508','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 01:37:06',0,NULL,3,1,11,1,NULL,'UM00021 \rProLee24K超轻碳纤骨长柄伞  brown'),(20228,826855420011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','98rkclassic','trcontracting@etcmail.com','Tonny Adams','323 Oakland Dr','Talking rock','GA','UNITED STATES','30175-3995','(770) 375-1614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 01:50:59',0,NULL,3,1,1,1,' LK177178682CN',NULL),(20229,826863572011,320812368138,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',7.99,'eastar4uk','fleurdelys_123','passe34@hotmail.com','gagne sylvain','562 des crecerelles app5','chicoutimi','QC','CANADA','g7h5s9','(418) 698-6070','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 02:23:51',0,NULL,3,1,11,1,NULL,'OT00002 '),(20230,915966986012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',19.98,'eastar4','areplane','handley.joshua@gmail.com','Joshua Handley','211 Pomeroy Ave<br>Apt 2315','Meriden','CT','UNITED STATES','06450-1720','(321) 412-5277','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 02:47:44',0,NULL,3,1,1,1,' LK182641448CN','AUI Transceiver  MX20T '),(20231,668818071013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','colegary_yahoo_com','colegary@yahoo.com','Gary Cole','324 E Glenwood Ave','Rogers','AR','UNITED STATES','72756-4714','(479) 659-1662','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 03:12:11',0,NULL,3,1,1,1,' LK182750054CN','HP 8pin 1.0 23cm  '),(20232,826878136011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','mikemsalazar2011','mikemsalazar@yahoo.com','Maikel Morales','5825 sw 9th ter<br>null','West Miami','FL','UNITED STATES','33144-5014','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 03:28:33',0,NULL,3,1,1,1,'\\ ',NULL),(20233,826890684011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','satellitestar432','satellitestar@yahoo.com','MIGUEL RAMIREZ','3702 W County Road 138','MIDLAND','TX','UNITED STATES','79706-6111','(432) 557-7570','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 04:36:11',0,NULL,3,1,1,1,'、 ',NULL),(20234,668838956013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','llamb7146','elsie_lamb1@eku.edu','Elsie Lamb','PO Box 633','Waco','KY','UNITED STATES','40385-0633','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 05:19:47',0,NULL,3,1,1,1,'、 ','接边斑马纹透明伞   '),(20235,668843299013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','jeanne6892','j091848@hotmail.com','Jeanne Racicot','RR1, Site 7, Box 18<br>15 Cow Bay Road','Alban','ON','CANADA','P0M 1A0','(705) 857-3102','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 05:55:07',0,NULL,3,1,3,1,' RA184531241CN','GLOT001*2 '),(20236,826919231011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','ricklin2','rriicckk@gmail.com','Richard Hall','1745 Tarah Trace Dr','Brandon','FL','UNITED STATES','33510','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 07:06:03',0,NULL,3,1,1,1,'\rLK170932029CN',NULL),(20237,614868980004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','okokoksport','leof@ukam.com','Leonid Farberov','25205 Avenue Tibbitts','Valencia','CA','UNITED STATES','91355-3433','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-14 07:10:25',0,NULL,3,1,1,1,' LK181396009CN',NULL),(20238,614871640004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','gagan778','kainthgagan2005@yahoo.com','gagan kainth','9135 139street','surrey','BC','CANADA','v3v 5x5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 07:30:40',0,NULL,3,1,3,1,' RA184531480CN','HSJA002 '),(20239,781978271001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','al_barb','barbie_67846@yahoo.com','Barbara Baden','509 1/2 N 9th St','Garden City','KS','UNITED STATES','67846','(620) 272-3056','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-14 09:07:40',0,NULL,3,1,1,1,'LK182907857CN ',NULL),(20240,916058222012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','yuna66','stephane.bofill@gmail.com','BOFILL STEPHANE','137 Avenue Foch<br>Villa Raphaël - Apt 3','BEZIERS','Languedoc-Roussillon','FRANCE','34500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 09:45:36',0,NULL,3,1,3,1,'RA184526754CN\r ','GLOT005 \r'),(20241,772726993007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','herobits','s.horrowitz@unsw.edu.au','Dr Steve Horrowitz','RHW PROFESSORIAL SUITE<br>Barker Street','Randwick','New South Wales','AUSTRALIA','2031','0293826677','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-14 09:48:16',0,NULL,3,1,11,1,NULL,'UM00001 \r发黄色的 可以发货了 '),(20242,668895651013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','mwks99','rosyandwayne@optusnet.com.au','Wayne Robertson','P.O. Box 862','Banora Point','New South Wales','AUSTRALIA','2486','0407039355','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 11:13:48',0,NULL,3,1,11,1,NULL,'WLIN010 '),(20243,916089579012,220901458046,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',9,'eastar4uk','leeonical','leeoverend@hotmail.com','Lee Overend','58 Abbeylane<br>Leigh','Wigan','Lancashire','UNITED KINGDOM','Wn7 5pf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 11:20:49',0,NULL,3,1,3,1,' RA184531652CN','SHLO009 '),(20244,826986468011,320730085436,'New 5.1 HD Audio gear Digital Sound decoder',1,'HDGE001',41.69,'eastar4uk','coderislt21','coderislt@yahoo.co.uk','Artur Masel','Ukmerges 196-142','Vilnius','','LITHUANIA','07169','37068327766','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 11:30:14',0,NULL,3,1,21,1,' RA184531167CN','HDGE001 \r客户需要欧标'),(20245,916101624012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','gnasherleslie','gnasher01@hotmail.com','leslie southernwood','46 holmwood road','ashford','Kent','UNITED KINGDOM','tn235dp','07970871890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 11:53:37',0,NULL,3,1,3,1,' RA184531175CN','HSJA002\r英标 '),(20246,827001699011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','7822ericw','e.wiersma@hetnet.nl','Eric Wiersma','Jachtlaan 5','HANK','','NETHERLANDS','4273LE','0162405075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 12:18:29',0,NULL,3,1,22,1,' BJ01669802','OTHP005 '),(20247,772015512007,170758626596,'New Altec Lansing UHP326 noise-isolating Earphones for iPod iPhone Music player',1,'HSAL001',26.88,'au-buy','sllrbl4325','sllrbl@aol.com','Sherry L. Lugar','8096 Busch','Center Line','MI','UNITED STATES','48015-1522','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-14 13:19:39',0,NULL,3,1,1,1,'/ ','HSAL001 '),(20248,827025222011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','mmos1490','mandouh@hotmail.com','mamdouh mostafa','sitio dos anjos<br>CP 36','Corumbatai','SP','BRAZIL','13540000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 13:24:11',0,NULL,3,1,11,1,' ','HSUE002 '),(20249,668936051013,230717843699,'2 pcs of New LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refriger',1,'LGFI001*2',99.99,'eastar4','hamma3006','hammma1248@yahoo.com.au','hamada el-halabi','6 dakara cls','meadow heights','Victoria','AUSTRALIA','3048','0412234277','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 13:55:36',0,NULL,3,1,3,1,' RA184531224CN','LGFI001*2 '),(20250,614952182004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',2,'BALO007',23,'cnfaner','mr.wolfie','misterwolfie@yahoo.co.uk','Martin O\'Hara','Ola Perssonsv. 16','Rinkaby','Skane','SWEDEN','29176','0046721614272','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 14:08:55',0,NULL,3,1,21,1,' RA184531388CN',' BALO007 '),(20251,916163306012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',44.89,'eastar4','fredelook','fa064734@skynet.be','KOOL - id0787788','4 rue carli','Evere','','BELGIUM','1140','0478789388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 14:26:51',0,NULL,3,1,21,1,'RA184531272CN ','GLOT001 '),(20252,668954276013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','ldcfn2011','ldcfn@list.ru','Andrey Nikiforov','Kosmonavtov 53-92','Kazan','Tatarstan','RUSSIAN FEDERATION','420061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 14:55:02',0,NULL,3,1,3,1,'RA184531290CN ','GLOT001*4 '),(20253,822889457011,320727195152,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',61.99,'eastar4','purplemilkdud','dudleyjon@bellsouth.net','Dudley Selinger','713 Burleigh Ct','Nashville','TN','UNITED STATES','37221-3616','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 15:32:11',0,NULL,3,1,1,1,' LK181152474CN',NULL),(20254,609675616003,130466041700,'NEW UNLOCKED ERICSSON F3507G 3G GPS DELL 5530+antenna',1,'WWOT001+ANCN001',40.8,'cnfaner','wongakiem','wongakiem@hotmail.com','Johan Wong','Floresstraat 1-H','Zwolle','','NETHERLANDS','8022AD','0621433213','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 15:39:06',0,NULL,3,1,21,1,' RA184531459CN','WWOT001+ANCN001 '),(20255,916205435012,220757998993,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',3.99,'eastar4uk','richy447','ebay@rebenn.co.uk','Richard Bennett','61, The Avenue','Egham','Surrey','UNITED KINGDOM','TW209AD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 15:55:54',0,NULL,3,1,3,1,' RA184531082CN','OTCN002 '),(20256,827097551011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','tanner7262','em.jojo@hotmail.co.uk','emma tanner','6 st martins park<br>marshfield','chippenham','wiltshire','UNITED KINGDOM','sn148pq','01225892012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 16:10:10',0,NULL,3,1,3,1,' RA184531136CN','LGAD001 '),(20257,827107856011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','karen260189','karen1111@yandex.ru','Karen Asatryan','Roschinskaya 7<br>51','Orel','Orel','RUSSIAN FEDERATION','302025','79192655556','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 16:29:05',0,NULL,3,1,3,1,' RA184531122CN','OTES001 '),(20258,827137051011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',15.96,'eastar4','susmit1','susmit@hotmail.com','Susmit Desai','94 White Pine Dr','Springfield','IL','UNITED STATES','62712-8758','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 17:20:57',0,NULL,3,1,1,1,' LK183090432CN',NULL),(20259,609723380003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',87.99,'cnfaner','nosvir04','demasyquintine@gmail.com','Arnaud Demasy','rue verte louche 1','Péruwelz','','BELGIUM','7600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 17:47:54',0,NULL,3,1,21,1,' RA184531428CN','GLOT001*2 '),(20260,827154554011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','nosvir04','demasyquintine@gmail.com','Arnaud Demasy','rue verte louche 1','Péruwelz','','BELGIUM','7600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 17:50:29',0,NULL,3,1,22,1,' BJ01669848','TRSN001 '),(20261,827177191011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','donealexandro','philipsman@mail.ru','Aleksander Filippov','Shirokaya st., 19-1-3','Moscow','','RUSSIAN FEDERATION','127224','(926)1566293','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 18:28:27',0,NULL,3,1,11,1,NULL,'OTCN002 '),(20262,609743122003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','artur-660','artur6607@gmail.com','Attila Bereczki','Gesztenyés út 1 5/3','Miskolc','alapértelmezés','HUNGARY','3529','36702792389','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 18:37:08',0,NULL,3,1,21,1,' RA184531445CN','BALO007 '),(20263,827201133011,320441564003,'2.1 Acer Aspire 3680 5570 5050 Bluetooth Module +cable',1,'BTAC2116',12.39,'eastar4','isaakc0707','isaakc07@live.com','Isaak Schroeder','57914 Calton Line','Vienna','ON','CANADA','N0J 1Z0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:06:01',0,NULL,3,1,2,1,'30112640471\r ','acer 6pin1.25 23cm '),(20264,615072252004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','duff0660','mackduffy44@gmail.com','Mack Duffy','1939 Ft Augustus Rd','Johnston\'s River','PE','CANADA','C1A7J8','(902) 569-9138','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:36:58',0,NULL,3,1,3,1,' RA184531493CN','RCLO006 '),(20265,916355351012,220829996162,'NIB Genuine Philips SPZ3000 PC Webcam Instant You Tube',1,'PHVE002',17.99,'eastar4uk','warlink','alexander-rohde@gmx.de','Alexander Rohde','Robert-Bosch-Str. 9','Oberboihingen','','GERMANY','72644','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 19:48:30',0,NULL,3,1,22,1,NULL,'PHVE002 '),(20266,827236675011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','davejm62','dave_morgan@btinternet.com','Dave Morgan','62 Blenheim Road, Caversham','Reading','Berkshire','UNITED KINGDOM','RG47RS','07774856505','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 20:06:01',0,NULL,3,1,3,1,'RA184531198CN ','MOAP001 '),(20267,827245954011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','pink-floyd-the-wall','blackcellar@hughes.net','TERRY BLACK','PO BOX 487','BANKS','OR','UNITED STATES','97106','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 20:20:33',0,NULL,3,1,1,1,' LK179750054CN','TRSN001 '),(20268,827262011011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','mirage80400','fumoffu80@ebuyclub.com','Noel Dodré','14 Lot la pature','Ham','Picardie','FRANCE','80400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 20:47:47',0,NULL,3,1,3,1,' RA184558981CN','GLOT001 '),(20269,782309261001,110808692776,'2 pcs of New LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerat',1,'LGFI001*2',99.99,'buysia','mick.mb','mbpools@hotmail.com','MB Pools','18 Augusta Circuit','Peregian Springs','Queensland','AUSTRALIA','4573','0437801195','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-14 22:12:12',0,NULL,3,1,3,1,' RA184531215CN','LGFI001*2 '),(20270,609824278003,130626402257,'3 pairs of New 3D Active Shutter TV Glasses Compatible  for  Sharp LC-40LE835U',1,'GLOT001*3',131.99,'cnfaner','upslatino','maritza7@juno.com','Jesus Escalante','1285 Merriam Ave<br># 305 Apt 305','bronx','NY','UNITED STATES','10452-2911','(212) 365-4189','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-14 22:14:34',0,NULL,3,1,1,1,'、 ',NULL),(20271,916446075012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',8.99,'eastar4uk','jasonsoft2009','usajason2318@gmail.com','Jiaxun Lin','1308 Avenue H<br>Apt 2F','Brooklyn','NY','UNITED STATES','11230-2418','(718) 207-4452','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 22:30:48',0,NULL,3,1,1,1,'LK179962005CN ','WLIN015 '),(20272,827330783011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','avl77andre','losev7777@gmail.com','Andre Losev','Simferopolskaya st, d.21, kv.64','Klimovsk','Moskovskaya oblast','RUSSIAN FEDERATION','142184','(903)133-4623','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 23:15:42',0,NULL,3,1,11,1,NULL,'WLIN011 '),(20273,782330937001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','rayscabin_2007','blackdragonheart2003@yahoo.com','Ray Clouse Jr','13769 Morse Rd SW','Pataskala','OH','UNITED STATES','43062-9317','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-14 23:06:15',0,NULL,3,1,1,1,' LK182941717CN',''),(20274,827335442011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001',53.98,'eastar4uk','chevypaul2','bourge2@mts.net','tony','310 robinson ave','selkirk','MB','CANADA','r1a1e1','(204) 292-5298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 23:27:39',0,NULL,3,1,3,1,'RA184558978CN ','GLOT001 '),(20275,609843683003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','dordelli','dordelli@yahoo.com','John Dordell','17674 La Rosa LN','Fountain Valley','CA','UNITED STATES','92708-4816','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-14 23:24:55',0,NULL,3,1,1,1,' LK177622004CN',NULL),(20276,916536733012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','lazerruus','bmcsmc2@rogers.com','Brian McLeish','4 Pritchard Court','Whitby','ON','CANADA','L1N 7X8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 02:52:35',0,NULL,3,1,2,1,'30112643746\r ',NULL),(20277,826269003002,120816654854,'5v AC adapter for Amazon ebook Kindle MP4 MP3 USB port',2,'OTAM001',15.98,'buysia','jinfluence','jinfluence@yahoo.com','Jonathan Becker','1622 Ford Ave.','Redondo Beach','CA','UNITED STATES','90278','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 03:26:03',0,NULL,3,1,1,1,' LK182312138CN',NULL),(20278,609901827003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','laygeng1','laygeng@reina.com.my','Lin Lay Geng','22-3, Jalan PJU 5/21<br>The Strand','Petaling Jaya','Selangor','MALAYSIA','47810','123156540','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 04:17:15',0,NULL,3,1,3,1,'RA184531476CN ','MOAP001 '),(20279,669215395013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','puddogatx','julianfoncellpowers@gmail.com','JULIAN POWERS','4825 concord rd','beaumont','TX','UNITED STATES','77703-1811','(512) 909-6601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 04:30:25',0,NULL,3,1,1,1,'/ ',NULL),(20280,916567334012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Mrs. Sally LeBoeuf','294 Point Laurel Dr','Lancaster','VA','UNITED STATES','22503-2308','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 04:50:20',0,NULL,3,1,1,1,'、 ',NULL),(20281,827431050011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','jesusrockstar24','aaron.sturbaum@yahoo.com','Aaron Sturbaum','2573 Pinebrook Trl','Cuyahoga Falls','OH','UNITED STATES','44223-3302','(234) 525-2998','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 05:15:14',0,NULL,3,1,1,1,'、 ',NULL),(20282,669229553013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',323.99,'eastar4','55goldenbear','kojinimport@gmail.com','Tsugane Takashi','2-2-6 Suwa','Suwashi','Nagano','JAPAN','392-0004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 06:10:20',0,NULL,3,1,6,1,'EE651291808CN ','GLSG009*3 \rTsugane Takashi\r2-2-6 Suwa\rSuwashi Nagano 392-0004 \rJapan\rPhone 0266-58-1122 \r\r'),(20283,916583845012,220922529417,'New LG AG-F200 Cinema 3D glasses for 2011 LG 3D LED HDTVs (2 pairs pack) Adult',1,'LGGL005',19.99,'eastar4','smi67','nl_smith@bigpond.com','Linda Smith','5 Harrier Ave','New Auckland ','Queensland','AUSTRALIA','4680','0749786309','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 06:12:49',0,NULL,3,1,11,1,NULL,'LGGL005 '),(20284,669230497013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','rcrebertpa','rcrebertpa@yahoo.com','Randy Rebert','PO Box 252<br>22 West Main Street','Everett','PA','UNITED STATES','15537-0252','(717) 965-4688','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 06:14:09',0,NULL,3,1,1,1,' LK182372998CN',NULL),(20285,825217321002,120841176481,'Brand New in box LG AG-F110 3D Cinema Series Glasses 2 Pack',2,'LGGL003',39.98,'buysia','missmuffitt5','missmuffitt_5@yahoo.com.au','Darlyn Watts','34 Deakin Crescent','Nanango','Queensland','AUSTRALIA','4615','0741632683','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-15 06:26:51',0,NULL,5,1,18,0,NULL,'LGGL003 \r没货 已退钱'),(20286,669240812013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',94.95,'eastar4','11cvi','vladimir.i.chernov@gmail.com','Vladimir Chernov','prosp.9 pyatiletki d.3 kv.5','Cheboksary','Chuvashiya','RUSSIAN FEDERATION','428027','+79176542579','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 07:33:40',0,NULL,5,1,18,0,' ','WLIN014 款已经都退了\r客户只想要一个 等直接付款'),(20287,765167248008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',2,'SCLO004',11.8,'au-buy','fiakina','ebay.fiakina@gmail.com','Adam Fiske','PO Box 308','Glenhuntly','Victoria','AUSTRALIA','3163','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-15 08:29:08',0,NULL,3,1,11,1,NULL,'SCLO004 '),(20288,827493728011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','jonnik-2822','jonnik@talktalk.net','Jon Gopsill','22 Heywood Terrace<br>Pill','Bristol','North Somerset','UNITED KINGDOM','BS20 0EA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 09:50:11',0,NULL,3,1,3,1,' RA184531051CN','GLOT001 '),(20289,669272287013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','masaykh2010','masaykh@gmail.com','Maksim Soifer','Garibaldi 1 kv 34','Kharkov','','UKRAINE','61121','+380638251253','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 10:05:07',0,NULL,3,1,22,1,NULL,'UM00042 \r接边蕾丝透明伞   '),(20290,615276594004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','richard2239','rjhwuk@yahoo.co.uk','Richard Holloran-Williams','61 Priory Close','Ivybridge','Devon','UNITED KINGDOM','PL21 9JG','07929911875','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 10:58:22',0,NULL,3,1,3,1,' RA184531502CN','HSJA011\r英标 '),(20291,826383003002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','vitalyekb','vschelkovkin@yandex.ru','Vitaly Shelkovkin','21/22, UL. Novgorodcevoi','Ekaterinburg','','RUSSIAN FEDERATION','620092','7 90438 05643','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-15 11:11:41',0,NULL,3,1,3,1,' RA184531326CN','LGAD001 '),(20292,8881326628974986,111,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'',0,'cnfaner','twinsmasterp','yannick.jette@live.ca','Yannick Jetté','326 29e Avenue','Sainte-Marthe-Sur-Le-Lac','QC','CANADA','J0N 1P0','(514) 554-9619',NULL,NULL,NULL,'2012-01-15 12:02:54',0,NULL,3,1,3,1,'RA184535005CN ','MOOE003\r补发部件F'),(20293,827556075011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','nickeha','nicklas.hallenborg@home.se','Nicklas Hallenborg','Enskiftesvägen 28','Eslöv','Skåne','SWEDEN','S-24135','+707500734','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 12:22:28',0,NULL,3,1,21,1,' RA184531330CN','GLOT001 '),(20294,669332579013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','world_ace','s.n.p1984@googlemail.com','Sunny atel','46 Southover Street','East Sussex','Brighton','UNITED KINGDOM','BN2 9UE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 13:16:01',0,NULL,3,1,3,1,' RA184531309CN','LGAD001 '),(20295,916743370012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','mronka','mronka@hotmail.co.uk','Edgars Jaujenieks','15 Bentley Avenue','Halifax','West Yorkshire','UNITED KINGDOM','hx38ut','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 13:29:39',0,NULL,3,1,3,1,' RA184531017CN','WLIN014 '),(20296,916741308012,220922467202,'New Nokia Easy-to-use Bluetooth Headset BH-301 w/Fashion Conscious',1,'HSNO036',37.99,'eastar4','timurdj','detyshev@mail.ru','Artem Detyshev','17-3-16','Angarsk','Irkutsk region','RUSSIAN FEDERATION','665841','007(902)5124164','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 13:34:14',0,NULL,3,1,11,1,NULL,'HSNO036\r英标 棕色的 '),(20297,669342081013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','matinlexa1992','matinlexa@mail.ru','Алексей Матин','yl. Parashutnaya d.4 korp.1 kv.68','St. Petersburg','Leningrad region','RUSSIAN FEDERATION','197341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 13:43:18',0,NULL,3,1,11,1,NULL,'WLAT001 '),(20298,8881326636798856,111,'New Original Plantronics Voyager Pro Bluetooth Headset',1,'',0,'cnfaner','johnschindler14','john@capitalad.net','John Schindler','10239 Ojai Santa Paula Rd','Ojai','CA','UNITED STATES','93023','',NULL,NULL,NULL,'2012-01-15 14:13:18',0,NULL,3,1,1,1,'LK119130708CN ','补发 '),(20299,827618365011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','geordiewillis','lockout2000@talk21.com','richard willis','5 westmarsh grove','stoke on trent','Staffordshire','UNITED KINGDOM','st6 7pt','07759522595','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 14:19:18',0,NULL,3,1,3,1,' RA184531034CN','GLOT001*4 '),(20300,615354799004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','agronoverde','maluco_sampa@hotmail.com','Linamara Fenner Santos','Av. Jacaranda, Lote 10, Apto 405<br>Ed. Villa Lucci','Aguas Claras','DF','BRAZIL','71927-540','(061) 8120-0272','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 14:53:59',0,NULL,3,1,3,1,' RA184531414CN','WWOT003+ANCN001 '),(20301,827649529011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','lennyc1956','mail1956@ntlworld.com','S Croton','10 Repton Drive','Ilkeston','Derbyshire','UNITED KINGDOM','DE7 5ES','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 15:14:49',0,NULL,3,1,3,1,' RA184531025CN','RELO003 '),(20302,916805208012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','speedsterporsche','rommel.cruz@tdsb.on.ca','Rommel    Cruz','107 Frankdale Ave','Toronto','ON','CANADA','M4J 4A4','(416) 466-8732','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 15:15:38',0,NULL,3,1,11,1,' BJ01669854','OTGR001+OTGR002 '),(20303,669384221013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','innokent1102','innokent@me.com','Иннокентий Калюжный','Щербакова 35-117','Екатеринбург','Россия','RUSSIAN FEDERATION','620076','9126450505','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 15:35:23',0,NULL,3,1,11,1,NULL,NULL),(20304,669387955013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','east_end_lights','eastendlights@gmail.com','John Wong','18 Mossman Crescent','Bull Creek','Western Australia','AUSTRALIA','6149','0433691991','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 15:37:29',0,NULL,3,1,3,1,' RA184531255CN','GLOT001*2 '),(20305,827716161011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','alison.2011','sweettalkingaly@ntlworld.com','Alison Higgins','32 Lonsdale Avenue<br>East Cosham','Portsmouth','Hampshire','UNITED KINGDOM','PO6 2PX','02392353239','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 16:48:51',0,NULL,3,1,3,1,' RA184531207CN','LGAD001 '),(20306,827718991011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','corvomaia1','corvomaia@hotmail.com','Luís Guilherme Cavalcante Maia','RUA MANUEL RODRIGUES, Nº188 Bairro: BOA VISTA / CASTELÃO','Fortaleza','Ceará','BRAZIL','60861-015','(085) 8805-6227','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 16:54:25',0,NULL,3,1,11,1,' BJ01669850','TRSN001 '),(20307,827725402011,320394931576,'Acer TM 5720 5720G 5320 Bluetooth Module 2.0 EDR+cable',1,'BTAC2006',9.88,'eastar4','1276cpaul','cpaulbest@gmail.com','Pavlos Constantinou','3b, Lefkou Anastasiadi str<br>Kaimakli','Nicosia','Nicosia','CYPRUS','1026','0035799671276','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 17:00:11',0,NULL,3,1,22,1,' ','BTAC2006 \racer 4pin1.25 15cm'),(20308,669437894013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','laisla3411','clasolo3411@hotmail.com','jose maria rodriguez gomez','calle arrayanes, num.46','san fernando','Andalucía Ceuta y Melilla','SPAIN','11100','657586725','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 17:10:10',0,NULL,3,1,21,1,' RA184531238CN','GLOT001*2 '),(20309,827738240011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','tommytomzx3','robjt3223@yahoo.com','robert thompson','10410 Saint Charles Rock Rd','Saint ann','MO','UNITED STATES','63074-1816','(214) 783-9577','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 17:13:54',0,NULL,3,1,1,1,'\rLK182407927CN','HP 8pin 1.25 18cm  '),(20310,615440655004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','teabag_696','teabag_696@hotmail.com','sam weaver','57 haywards road, charlton kings','cheltenham','Gloucestershire','UNITED KINGDOM','GL526RQ','01242570173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 17:42:35',0,NULL,3,1,3,1,' RA184531462CN','HBPH003\r英标 '),(20311,669457800013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','grandma_42','deb_w_42@yahoo.com','deb wall','23312 Goldstone Dr','long prairie','MN','UNITED STATES','56347-5518','(320) 732-3517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 17:43:28',0,NULL,3,1,1,1,'、 ',NULL),(20312,827766189011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','tcknk','knkct@hotmail.com','Ken Tsurusaki','1425 Sequoia Rd','Naperville','IL','UNITED STATES','60540','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-15 17:46:42',0,NULL,3,1,1,1,' LK161794284CN',' '),(20313,827789021011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','brwolf2010','djras@brwolf.com','David Rasmussen','2728 Loker Ave W<br>Palomar Technologies','Carlsbad','CA','UNITED STATES','92010-6603','(951) 206-4509','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 18:08:55',0,NULL,3,1,1,1,'、 ','ProLee24K超轻碳纤骨长柄伞  蓝色的 或黑色的'),(20314,916963120012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','tibuktu','pawel.maksymiak@gmail.com','Pawel Maksymiak','ANNANKATU 18, P.O.Box 400<br>European Chemicals Agency','Helsinki','Helsinki','FINLAND','00121','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 18:15:37',0,NULL,3,1,22,1,' BJ01669847','HSPH002 '),(20315,615466679004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','jacmeister2','jpr104@york.ac.uk','Emma Leadbeater','App2, 37 Turnbull Road<br>Stamford Brook','Alrincham','Cheshire','UNITED KINGDOM','WA14 5UP','07971147155','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:25:29',0,NULL,3,1,3,1,' RA184531706CN','HBPH003\r英标 '),(20316,827812029011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','philwezz','philwezz3@gmail.com','philip powell','74 chichester avenue<br>netherton','dudley','West Midlands','UNITED KINGDOM','DY2 9JL','01384352291','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 18:29:27',0,NULL,8,1,17,0,NULL,NULL),(20317,916985911012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','philwezz','philwezz3@gmail.com','philip powell','74 chichester avenue<br>netherton','dudley','West Midlands','UNITED KINGDOM','DY2 9JL','01384352291','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 18:34:51',0,NULL,3,1,3,1,' RA184531604CN',' LGRM001\r还买了 \rBrand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100\rLGAD001'),(20318,610224015003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001',43.89,'cnfaner','al.tush','altush@yandex.ru','Alexey Tushurashvili','Kokhomskoe shosse, 7-13','Ivanovo','Ivanovskaya obl','RUSSIAN FEDERATION','153051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 19:39:16',0,NULL,3,1,3,1,' RA184531269CN','GLOT001 '),(20319,917023221012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',65.98,'eastar4uk','134jaf','chtahird@hotmail.com','tahir mahmood','51 orpwood,stechford','birmingham','West Midlands','UNITED KINGDOM','B338LN','07988667412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 19:23:30',0,NULL,3,0,3,1,' RA184531578CN','LGRM001\r还买了 \rBrand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100\rLGAD001\r\r '),(20320,615536008004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','sinister69','nelsonwoodford@sbcglobal.net','Nelson Woodford','1282 Levier St','Edwards','CA','UNITED STATES','93523-2702','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-15 19:50:34',0,NULL,3,1,1,1,' LK183074925CN',NULL),(20321,782863462001,110808693373,'New Jabra JX10 Series II 2 Wireless Bluetooth headset black',1,'HSJA004',21.98,'buysia','brisk84','brisk@inbox.ru','Marat Gumyarov','Lomonosova st.<br>100-58','Severodvinsk','Arkhangelsk region','RUSSIAN FEDERATION','164512','+79210878500','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-15 19:58:44',0,NULL,3,1,11,1,'BJ01669739 ','HSJA004   发一个银色的当礼物送了  退款  '),(20322,917086148012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','j_sarnstrom','j_sarnstrom@yahoo.com','Johan Sarnstrom','Violvagen 17c','LAHOLM','','SWEDEN','31232','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 20:00:49',0,NULL,3,1,21,1,' RA184531357CN','RCMA001\r欧标\r '),(20323,669588253013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','megabytest','megabytestv@yandex.ru','Artur Myznikov','Rustaveli st. 50, app. 162','Saint-Petersburg','','RUSSIAN FEDERATION','195299','+79119088797','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 20:32:29',0,NULL,3,1,11,1,' ','WLIN014 '),(20324,827955173011,320730551325,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E card',1,'WLIN016',13.99,'eastar4uk','johnsoap','tony.johnson@tonaud.com','Tony Johnson','14, Rushmoor Grove','Backwell West Town','North Somerset','UNITED KINGDOM','BS48 3BW','01275464233','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 20:43:53',0,NULL,3,1,3,1,' RA184531105CN','WLIN016 '),(20325,827963200011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','anandpreet120','anandpreet@hotmail.co.uk','Anandpreet Singh','65 Hertford House<br>Taywood Road','Northolt','Middlesex','UNITED KINGDOM','UB56GD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 20:54:38',0,NULL,3,1,3,1,'RA184526635CN\r ','TRSN001 \r可以发货了 '),(20326,917154198012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','swixik','khalim@centrum.cz','Michal Sinagl','Konopistska 5','Praha 10','','CZECH REPUBLIC','10000','608831966','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 21:08:02',0,NULL,3,1,11,1,NULL,'MOMI002 '),(20327,773703407007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','tradeconnect','info@tradeconnect.com.au','Trade Connect','18 Kita Rd<br>(shopfront behind carpark)','Berowra Heights','New South Wales','AUSTRALIA','2082','0294567100','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-15 21:17:12',0,NULL,3,1,11,1,' BJ01669813','RELO002 '),(20328,669621455013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',23,'eastar4','gusbrowne','gbrowner@yahoo.com','Gustavo Browne','100 E 14th st<br>Apt 2804','Chicago','IL','UNITED STATES','60605-3675','(240) 416-4461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 21:32:55',0,NULL,3,1,1,1,'/ ',NULL),(20329,917182594012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','saleskimmer','sunnychana2003@gmail.com','Harj Nandhra','21 Lesie Road R1<br>Forest Fields','Nottingham','Nottinghamshire','UNITED KINGDOM','NG76PD','01159120084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 21:48:18',0,NULL,3,1,3,1,' RA184531119CN','SAFI001 '),(20330,828004914011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','skambar','skambar@gmx.de','Uwe Goldenstein','Westgaster Weg 13a','Aurich','','GERMANY','26603','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 21:52:55',0,NULL,3,1,22,1,' BJ01669845','OTHP005 '),(20331,773736418007,170740412441,'2 pair New 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001*2',87.99,'au-buy','nathanfife','natedg47@yahoo.com','Nathan Fife','1209 Wales Avenue','Birmingham','AL','UNITED STATES','35213-1413','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-15 22:07:49',0,NULL,3,1,1,1,' LK180481726CN','GLOT001*2 '),(20332,828023038011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',3,'HSNO005+CCNO001',47.67,'eastar4','svetayloulou','yloulou@hotmail.fr','yvette cretient','18, rue de Joyenval','CHAMBOURCY','Ile-de-France','FRANCE','78240','0130653008','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 22:54:56',0,NULL,3,1,3,1,' RA184531286CN','HSNO005+CCNO001 '),(20333,782984850001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','ebb_amps','ebbamps@socal.rr.com','Allen Elwood','437 Fermoore St','San Fernando','CA','UNITED STATES','91340-2302','(818) 361-5251','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-15 23:12:17',0,NULL,3,1,1,1,' LK177756615CN',NULL),(20334,828044373011,320730085700,'New Atheros AR5B95 AR9285 Half Mini PCI-E+ANTENNA',1,'WLAT009+ANTY001',6.99,'eastar4uk','mhsmulders','mhsmulders@hotmail.com','mh smulders','van hovedreef 8','rucphen','noord-braband','NETHERLANDS','4715 GH','0165342942','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 23:12:52',0,NULL,3,1,22,1,' BJ01669816','WLAT009+ANTY001 '),(20335,828049364011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','pierjudy','pierjudy@hotmail.com','Pierre Gallant','26 james lane','tide head','NB','CANADA','e3n 4r1','(506) 329-0220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 23:27:32',0,NULL,3,1,3,1,' RA184558995CN','GLOT001*2 '),(20336,917243248012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',4,'HSJA001',95.6,'eastar4','barrychickenman','shakey_ghost@yahoo.com','Barry Parker','24457 Mary N Smith, rd','Accomac','VA','UNITED STATES','23301','(757) 710-0737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 23:42:35',0,NULL,3,1,1,1,'、 ',NULL),(20337,615646502004,140519339941,'New Jabra BT320s StereoBluetooth Clip-On Earbud Headset',1,'HSJA003',22.69,'cnfaner','slybrood7','sly_007_@hotmail.com','Jason Luogameno','1 W Forest Ave','Englewood','NJ','UNITED STATES','07631-4004','(201) 230-2451','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 00:04:53',0,NULL,3,1,1,1,'、 ',NULL),(20338,828066358011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','jantrade','jantrad@hotmail.co.uk','Jan Ayoub','64E Carlinghow Lane','Batley','West Yorkshire','UNITED KINGDOM','WF17 8EF','01924473525','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 00:05:58',0,NULL,3,1,3,1,' RA184531048CN','GLOT001 '),(20339,765731011008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','8228jackson','dasuperstar@sbcglobal.net','robert jackson','195 Linda Vis','millbrae','CA','UNITED STATES','94030-2126','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-16 00:16:42',0,NULL,3,1,1,1,'/ ',NULL),(20340,917275118012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','lifeisbeachy','erin@lucky-luxe.com','Erin Napier','402 N Magnolia St<br>Ste B','Laurel','MS','UNITED STATES','39440-3994','(601) 498-1388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 01:04:17',0,NULL,3,1,1,1,' LK179975525CN',NULL),(20341,764956618007,170739882957,'New GENUINE PLANTRONICS Calisto pro Bluetooth Headset only',1,'HSPL014',53.99,'au-buy','mandeep355','mandeep.jaryal355@gmail.com','Mandeep Singh','4/9 York street','Nundah','Queensland','AUSTRALIA','4012','0420940355','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-16 01:05:41',0,NULL,3,1,3,1,'RA184526745CN\r ','HSPL014 '),(20342,828089624011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','ladybee4me','ninnie95d1d@yahoo.com','LINDSAY SUTTON','9513 Nettle Dr','CHARLOTTE','NC','UNITED STATES','28216-1758','(704) 506-6921','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 01:13:05',0,NULL,3,1,1,1,'、 ','爱雨透明伞    '),(20343,917283217012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','ashyus','ash.hussain@hotmail.co.uk','ashraf hussain','flat 4 ellen julia court 1 james voller way','london','London','UNITED KINGDOM','e12pf','02077909256','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 01:25:57',0,NULL,3,1,3,1,' RA184531065CN','LGRM001 '),(20344,917302356012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Henry Achatz','11225 Morrison Ave<br>Apt 301','North Hollywood','CA','UNITED STATES','91601-5356','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 02:12:56',0,NULL,3,1,1,1,' LK183221257CN',NULL),(20345,828119298011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','sherlocksecurit1','sherlocksecurit1@msn.com','Sherlock Morrison','5028 36th Ave','hyattsville','MD','UNITED STATES','20782','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 02:36:32',0,NULL,3,1,1,1,' LK180059226CN',NULL),(20346,915762907012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','elizajh208','alquitrajes@hotmail.com','John Jimenez','1616 SW 157th Ave','Pembroke Pines','FL','UNITED STATES','33027-2353','(786) 328-7549','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,''),(20347,8881326684175419,111,'EU plug',2,'',0,'eastar4uk','georgeuoa1','georgeuoa@yahoo.com','George Konaxis','Erythrou Stavrou 87','Drapetsona','Greece','GREECE','18648','',NULL,NULL,NULL,'2012-01-16 03:22:55',0,NULL,3,0,11,1,NULL,NULL),(20348,668793636013,230641625459,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',132.99,'eastar4','thesalesmanager','jtryan10@optushome.com.au','John Ryan','9 Welch Street','North Manly','New South Wales','AUSTRALIA','2100','0411655677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 03:31:49',0,NULL,3,1,3,1,' RA184531533CN','GLOT001*3 '),(20349,8881326684773507,111,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000 Cordless Mouse',2,'BALO007',23.98,'aliexpress','1006278211 ','ludovic.lambert57@gmail.com','Ludovic LAMBERT','76 rue de Verdun','SEMECOURT	','MOSELLE','FRANCE','57280','+00 33 0662170783',NULL,NULL,NULL,'2012-01-16 03:32:53',0,NULL,3,1,3,1,' RA184531312CN','BALO007*2 '),(20350,8881326685007616,111,'Brand new HP MCE Media Center Remote Control+ IR emitter',1,'OTHP005',16.99,'aliexpress','1006285622','yuri@megaguia.com.br','Yuri Marx	','rua raul pinto, 105','chacara','MG - Brasil	','BRAZIL','36.110-000','+55 32 3277-1249',NULL,NULL,NULL,'2012-01-16 03:36:47',0,NULL,3,1,25,1,'RT125002756HK ','OTHP005*1 '),(20351,828140080011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','bonniec852','bonnieview@sympatico.ca','Bonnie Cole','R. R. # 1<br>852 Crofts Road','Havelock','ON','CANADA','K0L 1Z0','(613) 472-2034','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 03:43:44',0,NULL,3,1,11,1,NULL,'HBPH009 '),(20352,8881326686012503,111,'Logitech MX Revolution Cordless Wireless Laser Mouse only ',2,'MOLO006',51.98,'aliexpress','1006291863 ','info@larslindenberg.ch','Lars Maeder	','Dorfstr.34c','Freienwil','Aargau','SWITZERLAND','5423','0041763477073',NULL,NULL,NULL,'2012-01-16 03:53:32',0,NULL,3,1,21,1,'RA184526547CN\r ','MOLO006*2 '),(20353,773861529007,170735485634,'New Blade Runner Saber LED Flash Light Umbrella Safety  5 colors availabe',1,'UM00031',27.99,'au-buy','pensivespatula','jason.bird@gmail.com','Jason Bird','39 Mayfair Place<br>Stretton','Brisbane','Queensland','AUSTRALIA','4116','0409636697','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-16 04:08:11',0,NULL,3,1,11,1,NULL,'UM00031\r黑色 '),(20354,615717820004,140515718199,'New IBM Unlocked MC8775 WWAN Card X61 T61 R61 Z60',1,'WWSI002',28.88,'cnfaner','ted1610_0','ted_silver@kfctristate.com','Ted Silver','143 Smithview Dr','Greentown','PA','UNITED STATES','18426-9809','(973) 713-5010','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 05:06:43',0,NULL,3,1,1,1,'LK182285327CN ',NULL),(20355,772706798007,170764043239,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',2,'PSGL001',185.98,'au-buy','fawzie2007','fawzie2000@hotmail.com','Ramli Haryanto','Unit 3/18 Barwon St<br>Box Hill North','Melbourne','Victoria','AUSTRALIA','3129','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-16 05:11:37',0,NULL,3,1,3,1,' RA184531516CN','PSGL001 '),(20356,669766887013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',1,'UDAP004',22.99,'eastar4','sergo-margo','spa.in.spa@gmail.com','Sergei Anikin','Prospekt Prosvescheniya<br>d. 30, korp. 3, kv. 5','Saint-Petersburg','','RUSSIAN FEDERATION','194358','+7(921)415-43-43','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 06:54:42',0,NULL,3,1,11,1,NULL,'UDAP004 '),(20357,8881326697354095,111,'NEW JABRA BT250V 耳机',1,'HSJA001',0,'eastar4','startrekeagle','startrekeagle@cimtel.net','Steve Shields','4455 S 289th West Ave','Mannford','OK','UNITED STATES','74044','(918) 645-3801',NULL,NULL,NULL,'2012-01-16 07:02:34',0,NULL,3,1,1,1,' LK106480625CN','补发的 \r只补发一个耳机'),(20358,8881326699681164,111,'Unlocked NEW Sierra Wireless WWAN MC8781 PCI-E HSUPA 3G',1,'WWSI005',0,'eastar4','levbarkan','levik2003@bk.ru','Lev Barkan','Russia, Sankt-Peterburg, ulitsa Varshavskaya dom 19 korpus 1 kvartira 113','St.-Petersburg','','RUSSIAN FEDERATION','196128','',NULL,NULL,NULL,'2012-01-16 07:41:21',0,NULL,3,1,11,1,NULL,'WWSI005\r补发的 '),(20359,917394360012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','gemmah08','gemma.higgs@westnet.com.au','Gemma Higgs','19 Platypus Close','KURANDA','Queensland','AUSTRALIA','4881','0740938140','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 08:02:45',0,NULL,3,1,11,1,NULL,'UM00006 \r蕾丝蝴蝶结伞 黑色'),(20360,8881326702014179,111,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',0,'eastar4','extreme0011','shannon@wulff.com.au','Shannon Wulff','14 Parkfield Rd','Kelmscott','Western Australia','AUSTRALIA','6111','0424935640',NULL,NULL,NULL,'2012-01-16 08:20:14',0,NULL,3,1,11,1,NULL,'补发 三条\rCASS003 \rCAB-6060'),(20361,615745456004,140662512199,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100',1,'HSPH008',114.99,'cnfaner','sniperfsl212','cote.remi212@hotmail.com','Rémi Côté','10289 133rd St<br>Suite 408','Surrey','BC','CANADA','V3T 0B1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 08:38:47',0,NULL,3,1,3,1,' RA184531618CN','HSPH008 '),(20362,669639976013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',10,'WLAT010',89.9,'eastar4','squarelabs','squarelab.net@gmail.com','Shin Seock-Joo','Daemyeong Apt 102-402<br>Pyeongnae-dong','Namyangju-si','Gyeonggi-do','KOREA,REPUBLIC OF','472-737','821025679330','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 08:44:21',0,NULL,3,1,3,1,'RA184534693CN ','WLAT010 '),(20363,827024674002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','nikikita11','nikikita@mail.ru','Nikita Usov','Krilov st. 62-54','Karaganda','Karagandinskaya','KAZAKHSTAN','100019','+77021886044','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-16 08:48:11',0,NULL,3,1,3,1,'RA184531635CN ','LGAD001 '),(20364,917407593012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','zilver512','b.cap@hotmail.com','b vd werff','Arebos 6','LEUSDEN','','NETHERLANDS','3831PZ','0655713450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 08:59:10',0,NULL,3,1,22,1,NULL,'WLIN013 '),(20365,8881326705199289,111,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',23.45,'eastar4','danny.pal','sasimaloe@gmail.com','Mr.Danny Pal','18-19TALATPRACHANIVAT3T.TASAI','MUANG','NONTHABURI,','THAILAND','11000','',NULL,NULL,NULL,'2012-01-16 09:13:19',0,NULL,3,1,3,1,' RA184531649CN','客户打了运费\rHSNO028 '),(20366,610444857003,130626402578,'4 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*4',174.99,'cnfaner','100trustbuyer','alex_aspire@inbox.ru','Alexander Istomin','str 250 let Chelyabinska/20/172','Chelyabinsk','Chelyabinskaya Oblast','RUSSIAN FEDERATION','454128','79227000067','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 09:26:50',0,NULL,3,1,3,1,'RA184531697CN\r ','GLOT001*4 '),(20367,828218359011,320814017766,'2 pcs of New LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refriger',1,'LGFI001*2',59.99,'eastar4uk','tngo5479','tutusquang@yahoo.com','Tony Ngo','5 meribah court<br>Noble Park','Melbourne','Victoria','AUSTRALIA','3174','610421772498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 09:51:54',0,NULL,3,1,3,1,'RA184526533CN\r ','LGFI001*2 '),(20368,827008726011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',96.99,'eastar4uk','mum000282','terry.blackmore@blueyonder.co.uk','TERRY BLACKMORE','UNIT 60 , HORNDON IND. PARK<br>STATION ROAD','WEST HORNDON','Essex','UNITED KINGDOM','CM13 3XL','01277814060','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 10:03:27',0,NULL,3,1,3,1,'RA184526649CN\r ','GLOT005*3 '),(20369,828225281011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',2,'UM00040',39.98,'eastar4','natys2011','nityaa@bk.ru','Natalia Ivanova','Saltukovskaya, 23-2-35','Moscow','Moscow Province','RUSSIAN FEDERATION','111672','89264801758','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 10:18:11',0,NULL,3,1,3,1,'RA184526666CN\r ',' UM00040'),(20427,616013055004,140626376379,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',20.9,'cnfaner','alexandre6457','kobe_bryant23@msn.com','alexandre martins pascoal','5 boulevard montcalm south','candiac','QC','CANADA','J5R3M1','(514) 949-8193','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 04:21:11',0,NULL,3,1,3,1,'RA184526723CN\r ','OTHP006 '),(20370,828243871011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',2,'ANCN001',9.78,'eastar4','likhomanov','likhomanoff@gmail.com','Danila Likhomanov','st. Tatisheva 60-219','Ekaterinburg','Sverdlovskaya','RUSSIAN FEDERATION','620028','79122278555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 11:29:40',0,NULL,3,1,11,1,NULL,' ANCN001'),(20371,669823661013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','jrsilva2011','joserobertoneno@ig.com.br','Elza P Tarin','RUA VITOR BRITO BASTOS , 1291<br>RUA VITOR BRITO BASTOS , 1282','São José do Rio Preto','São Paulo','BRAZIL','15030-550','19 33235913','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 12:32:31',0,NULL,3,1,3,1,'RA184526604CN\r ',' GLOT001*2'),(20372,669270343013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.98,'eastar4','khainii','philar1001@gmail.com','Lee Jungwoo','501 W 7th St','wilmington','DE','UNITED STATES','19801-2123','201 945 0004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 13:55:30',0,NULL,3,1,1,1,'LK109217206CN ',' 两个622ANXHMW\r系统没出单子，自己做的\r地址录错了'),(20373,774003731007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',2,'CC00002',71.98,'au-buy','severwolf63','severwolf@gmail.com','Maxim Kazanin','Alma-Atinskaya 120, kv.22','Samara','Samara Region','RUSSIAN FEDERATION','443106','+79371777754','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-16 14:04:31',0,NULL,3,1,3,1,'RA184526564CN\r ','CC00002 '),(20374,668610852013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','aia4445','aia@mchsi.com','DONALD WALLER','27 WEST HWY 61<br>PO BOX 333','ESKO','MN','UNITED STATES','55733','(218) 879-4445','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 14:04:41',0,NULL,3,1,1,1,'\\ ',NULL),(20375,917507089012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','fashionexpert07','arif@syeduk.com','Arif Syed','23 Courtlands Drive','Watford','Hertfordshire','UNITED KINGDOM','WD17 4HU','02089072100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 14:18:48',0,NULL,3,1,3,1,'RA184526652CN\r ','OTGR001 '),(20376,828314203011,320730086052,'New brand Logitech Digital IO Writing Pen',1,'NTLO002',23.99,'eastar4uk','0144scania12','farrow.tony@yahoo.com','anthony farrow','13 birch ave','bacton','Suffolk','UNITED KINGDOM','IP144NT','01449781673','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 15:08:46',0,NULL,3,1,3,1,'RA184526670CN\r ','NTLO002 '),(20377,610517029003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',2,'MOMI002',26.98,'cnfaner','alcidesneto','alcides.araujo@hotmail.com','Alcides Neto','Rua Quinze de Novembro, #3018 - Apt F102<br>Centro','Campo Grande,','Mato Grosso do Sul - MS,','BRAZIL','79020-901','+55 (67) 9122-8626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 15:16:00',0,NULL,3,1,3,1,'RA184526683CN\r ','MOMI002 '),(20378,615832713004,140482633304,'New GENUINE NOKIA HS-11W BLUETOOTH HEADSET track#',1,'HSNO023',13.89,'cnfaner','anderson.jackson3','andersonjackson3@gmail.com','Anderson Jackson III','6900 Preston Rd<br>Apt 1621','Plano','TX','UNITED STATES','75024-2531','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 15:45:04',0,NULL,5,1,18,1,NULL,'已退款   '),(20379,917544527012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','arthurcwillis','artwillis01@msn.com','Arthur Willis','976 Nathaniel Rd','Cleveland','OH','UNITED STATES','44110-3235','(216) 224-1095','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 15:48:49',0,NULL,3,1,1,1,'/ ',NULL),(20380,669887682013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','westphal63','awestphal@gmail.com','Andy Westphal','211  S Cochrans Green Cir','The Woodlands','TX','UNITED STATES','77381-6216','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 16:30:40',0,NULL,3,1,1,1,'\\ ',NULL),(20381,615849795004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','weiss7706','weiss7706@comcast.net','rodney weiss','12918 NE 54th St','vancouver','WA','UNITED STATES','98682-2168','(360) 256-0280','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 16:40:16',0,NULL,3,1,1,1,'\\ ',NULL),(20382,783282636001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','humatin1','matin0309@yahoo.com','ABDUL AZAM','1103 ROTTKAMP ST','VALLEY STREAM','NY','UNITED STATES','11580-2334','(347) 841-3990','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-16 16:55:45',0,NULL,3,1,1,1,'/ ',NULL),(20383,828385137011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','grandparents4ever','twooldfolks@wi.rr.com','Nancy Norby','726 Skylark Dr','Oconomowoc','WI','UNITED STATES','53066-1709','(262) 567-8901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 17:43:47',0,NULL,3,1,1,1,'LK176353028CN ','还买了 TDG-BR100 transmmitter 一个  如果明天还不回复 就发货'),(20384,828386117011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','lehat1001','lehat101@yahoo.co.uk','Stephen Motherway','98 F1 Lower Ford Street','Coventry','West Midlands','UNITED KINGDOM','CV1 5PW','02476257260','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 17:44:37',0,NULL,3,1,11,1,NULL,' BTAC2006'),(20385,828387384011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','grandparents4ever','twooldfolks@wi.rr.com','Nancy Norby','726 Skylark Dr','Oconomowoc','WI','UNITED STATES','53066-1709','(262) 567-8901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 17:49:07',0,NULL,3,0,17,0,NULL,' '),(20386,917620692012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',2,'BTGA2101',24.78,'eastar4','quickwhip','harryh@pobox.com','Harry Holzhauser','4842 Williamstown BLVD','Lakeland','FL','UNITED STATES','33810-3703','(972) 423-7184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 18:22:00',0,NULL,3,1,1,1,'\\ ',NULL),(20387,610580772003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','thepastics','thepastics5@comcast.net','Sean Pastic','323 Wellington Way','Swedesboro','NJ','UNITED STATES','08085-2527','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 18:31:15',0,NULL,3,1,1,1,'\\ ',NULL),(20388,917633242012,220913328219,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',4.99,'eastar4uk','plonck87','andreas.roethlisberger@windowslive.com','Andreas Roethlisberger','Breitestrasse 55','Winterthur','','SWITZERLAND','8400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 18:33:05',0,NULL,3,1,22,1,'BJ01669794\r ','OT00004 '),(20389,669928246013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','fatigedz','fafafarofa@yahoo.com.br','Fátima Araujo','Rua Evaristo da Veiga 35 - 1603','Rio de Janeiro','Rio de Janeiro','BRAZIL','20031040','21-22206857','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 18:19:53',0,NULL,3,1,11,1,' ',' UM00042'),(20390,828417842011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','larresch1','larresch@gmail.com','larre schlarmann','13331 poway rd','poway','CA','UNITED STATES','92064-4625','(858) 231-0957','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 18:40:45',0,NULL,3,1,1,1,'\\ ',NULL),(20391,828423547011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','42douglasadams42','kenostrovsky@gmail.com','Ken Ostrovsky','9 Roszel Rd<br>2-356 PwC Team Room','Princeton','NJ','UNITED STATES','08540-6255','(215) 316-1154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 18:49:16',0,NULL,3,1,1,1,'\\ ',NULL),(20392,917645071012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','ydbarnes1','ydbarns@gmail.com','yvonne barnes','14 buckingham court fulham close','crawley','West Sussex','UNITED KINGDOM','RH11 9AY','01293405960','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 18:57:14',0,NULL,3,1,3,1,'RA184526621CN\r ','HSJA002 '),(20393,828433236011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT001',89.78,'eastar4','alpalog','info@alpalogistics.gr','Alexandros Pagoulatos','53, Ortansias street<br>Aharnai','Attica','Attica','GREECE','136 77','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 19:05:25',0,NULL,3,1,21,1,'RA184526595CN\r ',' GLOT001'),(20394,828450850011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','senatorius','kthbrennan@aol.com','KEITH BRENNAN','15, NEWLANDS DRIVE<br>STANLEY','WAKEFIELD','West Yorkshire','UNITED KINGDOM','WF3 4DU','01924827913','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 19:31:44',0,NULL,3,1,3,1,'RA184526618CN\r ','GPS0010 '),(20395,917677645012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','skn97','skn97@hotmail.com','Stephen Nolly','967 1/2 Farnam St','Los Angeles','CA','UNITED STATES','90042-2226','(323) 509-8615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 19:35:02',0,NULL,3,1,1,1,'\\ ',NULL),(20396,827266153002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','disturbed_bcn','djg.bcn3@gmail.com','Daniel Jiménez García','C/ Santa Anna, nº 14, 3º 3ª','Hospitalet','Cataluña','SPAIN','08901','657489972','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-16 19:44:06',0,NULL,3,1,21,1,'RA184526555CN\r ',NULL),(20397,615932602004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','mary_wulf','marykaywulf@hotmail.com','Mary Wulf','47444 210th St','Morris','MN','UNITED STATES','56267-4720','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 20:15:16',0,NULL,3,1,1,1,'\\ ',NULL),(20398,828487026011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',3,'CASS003',32.97,'eastar4','glp0000','gareth_pomford@hotmail.com','Mr  Pomford','10 Meadow Way,Coppull','Chorley','Lancashire','UNITED KINGDOM','PR75DQ','01257792308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 20:28:23',0,NULL,3,1,11,1,'BJ01669785\r ',' CASS003'),(20399,610636815003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','dadaa71','dadaa1@gmail.com','Pasi Lehtinen','haapaniemenkatu 16 B 176','Helsinki','Suomi','FINLAND','00530','358405267286','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 20:40:44',0,NULL,3,1,21,1,'RA184526516CN\r ','MOAP001 '),(20400,828500427011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','delear1973','delear@msn.com','Delear Sawa','37102 Colgate Ct','Sterling Heights','MI','UNITED STATES','48310-4043','(586) 306-9861','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 20:55:08',0,NULL,3,1,1,1,'\\ ',NULL),(20401,615959946004,140584761831,'Logitech MX1000 Mouse special bluetooth version',1,'MOLO005',58.8,'cnfaner','g3-p0','benonlineorders@gmail.com','Benjamin Powers','813 University St','Memphis','TN','UNITED STATES','38107-5123','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 21:24:53',0,NULL,3,1,1,1,'\\ ',NULL),(20402,917744918012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','ldb68426','y4smin@aol.co.uk','lee  bonello','27 mansfield road, hextable','swanley','Kent','UNITED KINGDOM','BR87RG','01322615058','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 21:21:15',0,NULL,3,1,3,1,'RA184526706CN\r ','SAFI001 '),(20403,828526429011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','4801584735','newjerseyjr@hotmail.com','Joseph Borroum','4924 eaglesmere dr<br>Apt 315','orlando','FL','UNITED STATES','32819-5602','(321) 501-7232','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 21:39:12',0,NULL,3,1,1,1,'/ ',NULL),(20404,615972036004,140676421848,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',71.99,'cnfaner','jar1029','tito1029@bellsouth.net','Juan Ramos','426 Aiken Hunt Cir','Columbia','SC','UNITED STATES','29223-8429','(803) 446-9569','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 21:59:23',0,NULL,3,1,1,1,'\\ ',NULL),(20405,828539021011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sparksterthegreat','sparky001@ymail.com','Mark Tervit','54 Eaglesfield Drive','Bradford','West Yorkshire','UNITED KINGDOM','BD6 2PY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 22:05:06',0,NULL,3,1,11,1,NULL,' HSJA002 英标头'),(20406,670027046013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','phil.m.83','p.mammone@y7mail.com','phil mammone','33 seonaid place','gracemere','Queensland','AUSTRALIA','4702','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 22:13:46',0,NULL,3,1,4,1,'YW868898184CN ',NULL),(20407,615978625004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','sulytalan','mezgyi@gmail.com','Ádám Mezővári','Sajó utca 3','Budapest','Budapest','HUNGARY','1076','0036305436670','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 22:19:57',0,NULL,3,1,21,1,'RA184526520CN\r ','CACN004 '),(20408,917779528012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','sethstratton','sethstratton@hotmail.com','Seth Stratton','1800 E Shelby St','Seattle','WA','UNITED STATES','98112-2022','(206) 552-8816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 22:22:55',0,NULL,3,1,1,1,'/ ',NULL),(20409,917792421012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','diegolasrozas','diegolasrozas80@hotmail.com','Jose Maria Molina Sanchez','C/ Federica Montseny, 1A - Portal 2 Escalera 3 - 2º D','Mejorada del Campo','Madrid','SPAIN','28840','628638576','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 22:51:44',0,NULL,3,1,21,1,'RA184526578CN\r ','GLOT001 '),(20410,669974333013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',29.88,'eastar4','guruun','roannlive@hotmail.fr','Mm COULON VERONIQUE','18 RUE DE SARTROUVILLE','CORMEILLES EN PARISIS','Île-de-France','FRANCE','95240','06.85.60.98.74','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 23:10:43',0,NULL,3,1,11,1,'、 ','HS-11W  退款了\r只发 NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger     \r'),(20411,917804011012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','lieberherr-trade','e_lieberherr@bluewin.ch','Ernst Lieberherr-jun.','St.Gallerstrasse 50','St.Gallen','','SWITZERLAND','9403','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 23:18:35',0,NULL,3,1,21,1,'RA184526581CN\r ',' GLOT001'),(20412,917801563012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','j.romildo','malaquias@gmail.com','José Romildo Malaquias','Rua Maria Cândido Ribas Miranda, 16 Ap 02<br>Jardim Alvorada','Ouro Preto','MG','BRAZIL','35400-000','31 9122 9710','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 23:19:38',0,NULL,3,1,11,1,NULL,' WLAT009'),(20413,917806213012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','midgraphery','jenean@diamondgraphics.net','Jenean ONeal','655 Kennedy Rd','Lexington','KY','UNITED STATES','40511-1820','(859) 252-6578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 23:26:56',0,NULL,3,1,1,1,'/ ',NULL),(20414,917810339012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Mar K. Laird','64 Neff Dr','Canfield','OH','UNITED STATES','44406-1343','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 23:35:41',0,NULL,3,1,1,1,'/ ',NULL),(20415,917813511012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Jin Muller','4800 W Main St','League City','TX','UNITED STATES','77573-1799','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-16 23:46:08',0,NULL,3,1,1,1,'\\ ',NULL),(20416,774297671007,170739867756,'ew Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'au-buy','joeystam','joeystam@gmail.com','Joey Stam','5 Yarra Road','Wakerley','Queensland','AUSTRALIA','4154','0749876125','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 00:39:11',0,NULL,3,1,11,1,NULL,'WLIN014 '),(20417,610616891003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',53.8,'cnfaner','hdl54','dllesser@comcast.net','Diane Lesser','111 Smoke Ridge Rd','North Augusta','SC','UNITED STATES','29860-9620','(803) 279-1808','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-17 00:55:11',0,NULL,3,1,1,1,'/ ',' 一共买了两个苹果鼠标'),(20418,616020729004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',54.7,'cnfaner','blairambra09','blairambra@hotmail.com','Alain Bastonnais','2762 Alaska','Sherbrooke','QC','CANADA','J1E 0G2','(819) 239-1749','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 01:14:13',0,NULL,3,1,3,1,'RA184526697CN\r ','GLOT005 '),(20419,774312380007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','lauralloyd11','ljlloyd@students.latrobe.edu.au','Laura Lloyd','11/122 Edwards Road','Strathdale','Victoria','AUSTRALIA','3550','0439652659','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 01:27:45',0,NULL,3,1,11,1,NULL,'RELO002 '),(20420,670086163013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lenb78','len@thebooths.com.au','Len Booth','26 Moore St','Loganlea','Queensland','AUSTRALIA','4131','0731185757','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 02:03:34',0,NULL,3,1,11,1,NULL,' CACN004'),(20421,774327898007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','akoo2009','akoo_99@hotmail.com','Phil Scott','Unit 2, 37 Willcock Street,<br>Ardross','Perth','Western Australia','AUSTRALIA','6153','0893155531','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 02:26:33',0,NULL,3,1,11,1,NULL,'RELO003 '),(20422,670099872013,230677077093,'NEW Philips Sonicare Flexcare toothbrush hx6932/hx6930/R​S930/R930 Handle',2,'HBPH002',139.8,'eastar4','nocturnal540','galanghp@msn.com','Phong Huynh','540 Marble Springs Rd','lilburn','GA','UNITED STATES','30047-8057','(678) 978-1026','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 03:05:22',0,NULL,3,1,1,1,'\\ ',NULL),(20423,917894723012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.88,'eastar4','gv73','gvilkner@thettgroup.com','gregor vilkner','6205 Blue Jay Way','West Windsor','NJ','UNITED STATES','08550-5394','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 03:55:25',0,NULL,3,1,1,1,'\\ ',NULL),(20424,8881326772763758,111,'890 batteries',2,'',0,'au-buy','firestar09dm','firestar04@mail.ru','Lichko Dmitry','ulica Slavanskaya, 11','Borovlyany Minskiy rayon ','','BELARUS','223053 ','',NULL,NULL,NULL,'2012-01-17 03:59:23',0,NULL,3,0,21,1,'RA184526462CN \rRA184526462CN\r',NULL),(20425,670109652013,230641247782,'New Strawberry Anti-UV Sun/Rain parasol stick umbrella',1,'UM00013',21.99,'eastar4','momomori','maliyura@hotmail.com','Maor Ouzana','2631 NE 214th St','Miami','FL','UNITED STATES','33180-1125','(305) 335-8944','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 04:04:16',0,NULL,3,1,1,1,'\\ ',NULL),(20426,766279614008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','falcon-lord','falcon_lord@hotmail.com','Jason van Moorst','29 Seperation St','Fairfield','Victoria','AUSTRALIA','3078','0408369974','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 04:11:05',0,NULL,3,1,11,1,NULL,'BALO009 '),(20428,826293464011,320691683012,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',71.99,'eastar4','etiennefbetienne','hulk_still_rules24@hotmail.com','etienne fortier-brion','275 av. deslacasse','laval','QC','CANADA','h7k1j3','(514) 726-0798','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 04:31:55',0,NULL,3,1,3,1,'RA184526710CN\r ',' GLSG001'),(20429,774362285007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','darcy.manks','dgman1@student.monash.edu','darcy manks','75 tuckers rd clyde','clyde','Victoria','AUSTRALIA','3978','0406867870','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 05:03:26',0,NULL,3,1,11,1,NULL,'RELO003 '),(20430,917911100012,220886923591,'New lady lotus leaves outdoor sun/rain stick Umbrella',1,'UM00002',14.95,'eastar4uk','mephiticaltok','flesola@hotmail.com','Emma Davies','29 Koolinda cres','Karama','Northern Territory','AUSTRALIA','0812','0889415696','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 05:06:17',0,NULL,3,1,11,1,NULL,'UM00002 \rdark pinky   深粉色'),(20431,917929062012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','globalspan2012','globalispan@gmail.com','Shengzou Xie','29 Bridge Trl','Irvine','CA','UNITED STATES','92618-8849','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 06:40:56',0,NULL,3,1,1,1,'\\ ',' '),(20432,828695747011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','brianoz2009','brianrowan@bigpond.com.au','Brian Rowan','1 Monza Court','Deer Park','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 07:55:35',0,NULL,3,1,3,1,'RA184526737CN\r ',' LGRM001'),(20433,774395262007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','yrightme','arthus@optusnet.com.au','S Arthur','C/- Warringah Council<br>725 Pittwater Road','Dee Why','New South Wales','AUSTRALIA','2099','0299422111','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 08:09:55',0,NULL,3,1,11,1,NULL,'OTGR001 \r客户说可以春节后再发货'),(20434,670147309013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',95.98,'eastar4','whitethunderelectric','magick_fire@hotmail.com','Kris Daly','PO Box 759','Fyshwick','Australian Capital Territory','AUSTRALIA','2609','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 08:19:27',0,NULL,3,1,3,1,'RA184534353CN ',' 再发一个New Portable HD 720P Car Dashboard Camera Accident DVR\rGPS0006\r'),(20435,917949985012,220917856761,'4 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*4',248.99,'eastar4','ilott4274','gaililott62@hotmail.com','rick ilott','6 third ave. cheltenham','adelaide','South Australia','AUSTRALIA','5014','0418834927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 08:26:39',0,NULL,3,1,4,1,'YW868898151CN',' '),(20436,917949660012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','zelig23','get23@hotmail.com','guillaume vonthron','89, rue Lamarck','paris','Ile-de-France','FRANCE','75018','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 08:23:31',0,NULL,3,1,3,1,'RA184534469CN ','GLOT005 '),(20437,669228805013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jimmyaustinau','james.austin@terransoftware.com','James Austin','5 Mitchelton Ct','Melbourne','Victoria','AUSTRALIA','3133','0398018151','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 08:42:08',0,NULL,3,1,11,1,'BJ01669768 ',' CACN004'),(20438,766328251008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','loytek','woytek25@o2.pl','Wojciech Hakel','Wyszyńskiego 4b/107','Białystok','podlaskie','POLAND','15888','506 706737','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-17 09:14:23',0,NULL,3,1,22,1,'BJ01669761 ','RELO001 '),(20439,828716345011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',38.99,'eastar4uk','bernjay75','jaybernaldez0300@googlemail.com','jay bernaldez','10<br>julia street','kirwan','Queensland','AUSTRALIA','4817','07771556715','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 09:31:51',0,NULL,3,1,3,1,'RA184534490CN ','LGGL002 '),(20440,917966675012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',83.97,'eastar4','globalspan2012','globalispan@gmail.com','Loise Day','2951 Grant Ave','Philadelphia','PA','UNITED STATES','19114-1087','(503) 515-6054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 09:35:28',0,NULL,3,1,1,1,'LK180284672CN ',NULL),(20441,828720990011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','bulcsu','koppany.bulcsu@freemail.hu','ProgAdat Kft. Koppány Bulcsú','Máriássy utca 7.','Budapest','','HUNGARY','1095','+36-30-98-46-272','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 09:50:56',0,NULL,3,1,22,1,'BJ01669763 ',' CC00002'),(20442,828722646011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',19.98,'eastar4','tuan_ny24','tuan_ny@yahoo.com','Huong Trang Vu','70/313 Harris St','Pyrmont, Sydney','New South Wales','AUSTRALIA','2009','61425566063','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 09:57:53',0,NULL,3,1,11,1,'BJ01669767 ',' CASS002'),(20443,670168837013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','lisbeth.thrane.dk','lisbeth.thrane@gmail.com','Lisbeth Mikkelsen','Ballevej 34, Skarresø','Ryomgård','_UAES_NULL_','DENMARK','8550',' 32160402','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 10:30:17',0,NULL,3,1,21,1,'RA184534588CN ',' MOSA004'),(20444,616114981004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','raym259','messenger.ray@talktalk.net','RAYMOND MESSENGER','55 Cypress park, ESH WINNING','Durham','Durham','UNITED KINGDOM','DH79JD','01913735922','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 11:07:27',0,NULL,3,1,3,1,'RA184534526CN ','HSJA002 \r英标'),(20445,917997347012,220816379674,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT001*3',78.99,'eastar4uk','titia58200','titia77270@yahoo.fr','Hanriot Laetitia','5 route du bout du monde, le Gué botron','Saint Père','Bourgogne','FRANCE','58200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 11:29:27',0,NULL,3,1,3,1,'RA184534605CN ','GLOT001*3 '),(20446,917998669012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','busterbrownhil','jmhildreth_mhs@yahoo.com','Jack Hildreth','10745 Kern Rd','Osceola','IN','UNITED STATES','46561-9399','(574) 633-4165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 11:32:51',0,NULL,3,1,17,0,'LK184226542CN ',NULL),(20447,828751218011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',103.99,'eastar4uk','pitatom2002','tom.siomopoulos@epworth.org.au','Tom Siomopoulos','4 Miriam Close','Wantirna South','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 11:45:55',0,NULL,3,1,3,1,'RA184534512CN ','GLOT001*4 '),(20448,828752653011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','nprivat','nprivat@t-online.de','Norbert Schmale','Dalbker Strasse 112','Oerlinghausen','','GERMANY','33813','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 11:52:22',0,NULL,3,1,22,1,'BJ01669760 ',' ADAK002'),(20449,670185307013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','baloomp','gpfire1@gmail.com','Gavin phair','18 Murray Curcuit','upper coomera','Queensland','AUSTRALIA','4209','0243908070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 11:58:13',0,NULL,3,1,11,1,'BJ01669756 ',' HSSA002  澳标头'),(20450,670189407013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','n.shumkov','nshumkov@yandex.ru','Nikolay Shumkov','ul. Ural\'skaya ,d.55, kv.35','Perm','Permskii','RUSSIAN FEDERATION','614107','+79028388845','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 12:22:16',0,NULL,3,1,11,1,'BJ01669755 ','OT00004 '),(20451,918022206012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','tomaz_pfeuti','tpfeuti@uol.com.br','Tomaz Pfeuti','Av. Monteiro Lobato, 1221','Embu','São Paulo','BRAZIL','06846-510','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 12:52:06',0,NULL,3,1,3,1,'RA184534543CN ',' GLOT001'),(20452,616125495004,140630817200,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',34.99,'cnfaner','driveko','kisselevv@gmail.com','Vladimir Kisselev','Chingirlauskaya str. 114','Aksay','West Kazakhstan, Burlinskiy region','KAZAKHSTAN','090300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 12:58:53',0,NULL,3,1,3,1,'RA184534486CN ','CC00002 '),(20453,670198752013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',5.98,'eastar4','jeffakos','jeffakos@gmail.com','Nikos Sakellariou','Mikras Asias - Gipedo Toumpas','Thessaloniki','','GREECE','54351','+30 2310 954050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 13:04:22',0,NULL,3,1,22,1,'BJ01669766 ',' OTCN001'),(20454,610826985003,130598387172,'2 pairs of New Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',140.99,'cnfaner','fmmedina','kaotxu@gmail.com','Francisco Moya Medina','Calle Los Pinos, 14-C 5º-B','Alcorcón','Madrid','SPAIN','28922','654214204','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 13:06:53',0,NULL,3,1,21,1,'RA184534968CN ','GLSG001*2 '),(20455,828781092011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','ivohospodka','ivo.hospodka@multitone.cz','Ivo Hospodka','Jezerni 10','Prague','Prague','CZECH REPUBLIC','15000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 13:32:40',0,NULL,3,1,11,1,'BJ01669753 ','RCLO007+POLO001+RCLO008*4\r欧标 '),(20456,616153513004,140482242701,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET track#',1,'HSNO003',23.7,'cnfaner','viszlailori','burn-it@freemail.hu','Lorand Viszlai','Jozsef Attila 20.','MUCSONY','B-A-Z','HUNGARY','3744','003620-2049508','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 14:23:37',0,NULL,3,1,21,1,'BJ01669758 ','HSNO003\r欧标 '),(20457,761231039008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','mavic00','mavic00@hotmail.com','Alexis Desjardins','6760 rue des Bouleaux','st-hyacinthe','QC','CANADA','J2R 1C4','(450) 253-9629','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-17 14:30:34',0,NULL,3,1,11,1,'BJ01669748 ','CALO001 '),(20458,771280158007,170746939505,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'au-buy','ecnav67','vancecrofoot@gmail.com','Vance Crofoot','1861 N Van Ness Ave<br>Apt 305','Los Angeles','CA','UNITED STATES','90028-5680','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-17 14:53:13',0,NULL,3,1,1,1,'LK183121948CN ',NULL),(20459,918071426012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','cool-champ','pbhaskar@btinternet.com','P Bhaskar','10 Chedworth Court<br>Ingleby Barwick','Stockton on Tees','Cleveland','UNITED KINGDOM','TS17 5GL','01642308721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 15:11:25',0,NULL,3,1,3,1,'RA184534530CN ','HSJA002\r英标 '),(20460,918074580012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',6.98,'eastar4','alexmar-apollon','pantiossif@gmail.com','Pantelis Iossif','Andrea Kalvou 23','Nicosia','','CYPRUS','2107','35799510047','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 15:18:52',0,NULL,3,1,22,1,'BJ01669757 ',' OTCN003'),(20461,918090609012,220864660846,'New Pretty Cat w/Lotus Leaves Trim 3-Section Umbrella',1,'UM00039',19.99,'eastar4','sashapetyx','sashapetyxov@yandex.ru','Aleksandr  Petykhov','pos.Sadakovskiy<br>ul.Lunnaua, dom 7','Kirov','Kirovskaya obl','RUSSIAN FEDERATION','610013','89091333374','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 16:01:15',0,NULL,3,1,17,0,'RA184548905CN\r ',NULL),(20462,616179454004,140626375035,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',14.1,'cnfaner','r-why-u','frank@hadjigeorgiou.com','Frangiskos Hadjigeorgiou','17, Demetriou Glinou','Limassol','Limassol','CYPRUS','3095','99344443','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 16:10:33',0,NULL,3,1,21,1,'RA184534645CN ','OTCN005 '),(20463,828843048011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','captainnutter1982','captainrene17@hotmail.com','CHRIS REYNOLDS','18 Sea Crest Road','Lee On The Solent','Hampshire','UNITED KINGDOM','PO13 8HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 16:23:26',0,NULL,3,1,3,1,'RA184534628CN ','LGAD001 '),(20464,918101078012,220915146749,'New Auto On Gentelman Cat Rain/Sun J-handle Umbrella w/14 Skeleton',1,'UM00050',24.99,'eastar4','sashapetyx','sashapetyxov@yandex.ru','Aleksandr  Petykhov','pos.Sadakovskiy<br>ul.Lunnaua, dom 7','Kirov','Kirovskaya obl','RUSSIAN FEDERATION','610013','89091333374','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 16:26:34',0,NULL,3,1,3,1,'RA184548905CN\r ',' 绅士猫咪波点晴雨伞 弯柄长柄伞   \r再发一个可爱猫咪波浪边 三折伞  \rUM00050  UM00039'),(20465,828854495011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','pancir','candycarr@windstream.net','Candice S. Carr','3652 Shaffer Rd','Rock Creek','OH','UNITED STATES','44084-9728','(440) 478-2748','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 16:50:17',0,NULL,3,1,1,1,'LK182519971CN',NULL),(20466,610883359003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','pauinn','pauinnn@gmail.com','jose paulo zambi filho','Escadaria Serrat, 58<br>Centro','Vitória','Espirito Santo / ES','BRAZIL','29015-610','+552799999993','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 16:41:32',0,NULL,3,1,3,1,'RA184534659CN ','MOOE003 \rOEM的 '),(20467,918122301012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','m2keko','marcel.pis@gmail.com','Marcel Pis','Pannonska 12, byt 196','Svaty Jur','','SLOVAK REPUBLIC','90021','421904478500','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:11:42',0,NULL,3,1,22,1,'BJ01669752 ',' Marcel Pis\rPannonska 12/196\rSvaty Jur 90021\rSLOVAKIA  \r421904478500  改这个地址\r'),(20468,670265877013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','eddie5350','eddie@crawford1520.fsnet.co.uk','Eddie Crawford','M Barnwell Services Limited<br>14-16 Murray Place, Righead Industrial Estate','Bellshill','Lanarkshire','UNITED KINGDOM','ML4 3LP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:13:52',0,NULL,3,1,3,1,'RA184534574CN ',' LGAD001'),(20469,828884031011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','grin1975igor','grin1975@gmail.com','Anna Osadchaja','Potemkina 13A- 5','Zelenogradsk','Kaliningrad','RUSSIAN FEDERATION','238326','+79114939934','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 17:55:47',0,NULL,3,1,3,1,'RA184534565CN ','LGAD001 '),(20470,783763056001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','dhar2889','crowndrinking@yahoo.com','Dandre Harris','7643 long st','lenexa','KS','UNITED STATES','66216','(913) 601-0617','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-17 18:01:51',0,NULL,3,1,1,1,'LK183148035CN ',NULL),(20471,828891338011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',13.97,'eastar4','lilide26','laetitia.dereuse@sfr.fr','DEREUSE LAETITIA','LE CLOS MALET','VINSOBRES','Rhône-Alpes','FRANCE','26110','0676427795','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 18:11:14',0,NULL,3,1,11,1,'BJ01669743 ',' BTHP3000'),(20472,918159614012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','martyregan','martyregan63@sbcglobal.net','Martin  J Regan','321 S Sangamon St<br>Unit 510','Chicago','IL','UNITED STATES','60607-3624','(312) 997-2465','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 18:20:52',0,NULL,3,1,1,1,'LK178748377CN ',NULL),(20473,670294658013,230539874851,'New NOKIA HS-11W BLUETOOTH HEADSET HS 11W+adapter',1,'HSNO023',13.99,'eastar4','anderson.jackson3','andersonjackson3@gmail.com','Anderson Jackson III','6900 Preston Rd<br>Apt 1621','Plano','TX','UNITED STATES','75024-2531','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 18:38:00',0,NULL,5,1,18,1,NULL,'已经退款'),(20474,783535533001,110806566637,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',10,'GPS0010',806.42,'buysia','alartel','alartel@hotmail.com','JUAN TORRES','809 Silverwood<br>DALTON','DALTON','GA','UNITED STATES','30720-3616','(706) 537-9204','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-17 18:56:53',0,NULL,3,1,4,1,'YW868896865CN \r已发8个TK102，电池未发','先不发battery  只发8个 Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102 '),(20475,918134425012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','tweedybird','deckit@cableone.net','Brian Twede','1035 Lowell Dr','Idaho Falls','ID','UNITED STATES','83402-7100','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 19:03:56',0,NULL,3,1,1,1,'LK184498775CN ',NULL),(20476,918194014012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','tropicguy','tropicguy@msn.com','Albert Welbel','3127 N Carriageway Dr','Arlington Heights','IL','UNITED STATES','60004','(847) 922-5277','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 19:21:31',0,NULL,3,1,1,1,'LK176578763CN ',NULL),(20477,670312779013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','d_racmat','d_racmat@hotmail.com','Debora Rachmat','11162 Wildflower Rd','Temple City','CA','UNITED STATES','91780','(626) 455-0672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 19:22:44',0,NULL,3,1,1,1,'LK179465289CN ',NULL),(20478,670333887013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','quicbuy','quicbuy@yahoo.com','CHUNTO CHAN','3035 E Patrick Ln<br>Ste 14','Las Vegas','NV','UNITED STATES','89120-3478','(626) 617-5167','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 20:12:08',0,NULL,3,1,1,1,'LK182991761CN ',NULL),(20479,828983393011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','manuskool','manugalca@gmail.com','Manuel Gálvez Calero','C/ Virgen de Guaditoca, 23','Guadalcanal','Andalucía Ceuta y Melilla','SPAIN','41390','644044561','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 20:55:11',0,NULL,3,1,3,1,'RA184534472CN ','GLOT001*2\r贴确认签 \r客户想确认签收时间  想快点'),(20480,828992492011,320791705447,'New genuine Garmin GPS 12XL GPS Receiver',1,'GPS0009',96.99,'eastar4uk','assisvanderli','vanderliassis@yahoo.com.br','Vanderli Assis','Peter-Dorfler-Str 51','Lindenberg','','GERMANY','88161','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 21:15:49',0,NULL,3,1,4,1,'YW868896854CN ','GPS0009 '),(20481,918272503012,220901458242,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones red long cable',1,'HSPH002',22.99,'eastar4uk','koshitanto','ktanto@gmail.com','Justin Stevanz','Tiefenhofstrasse 68','Wadenswil','','SWITZERLAND','8820','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 21:33:09',0,NULL,3,1,22,1,'BJ01669751 ','HSPH002 '),(20482,766611591008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.99,'au-buy','constandinosp','constandinos_papadjiakos@hotmail.com','Constandinos Papadjiakos','40 Aiolou str. Kapsalis 4 Court Flat 203','Limassol','Limassol Cyprus','CYPRUS','3020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-17 21:36:13',0,NULL,3,1,22,1,'BJ01669746 ','SHLO009 '),(20483,918275219012,220816384329,'NIB 3D Active Shutter TV Glasses 4 SHARP LC-40LE835U',1,'GLOT001',26.99,'eastar4uk','jachym64','kumhala@quick.cz','Josef Kumhala','M. Pujmanové 1123/26','Havířov-Šumbark','výchozí','CZECH REPUBLIC','736 01','(420) 606090821 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 21:41:52',0,NULL,3,1,3,1,'RA184534415CN ','GLOT001 '),(20484,766616824008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.99,'au-buy','agreen1982','greenith1982@gmail.com','Andrew Green','Level 44, Ernst<br>680 George Street','Sydney','New South Wales','AUSTRALIA','2000','0415322983','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 21:48:35',0,NULL,3,1,3,1,'RA184534424CN ','GLOT001 '),(20485,827803010002,120845046354,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'buysia','aroca1977','aroca.josecarlos@gmail.com','JOSE ARLOS AROCA NAVARRO','CALLE ZULOAGA Nº2;4º-4','MIJAS','Andalucía Ceuta y Melilla','SPAIN','29649','669182775','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-17 22:08:03',0,NULL,3,1,22,1,'BJ01669759 ',' GPS0010'),(20486,918296644012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','busterbrownhil','jmhildreth_mhs@yahoo.com','Jack Hildreth','10745 Kern Rd','Osceola','IN','UNITED STATES','46561-9399','(574) 633-4165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 22:18:22',0,NULL,3,1,1,1,'LK184226542CN ',' 再发一个兼容眼镜  一共两副'),(20487,829038865011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','riguu','enricroberto@gmail.com','Enric Roberto Duran','Plaça Palma, 12','La Selva del Camp','Cataluña','SPAIN','43470','686056392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 22:54:14',0,NULL,3,1,21,1,'RA184534591CN ','SAFI001*2 '),(20488,670394691013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'eastar4','superneontimur','superneon83@yandex.ru','Timur Mazmishvili','Turistov 11a<br>16','Murmansk','Murmanskaia oblast','RUSSIAN FEDERATION','183038','+79522946293','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 23:02:04',0,NULL,3,1,11,1,'BJ01669764 ',' WLIN014'),(20489,918331326012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','falmatsea','falmatsea@gmail.com','Mr. Alen Mulic','San Salvador, Flat NRU. 7<br>Triq Depiro','SLIEMA','','MALTA','SLM 2033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 23:38:07',0,NULL,5,0,18,0,NULL,'已退款'),(20490,611023263003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','manuru17041990','manuel.fernandez-clemente@orange.fr','Manuel FERNANDEZ-CLEMENTE','30 residence du comte dauchy','Saint just en chaussee','OISE','FRANCE','60130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 23:44:53',0,NULL,3,1,3,1,'RA184534509CN ','MOOE003\rOEM的 '),(20491,829060865011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','warcon4166','warcon@juno.com','Warren Painter','53 Long Acre Rd','Scottsville','VA','UNITED STATES','24590-4634','(434) 286-3742','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 23:54:13',0,NULL,3,1,1,1,'LK170054255CN ',' '),(20492,918350128012,220568348189,'NEW GENUINE NOKIA BH-300 BLUETOOTH HEADSET BH 300',1,'HSNO013',15.4,'eastar4','bebutran','thuyhuetran@yahoo.com.au','thuy tran','28 vale st<br>canley vale','sydney','New South Wales','AUSTRALIA','2166','0287044219','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 00:33:44',0,NULL,3,1,11,1,'BJ01669762 ',' 澳标头 HSNO013'),(20493,670426572013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',132.99,'eastar4','jesp3285','jspaqgr@yahoo.com','Jose Esparza','749 Cougar Ranch Rd.','Beaumont','CA','UNITED STATES','92223','(909) 709-1113','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 01:17:31',0,NULL,3,1,1,1,'LK184282411CN ',''),(20494,829086716011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',53.98,'eastar4uk','livuca96','liv_london@yahoo.co.uk','lliviu cristea','silkstream road<br>10','londra','London','UNITED KINGDOM','ha8 0da','07712400497','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 01:19:43',0,NULL,3,1,3,1,'RA184534631CN ','GLOT001 '),(20495,774773360007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','katyo01','bass.boy@hotmail.com','Joshua Truscott','70 Avondale Rd','Cooranbong','New South Wales','AUSTRALIA','2265','0450712743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 01:29:42',0,NULL,3,1,11,1,'BJ01669765 ','RELO003 '),(20496,827873407002,120841235559,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'buysia','martynah','s_martyna@yahoo.com','Martyna Hnat','65 linden st','carteret','NJ','UNITED STATES','07008-2614','(732) 900-9431','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-18 01:44:30',0,NULL,3,1,1,1,'LK178981992CN ',NULL),(20497,918377511012,220917833707,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',4,'GPS0010',130.6,'eastar4','x_k3lli_x','k3lli@live.com.au','Hang Cao','171 Stockmans Way<br>Kensington','Melbourne','Victoria','AUSTRALIA','3031','61434643464','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 01:58:19',0,NULL,3,1,4,1,'RA184534614CN ',' GPS0010  '),(20498,8881326852327407,111,'Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.99,'aliexpress','1006328812 ','mmart1522@bresnan.net','Mary Martinez	','1009 Waukesha Avenue','Helena','Montana','UNITED STATES	','59601','+406 443 7337',NULL,NULL,NULL,'2012-01-18 02:05:27',0,NULL,3,1,1,1,'LK108776977CN ','HBPH003*1 '),(20499,611054648003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','plan20','jdiego24@aol.com','juan salazar','p.o. box 10814','salinas','CA','UNITED STATES','93912','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-18 02:19:09',0,NULL,3,1,1,1,'LK180549233CN ',NULL),(20500,8881326853205094,111,'New genuine Grohe Shower head holder made in Germany',1,'OTGR003',21.99,'aliexpress','1006329580 ','1@1.1','Roman Adyev	','13, bld 3, apt 300, Sayanskaya str.','Moscow','Moscow','RUSSIAN FEDERATION	','111531','+495 963 7626801',NULL,NULL,NULL,'2012-01-18 02:20:05',0,NULL,3,1,3,1,'RA184534557CN ','OTGR003*1 '),(20501,766696026008,180772181803,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'au-buy','scottwn2011','scott_n@rocketmail.com','Scott Nicholas','130 Stillwell\'s deviation','Avonsleigh','Victoria','AUSTRALIA','3782','0417204230','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 01:56:47',0,NULL,3,1,11,1,'BJ01669770 ','HBPH003 '),(20502,829109196011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','rgur5695','gurmanr@hotmail.com','ROMAN GURMAN','1008 ARBOR CT.','MOUNT PROSPECT','IL','UNITED STATES','60056','(847) 593-1037','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 02:32:18',0,NULL,3,1,1,1,'LK182979641CN ',NULL),(20503,8881326854672807,111,'PLANTRONICS ALTEC ADAPTER AUDIO BACKBEAT 903/ 906',1,'OTPL001',24.99,'eastar4uk','alik911','alik03@gmail.com','Albert Trakhtman','Shirokaya, 4','Donetsk ','','UKRAINE','83045','',NULL,NULL,NULL,'2012-01-18 02:44:32',0,NULL,3,1,21,1,'RA184534702CN ','OTPL001 '),(20504,8881326855525161,111,'Original Apple AirPort Extreme WiFi Card 54M',15,'WLAP002',185,'eastar4uk','stekkie18221','dennisgeerts@hotmail.com','Dennis Geerts','Vuntuslaan 9','1231NP Loosdrecht','','ORIGINAL APPLE AIRPORT EXTREME WIFI CARD 54M','','+ 31619382993',NULL,NULL,NULL,'2012-01-18 02:58:45',0,NULL,5,0,18,0,NULL,'WLAP002 \r录错了 已经重新录了'),(20505,8881326856588988,111,'Original Apple AirPort Extreme WiFi Card 54M',15,'WLAP002',185,'eastar4uk','stekkie18221','dennisgeerts@hotmail.com','Dennis Geerts','Vuntuslaan 9','1231NP Loosdrecht','','NEDERLAND','','+ 31619382993',NULL,NULL,NULL,'2012-01-18 03:16:28',0,NULL,3,1,12,1,'2100884693 ',' 客户要发DHL'),(20506,918402935012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','ear425goggles','erin_ashley425@yahoo.com','Andy Huffman','244 Hanging Moss Dr','Oviedo','FL','UNITED STATES','32765-9370','(304) 951-5519','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 03:21:45',0,NULL,3,1,1,1,'LK182339555CN ',NULL),(20507,918409878012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','paulja1970','p_j_aiken@yahoo.co.uk','Paul Aiken','C/- UnitingCare Moreland Hall<br>26 Jessie St','Moreland','Victoria','AUSTRALIA','3058','0393848867','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 03:42:22',0,NULL,5,0,18,0,NULL,'已退款 '),(20508,918411079012,220917833326,'New 8 pcs Professional Piano Tuning Tool Kit Musical Instruments',1,'OT00001',62.99,'eastar4','cppspl1986','charlespywell@abex.com.au','Charles Pywell','PO Box 32','Canungra','Queensland','AUSTRALIA','4275','0755435553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 03:46:53',0,NULL,3,1,4,1,'YW868898092CN\r ','客户同意节后发 \r新地址\rCharles Pywell\r2268 Tamborine Mountain Road\rCanungra\rQueensland 4275\rAustralia\r\r'),(20514,616399467004,140515701798,'New GENUINE NOKIA BH-205 BLUETOOTH HEADSET track#',1,'HSNO009',16.2,'cnfaner','magdysaleeb','nokia_elpaltalk@yahoo.com','nisseim botros','33 mary st<br>gorokan','gorokan','New South Wales','AUSTRALIA','2263','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 06:12:18',0,NULL,3,1,11,1,'BJ01669734 ','HSNO009 '),(20509,611072314003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.49,'cnfaner','jorgecuricosta','jorgeecc@msn.com','Valdemir Costa','Rua Xavier da Silva 681','Paranaguá','Paraná','BRAZIL','83203620','+55 41 3423-3555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 03:51:28',0,NULL,3,1,11,1,'BJ01669737 ','MOMI002\r黑色 '),(20510,829139999011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','tmcd2484','timbo159878@yahoo.com','Timothy McDonald','2395 Saffron CT','Tracy','CA','UNITED STATES','95377-8672','(209) 495-9525','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 04:28:09',0,NULL,3,1,1,1,'LK176813095CN ',NULL),(20511,827926531002,120841235559,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'buysia','s.luepker','s.luepker@juno.com','Steven Luepker','5729 Rosa Ave','Saint Louis','MO','UNITED STATES','63109-3257','(314) 752-9695','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-18 05:17:37',0,NULL,3,1,1,1,'LK181918779CN ',NULL),(20512,829154939011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',66.99,'eastar4uk','sniperfsl212','cote.remi212@hotmail.com','Rémi Côté','10289 133rd St<br>Suite 408','Surrey','BC','CANADA','V3T 0B1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 05:48:50',0,NULL,3,1,3,1,'RA184548825CN ','HSPH008 '),(20513,827933117002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','fergie937629','analitik_orel@list.ru','Anna Galieva','Rowinskaya,37/101','Orel','RU','RUSSIAN FEDERATION','302028','+79803632388','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-18 05:50:14',0,NULL,3,1,3,1,'RA184548817CN ',' LGAD001'),(20515,8881326867261063,111,'Jabra BT250V',1,'HSJA001',0,'eastar4','livthrume','san.pr.business@gmail.com','San Holder','30 Old Clayton Ct','Columbia','SC','UNITED STATES','29205-4539','',NULL,NULL,NULL,'2012-01-18 06:14:21',0,NULL,3,1,1,1,'LK108996902CN ',' 补发 全套 E邮宝改一个'),(20516,8881326868403629,111,'兼容眼镜 补发',2,'GLOT001',0,'eastar4','acarv4414','tash34c@aol.com','Carmen Carvajal','300 NW 62ND Ct','Miami','FL','UNITED STATES','33126','',NULL,NULL,NULL,'2012-01-18 06:33:23',0,NULL,3,1,1,1,'LK003795733CN ',' 用退回来的老款包装'),(20517,670240743013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','mni14','mnazir83@gmail.com','Mohamad Nazir Ismail','13, Jalan Raja Abdullah Lima,<br>Seksyen 9/19E','Shah Alam','Selangor','MALAYSIA','40100','0136260153','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 06:37:38',0,NULL,3,1,2,1,'30118703683\r ',NULL),(20518,8881326872930140,111,'5300 全高通用卡',1,'WLIN010',0,'eastar4','ookiininjin','jrx_2000@hotmail.com','Jeremy Christie','6769 Chateau Crt.','Delta','BC','CANADA','V4E3M7','(604) 364-2207',NULL,NULL,NULL,'2012-01-18 07:48:50',0,NULL,3,1,11,1,'BJ01669735 ',' 补发 已经补差价 WLIN010'),(20519,829176505011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','al_ma_33','al_ma_33@yahoo.co.uk','Manta Alexandru','Ispirescu Petre nr. 38, bl.P72B, et.3, ap.14., sector 5','Bucuresti','','ROMANIA','051028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 07:49:57',0,NULL,3,1,22,1,'BJ01669736 ',' ADAK002'),(20520,918464605012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','metlic_nn','v.shestoperov@gmail.com','Vitaly Shestoperov','Berezovskaya 114-207','Nizhniy Novgorod','','RUSSIAN FEDERATION','603157','79202960700','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 08:04:06',0,NULL,3,1,3,1,'RA184534680CN ',' GLOT001'),(20521,766774129008,180741191602,'2 pairs DLP-Link 3D Ready Projector Shutter Glasses',1,'GLOT005*2',113.98,'au-buy','bainbridge4_123','bainbridge4@hotmail.com','Bradley Bainbridge','10 Grose st','Murray Bridge','South Australia','AUSTRALIA','5253','0424999537','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 08:18:56',0,NULL,3,1,3,1,'RA184534676CN ','GLOT005*2 '),(20522,917989389012,220747230787,'NEW GENUINE NOKIA BH-302 BLUETOOTH HEADSET BH 302',1,'HSNO014',12.65,'eastar4uk','mixy.d','dombrovszki@gmail.com','Miklós Dombrovszki','Szarazhegy utca 33.','Budapest','Budapest','HUNGARY','1171','0036309666495','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 08:23:31',0,NULL,3,1,22,1,'BJ01669733 ','HSNO014 \r客户要车充 已付款 '),(20523,8881326876910316,111,'New Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',16.99,'aliexpress','1006331603 ','ralf@r-alf.de','Ralf Kraus	','Rudolf-Breitscheid-Strasse 25','Schwedt','Brandenburg','GERMANY','16303','+049 151 58954127',NULL,NULL,NULL,'2012-01-18 08:55:10',0,NULL,3,1,21,1,'RA184534662CN ','WLAT003*1 '),(20524,829198330011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','deus_ex-machina','pete.exmachina@gmail.com','Pierre Linchet','425, chaussee de Louvain','Ohain Lasne','','BELGIUM','1380','0473206866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 09:30:07',0,NULL,3,1,22,1,'BJ01669732 ','RCLO007+POLO001+RCLO008*4\r欧标 '),(20525,918489243012,220872406392,'4 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT001*4',175.99,'eastar4','ichirva','irina_chirva@mail.ru','Irina Chirva','mikroraion 5, dom 6, kv 31','Pyt-Yakh','Tyumen region','RUSSIAN FEDERATION','628383',' 9028521136','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 09:53:40',0,NULL,3,1,3,1,'RA184526825CN\r ','GLOT001*4 '),(20526,829206225011,320820765862,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook BH 104 long-lasting',1,'HSNO034',8.99,'eastar4uk','device7','kompiuteriai77@gmail.com','Arunas Ciuksys','Ratnycios g. 15','Kaunas','','LITHUANIA','44419','+370 684 09811','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 10:01:53',0,NULL,3,1,22,1,NULL,'HSNO034\r欧标 '),(20527,616434156004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','lenben_123','leninbude@talktalk.net','Len Benson','10 Valley Road','Bude','Cornwall','UNITED KINGDOM','EX23 8EP','01288354264','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 10:20:04',0,NULL,3,1,3,1,'RA184526839CN\r ','HSJA002 \r英标 '),(20528,829227803011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','thc1968','dkritseli@yahoo.gr','KARAPAPAS ATHANASSIOS','default','KRESTENA','ILIA','GREECE','27055','2625022644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 11:25:13',0,NULL,8,0,17,0,NULL,NULL),(20529,829228466011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','thc1968','dkritseli@yahoo.gr','KARAPAPAS ATHANASSIOS','default','KRESTENA','ILIA','GREECE','27055','2625022644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 11:26:25',0,NULL,3,1,21,1,'RA184526856CN\r ',' GLOT001  一共买了两幅眼镜（合并订单）'),(20530,670537430013,230393146792,'2.1 Acer Aspire 6930 6530 6930G Bluetooth Module+cable',1,'BTAC2113',12.39,'eastar4','gretannn','greta.rudzianska@hotmail.com','Greta Rudzianska','paribio 26-29','Vilnius','','LITHUANIA','08-013','860018147','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 12:05:58',0,NULL,3,1,22,1,' ',' BTAC2113'),(20531,918532954012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',94.99,'eastar4','beach_matt','mbeach143@hotmail.com','Matthew Beach','1314 Burkholder DR','Burlington','ON','CANADA','L7M 4V6','(905) 635-8338','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 12:24:41',0,NULL,3,1,3,1,'RA184526900CN\r ',' PSGL001'),(20532,829245279011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',8,'CASS003',55.12,'eastar4uk','andre.iacono','lorenalive@hotmail.co.uk','Lorena Oliveira','SRTVS, Qd 701 - Bloco K - Sala 725<br>Edificio Embassy Tower','BRasilia','Brasil','BRAZIL','70340908','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 12:28:48',0,NULL,3,1,3,1,'RA184534954CN\r ','CASS003 '),(20533,670542773013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','rriman','riman.richard@gmail.com','Richard Riman','E. Krasnohorske 1290/2','Havirov','','CZECH REPUBLIC','73601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 12:31:58',0,NULL,3,1,11,1,' ',' CACN004'),(20534,918548020012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','mccann_ni','craig.mccann@btopenworld.com','Craig McCann','6 Clanbrassil Gardens','Portadown','Armagh','UNITED KINGDOM','bt63 5yd','02838334479','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 13:09:45',0,NULL,3,1,3,1,'RA184534897CN\r ','SAFI001 '),(20535,918553434012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','lollie4545','laurenlm@tpg.com.au','Lauren Morrison','92 Victoria St, Werrington','Sydney','New South Wales','AUSTRALIA','2747','0296233182','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 13:22:23',0,NULL,3,0,11,1,NULL,' HSNO005  澳标头'),(20536,670528286013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.96,'eastar4','jlas8665','tp.lasternas-freres@wanadoo.fr','Jean François LASTERNAS','TP LASTERNAS FRERES<br>LA CHAMPAGNE','ST CYR LES CHAMPAGNES','Aquitaine','FRANCE','24270','05.53.62.40.22','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 13:24:11',0,NULL,3,1,3,1,'RA184534852CN\r ',' HSNO019'),(20537,918554419012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',6.98,'eastar4','steve_strings','custom22@tiscali.co.uk','Steve Courtie','Flat 27C Leigh Terrace<br>Old Castletown Road','DOUGLAS','Isle of Man','UNITED KINGDOM','IM1 5AW','01624623420','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 13:23:27',0,NULL,3,1,11,1,'、 ',' OTCN003'),(20538,670560075013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','11cvi','vladimir.i.chernov@gmail.com','Vladimir Chernov','ul. Kommunisticheskaya d.30 kv.11','Novocheboksarsk','Chuvashiya','RUSSIAN FEDERATION','429950','+79176542579','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 13:50:42',0,NULL,3,1,11,1,NULL,' WLIN014'),(20539,829272615011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',2,'GLOT001',53.98,'eastar4uk','chrishumm','chrishumm@talktalk.net','Christopher Humm','12, Carrisbrooke Way<br>LATCHBROOK','Saltash','Cornwall','UNITED KINGDOM','PL12 4UX','01752841408','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 13:53:26',0,NULL,3,1,3,1,'RA184534835CN\r ','GLOT001 '),(20540,670561256013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','tomwwwtom','t.kendall1@sky.com','thomas kendall','94 littledock lane<br>honicknowle','plymouth devon','Devon','UNITED KINGDOM','pl52lz','01752783521','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 13:54:45',0,NULL,3,1,3,1,'RA184534781CN\r ',' LGAD001'),(20541,918580581012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','jfhotte23','jfhotte23@hotmail.com','Jean-Francois Hotte','591 fogarty','val des monts','QC','CANADA','J8N 7S4','(819) 671-3455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 14:34:18',0,NULL,3,1,3,1,'RA184534821CN\r ',' GLOT001'),(20542,918581875012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','debiuk','a.thomson9@ntlworld.com','Deborah Thomson','8 Florida Avenue<br>Hartford','Huntingdon','Cambridgeshire','UNITED KINGDOM','PE29 1PY','01480374808','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 14:38:29',0,NULL,3,1,3,1,'RA184534778CN\r ','MOMI002\r黑色 '),(20543,829301712011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','fmdodds86','fiona.dodds@live.co.uk','Fiona Dodds','Talaris House<br>Chineham Business Park','Basingstoke','Hampshire','UNITED KINGDOM','RG24 8QZ','07738941219','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 15:24:15',0,NULL,3,1,3,1,'RA184534764CN\r ','HSNO035\r英标 '),(20544,918604718012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',1,'WLAP004',4.95,'eastar4','barbara-72','juretzky.szabolcs@chello.hu','Barbara Juretzkyné Heves','Ojtozi str.4/1.','Sopron','','HUNGARY','9400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 15:35:48',0,NULL,3,1,22,1,NULL,NULL),(20545,829308423011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','nemz-x','neriman-x@hotmail.co.uk','Neriman Bayram','6 Susan Road','Blackheath','London','UNITED KINGDOM','SE3 0JD','02088569166','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 15:36:25',0,NULL,3,1,11,1,' ',' HSNO005+CCNO001'),(20546,611198173003,130596581530,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','us3go','us3go@yahoo.co.uk','Richard Prescott','2 Maple Close<br>GAYTON','King\'s Lynn','Norfolk','UNITED KINGDOM','PE321UP','01553636101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 15:52:04',0,NULL,3,1,17,0,NULL,NULL),(20547,611199796003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','us3go','us3go@yahoo.co.uk','Richard Prescott','2 Maple Close<br>GAYTON','King\'s Lynn','Norfolk','UNITED KINGDOM','PE321UP','01553636101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 15:57:39',0,NULL,3,1,3,1,'RA184534716CN\r ','LGRM001\r还买了Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV      LGAD001 '),(20548,616502224004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','tata120473','tata159@yandex.ru','Андрей Ларионов','Зари, 103-100','Нижний Тагил','','RUSSIAN FEDERATION','622048','89022719060','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 15:58:00',0,NULL,3,1,3,1,'RA184534720CN\r ','MOOE001 '),(20549,829336287011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','fiedi.d','dfiedi@web.de','Dirk   Fiedler','Am Wietzerberg 3','Wedemark','','GERMANY','30900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 16:46:07',0,NULL,3,1,21,1,'RA184526785CN\r ','GLOT001 '),(20550,829338671011,320820766166,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',15.99,'eastar4uk','carden599','carden360@gmail.com','Nela Dalapa','Pergerjeva ul. 10','Ptuj','','SLOVENIA','2250','031336153','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 16:50:47',0,NULL,3,1,22,1,NULL,'HSAL001 '),(20551,829341662011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','trapperbill10','w.j.macgregor@talk21.com','William MacGregor','12 Wylie avenue, Newton Mearns','Glasgow U.K.','East Renfrewshire','UNITED KINGDOM','G776AX','01416396972','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 16:57:10',0,NULL,3,1,3,1,'RA184526873CN ','WLDE002 '),(20552,616524062004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','perpall','perpall@bellsouth.net','Lee Perpall','624 Ashe St','Key West','FL','UNITED STATES','33040-7111','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-18 17:00:45',0,NULL,3,1,1,1,'LK183190651CN ',NULL),(20553,827141431002,120841235348,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','r-netca','rob@r-net.ca','RaversNET Underground','c/o Robert McCallum<br>1532 Victoria Ave.','Regina','SK','CANADA','S4P 0P5','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-01-18 17:09:39',0,NULL,3,1,3,1,'RA184526799CN\r ',' GPS0006'),(20554,611227150003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','tekdragon','jasonjohnson@live.com','Jason Johnson','4333 15th Ave S<br>Apt 107','Fargo','ND','UNITED STATES','58103-3351','(701) 212-6348','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-18 17:27:25',0,NULL,3,1,1,1,'LK179711458CN ',NULL),(20555,918675106012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','mremulator','mremulator@ntlworld.com','David Penfold','6 Victoria Mews<br>7 Balfour Rd','Weybridge','Surrey','UNITED KINGDOM','KT138JB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 18:02:12',0,NULL,3,1,11,1,NULL,' WLIN016'),(20556,670653392013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','lilmicky','michael.ermakov@gmail.com','Michael Ermakov','Nosovihinskoe shosse, dom 21, kv 98','Reutov-5','Moscow region','RUSSIAN FEDERATION','143965','+7 985 7 726 726','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 18:54:18',0,NULL,3,1,11,1,'、 ',' WLIN014'),(20557,918694157012,220872413840,'4 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 18:38:56',0,NULL,3,1,21,1,'RA184526887CN\r','GLOT001*4\r申报为gift申报小于20￥ '),(20558,829397447011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ilolitaw','ilolitaw@gmail.com','Lolita Warren','19781 Dorset St','Southfield','MI','UNITED STATES','48075','(248) 519-3800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 19:05:15',0,NULL,3,1,1,1,'LK182427847CN ',NULL),(20559,766982324008,180762085514,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',5,'GPS0010',164.95,'au-buy','alartel','alartel@hotmail.com','JUAN TORRES','809 Silverwood<br>DALTON','DALTON','GA','UNITED STATES','30720-3616','(706) 537-9204','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-18 19:07:45',0,NULL,5,0,18,0,NULL,'已退款 '),(20560,829416041011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',43.99,'eastar4uk','marky270382','pistonasos@hotmail.es','MARCOS SIMON GARCIA','GERANIOS Nº 14<br>LLANOS DEL SOTILLO','ANDUJAR','Andalucía Ceuta y Melilla','SPAIN','23747','651387333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 19:22:53',0,NULL,3,1,21,1,'RA184526895CN\r ','GLSG001\r '),(20561,784247534001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','blueday955','odom86@sbcglobal.net','Gregory Odom','3500 Maple Ave<br>Suite 500','Dallas','TX','UNITED STATES','75219-3943','(214) 695-1406','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-18 19:28:00',0,NULL,3,1,1,1,'LK179584175CN ',NULL),(20562,829425002011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','sandra081277','sandra_brennan@yahoo.co.uk','Sandra Brennan','45 Hillview','Dunshaughlin','Meath','IRELAND','MH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 19:37:13',0,NULL,3,1,22,1,NULL,' HSNO005+CCNO001'),(20563,829425000011,320828187318,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',55.99,'eastar4uk','amiandos','andreas.ioannou@sodexo-cy.com','ANDREAS IOANNOU','106B, NIKOU GEORGIOU STREET','LIMASSOL','EPISKOPI','CYPRUS','4620','0035799213469','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 19:37:16',0,NULL,3,1,21,1,'RA184526811CN\r ','PSGL001 '),(20564,918730708012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','munjirudukuray','mkoroma01@yahoo.com','KULA KORTI','14143 Castle Blvd<br>APT 103','SILVER SPRING','MD','UNITED STATES','20904-4748','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 19:48:30',0,NULL,3,1,1,1,'LK184191503CN ',NULL),(20565,829434050011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','sian261168','s.schingford@hotmail.co.uk','sian hawkes','18 albert avenue','chingford','London','UNITED KINGDOM','e4 8lg','02085239166','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 19:52:50',0,NULL,3,1,11,1,NULL,' HSNO007'),(20566,670677525013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','bigguy-9480','bigguy3715@new.rr.com','Brian Lewellyn','335 Foster St','Oshkosh','WI','UNITED STATES','54902-5717','(920) 231-9480','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 19:45:03',0,NULL,3,1,1,1,'LK185053485CN',NULL),(20567,670694552013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','reginahappybiddingtoday','reginabrazeel@yahoo.com','Regina Brazeel','13908 Rollingwood Dr<br>apt 1235','Euless','TX','UNITED STATES','76040-7513','(817) 714-0686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 20:23:24',0,NULL,3,1,1,1,'LK176822675CN ',NULL),(20568,670701920013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','luistonetti','tonetti@crashinfo.com.br','Luis Antonio Tonetti','Rua Rio Grande do Sul, 432 ap. 44','Campinas','SP','BRAZIL','13030-290',' 551981548850','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 20:42:50',0,NULL,3,1,11,1,' ',' CACN004'),(20569,767049685008,180741191602,'2 pairs DLP-Link 3D Ready Projector Shutter Glasses',1,'GLOT005*2',113.98,'au-buy','miltonsixstring','romeo_royizxcode@hotmail.com','Milton Mdurwel','422 Hogans Rd','Melbourne','Victoria','AUSTRALIA','3029','61401790532','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 21:02:20',0,NULL,3,1,3,1,'RA184526771CN\r ','GLOT005*2 '),(20570,829483562011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','jamdodge83','andrews_j@live.co.uk','jamie andrews','39 willoughby close','dunstable','Bedfordshire','UNITED KINGDOM','lu6 3tf','01582478075','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 21:20:39',0,NULL,3,1,3,1,'RA184534906CN\r ','OTHP005 '),(20571,670717386013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','karlo.07','karlo013@yahoo.com','Tulan Corneliu','Herentalsebaan 624','Deurne( Antwerpen)','','BELGIUM','2100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 21:22:19',0,NULL,3,1,22,1,' ',' BTAC2014'),(20572,829485573011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','neo-tiv','timchenko.i@gmail.com','Igor Timchenko','Traktorostroiteley str, 79/42, 9','Kharkov','','UKRAINE','61120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 21:26:18',0,NULL,3,1,21,1,'RA184526768CN\r ','GLOT001*2 '),(20573,670722935013,230412694830,'2.0 Bluetooth Module cable DELL mini10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','owenlayzell','owen.layzell@virgin.net','Owen Layzell','61 Hampton Road, Forest Gate','London','London','UNITED KINGDOM','E70NX','02085220058','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 21:36:44',0,NULL,3,1,11,1,' ',' BTDE2002'),(20574,829499792011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','mrflea','bfrogel1@gmail.com','Bernard Frogel','270 Running Springs Dr','Palm Desert','CA','UNITED STATES','92211-3200','(858) 456-0593','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-18 21:55:45',0,NULL,3,1,1,1,'LK183235636CN',NULL),(20575,784323700001,110807072423,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'buysia','mansur28','elmansur@ig.com.br','Rafael Cyrino Mansur','R: Wilson Modesto Ribeiro, Nº 120 / 502','Belo Horizonte','Minas Gerais','BRAZIL','31160-430','55 (031) 313426-3469','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-18 21:59:40',0,NULL,3,1,3,1,'RA184534870CN\r ',' LGRM001'),(20576,611326402003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','rezern09','morten906@hotmail.com','Morten Arnevik','Toftevåg','Sæbøvik','','NORWAY','5454','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 22:00:34',0,NULL,3,1,21,1,'RA184534883CN\r ','MOOE002 '),(20577,755070980008,180755478767,'New Genuine Motorola H710 Bluetooth Wireless Headset  H 710+ AC adaptor',1,'HSMO021',29.39,'au-buy','stefaned666','stephane.dion@ccapcable.com','Stephane Dion','218 Champery','Québec','QC','CANADA','G2M0B2','(418) 849-4851','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-18 22:07:46',0,NULL,3,1,11,1,' ','HSMO021 '),(20578,829508470011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.98,'eastar4','jhm_lviv','jhm@ukr.net','Yaroslav Khomyak','Sokolyna 83b','Lviv','','UKRAINE','79038','+380676730684','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 22:12:19',0,NULL,3,1,22,1,NULL,' BTHP3001'),(20579,918826973012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','samicat2009','amglass@fsmail.net','PETER  JONES','118 BEDFORD ROAD<br>BARTON-LE-CLAY','BEDFORD','Bedfordshire','UNITED KINGDOM','MK45 4LR','01582881260','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 22:21:40',0,NULL,3,1,3,1,'RA184534818CN\r ','HSJA002\r英标 '),(20580,611335330003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',2,'TRSN001',55.18,'cnfaner','rickandcarols','carollschulz@gmail.com','carol schulz','3790 NW 19th St','Lauderhill','FL','UNITED STATES','33311-4122','(954) 535-9354','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-18 22:33:35',0,NULL,3,1,1,1,'LK173508264CN',' '),(20581,767092923008,180761131351,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'au-buy','alibann-2008','alibann@live.co.uk','Alison Bann','53 Attlee court','Caerphilly','Caerphilly','UNITED KINGDOM','CF83 1QU','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-18 22:41:57',0,NULL,3,1,11,1,NULL,'UM00041 '),(20582,670743910013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','hannesch0','joh.lerm@gmail.com','johannes Lerm','Kristinelundsvägen 4','Linköping','','SWEDEN','58337','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 22:43:41',0,NULL,3,1,22,1,'、 ',' OTHP003'),(20583,918837612012,220815927687,'Allied Telesyn CentreCOM AUI Ethernet 10Base-T 210T',2,'TRTT002',13.98,'eastar4uk','super881956','super88@netcarrier.com','charles w churchman','761 germantown pike','lafayette hill','PA','UNITED STATES','19444-1620','(215) 836-7028','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 22:45:20',0,NULL,3,1,1,1,'LK182589615CN ',NULL),(20584,616651274004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','edsweb99','chris@edwardsconstruction.co.uk','Chris Edwards','27 Llwyncelyn Terrace<br>Nelson','Treharris','Caerphilly','UNITED KINGDOM','CF46 6HF','01443451302','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 23:04:44',0,NULL,3,1,3,1,'RA184534804CN\r ','HSJA011\r英标 '),(20585,918830535012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','pctankman','george.steele@btinternet.com','George Steele','73 Rankinstown Road','Ballymena','Antrim','UNITED KINGDOM','BT42 3BX','02825640540','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-18 23:10:54',0,NULL,3,1,3,1,'RA184534795CN\r ','HSJA002 \r英标'),(20586,611346295003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','griffithx','jaumeandreu@hotmail.com','Jaume Andreu Jaume Bestard','Canonge Quetglas; nº21; 2º2ª','Inca','Baleares','SPAIN','07300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 23:17:16',0,NULL,3,1,21,1,'RA184534866CN\r ','BALO007 '),(20587,670759883013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.96,'eastar4','thegeorgeh2011','thegeorgeh@hotmail.com','Dong Hang','9889 Rio Hondo Pkwy','El Monte','CA','UNITED STATES','91733-1243','(626) 315-4490','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2012-01-18 23:47:13',0,NULL,3,1,1,1,'LK174702848CN ',NULL),(20588,670761219013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','hap893212011','fanivpatel@yahoo.com','sunny patel','Subway<br>3154 W 103rd Street','Chicago','IL','UNITED STATES','60655','(708) 897-1278','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-18 23:55:10',0,NULL,3,1,1,1,'LK179824358CN ',NULL),(20589,603910166003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','authenticityzdaname','chaunie77@yahoo.com','Richaun Little','11332 203rd St','Jamaica','NY','UNITED STATES','11412-2533','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-19 00:32:51',0,NULL,3,1,1,1,'LK176330645CN ',NULL),(20590,8881326937854984,111,'nokia BH-900 全套 补货',1,'HSNO019',0,'eastar4','sergedanko','plumberland@gmail.com','Serguei Danko','Lunacharskogo 29-11','Tarusa','Kaluzhskaya oblast','RUSSIAN FEDERATION','249100','916-740-1122',NULL,NULL,NULL,'2012-01-19 01:50:54',0,NULL,3,1,3,1,' RA184534999CN',' HSNO019'),(20591,8881326939205434,111,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',0,'cnfaner','craigblumus','craig@chivers.org','Craig 2012 Blum','46 Cherry Tree Road','Rainham','Kent','UNITED KINGDOM','ME8 8JZ','01634231031',NULL,NULL,NULL,'2012-01-19 02:13:25',0,NULL,3,0,3,1,'RA184534971CN ','MOMI004 白色的 补发 测试一下 确认左右键和光标能正常运作再发'),(20592,8881326941434725,111,'New Genuine Motorola H700 Bluetooth Wireless Headset',1,'HSMO011',0,'au-buy','argonsagas','duckpie@yahoo.com','Ron Martin','46 Weybridge Trail','Brampton','ON','CANADA','L6V 3Y3','(905) 454-1965',NULL,NULL,NULL,'2012-01-19 02:50:34',0,NULL,3,1,3,1,'RA184534985CN ','补发的 测试一下再发  '),(20593,8881326969395143,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'aliexpress','1006339331','highlanderden@rambler.ru','Denis Kobkin	','Karbisheva 2, 15 CNIII','Krasnogorskiy r-n, p.Nakhabino	','Moskovskaya obl.	','RUSSIAN FEDERATION	','143432','+7 963 6217580',NULL,NULL,NULL,'2012-01-19 10:36:35',0,NULL,3,1,3,1,' RA184521099CN\r\\','WLIN014*1 '),(20594,8881326969654761,111,'x2 45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT007',16.99,'aliexpress','1006118363','hpgc696@speedpost.net','Heeva Shahriari	','Unit 4 94 Maroubra Rd','Maroubra','New South Wales	','AUSTRALIA	','2035','+61 02 83239492',NULL,NULL,NULL,'2012-01-19 10:40:54',0,NULL,7,0,18,0,NULL,NULL),(20595,8881326969684915,111,'x2 45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT007',16.99,'aliexpress','1006118363','hpgc696@speedpost.net','Heeva Shahriari	','Unit 4 94 Maroubra Rd','Maroubra','New South Wales	','AUSTRALIA	','2035','+61 02 83239492',NULL,NULL,NULL,'2012-01-19 10:40:54',0,NULL,7,0,18,0,NULL,NULL),(20596,8881326969729167,111,'x2 45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT007',16.99,'aliexpress','1006118363','hpgc696@speedpost.net','Heeva Shahriari	','Unit 4 94 Maroubra Rd','Maroubra','New South Wales	','AUSTRALIA	','2035','+61 02 83239492',NULL,NULL,NULL,'2012-01-19 10:40:54',0,NULL,7,0,18,0,NULL,NULL),(20597,8881326969760451,111,'45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT007',16.99,'aliexpress','1006118363','hpgc696@speedpost.net','Heeva Shahriari	','Unit 4 94 Maroubra Rd','Maroubra','New South Wales	','AUSTRALIA	','2035','61 02 83239492',NULL,NULL,NULL,'2012-01-19 10:40:54',0,NULL,7,0,18,0,NULL,''),(20598,607326603003,130612786771,'Logitech RF Wireless Extender+ adapter +4 emitters for Harmony 890 Pro 1000',1,'RCLO007+POLO001+RCLO008*4',32.9,'cnfaner','nobabylone','clement.dattee@wanadoo.fr','Clément Dattée','30 Ter rue de Ballainvilliers','Longjumeau','Ile-de-France','FRANCE','91160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-19 14:49:14',0,NULL,5,1,3,1,' \\RA184521139CN\r','RCLO007+POLO001+RCLO008*4\r后台已标记发货'),(20599,915762907012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','elizajh208','alquitrajes@hotmail.com','John Jimenez','1616 SW 157th Ave','Pembroke Pines','FL','UNITED STATES','33027-2353','(786) 328-7549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-19 22:35:03',0,NULL,3,1,1,1,'LK88245480CN已发货  ',''),(20600,829532322011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','krzysztof.sielski','krzysztof.sielski@yahoo.co.uk','Krzysztof Sielski','57 Park Road','London','London','UNITED KINGDOM','SW192HU','07960840959','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-19 23:25:06',0,NULL,3,1,3,1,'RA184520323CN\r','  \rRELO003 后台已点发货'),(20601,827126134011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','andrew30127','kalachikov@gmail.com','Andrey Kalachikov','apt 177,<br>Prospekt Pobedy 28','Kursk','Russia','RUSSIAN FEDERATION','305021','89103140040','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-20 06:54:51',0,NULL,3,1,3,1,'RA184520218CN\r',' GLOT001 后台已点发货'),(20602,826517650011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',42.98,'eastar4','idmiha','promalianse@rambler.ru','Михаил Трефилов','Владимирская 2я дом 52 кор.2 кв.153','Москва','','RUSSIAN FEDERATION','111141','(495)9997875','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-20 08:57:06',0,NULL,3,1,3,1,'RA84531927CN ',' 客户买了两个 WLIN010+ANTY002 后台已点发货'),(20603,917259483012,220481113307,'Original Apple Adapter for Airport Wireless WiFi Card',10,'WLAP004',49.5,'eastar4','rentner42','f.fischer@me.com','Frank Fischer','Lychener Str. 78','Berlin','','GERMANY','10437','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-20 11:02:31',0,NULL,3,1,21,1,'RA184520399CN\r',' WLAP004 后台已点发货'),(20604,617114595004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','andy.smi','andysmi@mail.ru','Andrey Smirnov','Rosa Luxembourg St., 323-85','Irkutsk','Irkutskaya oblast','RUSSIAN FEDERATION','664053','(395) 299-9137','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-20 13:07:04',0,NULL,5,1,3,1,' \\RA184521195CN\r',' OTGR002\r后台已标记发货'),(20605,8881327066670291,111,'2.1 Acer Aspire 5920 5920G Bluetooth Module EDR+cable',1,'BTAC2114',0,'eastar4','pedrobiscoitobr','pedrogabini@gmail.com','Pedro Gabini','Condomínio Jardim Botânico V<br>Conjunto D, Casa 10','Brasilia','Distrito Federal','BRAZIL','71680-368','61 - 8168-9925',NULL,NULL,NULL,'2012-01-20 13:37:50',0,NULL,3,1,11,1,'BJ01669530\r\r ',' 补发'),(20606,8881327117442373,111,'NEW Genuine USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'aliexpress','1006362867','andersonmaurice.ma@gmail.com','Andy Gibbs	','3111 E TAHQUITZ CANYON WAY','PALM SPRINGS	','California','UNITED STATES	','92262-6956','+503 309 6418',NULL,NULL,NULL,'2012-01-21 03:44:02',0,NULL,3,1,1,1,'LK106046856CN 已发货 ','MOAP001*1'),(20607,8881327117935200,111,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',44.99,'aliexpress','1006360926','doda_90@mail.ru','Ilja Alenin	','bul var Kosmonavtov dom 22 kv. 128','Dzerzhinsk','Nizhegorodskaja oblast','RUSSIAN FEDERATION	','606039','+7 915 9327596',NULL,NULL,NULL,'2012-01-21 03:51:09',0,NULL,3,1,3,1,'RA184531913CN\r\\ ','LGRM001*1 '),(20608,8881327118871462,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'aliexpress','1006345969','garry_k@rambler.ru','Igor Kovalenko	','ul. Generala Paskevicha, d.19, kv.17','Smolensk	','Smolensk region	','RUSSIAN FEDERATION	','214031','+7 910 7200962',NULL,NULL,NULL,'2012-01-21 04:07:51',0,NULL,3,1,3,1,'RA184521045CN ','WLAT008*1 '),(20609,8881327204887784,111,'4 Ports USB Hub Board 1140C Charming Memo Board+Alarm Clock w/Highlighter',1,'OT00003',19.99,'aliexpress','1006367807','gonharovsergei@mail.ru','sergei Goncharov	','2nd Krasnoflotskaya 9-70','Krasnoyarsk	','Krasnoyarsk Territory	','RUSSIAN FEDERATION	','660027','+7 391 2055572',NULL,NULL,NULL,'2012-01-22 04:01:27',0,NULL,3,1,3,1,'RA184521173CN ','OT00003*1 '),(20610,8881327283459114,111,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'aliexpress','1006374838','green128@gmail.com','Alexey Gavrilov	','Varshavskoe shosse dom 154 korpus 3 kvartira 136','Moscow','Russia','RUSSIAN FEDERATION	','117405','+7 926 2372936',NULL,NULL,NULL,'2012-01-23 01:50:59',0,NULL,3,1,3,1,' \\RA184520337CN\r',NULL),(20611,8881327283646070,111,'LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',47.49,'aliexpress','1006379617','belinda@gigglesmiledesigns.com','Belinda Doyle	','19 Dalrymple St','Albion Park	','NSW	','AUSTRALIA	','2527','+61 02 42575386',NULL,NULL,NULL,'2012-01-23 01:54:06',0,NULL,3,1,3,1,'RA184531935CN\r、 ','LGGL002*1 '),(20612,8881327363651548,111,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UMTR001',0,'eastar4','vahik611','vahik002@yahoo.com','Vahram Jalalyan','Davitashen distr. IV block, build. 15, apt. 10','Yerevan','Yerevan','ARMENIA','0054','+37491477369',NULL,NULL,NULL,'2012-01-24 00:07:31',0,NULL,5,0,18,0,NULL,' 蓝色边的 '),(20613,8881327365989432,111,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',0,'eastar4uk','ipllewellyn1','llewelllynian547@btinternet.com','ian llewellyn','160 ty gwyn drive<br>brackla','bridgend','Bridgend','UNITED KINGDOM','cf312qj','01656668737',NULL,NULL,NULL,'2012-01-24 00:46:29',0,NULL,3,1,3,1,'RA184520116CN\r\\ ',' 补货'),(20614,764678082008,180793383706,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'au-buy','alaska-pc','rfayed@gmail.com','Raed Fayed','5 Ford Place','Gordon','Australian Capital Territory','AUSTRALIA','2906','0433099033','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-24 01:44:40',0,NULL,3,1,11,1,'\\ ',' \rOT00002 \r'),(20615,602675644003,130590334915,'New Motorola H350 Bluetooth Wireless Headset track#',1,'HSMO005',14.99,'cnfaner','nicky9203w57','mespedale@aol.com','mary ellen spedale','1060 1st Ave','franklin square','NY','UNITED STATES','11010','(516) 328-9581','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-25 00:18:53',0,NULL,3,1,1,1,'LK83084128CN已发货  ',' 客户同意等到节后'),(20616,8881327458420815,111,'兼容眼镜 补货',1,'GLOT001',0,'eastar4uk','nosa11','nstyl@hol.gr','NIKOLAOS STILIANIDIS','LORETZU MAVILI 20','HERAKLION','KRETE','GREECE','71306','+306972303154',NULL,NULL,NULL,'2012-01-25 02:27:00',0,NULL,3,1,21,1,'\\\rRA184520221CN\r ',' GLOT001'),(20617,8881327465687651,111,'NEW Genuine USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'aliexpress','1006393366','andersonmaurice.ma@gmail.com','Rene Quintanilla	','2759 W 14TH ST','LOS ANGELES	','California','UNITED STATES	','90006-4315','+503 309 6418',NULL,NULL,NULL,'2012-01-25 04:28:07',0,NULL,3,1,1,1,'LK041926275CN 已发货 ','MOAP001*1 '),(20618,8881327529236340,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',0,'eastar4','miguelgonzalez.cb','miguel.cb@terra.es','Miguel Angel Gonzalez Casado','Ezequiel Solana 82 4ºD','Madrid','Madrid','SPAIN','28017','659778180',NULL,NULL,NULL,'2012-01-25 22:07:16',0,NULL,3,1,22,1,'\\ ',' WLIN014  补货 '),(20619,828972595011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','jngtransport1974','jngtransport@gmail.com','JOSEPH HOLLAND','PO Box 12036','WILMINGTON','NC','UNITED STATES','28405-0100','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-25 23:52:16',0,NULL,3,1,1,1,'LK86624096CN已发货  ',' '),(20620,917788908012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','joecyg','joechyun@comcast.net','Joe Chyun','8021 Swan Cir','la palma','ca','UNITED STATES','90623-1939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-26 02:05:44',0,NULL,3,1,1,1,'LK87191445CN已发货  ',NULL),(20621,8881327571429712,111,'Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',55.99,'aliexpress','1006405489','chris@spaniel.me.uk','Chris Moore	','49 Bushey Court Bushey Road','London	','London	','UNITED KINGDOM	','sw20 0jf','+44 7866 635835',NULL,NULL,NULL,'2012-01-26 09:50:29',0,NULL,3,1,3,1,' \\RA184520195CN\r','HBPH002*1 '),(20622,8881327571784940,111,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',44.99,'aliexpress','1006349910','raimabd@rambler.ru','ilmira abdrashitova	','STREET 4-I TRUBETSKOY HOUSE 29','IZHEVSK','Udmurtia','RUSSIAN FEDERATION	','426041','89043117620',NULL,NULL,NULL,'2012-01-26 09:56:24',0,NULL,3,1,3,1,'RA184531839CN\r、 ','LGRM001*1 '),(20623,8881327571964373,111,'LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',47.49,'aliexpress','1006414776','costgv@yahoo.com','stan ioana	','AVENIZA ZARAGOZA N169','BORRIOL	','CASTELLON	','SPAIN','12190','+0034 666010075',NULL,NULL,NULL,'2012-01-26 09:59:24',0,NULL,3,1,21,1,'RA184520252CN\r\\ ','LGGL002*1 '),(20624,829365949011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','dezasm','dezaosm@gmail.com','André Luis Vidal Almeida','Rua Presidente Vargas, 452','Manoel Viana','Rio Grande do Sul','BRAZIL','97640-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-26 20:29:10',0,NULL,3,1,11,1,'\\ ',' TRSN001 后台已点发货'),(20625,8881327623826394,111,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',0,'eastar4uk','wizardone2000','gtaylory2k@hotmail.com','Greg Taylor','431 Ditchling Road','Brighton','East Sussex','UNITED KINGDOM','BN1 6XB','',NULL,NULL,NULL,'2012-01-27 00:23:46',0,NULL,3,1,3,1,' RA184532777CN\r',' GPS0010 补货'),(20626,8881327634361205,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',2,'WLAT008',17.98,'aliexpress','1006420482','trifonov@inbox.ru','Vitaly Trifonov	','yl. Krasnaya Presnia, dom. 23 korpys 1, kv. 97','Moscow','Moscow','RUSSIAN FEDERATION	','123022','+7 905 530-50-90',NULL,NULL,NULL,'2012-01-27 03:19:21',0,NULL,3,1,3,1,'、RA184531900CN\r ',NULL),(20627,616487818004,140583323292,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',37.99,'cnfaner','maako14','markopokkinen@gmail.com','Marko Pokkinen','Keikarinkuja 2 B 31','Vantaa','Uusimaa','FINLAND','01510',' 358400278007','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-27 11:10:58',0,NULL,5,1,21,1,'、RA184548803CN\r ','WWSI004+ANCN001 \r后台已标记发货'),(20628,923905032012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Deb Di Gregorio Camares','515 Valley St<br>Ste 190','MAPLEWOOD','NJ','UNITED STATES','07040-1389','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:21:36',0,NULL,3,1,1,1,' 已发货 LK134328433CN',' 改这个地址Hill Labs - Attn: Brady F Alle\r3 N. Bacton Hill Rd.\rPO Box 202\rFrazer, PA 19355\r'),(20629,8881327710135147,111,'兼容眼镜 ',2,'GLOT001',97,'eastar4','orxbetzalel','xexcelx@live.com','Or Betzalel','Laskov Haim 28A','Holon','','ISRAEL','58672','0528013813',NULL,NULL,NULL,'2012-01-28 00:22:15',0,NULL,3,1,3,1,'RA184520045CN\r\\ ',' GLOT001 客户加了8美金运费'),(20630,923905855012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Deb Di Gregorio Camares','515 Valley St<br>Ste 190','MAPLEWOOD','NJ','UNITED STATES','07040-1389','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:22:54',0,NULL,3,1,1,1,'LK87887615CN已发货  ',''),(20631,923907739012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Robert Beach','15 1st St NW<br>Apt 201','Waukon','IA','UNITED STATES','52172-1652','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:29:55',0,NULL,3,1,1,1,'LK85178636CN已发货  ',''),(20632,923908438012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Alan Deremo','2255 CRESTVIEW DR','LAGUNA BEACH','CA','UNITED STATES','92651-3468','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:31:42',0,NULL,3,1,1,1,'LK86584105CN已发货  ',''),(20633,8881327710735758,111,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',0,'eastar4uk','badger0141','b.mcgrath@sky.com','bernard mcgrath','2 hawthorn gardens drumsagard village<br>cambuslang','glasgow','south lanarkshire','UNITED KINGDOM','g72 7gp','',NULL,NULL,NULL,'2012-01-28 00:32:15',0,NULL,3,1,3,1,'、RA184531842CN\r ',' LGRM001  补货'),(20634,834208327011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','mato_sk_nm','grackom@gmail.com','Martin Gracko','1.maja 311/8','Nove Mesto nad Vahom','Slovakia','SLOVAK REPUBLIC','91501','+421904831404','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 00:32:37',0,NULL,3,1,22,1,'\\ ','OTHP005 \r欧标'),(20635,923909070012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Karla Buckmaster','3860 Sheldon Dr','Petoskey','MI','UNITED STATES','49770-8970','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:34:03',0,NULL,3,1,1,1,'LK82847226CN已发货  ',''),(20636,923909770012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Jo Ann Bengel','701 E FOOTHILL BLVD','AZUSA','CA','UNITED STATES','91702-2606','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:36:11',0,NULL,3,1,1,1,'LK87307276CN已发货  ',''),(20637,832715180002,120841235559,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'buysia','floop_bob','floop04@hotmail.com','ROBERT CAYA','821 Gratien','Wickham','QC','CANADA','j0c1s0','(819) 314-0211','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-01-28 00:55:44',0,NULL,5,1,3,1,'、RA184531768CN\r ','TRSN001 \r后台已标记发货\r'),(20638,923906819012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dilleown18','element4997@gmail.com','Karen Marie Johnson','PO Box 989<br>137 Waldemere Rd','LIVINGSTON MANOR','NY','UNITED STATES','12758-0989','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 00:27:39',0,NULL,3,1,1,1,'LK87525130CN已发货  ',''),(20639,619842056004,140667903666,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Antenna *3',1,'WLAT001+ANTY002',15.89,'cnfaner','jshlnsctt','josh_l@myfairpoint.net','Josh Linscott','125 Prospect St','millinocket','ME','UNITED STATES','04462-1327','(207) 746-7666','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-28 01:28:12',0,NULL,3,1,1,1,'LK85699637CN已发货  ',NULL),(20640,923929911012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',9.39,'eastar4uk','grelims','martin.barnes967@ntlworld.com','Martin Barnes','31 Kemerton Walk<br>Park South','Swindon','Wiltshire','UNITED KINGDOM','SN3 2EA','07990875353','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 01:45:05',0,NULL,3,1,3,1,'RA184526992CN\r','HSNO022\r英标  后台已点发货'),(20641,923941183012,220844147216,'New Philips Sonicare toothbrush Handle HX6930+charger',1,'HBPH002+HBPH003',86.9,'eastar4','langly510','everett.thompson@gmail.com','Everett W Thompson','8965 Research Dr<br>Secureauth Corporation Ste 200','Irvine','CA','UNITED STATES','92618-4237','(602) 315-2197','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 02:33:38',0,NULL,3,1,1,1,'LK88860375CN已发货  ',NULL),(20642,771508854008,180793383706,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'au-buy','roseneespence','gillmgr@hotkey.net.au','Mrs Gillian Rose','P.O. Box 290','Macedon','Victoria','AUSTRALIA','3440','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 02:59:14',0,NULL,3,1,11,1,'\\ ','OT00002 '),(20643,923965945012,220815932431,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',13.98,'eastar4uk','xandrcouk','alex@xandr.co.uk','Alexander Hess','c/o Blizzard Entertainment<br>5th Floor, The Atrium, Blackpool Retail Park','Blackpool','Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 04:00:42',0,NULL,3,1,21,1,'RA184521156CN\r ','SHLO002  后台已点发货'),(20644,674226108013,230641625431,'3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',132.99,'eastar4','wendyzulu56','wendybizaare@y7mail.com','Wendy  Bizaare','77 Crimea Road','Marsfield','New South Wales','AUSTRALIA','2122','0298735833','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 04:02:57',0,NULL,3,1,3,1,'RA184520031CN\r',' GLOT001*3  后台已点发货'),(20645,674226513013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','nakita333','jrieu@hotmail.com','Janice Rieu','10 Wendon Bay','Winnipeg','MB','CANADA','R2R 1W9','(204) 632-7221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 04:03:34',0,NULL,3,1,3,1,'RA184520028CN\r',' GLOT001*3 后台已点发货'),(20646,674235044013,230668626540,'3FT CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T Cable',3,'CASS001',29.97,'eastar4','n1ckston3','nickston3@gmail.com','Nick Stone','Unit 5 43 Herbert St<br>Atarmon','Sydney','New South Wales','AUSTRALIA','2065','0434566529','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 04:59:11',0,NULL,3,1,11,1,'\\ ',' CASS001 后台已点发货'),(20647,923980145012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','boufarik0503','ali.benad@yahoo.co.uk','Ali Benad','108 st andrews road<br>st andrews road','cambridge','Cambridgeshire','UNITED KINGDOM','cb4 1dn','01223351977','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 05:05:04',0,NULL,3,1,3,1,'RA184548785CN\r ','HSJA002\r英标 后台已点发货'),(20648,923981037012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','wombat10107','danielworsleyqld@hotmail.com','Mrs. A. Worsley','21 Glenmay Court','Morayfield','Queensland','AUSTRALIA','4506','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 05:08:40',0,NULL,3,1,11,1,' \\',' UM00005 后台已点发货'),(20649,674236373013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','mwks99','rosyandwayne@optusnet.com.au','Wayne Robertson','P.O. Box 862','Banora Point','New South Wales','AUSTRALIA','2486','0407039355','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 05:08:44',0,NULL,3,1,11,1,'\\ ',' WLIN010 后台已点发货'),(20650,674238758013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','tgcelectronics','tgcelectronics@sbcglobal.net','TGC Chavez','7203 Blackton Dr','La Mesa','CA','UNITED STATES','91941-7512','(619) 395-2932','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 05:27:24',0,NULL,3,1,1,1,'LK187502023CN ',' '),(20651,619882011004,140676374196,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',77.99,'cnfaner','zahid_jagani','zahid_jagani@yahoo.com','Mohamed Zahid Jagani','21 Frenchpark Circle','BRAMPTON','ON','CANADA','L6X 0Y5','(416) 856-7142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 05:42:46',0,NULL,5,1,3,1,'\\RA184520181CN\r ','HBPH002+HBPH003\r后台已标记发货'),(20652,923992344012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','puregolf69','grant@eagleprints.net','Grant Davis','2843 Remington Way','Tracy','CA','UNITED STATES','95377-6662','(209) 832-5112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 06:05:39',0,NULL,3,1,1,1,'LK84890363CN已发货  ',' '),(20653,614576266003,130626363912,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.95,'cnfaner','kraatzy','lkraatz@bigpond.net.au','Kelly Kraatz','P.O. Box 163','Belgian Gardens','Queensland','AUSTRALIA','4810','0747744569','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 06:41:53',0,NULL,3,1,3,1,'RA184548763CN\r ','RELO002 \r'),(20654,674248316013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ryanwhunt','ryan@ryanhunt.net','Ryan Hunt','PO BOX 168','Mortdale','New South Wales','AUSTRALIA','2223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 06:44:04',0,NULL,3,1,11,1,'\\ ',' CACN004 后台已点发货'),(20655,674250880013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','dylanioo7','paul_ankers@hotmail.com','paul ankers','288 oxford st','leederville','Western Australia','AUSTRALIA','6007','0894442055','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 07:01:22',0,NULL,3,1,4,1,'YW868898114CN\r ',' 后台已点发货'),(20656,771558022008,180794745393,'Brand new HP MCE Media Center Remote Control+IR Emitter',1,'OTHP005',14.8,'au-buy','bundius123','fourexman@yahoo.com','Brett Crebert','12 Beaufortia Turn','Halls Head','Western Australia','AUSTRALIA','6210','0895347964','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 07:29:01',0,NULL,3,1,11,1,'\\\r','OTHP005 '),(20657,834300429011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','samy-zelko','nedzad4369@gmail.com','Nedzad Omerovic','Jordanovac 72','Zagreb','','CROATIA','10000','00385977905668','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 07:40:55',0,NULL,3,1,22,1,'\\ ',' HSJA002 后台已点发货'),(20658,674257904013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','johanl10','johan.lorier@gmail.com','JIR Lorier','Wickenburg 63','Vlissingen','','NETHERLANDS','4385HS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 07:54:09',0,NULL,3,1,22,1,'BJ01669680\r\\',' CASS003 后台已点发货'),(20659,779732362007,170730544904,'Logitech MX1000 Mouse special Bluetooth Version+ charging base+adaptor+receiver',1,'MOLO005',59.8,'au-buy','stephenr2435','swrose@tpg.com.au','Stephen Rose','11 Flora pde','Tuncurry','New South Wales','AUSTRALIA','2428','0265576969','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 08:29:52',0,NULL,3,1,3,1,'RA184521111CN\r','MOLO005 后台已点发货'),(20660,924022031012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','1poleman','david.mair@bt.com','DAVID MAIR','9 CHANDLERS CLOSE','NEW WALTHAM','Lincolnshire','UNITED KINGDOM','DN36 4WH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 08:30:57',0,NULL,3,1,3,1,'RA184531825CN\r ','LGRM001 后台已点发货'),(20661,788707241001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','dmspiller','danieldmspiller@gmail.com','alss','Po Box 2558','Nerang BC','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-28 08:39:55',0,NULL,5,1,3,1,'、RA184531856CN\r ','GPS0006 \r后台已标记发货'),(20662,924038869012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','bass_of_love_74','bassoflove@hotmail.com','Glenn Karlsen','Fagerfjell','Finnsnes','Troms','NORWAY','9300','+47 97510507','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 09:30:35',0,NULL,3,1,22,1,'BJ01669399\r ',' HSNO005 '),(20663,924040889012,220877932141,'New HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'eastar4','diavluci','diavolo668@hotmail.com','Miguel Angel  Gomez Bernabe','c/San Jose Artesano,43, bajo 2','Torrellano','Comunidad Valenciana','SPAIN','03320','616234629','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 09:36:46',0,NULL,3,1,22,1,'BJ01669679\r\\ ',' RMSN003 后台已点发货'),(20664,771591453008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',2,'BALO009',15.98,'au-buy','sonikmick','sonikmick@internode.on.net','Michael Brindley','65 Ridge st<br>Greenslopes','Brisbane','Queensland','AUSTRALIA','4120','0733941727','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 09:51:45',0,NULL,3,1,11,1,'、BJ01669701\r ','BALO009 '),(20665,771617415008,180781265436,'New Grohe handheld Shower Head big water output w/Massage function + Grohe hose',1,'OTGR005+OTGR002',39.9,'au-buy','mickyt001','michael.tadros01@gmail.com','michael','1a /125 great north rd Five Dock','SYDNEY','New South Wales','AUSTRALIA','2046','0414889339','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 11:19:43',0,NULL,3,1,3,1,'RA184520354CN','OTGR005+OTGR002  后台已点发货'),(20666,834370126011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',35.49,'eastar4uk','mjlajg1000','mjl5000@aol.com','Martin John Little','30 Abbottsmoor<br>Baglan','Port Talbot','Neath Port Talbot','UNITED KINGDOM','SA12 6DT','07841566817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 11:40:12',0,NULL,3,1,3,1,'RA184531811CN\r ','LGAD001  后台已点发货'),(20667,619948720004,140675757780,'New 3D Active Shutter TV Glasses Compatible for LG AG-S110 AGS110',1,'GLOT001',43.89,'cnfaner','simonimaria','simoni-1996@hotmail.com','Maria Christou','Mykonou 15','Nicosia','Nicosia','CYPRUS','2301','99162040','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 12:08:48',0,NULL,5,1,21,1,'RA184520155CN\r\\ ','GLOT001 \r后台已标记发货'),(20668,779805743007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','sban8327','dangerously.nice@gmail.com','Satwinder Bangar','178<br>Hampstead Road','Clearview','South Australia','AUSTRALIA','5085','0401651204','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 12:31:14',0,NULL,3,1,11,1,'、BJ01669705\r ','RELO003 '),(20669,834392744011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',2,'BTHP2107',24.78,'eastar4','std654','andre.jenkins@iinet.net.au','André Jenkins','20 Lasswade St','Ashbury','New South Wales','AUSTRALIA','2193','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 12:43:02',0,NULL,3,1,11,1,'BJ01669704 \r、',' BTHP2107 后台已点发货'),(20670,674325107013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','justostalone','justo_stalone@bigpond.com','J. Malone','Po Box 5118<br>Algester','Brisbane','Queensland','AUSTRALIA','4115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:01:58',0,NULL,3,1,11,1,'、BJ01669708\r ',' WLIN014 后台已点发货'),(20671,834406302011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','beat102','amir.husanovic@gmail.com','Amir Husanovic','eSpares Ltd<br>13 -14 Chelsea Wharf, 15 Lots Road, Chelsea','London','London','UNITED KINGDOM','SW10 0QJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 13:19:13',0,NULL,3,1,3,1,'RA184531895CN\r','OTHP005 \r英标 后台已点发货'),(20672,619968911004,140667902883,'Brand new HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'cnfaner','dperec11','damir.perec@gmail.com','Damir Perec','Josipa Strganca 2','Zagreb','','CROATIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:26:04',0,NULL,5,1,21,1,'、RA184526958CN\r ','RMSN003 \r后台已标记发货'),(20673,924140738012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','mrhillnorm','hillnormandw@aol.com','No: 6','CHURCHSIDE<br>CLYSTHONITON','EXETER','Devon','UNITED KINGDOM','EX52LY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 14:00:11',0,NULL,3,1,3,1,'RA184531887CN\r ','HSJA002\r英标  后台已点发货'),(20674,924167988012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',5,'TRMX003',49.95,'eastar4','slay666football','slaylys@hotmail.com','Shany Carle','5610 Laflamme','Trois-Rivieres','QC','CANADA','g8y6y6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 14:55:03',0,NULL,3,1,3,1,'RA184531873CN\r ',' TRMX003 后台已点发货'),(20675,619994209004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','uziiiiii','bugmafia2004@rambler.ru','Ixari Grigore','209 rue. Parent app.301  GREENFIELD PARK','Montreal','QC','CANADA','J4V 3K5','(514) 655-5804','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 14:56:53',0,NULL,5,1,3,1,'、RA184531710CN\r ','MOOE001\rOEM \r后台已标记发货'),(20676,674386052013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','wills811','sharonkwills@gmail.com','Sharon Wills','2451 Bankston Cir','Snellville','GA','UNITED STATES','30078-5726','(770) 736-0518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 16:04:34',0,NULL,3,1,1,1,'LK84354759CN已发货  ',' '),(20677,834484982011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','8348stewart','stewart.oakland@sky.com','Stewart Oakland','10 Byron Avenue','Sheffield','South Yorkshire','UNITED KINGDOM','S351SQ','01142454099','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 16:09:43',0,NULL,3,1,3,1,'RA184531944CN\r ','MOAP001  后台已点发货'),(20678,924213653012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',2,'HSJA002',27.2,'eastar4uk','caz_noone','caz_noone@hotmail.co.uk','carole noone','6 birkdale road<br>durrington','worthing','West Sussex','UNITED KINGDOM','bn13 2qy','01903690495','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 16:19:06',0,NULL,3,1,3,1,'RA84526927CN','HSJA002\r英标  后台已点发货'),(20679,924233110012,220815928836,'Logitech RF Wireless Extender for Harmony 890 Pro 1000',1,'RCLO007',18.8,'eastar4uk','grassy-knowles','cjknowles@live.co.uk','Chris KNowles','Officers Mess<br>MOD Boscombe Down','Salisbury','Wiltshire','UNITED KINGDOM','SP4 0JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 16:50:33',0,NULL,3,1,3,1,'RA184531958CN\r','RCLO007\r英标  后台已点发货'),(20680,620043250004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','cruzerov','mahdal5@seznam.cz','René Mahdal','Podlesí 4937','Zlín','Czech republic','CZECH REPUBLIC','76005','+420604920010','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 17:09:52',0,NULL,3,1,17,0,NULL,' CACN004\r已发邮件问买家是否重复下订单'),(20681,620043973004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','cruzerov','mahdal5@seznam.cz','René Mahdal','Podlesí 4937','Zlín','Czech republic','CZECH REPUBLIC','76005','+420604920010','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 17:11:27',0,NULL,3,1,3,1,'RA184532131CN\r ','CACN004 \r一共4个 合并订单'),(20682,924251430012,220820867548,'New Grohe handheld Shower Head big water output + hose',1,'OTGR005+OTGR002',39.9,'eastar4','bostongosox','anthony.savoia@verizon.net','Anthony Savoia','4226 SW 68th Ter','Gainesville','FL','UNITED STATES','32608-6427','(352) 278-6759','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 17:20:14',0,NULL,3,1,1,1,'LK84712076CN已发货  ',NULL),(20683,620047439004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','millennium-91','millennium.chertkov@gmail.com','Evgenii Chertkov','Volgogradskaya 32, kv.193','Omsk','','RUSSIAN FEDERATION','644106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 17:28:07',0,NULL,5,1,3,1,'、RA184548851CN\r ','BALO007 \r后台已标记发货'),(20684,834550739011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','roboticlegs','josephhughes@gmail.com','Joseph Hughes','Tate Media<br>20 John Islip Street','Millbank','London','UNITED KINGDOM','SW1P 4RG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 18:03:21',0,NULL,3,1,3,1,'RA184531860CN\r ','WLDE002 后台已点发货'),(20685,924284331012,220763380753,'New Genuine Sony Ericsson HBH-DS220 Bluetooth Wireless',1,'HSSE006',39.9,'eastar4uk','rogiroux','rog.giroux@videotron.ca','Roger Giroux','212 Chemin des Mas #6','Boischatel','QC','CANADA','G0A 1H0','(514) 916-2078','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 18:12:20',0,NULL,3,1,3,1,'RA184526935CN\r ','HSSE006  后台已点发货'),(20686,924295311012,220872413840,'4 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 18:31:32',0,NULL,8,1,17,0,NULL,'GLOT001*4 '),(20687,834587765011,320812368138,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',7.99,'eastar4uk','wardell165','wardell165@aol.com','Wardell E.Rosario','5229 Ponce De Leon Blvd','Sebring','FL','UNITED STATES','33872-1729','(305) 978-7356','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 19:05:00',0,NULL,3,1,1,1,'LK85793898CN已发货  ',NULL),(20688,614779530003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','justagreatguy','1kandradavis@gmail.com','Kandra Davis','5315 Davie St','Davenport','IA','UNITED STATES','52806-2535','(563) 517-7331','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-28 19:10:53',0,NULL,3,1,1,1,'LK86122465CN已发货  ',NULL),(20689,924331615012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','amyneasham','neasham_88@hotmail.com','amy neasham','115<br>westmorland rise','peterlee','Durham','UNITED KINGDOM','sr8 2es','07701066796','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 19:19:12',0,NULL,3,1,3,1,'RA184521200CN\r','GLSG001*2  后台已点发货'),(20690,924342015012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.95,'eastar4uk','lanny_toy','lannytoy@yahoo.com','Lanny Toy','313 S Granada Ave','Alhambra','CA','UNITED STATES','91801-4029','(626) 576-1776','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 19:34:54',0,NULL,3,1,1,1,' \\LK187522898CN\r',NULL),(20691,924378830012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',13.98,'eastar4uk','piruloco1957','piruloco@gmail.com','Manuel Perez Cuadrado','Rio Nervion 28, 3C','Leganes','Madrid','SPAIN','28913','916898069','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 20:31:48',0,NULL,3,1,22,1,'\\ ','OTHP004 '),(20692,620127796004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','vesajo','didier.solty@neuf.fr','Didier SOLTYSIAK','10, Rue Le CORBUSIER','BOURGES','Centre','FRANCE','18000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 20:39:09',0,NULL,5,1,3,1,'RA184548794CN\r 、','BALO007 \r后台已标记发货'),(20693,834653035011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','polizois_123','kamikazi@freemail.gr','POLIZOIS TZAMPAZIS','ARGYROKASTROY 20','ALEXANDROYPOLI','EVROS','GREECE','68100','6932877284','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 20:55:14',0,NULL,3,1,21,1,'RA184520235CN\r ','GLOT001  后台已点发货'),(20694,924399643012,220871869126,'Genuine Jabra BT250V Bluetooth Headset BT 250V',1,'HSJA001',16.9,'eastar4uk','thewoolpuller','d.pearce1@ntlworld.com','David Pearce c/o Sandra Daubney','Mill House Farm<br>caythorpe heath','Caythorpe','Lincolnshire','UNITED KINGDOM','NG32 3EZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 21:05:51',0,NULL,3,1,3,1,'RA184532193CN\r ','HSJA001\r英标 '),(20695,780065848007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',4,'OTGR001',79.6,'au-buy','xkr42','j.hayes@bigpond.com','John Hayes','9 Wybelenna Street<br>Brookfield','Brisbane','Queensland','AUSTRALIA','4069','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 21:11:27',0,NULL,3,1,3,1,' RA184529659CN\r','OTGR001 '),(20696,614828429003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','alisd0001','alisd01@web.de','Ali Duman','Goethestr. 21','Leverkusen','','GERMANY','51379','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 21:16:56',0,NULL,5,1,21,1,'、RA184531808CN\r ','MOOE002 \rOEM\r后台已标记发货'),(20697,834668288011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','norfolkandwhaye','ebay@norfolkandwhaye.com','Richard Link','Route D\'Ath 177 / 5','Nimy','','BELGIUM','7020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 21:22:20',0,NULL,3,1,21,1,'RA184520306CN\r','TRSN001 后台已点发货'),(20698,771896774008,180755479508,'New Jabra BT250V FreeSpeak Bluetooth Headset  BT 250V+AC charger',1,'HSJA001',23.8,'au-buy','thewoolpuller','d.pearce1@ntlworld.com','David Pearce c/o Sandra Daubney','Mill House Farm<br>caythorpe heath','Caythorpe','Lincolnshire','UNITED KINGDOM','NG32 3EZ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 21:25:15',0,NULL,3,1,3,1,'RA184538222CN\r\r','HSJA001 \r英标 后台已点发货'),(20699,674511521013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','yuryve','yu_ve@mail.ru','Юрий Емец','ул. Бахчиванджи д. 19 кв. 26','Ахтубинск','Астраханская обл','RUSSIAN FEDERATION','416506','+79171737822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 21:43:41',0,NULL,3,1,11,1,'\\ ',' WLAP008 后台已点发货'),(20700,620149642004,140675756448,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Samsung SSG -2100AB',1,'GLOT001*2',87.99,'cnfaner','hadij69','hadijanos@hotmail.com','János Hadi','Kinizsi u. 33 I/9','Budapest','','HUNGARY','1092','+36 70 3309230','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 21:46:16',0,NULL,5,1,21,1,'RA184520080CN\r\\ ','GLOT001*2 \r后台已标记发货'),(20701,834690158011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','spoolframe8w3r','spoolframe@aol.com','Bill Masterman','3036 68th Ave W<br>Ste J','University Place','WA','UNITED STATES','98466-5230','(253) 565-9470','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 22:05:48',0,NULL,3,1,1,1,'LK86902869CN已发货  ',' '),(20702,620159008004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','joeyragss','joeyragss@msn.com','joseph miraglia','21 red maple dr','brick','NJ','UNITED STATES','08724-2094','(732) 458-0485','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-28 22:10:26',0,NULL,3,1,1,1,'LK78808464CN已发货  ',NULL),(20703,834698608011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',44.5,'eastar4uk','clarkescribe','mikejclarke@btinternet.com','Mike Clarke','76, Nunnery Street','Castle Hedingham','Essex','UNITED KINGDOM','CO93DP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 22:23:11',0,NULL,3,1,3,1,'RA184520178CN\r','HBPH002  后台已点发货'),(20704,834701580011,320730087727,'New Logitech IO Digital Notebook for Logitech IO / IO2',2,'NTLO001',21.98,'eastar4uk','melanieb5307','burgerbird@tiscali.co.uk','melanie Boarer','2 buckland barton cottages','newton abbot','Devon','UNITED KINGDOM','TQ12 4SA','01626367870','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 22:30:33',0,NULL,3,1,3,1,'RA184521142CN\r','NTLO001  后台已点发货'),(20705,620172085004,140675756778,'3 pairs of New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001*3',131.99,'cnfaner','doris4339','dorisagray67@yahoo.com','doris gray','7609 turlington rd','toano','VA','UNITED STATES','23168','(757) 741-2700','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-28 22:54:08',0,NULL,3,1,1,1,'LK81149974CN已发货  ',NULL),(20706,924458591012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','stroud53','chair@silverchair.net','Julie Johns','17 Hall Street','Merewether','New South Wales','AUSTRALIA','2291','0249634365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 23:04:08',0,NULL,3,1,11,1,' \\',' UM00005 后台已点发货'),(20707,834730964011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','7555ryan','ryanaw@interchange.ubc.ca','Ryan Whitehead','3015 W. 12th Avenue','Vancouver','BC','CANADA','V6K 2R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 23:43:43',0,NULL,3,1,11,1,'\\ ',' HSUE004 后台已点发货'),(20708,924475650012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',189.98,'eastar4','54quadcam','james.irwin@anu.edu.au','james irwin','53 Liverpool st<br>Macquarie','Canberra','Australian Capital Territory','AUSTRALIA','2614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 23:46:01',0,NULL,3,1,3,1,'RA184521125CN\r',' PSGL001 后台已点发货'),(20709,834731782011,320786774093,'New Portable HDMI HD H.264 1080P Car Dashboard Camera DVR',1,'CC00001',45.99,'eastar4uk','darren5393','tropicoolsales@tiscali.co.uk','darren mills','36 karina close<br>chigwell','chigwell','Essex','UNITED KINGDOM','ig74en','07967225434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 23:46:03',0,NULL,3,1,3,1,'RA184520204CN\r','CC00001 后台已点发货'),(20710,924479193012,220820867548,'New Grohe handheld Shower Head big water output + hose',1,'OTGR005+OTGR002',39.9,'eastar4','cas908','caschill@tampabay.rr.com','Conrad Schilling','130 Golf Vista Cir','Davenport','FL','UNITED STATES','33837-8481','(908) 419-4955','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 23:55:51',0,NULL,3,1,1,1,'LK85195254CN已发货  ',' '),(20711,674574334013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','jaydee1100','youraveragejoe2004@yahoo.com','butch datorin','11 Benaud Street','Blacktown City','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 00:20:57',0,NULL,3,1,11,1,'、BJ01669711\r ',' WLIN010 后台已点发货'),(20712,924484004012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',4,'HSNO005',55.56,'eastar4','36blue','nbillone@yahoo.com','joseph  n  billone','641 Larkfield Rd<br>BACK DOOR DELIVERY','east northport','NY','UNITED STATES','11731-4921','(631) 355-3376','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-29 00:08:19',0,NULL,3,1,1,1,'LK187832736CN\r ',NULL),(20713,834748836011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','daestewart','dstewart@norsat.com','Daniel AE Stewart','Suite 110 - 4020 Viking Way','Richmond','BC','CANADA','V6V 2L4','(604) 821-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 00:43:20',0,NULL,3,1,11,1,'\\ ',' HSNO019 后台已点发货'),(20714,614887905003,130596581759,'WMN2000B ULTRA SLIM WALL-MOUNT LED TV 46\"-55\"',1,'MOOE003',49.99,'cnfaner','kyliekay*','kylienathaniel@yahoo.com.au','Kylie Winnell','2 Dombarton Pl','Horsley','New South Wales','AUSTRALIA','2530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 00:59:22',0,NULL,5,1,3,1,'、RA184531670CN\r ','MOOE003\rOEM \r后台已标记发货'),(20715,674596536013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','jillby12','mrd@ix.net.au','jill williams','26 Blenheim Ave','oberon','New South Wales','AUSTRALIA','2787','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 01:57:50',0,NULL,3,1,4,1,'YW868898125CN\r ',' 后台已点发货'),(20716,834779492011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',20.9,'eastar4','darkmage32','andrewj@kempe.com.au','Andrew Jackman C/- DynamicFit Pty Ltd','Level 2/22 Malop Street','Geelong','Victoria','AUSTRALIA','3220','0352252900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 02:28:04',0,NULL,3,1,11,1,'\\ ',' OTHP006 后台已点发货'),(20717,834782080011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','jomococom','jomococom@aol.com','Jochen  Müller','Westfälische Str. 18','Olpe','','GERMANY','57462','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 02:30:56',0,NULL,3,1,22,1,'BJ01669684\r\r\\ ',' HSJA011 后台已点发货'),(20718,674615553013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','psarnilsson','psarnilsson@msn.com','Peter Nilsson','19447 Citrus Grove Rd','Riverside','CA','UNITED STATES','92508-6412','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-29 03:26:17',0,NULL,3,1,1,1,' \\LK180080229CN\r',NULL),(20719,772024112008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','kdutah','kathymeibaker@gmail.com','Lewis Baker','31 Flemington St','Glenside','South Australia','AUSTRALIA','5065','0408315597','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 04:35:33',0,NULL,3,1,11,1,' \\','UM00043 '),(20720,772042779008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','leninek03','leninekzlaticko@hotmail.com','Lenka Racanova','106/199<br>Pyrmont street','Pyrmont','New South Wales','AUSTRALIA','2009','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 05:14:28',0,NULL,5,0,18,0,NULL,'客户要求取消订单  \r已退款'),(20721,924575023012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','nandalaram','rameshnandala@yahoo.com','Ramesh Nandala','3/58<br>AILSA ST SOUTH','ALTONA MEADOWS','Victoria','AUSTRALIA','3028','0425095678','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 05:31:11',0,NULL,3,1,3,1,'RA184520120CN\r',' GLOT001 后台已点发货'),(20722,924582989012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','konstantin.timofeyev','timofeev82@rambler.ru','Konstantin Timofeyev','Konakovskiy proezd, home12/1, appt 100 ','Moscow','Moscow','RUSSIAN FEDERATION','125565','8-962-970-8928','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 06:06:56',0,NULL,3,1,11,1,'\\\r ',' CASS003 后台已点发货'),(20723,924603076012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',94.99,'eastar4','dino268','sam_2929@hotmail.com','Sam Elderfield','2835 Murray Dr','Victoria','BC','CANADA','v9a 2s6','(250) 713-6398','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 07:45:00',0,NULL,3,1,3,1,'RA184520408CN\r',' PSGL001 后台已点发货'),(20724,780235685007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.99,'au-buy','mlvglb','melvinhandsome@gmail.com','MELVIN GILBERT','3196 VINELAND AVE','BALDWIN PARK','CA','UNITED STATES','91706-5000','(310) 400-6727','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-29 07:46:14',0,NULL,3,1,1,1,' \\LK185342068CN\r',NULL),(20725,834852631011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','davidyuncken','ebay@yuncken.com','David Yuncken','c/o The Grand Hotel<br>333 Burnley St','Richmond','Victoria','AUSTRALIA','3121','0413487585','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 08:04:06',0,NULL,3,1,11,1,'\\\rBJ01669657\r',' WLIN011 后台已点发货'),(20726,789199578001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','johnshinoy','shinoyjohn@yahoo.com','shinoy john','901 Pump Rd<br>Apt 181','Richmond','VA','UNITED STATES','23238-5524','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-29 08:16:51',0,NULL,3,1,1,1,'LK82413644CN已发货  ','在包装盒上标注为书 '),(20727,780248096007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','tonyscockatoo','tony.place@optusnet.com.au','Tony Place','254 Mitcham Road','Mitcham','Victoria','AUSTRALIA','3132','0398742673','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 08:33:17',0,NULL,3,1,11,1,'、RA184521023CN\r ','RELO002 '),(20728,924622140012,220880695871,'New GENUINE NOKIA HS-26W BLUETOOTH HEADSET HS 26W',1,'HSNO032',15.99,'eastar4','sasijansasi','janthongsamer@mail.dk','Jan Nielsen','Stationspladsen 1 A','Ølgod','','DENMARK','6870','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 08:52:29',0,NULL,3,1,22,1,'\\ ',' HSNO032 后台已点发货'),(20729,674667924013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','f1tx3','blammo_fox@yahoo.com','Brett Scotland','28 lynanda court','Caboolture','Queensland','AUSTRALIA','4510','0754989291','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 09:01:25',0,NULL,3,1,4,1,'YW868898103CN\r ',' 后台已点发货'),(20730,834884275011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','thedbguy','spracy@hotmail.com','Steven Pracy','2 Causton Way','Rayleigh','Essex','UNITED KINGDOM','SS6 8DD','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'echeck '),(20731,924634398012,220701714802,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',6.98,'eastar4','ntmts','ntmts@hotmail.com','SEAN STEWART','PO BOX 927','JOONDALUP','Western Australia','AUSTRALIA','6027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 09:27:23',0,NULL,3,1,11,1,'、BJ01669702\r ',' OTCN003 后台已点发货'),(20732,834885288011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','scascabel','schtroumpf8@hotmail.com','Biondolillo Conceta','Rue Houckaye n° 18','Ensival','','BELGIUM','4800','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 09:39:18',0,NULL,3,1,22,1,'\\ ','TRSN001 '),(20733,674693220013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','motocachou','fiocorin@belgacom.net','Fiorella Corin','rue des houyeux 3','micheroux','','BELGIUM','4630','043776536','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 10:24:45',0,NULL,3,1,21,1,'RA184520062CN\r',' GLOT001*2 后台已点发货'),(20734,620315502004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','robertpdros','rosejmarshall@hotmail.com','rosemary Marshall','2 / 21 Hampden Road','Armadale','Victoria','AUSTRALIA','3143','61395002880','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 11:00:03',0,NULL,5,1,3,1,'、RA184548834CN\r ','HBPH007 \r后台已标记发货'),(20735,924701856012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','keccers','kayleigh.e.clark@googlemail.com','Charles Clark','34 Milton Avenue','Melksham','Wiltshire','UNITED KINGDOM','Sn12 7PQ','07770666468','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 11:41:17',0,NULL,3,1,3,1,'RA184527009CN\r','HSJA002英标 后台已点发货'),(20736,924709829012,220448710888,'Acer travelmate 3002 Bluetooth Module 2.0 EDR+cable',1,'BTAC2024',9.88,'eastar4','fispol','fispol@mail.chita.ru','Pavel Shevelev','p/b 406','Chita-10','','RUSSIAN FEDERATION','672010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 11:58:04',0,NULL,3,1,11,1,'\\ RA84521037CN ',' BTAC2024  不应该有号 后台已点发货'),(20737,924727546012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','zs.sz','szzs@chello.hu','Szekely  Zsolt /DMM STUDIO','Balzac u.15.II/2','Budapest','','HUNGARY','1136','(36) 303970709','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 12:29:19',0,NULL,3,1,22,1,'\\ ',' WLAT009 后台已点发货'),(20738,620357973004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','acmontandon','montandonjr@gmail.com','Antonio Carlos Montandon Júnior','QI 10 Bloco G Apto 103<br>Guara I','Guara','Distrito Federal','BRAZIL','71010-077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 13:04:22',0,NULL,5,1,3,1,'、RA184526860CN\r ','WWOT003+ANCN001 \r后台已标记发货'),(20739,620370613004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','ssvetlana10','fordstep@rambler.ru','Ssvetlana Stepanova','Baltiyskaya 23-106','Novosibirsk','Novosibirskay oblast\'','RUSSIAN FEDERATION','630058','+79529425042','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 13:35:56',0,NULL,5,1,3,1,'、RA184531666CN\r ','HSNO005 \r欧标\r后台已标记发货'),(20740,674777182013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','joeltromboneman','joelschier@yahoo.com.au','Joel Schier','P.O Box 609','Ardross','Western Australia','AUSTRALIA','6953','61413854052','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 14:11:18',0,NULL,3,1,11,1,'、RA184521054CN\r ',' HSNO016 后台已点发货'),(20741,674763576013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','bigman57','wolf3fox3@nate.com','myoungsuk yi','44-3<br>sinan-dong','andong-si','kyeongsangbuk-do','KOREA,REPUBLIC OF','760-140','01054477439','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 14:27:40',0,NULL,3,1,3,1,'RA184548777CN\r ',' GPS0004 后台已点发货'),(20742,772243662008,180792774183,'New Microsoft Wired Optical Wheel USB Compatible  Mouse White',1,'MOMI004',13.79,'au-buy','jarrydco','jarryd.o@live.com','Jarryd','8/50 Carlton Crescent','Summer Hill','New South Wales','AUSTRALIA','2130','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 14:34:43',0,NULL,3,1,11,1,'\\ ','MOMI004\r白色 '),(20743,835048170011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','mopedwinni','woerlemarkus@gmx.net','Daniel Wörle','Kleinfeldstraße 4.','Junkenhofen','','GERMANY','85302','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 14:49:53',0,NULL,3,1,22,1,'\\ ',' BTAS3002 后台已点发货'),(20744,834938621011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','beliboywo','beliboy@gekkoos.de','Wolfgang Olerich','Grambauerstraße 20','Schwedt','','GERMANY','16303','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 15:22:54',0,NULL,3,1,21,1,'RA184520249CN\r','OTSO002  后台已点发货'),(20745,615097308003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15.79,'cnfaner','karlton777torn-tx','him777@sbcglobal.net','Karlton Stevens','4102 Downgate Dr','Houston','TX','UNITED STATES','77084-3214','(281) 221-7766','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 15:26:58',0,NULL,3,1,1,1,'LK188162913CN\r ',NULL),(20746,674823264013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','w_sloth','wplins@gmail.com','Wesley Lins','SQS 412, Bloco O<br>105','Brasília','Distrito Federal','BRAZIL','70278-150','61 8431-1100','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 15:48:47',0,NULL,3,1,3,1,'RA184520014CN\r',' GLOT001*2 后台已点发货'),(20747,924861001012,220815931578,'New SAMSUNG WEP200 Bluetooth Headset black version',1,'HSSA002',10.99,'eastar4uk','493andy','andy.porter@talktalk.net','Andy Porter','22 Bluebell Close<br>Oakley Vale','Corby','Northamptonshire','UNITED KINGDOM','NN18 8LZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 15:53:28',0,NULL,3,1,3,1,'RA184531745CN\r ',' HSSA002 英标 后台已点发货'),(20748,835084879011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','bobbymac27','bobby-mac@ntlworld.com','c/o Rob Macauley','22 Bryn Street<br>Brynhyfryd','Swansea','Swansea','UNITED KINGDOM','SA5 9HP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 15:55:25',0,NULL,3,1,3,1,'RA184520297CN','HSJA011  英标\r客户要发票 后台已点发货'),(20749,620434303004,140667903751,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card',1,'WLAT009',10.9,'cnfaner','rmoss3475','qy@dr.com','Rob Moss','62 Stubbins Street<br>Ramsbottom','Bury','Lancashire','UNITED KINGDOM','BL0 0NL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 16:01:45',0,NULL,5,1,3,1,'、RA184531785CN\r ','WLAT009 \r后台已标记发货'),(20750,835110850011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',21.99,'eastar4uk','puma873210','nick.hibell@talktalk.net','nick hibell','8 southway','fleetwood','Lancashire','UNITED KINGDOM','fy78nh','07967093339','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 16:16:11',0,NULL,3,0,3,1,'RA184531754CN\r ','HSIT002\r英标   黑色的  后台已点发货'),(20751,924882293012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',2,'HSJA002',27.2,'eastar4uk','oleska.1582','oleska.81@interia.eu','aleksandra karaszkiewicz','7 the avenue','LUTON','Bedfordshire','UNITED KINGDOM','lu4 9af','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 16:18:11',0,NULL,3,1,3,1,'RA184548848CN\r ','HSJA002\r英标  后台已点发货'),(20752,674848454013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','fleabag08','graham@iinet.net.au','Graham Ringer','2 Sidcup Way<br>Kelmscott','Perth','Western Australia','AUSTRALIA','6111','0894951448','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 16:31:12',0,NULL,3,1,11,1,'BJ01669685\r\\ ',' HSNO016 后台已点发货'),(20753,674854180013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',0,'eastar4','3akah','daniil.loginov@gmail.com','Daniil Loginov','Strelbishenskiy pereulok, dom.5, kv.177','Moscow','','RUSSIAN FEDERATION','123317','+7(916)692-4051','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,11,1,' \\',' 再加个一个Bracket of half intel 5300 6250 wireless card to pci-e 后台已点发货'),(20754,835062191011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',53.98,'eastar4uk','kostas1984','skounis@hotmail.com','Konstantinos Skounakis','G. Soutsou 8','Aigaleo','Attiki','GREECE','12243','00306946982389','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 16:46:02',0,NULL,3,1,21,1,'RA184520059CN\r','GLOT001  后台已点发货'),(20755,835146568011,320826738279,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',72.99,'eastar4','fahad123456fahad','alameed90@hotmail.com','2674714791','4000 president blvd. pat. 1007 philadelphia . pa 19131','philadelphia','PA','UNITED STATES','19131','267 471 4791','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 16:57:32',0,NULL,3,1,1,1,' \\LK185755991CN\r',' Fahad Ali\r4000 Presidential Blvd\rApt 1007\rphiladelphia PA 19131-1720 \rUnited States'),(20756,835158232011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','kite1970','zoegamble@me.com','Zoe Gamble','42 Lake Avenue','Rhyl','Denbighshire','UNITED KINGDOM','LL18 1HY','01745360840','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 17:09:33',0,NULL,3,1,3,1,'RA184531771CN\r ','TRSN001 后台已点发货'),(20757,674877633013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','stratosnn','stratos@land.ru','Stanislav Avdeev','Alvsakersgrand 48 2TR','Stockholm','Alvsjo','SWEDEN','12572','46767602669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 17:16:39',0,NULL,3,1,22,1,'\\ ',' WLAT010 后台已点发货'),(20758,615167039003,130626402578,'4 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*4',174.99,'cnfaner','cmon6093','cmonahan1234@hotmail.com','Cathy Monahan','31 Emerald Dr.','Buffalo','WY','UNITED STATES','82834','(307) 670-1884','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 17:19:22',0,NULL,3,1,1,1,'LK87568206CN已发货  ',NULL),(20759,835182447011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','jonnik-2822','jonnik@talktalk.net','Jon Gopsill','22 Heywood Terrace<br>Pill','Bristol','North Somerset','UNITED KINGDOM','BS20 0EA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 17:34:49',0,NULL,3,1,3,1,'RA184520133CN\r','GLOT001 后台已点发货'),(20760,924982514012,220759518448,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',10.8,'eastar4uk','benx419','ben.pashley@gmail.com','Ben Pashley','17 Byne Road<br>Sydenham','London','London','UNITED KINGDOM','se26 5jf','07590771752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 17:59:14',0,NULL,3,1,3,1,'RA184531737CN\r ','CRLO001+POLO001  后台已点发货'),(20761,835212021011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','kafito','kafito@web.de','Patrick Held','Braunschweigerstr. 54','Berlin','','GERMANY','12055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 18:04:48',0,NULL,3,1,22,1,'\\ ',' WLAT003 后台已点发货'),(20762,835212502011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',66.99,'eastar4uk','ylvalie','janina.fischer@online.de','Janina Fischer','Herrenfeld 28','Glückstadt','','GERMANY','25348','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 18:05:13',0,NULL,3,1,21,1,'RA184520972CN\r','HSPH008\r欧标 后台已点发货'),(20763,835220800011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','jazz_masta123','polarisrcool@yahoo.com','Adam Campbell','39123 Prentiss St<br>Apt 304','Harrison Township','MI','UNITED STATES','48045-6047','(651) 283-2977','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 18:12:23',0,NULL,3,1,1,1,' \\LK188309667CN\r',NULL),(20764,835268145011,320790603894,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.98,'eastar4','b1bb1bb1b','b1b@bk.ru','MAXIM ROMANENKO','LITOVSKIY BULVAR, DOM 3, KORPUS 2, KV.657','MOSCOW','RU','RUSSIAN FEDERATION','117593','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 18:55:21',0,NULL,3,1,3,1,'RA184526975CN\r ',' LGAD001 后台已点发货'),(20765,615238015003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','hora900','ho_racio@hotmail.com','HORACIO JIMENEZ DEL ROSARIO','C/ LEON Y CASTILLO 200 PLANTA BAJA','LAS PALMAS G.C.','Canarias','SPAIN','35004','609502549','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 18:56:09',0,NULL,5,1,21,1,'\\RA184531799CN\r ','MOOE002\rOEM \r后台已标记发货'),(20766,835290425011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','belouga304','carl.beaulieu@videotron.ca','Carl Beaulieu','465 Jacquard','Repentigny','QC','CANADA','J5Y 3W8','(450) 654-5255','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 19:09:29',0,NULL,3,1,11,1,'BJ01669656\r\\ ','RCLO007+POLO001+RCLO008*4\r '),(20767,835288395011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','motoyzstp2012','motoyzstp@gmx.com','Shawn Phipps','623 Windsor Pl','Deale','MD','UNITED STATES','20751-9702','(410) 353-3737','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 19:12:53',0,NULL,3,1,1,1,' \\LK179068075CN\r',' '),(20768,620573948004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','crantrol','crantrol@centurytel.net','George T. Riedel','W6656 County Road O','Black River Falls','WI','UNITED STATES','54615-6501','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 19:20:22',0,NULL,3,1,1,1,'LK87542098CN已发货  ',NULL),(20769,615268862003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','gcaliari','giuliano.caliari@gmail.com','Giuliano Caliari','Rua dos Jacarandas Mimosos 267<br>Vila Mazzei','Sao Paulo - SP','Brazil','BRAZIL','02312-090','55-11-84898464','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 19:31:47',0,NULL,5,1,3,1,'\\ RA184531683CN\r ','MOLO006\r 在包装上标注\"Used\" 或\"Refurbished\" \r后台已标记发货'),(20770,835366120011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','lepsiskiai','klajoklis.vaiduoklis@gmail.com','Juras Jankevicius','Juozapaviciaus 19a-6','Kaunas','','LITHUANIA','45252','861686908','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 20:23:11',0,NULL,3,1,22,1,'BJ01669398\r ',' HSNO005+CCNO001'),(20771,835367272011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','cjjensen9939','cj9939@comcast.net','James Jensen','9939 Cherry Tree Ln','Indianapolis','IN','UNITED STATES','46235','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 20:17:57',0,NULL,3,1,1,1,'LK83826576CN已发货  ',' '),(20772,835393684011,320730085700,'New Atheros AR5B95 AR9285 Half Mini PCI-E+ANTENNA',1,'WLAT009+ANTY001',6.99,'eastar4uk','ewi001da','edward.willemsen@carthago-ict.nl','Edward Willemsen','Jan Vrijmanstraat 12','amsterdam','','NETHERLANDS','1087mc','0204164733','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 20:45:51',0,NULL,3,1,22,1,'\\ ','WLAT009+ANTY001 '),(20773,675062562013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','m32anna','mb2ks@aol.com','Mary Stafford','608 Gibbs St','Navasota','TX','UNITED STATES','77868-4314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-29 21:19:54',0,NULL,3,1,1,1,' \\',NULL),(20774,925200694012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','victoria8294','vpalmer1691@btinternet.com','V Palmer','3 Alder Road','Sturminster Newton','Dorset','UNITED KINGDOM','DT10 1AB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 21:03:48',0,NULL,3,1,3,1,'RA184531723CN\r','HSJA002\r英标 后台已点发货'),(20775,675071708013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','cameronjohnmowatt2010','cameronjohnmowatt@hotmail.co.uk','Cameron Mowatt','25 Redwood Drive','Chester','Cheshire','UNITED KINGDOM','CH24RT','07917305185','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 21:44:23',0,NULL,3,1,3,1,'RA184526989CN\r ',' LGAD001 后台已点发货'),(20776,620669822004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','pattyerwin','patty.erwin@hotmail.com','Patty Erwin','112 James St','Carterville','IL','UNITED STATES','62918-1111','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 21:56:00',0,NULL,3,1,1,1,'LK85833795CN\r已发货 \r ',NULL),(20777,925246158012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',94.99,'eastar4','hornofamalthea','mike_hagenson@yahoo.com','Jon Hagenson','650 E Bonita Ave<br>Apt 603','San Dimas','CA','UNITED STATES','91773-2748','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-29 21:59:56',0,NULL,3,1,1,1,' \\LK185591290CN\r',''),(20778,835460295011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','arnshaw2','johnwallison@btinternet.com','john allison','Ardblair<br>East Blair Farm','Glenfarg','Perthshire and Kinross','UNITED KINGDOM','PH2 9QL','07717791484','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 22:18:51',0,NULL,3,1,3,1,'RA184520345CN\r ','HSNO026\r英标  后台已点发货'),(20779,675092310013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','trony04','tonygamble12@yahoo.com','tony gamble','1 churchwood close','canterbury','Kent','UNITED KINGDOM','ct2 9bt','07739985323','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 22:26:18',0,NULL,3,1,3,1,'RA184526961CN\r ',' LGAD001 后台已点发货'),(20780,925267403012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',47.98,'eastar4','like-to-shop-around','lsmolica@sympatico.ca','Lesley Molica','1012 Sherman Cres','Pickering','ON','CANADA','L1X1P3','(905) 420-0969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 22:45:28',0,NULL,3,1,3,1,'RA184536442CN\r',' UM00005   再加个一个New Map Anti-UV Rain Sun Parasol Stick Umbrella    地图长柄伞 后台已点发货'),(20781,835482649011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','dani1269','fkallen@gmx.de','Frank Kallen','5712 Queen Aire Ln','Chattanooga','TN','UNITED STATES','37415-7024','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 22:59:52',0,NULL,3,1,1,1,' \\LK186486616CN\r',NULL),(20782,615387064003,130626363912,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.95,'cnfaner','ashakl2002','ashakl2002@yahoo.com','Alan Dubois','4C Plantation Ln','queensbury','NY','UNITED STATES','12804','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-29 23:25:46',0,NULL,3,1,1,1,'LK84602265CN已发货  ',NULL),(20783,925297102012,220872413840,'4 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 23:45:07',0,NULL,3,1,4,1,'YW868898136CN ','GLOT001*4 \r一共买了8副兼容眼镜（合并订单）\r申报为gift 申报20$'),(20784,674535950013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','e.sk','sk-al@yandex.ru','Alexandr Skurikhin','Oboronaya st 4-61<br>Murino','Leningradskaya oblast\'','','RUSSIAN FEDERATION','188662','79112477108','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 23:45:12',0,NULL,3,1,11,1,'BJ01669660\r\\ ',' CACN004 后台已点发货'),(20785,835511636011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','syrphil','phil121757@yahoo.com','Phillip Saturno','101 Sycamore St<br>Apt 8','Liverpool','NY','UNITED STATES','13088-4971','(315) 450-2642','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 00:05:40',0,NULL,3,1,1,1,' \\LK178258064CN\r',NULL),(20786,675142445013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','rowey_73','danrowe@pacific.net.au','Daniel Rowe','1 Watergum Place','Springfield','New South Wales','AUSTRALIA','2250','0243673661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:07:17',0,NULL,3,1,3,1,'RA184520102CN\r',' GLOT001*2 后台已点发货'),(20787,834547068011,320781470760,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',35.99,'eastar4','indritstrazimiri','teddy860@gmail.com','Indrit Strazimiri','1559 Birchwood Dr.','London','ON','CANADA','n6k 4x4','(519) 474-7449','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:26:43',0,NULL,3,1,11,1,'BJ01669683\r\\ ',' CC00002 后台已点发货'),(20788,925318640012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','jackgaet','landry.j@cgocable.ca','Gaétane Landry','6, rue Johan Beetz','Sept-Îles','QC','CANADA','G4R 1A6','(418) 962-0320','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:29:20',0,NULL,3,1,3,1,'RA184520076CN\r',' GLOT001 后台已点发货'),(20789,924325362012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',8.99,'eastar4uk','janosch400','ebay@jansiebke.eu','Jan  Siebke','Hittfelder Strasse 18','Rosengarten','','GERMANY','21224','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 01:38:04',0,NULL,3,1,22,1,'\\ ','WLIN015 '),(20790,615423547003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','liquidsnake3d','deiby.a.arias@gmail.com','Deiby  Arias','1921 Tinsman Ave','PENNSAUKEN','NJ','UNITED STATES','08110-2858','(856) 776-6161','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 01:46:41',0,NULL,3,1,1,1,'LK86896488CN已发货 ',NULL),(20791,925351954012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','jonnybbee','jonnybeee@bigpond.com.au','Jonathan Barwise','173 Thynne Road, Morninigside','Brisbane','Queensland','AUSTRALIA','4170','0439889981','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:47:48',0,NULL,3,1,3,1,'RA184520093CN\r',' GLOT001*2 后台已点发货'),(20814,925458138012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','pauldonjuan','paulfantasa@o2.co.uk','Paul Hiley','58 Windsor Road','Southport','Merseyside','UNITED KINGDOM','PR9 9DB','07754524002','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 08:03:13',0,NULL,3,1,3,1,'RA184520266CN\r','WLAT009 后台已点发货'),(20792,675156381013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','mohmmadtahirali','tahirali786@live.com','Syed Ali','104 WinterFold Drive','Brampton','ON','CANADA','L6V3T3','(647) 864-6414','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:50:35',0,NULL,3,1,11,1,'BJ01669655\r\\ ',' HSNO019 后台已点发货'),(20793,675163302013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','dsmi6847','tinymakayla2011@gmail.com','Derick Smith','3900 SW 52 Ave Unit 201','Pembroke Park','FL','UNITED STATES','33023','(754) 244-2313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 02:09:03',0,NULL,3,1,1,1,'LK81196237CN已发货  ',NULL),(20794,835560965011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','gasparsf','gaspar.sf@gmail.com','Gaspar Ferreira','Rua Cabo-Rocha, 215<br>Vila da Penha','Rio de Janeiro','Rio de Janeiro','BRAZIL','21211710','+55 21 9624-2141','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 02:17:21',0,NULL,3,1,3,1,'RA184520147CN\r',' GLOT001 后台已点发货'),(20795,675174689013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','nukizin','nukiz@live.jp','Adriano Costa','Rua Arquiteto Asdrúbal Sarmento, 134','Maceió','Alagoas','BRAZIL','57052720','558296193423','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 02:51:17',0,NULL,3,1,11,1,'\\\r\r ',' WLIN014  后台已点发货'),(20796,835582177011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','muflik101','roman_kuliyev@hotmail.com','Roman Kuliyev','1850 211th St<br>Apt 4D','BAYSIDE','NY','UNITED STATES','11360-1811','(718) 661-4852','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 03:12:51',0,NULL,3,1,1,1,' LK87737134CN已发货 ',' '),(20797,835522169011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','silvertoenails','ffrench@execs.com','Fernandel French','4524 Athlone Ave','Saint Louis','MO','UNITED STATES','63115-3129','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 03:19:24',0,NULL,3,1,1,1,'LK88021133CN已发货  ',NULL),(20798,615451210003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',70.55,'cnfaner','lh2010','lhdt2010@hotmail.com','Lifang Huang','209 E Del Mar Blvd','Pasadena','CA','UNITED STATES','91101-2712','(626) 394-4596','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 03:37:13',0,NULL,5,0,18,0,NULL,'自己人拍的 '),(20799,615451900003,130617205335,'New HP Easy User-friendly Mini Car Charger',1,'OT00007',9.9,'cnfaner','lh2010','lhdt2010@hotmail.com','Lifang Huang','209 E Del Mar Blvd','Pasadena','CA','UNITED STATES','91101-2712','(626) 394-4596','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-30 03:37:15',0,NULL,5,0,18,0,NULL,'自己人拍的 '),(20800,8881327897139327,111,'LG 3D Active Shutter Glasses AG-S110 - ',1,'LGGL002',47.49,'aliexpress','1006312868','kmn8@yandex.ru','Mikhail Kotov	','ul. Suschevskaya dom7 kv148','Vladimir','Vladimirskaya	','RUSSIAN FEDERATION	','600033','+7 920 6288334',NULL,NULL,NULL,'2012-01-30 04:18:59',0,NULL,3,1,3,1,'RA184521187CN ','LGGL002 *1 '),(20801,8881327897267536,111,'NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',22.67,'aliexpress','1006448041','+503 309 6418','Matthew Kitchie	','39 University Drive 415 Ulrich Student Center','Bethlehem','Pennsylvania	','UNITED STATES	','18015','',NULL,NULL,NULL,'2012-01-30 04:21:07',0,NULL,3,1,1,1,'\\LK048781527CN  ','MOAP001 *1 '),(20802,8881327897423255,111,'NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',22.67,'aliexpress','1006448086','andersonmaurice.ma@gmail.com','in california inc	','300 PACIFIC COAST HWY STE 408','HUNTINGTON BEACH	','California','UNITED STATES	','92648-7100','+503 309 6418',NULL,NULL,NULL,'2012-01-30 04:23:43',0,NULL,3,1,1,1,'LK055569295CN ','MOAP001 *1'),(20803,8881327897593390,111,'NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',22.67,'aliexpress','1006448111','andersonmaurice.ma@gmail.com','Asli Baki	','1 THOMAS CIR NW SUITE 200','WASHINGTON	','District of Columbia	','UNITED STATES	','20005-5802','+503 309 6418',NULL,NULL,NULL,'2012-01-30 04:26:33',0,NULL,3,1,1,1,'LK103484040CN  已发货 ','MOAP001 *1 '),(20804,620779123004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','timedvertigo11','timedvertigo@hotmail.com','Robert Ducheno','81 Solutions Drive<br>Apt 502','Halifax','NS','CANADA','B3S 1R7','(902) 403-6506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 04:38:33',0,NULL,5,1,3,1,'RA184520164CN\r\\\r ','HBPH003 \r后台已标记发货'),(20805,8881327898872521,111,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'aliexpress','1006439037','hyamiguel@hotmail.com','Miguel Yshara	','Omaeda 2643-2 Meson Flur 203','Fukaya shi	','Saitama ken	','JAPAN	','369 1246','+81 0485 947293',NULL,NULL,NULL,'2012-01-30 04:47:52',0,NULL,3,1,3,1,'RA184520270CN\r\\ ','BALO001 *1 '),(20806,780941788007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','enevelope','frenon@bigpond.com','Noni Lawrence','P.O.Box 8359 Gold Coast Mail Centre','Gold Coast','Queensland','AUSTRALIA','9726','0755396358','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 04:58:24',0,NULL,3,0,11,1,NULL,'OTGR001 '),(20807,835613085011,320730481564,'New lady Leopard lines w/lace Bowtie sun stick Umbrella',1,'UM00024',24.99,'eastar4','aemravan16','roman@carolina.rr.com','Angela Agadjanian','321 Porter St','Glendale','CA','UNITED STATES','91205-1907','(704) 351-6898','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 05:12:20',0,NULL,3,1,1,1,'已发货 LK84500261CN',NULL),(20808,835614659011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','jt9763','vhappy888@gmail.com','Jin Teh','15 Kent St','Knoxfield','Victoria','AUSTRALIA','3180','0387190004','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 05:18:03',0,NULL,8,1,17,0,NULL,NULL),(20809,835615850011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','jt9763','vhappy888@gmail.com','Jin Teh','15 Kent St','Knoxfield','Victoria','AUSTRALIA','3180','0387190004','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 05:22:48',0,NULL,3,1,3,1,'RA184520310CN\r',' GLOT001\r还买了TMR-BR100 后台已点发货'),(20889,925956130012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','travellight1','pascalbaillargeon@hotmail.com','pascal baillargeon','384 gabrielle-roy app 1<br>g7a3l2','St-Nicolas','QC','CANADA','G7A3L2','(418) 836-5397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 03:08:41',0,NULL,3,1,11,1,NULL,'OTCN004*10 '),(20811,8881327904373132,111,'TMR-BR100',1,'',0,'eastar4uk','ruffcolly','wrinkleys@tesco.net','Frederic Charles Wright','22 Parkhouse Road','Minehead','Somerset','UNITED KINGDOM','TA24 8AD','01643703180',NULL,NULL,NULL,'2012-01-30 06:19:33',0,NULL,3,1,3,1,' \\RA184520969CN\r',' TRSN001  补发'),(20812,780960986007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','mdav7581','neon848@hotmail.com','Myles Davitt','38 May Street','Robertson','New South Wales','AUSTRALIA','2577','0248851718','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 06:46:49',0,NULL,3,1,11,1,'BJ01669668\r\\ ','RELO002 '),(20813,608921130003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','wiskihase','src@ebi-handels-ag.ch','Breiti\'s - Elektro - Point','c/o Kilian Biland<br>Säckingerstrasse 78','Laufenburg','','GERMANY','79725','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 06:51:20',0,NULL,5,1,21,1,' RA184520283CN\r\\','BALO007 \r后台已标记发货'),(20815,772805551008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','jollyspruiker','amhyland02@yahoo.com.au','Andrew Hyland','15  Abingdon  St','Woolloongabba','Queensland','AUSTRALIA','4102','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 08:15:32',0,NULL,3,1,11,1,'BJ01669669\r\\','RELO001 '),(20816,925464560012,220886922636,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',15.95,'eastar4uk','elenafoxx','mandym102@hotmail.com','Elena von Essen','56 Pine St<br>#PH C','New York','NY','UNITED STATES','10005-1501','(808) 782-6982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 08:33:20',0,NULL,3,1,1,1,'LK186227449CN ','粉色  '),(20817,8881327912642447,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',0,'eastar4','glouck_eb','glouck@gmail.com','Ilya Gribov','PROFSOUZNAYA UL.,D. 85, KOR. 1, KV. 251<br>Verdun','Moscow','','RUSSIAN FEDERATION','117279','+7-916-684-7433',NULL,NULL,NULL,'2012-01-30 08:37:22',0,NULL,3,1,3,1,'RA184532180CN\r ',' WLIN014  补货'),(20818,8881327912763985,111,'New Plantronics Explorer 320 ',1,'HSPL002',0,'cnfaner','cmywings','cmywings50@yahoo.com','Jeff Conner','3706 Brophy Blvd','Cocoa','FL','UNITED STATES','32926-4005','(321) 636-7106',NULL,NULL,NULL,'2012-01-30 08:39:23',0,NULL,3,1,3,1,'RA184538488CN ',' 补货 HSPL002  '),(20819,8881327913199051,111,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI ',1,'HSUE003',0,'eastar4','sn0wcr4sh00','coldenlight@yahoo.com','Andrew Wong','138 Berlioz, Nuns Island <br>Verdun','Montreal','QC','CANADA','H3E 1K5','(514) 761-3663',NULL,NULL,NULL,'2012-01-30 08:46:39',0,NULL,3,1,3,1,'RA184532105CN\r ',' HSUE003 补货'),(20820,925468801012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','vumburo3','y.uzuner@hotmail.de','Yahya Uzuner','Enzianstr 1<br>( Schneiderei)','Berlin','','GERMANY','12203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 08:48:43',0,NULL,3,1,22,1,' ',' BTAC2012'),(20821,835674563011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','peace138','nissan138@gmail.com','Christine Tay','14 Palm Court','Croydon South','Victoria','AUSTRALIA','3136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 09:59:45',0,NULL,3,0,11,1,'BJ01669591\r ',' '),(20822,835674923011,320721398531,'New Genuine Sony Ericsson HBH-DS970 Bluetooth  Headset',1,'HSSE010',65.99,'eastar4','spylexxx','spylexx@mail.ru','Alexandr Belokrylov','Ryabikova 42<br>kv.8','Bratsk','Irkutskaya','RUSSIAN FEDERATION','665727','+79500787808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:08:15',0,NULL,3,1,3,1,'RA184532012CN\r ','HSSE010 '),(20823,620831263004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','dazzzydarren','darrenphillips68@googlemail.com','DARREN PHILLIPS','1 LLEWELLYN STREET','MERTHYR TYDFIL','Merthyr Tydfil','UNITED KINGDOM','CF47 8SR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:17:47',0,NULL,3,1,3,1,'RA184532065CN\r ','HSJA002\r英标 '),(20824,781001316007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','kalliopichristopoulou','kalliopi.christopoulou@gmail.com','Kalliopi Christopoulou  C/O Margareta Jensen','Östratornsvägen 18','Lund','Skåne','SWEDEN','224 68','0760745170','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 10:19:03',0,NULL,3,1,22,1,' ',' RELO002'),(20825,925512717012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','zajko_svk87','zajcus@gmail.com','Martin Sulak','Pecnianska 25','Bratislava','Bratislava','SLOVAK REPUBLIC','85101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 11:19:33',0,NULL,3,1,22,1,NULL,' WLAT007'),(20826,835710753011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.39,'eastar4','coolmoroder','avadadu@googlemail.com','Markus Heid','Königstraße 14-16','Aachen','','GERMANY','52064','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 12:09:34',0,NULL,3,1,22,1,' ','BTAC2105  acer 4pin1.25 8cm'),(20827,835713952011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','akos.klauko','aklauko@yahoo.co.uk','Kurucz Arnold','dr. Pándy Kálmán u. 8.','Újkígyós','','HUNGARY','5661','+36704591854','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 12:19:12',0,NULL,3,1,22,1,NULL,'TRSN001 '),(20828,835717033011,320820750152,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook',1,'HSNO034',14.99,'eastar4','mstoll71','stollm@arcor.de','Michael Stoll','Monschauer Straße 16','Bonn','','GERMANY','53121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 12:25:19',0,NULL,3,1,22,1,NULL,' 欧标 HSNO034'),(20829,835721984011,320730950190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',44.5,'eastar4uk','irm1001','morrisirm@aol.com','ian morris','4<br>BELL COURT, HURLEY','MAIDENHEAD','Berkshire','UNITED KINGDOM','SL6 5NA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 12:38:45',0,NULL,3,1,3,1,'RA184532128CN\r ','HBPH002 '),(20830,925439996012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','hangkiu','warren3338@gmail.com','warren cheung','8684 Rigby Ct','Las Vegas','NV','UNITED STATES','89148-1461','(702) 339-9711','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 13:50:43',0,NULL,3,1,1,1,'LK184684741CN ',NULL),(20831,772899264008,180794745292,'Brand new HP MCE Media Center Remote Control + IR RECEIVER+IR Emitter',1,'OTHP003',20.9,'au-buy','187dave_lewis','david_lewis1987@live.com.au','David G Lewis','8 Denison Street<br>Hornsby','Sydney','New South Wales','AUSTRALIA','2077','0294775274','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 13:57:53',0,NULL,3,1,11,1,NULL,'OTHP003 '),(20832,925581301012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','puposik','rainbow___@mail.ru','Liudmila Baranova','Moscow, 917-134','Moscow','Zelenograd','RUSSIAN FEDERATION','124575','89036750006','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 14:32:59',0,NULL,3,1,11,1,' ',' UM00008'),(20833,615569315003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','05061976','niels.engelsted@stofanet.dk','Niels Jørgensen','Frejasvej 26','DK 9870 Sindal','','DENMARK','x','98936059','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 14:33:03',0,NULL,3,1,21,1,'RA184532159CN\r ','HSNO019\r欧标 '),(20834,925592780012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','invcoop','expoemail@aol.com','Expo/Brian Landau','105A Glen St','Glen Cove','NY','UNITED STATES','11542','(516) 674-1420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 14:59:30',0,NULL,3,1,1,1,'LK188582368CN ',NULL),(20835,620893742004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','coleman401johnson','coleman401@yahoo.com','Nathan Coleman','401 Johnson Ave','Princeton','IN','UNITED STATES','47670','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 15:01:43',0,NULL,3,1,1,1,'LK186594638CN ',NULL),(20836,675322379013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','nikita.kulepetov','nikita@kulepetov.name','Nikita Kulepetov','Flat 56, 145 Communist Avenue','Seversk','Tomsk region','RUSSIAN FEDERATION','636037',' 79832377900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 15:11:15',0,NULL,3,1,11,1,NULL,' WLIN014'),(20837,675335484013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','pauljr1978','paul.ramirez78@gmail.com','Paul ramirez','2633 s oak','wichita','KS','UNITED STATES','67217','(316) 990-5300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 16:05:00',0,NULL,3,1,1,1,'LK183674822CN ',NULL),(20838,615599715003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',2,'ANTY002',11.98,'cnfaner','terany','teranyu@yandex.ru','Anton Teremshonok','Borisa Bogatkova, str.<br>194/8, ap.75','Novosibirsk','Novosibirsk Region','RUSSIAN FEDERATION','630017','+7-903-932-2235','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 16:21:28',0,NULL,3,1,3,1,'RA184532074CN\r ','ANTY002 '),(20839,925630698012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','hanatourusa','john@usahanatour.net','Seung Hyun Park','3053 W Olympic Blvd<br>Ste 101','Los Angeles','CA','UNITED STATES','90006-2558','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 16:24:44',0,NULL,3,1,1,1,'LK187190025CN ',NULL),(20840,925632918012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','henriquecastelo','henriquecasas@hotmail.com','Henrique Castelo Rodrigues Casas','Rua Hugo Carneiro, 1181<br>Bairro: Bosque','Rio Branco','Acre','BRAZIL','69908250','556832235580','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 16:30:15',0,NULL,3,1,11,1,' ',' OTCN004*10'),(20841,925665199012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',9.99,'eastar4','sergey1076','ilyin_sergey@mail.ru','Sergey ILyin','99 Carmathen Close','Farnborough','Hampshire','UNITED KINGDOM','gu14 8th','07906642734','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 17:30:24',0,NULL,3,1,11,1,' ',' CASS002'),(20842,925675157012,220915146069,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',99.99,'eastar4','loark1','wbridger@shaw.ca','Bill Bridger','123 Canyon Terrace W','Lethbridge','AB','CANADA','T1K 6W7','(780) 388-7952','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 17:48:30',0,NULL,3,1,3,1,'RA184532162CN\r ',' SAFI001*2'),(20843,675378384013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','joegordon44106','joegordon@roadrunner.com','Joe Gordon','2490 Kenilworth Rd','Cleveland Heights','OH','UNITED STATES','44106-2764','(216) 932-9489','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 17:53:16',0,NULL,3,1,1,1,'LK188917614CN ',NULL),(20844,620948213004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',23,'cnfaner','klaatu01','jim@reevesaudio.com','JIM REEVES','550 Callan Ave','EVANSTON','IL','UNITED STATES','60202','(847) 328-6703','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 17:59:01',0,NULL,3,1,1,1,'LK185368238CN ','一共2个 '),(20845,925734321012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','sherbinin14','sherbi14@list.ru','Shcherbinin Dmitrij','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','903 960 6564','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 19:17:25',0,NULL,3,1,1,1,'LK183912646CN ',NULL),(20846,925270282012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',9.39,'eastar4uk','destruktorpl','destruktor12344@wp.pl','Wielogorski Adam','378 North Circular Road<br>LPG AUTO CENTRE','London','London','UNITED KINGDOM','N13 6BJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 19:29:48',0,NULL,3,1,3,1,'RA184532114CN\r ','HSNO022\r英标 '),(20847,925743949012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','2006sukhwant','sskhosapau@yahoo.com','Sukhwant Khosa','211-13775 74 Ave','Surrey','BC','CANADA','V3W 9C5','(604) 592-6303','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 19:49:47',0,NULL,3,1,3,1,'RA184532233CN\r ',' GLOT001'),(20848,925765345012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','kazzspazz','krazykaz@ozemail.com.au','Roger/Norm Chahine','109 Banksia Rd','Greenacre','New South Wales','AUSTRALIA','2190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 20:02:36',0,NULL,3,1,3,1,'RA184532247CN\r ',' GLOT001'),(20849,925771515012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.89,'eastar4uk','yosiblu','yosiblumenfeld@hotmail.com','Yosef Blumenfeld','Skrinnarvägen 12','Eskilstuna','','SWEDEN','63359','016134034','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 20:09:44',0,NULL,3,1,22,1,NULL,'MOLO006 '),(20850,835954182011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','qbone23874','dagchr@hotmail.com','Dag Christian Hval Olsen','Gystadveien 5','Aurskog','Norway','NORWAY','1930','92602192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 20:31:21',0,NULL,3,1,22,1,' ','OTHP005 '),(20851,835957388011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','thiagogoncalez2011','thiagogoncalez@yahoo.com.br','Thiago Goncalez','Av. Marechal Rondon, 424 - Apt 43','Guarulhos','São Paulo','BRAZIL','07030-060',' 551183037850','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 20:36:56',0,NULL,3,1,3,1,'RA184532220CN\r ','GLOT001 '),(20852,925808088012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','82fast','mclyons111@gmail.com','Michael Lyons','5150 Palm Valley Rd<br>Ste 103','Ponte Vedra Beach','FL','UNITED STATES','32082','(904) 866-2202','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:08:50',0,NULL,3,1,1,1,'LK185199636CN ',NULL),(20853,0,320833565298,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',3.6,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:16:56',0,NULL,3,0,18,0,NULL,NULL),(20854,925815753012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','eugenwk','danielpeiler@gmx.de','Daniel Peiler','Paul- Heidelbach- Str. 10','Kassel','','GERMANY','34134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 21:17:02',0,NULL,3,1,22,1,NULL,' acer 8pin1.00 8cm'),(20855,0,220936951748,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',5.37,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:17:00',0,NULL,3,0,18,0,NULL,NULL),(20856,0,220936964761,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',7.2,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:17:05',0,NULL,3,0,18,0,NULL,NULL),(20857,0,320833563850,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',7.2,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:17:12',0,NULL,3,0,18,0,NULL,NULL),(20858,0,220936966467,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',10.53,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:17:17',0,NULL,3,0,18,0,NULL,NULL),(20859,0,320833564490,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',7.2,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:19:03',0,NULL,3,0,18,0,NULL,NULL),(20860,0,320833562878,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',5,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:19:09',0,NULL,3,0,18,0,NULL,NULL),(20861,0,220936963251,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',7.08,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:19:16',0,NULL,3,0,18,0,NULL,NULL),(20862,0,180801099382,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.04,'au-buy','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 21:21:12',0,NULL,3,0,18,0,NULL,NULL),(20863,0,170767890828,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',7.31,'au-buy','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 21:21:16',0,NULL,3,0,18,0,NULL,NULL),(20864,0,170767875171,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',8.1,'au-buy','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 21:21:21',0,NULL,3,0,18,0,NULL,NULL),(20865,675472099013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',6,'WLAP002',119.88,'eastar4','ukbytes11','ukbytes@gmail.com','Patrick Welsh','41 Bellflower Ave<br>South Park Village','Glasgow','Glasgow (City of)','UNITED KINGDOM','g53 7yd','01418817898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 21:22:22',0,NULL,3,1,3,1,'RA184532176CN\r ',' WLAP002  只发airport的  客户不要airmac'),(20866,835976537011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','nikongrapes','tlsauer18@hotmail.com','Terry Sauer','3060 18th Ave','Marion','IA','UNITED STATES','52302-1407','(319) 573-9892','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 21:05:59',0,NULL,3,1,1,1,'LK189031035CN ',NULL),(20867,0,320833574051,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',4.08,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:27:06',0,NULL,3,0,18,0,NULL,' 自己人拍的'),(20868,0,230733982935,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',4.24,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:27:13',0,NULL,3,0,18,0,NULL,' 自己人拍的'),(20869,0,230733985059,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',15.63,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:27:26',0,NULL,3,0,18,0,NULL,' 自己人拍的'),(20870,0,220936979661,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',12.9,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:27:32',0,NULL,3,0,18,0,NULL,' 自己人拍的'),(20871,925451273012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','abennyben','abennyben@hotmail.com','c.schafer','62 fairneyview rd','fernvale','qld','AUSTRALIA','4306','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 21:27:41',0,NULL,3,1,11,1,NULL,' UM00008'),(20872,0,220936977076,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',18.55,'eastar4','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 21:27:19',0,NULL,3,0,18,0,NULL,'  自己人拍的'),(20873,835996733011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','hewix','hewi@ish.de','Heiko Widliczek','Pfalzstr.20','Düsseldorf','','GERMANY','40477','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:45:34',0,NULL,3,1,21,1,'RA184532145CN\r ','HSNO035\r欧标 '),(20874,620950053004,140630816480,'New Nokia HS-26W Bluetooch Headset HS 26W',1,'HSNO032',14.99,'cnfaner','am.giles75','am.giles75@ntlworld.com','Andrew Giles','Sibamas<br>Newbolt Road','Portsmouth','Hampshire','UNITED KINGDOM','PO6 4NS','07905104053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 21:53:31',0,NULL,3,1,3,1,'RA184538103CN\r\r ','HSNO032 \r英标'),(20875,836010494011,320730549023,'3 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*3',78.99,'eastar4uk','thol12','tonyholroyd@virginmedia.com','anthony holroyd','12 harthill avenue<br>gildersome','leeds','West Yorkshire','UNITED KINGDOM','ls27 7ey','01132531851','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 22:32:41',0,NULL,3,1,3,1,'RA184532216CN\r ','GLOT001*3 '),(20876,925861060012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','wiking1467','wiking1412@wp.pl','Piotr Michalski','38  a   Steynton Avenue','Bexley','Kent','UNITED KINGDOM','DA5 3HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 22:42:09',0,NULL,3,1,3,1,'RA184532202CN\r ','HSJA010 英标 '),(20877,675508949013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','polman918','polman91@gmail.com','Jose Pablo Carmona Guillen','Prim 38 2ºD','Badajoz','Extremadura','SPAIN','06001','662266659','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 23:09:04',0,NULL,3,1,22,1,' ',' BTAC2014  acer 5pin1.25 20cm'),(20878,925873288012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','damnagain','god4uonly@gmail.com','Karen Bennett','2205  Bontanical Dr. Apt. 121','Killeen','TX','UNITED STATES','76542','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-30 23:09:46',0,NULL,3,1,1,1,'LK189005300CN\r ',NULL),(20879,925879444012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','akiu20','schwarzer_tim@gmx.de','Tim Schwarzer','August Bebel Str. 38','Plauen','','GERMANY','08525','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 23:25:24',0,NULL,3,1,21,1,'RA184532255CN\r ','GLOT001\r申报为gift '),(20880,615761542003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','marlow224','markmead@live.com','Mark Mead','90 Big Trees Rd','Murphys','CA','UNITED STATES','95247','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-30 23:44:49',0,NULL,3,1,1,1,'LK185752173CN ',' 银色的'),(20881,621077383004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',19.95,'cnfaner','nelcam111','nelcam@cogeco.ca','Nelson Camara','79 Chestnut Ave','Hamilton','ON','CANADA','L8L 6K8','(905) 544-9226','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 23:48:39',0,NULL,3,1,3,1,'RA184532091CN\r ','WLAP002 '),(20882,773191260008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.99,'au-buy','apocalypse1993','bobfred_rocks@hotmail.com','Sonny O\'Brien','P.O. BOX 5698 WEST END<br>Blakeney Street Unit 1 No. 1','Brisbane','Queensland','AUSTRALIA','4101','0738442233','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 01:06:43',0,NULL,3,1,11,1,NULL,'SHLO009\rblack ver1 '),(20883,621106924004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','sandoval35','tquintana@sc.rr.com','antonio quintana','4983 socastee blvd','myrtle beach','SC','UNITED STATES','29588-7224','(843) 457-1006','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-31 02:00:01',0,NULL,3,1,1,1,'LK185430916CN\r ',NULL),(20891,8881327979936578,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'aliexpress','1006475399','andersonmaurice.ma@gmail.com','John Mackenzie	','1 W HIGH POINT RD','Tierra Verde	','Florida','UNITED STATES	','34996-7019','5033096418',NULL,NULL,NULL,'2012-01-31 03:15:38',0,NULL,5,1,18,1,'LK033673821CN ',NULL),(20890,8881327979738738,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'aliexpress','1006471906','andersonmaurice.ma@gmail.com','Denise','114 Sands Point Dr','Tierra Verde	','Florida','UNITED STATES	','33715','+503 309 6418',NULL,NULL,NULL,'2012-01-31 03:15:38',0,NULL,3,1,1,1,'LK030082754CN ',NULL),(20888,8881327978710469,111,'CAB-6060',150,'CASS003',975,'eastar4','newdimension2011','netco2011@hotmail.co.uk','Rita Radia','8 Coniston Gardens','Ilford','Essex','UNITED KINGDOM','ig45lu','02085505815',NULL,NULL,NULL,'2012-01-31 02:58:30',0,NULL,3,1,12,1,'3125444221 ',' 申报30美金  \r'),(20892,8881327980047498,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - MOAP001',1,'MOAP001',27.99,'aliexpress','1006475520','andersonmaurice.ma@gmail.com','Ravellette Publications, Inc.	','105 S. Wood Ave. PO Box 788','Philip','South Dakota	','UNITED STATES	','57567','5033096418',NULL,NULL,NULL,'2012-01-31 03:20:47',0,NULL,5,1,18,1,'LK037180668CN ','后来订单号改为：\r1006500930 '),(20893,836112952011,320820750152,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook',1,'HSNO034',14.99,'eastar4','krystalchris','krystal_christopher@hotmail.com','Krystal Ross','38 Amaroo Cres','Orange','New South Wales','AUSTRALIA','2800','0263623528','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 03:24:27',0,NULL,3,1,11,1,NULL,' 澳标 HSNO034'),(20912,781515466007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',2,'UM00053',39.98,'au-buy','sleepy0401','leepedrazzini@bigpond.com','Lee Pedrazzini','81 Goodwin Street','Currajong','Queensland','AUSTRALIA','4812','0401919081','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 11:04:09',0,NULL,3,1,3,1,'RA184536969CN\r ','UM00053 '),(20894,675575337013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','qzyphus','joeselway@gmail.com','Joe Selway','5 Gould Road','Stirling','South Australia','AUSTRALIA','5152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 03:50:47',0,NULL,3,1,11,1,' ',' CASS003'),(20895,675575434013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','alexprim_2009','alexprym@mail.ru','Alexander Potapov','Vatutina st.<br>4-50','Vladivostok-109','Primorye territory','RUSSIAN FEDERATION','690109','(914)705-0620','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 03:51:51',0,NULL,3,1,3,1,'RA184532304CN\r ',' GLOT001*3'),(20896,773238857008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','casa_di_eleganza','w.dabboussi@adscene.com.au','Wassim Dabboussi','58a Highland Ave<br>Bankstown','Sydney','New South Wales','AUSTRALIA','2200','0297094742','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 03:53:59',0,NULL,3,1,11,1,NULL,'MOMI002\r黑色 '),(20897,836129028011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','marxiecorporation','marxiecorp@gmail.com','Ozspy Brunswick - Martin Gomulya','Shop 1, 259 Sydney Road','Brunswick','Victoria','AUSTRALIA','3056','0434379637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 04:13:18',0,NULL,8,1,17,1,' RA184532763CN','GPS0010 \r这个人先后买了两个TK102电池 ，由于缺货上一个还没发，合并订单'),(20898,925980522012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','klyan1949','kyan@ecfinc.com','Kam-Leung Yan','2610 Remico St SW<br>ECF Inc.','Wyoming','MI','UNITED STATES','49519-2408','(616) 531-0670 ext.: 717','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 04:34:31',0,NULL,3,1,1,1,'LK189604382CN ',' HBPH007'),(20899,925987939012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','kultegin1977','kultegin@mail.ru','Kultegin Makishev','Kenesaru, 1 - 99','Astana','','KAZAKHSTAN','010000','8(701)5228850','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 05:33:10',0,NULL,3,1,11,1,NULL,'OTGR001+OTGR002 '),(20900,615829809003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','hellenicmaga','tasso.kanavos@gmail.com','Tasso Kanavos','3590 west 15th ave','Vancouver','BC','CANADA','v6r2z4','(604) 732-0391','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 05:36:53',0,NULL,3,1,3,1,'RA184532043CN\r ','CRLO001+POLO001 '),(20901,675597933013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','sweetdeals777','navarro@rogers.com','Les Navarro','31 Oak park Cres','Maple','ON','CANADA','l6a 0b3','(416) 570-5175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 06:12:20',0,NULL,3,1,11,1,NULL,'HSSA002 '),(20902,781452822007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',1,'CC00002',35.99,'au-buy','neilgjohnson','neil.johnson@balwynhs.vic.edu.au','neil johnson','7/212 Waterdale Rd','Ivanhoe','Victoria','AUSTRALIA','3079','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 06:22:26',0,NULL,3,1,11,1,NULL,'CC00002 '),(20903,8881327991608775,111,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'',0,'cnfaner','lenben_123','leninbude@talktalk.net','Len Benson','10 Valley Road','Bude','Cornwall','UNITED KINGDOM','EX23 8EP','01288354264',NULL,NULL,NULL,'2012-01-31 06:33:28',0,NULL,3,1,3,1,'RA184532057CN\r ','HSJA002 \r英标 \r补发的 '),(20904,926005901012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','canonfdfan','n.m.mckechnie@bris.ac.uk','Nicol McKechnie','1 Whytes Close','Bristol','Bristol','UNITED KINGDOM','BS9 3HU','01179501462','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 06:36:14',0,NULL,3,1,3,1,'RA184532030CN\r ','WLAP008 '),(20905,790391779001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','igrmichr','igrmic@gmail.com','Ivica Grmic','Ilocka 39','Bjelovar','','CROATIA','43000','38598545454','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-31 07:30:00',0,NULL,3,1,21,1,'RA184532026CN\r ','GPS0006\r客户要求申报价值 US$10 \r欧标'),(20906,773286264008,180781221355,'New Jabra JX10 Series II 2 Wireless Bluetooth headset  Sliver +AC  adapter',1,'HSJA0012',18.98,'au-buy','mark-noel','dejlig-familiehund@hotmail.com','Mark Noel','Knudsbjergvej 5B st th','Hadsten','','DENMARK','8370','0045-42753717','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-31 07:52:51',0,NULL,3,1,22,1,NULL,'HSJA0012 \r银色'),(20907,836181587011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',21.98,'eastar4','stevotone','stephen.winter@roche.com','Stephen Winter','Deskside Support, Roche Products<br>6 Falcon Way, Shire Park','Welwyn Garden City','Hertfordshire','UNITED KINGDOM','AL7 1TW','07969688934','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 08:30:14',0,NULL,3,1,11,1,' ',' CASS003'),(20908,836190404011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','airbibo','bmwcars@gmx.com','Abraham Thomas Malayatoor','90 Archbishop Makarios III Avenue<br>4th Floor IT Dept.','Nicosia','','CYPRUS','1077','(357) 228-8844 ext.: 4','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 09:12:17',0,NULL,3,1,21,1,'RA184538151CN\r\r ',' HSJA002'),(20909,615862926003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',3,'HSJA012',56.94,'cnfaner','simone_ge','simone@gerths.de','Architekturbüro Gerths','Blumenthalstraße 51','Berlin','','GERMANY','13156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 09:33:10',0,NULL,3,1,21,1,'RA184536439CN\r ','HSJA012\r欧标  银色的'),(20910,615875422003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','vmiparamedic','vmimedic@facebook.com','Codi Lingenfelter','334 Violetta Ave','North Las Vegas','NV','UNITED STATES','89031-1784','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-31 10:36:17',0,NULL,3,1,1,1,'LK188566060CN\r ',NULL),(20911,781507893007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','nbec07','nada.bechara@hotmail.com','Nada Bechara','16 Tennyson St','Winston Hills','New South Wales','AUSTRALIA','2153','0296399893','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 10:36:55',0,NULL,3,1,11,1,'BJ01669595\r ','RELO003 '),(20913,621199531004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','vjendrisvelimir','vjendris@gmail.com','velimir jendriš','tita brezovačkog<br>27','vrbovec','','CROATIA','10340','00385911319008','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 11:04:55',0,NULL,3,1,21,1,'RA184538307CN\r\r ','欧标 HSJA011'),(20914,926070688012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lazarminator','brkljavko@yahoo.com','Jordan Markovic','7-21-19','Aktau','Mangystau','KAZAKHSTAN','130000','+77015251104','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 11:05:16',0,NULL,3,1,11,1,'BJ01669580\r ',' HSJA001\r'),(20915,836239341011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','9045426101','alex1god@mail.ru','ALEKSANDR OVCHENKOV','st. Entuziastov 66 50','Nizhny Tagil','Sverdlovskaya obl','RUSSIAN FEDERATION','622035','79045426101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 12:01:49',0,NULL,3,1,3,1,'RA184538267CN\r\r ',' HSSE011'),(20916,836240135011,320787441787,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',38.99,'eastar4uk','ashfell83','ashfell69@aol.co.uk','Mr Ashley Fell','Business Solutions Ground Floor Block A<br>Albion Mill Pollard Street','Manchester','Lancashire','UNITED KINGDOM','M47AJ','01612741320','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 12:03:02',0,NULL,3,1,3,1,'RA184538050CN\r\r ','LGGL002 '),(20917,675659771013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','krlitos01','krlitos01@vodafone.es','carlos delgado','cruceiro quebrado 6-1ºizda','ourense','Galicia','SPAIN','32005','609338844','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 12:08:48',0,NULL,3,1,21,1,'RA184538253CN\r\r\r ',' MOSA004'),(20918,773351556008,180794745393,'Brand new HP MCE Media Center Remote Control+IR Emitter',1,'OTHP005',14.8,'au-buy','m4k05','m4k0@hotmail.com','Scott McKenzie','5 Nurses Walk','Larrakeyah','Northern Territory','AUSTRALIA','0820','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 12:14:59',0,NULL,3,1,11,1,'BJ01669527\r\r ','OTHP005 '),(20919,675685195013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','dmglobenko','globendi@rambler.ru','Dmitry Globenko','Musa Djalil str., 27-2, flat 521','Moscow','Moscow','RUSSIAN FEDERATION','115580','+7(915)1439935','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 13:54:58',0,NULL,3,1,11,1,'BJ01669547\r\r ',' BTHU2005'),(20920,675685087013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','koguitar','koguita@gmail.com','Luis Casanova','U6 382 St Kilda St<br>Brighton','Melbourne','Victoria','AUSTRALIA','3186','0412246327','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ',' e-check'),(20921,926134180012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','david_cadtec','david@cadtec.com.br','David Oliveira','R. Helena 218 Cj 1305','S. Paulo','SP','BRAZIL','04552-050','55-11 37725255','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 14:02:06',0,NULL,3,1,11,1,'BJ01669525\r\r ',' MOAP001'),(20922,621263561004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','rodrigovg86','rodrigo.venturini.gargioni@gmail.com','Rodrigo Gargioni','Avenida Erico Verissimo<br>900/507','Porto Alegre','Rio Grande do Sul','BRAZIL','90160-180','+555185086178','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 15:45:18',0,NULL,3,1,3,1,'RA184538275CN\r\r ',' CACN004'),(20923,926193025012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','mjill123','jillhow@talktalk.net','M Jill Howlett','34 McMaster House, Latimer Road<br>Headington','Oxford','Oxfordshire','UNITED KINGDOM','OX3 7PX','01865750773','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 16:24:48',0,NULL,3,1,3,1,'RA184538029CN\r\r ','GLOT001*2 '),(20924,675727860013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','davezman14q','davidjbehr@yahoo.com','David Behr','9225 Brandywine rd','Corcoran','MN','UNITED STATES','55340-9562','(763) 245-3020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 16:26:45',0,NULL,3,1,1,1,'LK189259587CN\r ',NULL),(20925,926204391012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','baedary','typingmania@naver.com','jihun jung','535 S Alexandria Ave<br>535 S. Alexandria Ave. #Leasing Office Apt 113','los angeles','CA','UNITED STATES','90020-2801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 16:45:38',0,NULL,3,1,1,1,'LK189354866CN\r ',NULL),(20926,675739958013,230617529499,'NIB SAMSUNG WEP200 Bluetooth Headset WEP 200 black ver',1,'HSSA002',15.9,'eastar4','ricardoparini','rjparini@click.com.py','Ricardo Parini - AS1825','9438 NW 13th St','Doral','FL','UNITED STATES','33172-2822','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 17:03:54',0,NULL,3,1,1,1,'LK189624943CN\r ','款已经退 发一个白色的当礼物'),(20927,836375771011,320679575635,'Original Apple Adapter for Airport Wireless WiFi Card',20,'WLAP004',70,'eastar4uk','stekkie18221','ajgeerts@ziggo.nl','Dennis Geerts','Vuntuslaan 9','LOOSDRECHT','','NETHERLANDS','1231NP','035 582 0800','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 17:46:55',0,NULL,3,0,21,1,' RA184532785CN\r','WLAP004\r可以发8个\r '),(20928,926244889012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','r.frometa','reytania@yahoo.es','Reinaldo Frometa','800 Trenton Rd<br>Apt 354','Langhorne','PA','UNITED STATES','19047-5611','(786) 333-5647','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 18:02:21',0,NULL,3,1,1,1,'LK189638474CN\r ',' '),(20929,926248780012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','ls110860','lstephens@sc.rr.com','Lewis Stephens','128 Taylors Hill Dr','Columbia','SC','UNITED STATES','29201-2377','(803) 254-7982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 18:19:37',0,NULL,3,1,1,1,'LK189549672CN\r ',NULL),(20930,675777351013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','k_arunprahash','arunprahash@hotmail.com','KALYANASUNDARAM ARUNPRAHASH','TERNEVEIEN-12','HAFRSFJORD','STAVANGER','NORWAY','4049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 18:44:02',0,NULL,5,0,18,0,NULL,' HSNO019  cancel order'),(20931,790608291001,110808692953,'NEW Jabra BT 500 Over The Ear Bluetooth Headset BT 500',1,'HSJA010',26.5,'buysia','peepish1998','caronjewel@aol.com','Elaine Caron','50A Cucumber Hill Rd','Foster','RI','UNITED STATES','02825-1212','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-01-31 18:47:55',0,NULL,3,1,1,1,'LK189213673CN\r ',NULL),(20932,926272538012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','taedamien','taekdamien@hotmail.com','damien escoffier','2694<br>route d\'albi','montgaillard','Midi-Pyrénées','FRANCE','81630','0563405515','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 18:48:27',0,NULL,3,1,3,1,'RA184536694CN\r ','GLOT001 '),(20933,621329152004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',18.59,'cnfaner','markhesseling01','markhesseling@hotmail.com','Mark Hesseling','Industriestraat 185-2','HENGELO OV','','NETHERLANDS','7553CN','0620766189','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 19:02:34',0,NULL,3,1,21,1,'RA184536703CN\r ',' HSAL002'),(20934,790619916001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','metz338','showjump@canopycanada.net','Karen Metz','Box 810','Redcliff','AB','CANADA','T0J 2P0','(403) 548-6641','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-01-31 19:05:28',0,NULL,3,1,3,1,'RA184538298CN\r\r ',' GPS0006'),(20935,836255578011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','macroman5','wpaios1@hotmail.com','James Keane','59 Whipperley Ring','Luton','Bedfordshire','UNITED KINGDOM','LU15QS','01582725534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 18:59:06',0,NULL,3,1,3,1,'RA184538085CN\r\r ','HSJA011\r英标 '),(20936,836426780011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','hyula','rudolf@laresser.com','Rudolf Laresser','Großtraberg 93','Traberg','','AUSTRIA','4183','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 19:18:59',0,NULL,3,1,22,1,'BJ01669553\r\r ','MOAP001 '),(20937,675799768013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',110.97,'eastar4','hightopdawg','sincret@gmail.com','Iulia Kolyada','Paustovskogo 3, kv 43','Odessa','Odessa','UKRAINE','65111','0937258975','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 19:29:36',0,NULL,3,1,3,1,'RA184536629CN\r ',' HSNO019\rHSNO035\r还买了一个New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook'),(20938,836476514011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','andrearay0429','pedromaccool@yahoo.com','Reinaldo Ramirez','1701 N Summit Dr<br>Unit 217','Dalton','GA','UNITED STATES','30721-2391','(423) 443-0514','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 20:35:38',0,NULL,3,1,1,1,'LK190118051CN\r ',' 客户要求在2月14号之前到货，估计不能按时到达，需要再次跟客户确认。'),(20939,616052861003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',18.99,'cnfaner','www.nicospage.de','nico.grudzielski@gmx.de','Grudzielski, Nico','In den Weiden 25a','Kühnhausen','','GERMANY','99189','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 20:41:33',0,NULL,3,1,21,1,'RA184538148CN\r\r ',' HSUE002'),(20940,621374061004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','2011_grega','grega.sever@igmat.eu','Grega Sever','Pot cez gmajno 101','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 20:48:07',0,NULL,3,1,21,1,'RA184538284CN\r\r ',' HBPH007'),(20941,674737473013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','joeboater44','joeleidecker@comcast.net','louis leidecker','14533 Plumosa Dr','jacksonville','FL','UNITED STATES','32250-2221','(904) 223-3540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 21:14:36',0,NULL,3,1,1,1,'LK188977666CN\r ',NULL),(20942,926377286012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','philcorden210754','phillmutt@yahoo.co.uk','philip corden','35 friargate court<br>friargate','derby','Derbyshire','UNITED KINGDOM','de1 1he','01332738918','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 21:23:14',0,NULL,3,1,3,1,'RA184538046CN\r\r ','HSJA002\r英标 '),(20943,836512061011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','mirage80400','fumoffu80@ebuyclub.com','Noel Dodré','14 Lot la pature','Ham','Picardie','FRANCE','80400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 21:36:04',0,NULL,3,1,3,1,'RA184538125CN\r\r ','GLOT001*2 '),(20944,926384972012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jennab1215','jennabethbee@yahoo.com','J Bergklint','3608 W Locust Cir','Prospect','KY','UNITED STATES','40059-9069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 21:41:44',0,NULL,3,1,1,1,'LK186942908CN\r ',NULL),(20945,836543247011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','marxiecorporation','marxiecorp@gmail.com','Ozspy Brunswick - Martin Gomulya','Shop 1, 259 Sydney Road','Brunswick','Victoria','AUSTRALIA','3056','0434379637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 22:41:18',0,NULL,3,1,3,1,' RA184532763CN\r','GPS0010\r这个人先后买了两个TK102电池 ，由于缺货上一个还没发，合并订单'),(20946,926422125012,220747230995,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',3,'HSUE003',47.7,'eastar4uk','bernie1979dog','bernieflanagan_1@hotmail.co.uk','Bernadette Flanagan','28 Argyle Avenue<br>Bolehall','Tamworth','Staffs','UNITED KINGDOM','B77 3PH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 22:52:53',0,NULL,3,1,3,1,'RA184538094CN\r','HSUE003 '),(20947,675887033013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','diensh2005','dineshnik@hotmail.com','diensh patel','12225 Rue du celtis','Pierrefonds','QC','CANADA','H8Z0A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 23:15:31',0,NULL,3,1,3,1,'RA184538117CN\r',' GLOT001*2\r'),(20948,834913883002,120841235559,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'buysia','diensh2005','dineshnik@hotmail.com','diensh patel','12225 Rue du celtis','Pierrefonds','QC','CANADA','H8Z0A8','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-01-31 23:20:21',0,NULL,3,1,11,1,'BJ01669523\r ',' TRSN001'),(20949,836574647011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','skeptic201','liam_allen64@o2.co.uk','liam allen','64 grendon road<br>kings heath','birmingham','West Midlands','UNITED KINGDOM','b14 4qz','01216281861','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 00:04:08',0,NULL,3,1,3,1,'RA184536615CN\r ','UDAP001 '),(20950,675906810013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','kev2712','kulbrick@bigpond.net.au','Kevin Ulbrick','69 Serrell St','Malvern East','Victoria','AUSTRALIA','3145','0419375062','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 00:33:43',0,NULL,5,1,4,1,'YW868898044CN\r ','已发货，点不了 '),(20951,836579099011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','anandpreet120','anandpreet@hotmail.co.uk','Anandpreet Singh','65 Hertford House<br>Taywood Road','Northolt','Middlesex','UNITED KINGDOM','UB56GD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 00:19:21',0,NULL,3,1,3,1,'RA184538077CN\r\r ','GLOT001 '),(20952,773665551008,180794745393,'Brand new HP MCE Media Center Remote Control+IR Emitter',1,'OTHP005',14.8,'au-buy','lcdmanlcd','alantoop@internode.on.net','alan toop','150 Gair St','Frenchville','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-01 00:38:46',0,NULL,3,1,11,1,'BJ01669528\r\r ','OTHP005 '),(20953,926464969012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',76.99,'eastar4uk','qwertyrol','drcarsales1@hotmail.co.uk','darrel poole','UNIT 11 GREEN LANE DYE WORKS<br>yeadon','leeds','West Yorkshire','UNITED KINGDOM','ls19 7xp','07527455299','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 00:48:05',0,NULL,3,1,3,1,'RA184538196CN\r\r ','LGGL002*2 '),(20954,926464544012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','lecogif','lecogif@yahoo.com.br','Alexandre Gianotti de Freitas','R.Conselheiro Brotero,686 ap-64','São Paulo','São Paulo','BRAZIL','01232-010','551170298165','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 00:49:52',0,NULL,3,1,11,1,'BJ01669394\r ',' HSNO005'),(20955,675887206013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','chyanime','chyanime92@yahoo.com','Chyenne Bertrand','710 S College Rd<br>Apt 73','Lafayette','LA','UNITED STATES','70503-3385','(337) 764-3063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 01:02:30',0,NULL,3,1,1,1,'LK189291239CN\r ',NULL),(20956,675911269013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','terrywoodland2012','woodlandterry@yahoo.ca','Terry Woodland','5 Highland Drive','Shoal Harbour','NL','CANADA','A5A 4J7','(709) 427-7817','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 01:11:55',0,NULL,3,1,3,1,'RA184538324CN\r\r ',' GPS0004'),(20957,616127741003,130554589190,'New Philips Sonicare flexcare toothbrush Handle HX6930',1,'HBPH002',67.99,'cnfaner','zai4onok','anatomariya-ch200113@rambler.ru','mariya chavdar','13620 N Regal Ct','mead','WA','UNITED STATES','99021','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 01:14:17',0,NULL,3,1,1,1,'LK181896407CN\r ',NULL),(20958,836598719011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','yovchev78','yovchevgeorgi@yahoo.com','georgi yovchev','110 inwen court<br>grinstead road','london','London','UNITED KINGDOM','se8 5bj','07984469191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 01:22:24',0,NULL,3,1,17,0,'RA184533110CN\r ',NULL),(20959,836600440011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','yovchev78','yovchevgeorgi@yahoo.com','georgi yovchev','110 inwen court<br>grinstead road','london','London','UNITED KINGDOM','se8 5bj','07984469191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 01:27:54',0,NULL,3,1,3,1,'RA184533110CN\r ','HSNO035\r一共买了两个耳机 （合并订单） '),(20960,621450604004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','lainecurry','laine.curry@yahoo.com','Laine Curry','5907 Vickery Blvd','Dallas','TX','UNITED STATES','75206-6337','(214) 616-2316','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 01:31:41',0,NULL,3,1,1,1,'LK188981997CN\r ',NULL),(20961,836605464011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','williej6969','williej6969@yahoo.com','willie jones','3630 Vivian Ln','Columbus','GA','UNITED STATES','31906-4411','(706) 687-8472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 01:46:38',0,NULL,3,1,1,1,'LK183113955CN\r ',' '),(20962,8881328061677774,111,'兼容眼镜',3,'GLOT001',0,'eastar4uk','flartley','steve_spleen@sky.com','stephen barker','4 codale avenue, bispham','blackpool','Lancashire','UNITED KINGDOM','FY20BA','01253311072',NULL,NULL,NULL,'2012-02-01 02:01:17',0,NULL,5,1,18,0,NULL,'GLOT001\r客户开了case，承诺月底收不到就退款 \r已退款'),(20963,926495328012,220806897821,'New lady lace trim sun/rain stick Umbrella Ivory',1,'UM00011',24.99,'eastar4','ciara_chan82905','ciaradeuter@yahoo.com','Ciara Deuter','PO Box 868772','Tuscaloosa','AL','UNITED STATES','35486-0178','(334) 546-1546','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 02:20:07',0,NULL,3,1,1,1,'LK183023146CN\r ',' 象牙白'),(20964,8881328063358734,111,'New Jabra BT250V  只发耳机 不发电源',1,'HSJA001',0,'eastar4','962michael','mikerea@wowway.com','Michael Rea','376 Lange Dr','Troy','MI','UNITED STATES','48098-4624','(248) 844-9055',NULL,NULL,NULL,'2012-02-01 02:29:18',0,NULL,3,1,1,1,'LK162432180CN\r ','测试一下是否有杂音 '),(20965,616146118003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','twoyams','cherie.henderson@verizon.net','Cherie Henderson','343 E 74th St<br>Apt 11G','New York','NY','UNITED STATES','10021-3767','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 02:40:47',0,NULL,3,1,1,1,'LK179551067CN\r ',NULL),(20966,926363953012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','12taxicab','hellandjon@aol.com','John Wright','83 Buckswood drive, Gossops Green','Crawley','West Sussex','UNITED KINGDOM','RH118JA','07879615525','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 02:50:50',0,NULL,3,1,3,1,'RA184538182CN\r\r ','HSJA010\r英标 '),(20967,926511194012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','crios333','crios_olc@hotmail.com','Erik Henderson','3117 Quadra Street','Victoria','BC','CANADA','V8X 1E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 03:07:07',0,NULL,3,1,11,1,'BJ01669594\r ',' WLAT005'),(20968,8881328066428680,111,'Free shipping & Tracking - LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV - ',1,'LGRM001',44.99,'aliexpress','1006486409 ','olega59@yandex.ru','Baldin Oleg Aleksandrovich	','Street. Rahova 88 kv.14','Chita','RU','RUSSIAN FEDERATION	','672005','+7 924 3746155',NULL,NULL,NULL,'2012-02-01 03:20:28',0,NULL,3,1,3,1,'RA184538491CN ','LGRM001 *1 '),(20969,8881328066805872,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',27.99,'aliexpress','1006501405','andersonmaurice.ma@gmail.com','Natalie Martinez	','749 Gresham Ave SE','Atlanta','Georgia','UNITED STATES	','30316-3838','',NULL,NULL,NULL,'2012-02-01 03:26:45',0,NULL,5,1,18,0,NULL,'MOAP001 *1 '),(20970,8881328067003545,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',27.99,'aliexpress','1006501611','andersonmaurice.ma@gmail.com','Carol Hoyt	','PO Box 4759','Dowling Park	','Florida','UNITED STATES	','32064-1508','',NULL,NULL,NULL,'2012-02-01 03:30:03',0,NULL,5,1,18,0,NULL,'MOAP001 *1 '),(20971,836637945011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','lenard1951','lenardp@verizon.net','Lenard J. Persin','209 Boulevard, Unit 2','Passaic','NJ','UNITED STATES','07055','(646) 592-3428','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 03:31:52',0,NULL,3,1,1,1,'LK181647603CN\r ',' '),(20972,8881328067200231,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',27.99,'aliexpress','1006501892','andersonmaurice.ma@gmail.com','Joe Clark	','7111 TYLER ST','HOLLYWOOD','FLORIDA','UNITED STATES	','33024-7353','',NULL,NULL,NULL,'2012-02-01 03:33:20',0,NULL,5,1,18,0,NULL,'MOAP001 *1 '),(20973,8881328067311647,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',27.99,'aliexpress','1006501925','andersonmaurice.ma@gmail.com','anthony sandner	','72 N CENTRAL ST','EAST BRIDGEWATER	','Massachusetts','UNITED STATES	','33024-7353','',NULL,NULL,NULL,'2012-02-01 03:33:20',0,NULL,5,1,18,0,NULL,'MOAP001 *1 '),(20974,8881328067437305,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 - ',1,'MOAP001',27.99,'aliexpress','1006501966','andersonmaurice.ma@gmail.com','anthony sandner	','4735 PECOS ST DENVER PUBLIC SCHOOLS - REMINGTON ELEMENTARY ARTS DEPT','DENVER','Colorado','UNITED STATES	','80211-2331','',NULL,NULL,NULL,'2012-02-01 03:33:20',0,NULL,5,1,18,0,'','MOAP001  *1 '),(20975,675955216013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','thesandbergs2011','sandbergfamily1@googlemail.com','The Sandbergs','2104 NE Oak Dr','Ankeny','IA','UNITED STATES','50021-4622','(563) 212-9278','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 04:04:29',0,NULL,5,1,18,0,NULL,'已退款'),(20976,616163544003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','cbh123','cbh123@hotmail.com','Chris Hendriksen','11261 Terwilligers Valley Ln','Cincinnati','OH','UNITED STATES','45249-2740','(312) 450-4849','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 04:11:40',0,NULL,3,1,1,1,'LK188369983CN\r ',' '),(20977,8881328070247609,111,'890control',1,'',0,'au-buy','gadget!','n1kld@aol.com','Robert W Stanton','516 Merwin Ave','Milford','CT','UNITED STATES','06460-7111','(203) 626-1866',NULL,NULL,NULL,'2012-02-01 04:24:07',0,NULL,3,0,1,1,'LK068319441CN ','客户退回遥控器，补发 '),(20978,616169544003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','tax411','taxx411@facebook.com','Alex Abba','122 5th Ave<br>Attn: 4th Floor','New York','NY','UNITED STATES','10011-5605','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 05:02:23',0,NULL,3,1,1,1,'LK189834955CN\r ',NULL),(20979,616175792003,130626363900,'Brand New Logitech Unifying Receiver for M505 M705 M905 etc mouse- 100% official',1,'RELO002',12.95,'cnfaner','yummmydonuts','happydonutshop@gmail.com','Duygu Aksu','PO Box 2201','Thibodaux','LA','UNITED STATES','70310-0001','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 05:40:22',0,NULL,3,1,1,1,'LK190053537CN\r ',NULL),(20980,836691952011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','papirus747','sea_vegas@mail.ru','Yegor Savchenko','Ratyshnogo 100a - 17','Almaty','Almatinskaya','KAZAKHSTAN','050014','7-7770027672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 07:57:06',0,NULL,3,1,3,1,'RA184520805CN\r ',' GPS0007'),(20981,926577684012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','nivek3k','nivek3k@gmail.com','Kevin Wilson','Spenser\'s House<br>Hurstwood','Burnley','Lancashire','UNITED KINGDOM','BB10 3LG','01282412329','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 08:00:36',0,NULL,3,1,3,1,'RA184536884CN\r ','OTCN004*10 '),(20982,926588509012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','daisydaniel0','dbeynonfisher@aol.com','daniel Beynon-Fisher','9 scoply lane<br>whitley','dewbury','West Yorkshire','UNITED KINGDOM','wf12 0ng','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 08:45:17',0,NULL,3,1,3,1,'RA184536898CN\r ','UK plug   HSJA002'),(20983,8881328087765268,111,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150  ',1,'HSUE004',0,'cnfaner','roman.2262','roman.vesely@hotmail.com','Roman Vesely','Jeseniova 159','Praha 3 - Zizkov','','CZECH REPUBLIC','13000','',NULL,NULL,NULL,'2012-02-01 09:16:05',0,NULL,3,0,3,1,'RA184520685CN\r ',' HSUE004 new replacement'),(20984,926597734012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','gobione75','pelle@ropson.se','Per Olsson','Sjöbjörnsvägen 66D<br>Ropson AB','Stockholm','','SWEDEN','11767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 09:23:24',0,NULL,3,1,22,1,'BJ01669574\r ',' MOAP001'),(20985,8881328088452719,111,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',0,'eastar4','promythyus','brooksaar@gmail.com','Aaron Brooks','4A Mason Street','Thirlmere','New South Wales','AUSTRALIA','2572','0246819804',NULL,NULL,NULL,'2012-02-01 09:27:32',0,NULL,3,1,11,1,'BJ01669576\r ',' WLIN015'),(20986,676010539013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','vinaymote1','vinaymote1@yahoo.com','Vinay Mote','2106/28<br>Wills Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 09:55:28',0,NULL,3,1,3,1,'RA184520765CN\r ',' GLOT005 DLP 3D ready 投影仪兼容眼镜'),(20987,621541539004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.88,'cnfaner','ricis666','rbaranovskis@inbox.lv','Ritvars Baranovskis','Hornsevej 6','BYLDERUP BOU','Denmark','DENMARK','6372','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 10:44:10',0,NULL,3,1,21,1,'RA184536822CN\r ','HSNO022 \r欧标'),(20988,926632994012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','paulja1970','p_j_aiken@yahoo.co.uk','Paul Aiken','C/- UnitingCare Moreland Hall<br>26 Jessie St','Moreland','Victoria','AUSTRALIA','3058','0393848867','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 11:22:01',0,NULL,3,1,3,1,' RA184532919CN\r','OTGR001+OTGR002 \r货到了优先给这个客户发'),(20989,926650297012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','markg1828','markyboy1828@live.co.uk','Mark Gourdie','33 Main Street','Bathgate','West Lothian','UNITED KINGDOM','EH48 4HW','07939636839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 12:13:56',0,NULL,3,1,3,1,'RA184536907CN\r ','HSJA002  \r英标 '),(20990,836762270011,320441567733,'2.1 Acer Aspire 5680 5630 3690  Bluetooth Module+cable',1,'BTAC2122',12.39,'eastar4','lechucksky','lechucks@gmail.com','jose maria calvillo gallardo','marques del nervion 24 2ºa','sevilla','Sevilla','SPAIN','41005','954582022','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 12:19:46',0,NULL,3,1,22,1,'BJ01669571\r ',' BTAC2122 acer 8pin1.00 8cm '),(20991,926661729012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.99,'eastar4uk','tkle18','tkle18@gmail.com','Thien Le','2 Chevalier St','PROSPECT','South Australia','AUSTRALIA','5082','0411571418','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 12:46:47',0,NULL,3,1,11,1,'BJ01669589\r ','OTGR002 '),(20992,676049355013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',3,'OTCN001',17.94,'eastar4','simstermanp5052','simstermanp@gmail.com','Trevor Sims','98 Market St<br>Apt A','Northampton','MA','UNITED STATES','01060-3292','(413) 313-9379','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 12:58:21',0,NULL,3,1,1,1,'LK190259227CN\r ',NULL),(20993,926684107012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','wrangler6611','joel.aitken.is@gmail.com','Joel Aitken','86 Northey Drive','Toronto','ON','CANADA','M2l2S9','(647) 348-2770','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 13:48:26',0,NULL,3,1,3,1,'RA184536805CN\r ',' HBPH001'),(20994,621588010004,140667903814,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card + A pair of Antenna',2,'WLAT009+ANTY001',23.8,'cnfaner','piopawlu','piotrek@piopawlu.net','Svenska Resenätverket AB','Adolf Fredriks Kyrkogata 13','Stockholm','','SWEDEN','111 37','+46855801500','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:20:26',0,NULL,3,1,21,1,'RA184520694CN\r ','WLAT009+ANTY001 '),(20995,621591001004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','anastasia_coyote','an.messe@gmail.com','Anastasia Meshchaninova','Olhovaya street 1<br>flat 188','Vidnoe','Moscow area','RUSSIAN FEDERATION','142701','89859794875','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:28:19',0,NULL,3,1,3,1,'RA184520734CN\r ','OTTP001 '),(20996,836812593011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','basrik77','bas@rikker.nl','Bas Rikkerink','C. van  Renneslaan 37','Almelo','','NETHERLANDS','7604HV','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:43:59',0,NULL,3,1,22,1,'BJ01669572\r ',' WLIN015'),(20997,676076534013,230717844180,'New Princess Double Layer Net Yarn w/Lace Bowtie Anti-UV J-handle Umbrella',1,'UM00044',24.99,'eastar4','g.butty','gil.butty@pourlesyeux.ch','Gil Butty','ch François Lehmann 28','Le Grand-Saconnex','','SWITZERLAND','1218','794447758','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:44:35',0,NULL,3,1,22,1,'BJ1669570 ',' UM00044'),(20998,621597994004,140667905446,'NEW Replaceable Shell for logitech Mouse M705',1,'SHLO003',12.99,'cnfaner','igor259','igor_piskorskiy@mail.ru','Igor Piskorskiy','Elizarovih street, 22-43','Tomsk','','RUSSIAN FEDERATION','634012','8-953-920-47-86','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:54:51',0,NULL,3,1,3,1,'RA184520853CN\r ','SHLO003 '),(20999,926707596012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',49.98,'eastar4','diluera','diluera@hotmail.com','Diane Luera','3655 Noblett Dr','Conway','AR','UNITED STATES','72034-5599','(501) 428-7747','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 14:55:22',0,NULL,3,1,3,1,'RA184538911CN ','等包好之后\r需确认一下重量，算运费\rUM00034+UM00009\r还买了一个\rNew Rainbow Trim parasol Sun/Rian stick umbrella \r'),(21000,926629844012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','baztrev','trevhulb10@sky.com','Ace transport Fao Barry Hulbert','Winchester Avenue<br>Blaby Ind est, Blaby','Leicester','Leicestershire','UNITED KINGDOM','le8 4gz','01162770304','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 15:09:15',0,NULL,3,1,3,1,'RA184536819CN\r ','HSJA010\r英标 '),(21001,836824617011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','laimber82','ljohal82@hotmail.co.uk','KULWANT JOHAL','82 SCOTTS ROAD<br>SOUTHALL','LONDON','Middlesex','UNITED KINGDOM','ub25de','02085743077','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 15:19:33',0,NULL,3,1,11,1,'BJ01669575\r ',' HSNO007 英标'),(21002,926729399012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','monymanya','novoamonica71@hotmail.com','Monica Novoa','Avenida Son Vilar nº 14<br>Son Vilar -Es Castell-','Menorca','Baleares','SPAIN','07720','971159601','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 15:38:27',0,NULL,3,1,21,1,'RA184520779CN\r ','GLOT005 '),(21003,676100782013,230393147131,'2.1 Acer Extensa 5220 5620 5620Z Bluetooth Module+cable',1,'BTAC2106',12.39,'eastar4','34298siegmar','1433-39@onlinehome.de','Siegmar Cornelius','Torweg 6','Helsa','','GERMANY','34298','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 16:02:57',0,NULL,3,1,22,1,'BJ01669573\r ',' BTAC2106 acer 4pin1.25 15cm '),(21004,836851582011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',2,'GLOT001',53.98,'eastar4uk','0waldek','waldes@poczta.onet.pl','Waldemar Glinka','smocza 5,','szczecin','zachodniopomorskie','POLAND','70-731','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 16:17:52',0,NULL,3,1,21,1,'RA184520782CN\r ','GLOT001 '),(21005,836862580011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','teolmp2010','teolmp@gmail.com','Tennyson Pires','Rua Felipe de Oliveira, nº 842, apt 202','Porto Alegre','Rio Grande do Sul','BRAZIL','90630000','51-92523013','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 16:47:33',0,NULL,3,1,3,1,'RA184520663CN\r ','HSSE011'),(21006,621642708004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','ramonytomas','m00n82@hotmail.com','Carlos Montoya Ruiz','Vicenç Nubiola, 3  1ª 4ª esc. A','Pallejà','Cataluña','SPAIN','08780','645828589','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 17:28:05',0,NULL,3,1,21,1,'RA184520717CN\r ','MOOE001\rOEM '),(21007,676137845013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','vfer7004','vvinrobali@aol.com','vincent ferragamo','47 Claradon Ln','Staten Island','NY','UNITED STATES','10305-2808','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 17:46:35',0,NULL,3,1,1,1,'LK175264352CN\r ',' '),(21008,926798511012,220826597098,'NIB Kensington Expert Mouse Optical USB Trackbal K64325',1,'OTKE001',95.99,'eastar4','senaqueribsenaquerib','jgrmmg@hotmail.com','JORGE  GARCIA ROSILLO','C/CIRCUNVALACION DE LA ENCINA Nº 9 BAJO  IZQUIERDA','GRANADA (GRANADA)    ESPAÑA   (SPAIN)','Andalucía Ceuta y Melilla','SPAIN','18015','656466217','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 17:54:25',0,NULL,5,0,18,1,' ',' OTKE001 \r\r已退款\r等客户留好评 \r然后送一个鼠标当礼物'),(21009,616324301003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','fnaugtyguy','w_ar_1@hotmail.com','WILMER ARAGON','401 ITASCA ST','WOOD DALE','IL','UNITED STATES','60191-1407','(312) 446-7138','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 18:03:05',0,NULL,3,1,1,1,'LK189929812CN\r ',NULL),(21010,676145595013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',3,'WLIN014',56.97,'eastar4','ozshforever2008','ozshforever@gmail.com','Avriskin Mikhail','Vyazemsky ln, 5-7, 426','Saint Petersburg','Leningradskaya oblast','RUSSIAN FEDERATION','197022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 18:17:05',0,NULL,3,1,3,1,'RA184520748CN\r ',' WLIN014'),(21011,926810235012,220891421312,'NIB Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking TK103-2',1,'GPS0008',68.99,'eastar4uk','brunomede','brunomedeiro@msn.com','bruno medeiros','Rua porto da gama, 39<br>olavo bilac','duque de caxias','rio de janeiro','BRAZIL','25025430','+5502127834750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 18:23:15',0,NULL,3,1,3,1,'RA184520796CN\r ','GPS0008 '),(21012,621685359004,140516860457,'New Intel 5350 WiMAX Wifi 802.11n PCI-E Card not IBM',1,'WLIN012',32.89,'cnfaner','rd3bl','admin@cyberdom.ru','LEONID BELETSKI','Sudostroitelnaia 31-3-133','MOSCOW','','RUSSIAN FEDERATION','115407','(495)922-4712','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 19:23:05',0,NULL,3,1,3,1,'RA184520751CN\r ','WLIN012 '),(21013,621685768004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','rickf1032','rickfindley@comcast.net','Rick Findley','1032 Ridgecrest Dr','Kingston Springs','TN','UNITED STATES','37082-9760','(615) 952-9477','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-01 19:23:09',0,NULL,3,1,1,1,'LK190253895CN\r ',NULL),(21014,836957868011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','gimpire','potapov.danil@gmail.com','Danil Potapov','str. Vavilovyh 7/4 - 334','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195257','7-921-7500912','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 19:35:24',0,NULL,3,1,11,1,'BJ01669552\r ',' WLAT003'),(21015,926867427012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',36,'eastar4uk','smfarense','sm@gbu.pt','Armando Mestre','Rua 25 de Abril, 44 - 2º Esq','Pechão - Olhão','Portugal','PORTUGAL','8700-180','+351 963530302','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 19:43:39',0,NULL,3,1,21,1,'RA184520703CN\r ','WWSI006+ANCN001 '),(21016,835301232002,120844622416,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'buysia','rostislav4bay','rostislav4shopping@gmail.com','Rostislav Rusakov','Khabarovskaya street 14-2, Apt. 156','Moscow','','RUSSIAN FEDERATION','107589','+7 916 1339364','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-01 19:49:12',0,NULL,3,1,11,1,'BJ01669587\r ','HSUE003 '),(21017,836976518011,320730088401,'NEW sealed Logitech Wireless Laser Mouse M505 +unifying',1,'MOLO008',21.99,'eastar4uk','avatartron','tronavatar@gmail.com','James Scott','16 Tynwald Green<br>Moortown','Leeds','West Yorkshire','UNITED KINGDOM','LS175NL','01132120270','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 20:03:42',0,NULL,3,1,3,1,'RA184538474CN ','MOLO008\r已确认给买家发  黑色'),(21018,621734610004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','malbec123','malbec@netcourrier.com','malbec daniel','1 rue didier daurat','saint pierre du mont','landes','FRANCE','40280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 21:30:08',0,NULL,3,1,3,1,'RA184520677CN\r ','BALO007 '),(21019,616414549003,130596105709,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',18.98,'cnfaner','murat1983murat','muratdulkar@hotmail.com','Murat Dulkar','Solheims vn 85 a<br>1473','Lørenskog','Lørenskog','NORWAY','1473','004793499820','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 21:32:02',0,NULL,3,1,21,1,'RA184536836CN\r ','HSJA013 \r欧标  red'),(21020,616420271003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','tony090726','798518737@qq.com','Tony zhao','ellesmere<br>shropshire','ellesmere','Shropshire','UNITED KINGDOM','SY12 9AB','07414928822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 22:06:38',0,NULL,3,1,3,1,'RA184536853CN\r ','MOLO006 '),(21021,774093971008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','garyowens97','gary1997@btinternet.com','GARY OWENS','WREXHAM FURNITURE<br>45 WATERY ROAD','WREXHAM','Wrexham','UNITED KINGDOM','LL137SY','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-01 22:09:26',0,NULL,3,1,11,1,'BJ01669586\r ','RELO001 '),(21022,616437091003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','jesspinkman','a.sexto@gmail.com','Alejandro Sexto','c/ Perez Cepeda 4, 3Izq','A Coruna','Galicia','SPAIN','15004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 22:48:08',0,NULL,3,0,21,1,'RA184536840CN\r ','HBPH001 '),(21023,926966790012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','howardpmay','howard@mayfamily.ca','Howard May','209 rue Robert Est','chateauguay','QC','CANADA','J6J 1C2','(514) 569-4400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 23:26:08',0,NULL,3,1,3,1,'RA184536765CN\r ','RCLO006 '),(21024,621776568004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.49,'cnfaner','snowbirdtrader','denniscspaulding@gmail.com','Dennis Spaulding','13306 Shadberry Ln','Hudson','FL','UNITED STATES','34667-2719','(727) 233-0616','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 00:03:31',0,NULL,3,1,1,1,'LK186460874CN\r ',' white'),(21025,616457089003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','yourook','tiko.crowe@gmail.com','Ty Crowe','740 Pioneer Rd<br>Apt B','Brookings','OR','UNITED STATES','97415-7218','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 00:18:16',0,NULL,3,1,1,1,'LK190901860CN\r ',NULL),(21026,782347332007,170759689707,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',72.99,'au-buy','s-soss7','simonhelps77@gmail.com','Simon Helps','21 McDonlds Lane','Mulgrave','Victoria','AUSTRALIA','3170','0392623000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-02 01:02:48',0,NULL,3,1,3,1,'RA184533123CN\r','HSNO035\r澳标 '),(21027,837086556011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','pedgarsantos2012','pedgarsantos@gmail.com','Interponto Paulo Santos','Zona Industrial da Maia I<br>Sector IX Sul Lote 6','PT','MAIA','PORTUGAL','4470-516','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 01:16:31',0,NULL,3,1,22,1,'BJ01669568\r ',' HSUE002'),(21028,621807552004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','rebeiins36','rebeiins36@aol.com','Rico Serrano','10546 arleta ave','mission hills','CA','UNITED STATES','91345-2326','(818) 687-7941','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 02:27:10',0,NULL,3,1,1,1,'LK188774969CN\r ',NULL),(21029,836652626011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','jcrs421','pcgeeks0@gmail.com','Juan  Carlos Reyes','PO Box 2867','San Luis','AZ','UNITED STATES','85349-2867','(928) 627-3104','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 02:47:09',0,NULL,3,1,1,1,'LK189585414CN ',NULL),(21030,616494036003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','littleblackbirds','lbbbusiness@ymail.com','kristi buchanan','28 green valley drive','bidwell','OH','UNITED STATES','45614','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 03:11:04',0,NULL,3,1,1,1,'LK190178245CN\r ',''),(21031,8881328152895164,111,'New Apple PowerBook G4 AirPort Extreme WiFi Card A1026 新的',1,'WLAP003',54.99,'eastar4','pastorog ','pastorog@madnet.net','Roger Leach','101 W Adell St','Madera','CA','UNITED STATES','93638-0877','',NULL,NULL,NULL,'2012-02-02 03:21:35',0,NULL,3,1,1,1,'LK187999603CN\r ',NULL),(21032,837128738011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','lambslamborghini','lambswildthing2002@yahoo.com.au','LAMBROS GAKIOS','159 AMESS STREET','CARLTON NORTH','Victoria','AUSTRALIA','3054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 03:36:34',0,NULL,3,1,11,1,'BJ01669546\r ','MOLA001 '),(21033,8881328154529105,111,'New genuine Garmin GPS 12XL GPS Receiver',6,'GPS0009',570,'eastar4uk','theluckydoctor','amiramin72@gmail.com','M Amer Amin','Flat # 806, Dana Al Masood Tower, Najda Street','Abu Dhabi ','','UNITED ARAB EMIRATES','28985','',NULL,NULL,NULL,'2012-02-02 03:48:49',0,NULL,3,1,6,1,'EE667838733CN\r ','申报200$\rM.Amir Amin\rFlat #101, Villa # 36,\r Manaseer,P.O Box\rAbu Dhabi,\rU.A.E.\rTel:+971-50-6153945 (mobile)\r\r '),(21039,621614593004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','zaraostre','zaraostre@free.fr','Hubert CORNIL','68, rue du général Leclerc','CHATOU','Île-de-France','FRANCE','78400','0139527533','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 08:00:02',0,NULL,3,1,21,1,'RA184520836CN\r ','HBPH007 '),(21034,927042200012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',4,'GLOT001',107.96,'eastar4uk','kandi02082009','kandi.kolka@yahoo.com','kandi Kolka','2700 Shimmons Rd<br>Lot 59','Auburn Hills','MI','UNITED STATES','48326-2004','(248) 672-0714','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 04:32:26',0,NULL,3,1,1,1,'LK190356820CN\r ',NULL),(21035,616516720003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',5.99,'cnfaner','judgrick','rjbranam@coalgate.net','Richard E. Branam','4 N Main St<br>Ste 12','Coalgate','OK','UNITED STATES','74538-2844','(580) 320-1807','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 05:28:27',0,NULL,3,1,1,1,'LK189108587CN\r ',NULL),(21036,676348931013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','a-m_photos','annmargretphotos@aol.com','Barry Santiago','36 Osprey Dr','West Henrietta','NY','UNITED STATES','14586-9303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 06:25:26',0,NULL,3,1,1,1,'LK190291995CN\r ',NULL),(21037,8881328166588402,111,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card - WLIN015',1,'WLIN015',14.99,'aliexpress','1006471702','paritetinvest@gmail.com','Vasily Popov	','Malaya Kalitnikovskaya street, dom 2, korpus 2, apartment 197','Moscow','Russia','RUSSIAN FEDERATION	','109029','+007 495 6705179',NULL,NULL,NULL,'2012-02-02 07:09:48',0,NULL,3,1,3,1,'RA184534937CN','WLIN015 *1 '),(21038,927100260012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','kronic101','kron1c@msn.com','Margaret Rodgers','3 The Close, Melrose Park<br>Kinsealy','Swords','Dublin','IRELAND','Co','018400464','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 07:18:18',0,NULL,3,0,21,1,'RA184520840CN\r ','MOMI002 黑色 '),(21040,837199906011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',45.5,'eastar4','djano2007','jano.074@hotmail.com','djano laoulach','82 belmont st<br>merrylands','sydney','New South Wales','AUSTRALIA','2160','0296327183','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 09:15:36',0,NULL,3,1,3,1,'RA184520822CN\r','HSNO019+CCNO001\r 澳标'),(21041,621874165004,140626375805,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',6.3,'cnfaner','ketter_baby_doll123','ketter_baby_doll@yahoo.com','keightan crawford','316 adams st','adamsville','TN','UNITED STATES','38310','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 09:38:05',0,NULL,3,1,1,1,'LK185253155CN\r ',NULL),(21042,837210285011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',3,'WWSI004',110.97,'eastar4','gosi-at','ebay@gosi.at','Daniel Urstoeger','Obere Donaustrasse 69/20','Wien','','AUSTRIA','1020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 10:01:37',0,NULL,3,1,21,1,'RA184538390CN\r ','WWSI004 '),(21043,676383953013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','johno5451','mrmrsoldies@bigpond.com.au','john oldfield','7 Finniss Street','Gawler','South Australia','AUSTRALIA','5118','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 10:08:59',0,NULL,3,1,3,1,'RA184548732CN\r ','GLOT001*3 '),(21044,676384642013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','bric*brac','info@lebigdeal.net','Zoumis Roger','Rue de Birmingham 350','Bruxelles','','BELGIUM','1070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 10:11:45',0,NULL,3,1,21,1,'RA184548729CN\r ','GLOT001*2 '),(21045,774276361008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','cobester_syd','bryans_rego@hotmail.com','Bryan Samuel','112 Meurants Lane','Glenwood','New South Wales','AUSTRALIA','2768','0431485106','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-02 10:16:24',0,NULL,3,1,11,1,'BJ01669560\r ','BALO001 '),(21101,837712615011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','sinnsinner123','sinnsinner@hotmail.com','M. Moehamad','Blauwdasstraat 29','AMSTERDAM ZUIDOOST','','NETHERLANDS','1102SP','+31(0)624589627','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 08:40:18',0,NULL,3,1,22,1,'BJ01669563\r ','MOAP001 '),(21046,837232355011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',9.88,'eastar4','g2logic','j.first@seznam.cz','Jiří First','Tridvorska 1410','KOLIN','KOLIN','CZECH REPUBLIC','280 02','+420606828606','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 11:15:07',0,NULL,3,1,11,1,'BJ01669558\r ','BTHP2001 \rHP 8pin 1.0 3cm '),(21047,837243786011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','mpms571','smatsantos@portugalmail.pt','Sara Isabel Santos','Avenida Edmundo Lima Bastos<br>nº25, 1ºB','CARNAXIDE','OEIRAS','PORTUGAL','2790-485','+351916454440','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 11:53:14',0,NULL,3,1,22,1,'BJ01669532\r ','UDAP001 '),(21048,837244768011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','golfrabbit!','warren@saltfordmotors.co.uk','warren hunt','491 bath road','saltford','Bristol','UNITED KINGDOM','BS313HQ','01225872850','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 11:56:58',0,NULL,3,1,3,1,'RA184538372CN\r ',' MOAP001'),(21049,616575912003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','marsyanya','nickson2000@mail.ru','Vladimir Nikulenko','28 Kalarasha Street, Appartment 29','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 11:58:37',0,NULL,3,1,3,1,'RA184533208CN\r ','HSNO019\r欧标 '),(21050,621904116004,140644120744,'NIB genuine Philips SHS4847 Flexible Earhook Headphones Orange durable Bass Pipe',1,'HSPH007',22.5,'cnfaner','2011baydaa','mich_elle_94@hotmail.com','baydaa al-kendy','riskestien 21b','kristiansand','Hånes','NORWAY','4635',' 004747896849','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 12:21:33',0,NULL,3,1,21,1,'RA184538987CN\r ','HSPH007 \r欧标'),(21051,676415661013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','zhura1968','zhuraos@gmail.com','Олег Журавлёв','пер.Суворовцев,дом 2, кв 12','Петродворец','Санкт-Петербург','RUSSIAN FEDERATION','198510','(812)4206694','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 12:43:03',0,NULL,3,1,11,1,'BJ01669564\r ','WLAP008 '),(21052,837274511011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','marenas55-shop','mcmariomc@gmail.com','Marius Narmontas','38 Hazelbrook Crescent<br>Long Lane','Letterkenny','Donegal','IRELAND','1','0861291513','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 13:28:17',0,NULL,3,1,21,1,'RA184538505CN\r ',' TRSN001'),(21053,621920493004,140626375349,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',13.8,'cnfaner','merbanan1','banan@ludd.ltu.se','Benjamin Larsson','Kanngjutargränd 30','Vällingby','','SWEDEN','16257','0705127579','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 13:39:24',0,NULL,3,1,21,1,'RA184538960CN\r ','OTHP005 '),(21054,927220620012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',1,'CASS001',6.29,'eastar4uk','mgorczyca1976','gogers13@yahoo.com','Marek Gorczyca','50 The Ridings','Kidlington','Oxfordshire','UNITED KINGDOM','OX5 1UA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 14:08:49',0,NULL,3,1,3,1,'RA184538369CN\r ',' CASS001'),(21055,837304430011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','summias647','summias@hotmail.com','Muzammil Amir','1338 York Mills Rd # 604','North York','ON','CANADA','M3A 3M3','(416) 819-5055','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 14:58:45',0,NULL,3,1,3,1,'RA184538409CN\r ','HSSE011 '),(21056,676465536013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','salisthompson2011','salisthompson@gmail.com','Salis Henrique Thompson Vieira','Belmont Moranga 25<br>Campo Grande','Rio de Janeiro','Rio de Janeiro','BRAZIL','23059-150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 15:50:19',0,NULL,3,1,11,1,'BJ01669555\r ','CACN004 '),(21057,676468592013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','tradingkleo.inc','kleoeua@hotmail.com','Cleone Viecsinski','Benjamim Pereira, 265<br>Jaçãna','São Paulo','SP','BRAZIL','02274000','+55 11 22470754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 15:59:00',0,NULL,3,1,3,1,'RA184548750CN\r ','GPS0006 '),(21058,676471906013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','tennislawdog','tmcc7@aol.com','Terri McClung','3815 Farrington Cir','Birmingham','AL','UNITED STATES','35223-1548','(205) 602-5397','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 16:11:47',0,NULL,3,1,1,1,'LK189308795CN',' 二代卡 旧 '),(21059,837345366011,320826634655,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','aayron.m','aayron.matova@chilwell.org','Chris Archer','118 Cator Lane<br>Beeston','Nottingham','Nottinghamshire','UNITED KINGDOM','NG9 4BB','01158714930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 16:32:26',0,NULL,3,1,3,1,'RA184538457CN\r ',' HBPH001'),(21060,927282471012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','changingtide6157','lvinicombe@verizon.net','Mark Vinicombe','12 Lopatcong Dr','Ewing','NJ','UNITED STATES','08638-1310','(732) 353-4300 ext.: 4324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 16:40:25',0,NULL,3,1,1,1,'LK190216270CN\r ',NULL),(21061,676475117013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','ermolin19870402','erma18@tut.by','Slawa Ermolin','Pedchenko 12/86','Gomel','gomel','BELARUS','246000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 17:22:57',0,NULL,3,1,22,1,'BJ01669535\r ','HSNO016+CCNO001 '),(21062,927300836012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',3,'GLOT001',134.67,'eastar4','tilzenberger','jlo65644@bigpond.net.au','Mark Tilley','65 Blaxland Ave Two Rocks','Perth','Western Australia','AUSTRALIA','6037','0895615973','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 17:13:20',0,NULL,3,1,3,1,'RA184539007CN\r ','GLOT001 '),(21063,791517798001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'buysia','joemiri2010','joemiri@att.net','joe harris','1200 saffold st.','Greenwood','MS','UNITED STATES','38930','(662) 451-1300','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-02 17:53:50',0,NULL,3,1,1,1,'LK188995925CN\r ',NULL),(21064,837388901011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',1,'CASS003',10.99,'eastar4','kshchekuteev','kirji@mail.ru','Kirill Shchekuteev','Teply stan street 15/3 - 18','Moscow','','RUSSIAN FEDERATION','117465','89163535626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 18:00:40',0,NULL,3,1,11,1,'BJ01669554\r ','CASS003 '),(21065,837399662011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','li_mara','bishol1@madasafish.com','Limara N Bishop','Buena Vista, Catcott road, Burtle','Near Bridgwater','Somerset','UNITED KINGDOM','TA7 8NG','01278722235','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 18:21:08',0,NULL,3,1,3,1,'RA184548715CN\r ',' GLOT001*2'),(21066,927341565012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','jzal9871','josu.zaldibar@euskalnet.net','Josu Zaldibar Pagazaurtundua','Zubieta Etorbidea, 1<br>EzpelaDenda','Orozko','País Vasco','SPAIN','48410','656410077','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 18:21:47',0,NULL,3,1,22,1,' ',' WLAT009'),(21067,616680029003,130458644510,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',2,'HSNO019',75.36,'cnfaner','wanjalichtenwald','w.lichtenwald@web.de','Johannes Lichtenwald','wallauer Weg 4','Siegen','','GERMANY','57072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 18:25:20',0,NULL,3,1,21,1,'BJ01669391\r ','HSNO019 \r欧标'),(21068,927350022012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','oursfan13','oursfan48174@yahoo.com','Carly Lane','611 S Roessler St','Monroe','MI','UNITED STATES','48161-1694','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 18:36:29',0,NULL,3,1,1,1,NULL,NULL),(21069,837436013011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','mexicanjihad','mexicanjihad55@yahoo.com','Eric Lopez','6641 S Otis Way','Littleton','CO','UNITED STATES','80123-3661','(720) 771-3919','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-02 19:20:50',0,NULL,3,1,1,1,NULL,NULL),(21070,837433657011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',2,'HSUE002',39.98,'eastar4','mrmanny228','maeno100@aol.com','Emanuel Sanchez','240 E 82nd St<br>Doorman','New York','NY','UNITED STATES','10028-2703','(917) 584-5375','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 19:29:48',0,NULL,3,1,1,1,'LK188942401CN\r ',NULL),(21071,616712493003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','ishi93','colyer@gmail.com','Daniel Colyer','1806-7371 Westminster Hwy.<br>buzz#6113','Richmond','BC','CANADA','V6X0B4','(604) 277-3112','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 19:45:45',0,NULL,3,1,3,1,'RA184538315CN\r ','MOLO006 '),(21072,837455803011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','marteng_de','marteng@gmx.net','Martin Grugel','Auf der Hohl 11','Wettenberg','','GERMANY','35435','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 19:54:44',0,NULL,3,1,2,1,'30120029004\r ',NULL),(21073,927403384012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','joesayegh','joesayegh@gmail.com','Joe Sayegh','Flat 2<br>20 Weech Road','Hampstead','London','UNITED KINGDOM','NW6 1DL','02074331237','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 19:57:32',0,NULL,3,1,3,1,'RA184538443CN\r ',' WLHP002'),(21074,837473412011,320730086228,'NEW CAB-2660-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 1T',1,'CASS002',6.29,'eastar4uk','johnkirwan353','patrick.kirwan@gmail.com','Patrick Kirwan','Deerpark','Baltinglass','Wicklow','IRELAND','default','0863532518','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 20:21:16',0,NULL,3,1,21,1,'RA184538386CN\r ',' CASS002'),(21075,676600250013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','bue92684041','morten.bue@leirabil.no','Morten Bue','Skaugdalen','Rissa','Rissa','NORWAY','7100','45667059','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 21:32:43',0,NULL,3,1,4,1,'YW868896994CN\r ','GLOT001*4 '),(21076,927466252012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','pl0nker','paul.kench@uk.fujitsu.com','Paul Kench','94 Squirrels Heath Lane','Hornchurch','Essex','UNITED KINGDOM','RM112DZ','07736599821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 21:37:09',0,NULL,3,1,3,1,'RA184538430CN\r ','WLAT009 '),(21077,791639112001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','pigsanus','waynerickett@optusnet.com.au','Wayne Rickett','P O Box 1542','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-02 21:38:47',0,NULL,3,1,11,1,'BJ01669556\r ','BALO007 '),(21078,622114711004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','juiced1228','fivedollerfootlong@gmail.com','Colin Gill','Wichita Technology Services c/o Colin Gill<br>328 E First','Wichita','KS','UNITED STATES','67202','(316) 305-3484','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 00:00:44',0,NULL,3,1,1,1,NULL,NULL),(21079,927537976012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','jbugsvw','jbugsvw@aol.com','Johnny Harvey','25485 Alpine Ct','Murrieta','CA','UNITED STATES','92563','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 00:21:07',0,NULL,3,1,1,1,'LK189803508CN\r ',NULL),(21080,837594795011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','ledson2010','led_zepp2008@hotmail.com','Ledson Ribeiro','Parque Esplanada 1<br>Rua B Quadra N Lote 7 Casa 2','Valparaíso De Goiás','Goiás','BRAZIL','72878630','61-4102-6447','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 00:52:09',0,NULL,3,1,11,1,'BJ01669537\r ','UDAP001 '),(21081,782846309007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',2,'RELO002',27.98,'au-buy','southbrisgal','kimbalion33@hotmail.com','Sandra Collins','1021 Rochedae Road','Rochedale South','Queensland','AUSTRALIA','4123','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 01:54:55',0,NULL,3,1,11,1,'BJ01669557\r ',' RELO002'),(21082,8881328234319463,111,'Pirates of the Caribbean 4 On Stranger Tides Blue Ray 3D',1,'',17,'buysia','rtrillo52','rtrillom@prodigy.net.mx','Ricardo trillo','aldama 33-A','penjamo','Guanajuato','MEXICO','36900','014696920050',NULL,NULL,NULL,'2012-02-03 01:58:39',0,NULL,5,1,18,0,NULL,'已退款'),(21083,8881328235919447,111,'Original Logitech Harmony 890 LCD Remote Control US - RCLO003',1,'RCLO003',135.99,'aliexpress','1006525450 ','sanochkin_ka@mail.ru','Artem Sanochkin	','Sidorenko street 5-26','Komsomolsk-on-Amur	','Khabarovskiy kray	','RUSSIAN FEDERATION	','681021','+7 4217 531486',NULL,NULL,NULL,'2012-02-03 02:25:19',0,NULL,5,0,18,0,NULL,'由于成色问题，客户cancel了订单 '),(21084,8881328236119262,111,'New Grohe handheld Shower Head big water output w/Massage function + Grohe hose - OTGR005+OTGR002',1,'OTGR005+OTGR002',39.99,'aliexpress','1006539923 ','alexis1980@gmail.com','Aleksey Poptsov	','Kirova, 9 - 234','Yoshkar-Ola	','RU','RUSSIAN FEDERATION	','424038','+7 902 6718254',NULL,NULL,NULL,'2012-02-03 02:28:39',0,NULL,3,1,3,1,'RA184534945CN ','OTGR005+OTGR002 *1 '),(21085,837624991011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','amice234','nevhen@aol.com','Edward Neville','102 Church Road, Hanwell','London','London','UNITED KINGDOM','W73BE','07815863645','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 02:32:47',0,NULL,3,1,3,1,'RA184538426CN\r ',' MOAP001'),(21086,8881328236600456,111,'Free shipping & Tracking # - New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella - UM00053',1,'UM00053',19.99,'aliexpress','1006542921','bula-pt-101@yandex.ru','Alexsey Saburov	','Samarskaya oblast, Russian Federation','Tol iatti','Samarskaya oblast	','RUSSIAN FEDERATION	','445030','+7 917 8214145',NULL,NULL,NULL,'2012-02-03 02:36:22',0,NULL,3,1,3,1,'RA184534923CN ','UM00053 *1 '),(21087,927587462012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',2,'BTHP2007',19.76,'eastar4','maskedlizard','harrygish@gmail.com','Harry Gish','5700 Country Valley Ln','Fort Worth','TX','UNITED STATES','76179-7361','(214) 293-0061','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 02:43:11',0,NULL,3,1,1,1,'LK189691545CN\r ','HP 8pin 1.0 23cm  '),(21088,676688770013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','nikkvassoff','kvassoff@gmail.com','Nikolay Kvasov','R. Zorge st., 5A, apt.18','Tver','Tverskaya oblast','RUSSIAN FEDERATION','170023',' 79108534449','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 02:57:21',0,NULL,3,1,11,1,'BJ01669559\r ','WLIN014 '),(21089,676689679013,230393146954,'2.1 Acer Aspire 8920 8920G 8930 Bluetooth Module+cable',1,'BTAC2121',12.39,'eastar4','paulc56','cotlar@videotron.ca','Paul Côté','2624 Laure','Jonquière','QC','CANADA','g7s1e6','(418) 548-4051','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 03:03:00',0,NULL,3,1,2,1,'30120037706\r ','acer 8pin1.00 6cm  线序不同 '),(21090,622020001004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','wison1966','rodriguez_luis_e@yahoo.com','Luis Rodriguez','101 Vista Del Valle','Manati','PR','UNITED STATES','00674','(787) 603-6803','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 03:06:17',0,NULL,3,1,1,1,'LK182687396CN\r ',NULL),(21091,622145023004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','archie7195','archievelyn1@msn.com','Archie Featherston','11459 E 37th St','Yuma','AZ','UNITED STATES','85367-5676','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 03:33:29',0,NULL,3,1,1,1,'LK190744532CN\r ',NULL),(21092,622162790004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','dabowen46','doug.bowen1@gmail.com','Doug Bowen','411 Tufnell Road<br>Banyo','Brisbane','Queensland','AUSTRALIA','4014','0732678580','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 03:45:18',0,NULL,3,1,3,1,'RA184538412CN\r ','RELO003 '),(21093,837653088011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','fourjsb','jpwotg@aol.com','Jeffry Waxman','114 W Mission St<br>C/O Delmonte Management Co','Santa Barbara','CA','UNITED STATES','93101-2819','(805) 452-8581','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 04:19:43',0,NULL,3,1,1,1,'LK187849745CN\r ',' 银色的'),(21094,782886909007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','dinkum1878','dinkum.results@iinet.net.au','Colma Keating','PO Box 3005','SHELLEY','Western Australia','AUSTRALIA','6148','0893549734','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 04:25:07',0,NULL,3,1,11,1,'BJ01669521\r ',' BALO007'),(21095,927631559012,220828314408,'GPS USB receiver w/SIRF3 chip sets +antenna',1,'GPS0001',45.99,'eastar4','r.piontik','balabollng@mail.ru','Roman Piontik','Krasnogorodskaya<br>Dom 19 korp. 1 kv. 235','St. Petersburg','','RUSSIAN FEDERATION','198320','8-906-262-03-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 05:17:27',0,NULL,3,1,3,1,'RA184538995CN\r ','GPS0001 '),(21096,927642615012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','nathan-s14','not_available_id@hotmail.com','Nathan Pettinger','5605 SW Windflower Dr','Corvallis','OR','UNITED STATES','97333-1373','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 06:14:06',0,NULL,3,1,1,1,'LK187894642CN',NULL),(21097,927644414012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',27.78,'eastar4','mghussein','zain.md@live.com','mohamed ginawi hussein','14333 Preston Rd<br>Apt 2001','dallas','TX','UNITED STATES','75254-6503','(832) 314-5541','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 06:20:40',0,NULL,3,1,1,1,'LK184544727CN\r ',NULL),(21098,676734425013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','nik729','nik729@hotmail.com','Nik Rawley','300 W 8th St<br>Unit 422','Vancouver','WA','UNITED STATES','98660-3440','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 07:17:55',0,NULL,3,1,1,1,'LK185716176CN\r ',NULL),(21099,676730815013,230724607810,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'eastar4','dominiquejooste','dominique.jooste@my.jcu.edu.au','Dominique Jooste','3 Lemonwood Court','Townsville','Queensland','AUSTRALIA','4740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 06:52:45',0,NULL,3,1,11,1,'BJ01712797\r ','UM00053 \r全透明伞'),(21100,927655896012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','androter','spelnik@yandex.ru','Andrey Terekhin','Radishcheva st. h.6 ft.21','Biysk','Altay region','RUSSIAN FEDERATION','659322','+79132221888','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 07:18:51',0,NULL,3,1,11,1,'BJ01669561\r ',' WLIN013'),(21102,782938443007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','mutated1987','tyson.elder87@gmail.com','Robyn Turner','21 Sutherland Avenue','Dianella','Western Australia','AUSTRALIA','6059','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 08:49:30',0,NULL,3,1,11,1,'BJ01669562\r ','RELO002 '),(21103,676755807013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',10,'OT00004',78,'eastar4','mnx4mnx','me@mnx.su','Anton Semenov','Urieva Street, 8/7 - 12','Cheboksary','Chuvashia','RUSSIAN FEDERATION','428009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 09:30:18',0,NULL,3,1,3,1,'RA184538721CN\r ','OT00004 '),(21104,782967272007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',49.39,'au-buy','amanda5276','amanda@dreamy.com.au','Amanda Penna','11D Minerva Street','Rochedale South','Queensland','AUSTRALIA','4123','0734232884','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 10:39:47',0,NULL,3,1,3,1,' RA184532370CN\r',' LGFI001'),(21105,927716180012,220922497144,'New in box ZALMAN FG1000 FPS GUN Ergonomic Style Gaming USB Mouse  FG 1000',1,'MOZA001',24.99,'eastar4uk','jgra8938','john.gramley@gmail.com','John Gramley','2730 Fieldbrook Way','Escondido','CA','UNITED STATES','92027','(760) 715-4327','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 11:02:57',0,NULL,3,1,1,1,' LK192370930CN\r',NULL),(21106,782974361007,170750956694,'New Innovated Heart shape Fashion Rose Sun/Rain Umbrella  heart-shaped',1,'UM00047',23.74,'au-buy','bekah.123','becann@hotmail.com','Rebekah Ten-Bohmer','17 Brosnan Cresent','Parkhurst','Queensland','AUSTRALIA','4702','0401563878','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 11:05:17',0,NULL,3,1,11,1,NULL,'UM00047 '),(21107,927705914012,220826635770,'New HP Wireless Comfort Mobile wireless mouse 2.4G',1,'MOHP001',11.99,'eastar4uk','gedcorp','david@milnersrepetition.com.au','Milners Repetition','3 - 5 Tharle Street','Dandenong','Victoria','AUSTRALIA','3175','0397949629','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 11:12:53',0,NULL,3,1,11,1,NULL,' MOHP001\r'),(21108,927745917012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','bigmike-uk','mike_anderson@dsl.pipex.com','Mike Anderson','1 Thames Close','Ferndown','Dorset','UNITED KINGDOM','BH22 8XA','01202895639','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 12:34:30',0,NULL,3,1,3,1,' RA184532454CN\r',' OTCN004*10'),(21109,836125501011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRTT002',9.99,'eastar4','bowmanjeremy','jdbowman@live.com','Jeremy Bowman','1226 Commercial Ct','Harrisonburg','VA','UNITED STATES','22802-4675','(205) 577-9359','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 12:37:09',0,NULL,3,1,1,1,' LK193274515CN\r',NULL),(21110,837786189011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',21.99,'eastar4uk','spyone22','spyone@gmail.com','Spyros Koulouridakis','Albert 23','Chania','Crete','GREECE','73100','00306944574736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 12:56:31',0,NULL,3,1,22,1,NULL,' HSIT002欧标\r '),(21111,676798863013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','rh_fragmaster','st.privat@gmx.de','Stephan Schott','Birkenweg 25','Bad Schwartau','','GERMANY','23611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 12:57:05',0,NULL,3,1,22,1,'BJ01669395\r ','欧标 \rHSNO019'),(21112,676801627013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','domezone69','domez69@hotmail.com','Koulmandas George','Kithiron 9 Xaidari','Athens','Greece','GREECE','12461','00306944373656','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 13:08:36',0,NULL,3,1,21,1,'RA184532587CN\r ','GLOT001*2 '),(21113,616938529003,130596581579,'New genuine LG 3D Active Shutter Glasses AG-S110',1,'LGGL002',62.99,'cnfaner','racdital','oscarmachiperez@hotmail.com','Oscar Machi Perez','Residencial Aljarasol Numero 93<br>Mairena del Aljarafe','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41927','669210353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 13:13:10',0,NULL,3,1,21,1,' RA184532689CN\r','LGGL002 '),(21114,834884275011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','thedbguy','spracy@hotmail.com','Steven Pracy','2 Causton Way','Rayleigh','Essex','UNITED KINGDOM','SS6 8DD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 13:20:41',0,NULL,3,1,3,1,' RA184532445CN\r',' RCLO007+POLO001+RCLO008*4\r英标'),(21115,837823556011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','wideload42','wideload42@hotmail.co.uk','Keith Perry','29 Moths Grace','Basingstoke','Hampshire','UNITED KINGDOM','RG24 9FY','01256844276','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 14:41:03',0,NULL,3,1,3,1,' RA184532423CN\r','GLOT001*4 '),(21116,927797867012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','agramatos','andreasthebutcher@gmail.com','Andreas Constantinou','Faistou 7<br>Flat 303','Limassol','Limassol','CYPRUS','3011','357 99 810657','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 14:51:42',0,NULL,3,1,21,1,' RA184532560CN\r','GLOT001*2 '),(21117,927817527012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','haupt-achtung','black_cat1@hotbox.ru','Mereuta Evghenia','Stroescu<br>11/3','Chişinău','moldova/Kishinev','MOLDOVA, REPUBLIC OF','md2051','+37379659583','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 15:34:49',0,NULL,3,1,22,1,NULL,'UM00006 '),(21118,616977677003,130626402578,'4 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*4',174.99,'cnfaner','mustangelbay','ouyedm@yahoo.com','Mustapha ouyed','6153 ave Gérard-Morisset','Montreal','QC','CANADA','H1M 3J8','(514) 259-9592','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 15:49:35',0,NULL,3,1,3,1,' RA184532542CN\r',' '),(21119,622300427004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',18.59,'cnfaner','marcellorio','marcello@marcello.odo.br','Marcello Antunes','Av Ataulfo de Paiva, 135 - 814','Rio de Janeiro','Rio de Janeiro','BRAZIL','22440-030','21-2511-4723','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 15:52:21',0,NULL,3,1,3,1,' RA184532715CN\r','HSAL002 \r美标'),(21120,927831767012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','chrissybing','sales@rocketrhubarb.co.uk','Chris Crosby','18 Mistletoe Drive','Walsall','West Midlands','UNITED KINGDOM','WS5 4SW','07900670925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 16:05:14',0,NULL,3,1,3,1,' RA184532406CN\r',' GLOT001'),(21121,927839624012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',4,'OTCN004*10',41.56,'eastar4uk','3354dave','dave.pemberton@ecmsys.co.uk','Dave Pemberton','ECM Systems Ltd,<br>Ellifoot Park, Burstwick','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU12 9DZ','01964672000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 16:20:54',0,NULL,3,1,3,1,' RA184532335CN\r','OTCN004*10 '),(21122,927526879012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',12.49,'eastar4uk','oddsyd','oddsyd@yahoo.gr','Alexandros Savidis','Peloponisou, 50<br>50','Argiroupoli','Athens','GREECE','16451','2109950833','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 16:58:00',0,NULL,3,1,22,1,NULL,' OTHP003\r'),(21123,927862170012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','kojaci','massa.ad@orange.fr','Adrien MASSARONI','18 rue du martin pêcheur<br>La grive','bourgoin jallieu','Rhône-Alpes','FRANCE','38300','06.34.12.57.62','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 17:08:00',0,NULL,3,1,3,1,' RA184532437CN\r',' GLOT001'),(21124,676873373013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','atomohod','atomshiki@gmail.com','Andrey Sokolov','Privolnaya st. h61/1 ap.101','Moskow','','RUSSIAN FEDERATION','109431','8-926-121-6767','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 17:09:34',0,NULL,3,1,3,1,' RA184532468CN\r','GLOT001*2 '),(21125,837903958011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',1,'UM00021',26.99,'eastar4','itchybum101','sissanchon@hotmail.com','Steve','34 Cornelia Rd','Toongabbie','New South Wales','AUSTRALIA','2146','0424166454','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 17:40:30',0,NULL,5,0,18,1,NULL,'UM00021\r红色的 \r没有红色的 客户要求退款  \r已经退款了'),(21126,927926754012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','jtyler210','jcutshall@satx.rr.com','Jon Cutshall','7207 W Beverly Mae Dr','San Antonio','TX','UNITED STATES','78229','(210) 614-9427','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 19:01:50',0,NULL,3,1,1,1,' LK193055713CN\r',NULL),(21127,927945947012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',4,'GLOT001*2',211.96,'eastar4uk','solsken2008','sthakrar@tele2.se','Sandip Thakrar','Lokegatan 5','Märsta','','SWEDEN','19558','0739-443841','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 19:32:11',0,NULL,3,0,4,1,'YW868897952CN ','最好控制在2000g以内 '),(21128,927943281012,220901458172,'New SAMSUNG Magic Water Filter WSF-100 for Samsung Refrigerator',1,'SAFI002',33.99,'eastar4uk','athanasios_v','sakis_votsis@yahoo.gr','Athanasios Votsis','Palaiochora','Palaiochora','Chania','GREECE','73001','+306973048133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 19:36:03',0,NULL,3,1,21,1,' RA184532661CN\r',' SAFI002'),(21129,927400258012,220903895938,'4 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*4',149.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 19:36:51',0,NULL,3,1,4,1,'YW868897941CN ',' LGGL002*4\r申报为gift 申报小于20$\r\r还买了GLOT001*4\r4 pairs 3D Active shutter Glasses 4 Panasonic TC-P50ST30\r\r'),(21130,837970975011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','theepan444','ruban444@yahoo.com','ruban','86 brighton road<br>west sussex','worthing','West Sussex','UNITED KINGDOM','bn11 2en','07424133398','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 19:42:39',0,NULL,3,1,3,1,' RA184532321CN\r',' RELO003'),(21131,676953345013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',39.96,'eastar4','lsmldnd11','lsmldnd@hotmail.com','Luis Maldonado','385 Mattie Byrd Ln','Clinton','NC','UNITED STATES','28328-0882','(910) 379-4857','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 20:34:52',0,NULL,3,1,1,1,' LK192785509CN\r','二代卡 旧 '),(21132,837611254011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','02harley-hiles','hiles_rocker67@hotmail.com','Daniel Hiles','908 Edgehill Ln','Anderson','IN','UNITED STATES','46012-9709','(765) 618-3801','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 20:47:09',0,NULL,3,1,1,1,' LK191164622CN\r',NULL),(21133,837998574011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','heitors2talitapmms','diegoricardy@hotmail.com','Munir Sami Campitelli Ibrahim','Rua Bataiporã, n.º 1661 - Bairro Centro - Residência','Nova Andradina','Mato Grosso do Sul','BRAZIL','79750000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 21:01:59',0,NULL,3,1,3,1,' RA184532499CN\r','LGRM001 '),(21134,838014444011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','dodgyinternetcharacter','thomasgemmill@gmail.com','Tom Gemmill','Glasslin, Fermieflatt Farm<br>Kinneff','MONTROSE','Angus','UNITED KINGDOM','DD10 0TQ','01569750242','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 21:04:47',0,NULL,3,1,3,1,' RA184532264CN\r',' OTHP005\r'),(21135,622418469004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','lucaubert31','luc.aubert.31@gmail.com','luc aubert','12 chemin des clotasses<br>Appartement B9','Toulouse','Midi-Pyrénées','FRANCE','31400','0608104269','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 21:38:56',0,NULL,3,1,3,1,'RA184529115CN\r ','OTSO002 '),(21136,617096507003,130626402767,'New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001',43.89,'cnfaner','rugbynames','pgs@gmx.co.uk','paul smith','2 The Brooks,, Moss Lane,','Sale','Cheshire','UNITED KINGDOM','M335AR','01619730865','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 21:36:26',0,NULL,3,1,3,1,' RA184532701CN\r','GLOT001 '),(21137,617121088003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','drizzage','booge@tampabay.rr.com','Scott Bourgeois','14300 Imlay City Rd','Mussey','MI','UNITED STATES','48014-2603','(727) 251-1704','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 23:03:17',0,NULL,3,1,1,1,' LK191549526CN\r',NULL),(21138,617136298003,130626363900,'Brand New Logitech Unifying Receiver for M505 M705 M905 etc mouse- 100% official',1,'RELO002',12.95,'cnfaner','terminator911','cmedrano78@hotmail.com','Cesar Medrano','2712 NW 38th St','Oklahoma City','OK','UNITED STATES','73112-7457','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-04 00:10:11',0,NULL,3,1,1,1,' LK193169389CN\r',NULL),(21139,775094452008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',2,'MOMI002',26.2,'au-buy','ridaparkida','ridapark@internode.on.net','Ida Zimbardi','7 Rida Park Drive','Kilmore','Victoria','AUSTRALIA','3764','0357822087','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 00:46:29',0,NULL,3,1,11,1,NULL,'MOMI002 '),(21140,622466764004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',25.99,'cnfaner','1941schwalm','fls@hal-pc.org','frank schwalm','15318 E Willowwind Cir','Houston','TX','UNITED STATES','77071','(713) 298-7088','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-04 00:53:57',0,NULL,3,1,1,1,' LK192806725CN\r',NULL),(21141,677036153013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','ilni','aficio3@gmail.com','Ilya Nikitin','27/13, Ul. Zemlyanoj Val','Moscow','','RUSSIAN FEDERATION','105064','(926) 738-7027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 01:37:12',0,NULL,3,1,11,1,NULL,'WLIN014 '),(21142,783320536007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','bn.man','beamerm3@telus.net','bob naletilich','435 klarvatten lake wynd','edmonton','AB','CANADA','t5z3b9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-04 01:50:43',0,NULL,3,1,11,1,NULL,'RCLO007+POLO001+RCLO008*4 '),(21143,677069971013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','espinal2981','canela2981@hotmail.com','gisselle canela','626 Riverside Dr<br>Apt 16J','new york','NY','UNITED STATES','10031-7223','(347) 283-5632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 04:01:06',0,NULL,3,1,1,1,' LK192625285CN\r',NULL),(21144,617181879003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','meomeo88catherine','caty_vo@hotmail.com','Catherine  Vo','11 Deodar st','Inala','Queensland','AUSTRALIA','4077','0733300030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 04:17:01',0,NULL,3,1,3,1,' RA184532794CN\r','HBPH001 '),(21145,838161922011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',8.54,'eastar4uk','maxitoine','antoine.jarry@laposte.net','Antoine Jarry','21 rue du ruisseau','Ste Luce sur Loire','Pays de la Loire','FRANCE','44980','0630301451','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 04:29:55',0,NULL,3,1,11,1,NULL,' OTHP005\r'),(21146,928167508012,220682003790,'2.1 Acer As 6530G Extensa 5235 Bluetooth Module+cable',1,'BTAC2113',12.39,'eastar4','phil7793','prthomas35@hotmail.co.uk','phil thomas','80 moor drive<br>birleywood','skelmersdale','Lancashire','UNITED KINGDOM','wn8 9by','07533306351','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 04:54:45',0,NULL,3,1,2,1,NULL,'BTAC2113 \racer 5pin1.25 6cm   '),(21147,838172590011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','allstarlegends','msarich@hotmail.com','michael sarich','2290 Cochrane Rd<br># B','Morgan Hill','CA','UNITED STATES','95037-9306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 05:20:38',0,NULL,3,1,1,1,' LK190880609CN\r',NULL),(21148,838174409011,320519467222,'100% NEW CAB-6060 Back to Back DTE DCE WIC-1T Cable',2,'CASS003',21.98,'eastar4','valkyriee','nick@nickandnatalie.com','Nicholas Marshall (Downer)','Triniti 1<br>39 Delhi Road','North Ryde','New South Wales','AUSTRALIA','2113','0428496316','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 05:31:58',0,NULL,3,1,11,1,NULL,'CASS003 '),(21149,928166467012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','John Mackenzie','1 W HIGH POINT RD','STUART','FL','UNITED STATES','34996-7019','(503) 309-6418','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 06:44:43',0,NULL,3,1,1,1,'LK195752601CN\r ',NULL),(21150,928189930012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Ravellette Publications, Inc.','PO Box 788<br>105 S. Wood Ave','Philip','SD','UNITED STATES','57567-0788','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 06:50:28',0,NULL,3,1,1,1,'LK196849329CN\r ',NULL),(21151,928197212012,220903895838,'2 pairs of New genuine LG 3D Active Shutter Glasses AG-S110 S110 adult size',1,'LGGL002*2',76.99,'eastar4uk','dimka200sx','megazlo2@gmail.com','Dmitry Sokolov','Petrozavodskaya 11-1-88','Moscow','','RUSSIAN FEDERATION','125502','(915) 483-8229','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 07:25:29',0,NULL,3,1,3,1,' RA184532508CN\r',' LGGL002*2'),(21152,676787002013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','sunny417','aerosanya@yandex.ru','Aleksandr Vitvitsky','ulitsa Baikalskaya, dom 159 kvartira 15<br>Russian Federation','Irkutsk','Irkutskaya Oblast','RUSSIAN FEDERATION','664031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 07:31:14',0,NULL,3,1,11,1,NULL,'WLAT010 '),(21153,792260577001,110819086654,'Logitech MX1000 Mouse special Bluetooth Version MX1000',2,'MOLO005',119.6,'buysia','roberthx2010','roberthx@optusnet.com.au','Robert Moyses','23 Pennell Ave','St Albans','Victoria','AUSTRALIA','3021','0393569690','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-04 07:44:38',0,NULL,3,1,3,1,'RA184529225CN\r ','MOLO005 '),(21154,836482604002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','2010comox','jrlinks@mac.com','James Reid','1091 Broughton St.<br>Apt. 32','Vancouver','BC','CANADA','V6G 2A9','(604) 662-8849','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-04 07:46:07',0,NULL,3,1,3,1,'RA184519237CN\r ','MOLO001 '),(21155,617211123003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001',43.89,'cnfaner','blitzanni','habibullah1@hotmail.de','Annika Kurt','Albert Schweitzer str 5','Norderstedt','','GERMANY','22844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:01:29',0,NULL,3,1,21,1,' RA184532692CN\r','GLOT001 '),(21156,928209436012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','cormo11','eric-b11@live.fr','Eric Boudeau','18 rue Maurice Dagniac','PORT LA NOUVELLE','Languedoc-Roussillon','FRANCE','11210','0619104889','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:18:04',0,NULL,3,1,2,1,NULL,'acer 5pin1.25 15cm  '),(21157,677109482013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','akatone1','lyngrantham@bigpond.com','lyn grantham','58 blyth street , clearview','adelaide','South Australia','AUSTRALIA','5085','0882605926','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:33:22',0,NULL,3,1,4,1,'YW868897963CN ','GLOT001*4 '),(21158,838214422011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT001*2',88.99,'eastar4','alpalog','info@alpalogistics.gr','Alexandros Pagoulatos','53, Ortansias street<br>Aharnai','Attica','Attica','GREECE','136 77','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:54:12',0,NULL,3,1,21,1,' RA184532658CN\r','GLOT001*2 '),(21159,928190743012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Natalie Martinez','749 Gresham Ave SE','Atlanta','GA','UNITED STATES','30316-3838','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 09:12:08',0,NULL,3,1,1,1,'LK197709274CN\r\r ',NULL),(21160,928225179012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Carol Hoyt','PO Box 4759','Dowling Park','FL','UNITED STATES','32064-1508','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 09:15:14',0,NULL,3,1,1,1,'LK194546603CN\r ',NULL),(21161,838244153011,320827754575,'New 4 Parking Sensor Car Reverse backup Radar kit w/ buzzer 10 colors available',1,'PS00002',14.99,'eastar4uk','micallef117','xib117@yahoo.co.uk','Charmaine Sciberras','Flat 1 Zantedeschia<br>Triq il- Qanpiena','Swatar','Malta','MALTA','BKR 13','0035621491441','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 10:39:08',0,NULL,3,1,22,1,NULL,' PS00002\rChampagne  香槟色'),(21162,928259040012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Joe Clark','7111 TYLER ST','HOLLYWOOD','FL','UNITED STATES','33024-7353','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 10:58:08',0,NULL,3,1,1,1,'LK195473403CN\r ',NULL),(21163,677137740013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','com253','wingoodwayne@hotmail.com','wayne goodwin','9 casserley ave','girrawheen','Western Australia','AUSTRALIA','6064','0892473090','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 10:58:12',0,NULL,3,1,3,1,' RA184532627CN\r','GPS0006 '),(21164,838255151011,320617832827,'New GENUINE NOKIA BH-500 BLUETOOTH HEADSET BH 500',1,'HSNO015',35.99,'eastar4','romanovigor63','igor@rcmag54.ru','IGOR ROMANOV','AVIASTROITELEI 33 23','NOVOSIBIRSK','NSK','RUSSIAN FEDERATION','630084','+79139136404','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 11:05:57',0,NULL,5,1,18,1,NULL,'欧标\rHSNO015 \r由于无货了  客户不回复   我给她退款了'),(21165,928263544012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',20.78,'eastar4uk','takara92','takara@klinos.com','Nicolas BARBIER','14 route de Champagne','Ecully','Rhône-Alpes','FRANCE','69130','0673736997','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 11:08:02',0,NULL,3,1,11,1,NULL,' OTCN004*10'),(21166,838284302011,320820766323,'New Altec Lansing Backbeat Plus UHP206 Earphones Compatible w/iPhone ipod mp3mp4',1,'HSAL002',10.99,'eastar4uk','khevz0rd','khevinm@gmail.com','Khevin Iam Pettri Mituti','Avenida Shigeo Mori, 349','Campinas','São Paulo','BRAZIL','13083-760','1171816091','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 12:30:31',0,NULL,3,1,11,1,NULL,' HSAL002'),(21167,928292032012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','powerfuloz!','jeff@themeadowsclub.com','Jeffery A Zielinski','16125 Chablis Lane','Plainfield','IL','UNITED STATES','60586','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 12:41:29',0,NULL,3,1,1,1,' LK191513606CN\r',NULL),(21168,928300612012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',67.4,'eastar4uk','otokill','otokill@hotmail.fr','steve sese','174 avenue de la Lanterne<br>Le Jacamar B2','nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','0664195731','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 12:50:16',0,NULL,3,1,3,1,' RA184532383CN\r',' GLOT005'),(21169,622609776004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','povestka','c_a_t@bk.ru','Andrey Khokhlov','16 Pyatnitskoye shosse, Appartment 166','Moskow','Moskowskaya oblast','RUSSIAN FEDERATION','125464','+7(963)692-5522','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 13:56:51',0,NULL,3,1,3,1,'RA184538942CN\r ','OTGR001+OTGR002 '),(21170,622555501004,140667903949,'New Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card Over AR5008',1,'WLAT010',12.9,'cnfaner','i.dle','ianjdoyle@gmail.com','Ian Doyle','Jalan Kulintang no.16','Mataram','NTB Province','INDONESIA','83126','082147914858','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 14:04:47',0,NULL,3,1,3,1,' RA184532595CN\r','WLAT010 '),(21171,928333734012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','s0u1mate','vveresko@ngs.ru','Vyacheslav Vereskovsky','Dachnaya 32-31','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630082','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 14:06:07',0,NULL,3,1,11,1,NULL,'TRMX003 \rAUI Transceiver  MX20T'),(21172,928345399012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','anthony sandner','72 N CENTRAL ST','EAST BRIDGEWATER','MA','UNITED STATES','02333-1736','(503) 622-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 14:30:58',0,NULL,3,1,1,1,'LK195611351CN\r ',NULL),(21173,928347472012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Jeanine Donofrio','713 W ANNIE ST','AUSTIN','TX','UNITED STATES','78704-4103','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 14:33:41',0,NULL,3,1,1,1,'LK190696179CN\r ',NULL),(21174,928348682012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','April Drewrey','28080 Hasley Canyon Rd<br>Ste 106','CASTAIC','CA','UNITED STATES','91384-4583','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 14:37:11',0,NULL,3,1,1,1,'LK195500072CN\r ',NULL),(21175,928351506012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','bluebird493','loriwhitlock@comcast.net','Lori Whitlock','2660 S 1475 W','Syracuse','UT','UNITED STATES','84075','(801) 728-0639','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 14:43:08',0,NULL,3,1,1,1,' LK192863223CN\r',NULL),(21176,622627048004,140662512199,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100',1,'HSPH008',114.99,'cnfaner','belly2785','krazycook38@yahoo.com','Marcus Juarez','9112 26th Pl','Brookfield','IL','UNITED STATES','60513','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-04 14:47:28',0,NULL,3,1,1,1,' LK187076008CN\r',NULL),(21177,838360310011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','gcot3217','jeanmdn@hotmail.com','Guy Cote','6991 Des Tulipes St','St-Hubert','QC','CANADA','J3Y 8S1','(514) 916-5573','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 15:28:06',0,NULL,3,1,3,1,'RA184532525CN\r','LGRM001 '),(21178,677219765013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','temba2000','temba2000@yahoo.com','Rodney Thomas','P.O. Box 310216','Birmingham','AL','UNITED STATES','35231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 15:40:32',0,NULL,3,1,1,1,' LK192379718CN\r','二代卡 旧 '),(21179,775362910008,180792774183,'New Microsoft Wired Optical Wheel USB Compatible  Mouse White',1,'MOMI004',13.1,'au-buy','jarrydco','jarryd.o@live.com','Jarryd','8/50 Carlton Crescent','Summer Hill','New South Wales','AUSTRALIA','2130','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 16:27:57',0,NULL,3,1,11,1,NULL,'MOMI004 '),(21180,783582083007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','sturlemonstad','sturle.monstad@lyse.net','Sturle Monstad','Elgfaret 1','Porsgrunn','Telemark','NORWAY','3930','+4745034105','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-04 16:37:51',0,NULL,3,1,22,1,NULL,'RCLO007+POLO001+RCLO008*4 \r欧标'),(21181,928417968012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Stephen G. Czapla','HC 69 Box 3021<br>14130 Dos Palos Rd','Santa Margarita','CA','UNITED STATES','93453-3021','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 16:43:22',0,NULL,3,1,1,1,'LK193117789CN\r ',NULL),(21182,677245630013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','ownedbyascottie','averra2@comcast.net','Sandra Mauldin','1407 Ivy Ct','Murfreesboro','TN','UNITED STATES','37130-2210','(615) 216-5625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 16:47:02',0,NULL,3,1,1,1,' LK188649688CN\r',NULL),(21183,928426932012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','alainspuds','nightwalkeralain@yahoo.com','elizabeth saleh','700 WARREN RD<br>APT 11-1E','ITHACA','NY','UNITED STATES','14850-1203','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 17:05:27',0,NULL,3,1,1,1,'LK193062714CN\r ',NULL),(21184,928436632012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Agrobiotek BPS','7993 NW 21ST ST','Doral','FL','UNITED STATES','33122-1616','(503) 722-6448','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 17:13:19',0,NULL,3,1,1,1,'LK197613077CN\r ',NULL),(21185,928438624012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Field Guides Inc.','9433 Fm 2244<br>Ste 1-150','AUSTIN','TX','UNITED STATES','78733-6130','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 17:16:40',0,NULL,3,1,1,1,'LK194568572CN\r',NULL),(21186,928368892012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','masmaster','mshtephan@gmail.com','Maxim Shtephan','Chaplinskoe highway, 7','Kakhovka','Kherson reg','UKRAINE','74800','(380)-50-4422022','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 17:21:06',0,NULL,3,1,22,1,NULL,' WLIN014'),(21187,838433955011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','simontrucks2012','simontrucks@yahoo.com','siamak talebi','18150 nw cornell rd','Beaverton','OR','UNITED STATES','97006-8600','(503) 327-1333','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 17:48:31',0,NULL,3,1,1,1,' LK192946016CN\r',NULL),(21188,928463157012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','twitzie27','floydbeckford@live.co.uk','floyd beckford','11 primrose walk<br>primrose walk','new cross','London','UNITED KINGDOM','se14 6lr','07428142396','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-04 17:53:00',0,NULL,3,1,3,1,'RA184532352CN\r',' HSJA002 英标'),(21189,928445399012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Willard Jeffrey','109 Park Ave<br>Ste E','FALLS CHURCH','VA','UNITED STATES','22046-4333','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 17:55:04',0,NULL,3,1,1,1,'LK195697335CN\r ',NULL),(21190,838485844011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','vicky_b7','vickygrenier83@hotmail.ca','Vicky Grenier','851, rue du boisé','Granby','QC','CANADA','J2J 2X4','(450) 378-4168','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 19:06:32',0,NULL,3,1,3,1,' RA184532556CN\r','GLOT001 '),(21191,837644782011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','archie7195','archievelyn1@msn.com','Archie Featherston','11459 E 37th St','Yuma','AZ','UNITED STATES','85367-5676','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 19:36:41',0,NULL,3,1,1,1,' LK191743290CN\r',' '),(21192,677339442013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','naug7772','naky3365@yahoo.com','Naky Augustin','1306 19th ave north','Lake Worth','FL','UNITED STATES','33460','(561) 588-3933','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 20:25:04',0,NULL,3,1,1,1,' LK185633030CN\r','二代卡 旧 '),(21193,838548195011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','gdonamaria','nhs@newhope-school.org','Guillermo Donamaria','2034 N 75th Ct','Elmwood park','IL','UNITED STATES','60707-3602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 20:55:02',0,NULL,3,1,1,1,' LK186701005CN\r',NULL),(21194,783744980007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','davidjones222','davidjones222@hotmail.com','David Jones','2/37 Kenthurst Road<br>ST IVES','Sydney','New South Wales','AUSTRALIA','2075','02 9440 4559','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 21:31:38',0,NULL,3,1,11,1,NULL,'RCLO007+POLO001+RCLO008*4 \r澳标\r'),(21195,928616664012,220901458489,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',3.8,'eastar4uk','aprilrabby','songbo5656@gmail.com','Bo Song','1023 Cooper Dr N','Columbia','MO','UNITED STATES','65201-7111','(573) 489-6211','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 22:01:40',0,NULL,3,1,1,1,' LK190871160CN\r',' '),(21196,677376914013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','alceujr','alceu@vetorzero.com.br','Alceu Matheus Baptistao Junior','Rua Joaquim Floriano, 913<br>8th floor','Sao Paulo','SP','BRAZIL','04534 013','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-02-04 22:11:38',0,NULL,3,1,11,1,'BJ01669396\r ','HSNO019 '),(21197,838600391011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRTT002',9.99,'eastar4','jonevk','jon@vankleeck.org','Jonathan E. Van Kleeck','7569 W Beloit Rd','West Allis','WI','UNITED STATES','53219-2445','(414) 727-9134','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 22:47:07',0,NULL,3,1,1,1,' LK189157441CN\r',NULL),(21198,792639884001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','ilsesauna','heinrich1947@web.de','Ursula Eicke','Bergmannstr.5','Hagenburg','','GERMANY','31558','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-04 23:24:37',0,NULL,3,1,22,1,NULL,'BALO007 '),(21199,838625450011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','nl-5','john.hollan@comcast.net','John Hollan','1389 Lemonwood Rd','Jacksonville','FL','UNITED STATES','32259-3100','(904) 312-3259','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 23:48:21',0,NULL,3,1,1,1,' LK191379402CN\r',NULL),(21200,622815637004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','jkennedy362','rjkennedy@gmail.com','ronnie j kennedy','2108 Josephs Run','New Richmond','OH','UNITED STATES','45157','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-04 23:49:55',0,NULL,3,1,1,1,' LK191611965CN\r',NULL),(21201,677404196013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',177.98,'eastar4','starmajik','rebecca.arena@me.com','Paul Arena','1970 Cardinal Dr','Shakopee','MN','UNITED STATES','55379','(952) 465-4478','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 23:57:38',0,NULL,3,1,1,1,' LK192583121CN\r',' '),(21202,783806501007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','madmax455753','max05@iinet.net.au','matthew Suridge','po box 108','roxby downs','South Australia','AUSTRALIA','5725','0886713305','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 00:08:18',0,NULL,3,1,11,1,NULL,'RELO002 '),(21203,928671234012,220527267230,'2.0 New ASUS Bluetooth Module +cable for EEEPC1005/W5F',1,'BTHU2001',9.88,'eastar4','jrafonso','rafaelafonso2@gmail.com','joao afonso','Alameda Linhas de Torres, 94-3ºdto.','Lisboa','Portugal','PORTUGAL','1750-147','(351) 961 773672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 00:09:03',0,NULL,3,1,22,1,NULL,'BTHU2001 \r华硕10pin 0.8 6cm '),(21204,838638954011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','geraaldhenry','quayon@gmail.com','Quayon lewis','40 partridge Way','wood green','London','UNITED KINGDOM','n22 8dw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 00:29:49',0,NULL,3,1,3,1,' RA184532349CN\r',' CACN004'),(21205,677417806013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','gugutse','abarbalat@sbcglobal.net','alex barbalat','253 arrowhead way','hayward','CA','UNITED STATES','94544-6649','(650) 520-7246','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(21206,928678023012,220877932141,'New HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',19.99,'eastar4','ltngnx','sntgro@gmail.com','Diogenes Deaza','940 Kenneth Ave<br>Apt 1','Elizabeth','NJ','UNITED STATES','07202-3114','(908) 248-2281','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 00:24:57',0,NULL,5,1,18,1,NULL,'由于无货问客户发这个行吗RM-MCE20E \r\r客户要求撤单  已退款'),(21207,617511289003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',87.99,'cnfaner','smooth3331cj','smooth33312000@yahoo.com','clinton malone','22 cottage ave','wingdale','NY','UNITED STATES','12594-1623','(845) 632-2740','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-05 01:14:51',0,NULL,3,1,1,1,' LK191398295CN\r',NULL),(21208,622840782004,140676374196,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',77.99,'cnfaner','bdinh1','bang_dinh@bose.com','Bang Dinh','3885 W 26th St','Yuma','AZ','UNITED STATES','85364','(928) 941-5967','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-05 01:41:06',0,NULL,3,1,1,1,' LK192799905CN\r',NULL),(21209,677432532013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','bj_stangman','bj_stangman@yahoo.com','Billy Smith','913 Cooper Dr N','Columbia','MO','UNITED STATES','65201-7114','(573) 424-0287','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 01:43:56',0,NULL,3,1,1,1,' LK188687071CN\r',NULL),(21210,783813753007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',18.99,'au-buy','mrtickle19','heather.whitecross@gmail.com','Heather Hill','15  William  St<br>Level 6','Melbourne','Victoria','AUSTRALIA','3000','0392565344','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 02:15:40',0,NULL,3,1,11,1,' ','UM00001 '),(21211,838670875011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','ipbpag','iperron@videotron.ca','Isabelle Perron','799 desjardins','Granby','QC','CANADA','J2H2N3','(450) 777-2480','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 02:16:40',0,NULL,3,1,3,1,' RA184532471CN\r','LGRM001 '),(21212,838706809011,320820766166,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',15.99,'eastar4uk','babyboy2324','vbigpapa@gmail.com','victor sinclair','892pinest','brooklyn','NY','UNITED STATES','11208','(347) 675-2191','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 04:38:22',0,NULL,3,1,1,1,' LK192635742CN\r',NULL),(21213,838709072011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','bram7704','bramsey1987@gmail.com','Brian Ramsey','2555 95th street<br>apt 213','port arthur','TX','UNITED STATES','77640','(281) 630-1324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 04:46:51',0,NULL,3,1,1,1,' LK190055572CN\r',NULL),(21214,783875620007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.38,'au-buy','wezlej','wesleyjbryant@hotmail.com','Wesley Bryant','81 Hawkhurst Street','Yarraville','Victoria','AUSTRALIA','3013','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 04:33:11',0,NULL,3,1,11,1,' ',' RELO003'),(21215,783895267007,170740412441,'2 pair New 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001*2',88.99,'au-buy','mrchev57929g','mrchev57@bigpond.com','Mr Jamie Pollard','8 Mt. Pleasant Road','BURRA','South Australia','AUSTRALIA','5417','0888922436','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 06:23:59',0,NULL,3,1,3,1,'RA184533185CN\r ',' GLOT001*2\r还买了一个TRSN001\r\r\r'),(21216,775678661008,180789713918,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',26.59,'au-buy','mrchev57929g','mrchev57@bigpond.com','Mr Jamie Pollard','8 Mt. Pleasant Road','BURRA','South Australia','AUSTRALIA','5417','0888922436','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 06:25:54',0,NULL,3,1,17,0,'RA184533185CN\r ',NULL),(21217,928795863012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','piano054','hmpluska@naver.com','Seong Ryong Kim','BaemalTown Apt. 102-206<br>Bongsan-dong','Wonju-si','Gangwon-do','KOREA,REPUBLIC OF','220-080','82-11-515-5312','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 07:53:09',0,NULL,3,1,11,1,NULL,'MOMI002 \r'),(21218,838752770011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','jimmy56892','jimmy.tran@live.se','Jimmy Tran','Bandyvagen 1','Ronneby','Blekinge','SWEDEN','37233','+46 708721490','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 08:32:47',0,NULL,3,1,22,1,NULL,'ADAK002 '),(21219,838771312011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','ssg145','luke_james145@hotmail.com','Luke James','19 Grey St','Belgrave','Victoria','AUSTRALIA','3160','0397548182','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 09:16:57',0,NULL,3,1,3,1,' RA184532485CN\r','LGRM001 '),(21220,838781832011,320801187531,'NIB genuine Philips SHS4800 Flexible Earhook Headphones 5-position adjustable',1,'HSPH003',13.99,'eastar4uk','vitalyskorokhod','vitaly.mylo@gmail.com','Vitaly Skorokhod','Knyagyni Olgy street 8, app. 9','Lviv','UA','UKRAINE','79057','+38068 500 1940','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 09:44:10',0,NULL,3,1,22,1,'BJ01669409\r ',' HSPH003'),(21221,928843522012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','pixiemouse2','angiescrangie@hotmail.com','Angie Pritchard','12 Dundas Street','Mayfield','New South Wales','AUSTRALIA','2304','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 10:05:30',0,NULL,3,1,11,1,NULL,'UM00008 '),(21222,928846443012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',26.99,'eastar4uk','booleypaul','bholapeter@yahoo.co.uk','peter bhola','17 somerset road','southall','Middlesex','UNITED KINGDOM','ub12tz','07944920190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 10:11:02',0,NULL,3,1,3,1,' RA184532397CN\r',' GLOT001'),(21223,622936504004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','ereia','polyakova.lubov@euroset.ru','Lubov Polyakova','Leningradskoe shosse, 100-78','Moscow','Moscow','RUSSIAN FEDERATION','125195','9260234000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 10:28:11',0,NULL,3,1,3,1,' RA184532600CN\r','HSJA002\r欧标 '),(21224,837053683002,120844622416,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'buysia','matushkoster','usa.cloth@gmail.com','Max Matushko','3851 Holcomb Bridge Rd<br>Ste 100','Norcross','GA','UNITED STATES','30092-5246','801 713 7835','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-05 10:39:34',0,NULL,3,1,1,1,' LK191777735CN\r',NULL),(21225,838819961011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','piergibay','gilbert.pierron@freesbee.fr','GILB PIERRON','SAB  ET CHROMINOX<br>PONT DE VALENTINE','SAINT GAUDENS','Midi-Pyrénées','FRANCE','31800','0033670760407','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 11:16:45',0,NULL,3,1,11,1,NULL,' GPS0010'),(21226,928877620012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','bluekwacker600','petrenee@aol.com','Peter Webster','7 The Gardens, Heath Road, Halifax','Halifax','West Yorkshire','UNITED KINGDOM','hx1 2pl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 11:15:09',0,NULL,3,1,3,1,'RA184538939CN\r ',' OTGR001'),(21227,677598419013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','manudu69','ducpmanu@free.fr','Pierre-Emmanuel DUC','14 Rue De Beauce','PARIS','Ile-de-France','FRANCE','75003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 13:28:02',0,NULL,3,1,11,1,NULL,'CACN004 '),(21228,784052062007,170762819424,'Brand new HP MCE Media Center + microsoft Remote Control + IR RECEIVER',1,'OTHP006',19.86,'au-buy','sall99','michael-ebay@sallaway.com','Michael Sallaway','2 Childs Street','Rochedale South','Queensland','AUSTRALIA','4123','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 13:31:20',0,NULL,3,1,11,1,' ','OTHP006 '),(21229,928954876012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','solbalraj','solbalraj@aol.com','Solomon Balraj','2012 W Gerald Drive<br>Churchill Park','Peoria','IL','UNITED STATES','61615-1188','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 13:35:23',0,NULL,3,1,1,1,' LK191696334CN\r',NULL),(21230,838890952011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','dwc316','michael_adams@drivingwithchrist.com','Michael Adams','193 Tunnel Hill Rd','Elizabethtown','KY','UNITED STATES','42701-8059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 13:34:20',0,NULL,3,1,1,1,' \rLK193201305CN\r',' 无线蓝牙二合一 '),(21231,837969153011,320800724933,'4 pairs 3D Active shutter Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 14:15:02',0,NULL,8,1,17,0,NULL,' GLOT001*4\r申报为gift 申报小于20$'),(21232,784090178007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',2,'RELO002',26.58,'au-buy','yapster0','mr.optus@gmail.com','Ian Younger','2 Canterbury Drive','MORPETH MANOR','New South Wales','AUSTRALIA','2321','0419441887','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 14:39:45',0,NULL,3,1,11,1,NULL,'RELO002 '),(21233,837181807002,120853616250,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones',1,'HSAL002',18.99,'buysia','prophetkyro','prophet_kyro@hotmail.com','Jessy Tremblay','8250, Rue de Marseille Appt:2','Montréal','QC','CANADA','H1L 1P6','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-05 15:01:03',0,NULL,3,1,11,1,NULL,'HSAL002\r美标 '),(21234,675248182013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','marilynb5253','maz_waz03@hotmail.com','marilyn Bywaters','44 Talus Drive','MOUNT RICHON','Western Australia','AUSTRALIA','6112','0894981315','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 15:01:33',0,NULL,3,1,3,1,' RA184532573CN\r','GLOT001*2 '),(21235,775313421008,180792774183,'New Microsoft Wired Optical Wheel USB Compatible  Mouse White',4,'MOMI004',52.4,'au-buy','lolokopterko','lolokopterka@azet.sk','Andrej Gasper','P.O. Box  86<br>P.O. Box  86','Banská Bystrica','Slovakia','SLOVAK REPUBLIC','97411','00421908683508','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 15:13:52',0,NULL,3,1,21,1,' RA184532539CN\r','MOMI004 '),(21236,838963579011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','rhubarbscientist','ddilks@affinitus.co.uk','Derek Dilks c/o Affinitus Group','Units 4-5 Grove Dairy Business Centre<br>Bobbing Hill','Sittingbourne','Kent','UNITED KINGDOM','ME9 8NY','01795844555','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 15:31:41',0,NULL,3,1,3,1,' RA184532318CN\r',' SAFI001*2'),(21237,928673669012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','mjbarch0902','blackwood14@verizon.net','martin blackwood','17944 Pond Rd','ashton','MD','UNITED STATES','20861-9756','(301) 570-4484','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 15:44:43',0,NULL,3,1,1,1,' LK193207073CN\r',NULL),(21238,617735668003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','meodien','daothaihy@hotmail.com','duc-thai-hy dao','7444 champagneur','montreal','QC','CANADA','H3N2J9','(514) 274-7904','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 16:00:42',0,NULL,3,1,3,1,' RA184532511CN\r','BALO007 '),(21239,838913873011,320462974714,'2.0 New ASUS Bluetooth Module +cable epc901 epc1000',1,'BTHU2004',9.88,'eastar4','kevinj76600','joly_kevin@orange.fr','yohann joly','135 rue rene cance','le havre','Haute-Normandie','FRANCE','76660','06.88.04.89.89.','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 16:45:31',0,NULL,3,1,2,1,NULL,'华硕 10 pin 1.0 5cm '),(21240,929107934012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','tony_benz','tikvichkata@hotmail.com','Atanas Baldzhiyski','125 High St<br>Pricewaterhousecoopers','Boston','MA','UNITED STATES','02110-2704','(508) 292-0172','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 17:13:38',0,NULL,3,1,1,1,' LK192954701CN\r',NULL),(21241,776004558008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.1,'au-buy','catloverjoe','thehatchetman@optusnet.com.au','Tim Vonja','2/30 Walter Street','St Albans','Victoria','AUSTRALIA','3021','030400247709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 17:44:58',0,NULL,3,1,11,1,NULL,'MOMI002 '),(21242,929126870012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','wanna_know_that','olesya_panova@mail.ru','Olessya Korotkaya','Akademika Satpaeva 253, ap.254','Pavlodar','','KAZAKHSTAN','140000','87019520441','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 17:57:57',0,NULL,3,1,11,1,NULL,'UM00006 \r蕾丝蝴蝶结伞 黑色'),(21243,929173069012,220904944805,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',11.99,'eastar4uk','petrolheaddave','davecperry@hotmail.com','David Perry','29 Brentwood Crescent','Southampton','Hampshire','UNITED KINGDOM','SO18 2BE','07887655341','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 18:04:45',0,NULL,3,1,3,1,' RA184532278CN\r',' WLIN014'),(21244,929183387012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','saltpillar','saltpillar@aol.com','Michel   weathers','618 Shields St','Hampton','VA','UNITED STATES','23669-1549','(757) 303-6773','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 18:11:57',0,NULL,3,1,1,1,' LK173524960CN\r',NULL),(21245,677765012013,230547010797,'New genuine IBM Intel Advanced-N WiMAX 6250 622ANXHMW',1,'WLIN002',39.99,'eastar4','dimitavt78','dimitavt@mail.ru','Dmitry Avtonomov','Academician Yangel 14-4-8<br>Ул Акад. Янгеля дом 14 корп. 4 кварт. 8','Moscow','Moscow','RUSSIAN FEDERATION','117534','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 18:32:57',0,NULL,3,1,11,1,NULL,'WLIN002 '),(21246,929232413012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','kornienkomv','kvakvamax@yandex.ru','MAKSIM KORNIENKO','ul. S.Krivoy, dom 26, kvartira 121','Chelyabinsk','','RUSSIAN FEDERATION','454080','+7 9128939047','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 18:50:48',0,NULL,3,1,11,1,NULL,' OTGR001'),(21247,839158538011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','bjornekdahl','letheproduktion@gmail.com','Björn Ekdahl','Flogstavägen 31C','Uppsala','','SWEDEN','75273','0046735612429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 18:56:34',0,NULL,3,1,22,1,NULL,' MOAP001'),(21248,784323923007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',20.28,'au-buy','carlsen79','sgcarlsen@gmail.com','Svein Gisle Carlsen','Professor Dahls Gate 16','Oslo','Oslo','NORWAY','0355','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 19:14:01',0,NULL,3,1,22,1,' ','HSUE003 '),(21249,929278967012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','bachus20','bachus@post.pl','Dominik Siedlak','Moresoft Computers, Unit B17,  KCR Industrial Estate<br>Kimmage, Dublin 12','Dublin','Dublin','IRELAND','D12','3531086354','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 19:24:02',0,NULL,3,1,22,1,' ','RMSN002 \rSONY MCE 遥控  白色   RM-MCE20E'),(21250,839197349011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','rafaboy2009','rafaboy.almeida@ig.com.br','Rafael Almeida','Rua Juiz Niltho Leite, nº 153, Ap 11<br>Jardim Primavera','Volta Redonda','Rio de Janeiro','BRAZIL','27283-430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 19:26:23',0,NULL,3,1,11,1,NULL,'HSJA002 '),(21251,617887844003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15.79,'cnfaner','adam1967uk','adam.ozarski@hotmail.co.uk','Adam Ozarski','86 Howards Way','Newton Abbot','Devon','UNITED KINGDOM','TQ124HX','01626438396','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 19:45:21',0,NULL,3,1,3,1,'RA184533070CN\r ','HSNO005+CCNO001 '),(21252,677824879013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.96,'eastar4','judycay1','judy@judycay.com','Judy C Dohm','1000 Windcrest Dr SE','New Prague','MN','UNITED STATES','56071','(952) 758-3613','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 19:46:50',0,NULL,3,1,1,1,'LK191855645CN\r ',NULL),(21253,677845469013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','azwampler','azwamp@msn.com','Ronald H Wampler','7767 E Windriver Dr','Tucson','AZ','UNITED STATES','85750','(529) 661-6814','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 20:13:06',0,NULL,3,1,1,1,' LK190131322CN\r',NULL),(21254,929364038012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',4,'TRMX003',39.96,'eastar4','dkffiv','dkffiv@gmail.com','William Nociti','597 Piermont Rd','Demarest','NJ','UNITED STATES','07627-1104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 20:40:00',0,NULL,3,1,1,1,' LK193260533CN\r','AUI Transceiver  MX20T '),(21255,837495115002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','9437gillian','gdopecope@aol.com','gillian cope','3beaconsfield drive','stoke on trent','Staffordshire','UNITED KINGDOM','st3 3dz','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 20:55:45',0,NULL,3,1,4,1,'YW868897930CN ','OTPH003 '),(21256,837494128002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','m_jones_4305','caragjones@aol.com','milton jones','118 Highland st.','cool ridge','WV','UNITED STATES','25825','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-05 20:58:23',0,NULL,3,1,1,1,' LK191069618CN\r',NULL),(21257,929381813012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','jacare66','jacare66pt@msn.com','carlos aldeias','11 mimosa court binfield road','london','London','UNITED KINGDOM','sw4 6sx','07940661419','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 21:00:52',0,NULL,3,1,3,1,'RA184532281CN\r ',' HSJA002英标'),(21258,617930214003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','jimmybeth123','jimmybeth@hotmail.com','James Nicola','14780 Fox','Redford','MI','UNITED STATES','48239-3163','(313) 387-1416','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-05 20:51:06',0,NULL,3,1,1,1,' LK186983350CN\r',NULL),(21259,839307136011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','dinem76','m.bagocius@gmail.com','Mindaugas Bagocius','72 Longland road','Northampton','Northamptonshire','UNITED KINGDOM','NN32RG','07411048084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 21:26:31',0,NULL,8,1,17,0,NULL,NULL),(21260,793270645001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','tomtom17fr','thomas.roche1@free.fr','Thomas roche','12 RUE ALBERT 1ER','LA ROCHELLE','Poitou-Charentes','FRANCE','17000','0689391778','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-05 21:27:58',0,NULL,3,1,11,1,NULL,'BALO007 '),(21261,839294666011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','constantino9082','consnet4@hotmail.com','constantino perez lopez','via romana nº15 bjo','ibiza','Baleares','SPAIN','07800','670309313','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 21:33:00',0,NULL,3,1,21,1,'RA184538956CN\r ','HSNO035欧标 '),(21262,929423121012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','plklg980105','pacoylaura@telefonica.net','Laura Ortega de Frutos','C/ Rafael Bergamin, 12<br>Esc. Dcha 5ºD','Madrid','Madrid','SPAIN','28043','656403780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 21:55:26',0,NULL,3,1,21,1,' RA184532675CN\r','GLOT001 '),(21263,839331283011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',53.98,'eastar4uk','dinem76','m.bagocius@gmail.com','Mindaugas Bagocius','72 Longland road','Northampton','Northamptonshire','UNITED KINGDOM','NN32RG','07411048084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 22:08:54',0,NULL,3,1,3,1,' RA184532410CN\r','GLOT001 \r又买了一个GLOT001\r共三个'),(21264,929448815012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','chaoskitty65','shawna.north@sasktel.net','S. North','727 Elizabeth Street','Moose Jaw','SK','CANADA','S6H 6B2','(306) 692-4162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 22:37:48',0,NULL,3,1,3,1,' RA184532984CN\r',' OTGR001'),(21265,839186449011,320394934550,'Acer Aspire 6920 6920G Bluetooth Module 2.0 EDR+cable',1,'BTAC2016',9.88,'eastar4','ajbinegar8290','sweet_lil_baby12345@live.com','Ashley Robison','514 S Riverview Ave','miamisburg','OH','UNITED STATES','45342-3028','(937) 366-6130','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 23:08:29',0,NULL,3,1,1,1,' LK192488240CN\r','acer 8pin0.8 16cm '),(21266,784494819007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','graduatetaz2000','graduatetaz2000@yahoo.com','Home','869 McAdoo st','Clinton','TN','UNITED STATES','37716','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 23:13:48',0,NULL,3,1,1,1,' LK188183343CN\r',' RCLO007+POLO001+RCLO008*4'),(21267,929468851012,220928720352,'New genuine Grohe Shower head holder made in Germany',1,'OTGR003',12.99,'eastar4uk','chewbury','ssmith@streets.ie','Shane Smith','410 Riverforest','Leixlip','Kildare','IRELAND','00','0833163450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 23:20:55',0,NULL,3,1,21,1,' RA184532295CN\r','OTGR003 '),(21268,839373807011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','ksysiu69','chiavo92@gmail.com','Tomasz Topczewski','Plac Świętego Macieja 15/7','Wrocław','dolnośląskie','POLAND','50-244','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 23:38:07',0,NULL,3,1,22,1,NULL,' UDAP001'),(21269,784507994007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','e-tronicsdepot','mdmmason@yahoo.com','Daniel Mason','135 Main Street','Gananoque','ON','CANADA','K7G 2M1','(613) 463-9448','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 23:53:18',0,NULL,3,1,11,1,NULL,' RCLO007+POLO001+RCLO008*4'),(21270,776291453008,180781221355,'New Jabra JX10 Series II 2 Wireless Bluetooth headset  Sliver +AC  adapter',1,'HSJA0012',18.03,'au-buy','archery.717','bowkill94@yahoo.com','garry pomraning','345 Mitchell Rd','airville','PA','UNITED STATES','17302-9006','(717) 668-3681','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 00:25:33',0,NULL,3,1,1,1,' LK192391308CN\r','HSJA0012'),(21271,675685087013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','koguitar','koguita@gmail.com','Luis Casanova','U6 382 St Kilda St<br>Brighton','Melbourne','Victoria','AUSTRALIA','3186','0412246327','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 00:31:24',0,NULL,3,1,11,1,NULL,'CASS003 \rCAB-6060'),(21272,839396292011,320737032202,'3 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*3',163.99,'eastar4','sixperf','jmitchll@bigpond.net.au','John Mitchell','68 Warrane Road','Willoughby','New South Wales','AUSTRALIA','2068','0294175338','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 00:43:51',0,NULL,3,1,3,1,' RA184532750CN\r','GLOT005*3 '),(21273,839399881011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','rachelsssssss','rachelendless@gmail.com','QIANQIAN SONG','900 COLLEGE ST<br>UMHB STATION BOX 8763','Belton','TX','UNITED STATES','76513-2578','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 00:54:53',0,NULL,3,1,1,1,' LK192213568CN\r',NULL),(21274,677965840013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','vicmazz64','vicmazz64@bigpond.com','Vittorio Mazzarolo','P O Box 140','Wallan','Victoria','AUSTRALIA','3756','0419643367','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 01:36:11',0,NULL,3,1,3,1,' RA184532644CN\r','GLOT001*2 '),(21275,677967798013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','gaodonto10','gaodonto@gmail.com','Guilherme Martins','SQN 213 BLOCO A APA 102','BRASILIA','DF','BRAZIL','70872010','00556181210794','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 01:48:20',0,NULL,3,1,3,1,' RA184532613CN\r','GPS0006 \r申报30美金'),(21276,839419029011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','caitie97497087','caitlingoldie@hotmail.com','Caitlin Goldie','139 THAMES BOULEVARD','TARNEIT','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 01:57:20',0,NULL,3,1,11,1,NULL,'UM00040 \r爱雨透明伞  '),(21277,677975849013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','zdanek68','zdanek.andrzej@gmail.com','andrew zdanowicz','226 E Hillcrest Ave','WOOD DALE','IL','UNITED STATES','60191-1424','(630) 261-5220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 02:16:16',0,NULL,3,1,1,1,'LK186204403CN\r ',NULL),(21280,8881328495496313,111,'A pair of New 3D Active Shutter TV Glasses with IR emitter - GLOT002+GLOT003',1,'GLOT002+GLOT003',79.99,'aliexpress','1006582148','wolfalone@list.ru','Vladimir Bogdanov	','Skolnaya 6 - 8','Gavrilovo','Leningradskaya obl.	','RUSSIAN FEDERATION	','188870','+7 921 7785349',NULL,NULL,NULL,'2012-02-06 02:31:36',0,NULL,5,1,18,1,'','GLOT002+GLOT003 \r客户要取消订单'),(21278,677977859013,230721079075,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',99.99,'eastar4','advantage549','advantageguideservice@gmail.com','joe jochman','1296 15th Ave','Arkdale','WI','UNITED STATES','54613-9713','(715) 459-4366','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 02:25:30',0,NULL,3,1,1,1,' LK191501568CN\r',NULL),(21279,8881328495309105,111,'New Map Anti-UV Rain Sun Parasol Stick Umbrella - UM00007',1,'UM00007',24.99,'aliexpress','1006556162 ','inspirationalcareers@yahoo.co.uk','Denise Chambers	','167 Griffin Close Dollis Hill','Brent','London','UNITED KINGDOM	','NW10 ILR','+07958 238 565',NULL,NULL,NULL,'2012-02-06 02:28:29',0,NULL,3,1,3,1,'RA184533106CN\r ','UM00007 '),(21281,617990470003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','karen59clark','karenclark18@yahoo.com','karen clark','411 Purtle Rd','lafayette','TN','UNITED STATES','37083-4255','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-06 04:11:32',0,NULL,3,1,1,1,' LK192560117CN\r',NULL),(21282,8881328501665876,111,'New SAMSUNG SSG-3700CR Rechargeable 3D Glasses',1,'GLSG008',159.99,'eastar4','Oddur Bogason ','oddz@hive.is','Oddur Bogason ','Mavanes 13 ','Gardabaer','','ICELAND ','210','',NULL,NULL,NULL,'2012-02-06 04:14:25',0,NULL,3,1,3,1,'RA184533199CN\r ','GLSG008 \r直接打得款'),(21283,784583146007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','krisgret','krisgret@megalink.net','Gretchen Anderson','10666 Boulder Canyon Rd','Rancho Cucamonga','CA','UNITED STATES','91737-2476','(207) 357-5639','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 04:17:40',0,NULL,3,1,1,1,NULL,''),(21284,839467024011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','jhvbheidi','jhvb@shaw.ca','Jessica Heidi Von Braun','8512 English Church Road RR#1','Mount Hope','ON','CANADA','L0R 1W0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 04:38:54',0,NULL,3,1,11,1,NULL,'HBPH009 '),(21285,839468269011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','mysneadbusiness','carmen.snead@yahoo.com','Carmen Snead','19336 Harned St','Detroit','MI','UNITED STATES','48234-1507','(313) 330-4303','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 04:41:54',0,NULL,3,1,1,1,' LK192457066CN\r',' '),(21286,929578219012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',109.99,'eastar4','buymygoodproduct','malvin.young@gmail.com','malvin young','27 lilly mckeowan cres.','mount albert','ON','CANADA','l0g1m0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 04:50:46',0,NULL,3,1,3,1,' RA184532746CN\r','GLOT005*2 '),(21287,929579728012,220705652073,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET',1,'HSNO005',10.48,'eastar4uk','slainbymegatron','dan_levan@yahoo.com','DANIEL LEVAN','2718 Lafeuille Cir<br>Apt 2','CINCINNATI','OH','UNITED STATES','45211-8246','(513) 471-3265','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 04:53:44',0,NULL,3,1,1,1,'LK192376800CN\r ',''),(21288,677597897013,230696519806,'New genuine LG 3D Active Shutter Glasses AG-S110 S110',1,'LGGL002',63.99,'eastar4','engine201','ivrusoze@mail.ru','ivan Korotaev','street lenina house 25 flat 62','ozery','moscau region','RUSSIAN FEDERATION','140560','89057201535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 05:01:42',0,NULL,3,1,3,1,' RA184532967CN\r','LGGL002 '),(21289,677922707013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','tommyds23','tommyds23@hotmail.com','Tomorrow Smith','222 Ridge Dr','Manhattan','KS','UNITED STATES','66502-3827','(785) 410-3044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 05:07:46',0,NULL,3,1,1,1,' LK193008086CN\r','接边蕾丝透明伞    '),(21290,929596027012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','intershoppa','loaney4@bigpond.com','Leigh Lo`ane','P.O.Box 1005','Buddina','Queensland','AUSTRALIA','4575','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 06:07:30',0,NULL,3,1,11,1,NULL,'UM00014 \r美女涂鸦伞 '),(21291,618073217003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.59,'cnfaner','tsakmakisdm','tsakmakisd@yahoo.gr','dimitris tsakmakis','Domestichou 20','Komotini','','GREECE','69100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 06:33:23',0,NULL,3,1,21,1,' RA184532729CN\r','TRSN001 '),(21292,678028144013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','vgt67','vgt2plus@yahoo.com','Vicente Guzman','785 w Heather ST','Rialto','CA','UNITED STATES','92376-2677','(310) 425-5764','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 07:03:38',0,NULL,3,1,1,1,' LK187304779CN\r',' '),(21293,678036676013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','coyote150961','coyote@targo.ca','Jean-Francois Michaud','397 Rg de l\'Eglise','St-Edouard','QC','CANADA','J0L 1Y0','(450) 454-3716','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 07:54:36',0,NULL,3,1,3,1,' RA184532732CN\r','GPS0006 '),(21294,929620921012,220448682374,'Acer Aspire 4720 4720G 4720Z Bluetooth Module 2.0+cable',1,'BTAC2014',9.88,'eastar4','alexandrzu','zas_50@mail.ru','Zubtsov Alexander','20 Derbenevskaya St., Building 16, Floor 3 ','Moscow','Moscow','RUSSIAN FEDERATION','115114','+7 909 6802830','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 08:08:09',0,NULL,3,1,11,1,NULL,'BTAC2014 \racer 5pin1.25 20cm'),(21295,678042312013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','kuleshs83','kuleshs@yandex.ru','Sergey Kuleshov','Adriena Lezhena 24 - 22','Novosibirsk','RU','RUSSIAN FEDERATION','630089','9130150538','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 08:29:59',0,NULL,3,1,11,1,NULL,'WLAT008 '),(21296,929628441012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','carl01793','cuffy1@googlemail.com','Carl Higgs','20 Camden close<br>Grange Park','Swindon','Wiltshire','UNITED KINGDOM','SN5 6BU','01793428425','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 08:39:48',0,NULL,3,1,3,1,'RA184519254CN\r ',' MOLO001'),(21297,623422632004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',19.95,'cnfaner','abell5129','madmoody@gmail.com','Adrian Bell','18 Siebel Street','Blacktown','New South Wales','AUSTRALIA','2148','0402903042','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 08:59:00',0,NULL,3,1,3,1,' RA184532803CN\r','WLAP002 '),(21298,839520130011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','spatres10','sspatres@yahoo.com','Salman Patres','1069 silverfox drive','London','ON','CANADA','n6g0g2','(519) 701-2473','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 08:54:42',0,NULL,3,1,11,1,'BJ01712770 ','HSJA011 '),(21299,678049526013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','kornaz_gb','giedrius.stalioraitis@gmail.com','Giedrius Stalioraitis','Perkunkiemio 9-67','Vilnius','Vilnius','LITHUANIA','12114','37068666379','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 09:11:56',0,NULL,3,1,22,1,'BJ01712766 ','WLAP008 '),(21300,8881328523378921,111,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card WLAT001',1,'WLAT001',13.99,'aliexpress','1006600392','1@1.com','Vyacheslav','Slobodka House 26 apartment 15','Bogorodskoe','Sergiev-Posad	','RUSSIAN FEDERATION	','141342','+7 905 5135033',NULL,NULL,NULL,'2012-02-06 10:16:18',0,NULL,3,1,3,1,'RA184533049CN\r ','WLAT001 '),(21301,839543759011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','jonphoe','rgreetham@aol.com','Robert Greetham','The Grange<br>Faulding Lane','South Killingholme','Lincolnshire','UNITED KINGDOM','DN403EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 10:19:38',0,NULL,3,1,3,1,'RA184532865CN\r ',' RELO003'),(21302,618110712003,130458358255,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+Carcharger',1,'HSNO005+CCNO001',15.79,'cnfaner','pa_wolf0676','patrick.wolf0676@gmail.com','Patrick Wolf','T-Mobile Shop Lienz<br>Johannesplatz 12','Lienz','','AUSTRIA','9900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 10:31:06',0,NULL,3,1,21,1,'RA184533066CN\r ','HSNO005+CCNO001 \r欧标'),(21303,776447251008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',44.64,'au-buy','ankurdhar','ankurandlisa@hotmail.com','Lisa Dhar','PO Box 741','Crows Nest','New South Wales','AUSTRALIA','1585','0282034211','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-06 10:55:59',0,NULL,3,1,3,1,'RA184532882CN\r ',' HBPH007'),(21304,929670681012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','jayjen880','jayskim1@dodo.com.au','Jayson Jensen','37 Daytona Drive<br>Kirwan','Townsville','Queensland','AUSTRALIA','4817','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 11:05:07',0,NULL,3,1,2,1,'30120557342\r ','HP 8pin 1.0 23cm  '),(21305,839565758011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','totoro05000','belmonte.cedric@gmail.com','Cédric Belmonte','2 Rue Nestlé','Gap','Provence-Alpes-Côte d\'Azur','FRANCE','05000','06.99.01.65.44','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 11:31:50',0,NULL,3,1,11,1,'BJ01669414\r ','RELO003 '),(21306,839583130011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','munners-2008','kev.munnerley@gmail.com','kevin munnerley','50 the maples ','winsford','Cheshire','UNITED KINGDOM','cw7 3bf','01606860110','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 12:27:25',0,NULL,3,1,3,1,'RA184532936CN\r ','SAFI001*2 \reastar4uk'),(21307,623474693004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','buykorea2020','yeol@nate.com','JIYEOL PARK','1209-8, Shinjeong 3-dong,<br>Yangcheon-gu,','Seoul','Seoul','KOREA,REPUBLIC OF','158-073','0163964633','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 13:19:33',0,NULL,3,1,3,1,'RA184532896CN\r ','OTCN004 '),(21308,678124095013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','ostibiker','angelopeca@yahoo.com.br','Angelo Peca','Rua Delmiro Gouveia<br>255','São Paulo','São Paulo','BRAZIL','03266190','55 11 29110638','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 14:42:05',0,NULL,3,1,3,1,'RA184532940CN\r ','GPS0006 '),(21309,776530082008,180755522339,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.04,'au-buy','piper551','piperette@hotmail.com','Carol Denise','763 Bay Street','Midland','ON','CANADA','L4R 1M5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 15:11:58',0,NULL,3,1,11,1,'BJ01669400\r ','HBPH009'),(21310,929788947012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','livergais','livergais@spray.se','kenneth karlsson','storegårdsvägen 1b','nol','','SWEDEN','44942','+46764138966','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 16:04:59',0,NULL,3,1,22,1,'BJ01669410\r ','MOAP001 '),(21311,839706097011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ixia-2008','jclaude.girard@gmail.com','Jean-Claude GIRARD','res le vieux pont avenue du mont aigoual<br>log 20 bat B','ganges','Languedoc-Roussillon','FRANCE','34190','0661894736','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 17:28:01',0,NULL,3,1,3,1,'RA184533035CN\r ',' MOAP001'),(21312,678184334013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','alexander.anderson308','alexander.anderson@my.und.edu','alexander anderson','108b walsh hall','Grand Forks','ND','UNITED STATES','58202-1401','(651) 491-7850','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 17:45:59',0,NULL,3,1,1,1,'LK192387498CN\r ',NULL),(21313,623558051004,140667903814,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card + A pair of Antenna',1,'WLAT009+ANTY001',11.9,'cnfaner','yakinbob','bobwendy@juno.com','bob Lombardo','2602 Lavin Ct','Troy','NY','UNITED STATES','12180-1715','(518) 274-9851','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-06 18:04:47',0,NULL,3,1,1,1,'LK192438800CN\r ',NULL),(21314,618232732003,130503492964,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.85,'cnfaner','dencet','dimaadm@mail.ru','Дмитрий Чупин','ул. Сосьвинская, д. 47, кв. 158','Тюмень','Тюменская область','RUSSIAN FEDERATION','625031','89129921148','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 18:12:56',0,NULL,3,1,3,1,'RA184532922CN\r ','WLAT007 '),(21315,929897311012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','mika_nokava','oneesan0@gmail.com','Ksenia Sultanova','Mira, 42, 6','Yekaterinburg','','RUSSIAN FEDERATION','620078','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 19:08:04',0,NULL,3,1,11,1,'\\ ','UM00008 '),(21316,839800797011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','jeffpsw','pcondon8@insightbb.com','Pete Condon','41 Manchester Ct','Bluffton','SC','UNITED STATES','29910-7455','(843) 706-7002','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-06 19:58:45',0,NULL,3,1,1,1,'LK191517568CN\r ',NULL),(21317,678246571013,230608895412,'New bulk GENUINE NOKIA BH-700 BLUETOOTH HEADSET BH 700',1,'HSNO028',18.45,'eastar4','lexsos99','ulitka74@mail.ru','Scheffer Alexander','Bredowstr. 8','Dortmund','','GERMANY','44309','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 19:59:09',0,NULL,3,1,22,1,'BJ01669403\r ','欧标 \rHSNO028'),(21318,793726234001,110808693045,'Mystery UFO Floats Completely silent In Mid-air',1,'OT00005',8.49,'buysia','viniciusws','cinhows@gmail.com','Vinícius Oliveira de Melo','Republica Do Chile 330, Edifício Ventura - 6° Andar  Centro<br>Ramal: 704-9511','Rio de Janeiro','Rio de Janeiro','BRAZIL','20031-170','55 21 2144-9511','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-06 20:06:47',0,NULL,3,1,11,1,'BJ01669408\r ','OT00005 '),(21319,776712272008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',24.69,'au-buy','markyd3','markdavis@sky.com','Mark Davis','3 The Twitten','Burgess Hill','West Sussex','UNITED KINGDOM','RH15 8BX','07769644989','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 21:00:28',0,NULL,3,1,11,1,'BJ01669411\r ',' MOLO006'),(21320,678279580013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','siemens350','noleenmegaair@yahoo.com','Leonid Loiterstein','Chaikovskogo 2/7, kv. 76','St.Petersburg','','RUSSIAN FEDERATION','191187','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 21:13:25',0,NULL,3,1,11,1,'BJ01669413\r ','WLIN014 '),(21321,929988170012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','ddunn64','d.dunn09@btinternet.com','david dunn','4 cunningham cresent<br>sholing','southampton','Hampshire','UNITED KINGDOM','so19 8la','02380432606','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 21:29:47',0,NULL,3,1,3,1,'RA184532879CN\r ',' HSJA010 英标'),(21322,678290659013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','e.mack84','emmet.macken@gmail.com','Emmet Macken','Leedaun,<br>Brookhill,','Claremorris','Mayo','IRELAND','default','0851151567','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 21:37:33',0,NULL,3,1,22,1,'BJ01669412\r ','CASS003 '),(21323,930005732012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',8.39,'eastar4uk','jonarg99','john@johnargyle.co.uk','John Argyle','23 Edward Road<br>Kennington','Oxford','Oxfordshire','UNITED KINGDOM','OX1 5LH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 21:50:11',0,NULL,3,1,3,1,'RA184532953CN\r ',' RELO002'),(21324,839875943011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','richreichle','reichle1@yahoo.com','Richard A. Reichle','809 Yorkmont Rd','Charlotte','NC','UNITED STATES','28217-2426','(704) 975-3391','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 22:08:47',0,NULL,3,1,1,1,'LK193918780CN\r ','3.0 ASUS 6PIN 12CM   '),(21325,927618008012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','cutepeachbunny','vjerolamon@gmail.com','vanessa jerolamon','3333 shasta way<br>Spc 65','klamath falls','OR','UNITED STATES','97603-4452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 22:55:31',0,NULL,3,1,1,1,'LK192532120CN',NULL),(21326,930062004012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','andesite_mtn','christopher.halvorson@gmail.com','Chris Halvorson','1936 S Teal Ln','Boise','ID','UNITED STATES','83706-4050','(208) 559-2549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-06 23:58:39',0,NULL,3,1,1,1,'LK186444942CN\r ',NULL),(21327,678338903013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','fionab_2011','fiona.boundey@dbp.net.au','Fiona Boundey','12 Reeves Entrance','Success','Western Australia','AUSTRALIA','6164','0894143512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 00:21:36',0,NULL,3,1,3,1,'RA184533052CN\r ','GLOT001*2 '),(21328,839934020011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','maddrake','sign_right_here@msn.com','Arthur Garza','7138 Larksong St','San Antonio','TX','UNITED STATES','78238-1326','(210) 467-2908','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-07 00:47:47',0,NULL,3,1,1,1,'LK193859199CN\r ',NULL),(21329,839947671011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','danielhunt1989','rangul04@yahoo.com','Daniel Hunt','535 Wood Mist dr','Houston','TX','UNITED STATES','77013-4820','(832) 892-4496','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-07 01:28:50',0,NULL,3,1,1,1,'LK188886846CN\r ',NULL),(21330,618377481003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','geezertop','geezertop@yahoo.com','Leslie R. Top','HC 73 Box 34B','Mountain Grove','MO','UNITED STATES','65711-8708','(417) 259-1377','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-07 01:41:25',0,NULL,3,1,1,1,'LK193094500CN\r ',NULL),(21331,785054503007,170728921512,'New Jabra BT135 Bluetooth headset+AC power charger',1,'HSJA007',13.82,'au-buy','rosamurphy915','rosamurphy@sbcglobal.net','Rosa Murphy','4268 River Oaks Dr','Florissant','MO','UNITED STATES','63034-3009','(314) 355-2683','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 01:57:51',0,NULL,3,1,1,1,'LK191175537CN\r ','缺线 '),(21332,930134995012,220455468757,'HP NW8000 NC8230 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',9.88,'eastar4','gward25','graylingward@hotmail.com','garyling ward','2204 bush dr','arlington','TX','UNITED STATES','76014','(682) 556-1401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 03:32:13',0,NULL,3,1,1,1,'LK193671508CN\r ','HP 8pin 1.0 3cm  '),(21333,678380818013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','debroosters','harleys@nelsonbay.com','Deb Sullivan','22 The Breakwater Corlette<br>Port Stephens','Port Stephens','New South Wales','AUSTRALIA','2315','0249811502','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 03:35:43',0,NULL,3,1,11,1,'\\ ','UM00033 \r韩版透明伞 '),(21334,838176392002,120854117159,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'buysia','0603eric13','eric13@sfr.fr','MESSELIER eric','1820 chemin des tuillieres','les milles','Provence-Alpes-Côte d\'Azur','FRANCE','13290','0634124959','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-07 04:16:35',0,NULL,3,1,11,1,'BJ01669405\r ','GPS0010 '),(21335,793903847001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',2,'OT00002',25.98,'buysia','tinkers7','thinkers77@verizon.net','lorie hallman','1790 Hillmeade Sq','Frederick','MD','UNITED STATES','21702-3089','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-07 04:21:54',0,NULL,3,1,1,1,'LK193537137CN\r ',NULL),(21336,839999757011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','thundersecurity','thundersecuritycctv@gmail.com','Charles  Alphonse','3411 Vaughn St.','Knoxville','TN','UNITED STATES','37920','(865) 223-6941','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 04:26:56',0,NULL,3,1,1,1,'LK191392341CN\r ','新地址\rCharles  Alphonse\r3706 Alpine Dr. \rKnoxville TN 37920\rUNITED STATES\r(865) 223-6941\r '),(21337,930158684012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','vadiml1976','vadiml@optonline.net','Vadim Lipovetsky','345 Bullard Ave','Paramus','NJ','UNITED STATES','07652-4637','(201) 261-0540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 05:01:39',0,NULL,3,1,1,1,'LK193211546CN\r ',' '),(21338,840009216011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',3,'CASS002',29.97,'eastar4','n1ckston3','nickston3@gmail.com','Nick Stone','Unit 5 43 Herbert St<br>Atarmon','Sydney','New South Wales','AUSTRALIA','2065','0434566529','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 05:12:36',0,NULL,3,1,11,1,'BJ01669404\r ','CASS002\r '),(21339,776881992008,180762085457,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring',1,'UM00021',25.64,'au-buy','svick5','a.svickerman@gmail.com','sally vickerman','14 parkview street<br>milton','brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 06:00:48',0,NULL,3,1,17,0,'RA184533137CN\r ','UM00021 蓝色'),(21340,785113482007,170735464388,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',26.59,'au-buy','svick5','a.svickerman@gmail.com','sally vickerman','14 parkview street<br>milton','brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 06:04:00',0,NULL,3,1,3,1,'RA184533137CN\r ','UM00008\r还买了一把UM00021 蓝色 \rNew prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella   Leather ring'),(21341,618237650003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',2,'HSJA012',37.96,'cnfaner','jyane87','jyane87@hotmail.fr','biad halima','1 allée le gréco','limoges','Limousin','FRANCE','87100','06.15.59.12.42','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 06:12:44',0,NULL,3,1,3,1,'RA184533021CN\r ','HSJA012 \rsilver\r欧标'),(21342,623761394004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',21.9,'cnfaner','zynxman','zynxcheg@gmail.com','Sergey Petrov','Baumana, 219/6, 19','Irkutsk','','RUSSIAN FEDERATION','664048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 06:34:59',0,NULL,3,1,3,1,'RA184533018CN\r ','OTGR005 '),(21343,623764185004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','akvara','akvara@gmail.com','Andrius Kvaraciejus','Paribio 28-37','Vilnius','','LITHUANIA','LT08103','(370) 685 55031','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 06:58:30',0,NULL,3,1,21,1,'RA184533154CN\r ','HSNO005 '),(21344,840036131011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','afzal_2u','afzal_2u@yahoo.com','muhammed ramay','595 proudfoot lane #103,<br>london ontario','london','ON','CANADA','n6h4s1','(519) 694-1813','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 07:33:58',0,NULL,3,1,11,1,'BJ01669401\r ','HSJA011 '),(21345,623771932004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','1865582','bbrv@inbox.ru','Konstantin V. Bobrov','pr. Bolshevikov, d. 13 korp. 3, kv. 43','St. Petersburg','Russia','RUSSIAN FEDERATION','193168','+7 911 7413079','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 07:55:15',0,NULL,3,1,3,1,'RA184533741CN\r ','OTTP001 '),(21346,775143455008,180794745393,'Brand new HP MCE Media Center Remote Control+IR Emitter',1,'OTHP005',14.06,'au-buy','jwort70','nerdnetworks@gmail.com','John Wortley','Ericsson Australia<br>Level 8, 818 Bourke St','Docklands','Victoria','AUSTRALIA','3008','0414232487','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 08:21:41',0,NULL,3,1,11,1,'BJ01669392\r ','OTHP005 '),(21347,840070198011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','shavenraven','adamraven_1@hotmail.com','Adam Raven','Project Database<br>Sir Peter Thompson House, 25 Market Close','Poole','Dorset','UNITED KINGDOM','BH151NE','07867932686','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 09:50:51',0,NULL,3,1,3,1,'RA184529035CN\r ','WLAT008 '),(21348,840075035011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',9.49,'eastar4','4kacper','email@4kacper.net','Kacper Siminski','5 Silverburn Avenue','Richmond','New South Wales','AUSTRALIA','2753','0413231403','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 10:08:06',0,NULL,3,1,2,1,'30120695312\r ',NULL),(21349,784939363007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',37.98,'au-buy','krismt1407','kris.tully@bigpond.com','Kristine Tully','36 Weinholt Street<br>SHERWOOD','BRISBANE','Queensland','AUSTRALIA','4075','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 10:50:08',0,NULL,3,1,3,1,'RA184529185CN\r ','UM00033\r买了两把伞  一个猫的 一个鞋子的  '),(21350,930233849012,220886271520,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',10.99,'eastar4uk','bogdan.orlov','fluxtory@gmail.com','Bogdan Orlov','Mejerigatan 2B rum 823','Göteborg','','SWEDEN','41276','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 10:53:38',0,NULL,3,1,22,1,'BJ01712767\r ','MOMI004 '),(21351,838393783011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','xar_kout','xarkoutroukis@hotmail.gr','KOUTROUKIS CHARALAMPOS','AGXIALOU 39-41','KOMOTINI','komotini','GREECE','69100','6971921781','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 11:11:41',0,NULL,3,1,22,1,'BJ01712776\r ','HSJA002 '),(21352,930259160012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','leoncartledge','leon_mish@iprimus.com.au','Leon Cartledge','20 Second Ave','Bridgewater','South Australia','AUSTRALIA','5155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 11:43:55',0,NULL,3,1,3,1,'RA184529203CN\r ','GLOT001*2 '),(21353,930265471012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','pepegrillo2012','zipppy@hotmail.es','Octavio Serrano Lopera','C/. Apuente 8 - 14','Puerto de Sagunto','Comunidad Valenciana','SPAIN','46520','962673385','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 12:04:23',0,NULL,3,1,21,1,'RA184529150CN\r ','GLOT001 '),(21354,929762794012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','stacysusanne','stacysusanne@yahoo.com','Stacy Chapman','PO Box 1613','Dripping Springs','TX','UNITED STATES','78620-1613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 12:34:49',0,NULL,3,1,1,1,'LK185477975CN\r ',NULL),(21355,618498772003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','mrva385','dbelak@gmail.com','Dario Belak','Jasenik 7a','Zagreb','','CROATIA','10000','00385915388993','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 13:17:26',0,NULL,3,1,21,1,'RA184529092CN\r ','BALO007 '),(21356,623837710004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',99,'cnfaner','artshaper','osx86@sixflow.net','won-taek seo','Office 201, 39-6, Baekjegobun-ro 27-gil, Songpa-gu','seoul','','KOREA,REPUBLIC OF','138-837','82-10-7312-2154','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 13:45:01',0,NULL,3,1,3,1,'RA184529013CN\r ','WLAP008 '),(21357,840146495011,320826634884,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',13.99,'eastar4uk','holaus2005','holaus.anton@hotmail.com','anton holaus','märzenstr. 3','stumm','','AUSTRIA','6272','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 13:58:17',0,NULL,3,1,22,1,'BJ01712774\r ',' OTGR005'),(21358,678515203013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','nata161','ne_morozova@list.ru','863natalia morozova','volkova, 7. kv. 30','rostov on don','rostov','RUSSIAN FEDERATION','863','(918) 5040294','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 15:02:33',0,NULL,3,1,11,1,'BJ01712783\r ','UM00042 '),(21359,840173417011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','tahoe827','heavydee388@yahoo.com','Dennis Roman','12 Empire Blvd','Moonachie','NJ','UNITED STATES','07074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 15:11:36',0,NULL,3,1,1,1,'LK192457415CN\r ',NULL),(21360,840187555011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','alex_hachik','alex.k@liaisongroup.ca','Sasha K','65 Combe Ave','Toronto','ON','CANADA','M3H 4J5','(416) 910-0660','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 15:47:42',0,NULL,3,1,11,1,'BJ01712773\r ','HSJA002 '),(21361,678527511013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','158goodwin','bigdady2123@hotmail.com','Travis Goodwin','158 Pleasant View Rd','Blythewood','SC','UNITED STATES','29016-9677','(803) 467-1442','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 15:47:57',0,NULL,3,1,1,1,'LK190097643CN\r ',NULL),(21362,840195225011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','fingam','framagni@gmail.com','Francesco Magni','c/o Sagres Securities SA<br>Via Balestra 17','Lugano','TI','SWITZERLAND','6900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:06:03',0,NULL,3,1,22,1,'BJ01712769\r ','MOAP001 '),(21363,930361243012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*2',52.99,'eastar4uk','norflyfisherman72','john@siktedukfabrikken.no','John Anders Hagen','Soleieveien 8','Namsos','Nord Trondelag','NORWAY','7800','(0047) 99317895','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:10:55',0,NULL,3,1,21,1,'RA184529132CN\r ','GLOT001*2 '),(21364,618552113003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','evbill','wwblount@bigfoot.com','William Blount','15411 Lahser Rd','Detroit','MI','UNITED STATES','48223','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-07 16:42:17',0,NULL,3,1,1,1,'LK192605649CN\r ',NULL),(21365,678548887013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','shicobie','tommyloftis1@gmail.com','Tommy Loftis','10370 Blackwell Rd','Central Point','OR','UNITED STATES','97502-9659','(541) 890-1115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 16:50:42',0,NULL,3,1,1,1,'LK193124731CN\r ',NULL),(21366,840217179011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','camilomarin','pollitomarin@hotmail.com','Camilo Marin','3640 Valley Creek Dr','Flowery Branch','GA','UNITED STATES','30542-3093','(770) 561-8039','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 16:54:58',0,NULL,3,1,1,1,'LK194823099CN\r ',NULL),(21367,678554541013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',37.98,'eastar4','romoles','sla@mail.ru','Vyacheslav Almazov','Beloborodova, 2k2, 105','Mytishchi','Moscow','RUSSIAN FEDERATION','141006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 17:10:31',0,NULL,3,1,11,1,'BJ01712779\r ','WLIN014 \r一共买了两个'),(21368,678559421013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','lamirajka','o.tumarova@yandex.ru','olqa tumarova','R. Rustamov st, 54 app. 30','Baku','absheron','AZERBAIJAN','az 1118','0124213004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 17:19:43',0,NULL,3,1,11,1,'BJ01712782\r ','UM00009 \r黑底七色边彩虹伞 '),(21369,785319795007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','care4yourit','accounts@care4yourit.co.uk','Care 4 Your IT Ltd','43 Dellfield Avenue<br>Birchwood','Lincoln','Lincolnshire','UNITED KINGDOM','LN6 0PR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 17:30:56',0,NULL,3,1,11,1,'BJ01712768\r ','RCLO007+POLO001+RCLO008*4 '),(21370,840244966011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','texteal','texlaps@yahoo.com','Nicole Lapeyrolerie','1106 Willowbrook Dr','Cedar Park','TX','UNITED STATES','78613-3698','(512) 259-2417','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 17:52:14',0,NULL,3,1,1,1,'LK191340199CN\r ',NULL),(21371,678572019013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','tusmila','kaosbrutal@gmail.com','Carles Lorenzo Ampurdanes','c/ Enric Prat de la Riba, 229 4º 1 ª','L\'Hospitalet','Cataluña','SPAIN','08901','629505189','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 17:55:35',0,NULL,3,1,2,1,'30120711003\r ',NULL),(21372,678573106013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','odnetdesign_1a','o.donnet@vtxnet.ch','Olivier Donnet','Bois de la fontaine 9','Lausanne','','SWITZERLAND','1007','0041762892465','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 17:59:53',0,NULL,3,1,22,1,'BJ01712777\r ','HSNO019\r欧标 '),(21373,794136561001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','bruno_falcon2012','bruno_falcon@terra.com.br','Barbara Betania','Rua:Rubens Golçalves de Fretitas  N 591','Praia Grande','São Paulo','BRAZIL','11703-130',' 34711346','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-07 18:07:33',0,NULL,3,1,3,1,'RA184529089CN\r ','GPS0006 '),(21374,930438376012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','ed20090_1','ercarson@verizon.net','Ed Carson','18876 Shoshonee Rd','Apple Valley','CA','UNITED STATES','92307-5909','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 18:35:37',0,NULL,3,1,1,1,'LK189432974CN\r ','HBPH007 '),(21375,623923061004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','samo939','karstenbang@gmail.com','Karsten Bang','Præstebakken 6 1.vh. Lejlighed 922','Esbjerg','','DENMARK','6700','+4531951680','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 18:36:28',0,NULL,3,1,21,1,'RA184529101CN\r ','BALO007 '),(21376,930483887012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','ncc3360','ncc3360@yahoo.co.uk','kate threlfall','c/o lower courtsmoor<br>church stanton','taunton','Somerset','UNITED KINGDOM','TA3 7QQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 19:42:00',0,NULL,3,1,3,1,'RA184533724CN\r ','HSJA010 英标 '),(21377,777166959008,180794745292,'Brand new HP MCE Media Center Remote Control + IR RECEIVER+IR Emitter',1,'OTHP003',19.86,'au-buy','frr792','heybuhay@gmail.com','John  Buhay','60 Madison Ave<br>Fl 3','New York','NY','UNITED STATES','10010-1620','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 20:01:16',0,NULL,3,1,1,1,'LK192011367CN\r ',NULL),(21378,678629384013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',2,'TRTT002*10',170,'eastar4','alau4379','amelie.laurent@clg.qc.ca','Amelie Laurent','100, rue Duquet','Ste-Therese','QC','CANADA','J7E 3G6','(450) 430-3120 ext.: 2801','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 20:17:06',0,NULL,3,1,3,1,'RA184529234CN\r ','TRTT002 *10\r'),(21379,678648119013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',39.96,'eastar4','jankespol','lkoscielniak@gmail.com','Lukasz Koscielniak','233 Lasswade Road','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH16 6QT','07704586396','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 20:53:56',0,NULL,3,1,11,1,'BJ01712775\r ','CASS001\rCAB-SS-2626'),(21380,930534416012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','usserymansfield111','royalpestcontrol@yahoo.com','Stephen Ussery','2607 N Main St','Blanchard','OK','UNITED STATES','73010','(405) 485-3220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 20:57:51',0,NULL,3,1,1,1,'LK193692953CN\r ',''),(21381,928323126012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','troutwife','andybartlett@live.co.uk','andy bartlett','6 beaufort close<br>bedgrove','aylesbury','Buckinghamshire','UNITED KINGDOM','hp219bb','01296421860','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 21:12:35',0,NULL,3,1,3,1,'RA184529146CN\r ','GLOT001*2 '),(21382,678658940013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','aeromedic1','bellilint1@hotmail.com','Aaron Campeau','3717 Wildwood Dr.','windsor','ON','CANADA','n8r2b4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 21:21:30',0,NULL,3,1,3,1,'RA184529177CN\r ','GLOT001*4'),(21383,930565805012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','paulod11','paulosenor@yahoo.com','paulo delgado','16804 124th ave se','Renton','WA','UNITED STATES','98058-6039','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 21:51:22',0,NULL,3,1,1,1,'LK190331329CN\r ',''),(21384,840394282011,320826634908,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',18.99,'eastar4uk','dimitur2010','dimitur_andonov@abv.bg','Dimitur Andonov ID 10450','Access Self Storage, UNIT 1345<br>19 Moorfield Road, Slyfield Ind. Est.','Guildford','Surrey','UNITED KINGDOM','GU1 1RU','3598 88626915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 22:07:54',0,NULL,3,1,3,1,' RA184529512CN\r','OTGR006 '),(21385,618674994003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','chubbyfatazn','brianj.chow@yahoo.com','Brian Chow','2529 Rio Grande St<br>Apt 56','Austin','TX','UNITED STATES','78705-4510','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-07 22:15:05',0,NULL,3,1,1,1,'LK194386858CN\r ',NULL),(21386,794263864001,110807072617,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',35.99,'buysia','nuudeli2010','aake.montonen@kymp.net','Aake Montonen','Saksalanraitti 122','Kotka','Kotka','FINLAND','48810','+358407232056','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-07 22:04:07',0,NULL,3,1,22,1,'BJ01712772\r ','CC00002 '),(21387,930590428012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','blueorchid630','d.stanley940@ntlworld.com','DAWN PETRIE','31 HILTONS FARM CLOSE, AUDENSHAW','MANCHESTER','Greater Manchester','UNITED KINGDOM','M345JP','01612850893','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 22:37:56',0,NULL,3,1,3,1,'RA184529044CN\r ','HSJA002 英标 '),(21388,678688018013,230678127185,'New SAMSUNG SSG-3700CR Rechargeable 3D Glasses',1,'GLSG008',152.99,'eastar4','nowel777','nowel_66@hotmail.com','Jean-François Noel','57 Brossard','Saint-Constant','QC','CANADA','j5a 0a7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 22:44:13',0,NULL,3,1,3,1,'RA184529163CN\r ','GLSG008'),(21389,618689923003,130554588921,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',54.99,'cnfaner','badboys1964','badboysfireman@videotron.ca','Pierre Desrochers','700 Paul-Doyon','Boucherville','QC','CANADA','J4B8N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 23:06:54',0,NULL,3,1,3,1,'RA184519016CN\r ','KBFF001 '),(21390,785499694007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.34,'au-buy','kungfumonkeyslayer','pod451@hotmail.com','James Lever','25 Rutland Road','Hove','East Sussex','UNITED KINGDOM','BN3 5FF','01273327366','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 23:16:57',0,NULL,3,1,11,1,'BJ01712771\r ','RCLO007+POLO001+RCLO008*4 '),(21391,624030711004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','osna-man','osnaman81@freenet.de','Benjamin Latusek','An der Bahn 2a','Melle','','GERMANY','49324','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 23:41:15',0,NULL,3,1,21,1,'RA184529061CN\r ','MOOE001\rOEM '),(21392,777280984008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',20.89,'au-buy','bellarue07','kellijones070@gmail.com','Kelli Jones','42 Wayford Circle','Hocking','Western Australia','AUSTRALIA','6065','61892065758','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 00:08:32',0,NULL,3,1,11,1,'BJ01712784\r ','UM00043 '),(21393,930627380012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','5402steve','sjm42@tpg.com.au','Steve Matthews','25 Lomatia Street <br>Everton Hills','Brisbane','Queensland','AUSTRALIA','4053','0733550762','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 00:11:44',0,NULL,3,1,3,1,'RA184529194CN\r ','GLOT001*2'),(21394,840448892011,320735039422,'New HP Media Center receiver+microsoft Remote Control',1,'OTHP006',20.9,'eastar4','astrapak5630','astrapak@gmail.com','Jerome Pirlet','10 Rue du pont rouge','Senzeilles','','BELGIUM','5630','00324983045','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 00:34:47',0,NULL,3,1,22,1,'BJ01712778\r ','OTHP006'),(21395,678723179013,230613960519,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',81.9,'eastar4','ciclopsstudio','leonardocaminha@hotmail.com','leonardo caminha','Rua das ninfas #189 Ap.1502<br>Boa Vista','Recife','Pernambuco','BRAZIL','50070-050','(558) 199-7443 ext.: 81','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 01:04:52',0,NULL,3,1,3,1,'RA184529251CN\r ','OTES001'),(21396,840463622011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','carrotslovetomatoes','julie.m.bann@gmail.com','Julie Bannister','5 Cold Spring Ln','East Falmouth','MA','UNITED STATES','02536-4775','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 01:24:50',0,NULL,3,1,1,1,'LK189783454CN\r ',''),(21397,930650072012,220502385280,'New 2.1 Bluetooth Module for Gateway P-7811 7805U 7801U',1,'BTGA2101',12.39,'eastar4','digiancidade','digitronic_engenheiro@hotmail.com','Digian Cidade','Rua São Paulo, 752, Vila Becker<br>Rua Tiradentes, 70, Vila Becker','Dois Irmãos','Rio Grande do Sul','BRAZIL','93950000','55196835768','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 01:25:33',0,NULL,3,1,11,1,'BJ01712780\r ','BTGA2101\r记得告诉客户号'),(21398,930658433012,220782958082,'New Jabra BT135 BT 135 wireless Bluetooth Headset',1,'HSJA007',14.85,'eastar4','headhuntermike','mikehansen47@live.com','mike Hansen','39710 145th st','Stratford','SD','UNITED STATES','57474-7103','(605) 395-7435','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 01:45:56',0,NULL,3,1,1,1,'LK191483379CN\r ',''),(21399,930659598012,220872377067,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',69.99,'eastar4uk','zlud4809','vissie87@hotmail.com','zach ludovissie','518 5th street ne','staples','MN','UNITED STATES','56479','(218) 895-6311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 01:47:50',0,NULL,3,1,1,1,'LK194198789CN\r ',NULL),(21400,8881328665942835,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 for Apple ',1,'MOAP001',27.99,'aliexpress','1006637993','1@1.com','Peter Kamm','Hasenweg 19 ','	Steffisburg','BE','SWITZERLAND','3613','',NULL,NULL,NULL,'2012-02-08 01:52:22',0,NULL,5,1,18,0,NULL,'MOAP001 \r申报为computer mouse \r申报28USD\r地址错了 已重新填写订单'),(21401,930661822012,220708784028,'New IBM Atheros AR5BXB6 AR5424 Wireless MINI PCI-E Card',1,'WLAT005',9.89,'eastar4','ljscott1990','mafia.emu@gmail.com','Lewis Scott','7 Dalwood Pl','Mount Annan','New South Wales','AUSTRALIA','2567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 01:55:49',0,NULL,3,1,2,1,'30120709360\r ','WLAT005'),(21402,624059831004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',25.5,'cnfaner','skayslund','slundgren01@sbcglobal.net','Sandra Lundgren','4002 Steeplechase Dr','Colleyville','TX','UNITED STATES','76034','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-08 01:56:03',0,NULL,3,1,1,1,'LK191851263CN\r ',NULL),(21403,618726930003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','gboyp','etoile1026@hotmail.com','Brian Oh','4956 Topcrest Dr','South Jordan','UT','UNITED STATES','84095-8793','(801) 979-9111','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-08 01:58:43',0,NULL,3,1,1,1,'LK194783219CN\r ','OEM '),(21404,618736237003,130458926917,'NEW ULTIMATE EARS METRO.FI 220 EARPHONE UE220 track#',1,'HSUE002',18.99,'cnfaner','antsburger','ants087@yahoo.com','Anthony Nguyen','141 Harvard St','Quincy','MA','UNITED STATES','02170-1105','(781) 300-1549','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-08 02:39:52',0,NULL,3,1,1,1,'LK185532610CN\r ','cnfaner'),(21405,840488562011,320735039422,'New HP Media Center receiver+microsoft Remote Control',2,'OTHP006',41.8,'eastar4','darkmage32','andrewj@kempe.com.au','Andrew Jackman C/- DynamicFit Pty Ltd','Level 2/22 Malop Street','Geelong','Victoria','AUSTRALIA','3220','0352252900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 02:40:57',0,NULL,3,1,3,1,'RA184529027CN\r ','OTHP006'),(21406,8881328669019426,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',2,'UM00008',49.98,'aliexpress','1006637115','1@1.com','Anna Matveenko','10 line, 23 - 1 ','Saint-Petersburg','Russia','RUSSIAN FEDERATION','199178','	+7 921 7431195',NULL,NULL,NULL,'2012-02-08 02:43:39',0,NULL,3,1,3,1,'RA184538718CN\r ','UM00008\rr_78@list.ru\r\r'),(21407,8881328669152326,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 for Apple - ',1,'MOAP001',27.99,'aliexpress','1006637993','1@1.com','Peter Kamm','Hasenweg 19 ','Steffisburg','BE','SWITZERLAND','3613','+0041 33 4381838',NULL,NULL,NULL,'2012-02-08 02:45:52',0,NULL,3,1,21,1,'RA184538823CN\r ','MOAP001   \rpkamm@gmx.ch\r申报为computer mouse \r申报28USD \r'),(21408,930137023012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','abennyben','abennyben@hotmail.com','Benjamin Williams','1022 Lowood/Minden Road','Minden','Queensland','AUSTRALIA','4311','0754268308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 03:05:32',0,NULL,3,1,11,1,'BJ01712785\r ','eastar4'),(21409,8881328670704926,111,'New Sony Ericsson HBH-DS970 Bluetooth headset HBH DS 970+AC adapter',1,'HSSE010',0,'au-buy','grisu_ii','lohmann.la@web.de','Jörg Lohmann','PostNummer 37557030<br>Packstation 101','Lampertheim','','GERMANY','68623','',NULL,NULL,NULL,'2012-02-08 03:11:44',0,NULL,3,1,21,1,'RA184533980CN ','HSSE010\r补发的\r换新地址\rJörg Lohmann\rEuroparing 28\rD-68623 Lampertheim\rGermany\r'),(21410,785571825007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',18.9,'au-buy','thaisy48','handy48@hotmail.com','Duc Nghia Duong','16 The Avenue<br>Caroline Springs','Melbourne','Victoria','AUSTRALIA','3023','0403139709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 03:15:46',0,NULL,3,1,3,1,'BJ01715715\r\r','OTGR001\rau-buy'),(21411,783053008007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.38,'au-buy','bluemountain2','gongxindi@gmail.com','Xindi Gong','17/10A  Mears  Ave','Randwick','New South Wales','AUSTRALIA','2031','0432511514','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 03:56:59',0,NULL,3,1,11,1,'BJ01712789\r ','RELO003\rau-buy'),(21412,785583443007,170762819424,'Brand new HP MCE Media Center + microsoft Remote Control + IR RECEIVER',1,'OTHP006',19.86,'au-buy','jd_desha47','desha47@hotmail.com','Jean Deschanel','8 Rylah Crescent<br>Wanniassa','Canberra','Australian Capital Territory','AUSTRALIA','2903','0422503664','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 04:02:49',0,NULL,3,1,11,1,'BJ01669406\r ','OTHP006\rau-buy'),(21413,840548382011,320820750152,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook',1,'HSNO034',14.99,'eastar4','retul','yuriy.p@bk.ru','Dmitriy Stepanov','Sakko i Vancetti 4-43','Korolev','Moscovskaya oblast','RUSSIAN FEDERATION','141078','+79110139175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 06:49:46',0,NULL,3,1,11,1,'BJ01712786\r ','eastar4\rHSNO034\r欧标'),(21414,678797808013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','peterpicard256','picard@spin.net.au','Peter Dorrell','2/17 Wenwood Street','Ringwood East','Victoria','AUSTRALIA','3135','0398798103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 07:37:30',0,NULL,3,1,3,1,'RA184529248CN\r ','eastar4\rGLOT005'),(21415,840565155011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','big-duke-six72','craig@seaton16.fsnet.co.uk','craig Seaton','12 Burns Begg Cres','Balfron','Stirlingshire','UNITED KINGDOM','G630NR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 08:07:29',0,NULL,3,1,3,1,'RA184538868CN\r ','GLOT001*2\reastar4uk'),(21416,840577060011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','ch157','krall1@iprimus.com.au','Craig Horton','157 Eglinton Crescent<br>Hamersley','Perth','Western Australia','AUSTRALIA','6022','0894473190','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 08:58:09',0,NULL,3,1,3,1,'RA184538908CN\r ','MOAP001\reastar4uk'),(21417,930774685012,220815928722,'Logitech MX Revolution Cordless Wireless Laser Mouse',1,'MOLO006',17.89,'eastar4uk','bluecookie2004','ray@raymondcook.net','Ray Cook','95 Randale Drive','Bury','Lancashire','UNITED KINGDOM','BL98NF','01617966350','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 09:05:04',0,NULL,3,1,3,1,'RA184538810CN\r ','MOLO006\reastar4uk'),(21418,840582673011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ccbthealthcareonline','juneupton@ccbt.co.uk','June Upton','14 Edward Street<br>Tudor Court','Birmingham','West Midlands','UNITED KINGDOM','B1 2RX','1212332873','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 09:19:01',0,NULL,3,1,3,1,'RA184538766CN\r ','RELO003\reastar4uk'),(21419,930781666012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','minvarin','smmannasz@optusnet.com.au','Michael Mannasz','28 Fifth Avenue','Denistone','New South Wales','AUSTRALIA','2114','0430222768','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 09:30:06',0,NULL,3,1,3,1,'RA184533738CN\r ','eastar4\rGLOT001'),(21420,930793854012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','traci0071','tracih@aanet.com.au','Traci Harding','45 St Albans Rd','Wisemans Ferry','New South Wales','AUSTRALIA','2775','0245664469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 10:10:41',0,NULL,3,1,11,1,'BJ01712795\r ','eastar4\rUM00008'),(21421,776928845008,180810778720,'4 pairs of  New in box 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001*4',175.99,'au-buy','bjalweyn','bjalweyn@hotmail.com','Brant Alweyn','11 Gerovich Way<br>SPEARWOOD','Perth','Western Australia','AUSTRALIA','6163','0894349443','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 10:19:02',0,NULL,3,1,3,1,'RA184538806CN\r ','GLOT001*4\rau-buy'),(21422,930802416012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','zuza1970','ebay@m-it.pl','Ewa Polecińska','Długa 158A','Borowa Góra','mazowieckie','POLAND','05-140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 10:38:04',0,NULL,3,1,11,1,'BJ01712794\r ','eastar4\rCASS003\rCAB-6060'),(21423,840339348011,320791295540,'NIB Mini Spy Vehicle Realtime Tracker GSM GPRS GPS System Tracking  TK103-2',1,'GPS0008',111.99,'eastar4','matyuha2007','olehmudrak@gmail.com','Oleh Mudrak','Kolodyazna, 4/128','Mykolayiv','','UKRAINE','54003','+380675101941','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 10:50:54',0,NULL,3,1,21,1,'RA184538845CN\r ','eastar4\rGPS0008'),(21424,840648700011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','ricknason','rick@nason.me.uk','Richard Nason','53, St. Austell Avenue','Macclesfield','Cheshire','UNITED KINGDOM','SK10 3NN','01625432991','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 12:54:45',0,NULL,3,1,3,1,'RA184538770CN\r ','WLDE001\reastar4uk'),(21425,840653861011,320814026443,'NIB Genuine LG Premium Water Filter Gen11042FR-08 for Kenmore LG refrigerators',2,'LGFI001',103.98,'eastar4','ricardo8921','ricardo_minnesota@hotmail.com','Ricardo Barroso Camara','Rua Clovis Machado 215 apt 501','Vitoria','Espirito Santo','BRAZIL','29050-585','55 27 98995268','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 13:12:32',0,NULL,3,1,3,1,'RA184538837CN\r ','eastar4\rLGFI001'),(21426,624184133004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',54.7,'cnfaner','robifleur','m.tamas@freemail.hu','Tamas Mikola','Bocskai ut 75. 3/33','Budapest','','HUNGARY','1113','06204217748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 13:15:40',0,NULL,3,1,21,1,'RA184533675CN\r ','cnfaner\rGLOT005'),(21427,840637131011,320786773698,'New iTech Clip II mini Multipoint Bluetooth Headset black',1,'HSIT002',21.99,'eastar4uk','rafto9','georgerafto99@gmail.com','Γιώργος Ραφτόπουλος','Αγίου Γεωργίου παστίδα<br>Ρόδος','Ρόδος','προεπιλογή','GREECE','85106','2241047778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 13:50:31',0,NULL,3,1,22,1,'BJ01669374\r ','HSIT002  \r欧标\reastar4uk'),(21428,678875097013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','larisa110690','wokoladka6@yandex.ru','Larisa Pribylovskaya','Popova Street, 17-10<br>-','Mytyschi','Moskovskaja oblast\'','RUSSIAN FEDERATION','141007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 13:50:40',0,NULL,3,1,11,1,'BJ01712792\r ','eastar4\rUM00042'),(21429,930897691012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','1ski53','ken.kawahara@verizon.net','Kenneth Kawahara','1808 Harvest Ln','Camarillo','CA','UNITED STATES','93012-4213','(310) 944-0371','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 14:55:48',0,NULL,3,1,1,1,'LK193929155CN\r ','eastar4'),(21430,618177239003,130603400330,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',5.9,'cnfaner','tim_carter81','tmc@city-office.com','Troels Christensen','5 Independence Way<br>Ste 300','Princeton','NJ','UNITED STATES','08540-6627','(609) 514-5100','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-08 15:49:02',0,NULL,3,1,1,1,'LK194106955CN\r ','cnfaner'),(21431,840747834011,320800724933,'4 pairs 3D Active shutter Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 16:57:52',0,NULL,3,1,21,1,'RA184538797CN\r ','GLOT001*4\reastar4uk\r申报为gift 申报低于20￥'),(21432,678986090013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','janupollo','ogg@bk.ru','Ian Gorboun','Rustaveli, 2-25','St. Petersburg','','RUSSIAN FEDERATION','195273','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 19:16:29',0,NULL,3,1,11,1,'BJ01712790\r ','eastar4\rHSNO019\r欧标'),(21433,794688396001,110822404368,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',37.98,'buysia','pededive','mpede@aol.com','Peter Königer','Julius-Leber-Str. 31','Aalen','','GERMANY','73430','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-08 20:12:22',0,NULL,3,1,21,1,'RA184538899CN\r ','buysia\rHSNO035\r欧标'),(21434,679016226013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',2,'WLIN010',38.98,'eastar4','dot1q','timothybryandennehy@yahoo.com','Timothy Dennehy','19 Overhill Rd','Mill Valley','CA','UNITED STATES','94941-1361','(785) 615-1370','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 20:22:42',0,NULL,3,1,1,1,'LK193864344CN\r ','eastar4'),(21435,679023252013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','alexus6400','alexus@takas.lt','Aleksas Štutas','S. Daukanto 24a','Klaipeda','','LITHUANIA','LT-92124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 20:38:26',0,NULL,3,1,22,1,'BJ01712788\r ','eastar4\rCACN004'),(21436,931102866012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','gurvarun89','gurvarun.singh@gmail.com','Gurvarun Singh','280 West 2nd Street','Hamilton','ON','CANADA','L9C 3G8','(289) 689-4688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 20:56:43',0,NULL,3,1,11,1,'BJ01712787\r ','eastar4\rHSNO005'),(21437,931117017012,220759518448,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',10.8,'eastar4uk','giamgaj','giamgaj@earthlink.net','Carl Hosoda','3802 Ezie St','San Jose','CA','UNITED STATES','95111-3512','(408) 593-1617','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 21:17:21',0,NULL,3,1,1,1,'LK194941952CN\r ','eastar4uk'),(21438,619009278003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','desdicado7','gobla2@gmail.com','Oystein Hogset','Heggeveien 7','Drammen','','NORWAY','3043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 21:25:39',0,NULL,3,1,21,1,'RA184538854CN\r ','cnfaner\rMOLO006'),(21439,678990212013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','hvyardsales','hvyards@yahoo.com','Robert Norris','105 Hone St','Kingston','NY','UNITED STATES','12401-6334','(845) 901-2999','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 21:37:23',0,NULL,3,1,1,1,'LK190177718CN\r ','eastar4\r'),(21440,839045126002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','doltheadz','allanv@rogers.com','Allan Versaevel','920 Lincoln Drive','Woodstock','ON','CANADA','N4S 2N3','(519) 539-4322','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-08 21:54:03',0,NULL,3,1,3,1,'RA184519245CN\r ','buysia\rMOLO001'),(21441,931141130012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','mdhice','mdhice@charter.net','Debra L Hice','7168 Knobs Lndg','Connellys Springs','NC','UNITED STATES','28612','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 21:59:17',0,NULL,3,1,1,1,'LK188969545CN\r ','eastar4'),(21442,931164888012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','fikibird','fikibird@yahoo.com','Carolyn Stearns','216 Amapola Circle','Terrytown','LA','UNITED STATES','70056','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 22:47:48',0,NULL,3,1,1,1,'LK193155226CN\r ','eastar4'),(21443,624377856004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.88,'cnfaner','fredex203','frede203@hotmail.com','carlos frederico Soares','Visconde de figueiredo n:48<br>Apto:102','Rio de janeiro','Rio de Janeiro','BRAZIL','20550050','+55 21 94164255','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 22:47:50',0,NULL,3,1,3,1,'RA184533707CN\r ','cnfaner\rHSNO022\r美标'),(21444,624376624004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32,'cnfaner','espinete80','espi37@terra.es','SANTIAGO LORENZO BORDA','C/ PORTUTXO Nº3, 1ºA','ASTIGARRAGA','País Vasco','SPAIN','20115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 23:02:45',0,NULL,3,1,21,1,'RA184538783CN\r ','cnfaner\rGPS0010'),(21445,840953470011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','studio_gear_sales','brattwell@gmail.com','Rory Attwell','13B Brent House<br>Brenthouse Road','London','London','UNITED KINGDOM','E9 6QQ','07904325736','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 23:12:32',0,NULL,3,1,3,1,'RA184538871CN\r ','MOAP001\reastar4uk'),(21446,677417806013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','gugutse','abarbalat@sbcglobal.net','alex barbalat','253 arrowhead way','hayward','CA','UNITED STATES','94544-6649','(650) 520-7246','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 23:23:15',0,NULL,3,1,1,1,'LK193727799CN\r ','eastar4'),(21447,840965385011,320791705383,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',37.99,'eastar4uk','erdingtonjohn','j.lambert@tswc.co.uk','Jayne Phelan','174 Brantley road<br>Aston','Birmingham','EN','UNITED KINGDOM','B6 7DP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 23:46:38',0,NULL,3,1,3,1,'RA184533755CN\r ','GPS0006\reastar4uk'),(21448,624394058004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','76deldave','davidsonlinepurchase@comcast.net','David Agnew','76 Cypress Tree Circle<br>Timberlane','Newark','DE','UNITED STATES','19702','(302) 367-5061','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-08 23:56:12',0,NULL,3,1,1,1,'LK190355206CN\r ','cnfaner'),(21449,840978267011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',27.96,'eastar4','vardanarm','sevw@yandex.ru','Vardan Manukyan','st. G. Njde 13/1 ap. 4','Yerevan','Yerevan','ARMENIA','374','+37493443907','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 00:25:39',0,NULL,3,1,22,1,'BJ01712796\r ','eastar4\rHSNO007+HSNO008\r再发一个NEW GENUINE NOKIA BH-204\r'),(21450,931206504012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','4drfocus','rdracrlw@yahoo.com','phillip munson','3201 Marcella Dr<br>null','salina','KS','UNITED STATES','67401-8989','(785) 787-9144','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 00:37:28',0,NULL,3,1,1,1,'LK192368366CN\r ','eastar4'),(21451,840989391011,320441946530,'2.1 HP mini 2133 2140 Bluetooth Module EDR + cable',1,'BTHP2101',12.39,'eastar4','ritarded09','synper311@aol.com','Brett Carlock','108 Oak Mills Xing','West Henrietta','NY','UNITED STATES','14586-9002','(908) 803-3256','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 01:01:27',0,NULL,3,1,1,1,'LK194710582CN\r ','eastar4\rHP 8pin 1.0 3cm'),(21452,931218511012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',91.99,'eastar4','hornofamalthea','mike_hagenson@yahoo.com','Jon Hagenson','650 E Bonita Ave<br>Apt 603','San Dimas','CA','UNITED STATES','91773-2748','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 01:13:10',0,NULL,3,1,1,1,'LK186811071CN\r ','eastar4'),(21453,841002536011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','rosh1984','ronan_jones@hotmail.com','Roshan Balgobin','Koh-I-Noor<br>Station Road','Sutton Weaver','Cheshire','UNITED KINGDOM','WA7 3EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 01:44:50',0,NULL,3,1,3,1,'RA184533667CN\r ','GLOT001\reastar4uk'),(21461,794873025001,110822404368,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',37.98,'buysia','bmssomeluz','toninhosomeluz@hotmail.com','Antonio Arcanjo','Rua General Alcoforado 561','Campo Grande','Mato Grosso Do Sul','BRAZIL','79081160','(+55) 3346-6446','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-09 05:41:34',0,NULL,3,1,3,1,'RA184533698CN\r ','buysia\rHSNO035\r美标'),(21454,8881328753276336,111,'Free shipping & Tracking - AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV - ',1,'LGRM001',44.99,'aliexpress','1006661687','marcos-avelar@hotmail.com','Marcos Avelar','Dr Odecio Roland, 630 jd. Santo Andre ','Limeira','Sao Paulo','BRAZIL','13484120','+55 19 81945369',NULL,NULL,NULL,'2012-02-09 02:07:56',0,NULL,3,1,3,1,'RA184538735CN ','LGRM001 \raliexpress'),(21455,841022670011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',3,'CASS002',29.97,'eastar4','jonlundy','jon@xuu.cc','Jon Lundy','228 W 600 N<br>Apt 7','Salt Lake City','UT','UNITED STATES','84103-1300','(801) 556-8904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 02:46:40',0,NULL,3,1,1,1,'LK192897156CN\r ','eastar4'),(21456,619092785003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','jhamilt4','icanthinkofone@hotmail.com','Jason Hamilton','700 - 2380 Baseline Rd','Nepean','ON','CANADA','K2C 3J4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 03:17:07',0,NULL,3,1,3,1,'RA184538885CN\r ','cnfaner\rMOLO006'),(21457,8881328759417295,111,'HP MCE Media Center Remote Control+ IR emitte ',1,'OTHP004',5,'eastar4uk','paulobarreiros','paulo.a.barreiros@gmail.com','Paulo Barreiros','Rua Ferreira de Castro, 22 Esq','Evora','Evora','PORTUGAL','7005-488','+351917745068',NULL,NULL,NULL,'2012-02-09 03:50:17',0,NULL,3,1,21,1,'RA184533432CN ','OTHP004\rNew HP MCE Media Center Remote Control big+ IR RECEVE'),(21459,786084348007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','shahaamawan','shahaam@gmail.com','Shair A Awan','9 Circuit Drive','Hendon','South Australia','AUSTRALIA','5014','0882682033','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 04:19:10',0,NULL,3,1,11,1,'BJ01712793\r ','au-buy\rRELO002'),(21458,931270572012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','willushutup','grainum@gmail.com','Brian Carney','2048 Holly St','Denver','CO','UNITED STATES','80207-3841','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 03:52:53',0,NULL,3,1,1,1,'LK192003238CN\r ','eastar4'),(21460,931278413012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','carnevil09','jas2061461@maricopa.edu','Jason Cole','6002 W Tonopah Dr','Glendale','AZ','UNITED STATES','85308-6710','(623) 521-1528','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 04:22:59',0,NULL,3,1,1,1,'LK189882797CN\r ','eastar4\rAUI Transceiver  MX20T'),(21462,8881328767441959,111,'BH-904 and BH-900',1,'',117.97,'eastar4','jamestaylor_nz','stephen_jeep@msn.com','James Taylor','23 Arawa St','Andersons Bay ','Dunedin','NEW ZEALAND ','9012','',NULL,NULL,NULL,'2012-02-09 06:04:01',0,NULL,3,0,3,1,'RA184533684CN\r ','eastar4\rHSNO019+HSNO035\r一共买了 一个新的NOKIA BH-904   一个新的NOKIA BH-900\r已入库 直接打款'),(21463,619120666003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','delaisladalila2012','delaisladalila@yahoo.com','dalila de la Isla','4641 cedarwood way','Sacramento','CA','UNITED STATES','95823-3706','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-09 06:27:08',0,NULL,3,1,1,1,'LK193500260CN\r ','cnfaner'),(21464,786129239007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','sbastien5932','delsebman@free.fr','Sébastien Coopman','22 et 24 rue du Capitaine Picavet','LEERS','Nord-Pas-de-Calais','FRANCE','59115','0320550347','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 08:02:00',0,NULL,3,1,11,1,'BJ01712798\r ','au-buy\rRCLO007+POLO001+RCLO008*4'),(21465,679190212013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',5.98,'eastar4','jamblist','grose.james@gmail.com','James Grose','82 Asling Street','Brighton','Victoria','AUSTRALIA','3186','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 08:57:38',0,NULL,3,1,11,1,'BJ01712799\r ','eastar4\rOTCN001'),(21466,841106081011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sarveshmenon','jscmenon@yahoo.com.au','Sarvesh Janardhanan','40/21-29 Third Ave','Blacktown','New South Wales','AUSTRALIA','2148','020422125453','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 08:59:06',0,NULL,3,1,11,1,'BJ01712800\r ','eastar4\rHSJA002'),(21467,841111742011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','leoncartledge','leon_mish@iprimus.com.au','Leon Cartledge','20 Second Ave','Bridgewater','South Australia','AUSTRALIA','5155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 09:20:13',0,NULL,3,1,3,1,'RA184533809CN ','eastar4\rLGRM001'),(21468,931350525012,220828314408,'GPS USB receiver w/SIRF3 chip sets +antenna',1,'GPS0001',45.99,'eastar4','locutox','lytyx@iinet.net.au','Ryan Thompson','68 Kent St','Minto','New South Wales','AUSTRALIA','2566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 09:38:47',0,NULL,3,1,3,1,' RA184529574CN\r','eastar4\rGPS0001'),(21469,679200254013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','yaburan','bu_ran@mail.ru','Андрей Бурцев','Цимлянская, 28, 170','Москва','Россия','RUSSIAN FEDERATION','109559','(495) 3599586','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 09:54:19',0,NULL,3,1,11,1,'、 ','eastar4\rCACN004'),(21470,786157584007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',2,'CC00002',71.98,'au-buy','inozzie','winsum7@bigpond.com','Lisa Chawner','8 Cassegrain cl','Eleebana','New South Wales','AUSTRALIA','2282','0249468080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 10:03:49',0,NULL,3,1,3,1,'RA184519055CN\r ','au-buy\rCC00002'),(21471,619154764003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',87.99,'cnfaner','pablo_kam','scratchgo@gmail.com','Pavlo Kaminskij','Zhmerinskaja 36/194','Kyiv','','UKRAINE','03148','380638592008','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 10:09:38',0,NULL,3,1,21,1,'RA184519047CN\r ','cnfaner\rGLOT001*2'),(21472,931365817012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','sammywhiskas','richard.hopewell@sky.com','RICHARD HOPEWELL','2<br>THE CRESCENT','NEWARK','Nottinghamshire','UNITED KINGDOM','NG244DU','07885221122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 10:31:45',0,NULL,3,1,2,1,'30120960682\r ','eastar4\rBTAC2013\racer 5pin1.25 15cm'),(21473,931370498012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','tention66626','wesley_smith_1993@hotmail.co.uk','wesley smith','107 woodward Road','Dagenham','Essex','UNITED KINGDOM','RM9 4ST','02085170566','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 10:47:21',0,NULL,3,1,3,1,'RA184538678CN ','eastar4uk\r英标\rHSJA002'),(21474,841138363011,320730084340,'GENUINE NOKIA HS-36W BLUETOOTH HEADSET',1,'HSNO026',10.4,'eastar4uk','micklinzityler','mick.mcguckin@hotmail.com','michael mcguckin','46 oak grove<br>conisbrough','doncaster','South Yorkshire','UNITED KINGDOM','dn12 2hn','07789273508','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 11:02:03',0,NULL,3,1,3,1,'RA184538616CN ','eastar4uk\rHSNO026\r英标'),(21475,931383343012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','dystew','naomi19bradley@gmail.com','Naomi Bradley','20 Pandian Cres','Bellbowrie','Queensland','AUSTRALIA','4070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 11:29:57',0,NULL,3,0,11,1,'BJ01715708 ','eastar4\rUM00004\r已入库\r客户要换发成向日葵三折伞'),(21476,679219549013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','dotomaz','tomazd@inetis.com','Tomaz Dobrisek','Polzela 126','Polzela','/','SLOVENIA','3313','041836408','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 11:32:42',0,NULL,3,1,22,1,'、 ','eastar4\rCACN004'),(21477,619177440003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','eddiej2010','ed.j.lugo@gmail.com','Edward Lugo','2022 Atapha Nene','Tallahassee','FL','UNITED STATES','32301-5853','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-09 12:11:32',0,NULL,3,1,1,1,'LK196074711CN\r ','cnfaner'),(21478,777954679008,180757094165,'New Replaceable Shell for logitech Mouse MX518  MX 518',1,'SHLO004',12.21,'au-buy','alexgabb','alexgabb@gmail.com','Alex Gabb','36 Stanfield Road<br>Great Barr','Birmingham','West Midlands','UNITED KINGDOM','B437LR','01212582339','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 12:16:20',0,NULL,3,1,11,1,'、 ','au-buy\rSHLO004'),(21479,931402364012,220815927687,'Allied Telesyn CentreCOM AUI Ethernet 10Base-T 210T',1,'TRTT002',25.86,'eastar4uk','quikpt2009','nuno.mrr@gmail.com','Nuno Reis','REGRA - Nuno Reis<br>Rua do Entreposto Industrial, n3, 1 Esquerdo','Amadora Alfragide','','PORTUGAL','2610-135','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 12:28:26',0,NULL,3,1,21,1,'RA184538752CN ','eastar4uk\r\rTRTT002+CASS002\r再发三条 CAB-2660'),(21480,619181489003,130554587045,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.49,'cnfaner','onliner.by','torrents.torrents.pir2pir@gmail.com','Hrybouski Raman','Yanki Luchiny 54-65','Minsk','','BELARUS','220112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:30:40',0,NULL,3,1,21,1,'RA184538664CN ','cnfaner\rMOMI002'),(21481,679232934013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',3,'CASS001',29.97,'eastar4','quikpt2009','nuno.mrr@gmail.com','Nuno Reis','REGRA - Nuno Reis<br>Rua do Entreposto Industrial, n3, 1 Esquerdo','Amadora Alfragide','','PORTUGAL','2610-135','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:34:49',0,NULL,3,1,22,1,'\\ ','eastar4\rCASS001\rCAB-SS-2626'),(21482,624529419004,140667905364,'NEW Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',15.99,'cnfaner','pkopt','koptilin@gmail.com','Pavel Koptilin','Dobrovolskogo 124 - 113','Odessa','','UKRAINE','65111','380501906845','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:38:34',0,NULL,3,1,21,1,'RA184533993CN ','cnfaner\rSHLO005'),(21483,929763991012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','armanchiksatenik','badkarmaa@bigmir.net','Satenik Aivazyan','62a Mayakovskovo  Str., Apt. 118','Kiev','Kiev district','UKRAINE','02222','0936574819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 13:10:15',0,NULL,3,1,22,1,'\\ ','eastar4\rOTCN005*10\r白色的'),(21484,931418878012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','spencerspark','spencerspark@msn.com','darren spencer','17 advice avenue<br>chafford hundred','grays','Essex','UNITED KINGDOM','RM16 6qn','07960777888','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 13:15:53',0,NULL,3,1,3,1,'RA184538681CN ','eastar4uk\rSAFI001'),(21485,931422722012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','yorikiriho','yorikirineo@yahoo.co.jp','Hiroshi Oshima','1629-13 Hisasue Takatsuku','Kawasaki','Kanagawa','JAPAN','2130026',' 0447985532','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 13:27:06',0,NULL,3,1,11,1,'、 ','eastar4\rOTGR002'),(21486,777992552008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.55,'au-buy','8297john','jpearson04@gmail.com','John Pearson','PO Box 194','Battery Point','Tasmania','AUSTRALIA','7004','0407569198','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 14:17:03',0,NULL,3,1,11,1,'\\ ','au-buy\rSCLO004'),(21487,931459600012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','zebi20','zebi1@o2.pl','ZBIGNIEW BRZOZOWSKI','40 LEABOURNE ROAD','CARLISLE','Cumbria','UNITED KINGDOM','CA24QL','0128596111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 14:59:52',0,NULL,3,1,3,1,'RA184538633CN ','eastar4uk\rGLOT001*2'),(21488,841221695011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','adamsa_11','adams_1898@yahoo.com','Alix  Adams','62 St Leonards Road','Hythe','Kent','UNITED KINGDOM','CT21 6HW','01303262565','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 15:06:32',0,NULL,3,1,3,1,'RA184538704CN ','eastar4uk\rMOAP001'),(21489,679283745013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','miguelito32','miguelito32@hotmail.com','Miguel Perez','75 Fort Washington Ave<br>Apt 35','new york','NY','UNITED STATES','10032-4631','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 15:53:29',0,NULL,3,1,1,1,'LK194367023CN\r ','eastar4'),(21490,619202243003,130554587233,'Logitech MX Revolution Cordless Wireless Mouse only',1,'MOLO006',24.99,'cnfaner','wonderfulgold','toigor@list.ru','Igor Cherkasov','Kavalergardskaya 3, app. 29','Saint Petersburg','','RUSSIAN FEDERATION','191015','+7 903 095 11 55','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 16:16:10',0,NULL,5,1,18,1,NULL,'cnfaner\rMOLO006\r已退款'),(21491,841035156011,320618274704,'New 3.0 Bluetooth BCM2070 Module+cable HP mini5101 5102',1,'BTHP3003',19.98,'eastar4','zappeastusa3','zappusa3@gmail.com','Andrei Third','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 16:16:43',0,NULL,3,1,1,1,'LK196097125CN\r ','eastar4\rHp 8pin1.0 3cm\r把物品编号写在包裹上320618274704'),(21492,931503742012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',29.97,'eastar4','dburn3tt62','misfit@byu.edu','David Burnett','305 E 2100 N','Provo','UT','UNITED STATES','84604-5825','(801) 373-5602','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 16:35:17',0,NULL,3,1,1,1,'LK192818215CN\r ','eastar4\rAUI Transceiver  MX20T'),(21493,841315743011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','alexey.belousov','alexey@beliy.pro','Alexey Belousov','ul. Hrustalnaya, dom 40, kv. 10','Tver\'','Tverskaya obl','RUSSIAN FEDERATION','170021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 18:31:34',0,NULL,3,1,11,1,'、 ','eastar4\rMOCN001'),(21494,841363936011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','kenneth5420','kendavies51@btinternet.com','kenneth davies','30 lodge close','orpington','Kent','UNITED KINGDOM','BR60QQ','01689834951','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 19:47:42',0,NULL,3,1,3,1,'RA184538695CN ','eastar4uk\rSAFI001*2'),(21495,841402879011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',3,'GLOT001',80.97,'eastar4uk','alkisp','alkispapp@gmail.com','ALKIVIADIS PAPPAS','LAMPRIDI 24','IOANNINA','IOANNINA','GREECE','45332','6973538588','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 20:55:10',0,NULL,3,1,21,1,'RA184538647CN ','eastar4uk\rGLOT001'),(21496,841411685011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','ug190665','uwe.grothaus@teleos-web.de','Uwe Grothaus','Grefte 41','Hille','','GERMANY','32479','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 21:04:27',0,NULL,3,1,2,1,'30120958593\r ','eastar4'),(21497,841413684011,320735039422,'New HP Media Center receiver+microsoft Remote Control',2,'OTHP006',41.8,'eastar4','rbrohman','r.brohman@rogers.com','Ryan Brohman','30 Charlotte Cres','Kitchener','ON','CANADA','N2B 2K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 21:07:08',0,NULL,3,1,3,1,' RA184529530CN\r','eastar4\rOTHP006'),(21498,931668179012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','iprocure2k3','tomlu_usa@yahoo.com','Cesar Torres','3475 N Country Club Dr<br>Apt 601','Miami','FL','UNITED STATES','33180-1725','(404) 826-9703','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 21:10:36',0,NULL,3,1,1,1,'LK193913487CN\r ','eastar4'),(21499,841413468011,320844193480,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',216,'eastar4uk','johnrohan','john.rohan@btinternet.com','John Rohan','280 The Ridgeway','Enfield','Middlesex','UNITED KINGDOM','EN2 8AP','02083637114','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 21:11:04',0,NULL,3,1,3,1,'RA184538655CN ','eastar4uk\rPSGL001*4'),(21500,841424020011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','dj-team101','brechtvanpoucke@hotmail.com','brecht vanpoucke','vichtesteenweg  72','deerlijk','','BELGIUM','8540','0477808363','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 21:25:15',0,NULL,3,1,22,1,'BJ01715763 ','eastar4uk\rMOAP001'),(21501,679414133013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','loveday55555','jaysonloveday@live.com','jason loveday','47 Conor clune road<br>Navan road','Dublin','Dublin','IRELAND','d7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 21:29:12',0,NULL,3,1,22,1,'\\ ','eastar4\rWLAP002'),(21502,624705928004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',18.59,'cnfaner','frozenghost007','dannymachkovski@rocketmail.com','Danny Machkovski','582 Country Glen Rd','MARKHAM','ON','CANADA','L6B 1E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 21:55:20',0,NULL,3,1,3,1,'RA184533976CN ','cnfaner\rHSAL002\r美标'),(21503,679424985013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',2,'WLAP002',39.96,'eastar4','gothicbargaingear','corenetworks@hotmail.com','Patrick Welsh','6 Langford Pl<br>Langford Pl',', Glasgow','Glasgow (City of)','UNITED KINGDOM','g53 7hz','01418817898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 21:58:03',0,NULL,3,1,11,1,'\\ ','eastar4\rWLAP002\r发AIRPORT的'),(21504,786462910007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',18.79,'au-buy','jazijen','jencrouchy@gmail.com','Jenny Crouch','PO BOX 6215','TWEED HEADS SOUTH','New South Wales','AUSTRALIA','2486','0407282689','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 22:05:56',0,NULL,3,1,11,1,'、 ','au-buy\rcolor dot\rUM00033'),(21505,931706217012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','jon64344','herblifee@btinternet.com','john michie','11 Prospect Avenue<br>Cambuslang','Glasgow','South Lanarkshire','UNITED KINGDOM','G728BW','01416411887','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 22:14:14',0,NULL,3,1,2,1,'30120961463\r ','eastar4'),(21506,679451170013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',1,'BTHP2107',12.39,'eastar4','francobarber','franco.barber@gmail.com','Franco Barber','4150 Anna Maria Dr','Columbus','OH','UNITED STATES','43224-2113','(614) 209-9869','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 23:23:49',0,NULL,3,1,1,1,'LK194571231CN\r ','eastar4\rHP 8pin 1.0 23cm'),(21507,786496768007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',31.01,'au-buy','sylviabx','sylviaschaue@hotmail.com','sylvia schaue','hameau de savis<br>15c allée de l\'airial','castres gironde','Aquitaine','FRANCE','33640','05.56.67.69.05','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 23:28:10',0,NULL,3,1,11,1,'、 ','au-buy\rRCLO007+POLO001+RCLO008*4 欧标'),(21508,841238227011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','alderley1988','tjeans@fsmail.net','Thomas Jeans','Norbury House<br>Ancoats Lane','Alderley Edge','Cheshire','UNITED KINGDOM','SK97TT','07772154999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 23:29:10',0,NULL,3,1,3,1,'RA184533928CN ','eastar4uk\rRCLO007+POLO001+RCLO008*4'),(21509,841495954011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',2,'GPS0010',39.98,'eastar4uk','endeavour_one','eb@silktel.com','Tony Davidson','Adamcan P/L  Adam n Eve Bld<br>107 Gladstone St [PO Box 1214]','FYSHWICK ACT 2609','Australian Capital Territory','AUSTRALIA','2609','0431912648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 00:19:49',0,NULL,3,1,3,1,'RA184538620CN ','eastar4uk\rGPS0010'),(21510,786507596007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.26,'au-buy','aleksejsah','ale2w@inbox.lv','Aleksejs Sahnovs','1Latimer Close','Crawley','West Sussex','UNITED KINGDOM','RH11 7SJ','7879182946','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 00:02:29',0,NULL,3,1,11,1,'\\ ','au-buy\rRELO003'),(21511,841517760011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','priustwo','apfqwerty@gmail.com','Tony Frisna','123 Sandy Creek Dr','gastonia','NC','UNITED STATES','28052-9466','(704) 678-5168','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 01:33:13',0,NULL,3,1,1,1,'LK194378732CN\r ','eastar4'),(21512,795292192001,110822404368,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',37.98,'buysia','vfreeze520','bjeff520@yahoo.com','Brett Robideaux','4877 Moonshine Ridge Trl','Parker','CO','UNITED STATES','80134-5145','(303) 841-7845','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-10 02:29:36',0,NULL,3,1,1,1,'LK195043488CN\r ','buysia'),(21513,931810941012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',93.89,'eastar4','agnes_pietersma','agnes_pietersma@rogers.com','Agnes Pietersma','54 Hertle Av.','Toronto','ON','CANADA','M4L 2T4','(416) 901-1173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 03:04:26',0,NULL,3,1,3,1,'RA184534000CN ','eastar4\rUM00014+HBPH001\r美女涂鸦伞 \r\r再发一个\rNew Philips Sonicare flexcare toothbrush Handle HX6950 \r'),(21514,841546881011,320786223346,'New Jabra JX10 Series II 2  Bluetooth headset red',1,'HSJA012',19.98,'eastar4','jipiner','unkeldaddy@carolina.rr.com','Jennifer Adkins','5456 Gwynne Ave','Charlotte','NC','UNITED STATES','28205-7429','(704) 516-9654','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 03:04:49',0,NULL,3,1,1,1,'LK195527835CN\r ','eastar4\r红色的'),(21515,778309189008,180757093345,'Logitech MX Revolution Cordless Wireless Laser Mouse only',1,'MOLO006',24.43,'au-buy','stunna1958','stunna1958@comcast.net','Terree Frazier','350 Cooper Ave','Oaklyn','NJ','UNITED STATES','08107-2110','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 03:24:15',0,NULL,3,1,1,1,'LK195055203CN\r ','au-buy'),(21516,795312967001,110822404487,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',27.78,'buysia','yanni756922','romanyyanni@yahoo.com','yanni roumany','84 Highland Ave<br>Apt C1','jersey city','NJ','UNITED STATES','07306-5815','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-10 03:52:29',0,NULL,3,1,1,1,'LK194883282CN\r ','buysia\r买了2个'),(21517,624794342004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','need-for-4x4','rbreems1@gmail.com','Roger Breems','33008 Forest Blvd','stacy','MN','UNITED STATES','55079-9513','(651) 462-8053','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-10 04:33:38',0,NULL,3,1,1,1,'LK191778311CN\r ','cnfaner'),(21518,795336753001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','meljn515','mel6654@rochester.rr.com','Melba Nephew','378 Countess Dr','West Henrietta','NY','UNITED STATES','14586-9422','(585) 645-3920','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-10 05:34:38',0,NULL,3,1,1,1,'LK195477983CN\r ','buysia'),(21519,931857096012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','tonyzoc','tonyzoc@yahoo.com','Anthony Zoccolillo','118 Rose Lane Ter','Syracuse','NY','UNITED STATES','13219-2846','(716) 907-2341','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(21520,679537363013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','185markd','markwdenny@hotmail.com','mark denny','29 old bay road <br>deception bay','brisbane','Queensland','AUSTRALIA','4508','0414242559','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 06:11:10',0,NULL,3,1,3,1,'RA184533914CN ','eastar4\rGLOT001*2'),(21521,931864988012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','khalumai','umair719+ebay@gmail.com','Umair Khalid','12102 Landsdown Ridgeway','Humble','TX','UNITED STATES','77346','(832) 296-4504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 06:37:21',0,NULL,3,1,1,1,'LK196066851CN\r ','eastar4'),(21522,841601355011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ejberry1966','berryed@mail.com','edwin berry','17359 w jackson st','Goodyear','AZ','UNITED STATES','85338-6047','(602) 430-5304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 07:13:18',0,NULL,3,1,1,1,'LK196072865CN\r ','eastar4'),(21523,624821462004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','juliasaukina','saukina@rambler.ru','Yulia Saukina','Street 1905year, 5-223','Moskow','Russia','RUSSIAN FEDERATION','123100','+79162276651','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 07:50:38',0,NULL,3,1,3,1,'RA184519020CN\r ','cnfaner\rLGAD001'),(21524,679554435013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','rvanmoorsel','rene@vanmoorsel.org','Rene van Moorsel','Zeebruggestraat 2','EINDHOVEN','','NETHERLANDS','5628NJ','06811881004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 08:05:48',0,NULL,3,1,22,1,'\\ ','eastar4\rWLAT008'),(21525,624835980004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',2,'HSAL001',51.98,'cnfaner','kviktor-2012','viktor.k86@list.ru','Viktor Kotov','prospekt Udarnikov, 38-2, 749','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','195279',' 79516658784','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 09:22:51',0,NULL,3,1,3,1,'RA184519152CN\r ','cnfaner\rHSAL001\r欧标'),(21526,931917467012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.88,'eastar4','tbdmk','otrybhnx@gmail.com','Александр Игоревич Чигирев','бульвар Алексея Толстого дом 16 квартира 39','Санкт-Петербург','Северо-Запад','RUSSIAN FEDERATION','196608','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 10:09:16',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2023\racer 8pin1.00 18cm\rebay 通知 不让发货  对方可能是假冒的  但已经发了3.23号  '),(21527,841654193011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','cognitio321','info@cognitio.de','Andreas Hoffmann','Westendstraße 23','Niedenstein','','GERMANY','34305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 10:54:05',0,NULL,3,1,21,1,' RA184529472CN\r','eastar4uk\rOTSO002'),(21528,841660713011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','asphalt-dancer','info@at-z.de','Uwe Zillner','Brünststrasse 2','Hauzenberg','','GERMANY','94051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 11:04:01',0,NULL,3,1,2,1,NULL,'eastar4\rADAK002'),(21529,841664257011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','bolduc945','bolduc05@hotmail.com','Bolduc Alain','945 du Fédéral','Sherbrooke','QC','CANADA','J1H 5A6','(819) 823-6828','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 11:14:35',0,NULL,3,1,2,1,NULL,'eastar4'),(21530,841669146011,320571360819,'New Atheros AR5B93 Half WiFi Mini PCI-E card+antenna',1,'WLAT008+ANTY001',10.99,'eastar4','kereat','taereks@hotmail.com','taerek schutteman','Veelmanlanden 12','ENSCHEDE','','NETHERLANDS','7542MB','06147350377','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 11:31:00',0,NULL,3,1,22,1,NULL,'eastar4\rWLAT008+ANTY001'),(21531,619516532003,130522141310,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.89,'cnfaner','yiannispap','yiannis.georgia@yahoo.gr','IOANNIS PAPADOPOULOS','DIMOKRITOU 37 EVOSMOS','THESSALONIKI','THESSALONIKI','GREECE','56224','00306977254634','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 11:59:06',0,NULL,3,1,21,1,' RA184529910CN\r','cnfaner\rHSNO004\r欧标'),(21532,679419246013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','nikos23bak','fowler23robbie@hotmail.com','NIKOLAOS BAKAOUKAS','ANDRIANOUPOLEOS 7','KERATSINI','','GREECE','18756','00306972541123','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:19:48',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2014\racer 5pin1.25 20cm '),(21533,931990816012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','stnickofmyra','nickofmyra@yahoo.com.au','Paul Walliker','23-25 High St<br>3 Hiscock court','Pyalong','Victoria','AUSTRALIA','3521','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:40:54',0,NULL,3,1,2,1,NULL,'eastar4\rWLAT009'),(21534,931990759012,220922497144,'New in box ZALMAN FG1000 FPS GUN Ergonomic Style Gaming USB Mouse  FG 1000',1,'MOZA001',24.99,'eastar4uk','demigod585','animaq@mail.ru','Hajar Nasirova','Sattar Bahulul-zadeh-20a Appartment 18','Baku','','AZERBAIJAN','AZ1108','+994519700333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 13:41:54',0,NULL,3,1,22,1,' ','eastar4uk\rMOZA001'),(21535,619541107003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',5.99,'cnfaner','ruud-1954','rreinders@home.nl','Ruud Reinders','Mgr Dubbelmanstraat 21','HEESWIJK DINTHER','','NETHERLANDS','5473DK','0413293424','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:51:00',0,NULL,3,1,21,1,' RA184529937CN\r','cnfaner\rANTY002'),(21536,932003705012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','evenson187','evenson187@hotmail.com','Scott Evenson','1407 Plum Ln','Aberdeen','SD','UNITED STATES','57401-6823','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 14:13:28',0,NULL,3,1,1,1,'LK195667143CN\r ','eastar4'),(21537,841738312011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','lmanis','prayingmanis@gmail.com','H. Lee Manis','4661 Pine Dr','nazareth','PA','UNITED STATES','18064-8517','(610) 360-4109','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 14:50:37',0,NULL,3,1,1,1,'LK196153595CN\r ','eastar4'),(21538,839828774002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','gmulhearn7','gmulhearn@verizon.net','gary mulhearn','3 Pamrapo Court','Bayonne','NJ','UNITED STATES','07002','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-10 15:21:37',0,NULL,3,1,1,1,'LK196634331CN\r ','buysia'),(21539,624922932004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','harkinsfarm','harkinsfarm@hotmail.com','John Harkins','10000 State Rt. 127 E.','Marshallville','GA','UNITED STATES','31057','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-10 15:50:08',0,NULL,3,1,1,1,'LK194974814CN\r ','cnfaner'),(21540,795511439001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','alzxzx','alritt@comcast.net','A. Ritt','7896 SE Wren Ave<br>null','Hobe Sound','FL','UNITED STATES','33455-4555','(772) 546-7315','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-10 16:29:59',0,NULL,3,1,1,1,'LK193547960CN\r ','buysia'),(21541,839873759002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','celltronix716','otgwireless@gmail.com','feras abdellatif','1601 Pine Ave','niagara falls','NY','UNITED STATES','14301-2211','(716) 507-9899','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 17:06:59',0,NULL,3,1,1,1,'LK193495936CN\r ','buysia'),(21542,932112676012,220815931796,'New Sony Ericsson HBH-DS970 Bluetooth headset',1,'HSSE010',39.9,'eastar4uk','greenislandmom','deb_n@yahoo.com','Debra Nicholls','9003 31st ave sw','Seattle','WA','UNITED STATES','98126-3904','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 17:57:46',0,NULL,3,1,1,1,'LK194111632CN','eastar4uk'),(21543,679727551013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','sjx033','rdhumbert@comcast.net','Rick Humbert','5600 Northwood Rdg','Bloomington','MN','UNITED STATES','55437-1724','(952) 831-6456','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 19:02:28',0,NULL,3,1,1,1,'LK193673336CN\r ','eastar4'),(21544,619637916003,130596581492,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'cnfaner','16mdixon','mdixon16@bellsouth.net','Mary P. Dixon','4489 Billy Maher Rd','Memphis','TN','UNITED STATES','38135-1119','(901) 581-8948','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-10 19:10:19',0,NULL,3,1,1,1,'LK197782739CN\r ','cnfaner'),(21545,679739996013,230393459225,'2.1 New Acer Timeline 3810 3810T Bluetooth Module+cable',1,'BTAC2118',12.39,'eastar4','aneiros','jlaneiros@gmail.com','Juan Luis Iglesias Aneiros','Plaza de Galicia 2 4 D','A Coruña','Galicia','SPAIN','15004','651735097','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 19:25:02',0,NULL,3,1,2,1,NULL,'eastar4\rBTAC2118\racer 8pin1.0 3cm'),(21546,841890795011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','alanparsoncom','manolomestres@gmail.com','Manuel Mestres Arias','Juan S. Elcano, 46','El Campello','Comunidad Valenciana','SPAIN','03560','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 19:51:13',0,NULL,3,1,21,1,'RA184529486CN\r ','eastar4uk\rGLOT001'),(21547,840644369011,320791705383,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',37.99,'eastar4uk','rui4012','ruipereira@sky.com','rui pereira','6 roach close','worcester','Worcestershire','UNITED KINGDOM','wr5 3hz','01905357159','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 20:08:29',0,NULL,3,1,3,1,' RA184529755CN\r','eastar4uk\rGPS0006'),(21548,841906042011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','francupa','fracupa@hotmail.com','FRANCISCO CUENCA PADILLA','C/ CANTIÑA,19','CERRALBA - PIZARRA','Andalucía Ceuta y Melilla','SPAIN','29569','696252244','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 20:18:29',0,NULL,3,1,21,1,' RA184529818CN\r','eastar4\rLGRM001'),(21549,932203914012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','gmat7568','georgeparayil@yahoo.co.uk','george mathew parayil','11<br>petworth gardens','southampton','Hampshire','UNITED KINGDOM','so16 8ee','02380360165','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 20:30:52',0,NULL,3,1,3,1,'RA184529821CN\r ','eastar4uk\rOTCN004*10'),(21550,619668153003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','max.popov','pmmxxx@gmail.com','Maksym Popov','Keramicheskiy per. 7a','Kiev','','UKRAINE','03039','+380504121501','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 20:34:36',0,NULL,3,1,21,1,' RA184529985CN\r','cnfaner\rMOAP001'),(21551,841932170011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','joannamilena','aska21@interia.eu','Joanna Romanowska','85<br>wentworth road','Rugby','Warwickshire','UNITED KINGDOM','cv22 6bl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 21:06:37',0,NULL,3,1,3,1,' RA184529469CN\r','eastar4uk\rTRSN001'),(21552,619690816003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','makcue','marko_sand@gmx.de','Marko Sand','Lärchenstraße 10','Schwarmstedt','','GERMANY','29690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 21:41:23',0,NULL,3,1,21,1,'RA184529971CN\r ','cnfaner\rSHLO009'),(21553,839872949011,320730086052,'New brand Logitech Digital IO Writing Pen',2,'NTLO002',47.98,'eastar4uk','gibsongirlsgibson','tinagibson67@hotmail.com','martina gibson','1 old court manor<br>craigavon','craigavon','Armagh','UNITED KINGDOM','BT655ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 21:25:21',0,NULL,3,1,3,1,'RA184519311CN','eastar4uk\rNTLO002'),(21554,679801751013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','thedigitaledge','theedge1@citlink.net','Jesse Jackson','49 Pioneer Loop','Crossville','TN','UNITED STATES','38571-3806','(931) 484-9744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 22:11:38',0,NULL,3,1,1,1,'LK195113612CN\r ','eastar4'),(21555,679808389013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','spacekji','jirka.spacek@gmail.com','Jiri Spacek','Varsavska 212','Pardubice','Pardubicky kraj','CZECH REPUBLIC','53009',' 420732155833','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 22:34:18',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(21556,841978437011,320820765862,'New Nokia Bluetooth Headset BH-104 w/adjustable ear hook BH 104 long-lasting',2,'HSNO034',17.98,'eastar4uk','123keithbam','keithbamford@btinternet.com','keith bamford','43 woodrow lane<br>catshill','bromsgrove','Worcestershire','UNITED KINGDOM','B610PP','01527878489','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 22:47:16',0,NULL,3,1,3,1,'RA184523188CN  ','eastar4uk\r英标\rHSNO034\r单子全退款 然后发一个当礼物'),(21557,619711879003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',2,'HBPH009',37.98,'cnfaner','brd79','bruce.davies@utoronto.ca','Bruce Davies','54 Kingston Rd','Toronto','ON','CANADA','M4L 1S4','(416) 895-1273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 22:57:47',0,NULL,3,1,3,1,'RA184519325CN ','cnfaner\rHBPH009'),(21558,679831026013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','elikzayka','elikzaika@live.com','Eleonora Pshenichnova','mikrorayon 1 maya, dom 25, kvartira 329','Balashiha','Moskovskaya oblast\'','RUSSIAN FEDERATION','143911','+79164496741','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 00:04:53',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN014'),(21559,795718805001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','prtbone78','prtbone78@aol.com','Antonio Talavera','7979 78th Ave','glendale','NY','UNITED STATES','11385-7512','(347) 392-0146','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-11 00:10:15',0,NULL,3,1,1,1,'LK194682325CN\r ','buysia'),(21560,625083724004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','moncorso','canmontr@gmail.com','Nejivoi Maxim','3440 Decelles place app.103','Montreal','QC','CANADA','H3S1X4','(514) 344-9961','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 00:25:34',0,NULL,3,1,3,1,' RA184529906CN\r','cnfaner\rHSNO005\r美标'),(21561,679841919013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','deer-jerky','deerjrky@yahoo.com','Anthony L Hamilton','439 Furman RD','Sunbury','PA','UNITED STATES','17801','(570) 286-1945','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 00:57:00',0,NULL,3,1,1,1,'LK195524388CN\r ','eastar4'),(21562,932353126012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','pennine-group','sales@pennine-group.net','Allun O\'Brien','18 Park Hill Grove<br>Off Barnsley Road','Dodworth','Barnsley','UNITED KINGDOM','S75 3LX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 02:54:11',0,NULL,3,1,3,1,' RA184529716CN\r','eastar4uk\rWLAP008'),(21563,795788011001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','audiblauspit','mdiciero@hotmail.com','Mike DiCiero','7845 Albert-Laberge','Montreal','QC','CANADA','H1E6A5','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-11 05:03:13',0,NULL,3,1,11,1,NULL,'buysia\rBALO007'),(21564,842087461011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','khan4193','kelly1158@msn.com','Kelly Hansen','1160 Hillcrest Dr','Springville','UT','UNITED STATES','84663-2153','(801) 915-6987','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 05:39:05',0,NULL,3,1,1,1,'LK196920867CN ','eastar4'),(21565,625021947004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','vazkiller26','dir_pmo@mail.ru','Юрий Коротич','Кирова<br>235 кв 4','Буденновск','Ставропольский край','RUSSIAN FEDERATION','356800','(962)404-3000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 08:08:30',0,NULL,3,1,3,1,' RA184519149CN\r','cnfaner\rMOOE001\rOEM'),(21566,619806297003,130620867997,'NIB Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103-2',1,'GPS0008',110.99,'cnfaner','boukern','boukern@yahoo.com','Naoufel Bouker','Transversal sexta 10 Bloque 7  3ºA','Madrid','Madrid','SPAIN','28021','654539708','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 08:38:28',0,NULL,3,1,21,1,' RA184519135CN\r','cnfaner\rGPS0008'),(21567,932441416012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',30.49,'eastar4uk','markrwheeler','markxwheeler@hotmail.com','Mark Wheeler','126 Millfield Road','Birmingham','West Midlands','UNITED KINGDOM','B20 1EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 09:08:46',0,NULL,3,1,3,1,' RA184529835CN\r','eastar4uk\rLGRM001'),(21568,679927550013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','dmitriy_kokin','dmitry.cox@mail.ru','Dmitriy Kokin','Lihvenceva 76 kv.30','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426000','89199090009','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 09:18:04',0,NULL,3,1,11,1,' ','eastar4\rCACN004'),(21569,679932865013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','xboxlivecodenet','xboxlivecode@pp.inet.fi','Kai Hakio','mervinpiha 8','Pirkkala','xxx','FINLAND','33960','+358456337222','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 09:44:37',0,NULL,3,1,21,1,' RA184529804CN\r','eastar4\rGLOT001*2'),(21570,842153839011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','shammiminhas','shammi_singh4u@yahoo.com','SHAMSHER SINGH','1 KEITH STREET','OAKLEIGH EAST','Victoria','AUSTRALIA','3166','0061451413595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 10:22:52',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA002'),(21571,842156695011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',3,'CASS003',20.67,'eastar4uk','comic_collectable_toyz','dbmitchell@blueyonder.co.uk','David Mitchell','11 Wallington Avenue, Cullercoats','North Shields','Tyne and Wear','UNITED KINGDOM','NE30 3SH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 10:31:22',0,NULL,3,1,3,1,'RA184529968CN\r','eastar4uk\rCASS003'),(21572,932485757012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','segis99sven','segis@telia.com','Sven Leeb-Lundberg','Segebadengatan 7','VISBY','N/A','SWEDEN','62139','+46733920238','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 11:16:46',0,NULL,3,1,22,1,NULL,'eastar4uk\rWLAP008'),(21573,778936182008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','star-pirate','dark-heart@hotmail.co.uk','Phillip Whitehead','207 Wash Lane','Bury','Greater Manchester','UNITED KINGDOM','BL9 7DH','07944198742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 13:14:05',0,NULL,3,1,11,1,NULL,'au-buy\rMOMI002'),(21574,787192260007,170728982479,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'au-buy','peterb410','pete.debbie@bigpond.com','Peter Bowie','418 Hay Road','Deniliquin','New South Wales','AUSTRALIA','2710','0429855892','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 13:28:44',0,NULL,3,1,3,1,' RA184529999CN\r','au-buy\rGPS0004'),(21575,932538446012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','2easyformy','chip185@yandex.ru','Anatoly Malkov','Lenina d.27 kv.30','Pervouralsk','Sverdlovskaya Obl','RUSSIAN FEDERATION','623100',' 89226002591','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 13:31:33',0,NULL,3,1,11,1,NULL,'eastar4\rMOMI002'),(21576,625230479004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','marandmat','marandmatt@aol.com','Matthew Gorny','9806 Zimmer Dr','Algonquin','IL','UNITED STATES','60102-9693','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-11 13:50:39',0,NULL,3,1,1,1,'LK179101584CN\r ','cnfaner'),(21577,625232907004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','bertusherb','herbert.leitner@gmx.net','Herbert Leitner','Seidengasse 4','Traismauer','','AUSTRIA','3133','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 13:56:48',0,NULL,3,1,21,1,' RA184529945CN\r','cnfaner\rBALO007'),(21578,932584042012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','msims65','msimsdr@aol.com','Melissa Sims','9621 Chesapeake Blvd<br>Apt # W7E','Norfolk','VA','UNITED STATES','23503','(757) 537-9079','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 15:05:54',0,NULL,3,1,1,1,'LK193642444CN\r ','eastar4'),(21579,927162196012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','jayq86','ja_dunn@live.com','Jackie  Dunn','1025 Allouez Rd','Marquette','MI','UNITED STATES','49855-5272','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 15:42:56',0,NULL,3,1,1,1,'LK197930698CN\r ','eastar4'),(21580,842273801011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',44.89,'eastar4','dandudee','danbenatar@hotmail.com','dan benatar','26 rue trenet','notre-dame de l\'île-perrot','QC','CANADA','J7V 7P2','(514) 902-0914','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 16:12:28',0,NULL,3,1,3,1,' RA184529565CN\r','eastar4'),(21581,842318902011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','pirhanas','ronl@pirhanas.co.uk','Ian P Sharp','6 Ullswater Drive<br>Fairfield Park','Bath','Somerset','UNITED KINGDOM','BA1 6NP','07050685618','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 16:55:23',0,NULL,3,1,3,1,' RA184519121CN\r','eastar4uk\rGLOT001'),(21582,842326736011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','salshoghut','leggz4380@aol.com','V Crotwell','2580 E Tahquitz Canyon Way<br>Apt 201','Palm Springs','CA','UNITED STATES','92262-7049','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 17:08:19',0,NULL,3,1,1,1,'LK194062375CN\r ','eastar4'),(21583,619944971003,130596105709,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',18.98,'cnfaner','almentis1mbc','almentis@aol.com','Ann Mentis','PO Box 2881','Gulf Shores','AL','UNITED STATES','36547-2881','(251) 967-4706','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-11 17:13:58',0,NULL,3,1,1,1,'LK197654403CN\r ','cnfaner'),(21584,787309266007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','jefforu','jefforu71@yahoo.com','Jeffrey Owens','7625 Clark Rd','Hanover','MD','UNITED STATES','21076','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 17:33:18',0,NULL,3,1,1,1,'LK196831950CN\r ','au-buy'),(21585,796057197001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'buysia','nogau','nogau@tlb.sympatico.ca','Normand Gauthier','120, Morissette St.','Val-d\'Or','QC','CANADA','J9P 6Z4','(819) 874-0981','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-11 18:27:44',0,NULL,3,1,11,1,NULL,'buysia\rRCLO007'),(21586,842389418011,320801187531,'NIB genuine Philips SHS4800 Flexible Earhook Headphones 5-position adjustable',1,'HSPH003',13.99,'eastar4uk','enlitenen','arne.e.larsson@gmail.com','Arne Larsson','Larsbodavägen 82  7 tr.<br>lgh. 26','Farsta','sthlm','SWEDEN','12341','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 18:51:44',0,NULL,3,1,22,1,' ','eastar4uk\rHSPH003'),(21587,625342167004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',25.99,'cnfaner','ginnforheisman','colinoverlandpro@hotmail.com','Colin Overland','219 SW 299th Pl','Federal Way','WA','UNITED STATES','98023-3570','(253) 797-8283','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-11 19:00:20',0,NULL,3,1,1,1,'LK197360695CN\r ','cnfaner'),(21588,796101135001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','eferrara84','ericferrara@gmail.com','Eric Ferrara','900 N Stafford St<br>Apt 907','Arlington','VA','UNITED STATES','22203-1843','(703) 795-3047','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-11 19:43:55',0,NULL,3,1,1,1,'LK192349490CN\r ','buysia'),(21589,620013091003,130553375553,'New GENUINE NOKIA BH-100 BLUETOOTH HEADSET track#',1,'HSNO030',11.89,'cnfaner','maglicd','danijel.maglic@mobitel.si','Danijel Maglic','Krozna pot 4','Ljubljana','','SLOVENIA','1000','(+386)41232260','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 19:59:14',0,NULL,3,1,21,1,' RA184529897CN\r','cnfaner\rHSNO030\r欧标'),(21590,932768048012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','djroni','djroni@gmail.com','varinder sahota','10501 Peruvian way','Sacramento','CA','UNITED STATES','95830-9337','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 20:12:30',0,NULL,3,1,1,1,NULL,'eastar4'),(21591,625379913004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','jayz89jason','lovelifelovemusic@hotmail.com','Jason Gold','20 st mungo\'s whynd','Alloa','Clackmannan','UNITED KINGDOM','FK10 1LQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 20:36:42',0,NULL,3,1,3,1,' RA184529849CN\r','cnfaner\rHBPH003'),(21592,932802755012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','2011amyliz76','amyelizabethpickard@gmail.com','Amy Pickard','PO Box 80','Ferndale','WA','UNITED STATES','98248-0080','(360) 739-9015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 20:54:09',0,NULL,3,1,1,1,'LK196609725CN\r ','eastar4');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (21593,932805713012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','daveyfifibaby','fionahill105@btinternet.com','fiona hill','1a Valebridge Road','Burgess Hill','West Sussex','UNITED KINGDOM','rh15 0RA','07763397517','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 21:00:31',0,NULL,3,1,3,1,' RA184532975CN\r','eastar4uk\rHBPH003'),(21594,840556325002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','glied46','glied46@aol.com','Gary Liedtke','1858 20th St NW','Cedar Rapids','IA','UNITED STATES','52405-1480','(319) 651-4192','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-11 23:06:26',0,NULL,3,1,1,1,'LK191764961CN\r ','buysia'),(21595,932872742012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.39,'eastar4','zedcred','zedcred@ntlworld.com','Michael Street','32 Berry Drive<br>Bromham','Bedford','Bedfordshire','UNITED KINGDOM','MK43 8QA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 23:11:30',0,NULL,3,1,2,1,NULL,'eastar4'),(21596,932865603012,220901458596,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',6.99,'eastar4uk','winfuzz','isa_belette@hotmail.com','Isabelle Bernier','1017 Alexis Galipeau','Beloeil','QC','CANADA','J3G 0K7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 22:59:21',0,NULL,3,1,11,1,NULL,'eastar4uk\rBALO001'),(21597,842533607011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','peanut52553','klsuchar@shaw.ca','Karen Suchar','263093 Butte Hills Way','Rocky View County','AB','CANADA','T4A0N9','(403) 226-2244','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 23:22:00',0,NULL,3,1,11,1,NULL,'eastar4\rHBPH009'),(21598,932898139012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','dillera','dillera@dillernet.com','Andrew Diller','918 S Farragut St','Philadelphia','PA','UNITED STATES','19143-3607','(215) 386-3637','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 00:17:28',0,NULL,3,1,1,1,'LK197663025CN\r ','eastar4'),(21599,680233189013,230444987926,'New Atheros AR9281 802.11N  WiFi over AR5008+ 2 antenna',1,'WLAT010+ANTY001',10.99,'eastar4','ittrium','ittrium@gmail.com','Aleksandr Kalinichenko','Budapeshtskaya 91-1-123','St.Petersburg','','RUSSIAN FEDERATION','192283','7-(905)-2604986','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 00:31:00',0,NULL,3,1,11,1,'BJ01669322\r ','eastar4\rWLAT010+ANTY001'),(21600,787517358007,170762346425,'New in box genuine Linksys DMP100 Wireless-N Music Extender Wireless Home Audio',1,'OTLK001',119,'au-buy','whatsthematterhorne','4chrishorne@f2s.com','C P Horne','87 Tanhouse Avenue<br>Great Barr','Birmingham','West Midlands','UNITED KINGDOM','B43 5AQ','01213583913','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 00:37:29',0,NULL,5,1,4,1,'YW868897786CN\r','au-buy\rOTLK001已发，点不了发货'),(21601,680236939013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','jkwwkj','jkevinwilliams@yahoo.com','john kevin williams','1284 high st','westwood','MA','UNITED STATES','02090','(781) 762-9312','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 00:46:29',0,NULL,3,1,1,1,'LK197557914CN\r ','eastar4'),(21602,619100622003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','xmlking','xmlking@yahoo.com','Sumanth Chinthagunta','19897 Paso Robles Dr','Riverside','CA','UNITED STATES','92508-6484','(951) 732-7866','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 01:12:30',0,NULL,3,1,1,1,'LK197153835CN\r ','cnfaner'),(21603,625456473004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','wreckah','dick@rreck.com','Dick Reck','128 Hillcrest Ave','Hinsdale','IL','UNITED STATES','60521','(312) 307-8030','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 00:59:24',0,NULL,3,1,1,1,'LK197514131CN\r ','cnfaner'),(21604,842576020011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',2,'GLOT001',89.78,'eastar4','josecortez559','cortezgarcia79@yahoo.com','Bernardina Cortez','Po Box 484<br>318 six st.','Kettleman City','CA','UNITED STATES','93239-0484','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 01:31:02',0,NULL,3,1,1,1,'LK196698120CN\r\r ','eastar4'),(21605,842581548011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','nyscreech','lkuliyev@hotmail.com','Leo Kuliyev','7534 Bell Blvd<br>Apt 4G','Oakland Gardens','NY','UNITED STATES','11364','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 01:48:29',0,NULL,3,1,1,1,'LK197720782CN\r ','eastar4'),(21606,932936596012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Jackson Jenkins','11024 Coffman Ave','Hagerstown','MD','UNITED STATES','21740-7617','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 02:13:39',0,NULL,3,1,1,1,'LK197182615CN\r ','eastar4'),(21607,932937602012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Agrobiotek BPS','7993 NW 21st St','Doral','FL','UNITED STATES','33122-1616','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 02:16:20',0,NULL,3,1,1,1,'LK197279186CN\r ','eastar4'),(21608,932938368012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Field Guides Inc.','9433 Fm 2244<br>Ste 1-150','Austin','TX','UNITED STATES','78733-6130','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 02:19:17',0,NULL,3,1,1,1,'LK197584129CN\r ','eastar4'),(21609,842591812011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','fgjoh','johannsen.pete@gmail.com','Peter Johannsen','275 Prospect Rd','Blair Athol','South Australia','AUSTRALIA','5084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 02:23:34',0,NULL,3,1,2,1,NULL,'eastar4'),(21610,932934202012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Juan Almanzer AP-007592','8532 NW 66th St','Miami','FL','UNITED STATES','33166-2635','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 02:10:13',0,NULL,3,1,1,1,'LK196767973CN\r ','eastar4'),(21611,932947118012,220872413885,'3 pair 3D TV Activ Shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*3',78.99,'eastar4uk','jdmm3412','josephdm42@gmail.com','Joseph Meyers','2307 W 7th St','Cleveland','OH','UNITED STATES','44113-4503','(216) 288-2812','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 02:46:15',0,NULL,3,1,1,1,'LK198879589CN\r ','eastar4uk'),(21612,932939246012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Henry Harpending','1488 Ken Rey St','Salt Lake City','UT','UNITED STATES','84108-2618','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 03:58:03',0,NULL,3,1,1,1,'LK193288620CN\r ','eastar4'),(21613,932968671012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Shihao Zhao LAGSF','216 S 5th.-124390','La Puente','CA','UNITED STATES','91746','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 04:02:10',0,NULL,3,1,1,1,'LK195682066CN\r ','eastar4'),(21614,932970350012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','91chris25','chris_exadactylos@hotmail.com','Chris Exadactylos ','7 Adler court ','Keilor downs','Victoria','AUSTRALIA','3038','0393673665','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 04:04:53',0,NULL,3,1,3,1,' RA184529680CN\r','eastar4\rGLOT001*2'),(21615,932970050012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','James Wacksman','900 Hillcrest Ct<br>Tallahassee','Tallahassee','FL','UNITED STATES','32308-5060','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 04:07:02',0,NULL,3,1,1,1,'LK196463787CN\r ','eastar4'),(21616,932973494012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','John A Kriho','1305 Remington Rd<br>Ste G','Schaumburg','IL','UNITED STATES','60173-4820','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 04:18:45',0,NULL,3,1,1,1,'LK194969876CN\r ','eastar4'),(21617,932974161012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Diane Mucci','74 S Main St<br>Apt 1','Mullica Hill','NJ','UNITED STATES','08062-9702','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 04:21:34',0,NULL,3,1,1,1,'LK195414498CN\r ','eastar4'),(21618,932977120012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','ukesell247','ukesell@gmail.com','Farhad Soleimaninia','57 Hollowfield Walk<br>Northolt','London','London','UNITED KINGDOM','UB5 5SX','07985431058','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 04:34:05',0,NULL,3,1,3,1,' RA184529764CN\r','eastar4uk\rHSJA002\r英标'),(21619,680289463013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',175.99,'eastar4','lekingcreole','lekingeric@yahoo.ca','Eric Poulin','263 ANDRE OUIMET','ST-EUSTACHE','QC','CANADA','J7R5H6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 05:01:43',0,NULL,3,1,3,1,' RA184530008CN\r','eastar4\rGLOT001*4'),(21620,932995921012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','25wade','lesbarwick@clear.net.nz','Bill Hewitt','32 Walter Raleigh Crescent Hollywell','Gold Coast','Queensland','AUSTRALIA','4216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 05:55:19',0,NULL,3,1,2,1,NULL,'eastar4'),(21621,680309436013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',5,'CACN004',64.7,'eastar4','rutin_f','fartunin@gmail.com','Aleksey Fartunin','Olhovaya str., 9-239<br>6 mrk.','VIDNOE','Moscow region','RUSSIAN FEDERATION','142701','7-910-427-63-67','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 07:19:01',0,NULL,3,1,3,1,' RA184529852CN\r','eastar4\rCACN004'),(21622,779353813008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','michsan69','m.buschgens@online.nl','Michael Büschgens','Duitslandlaan 9','Heerlen','','NETHERLANDS','6414 HN','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 07:27:28',0,NULL,5,1,18,1,NULL,'au-buy\rRELO001\r缺货已退款'),(21623,933032158012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','klcon','lazzeraith1@yahoo.com','Kenneth Conner','133 Raymond Sills Rd','Silver Creek','MS','UNITED STATES','39663','(601) 990-8443','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 08:27:17',0,NULL,3,1,1,1,'LK197281953CN\r ','eastar4'),(21624,680321092013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','ben2686','benschepers@yahoo.com','ben schepers','grachtstraat 20','sibculo','','NETHERLANDS','7693 pc','06 22703879','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 08:28:27',0,NULL,3,1,21,1,' RA184529720CN\r','eastar4\rGLOT001*2'),(21625,779388169008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',2,'HBPH007',93.98,'au-buy','gdanddj','info@defab.com.au','Joe DePetro','Unit 2, 3 Magazine Way','Maribyrnong','Victoria','AUSTRALIA','3032','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:31:05',0,NULL,3,1,3,1,' RA184529883CN\r','au-buy\rHBPH007'),(21626,842699468011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','conardeastgrn','conardeastgrn@aol.com','marilin conard','3207 Coventry Ln<br>apt 7','east greenbush','NY','UNITED STATES','12061-2322','(518) 364-8115','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 09:35:58',0,NULL,3,1,1,1,'LK195360260CN\r ','eastar4'),(21627,779396118008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',2,'MOMI002',27.58,'au-buy','lazarettomd','lazaretto@gmail.com','Sara MacDonald','6 Greenbrook Way','BERTRAM','Western Australia','AUSTRALIA','6167','0415379430','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:51:15',0,NULL,3,1,11,1,NULL,'au-buy\rMOMI002'),(21628,933067449012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','scottyr35','scott.robson84@gmail.com','Scott Robson','25227 S. Mallard Dr.','Channahon','IL','UNITED STATES','60410','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 09:56:44',0,NULL,3,1,1,1,'LK194990851CN\r ','eastar4'),(21629,842719016011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','jim_in_devon','jimhoughton@gmail.com','Jim Houghton','Kingsway, North Road','Lifton','Devon','UNITED KINGDOM','PL160EH','07767815705','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 10:19:49',0,NULL,3,1,3,1,' RA184529676CN\r','eastar4uk\rWLDE001'),(21630,842729487011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','19janice59','janice.lee@blueyonder.co.uk','Janic e Lee','324 Main Street','Alexandria','West Dunbartonshire','UNITED KINGDOM','G830AL','07748194313','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 10:41:29',0,NULL,3,1,3,1,' RA184529490CN\r','eastar4uk\rMOAP001'),(21631,933089627012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','ascensionskate','localityfilms@gmail.com','Kenneth W Barnes','10203 Christiano Dr','Glen Allen','VA','UNITED STATES','23060-3775','(804) 264-1128','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 10:42:48',0,NULL,3,1,1,1,'LK196174652CN\r ','eastar4'),(21632,676369575013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','bel73h','mce.belinda@bigpond.com','Belinda Carter','75 Waratah St','Windang','New South Wales','AUSTRALIA','2528','0411453433','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 10:59:58',0,NULL,3,1,11,1,'BJ01715723 ','eastar4\rUM00042'),(21633,787693478007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','lando4982','sam.lando@bankwest.com.au','Sam Lando','22 Cityview Road','Balwyn North','Victoria','AUSTRALIA','3104','0398599578','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 11:22:58',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR001'),(21634,842770712011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ho**97**','hoangan1228@comcast.net','Hung-Hoang J. Nguyen','3005 Briarsage Ln','Pearland','TX','UNITED STATES','77581-3555','(832) 576-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 12:06:24',0,NULL,3,1,1,1,'LK197558574CN\r ','eastar4'),(21635,842779499011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','nitsanphotography','dirty-space-monkey@hotmail.co.uk','nitsan simantov','101 orchard way','east grinstead','West Sussex','UNITED KINGDOM','RH19 1AU','01342316432','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 12:24:14',0,NULL,3,1,3,1,' RA184529509CN\r','eastar4uk\rMOAP001'),(21636,933144941012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UM00001',19.99,'eastar4','charqui06','charqui06@hotmail.com','Miluschka Bravo Soldevilla','C/ Mencey Taoro, Bloque 22, Vivienda  Nº 27<br>LLANO DEL CAMELLO - SAN MIGUEL DE ABONA','Santa Cruz De tenerife','Santa Cruz de Tenerife','SPAIN','38620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 12:29:25',0,NULL,3,1,22,1,'BJ01715705 ','eastar4\rUM00001'),(21637,842835019011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','themurrman','mgrudz@mac.com','Murray Grudzinski','LCBO<br>34 Barrack Street','Kingston','ON','CANADA','K7K 7A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 14:06:00',0,NULL,3,1,2,1,NULL,'eastar4'),(21638,680050188013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','shapkinshapkin','shapkin76@mail.ru','YURIY SHAPKIN','B. Polyanka, 28, kv.143','Moscow','Moskow','RUSSIAN FEDERATION','119180','(916)4270614','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 14:08:28',0,NULL,3,1,3,1,' RA184529662CN\r','eastar4\rGPS0006'),(21639,933212169012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',26.99,'eastar4uk','1969breedon','joannelaurens@aol.com','joanne laurens','28 kelsey lane<br>althorpe','scunthorpe','Lincolnshire','UNITED KINGDOM','dn173hq','01724782611','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 14:22:25',0,NULL,3,1,3,1,' RA184529543CN\r','eastar4uk\rGLOT001'),(21640,625650866004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','g-kfo','feodor.gk@gmail.com','Feodor Gerasimenko-K.','Novokosinskaya 6-2, 103','Moscow','Moscow','RUSSIAN FEDERATION','111673','+7-985-9202341','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 14:41:56',0,NULL,3,1,3,1,' RA184529866CN\r','cnfaner\rOTTP001'),(21641,779582983008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',46.99,'au-buy','ajm250','melloraj@netscape.net','Andrew  Mellor','8 Meadowsweet Close','Cambridge','Cambridgeshire','UNITED KINGDOM','CB236ET','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 15:57:40',0,NULL,3,1,3,1,' RA184529870CN\r','au-buy\rHBPH007'),(21642,842938895011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','macca-man','andymacca@mac.com','Andrew J McDonnell','204 Park Road<br>Guiseley','Leeds','West Yorkshire','UNITED KINGDOM','LS20 8EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 16:34:57',0,NULL,3,1,3,1,' RA184529557CN\r','eastar4uk\rTRSN001'),(21643,680507888013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','zaunfink','claudialoof@web.de','Claudia Loof','Plumpstr. 6','Eutin','','GERMANY','23701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 16:42:39',0,NULL,3,1,2,1,NULL,'eastar4'),(21644,680506313013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','vitaliki_gmbh','oleg@petrov.com.ua','Oleg Petrov','Khodakovskogo<br>4 kv 6','Donetsk','Donetskiy','UKRAINE','83023','38(050)3475456','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 17:05:34',0,NULL,3,1,22,1,' ','eastar4\rWLIN014'),(21645,620376992003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','sssampso','ssampso@yahoo.com','scott sampson','314 E 12th Ave','milbank','SD','UNITED STATES','57252-3604','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 17:17:30',0,NULL,3,1,1,1,'LK197971975CN\r ','cnfaner'),(21646,842980147011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','09daniboy','wheelsautos@yahoo.com','Alan Singer','539 Derby Ave','Woodmere','NY','UNITED STATES','11598-2712','(516) 569-0961','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 17:23:37',0,NULL,3,1,1,1,'LK193140592CN\r ','eastar4'),(21647,933360560012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',11,'eastar4uk','loothi','lucy@triffid.org','Lucy Newman','20A Alexandra Villas','Brighton','East Sussex','UNITED KINGDOM','BN1 3RF','07942090651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 17:26:27',0,NULL,3,1,3,1,' RA184529747CN\r','eastar4uk\rWLHP002'),(21648,933382935012,220816379647,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*3',78.99,'eastar4uk','4163tonyw','tonywalker123@btinternet.com','tony walker','10 holme close','weymouth','Dorset','UNITED KINGDOM','DT3 5RW','01305816474','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 17:49:18',0,NULL,3,1,3,1,' RA184529954CN\r','eastar4uk\rGLOT001*3'),(21649,843022379011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3002',19.98,'eastar4','guevenyilmaz','guevenyilmaz@hotmail.com','Güven Yilmaz','8. Straße 1','Kematen an der Ybbs','','AUSTRIA','3331','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 18:05:54',0,NULL,3,1,22,1,' ','eastar4\rBTHP3002\rHP 6pin1.0 3cm'),(21650,625768026004,140667903246,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',18.49,'cnfaner','behc777','rey@spmi.ru','Evgeny Chorpita','Tikhoretskiy pr., dom 27, korp. 2, kv. 42<br>+7 911 7129060','Sankt-Peterburg','RU','RUSSIAN FEDERATION','195427','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 18:15:54',0,NULL,3,1,3,1,' RA184529781CN\r','cnfaner\rWLIN010'),(21651,843047136011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','hichamdk','hichamtl@gmail.com','Hicham Alaoui','121 General Brock','Roxboro','QC','CANADA','H8Y1H9','(514) 653-4484','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 18:28:29',0,NULL,3,1,3,1,' RA184529778CN\r','eastar4\rLGRM001'),(21652,680554895013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','waxwax','wax@ducatimonster.hu','Bence Wax','Szigeti József street','Budapest','Budapest','HUNGARY','1041',' 36202365821','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 18:33:44',0,NULL,3,1,22,1,'BJ01715702\r ','eastar4\rWLAP002\r新地址\rBence Wax\rSzigeti J?zsef street 5.\rBudapest   1041\rHungary\r 36202365821\r'),(21653,843048320011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','pharenmchugh','pemchugh2@gmail.com','Pharen McHugh','USC Student Box 84207 1400 GREENE STREET','Columbia','SC','UNITED STATES','29225-0001','(803) 727-6182','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 18:29:45',0,NULL,3,1,1,1,'LK191689418CN\r ','eastar4'),(21654,933518718012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','burgmeise','tnowka@gmx.de','Thomas Nowka','Gartenstraße 3','Meißen','','GERMANY','01662','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 19:46:31',0,NULL,3,1,2,1,NULL,'eastar4\r欧标'),(21655,779655943008,180757094136,'New Original LOGITECH Mini USB Receiver for MX3200/3000/600 LX710/5/7/8 S510',1,'RELO001',8.9,'au-buy','karimovic','karimospace-ebay@yahoo.fr','Karim Rahmouni','8, place Pierre Semard<br>impasse Clos Millet','BOUCAU','Aquitaine','FRANCE','64340','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 19:49:56',0,NULL,5,1,18,1,NULL,'au-buy\rRELO001\r缺货已退款'),(21656,788078777007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','educastrofoto','classic.photos@hotmail.com','Diogo Eduardo C. Oliveira','Avenida dos alpes Qd.9<br>Ed. manhattan 3 Apto.404-B','Goiania','Goias','BRAZIL','74310-010','55 62 96458908','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 20:05:44',0,NULL,3,1,11,1,'BJ01715710\r ','au-buy\rUM00001\r蓝色的'),(21657,933558406012,220448695602,'Acer Aspire 5100 5110 3100  Bluetooth Module 2.0+cable',1,'BTAC2021',9.88,'eastar4','tick*tack','alconaut@gmail.com','Daniel Bibbiani','Schorndorfer Str.128','Ludwigsburg','','GERMANY','71638','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 20:13:46',0,NULL,3,1,2,1,NULL,'eastar4\racer 8pin1.00 8cm'),(21658,933612924012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','wavegluider','wavi@aol.com','Avi Wrobel','12947 Rubens Ave','Los Angeles','CA','UNITED STATES','90066-6541','(310) 466-6293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 21:13:31',0,NULL,3,1,1,1,'LK196178243CN\r ','eastar4'),(21659,843220957011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','romikus13','roman.klyukin@gmail.com','Roman  Klyukin','Udarnikov 41/1-460','Sankt-Peterburg','RUSSIAN FEDERATION','RUSSIAN FEDERATION','195030','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 21:18:57',0,NULL,3,1,11,1,NULL,'eastar4uk\rGPS0010'),(21660,843226235011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','lancaster11radek','rad2@rogers.blackberry.net','radek bandzierz','127 John St ','carleton place ','ON','CANADA','k7c1n7','(613) 852-2323','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 21:25:52',0,NULL,3,1,11,1,NULL,'eastar4\rHSSA003'),(21661,620546316003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',2,'RCLO007',53.8,'cnfaner','bjensen224','bjensen@dls.net','Bryce Jensen','18N303 Sawyer Rd','West dundee','IL','UNITED STATES','60118-9283','(224) 629-0198','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 21:31:19',0,NULL,3,1,1,1,'LK196170749CN\r ','cnfaner'),(21662,933647586012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','staaaff','frasse_89@hotmail.com','Staffan Uhlmann','Orrvägen 10','Täby','','SWEDEN','18351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 21:58:34',0,NULL,5,0,18,0,NULL,'eastar4\r客户要撤单'),(21663,625915299004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','sandi357','sandi357@msn.com','Sandra Smith','309 Naylor Ave','Taft','CA','UNITED STATES','93268-4220','(661) 319-2253','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 22:00:19',0,NULL,3,1,1,1,'LK194038773CN\r ','cnfaner'),(21664,843250025011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','7248444','dark301@hotmail.com','Mehdi Huseynov','Ruzgar Qasimov 36','Ganja','Azerbaijan','AZERBAIJAN','Az2000','+994503105094','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 22:03:05',0,NULL,3,1,22,1,' ','eastar4\rHSJA002'),(21665,625922346004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',54.7,'cnfaner','mariomst2009','vinicius_trev@hotmail.com','Mario Trevisan','Rua João pessoa  719 apto 122','Matão','SP','BRAZIL','15990-020','+551633827766','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 22:20:03',0,NULL,3,1,3,1,' RA184529795CN\r','cnfaner\rGLOT005'),(21666,841234064002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','madhatrs','snoodge@gmail.com','Sean Seeger','8155 E Columbus Ave','Scottsdale','AZ','UNITED STATES','85251-5807','(480) 326-5789','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-12 22:25:24',0,NULL,3,1,1,1,'LK197819045CN\r ','buysia'),(21667,843268175011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',2,'WLIN015',29.98,'eastar4','alty134','dimon113@gmail.com','DMITRIY ZHILINSKIY','1001-155 ANTIBES DRIVE','NORTH YORK','ON','CANADA','M2R 3G7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 22:32:32',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN015\r无线蓝牙二合一'),(21668,843282702011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','lasma','workingmom68@hotmail.com','Lisa Sigler','5035 Springhouse Cir','Baltimore','MD','UNITED STATES','21237','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-12 23:06:16',0,NULL,3,1,1,1,'LK194285063CN\r ','eastar4'),(21669,680751843013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',2,'UM00042',39.98,'eastar4','atserp*2011','gracepresta_1@hotmail.com','Grace Presta','87 Atlee Avenue','Toronto','ON','CANADA','M1N 3X5','(647) 283-2921','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 23:15:39',0,NULL,3,1,11,1,NULL,'eastar4\rUM00042'),(21670,788222244007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','gupstones','gupstones@optusnet.com.au','kylie johnstone','110 Evan St','south mackay','Queensland','AUSTRALIA','4740','0749510171','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 00:08:39',0,NULL,3,1,3,1,' RA184519118CN\r','au-buy\rLGFI001'),(21671,933712850012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',89.78,'eastar4','fr.bueno','eng.frb@gmail.com','Fabricio Bueno','QE 38 Bl. D Ap. 105 Euzebio P. Araujo. II<br>Guara II','Brasilia','Distrito Federal','BRAZIL','71070-604','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 00:09:16',0,NULL,3,1,3,1,' RA184529733CN\r','eastar4\rGLOT001'),(21672,932974820012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Edward Cole','8226 Green River Way','Liverpool','NY','UNITED STATES','13090-6810','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 01:11:44',0,NULL,3,1,1,1,'LK194430137CN\r ','eastar4'),(21673,933742878012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Spring Street Mac','600 S Spring St<br>Ste R3','Los Angeles','CA','UNITED STATES','90014-1992','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 01:16:28',0,NULL,3,1,1,1,'LK196713330CN\r ','eastar4'),(21674,843338079011,320828181306,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',42.99,'eastar4uk','stevesteveyp','stevesteveyp@btinternet.com','Steve','15 Barlow Court<br>Kingsbury','Tamworth','Warwickshire','UNITED KINGDOM','B782HB','01827870454','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 01:20:52',0,NULL,3,1,11,1,'\r ','eastar4uk\rHSNO035\r英标'),(21675,620621735003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','anh402','av.hazelrigg@comcast.net','Allan N Hazelrigg','618 E Davis St','Sullivan','IN','UNITED STATES','47882-1639','(812) 268-5707','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-13 01:32:05',0,NULL,3,1,1,1,'LK196499849CN\r ','cnfaner'),(21676,8881329097742376,111,'New Vivienne Westwood Red w/lace Boetie Sun Rain Stick Umbrella - ',1,'UM00027',24.99,'aliexpress','1006694326','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','	+7 965 5682175',NULL,NULL,NULL,'2012-02-13 01:49:02',0,NULL,8,0,17,0,NULL,' 客户改要枫叶小熊伞UM00023\r'),(21677,8881329097966423,111,'New Korea Cute Painting 3-Section Sun/Rain Umbrella - ',1,'UM00036',19.99,'aliexpress','1006694327','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','+7 965 5682175',NULL,NULL,NULL,'2012-02-13 01:52:46',0,NULL,8,1,17,0,NULL,''),(21678,8881329098253859,111,'Replaceable Shell for logitech Performance MX Mouse M950 - ',1,'SHLO002',17.99,'aliexpress','1006694328','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','+7 965 5682175',NULL,NULL,NULL,'2012-02-13 01:57:33',0,NULL,8,1,17,0,NULL,'客户买了两个  SHLO002 录单子是数量录错了'),(21679,8881329098471926,111,'Replaceable Shell for logitech Anywhere MX Mouse M905 - ',2,'SHLO005',31.98,'aliexpress','1006694329','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','+7 965 5682175',NULL,NULL,NULL,'2012-02-13 02:01:11',0,NULL,8,1,17,0,NULL,NULL),(21680,8881329098717723,111,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4 - ',2,'GRUG001',359.98,'aliexpress','1006694329','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','+7 965 5682175',NULL,NULL,NULL,'2012-02-13 02:05:17',0,NULL,5,0,18,0,NULL,'录错了 '),(21681,8881329098740660,111,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4 - ',2,'GRUG001',359.98,'aliexpress','1006694330','1@1.com','Denis Koryakin','Tverskaya 54-117 ','Izhevsk','Udm','RUSSIAN FEDERATION','426052','+7 965 5682175',NULL,NULL,NULL,'2012-02-13 02:05:17',0,NULL,3,0,5,0,'CP243056078CN','两个SHLO005 两个SHLO002 一个UM00036 \r还有一个枫叶小熊伞 '),(21682,843374358011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','epage5','epage5@hotmail.com','Ernest Page','11030 Ullswater Ln','Windermere','FL','UNITED STATES','34786-5411','(407) 963-4772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 02:54:37',0,NULL,3,1,1,1,'LK197241954CN\r ','eastar4'),(21683,680806230013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',2,'UM00042',39.98,'eastar4','el0234','l_hannay@hotmail.com','L Hannay','15 Bineen St<br>Carina','Brisbane','Queensland','AUSTRALIA','4152','0401903030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 03:06:03',0,NULL,3,1,11,1,'BJ01715706\r ','eastar4\rUM00042\r客户买了两把伞分两个地址发，这个地址就发一把'),(21684,8881329103225736,111,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','el0234','l_hannay@hotmail.com','D Young',' 38 Taloumbi Road Coffs ','Harbour','NSW','AUSTRALIA','2450 ','',NULL,NULL,NULL,'2012-02-13 03:20:25',0,NULL,3,1,11,1,'BJ01715709\r ','eastar4\rUM00042 '),(21685,8881329103695938,111,'Sony TMR-BR100 3D Sync Transmitter ',1,'TRSN001',26.99,'cnfaner','debu7 ','nb2ebay@hotmail.com','Devang Patel','12929 Centre Park Cir Apt 217','Herndon','VA ','USA','20171-5943','',NULL,NULL,NULL,'2012-02-13 03:27:32',0,NULL,3,1,1,1,'LK189445791CN','Usa-view \rTRSN001\r重做的订单'),(21686,680829008013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','mcavellaneda11','mcavellaneda@gmail.com','Carolina Avellaneda','275 W Roosevelt St<br>Apt 1246','Baton Rouge','LA','UNITED STATES','70802-7817','(225) 578-0760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 03:31:26',0,NULL,3,1,1,1,'LK192837444CN\r ','eastar4'),(21687,788295090007,170730545154,'New Logitech Cradle L-LG7 for Harmony remote 880 890 + US AC adapter',2,'CRLO001+POLO001',33.98,'au-buy','gnimelfaj','jfleming@ectsi.net','Andrew Fleming','4204 96th St','Lubbock','TX','UNITED STATES','79423-3974','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 03:36:28',0,NULL,3,1,1,1,'LK190411720CN\r ','au-buy'),(21688,932324123012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','dinahs*kitschn','dannye.nunn@gmail.com','Dannye Nunn','2/8 Turf Court','Greenmount','Western Australia','AUSTRALIA','6056','0000000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 03:53:13',0,NULL,3,1,11,1,'BJ01715711\r ','eastar4\rUM00006'),(21689,619452297003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','sonoeyes','pjcook2006@sbcglobal.net','Patricia Cook','6219 Stable Point Dr','San Antonio','TX','UNITED STATES','78249-4617','(210) 558-9370','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-13 03:58:00',0,NULL,3,1,1,1,'LK197847182CN\r ','cnfaner\rsilver'),(21690,626017624004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','olega1975','oleg.ch.oleg@yandex.ru','Oleg Chervyakov','Veteranov 155, 47','Saint-Petersburg','','RUSSIAN FEDERATION','198264','+7(905)280-57-45','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 04:08:32',0,NULL,3,1,3,1,' ','cnfaner\rWWOT003+ANCN001'),(21691,933815797012,220915147042,'New Innovated Heart shape Fashion Rose Sun/Rain Umbrella',1,'UM00047',24.99,'eastar4','veraflowerpower','verazholondz@gmail.com','Vera Zholondz','ASU Dr #212','Alcorn State','MS','UNITED STATES','39096-7500','(601) 493-3642','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 04:12:13',0,NULL,3,1,1,1,'LK197973490CN\r ','eastar4'),(21692,8881329107030443,111,'4 Logitech RF Extender Wires',1,'',12.9,'au-buy','endlessaddcitions','endlessaddcitions@gmail.com','Kevin Cayer','1150 Southdale Ave','Oshawa ','Ont','CANADA','L1H 7Z2','',NULL,NULL,NULL,'2012-02-13 04:23:50',0,NULL,3,1,3,1,' RA184529605CN\r','au-buy\r已付邮费$10 AUD \r只是4条雷管，没有发射器'),(21693,780042196008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','steadman1973','david.maguire1@bigpond.com','David Maguire','84 Delaney Avenue','Bright','Victoria','AUSTRALIA','3741','0357501189','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 04:37:47',0,NULL,3,1,11,1,'BJ01715724 ','au-buy\rUM00043'),(21694,933813625012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','svoruz','svoruz@hotmail.com','Sean Voruz','19710 Clubhouse Dr<br>APT 6-220','Parker','CO','UNITED STATES','80138-6240','(618) 531-3800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 04:46:16',0,NULL,3,1,1,1,'LK194405251CN\r ','eastar4'),(21695,780046091008,180755479839,'ULTIMATE EARS METRO.FI 220 EARPHONE',1,'HSUE002',19.99,'au-buy','oziebill','jwgooden@bigpond.net.au','James Gooden','18 Benjamin Circle','RUTHERFORD','New South Wales','AUSTRALIA','2320','0249319193','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 04:59:00',0,NULL,3,1,11,1,NULL,'au-buy\rHSUE002\r澳标\r'),(21696,841388258002,120844622295,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'buysia','piercero','portlandpearl@gmail.com','Robyn Pierce','1130 NW 12th Ave<br>Apt 320','Portland','OR','UNITED STATES','97209-2856','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-13 05:31:09',0,NULL,3,1,1,1,'LK196768846CN\r ','buysia\r'),(21697,843421116011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','lanyameme1','aliciascott527@comcast.net','Alicia Scott','527 E 58th St','Jacksonville','FL','UNITED STATES','32208-4822','(904) 329-4601','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 05:44:16',0,NULL,3,1,1,1,'LK192795245CN\r ','eastar4'),(21698,843435979011,320721404615,'Transparent Dome Rain Sun Umbrella with pink trim',1,'UM00001',19.99,'eastar4','emmieewee','z_3mily@hotmail.com','Emily Cui','203-335 Cedar St','New Westminster','BC','CANADA','V3L 3N9','(604) 523-1681','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 07:02:06',0,NULL,3,1,11,1,'BJ01715707 ','eastar4\rUM00001'),(21699,626040217004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','makippesan3','makippesan@yahoo.co.jp','MAKIKO TANO','Starfish 23 Avalon Pd','Avalon','New South Wales','AUSTRALIA','2107','0438669821','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 07:02:44',0,NULL,3,1,3,1,' RA184529526CN\r','cnfaner\rHBPH007'),(21700,786199193007,170746939505,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.31,'au-buy','silent_g118','angus.cornwell@exemail.com.au','Angus Cornwell','41 Reiby St','Newtown','New South Wales','AUSTRALIA','2042','0419217746','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 07:08:03',0,NULL,3,1,11,1,NULL,'au-buy\rMOAP001'),(21701,933861673012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','patrickjoseph3810','patrickjgatt@onvol.net','Patrick J Gatt','Valentine Rose<br>Triq il-Barjol','Mosta','MOSTA','MALTA','MST4471','00356 99801277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 07:51:54',0,NULL,3,1,21,1,'RA184519183CN\r ','eastar4uk\rOTCN004*10'),(21702,843452251011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','stokeysime','simon.wood8@bigpond.com','simon wood - mindarie car hire','41 Boranup Avenue','Clarkson','Western Australia','AUSTRALIA','6030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 08:22:12',0,NULL,3,1,3,1,'RA184529591CN\r','eastar4\rGPS0007'),(21703,8881329121539808,111,'CAB-6060',1,'CASS003',0,'eastar4','stevotone','stephen.winter@roche.com','Stephen Winter','Deskside Support, Roche Products<br>6 Falcon Way, Shire Park','Welwyn Garden City','Hertfordshire','UNITED KINGDOM','AL7 1TW','07969688934',NULL,NULL,NULL,'2012-02-13 08:25:39',0,NULL,3,1,11,1,NULL,'CASS003\r补发的 '),(21704,933882090012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','freyaru11','freyaru11@hotmail.com','James Lewis','8315 SE Stark St<br>Apt 7','portland','OR','UNITED STATES','97216-1144','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 09:00:40',0,NULL,3,1,1,1,'LK197867496CN\r ','eastar4'),(21705,843465795011,320730548951,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',78.99,'eastar4uk','aussiedene','denefrench@gmail.com','Dene French','11 Alyce Close','Bolwarra Heights','New South Wales','AUSTRALIA','2320','610249385545','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 09:15:42',0,NULL,3,1,3,1,'RA184519166CN\r ','eastar4uk\rGLOT001*3'),(21706,786545685007,170762819424,'Brand new HP MCE Media Center + microsoft Remote Control + IR RECEIVER',4,'OTHP006',78.6,'au-buy','protocorp77','sent.to.inbox@gmail.com','Mathew Godan','30 Mulgrave Rd (On Third Ave Turn Into Bulloo St Then Mulgrave)<br>Marsden','Brisbane','Queensland','AUSTRALIA','4132','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 08:58:42',0,NULL,3,1,3,1,'RA184594666CN ','au-buy\rOTHP006'),(21707,8881329124819023,111,'Free Shipping & Tracking # !!! New Fire-Pad Professional FPS Gaming Game Surface Mouse Pad - ',1,'MOFP001',6.99,'aliexpress','1006724257','thespawn1965@hotmail.com','Sylvain Lefebvre','3555 BERRI RUE APT 1206,MONTREAL','MONTREAL','Quebec','CANADA','H2L 4G4','+514 238 4525',NULL,NULL,NULL,'2012-02-13 09:20:19',0,NULL,3,1,3,1,' RA184529614CN\r','MOFP001 '),(21708,933889427012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',4,'OTCN003',19.96,'eastar4uk','4gwaun','it.is@hotmail.co.uk','Anne Lloyd','4 GWAUN COTTAGES<br>Llanharry Meadow','Pontyclun Mig Glamorgan','Rhondda Cynon Taff','UNITED KINGDOM','CF729LW','07722396611','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 09:23:50',0,NULL,3,1,3,1,'RA184519206CN\r ','eastar4uk\rOTCN003'),(21709,8881329128476612,111,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',0,'eastar4','ingenieur_boeblingen','andreas.heintze@o2online.de','Andreas Heintze','Schwabstraße 10','Böblingen','','GERMANY','71032','',NULL,NULL,NULL,'2012-02-13 10:21:16',0,NULL,3,1,22,1,'BJ01715677\r ','只补发个耳机\rHSJA002 '),(21710,843510995011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','viking2seafarer','munroian@bigpond.com','ian Munro','10 Taperell drive','Tugun','Queensland','AUSTRALIA','4224','0402146520','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 11:50:12',0,NULL,3,1,3,1,'RR658650434CN\r ','eastar4\rLGRM001'),(21711,843545628011,320730551325,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E card',1,'WLIN016',13.99,'eastar4uk','14daviddn','david@sithlord.co.uk','David Pollicott','59, Wessex Drive','Cheltenham','Gloucestershire','UNITED KINGDOM','GL525AF','01242252385','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 13:31:43',0,NULL,3,1,3,1,'RR658650859CN\r ','eastar4uk\rWLIN016\r'),(21712,797128745001,110819087341,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'buysia','slayersa','antislon@mail.ru','Sergey Potuzhnyy','Sovetskaya 86, kv 27.','Noyabrsk','YNAO','RUSSIAN FEDERATION','629807','7(961)5525252','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-13 14:21:58',0,NULL,3,1,11,1,'BJ01715681 ','buysia\rBALO001'),(21713,680954011013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mikhail_russia_2008','m_krasnopolskiy@mail.ru','Mikhail Krasnopolskiy','Moscow ave h133 f 44','Voronezh','','RUSSIAN FEDERATION','394005','+7(920)225-55-43','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 14:22:40',0,NULL,3,1,11,1,'BJ01669293\r ','eastar4\rCACN004'),(21714,933997041012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','chocolatecherub2004','keri@twolittleflowers.com','Keri Barr','64 Harcourt Road','Bushey','Hertfordshire','UNITED KINGDOM','wd23 3pe','07980956620','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 14:37:17',0,NULL,3,1,3,1,'RR658650814CN ','eastar4uk\rSAFI001'),(21715,843570469011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','snowdude124','dsn35155@bigpond.net.au','David Snowman','6 Eradu Ramble','Hocking','Western Australia','AUSTRALIA','6065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 14:37:30',0,NULL,3,1,3,1,'RR658650981CN\r ','eastar4\rHSUE002\r\r新地址\rDavid Snowman\r22 Heacham avenue\rhocking 6065\rWestern Australia\rAUSTRALIA\r'),(21716,934022461012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','roadpirates','drummerzone77@gmail.com','Macca Francesco','175, Sullivan Road','Coventry','Warwickshire','UNITED KINGDOM','CV6 7JU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 15:34:59',0,NULL,3,1,11,1,'BJ01715694\r ','eastar4\rTRMX003'),(21717,680966840013,230445490260,'NEW Atheros AR5008 802.11N 300M Wireles Mini PCI-E Card',1,'WLAT001',13.99,'eastar4','ebekman','ebekman@gmail.com','Eduardo Bekman','Av Almirante Barroso 52 / 21º Andar (BRR)','Rio de Janeiro','RJ','BRAZIL','20031-000','+552182221963','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 15:47:30',0,NULL,3,1,11,1,'BJ01669289\r ','eastar4\rWLAT001'),(21718,934032225012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',175.99,'eastar4','snacks09','lanamodell@yahoo.com','Lana O\'Dell','5115 B Sayers Court','Fort Polk','LA','UNITED STATES','71459','(337) 404-3318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 15:55:47',0,NULL,3,1,1,1,'LK197480866CN\r ','eastar4'),(21719,626159437004,140676374196,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',77.99,'cnfaner','crhstuff','harleyspringer94@aol.com','Cheryl Haumann','2382 Council Rd','Graham','NC','UNITED STATES','27253-9410','(336) 222-0300','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-13 16:21:14',0,NULL,3,1,1,1,'LK187393204CN\r ','cnfaner'),(21720,620812253003,130620864552,'2 pairs of new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005*2',108.99,'cnfaner','klekovkinav','promoprotein@gmail.com','Alexander Klekovkin','ul. Pirogova<br>78 - 296','Stavropol','Stavropolskiy krai','RUSSIAN FEDERATION','355011','7-928-630-77-22','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 17:01:54',0,NULL,3,1,3,1,'RR184508217CN\r ','cnfaner\rGLOT005*2'),(21721,934104565012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4uk','ian_net','ian.on.the.net@ntlworld.com','Ian Charles Gilbert','18 Luke Street','Eynesbury , St. Neots','Cambridgeshire','UNITED KINGDOM','PE19 2TP','01480350918','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 18:09:08',0,NULL,3,1,3,1,'RR658650845CN ','eastar4uk\rOTCN003'),(21722,934108997012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','jennyradio','jenny@becomex.com','Has','Burg. A Campostraat 17','Hulsberg','','NETHERLANDS','6336BN','0455335007','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 18:16:05',0,NULL,3,1,11,1,'BJ01669312\r ','eastar4\rBTHP2007\rHP 8pin 1.0 23cm '),(21723,843671815011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','sakapfet1','oneloveformypeople@hotmail.com','Frédérick Vital','5915 Airport Rd  Suite 415','Mississauga','ON','CANADA','L4V 1T1','(905) 678-9818 ext.: 236','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 18:17:44',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA002'),(21724,625648420004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',5,'WLAP008',99,'cnfaner','darkcynnr','darkcynnr@email.com','Yuri Radzik','2216 T St<br>Apt 2','Sacramento','CA','UNITED STATES','95816-7136','(916) 284-4153','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-13 18:26:56',0,NULL,3,1,1,1,'LK198372307CN\r ','cnfaner'),(21725,843681567011,320730083814,'Bracket of MINI HALF WLAN/WIFI/WIRELESS CARD to PCI-E',1,'MOCN001',4.99,'eastar4uk','lemarq5830','lemarq.nho@terra.com.br','Lezandro Marquardt','Rua Senador Salgado Filho 257/302 - Centro','Esteio','Rio Grande do Sul','BRAZIL','93260140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 18:32:05',0,NULL,3,1,11,1,'BJ01669317\r ','eastar4uk\rMOCN001'),(21726,843700108011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','nikituk1','jt57@mail.adsl4less.com','Nicola Tranter','1 Elderside Close<br>Brownhills','Walsall','West Midlands','UNITED KINGDOM','WS8 6HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 19:01:45',0,NULL,3,1,3,1,'RR658650978CN\r ','eastar4uk\rGLOT001'),(21727,934145070012,220815927687,'Allied Telesyn CentreCOM AUI Ethernet 10Base-T 210T',1,'TRTT002',6.99,'eastar4uk','go-go-boss','ken@eirss.ie','Ken OHara','Lacken House<br>Lacken','Blessington','Wicklow','IRELAND','default','0876622889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 19:10:25',0,NULL,3,1,3,1,'RR658650893CN ','eastar4uk\rTRTT002'),(21728,934155894012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','howington2005','cajundawgma@yahoo.com','paul howington','7240 vance rd','kernersville','NC','UNITED STATES','27284-7223','(336) 993-4745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 19:24:13',0,NULL,3,1,1,1,'LK198075167CN\r ','eastar4'),(21729,680832449013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','ktdramas','ktdramas@yahoo.com.hk','Kenny Kwan','1040 S Vail Ave','Montebello','CA','UNITED STATES','90640-6020','(626) 487-9088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 19:24:42',0,NULL,3,1,1,1,'LK196325701CN\r ','eastar4'),(21730,681084842013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',3,'GLOT005',167.1,'eastar4','petina24','heine_66@hotmail.com','Petra Pápai','Nagy Imre út 18.','Győr','Győr-Moson-Sopron','HUNGARY','9024','06306469410','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 20:16:04',0,NULL,3,1,3,1,'RA184508486CN ','eastar4\rGLOT005'),(21731,934193701012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','rree4490','ray.reeves@gmail.com','Smoky Mountain Escapes - Reeves','2046 Upper Middle Creek Rd','Sevierville','TN','UNITED STATES','37876-7489','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 20:18:16',0,NULL,3,1,1,1,'LK198440231CN\r ','eastar4'),(21732,620896840003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','kirkw50kirk','kirkw50@yahoo.com','Kirk Wilson','18105 Marina way','Garrison','MN','UNITED STATES','56450-9690','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-13 20:29:26',0,NULL,3,1,1,1,'LK181236625CN\r ','cnfaner'),(21733,780378648008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',2,'BALO009',15.98,'au-buy','bradalwes1','bradalwes@msn.com','James Alwes','16100 NE 13th Cir','Vancouver','WA','UNITED STATES','98684-4164','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 20:46:10',0,NULL,3,1,1,1,'LK197771135CN ','au-buy'),(21734,788655625007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','mlh2005','hudcon@bigpond.net.au','Marina  Huddleston','P.O Box  415<br>KENMORE','Brisbane','Queensland','AUSTRALIA','4069','0733743015','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 20:43:00',0,NULL,3,1,11,1,'BJ01715688 ','au-buy\rOTGR001'),(21735,934239886012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','japicius','felicianojuarez@gmail.com','Feliciano Juarez Lozano','CNP Insurance Services, S.A.<br>Ochandiano 10, 2a planta','Madrid','Madrid','SPAIN','28023','915243400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 21:28:25',0,NULL,3,1,3,1,'RR658650902CN ','eastar4uk\rRCLO006'),(21736,843835792011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','raenuja','solomanz@hotmail.com','P Senn','56 Hill crescent, Worcester Park','Sutton','Surrey','UNITED KINGDOM','KT4 8NA','07877491043','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 22:54:14',0,NULL,3,1,3,1,'RR658650964CN\r ','eastar4uk\rGLOT001'),(21737,681143787013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',55.7,'eastar4','jaydubya14','jwiduch@gmail.com','John Widuch','2300 Adler Ct','Lisle','IL','UNITED STATES','60532-2001','(630) 624-2081','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 23:03:00',0,NULL,3,1,1,1,' LK196935416CN','eastar4'),(21738,843846851011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','lancastercomputers','wayne.ward@lancastercomputers.co.uk','Wayne Ward','18 Lymm Ave','Lancaster','Lancashire','UNITED KINGDOM','LA15DA','07957448652','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 23:23:09',0,NULL,3,1,3,1,'RA184538602CN\r ','eastar4uk\rMOAP001'),(21739,843845153011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tickertoo','diann-pavelka@uiowa.edu','Diann L. Pavelka','600 E Main St','Lisbon','IA','UNITED STATES','52253-9749','(319) 335-4063','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 23:19:17',0,NULL,3,1,1,1,'LK198157135CN\r ','eastar4'),(21740,934312958012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','meeasf','ziafarooq@gmail.com','Shazia Farooq Zia','Goeschlgasse 12/7','Wien/Vienna','','AUSTRIA','1030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 00:11:30',0,NULL,3,1,11,1,'BJ01669305\r ','eastar4\rBTAC2005\racer 4pin1.25 8cm '),(21741,934330169012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',3,'TRMX003',29.97,'eastar4','sam13hain','daniel.chartrand@gmail.com','daniel chartrand','7440 perce neige','st-hubert','QC','CANADA','j3y 0a3','(514) 705-1553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 01:01:38',0,NULL,3,1,11,1,'BJ01715699\r ','eastar4\rTRMX003'),(21742,841824461002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','2012adamsr','raymondadams@nf.sympatico.ca','Raymond Adams','78 major','Roddicckton','NL','CANADA','A0K 4P0','(709) 457-2407','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-14 01:25:20',0,NULL,3,1,3,1,'RR658650301CN ','buysia\rGPS0004'),(21863,935398468012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',2,'GLOT001*2',177.98,'eastar4','izy4','israel.mcgregor@ge.com','Israel McGregor','15/99-103 Saddington street','St Marys','New South Wales','AUSTRALIA','2760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 02:45:48',0,NULL,3,1,4,1,'YW868897510CN ','eastar4'),(21743,788784816007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','pixcy04','pixcy04@yahoo.com','melaine fowler','101 meadowglen dr','madison','AL','UNITED STATES','35757-7670','(615) 500-0245','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 02:31:19',0,NULL,3,1,1,1,' LK191159021CN','au-buy'),(21744,934364916012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','guardrail7','guardrail871@aol.com','BRIAN CAREY','1136 Westbrook Dr','KINGSPORT','TN','UNITED STATES','37663-2427','(423) 239-0360','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 02:47:01',0,NULL,3,1,1,1,' LK199103160CN','eastar4'),(21745,841861121002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','joe-nna','joehanna@ican.net','Joseph Hanna','2258 Mondavi St','Orleans','ON','CANADA','K4A4S5','(613) 868-8882','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-14 03:19:45',0,NULL,3,1,3,1,'RR658650275CN ','buysia\rLGAD001'),(21746,843932174011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','itiroroberto','odontologica@msn.com','Itiro Roberto Yoshiyasu','R. Vitorio Sbalqueiro, 174 casa 5','Curitiba','Parana','BRAZIL','82100060','55 41 33237517','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 04:02:04',0,NULL,3,0,11,1,'BJ01669330\r ','eastar4'),(21747,788821608007,170728982479,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'au-buy','cozdavo','cozdavo@hotmail.com','maya barnes','92 heath st','broulee','New South Wales','AUSTRALIA','2537','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 05:01:13',0,NULL,3,1,3,1,'RR658650235CN ','au-buy\rGPS0004'),(21748,934410402012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','akiwi6620','curbwhacker@yahoo.com','Peggy S Bartling','818 Remington St','Fort Collins','CO','UNITED STATES','80524-3335','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 05:38:34',0,NULL,3,1,1,1,'/ ','eastar4'),(21749,843953506011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',5,'HSNO019+CCNO001',214.95,'eastar4','jukmak','shaka@finx.org','Jukka Mäkelä','Hiekkatie 1','Rahkonen','','FINLAND','68390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 05:43:16',0,NULL,3,1,3,1,'RR658650394CN\r ','eastar4\rHSNO019+CCNO001'),(21750,797488505001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','kuzyanov2011','agroprom-tex@bk.ru','Kuzyanov Nickolay','Sovnarkomovskay 26-39','Nizhny Novgorod','Nizhegorotskaya','RUSSIAN FEDERATION','603086','(790)360-37677','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-14 06:18:45',0,NULL,5,1,18,0,NULL,'buysia\rHSJA002\r欧标\rAC adapter  ebay 发警告\r已退款'),(21751,843960158011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','kuzyanov2011','agroprom-tex@bk.ru','Kuzyanov Nickolay','Sovnarkomovskay 26-39','Nizhny Novgorod','Nizhegorotskaya','RUSSIAN FEDERATION','603086','(790)360-37677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 06:21:09',0,NULL,3,1,11,1,'BJ01714408\r ','eastar4\r欧标\rHSJA002   \r由于 ebay 发警告\r客户又买了一次，就发这个吧'),(21752,681246096013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',4,'WLAT009+ANTY001',47.92,'eastar4','kazuyukisakoda1970','kazuyukisakoda@gmail.com','Kazuyuki Sakoda','5-1-12 Kitashinagawa','Shinagawa-ku','Tokyo','JAPAN','1410001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 07:19:48',0,NULL,3,1,3,1,'RR658650111CN\r ','eastar4\rWLAT009+ANTY001'),(21753,843972071011,320814060092,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',146.99,'eastar4','hamann-mmm','liga74@inbox.ru','Alexander Matskevich','Miliceyskaya','Chelyabinsk','RUSSIA','RUSSIAN FEDERATION','454028','89080509991','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 07:25:19',0,NULL,3,1,3,1,'RR658650200CN ','eastar4\rSAFI001*3'),(21754,843973070011,320737041206,'4 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*4',127.99,'eastar4uk','podani1981','podani@gmail.com','Daniel Pocsi','Szentendrei ut 109','Tahitotfalu','','HUNGARY','2022','+36303990289','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 07:29:18',0,NULL,3,1,3,1,'RA184508438CN ','eastar4uk\rGLOT005*4\r'),(21755,621039810003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',2,'OT00002',25.8,'cnfaner','harrismeh9','ebay@twharris.org','Marion Harris','2057 E Otero Ln','Centennial','CO','UNITED STATES','80122-3248','(303) 795-2458','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-14 07:39:35',0,NULL,3,1,1,1,'/ ','cnfaner'),(21756,797516910001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',39.98,'buysia','714ajay','ajay@kumba.com','Ajay Manaktala','1014 London Cir','Placentia','CA','UNITED STATES','92870-4335','(714) 366-6565','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-14 08:07:00',0,NULL,3,1,1,1,' LK198770887CN','buysia'),(21757,934446858012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','shadowkka','budaevkv@gmail.com','Konstantin Budaev','Yunosti, 9, 102','Zelenograd','Moscow','RUSSIAN FEDERATION','124482','+79652916030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 08:34:29',0,NULL,3,1,11,1,'BJ01669311\r ','eastar4\rMOMI002'),(21758,681256632013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','acudoc2007','drlrose@bigpond.com','Leonard Rose','35 Eucalypt Ave','Lower Templestowe','Victoria','AUSTRALIA','3107','0398484898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 08:31:34',0,NULL,3,1,3,1,'RR658650862CN ','eastar4\rGLSG009*3'),(21759,934454607012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','toddsmall','toddzilla305@gmail.com','Todd Small','2102 Alton Rd<br>Apt 1','Miami Beach','FL','UNITED STATES','33140-4549','(786) 709-6276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 09:06:52',0,NULL,3,1,1,1,'/ ','eastar4'),(21760,780596929008,180810122944,'New ATA33 40 Pin to 40 Pin 3.5\" male to female Desktop IDE Hard Drive Cable 30cm',1,'OTCN002',6.98,'au-buy','jaenrock','rmasoft@hotmail.com','RAFAEL EDUARDO MARQUEZ ARROYO','C/ FERMIN PALMA, 2 - 1º DCHA','JAEN','Andalucía Ceuta y Melilla','SPAIN','23008','652179540','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 09:28:36',0,NULL,3,1,11,1,'BJ01669324\r ','au-buy\rOTCN002'),(21761,780603986008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','prettythings00','prettythings00@optusnet.com.au','margot clarke','19 surrey street','east bentleigh','victoria','AUSTRALIA','3165','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 09:56:29',0,NULL,3,1,11,1,NULL,'au-buy\rUM00043'),(21762,844012742011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',16.54,'eastar4uk','kootoo75','adam.parts@gmail.com','PLEE Nicolas - Data Up','13 rue Bonaparte','Paris','Ile-de-France','FRANCE','75006','0660283597','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 10:17:24',0,NULL,3,1,11,1,'BJ01669326 ','eastar4uk\rCACN004'),(21763,621067174003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','waz_up777','coop123@gmail.com','R Cooper','1562 Danforth Ave.<br>Box 72063','Toronto','ON','CANADA','M4J 1N4','(647) 241-4968','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 10:24:32',0,NULL,3,1,3,1,'RA184519339CN ','cnfaner\rHBPH009'),(21764,934483196012,220449528076,'100% NEW DB60 Serial DCE / DTE back to back Cable 3 ft',1,'CASS002',9.99,'eastar4','darkb91','brahim.s@gmail.com','Brahim SAHFA','30 Bis Rue Gaston Meunier','JUVISY-SUR-ORGE','Ile-de-France','FRANCE','91260','+33660259832','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 10:47:35',0,NULL,3,1,11,1,'BJ01669319\r ','eastar4\rCASS002'),(21765,934490550012,220689444211,'New IBM Unlocked MC8775 WWAN Card  X61 T61 R61 Z60',1,'WWSI002',29.88,'eastar4','christoph5670','anwatfa@advancedce.fr','George Watfa','900 E Vermont Ave<br>Aim Telecom','Anaheim','CA','UNITED STATES','92805-5615','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 11:10:38',0,NULL,3,1,1,1,'/ ','eastar4'),(21766,620171991003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','opokr','pokryshko@ukrpost.ua','Pokryshko Oleg Aleksandrovich','Polkovnika D.Nechaya, 16','Ternopol','','UKRAINE','46000','0673510710','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 11:30:38',0,NULL,3,1,3,1,'RR658650244CN ','cnfaner\rOT00002'),(21767,780643675008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',46.99,'au-buy','the_councillor','gavstollar@hotmail.com','G P Stollar','1 View Point<br>1475 High Road','London','London','UNITED KINGDOM','N209PL','02084455603','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 12:27:28',0,NULL,3,1,3,1,'RR658650160CN ','au-buy\rHBPH007'),(21768,797623657001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'buysia','sno-ape','dbeaudoin@telus.net','Denis Beaudoin','P.O. box 511','Bellevue','AB','CANADA','T0K0c0','(403) 563-0449','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-14 14:44:07',0,NULL,3,1,3,1,'RR658650403CN ','buysia\rGPS0006'),(21769,934575557012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT001',53.98,'eastar4uk','booleypaul','bholapeter@yahoo.co.uk','peter bhola','17 somerset road','southall','Middlesex','UNITED KINGDOM','ub12tz','07944920190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 15:11:05',0,NULL,3,1,3,1,'RA184538514CN\r ','eastar4uk\rGLOT001'),(21770,934586502012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','kracuc','kracuszek@gmail.com','Pawel Kracki','Gornoslaska 14/408A','Warszawa','mazowieckie','POLAND','00432','508 406738','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 15:37:00',0,NULL,3,1,11,1,'BJ01669320\r ','eastar4uk\rSCLO004'),(21771,934145830012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','kkaufman98','kevman24@yahoo.com','Kevin Kaufman','1626 Natural Bridge Dr','Frisco','TX','UNITED STATES','75034-4352','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 16:44:48',0,NULL,3,1,1,1,'/ ','eastar4'),(21772,934648968012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','eaststageing','paypal@eaststageing.com','Philip Bennett','6 lyon Close<br>Ipswich','Kesgrave','Suffolk','UNITED KINGDOM','IP5 2XW','07928500275','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 17:43:06',0,NULL,3,1,3,1,'RA184529319CN\r ','eastar4uk\rOTCN004*10'),(21773,681399716013,230498933544,'2.1 Acer Aspire 4745 4820T Bluetooth Module EDR + cable',1,'BTAC2110',12.39,'eastar4','mohonkosergey','mohonko@yandex.ru','Мохонько Сергей Николаевич','ул. Казанская д. 34 кв. 5','Санкт-Петербург','AL','RUSSIAN FEDERATION','190031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 18:18:38',0,NULL,3,1,11,1,'BJ01669302\r ','eastar4\rBTAC2110\racer 5pin 1.0 3cm '),(21774,837602642011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','rb80sbaby','rb89@live.co.uk','sandra brown','177 Millicent Fawcett<br>Pembury Road','London','London','UNITED KINGDOM','n17 6sy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 18:39:29',0,NULL,3,1,3,1,'RA184508543CN\r ','eastar4uk\rOTES001'),(21775,844204956011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','mjat23','mjat23@btopenworld.com','Martin Johnson','45 Lowlands Drive<br>Stanwell','Staines','Middlesex','UNITED KINGDOM','TW19 7JX','07949118190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 18:40:15',0,NULL,3,1,3,1,'RA184538576CN\r ','eastar4uk\rMOAP001'),(21776,626565157004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','biscuit686','dimych182@gmail.com','Navitski Siarhei','pr-t. Stroiteley 4 - 197','Vitebsk','','BELARUS','210027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 19:19:19',0,NULL,3,1,3,1,'RR658650292CN ','cnfaner\rCACN004'),(21777,789091880007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','johnc1013','clarkshouse@hotmail.co.uk','John  Clark','U80. 88-98 Limetree Paarade','Runaway Bay','Queensland','AUSTRALIA','4216','0450339912','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 19:25:35',0,NULL,3,1,11,1,'BJ01715693 ','au-buy\rOTGR001'),(21778,934706781012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',10,'MOAP001',279.9,'eastar4','youtube12345','1a1z2s2x@gmail.com','Dennis Arculeo','200 MADISON AVE','NEW YORK','NY','UNITED STATES','10016-3903','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 19:38:31',0,NULL,3,1,4,1,' YW868897635CN','eastar4'),(21779,934720786012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Molly Vilhauer','1520 Kensington Rd<br>Ste 115','Oak Brook','IL','UNITED STATES','60523-2140','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 19:44:01',0,NULL,3,1,1,1,'/ ','eastar4'),(21780,844294399011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','torditoreal','peypil@hotmail.com','Jose Vazquez Barberan','Raco de San Llorens 1 Bajo','Alboraya','Comunidad Valenciana','SPAIN','46120','630550314','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 21:13:11',0,NULL,3,1,11,1,NULL,'eastar4\r欧标\rHSJA002'),(21781,626631043004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','cameramen','nautilus@te.net.ua','Viktor  Nikitiuk','Filatova str. 49/2 apt. 98','Odessa','','UKRAINE','65074','380677253250','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 22:30:29',0,NULL,3,1,3,1,'RR658650258CN ','cnfaner\rHBPH007'),(21782,844343385011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','tabd5316','tarekpathology@hotmail.com','tarek abdl-fatah','18 chilwell street<br>lenton','nottingham','Nottinghamshire','UNITED KINGDOM','ng7 1sb','01159240821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 22:59:58',0,NULL,3,1,3,1,'RA184538593CN\r ','eastar4uk\rGLOT001'),(21783,844346651011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','gapark','grahamapark@supanet.com','Graham A Park','10 Carlin Terrace, Dyce','Aberdeen','Aberdeenshire','UNITED KINGDOM','AB21 7JR','01224723268','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 23:49:27',0,NULL,3,1,3,1,'RA184538528CN\r ','eastar4uk\rGLOT001'),(21784,797866528001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'buysia','jerry2239','geraldstevens03@aol.com','Gerald Stevens','526 Yankee Point Rd','Lancaster','VA','UNITED STATES','22503-4021','(804) 462-0529','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 00:14:11',0,NULL,3,1,1,1,'/ ','buysia'),(21785,621296439003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','sly7449','sly7449@comcast.net','Malcolm Sylvester','2076 Shamrock Dr','Decatur','GA','UNITED STATES','30032-5953','(404) 343-1391','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 00:16:55',0,NULL,3,1,1,1,'LK198163745CN','cnfaner'),(21786,681527829013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',4,'CASS001',39.96,'eastar4','monczko','monczko@mac.com','Barry Monczko','12 Horizon Ave','Ashmore','Queensland','AUSTRALIA','4214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 00:31:50',0,NULL,3,1,11,1,'BJ01669316\r ','eastar4\rCASS001'),(21787,681532717013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','superstar-rach','rachel.gamble@derby.gov.uk','Rachel Gamble','44 Malham Road<br>Littleover','Derby','Derbyshire','UNITED KINGDOM','DE23 3RW','01332441505','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 00:59:58',0,NULL,3,1,3,1,'RR658650195CN\r ','eastar4\rLGAD001'),(21788,934875759012,220708807209,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',40.8,'eastar4','steveljack','jacks@stgeorge.com.au','Steve Jack','c/o St George Bank IT<br>4-16 Montgomery St','Kogarah','New South Wales','AUSTRALIA','2217','0407289060','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 01:11:47',0,NULL,3,1,3,1,'RR658650187CN ','eastar4\rWWOT001'),(21789,844391216011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','4765gary','quattrodoc@aol.com','Gary Karl','7517 Rushing Current St','Las Vegas','NV','UNITED STATES','89131-2534','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 01:24:07',0,NULL,3,1,1,1,'/ ','eastar4'),(21790,842325909002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','scottsanderson012012','scott.sanderson01@gmail.com','Scott Sanderson','7562 Sherwood Rd','Woodbury','MN','UNITED STATES','55125-2841','(651) 785-7781','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 02:58:25',0,NULL,3,1,1,1,'/ ','buysia'),(21791,780987232008,180758271107,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',5.9,'au-buy','nohj44','ijsygent@tpg.com.au','John Gent','179 Tamar St','Ballina','New South Wales','AUSTRALIA','2478','0266864493','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 03:10:04',0,NULL,3,1,11,1,'BJ01669240\r ','au-buy\rSCLO005'),(21792,681562009013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','cheriwilson','cheriwilson@yahoo.com','Cheri Wilson','N16550 County Road D','Owen','WI','UNITED STATES','54460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 03:16:12',0,NULL,3,1,1,1,'/ ','eastar4'),(21793,797920107001,110819588427,'Logitech Charging Cradle L-LG7 for Harmony 880 890 Pro',1,'CRLO002',9.9,'buysia','mdowns.312','mdownz@sbcglobal.net','Michael Downs','400 N La Salle Dr<br>Apt 4510','Chicago','IL','UNITED STATES','60654-8538','(312) 670-2365','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 03:23:53',0,NULL,3,1,1,1,'/ ','buysia'),(21794,934925041012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','akinsdf','ddac@ddac.us','D.D. Akins Comptronics','2548 Highgate Dr','Richmond','CA','UNITED STATES','94806-5258','(510) 455-0615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 03:38:05',0,NULL,3,1,1,1,'/ ','eastar4'),(21795,8881329277284141,111,'New in box TWINBIRD HC-4107 Mini cleaner for PC - ',1,'OTTB001',15.99,'aliexpress','1006778702','luisaugustodias@bol.com.br','Luis Augusto Dias','av berenice magalhaes, 335 lj7 ','igarape','minas gerais','BRAZIL','32900000','+51 31 35345727',NULL,NULL,NULL,'2012-02-15 03:41:24',0,NULL,3,1,3,1,'RR658650831CN ','OTTB001 '),(21796,8881329277502329,111,'New in box SONY 3D Active Glasses TDG-BR250 rechargeable - ',1,'OTSO004',89.99,'aliexpress','1006777393','dryko1977@hotmail.com','adriano carvalho','Rua Aracoiaba da Serra 395 ','Guarulhos','Sao Paulo','BRAZIL','07132-030','67264843/ +55 11 49622274',NULL,NULL,NULL,'2012-02-15 03:45:02',0,NULL,3,1,3,1,'RR658650947CN ','OTSO004 '),(21797,842354173002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','taka-talk','meow_kick@live.jp','TAKAKO HASHIMOTO','1918-2-803, Harada-cho','Marugame','Kagawa','JAPAN','763-0074',' 09031840785','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 04:56:27',0,NULL,3,1,3,1,'RR658650289CN ','buysia\rMOLO001'),(21798,626717981004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',55.45,'cnfaner','garyckys','garyckys@yahoo.com','Mr Gary Chong UMobile Sdn Bhd','Level 8, Postal No 08-16 to 08-18 Berjaya Time Square,<br>1, Jalan Imbi','Kuala Lumpur','','MALAYSIA','55100','0182998123','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 05:48:13',0,NULL,3,1,3,1,'RR658650227CN ','cnfaner\rWWSI006'),(21799,797950940001,110819087341,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'buysia','hbellos2012','helloheidi2008@yahoo.com','Heidi Bellos','2800 E 12th st','Kansas City','MO','UNITED STATES','64127-1324','(816) 695-7344','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 06:22:14',0,NULL,3,1,1,1,'/ ','buysia'),(21800,781032267008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'au-buy','kapanarm','armen.mkrtchyan777@gmail.com','Armen3749454978 Mkrtchyan','Saryan str. 20 apartment 37','Erevan','','ARMENIA','0002','0037494549898','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 06:48:47',0,NULL,3,1,11,1,'BJ01669329\r ','au-buy\rSCLO004'),(21801,844478541011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','funatics1raudel','munozraudel@ymail.com','raudel munoz','1170 N Gilbert St','Anaheim','CA','UNITED STATES','92801-1401','(562) 644-2328','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 07:27:54',0,NULL,3,1,1,1,' LK198534764CN','eastar4\rHSJA011\r再发一个New Jabra BT500v BT 500v wireless Bluetooth Headset'),(21802,844485235011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','funatics1raudel','munozraudel@ymail.com','raudel munoz','1170 N Gilbert St','Anaheim','CA','UNITED STATES','92801-1401','(562) 644-2328','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 07:53:24',0,NULL,8,1,17,0,NULL,'eastar4'),(21803,8881329293668777,111,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E card',1,'WLIN016',0,'eastar4','fprl92','fponetouch@gmail.com','PIERRELLE Fabrice','33 rue de Neuilly','CLICHY la GARENNE','Ile-de-France','FRANCE','92110','0650674512',NULL,NULL,NULL,'2012-02-15 08:14:28',0,NULL,3,1,11,1,'BJ01669298\r ','补发的 '),(21915,845439651011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',15,'HSUE002',299.85,'eastar4','buyjapan001','ebaycustomers001@yahoo.com','Nickie Shibuya','Horiguchi 7D-305 mezon noukendai<br>Kanazawaku','Yokohamasi','Kanagawa','JAPAN','2360054','+81-45-788-2769','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 03:04:16',0,NULL,3,1,3,1,'RA184524400CN ','eastar4\rHSUE002\r电话号码写在包装上81-45-788-2769\r'),(21804,8881329295855071,111,'Brand new HP MCE Media Center + Sony Remote Control RM-MCE10E',1,'RMSN003',0,'cnfaner','dperec11','damir.perec@gmail.com','Damir Perec','Josipa Strganca 2','Zagreb','','CROATIA','10090','',NULL,NULL,NULL,'2012-02-15 08:50:55',0,NULL,5,1,18,1,NULL,'RMSN003\r补发\r这个产品已经下架了\r已退款'),(21805,844500288011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',44.89,'eastar4','magic-toon','fabien.edouard@wanadoo.fr','FABIEN EDOUARD','36 boulevard PASTEUR','LE COTEAU','Rhône-Alpes','FRANCE','42120','06.87.09.79.30','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 08:58:56',0,NULL,3,1,3,1,'RR658650125CN ','eastar4\rGLOT001'),(21806,844513827011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','dimkra','kramoney@yandex.ru','Vodolaz Boris','Klubnaya, 10a, kv.12','Rostov-na-Donu','','RUSSIAN FEDERATION','344112','(903) 401-8990','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 09:50:56',0,NULL,3,1,11,1,'BJ01669300\r ','eastar4\rHSNO007\r欧标'),(21807,789366791007,170775756264,'New 40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',5.98,'au-buy','ant0nyk1ng','antony_king@hotmail.com','Antony King','16 Mary Orr Ct','Camp Mountain','Queensland','AUSTRALIA','4520','0412722185','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 10:31:45',0,NULL,3,1,11,1,'/ ','au-buy\rOTCN001'),(21808,626759181004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','shkiper82','bankir82@rambler.ru','Svetenjuk Vitalii','8-March 4-7','Omsk','Omskaya Obl','RUSSIAN FEDERATION','644010','+79139705254','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 10:32:07',0,NULL,3,1,3,1,' RA184508150CN','cnfaner\rOEM\rMN1000B\rNew SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"\r已付差价\r'),(21809,935022231012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Diana Fernandez','253 Passaic Ave<br>Canfield Scientific, Inc.','Fairfield','NJ','UNITED STATES','07004-2534','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 10:32:35',0,NULL,3,1,1,1,'/ ','eastar4'),(21810,681637003013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','moss.adrian.526','mossy_526@live.com.au','Adrian Moss','485 limestone ck rd','Yeppoon','Queensland','AUSTRALIA','4703','0749394430','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 10:46:58',0,NULL,3,1,3,1,'RA65865045CN ','eastar4\rGPS0004'),(21811,681640922013,230719934938,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.99,'eastar4','geradip','makisadipas@gmail.com','Makis Antipas','Kifissias 44 Avenue<br>Cosmote SA, Building A','Maroussi','Athens, Attiki, Greece','GREECE','15125','0030 6984111522','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 11:03:38',0,NULL,3,1,11,1,'BJ01669327\r ','eastar4\rMOHP002'),(21812,626770428004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','pepepotamopantuflo','jmruizbueno@wanadoo.es','JOSE MARIA RUIZ BUENO','Aldebarán, 21; casa 17 - 1ºA','ZARAGOZA','Aragón','SPAIN','50012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 11:26:21',0,NULL,3,1,3,1,'RR658650261CN ','cnfaner\rBALO007'),(21813,935045939012,220908829691,'4 pairs of New 3D Active Shutter TV Glasses compatible 4 3D TV Sony  LG samsung',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 11:51:32',0,NULL,3,1,4,1,'YW868897495CN ','eastar4uk'),(21814,789393038007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','urmila60','urmila_sharma@hotmail.com','Urmila Sharma','148 Minchin Drive','Minchinbury','New South Wales','AUSTRALIA','2770','0432077486','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 12:02:34',0,NULL,3,1,11,1,'BJ01715689 ','au-buy\rOTGR001'),(21815,781118785008,180764313016,'New Philips Sonicare Flexcare Toothbrush Handle HX6930',1,'HBPH002',67.99,'au-buy','angelicdarts','brendahaynes46@btinternet.com','Brenda J Haynes','46 Glebelands','Burton Pidsea','East Riding Of Yorkshire','UNITED KINGDOM','HU12 9AS','01964670948','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 12:44:14',0,NULL,3,1,3,1,'RR658650173CN ','au-buy\rHBPH002'),(21816,844565557011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','markh1300','markthecabby50@yahoo.co.uk','mark head','34 unity road','enfield','Middlesex','UNITED KINGDOM','en36pa','01992761305','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-15 12:44:43',0,NULL,3,1,3,1,'RR658650709CN\r ','eastar4uk\rHSJA011\r英标'),(21817,844579259011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','viktortassi','captainsheldon@gmail.com','Viktor Tassi (DBI Szoftver Kft)','Füredi út 76<br>1/21','Debrecen','Hajdu-Bihar Megye','HUNGARY','4032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 13:27:10',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN015\r 无线蓝牙二合一'),(21818,844580181011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','townsj1','townsj62@att.net','Jacqueline Townsel','925 Westhaven Cir','Clarksdale','MS','UNITED STATES','38614-3613','(662) 627-7723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 13:27:44',0,NULL,3,1,1,1,' LK198695996CN','eastar4\r再发一个New Jabra BT250V Headset\rHSJA001'),(21819,681680315013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','leannejowen','leelee.owen@gmail.com','Leanne  Owen','96-11 Harrisford Street','Hamilton','ON','CANADA','L8K 6L7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 14:01:46',0,NULL,3,1,11,1,NULL,'eastar4\rUM00033\r客户改发成带鞋子的模型'),(21820,844593045011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','nidwaldner','sam@vanryder.net','Samuel Van Ryder','4121 Dickson St','Houston','TX','UNITED STATES','77007-7318','(713) 417-7306','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 14:03:23',0,NULL,3,1,1,1,'/ ','eastar4'),(21821,935096988012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','busterbrownhil','jmhildreth_mhs@yahoo.com','Jack Hildreth','10745 Kern Rd','Osceola','IN','UNITED STATES','46561-9399','(574) 633-4165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 14:10:00',0,NULL,3,1,1,1,'/ ','eastar4'),(21822,626823012004,140630817200,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',34.99,'cnfaner','denis_rr','moyemail.home@gmail.com','Denis Bukhman','Chehova 8., apt. 47','Simferopol','AR Crimea','UKRAINE','95011','+380676500194','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 15:21:33',0,NULL,3,1,3,1,'RA184538580CN\r ','cnfaner CC00002'),(21823,844624362011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','egi_2010','chivoo@mail.ru','Ilya Egorov','Krasnodonskaya 2-1-216','Moscow','','RUSSIAN FEDERATION','109387','+79150278949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 15:25:32',0,NULL,3,1,3,1,'RR658650876CN ','eastar4uk\rOTSO002'),(21824,935139295012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','hitriy_chen','alexst89@mail.ru','Maxim Lebed','Atarbekova street, 11, kv.28','Krasnodar','Krasnodar region','RUSSIAN FEDERATION','350049','+7918 137-1767','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:00:25',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(21825,681717653013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',19.98,'eastar4','ernie-89','martinlundberg89@hotmail.com','Hagarnevägen 39E Lundberg','Hagarnevägen 39E','Uddevalla','Västragötaland','SWEDEN','45133','0736978935','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:14:12',0,NULL,3,1,11,1,'BJ01669299\r ','eastar4\rCASS001\r贴航空签\rCAB-SS-2626'),(21826,935150525012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','alexpuzyrev','puzyrev.rus@gmail.com','Александр Пузырев','пер.Городской, 15, 79','Тула','','RUSSIAN FEDERATION','300012','(920) 7857205','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:17:04',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(21827,681720350013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','da_petcu21','dapetcu21@gmail.com','Danut Petcu','Nr. 18 Bl. G4 Sc. B Ap. 27<br>Strada 13 Decembrie','Ploiesti','Prahova','ROMANIA','100537','0729983468','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:23:34',0,NULL,3,1,11,1,'BJ01669291\r ','eastar4\rCACN004\r贴航空签'),(21828,935160590012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',1,'CASS001',6.29,'eastar4uk','tormod_macleod','tormod.macleod@gmail.com','Tormod Macleod','4 Turnberry Drive','Kirkcaldy','Fife','UNITED KINGDOM','KY2 6SS','01592201232','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-15 16:36:09',0,NULL,3,1,3,1,'RR658650955CN ','eastar4uk\rCASS001\rCAB-SS-2626'),(21829,844466032011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','hallanm','jasrajsingh7@yahoo.com','Manraj Hallan','38 Taralake Cape NE','Calgary','AB','CANADA','T3J0J1','(403) 630-1677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:41:07',0,NULL,3,1,3,1,'RR658650363CN\r ','eastar4\rHSSE011'),(21830,798129643001,110819087341,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'buysia','leosetta','leo.setta@gmail.com','Leo Setta','Rua Assunção 159, apto 204, bloco1<br>Botafogo','Rio de Janeiro,','RJ','BRAZIL','22251-030','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 16:49:30',0,NULL,3,1,11,1,'BJ01715691 ','buysia\rBALO001'),(21831,844677560011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','theo70a','ted.smith@theoden.com','Ted Smith','4640 S Wright Way','Morrison','CO','UNITED STATES','80465','(720) 934-5230','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4uk'),(21832,935188514012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','davecooker','judycarver@att.net','David M. Moulton','8 Magnolia Hill Ct','Cromwell','CT','UNITED STATES','06416','(860) 635-1460','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 17:30:14',0,NULL,3,1,1,1,'/ ','eastar4'),(21833,935199820012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','stephennw','achilles@mts.net','Achilles Foot Clinic','202-584 Pembina Hwy.','Winnipeg','MB','CANADA','R3M 3X7','(204) 453-2144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 17:50:26',0,NULL,3,1,3,1,'RR658650417CN\r ','eastar4\rGLOT001'),(21834,621502093003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',2,'HSJA001',47.6,'cnfaner','dogsshreksbears','polarrican@hotmail.com','tomas rivera','2001 morris ave<br>Apt 4C','bronx','NY','UNITED STATES','10453-4248','(917) 416-6749','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 17:39:06',0,NULL,3,1,1,1,'LK196170491CN','cnfaner'),(21835,844709218011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',9.6,'eastar4uk','fsolish','js@ultra.no','Joachim Slikker','Mosseveien 224','Oslo','','NORWAY','1169','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 18:24:58',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLDE002'),(21836,844719184011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','foxserz','foxse@bk.ru','Evgeny Babaev','Dubninskaya 24-4-135','Moscow','Moscow','RUSSIAN FEDERATION','127540','(926)2536717','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 18:42:52',0,NULL,3,1,11,1,'BJ01669308\r ','eastar4\rWLIN015\r 无线蓝牙二合一'),(21837,931857096012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',29.98,'eastar4','tonyzoc','tonyzoc@yahoo.com','Anthony Zoccolillo','118 Rose Lane Ter','Syracuse','NY','UNITED STATES','13219-2846','(716) 907-2341','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 18:17:16',0,NULL,3,1,1,1,'/ ','eastar4'),(21838,621533585003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','draxx31','draxx31@yahoo.fr','Jacques VILLALBA','1 rue de l\'Aubisque','LA SALVETAT-ST-GILLES','Midi-Pyrénées','FRANCE','31880','+33561071778','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 19:06:17',0,NULL,3,1,3,1,'RR658650315CN ','cnfaner\rBALO007'),(21839,935248296012,220816316803,'New Auto folding Sun Rain Leopard lines stick Umbrella',1,'UM00016',24.99,'eastar4','ashcroft1949','dianneashcroft49@hotmail.com','dianne heenan','41 fahey street<br>shepparton','shepparton','Victoria','AUSTRALIA','3630','0401458149','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 19:09:17',0,NULL,3,1,11,1,NULL,'eastar4\rUM00016\r网眼豹纹双层网纱长柄伞  '),(21840,935253732012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',2,'WLHP002',35,'eastar4','zimzillakilla','zimzillakilla@gmail.com','israel chagollan','1650 Redondo Ave<br>Apt 5','long beach','CA','UNITED STATES','90804-2648','(562) 200-1921','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 19:15:56',0,NULL,3,1,1,1,'/ ','eastar4'),(21841,626912297004,140667903666,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Antenna *3',1,'WLAT001+ANTY002',15.89,'cnfaner','inocentpc','c0smin@yahoo.com','Cosmin Cazan','2213 Hampshire Pike','Columbia','TN','UNITED STATES','38401-7151','(931) 388-8051','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 19:45:07',0,NULL,3,1,1,1,'/ ','cnfaner'),(21842,844757663011,320786774093,'New Portable HDMI HD H.264 1080P Car Dashboard Camera DVR',1,'CC00001',45.99,'eastar4uk','ronnieireland2006','ronnieireland@yahoo.co.uk','ronan furlong','41 watson park<br>killiney','co dublin','Dublin','IRELAND','default','0872278148','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 19:42:08',0,NULL,3,1,3,1,'RA184508115CN ','eastar4uk\rCC00001'),(21843,626926068004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','fernandosupriano','manozoff@hotmail.com','Fernando Ramiro Supriano','Rua Dr. Julio Prestes 331','Piracicaba','SP','BRAZIL','13418-500','(19) 34227862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 20:20:44',0,NULL,3,1,3,1,'RR658650346CN ','cnfaner\rRELO003'),(21844,626927253004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','eboer1410','eric.de.boer@orange.nl','eric de boer','4962 S Marigold way','Chandler','AZ','UNITED STATES','85248-5519','(480) 634-6080','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 20:23:13',0,NULL,3,1,1,1,'LK200057544CN','cnfaner'),(21845,621570305003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','alejosoljancic','alejandrosoljancic@hotmail.com','sonia salinas','7615 Roanoke Ave<br>Fairfax','Annandale','VA','UNITED STATES','22003-5446','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 20:42:24',0,NULL,3,1,1,1,'LK198709182CN\r ','cnfaner'),(21846,935312961012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','DANNY L BURTON','65 UNION AVE<br>STE 500','MEMPHIS','TN','UNITED STATES','38103-5137','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 20:50:33',0,NULL,3,1,1,1,'/ ','eastar4'),(21847,935353133012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','P.H. Naffah','2595 N 143RD DR','GOODYEAR','AZ','UNITED STATES','85395-1457','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 22:02:55',0,NULL,3,1,1,1,'/ ','eastar4'),(21848,935370157012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','bigsos1961','bigsos@hotmail.co.uk','michael allan mitchell','24 thirlmere avenue<br>marden estate','north shields','Tyne and Wear','UNITED KINGDOM','ne303uq','01912802551','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-15 22:32:42',0,NULL,3,1,3,1,'RR658650880CN ','eastar4uk\rHSJA010\r英标'),(21849,935372246012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','TJ DeBellis','200 Rusty Ln','Rochester','NY','UNITED STATES','14626-1208','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 22:38:27',0,NULL,3,1,1,1,'/ ','eastar4'),(21850,844864123011,320441946555,'2.1 HP NC4400 TC4200 TC4400 Bluetooth Module EDR +cable',1,'BTHP2107',12.39,'eastar4','minus29','steven@minus29.com','Steven Clark','772 Norwood Place','Qualicum Beach','BC','CANADA','V9K 2P9','(250) 752-4246','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 23:08:02',0,NULL,3,1,11,1,'BJ01669296\r ','eastar4\rBTHP2107\rHP 8pin 1.0 23cm '),(21851,935387586012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','townsj1','townsj62@att.net','Jacqueline Townsel','925 Westhaven Cir','Clarksdale','MS','UNITED STATES','38614-3613','(662) 627-7723','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 23:13:40',0,NULL,8,1,17,0,NULL,'eastar4'),(21852,626984462004,140550602649,'New Ericsson F3607GW DELL 5540 3G GPS WWAN Card+antenna',1,'WWOT003+ANCN001',48.9,'cnfaner','luis_marcel','lmpmilla@ibest.com.br','Luis Marcel Pereira Milla','Conjunto Europa, Rua 1-G, 1015 - Colonia Vitoria','Guarapuava','PR','BRAZIL','85139400',' 554236251955','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 23:24:01',0,NULL,3,1,3,1,'RR658650350CN ','cnfaner\rWWOT003+ANCN001'),(21853,681875677013,230695960165,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',86.9,'eastar4','hmb1e','hmb1e@cmf-co.com','Harold M Baskin','900 SW 70th Ave','Miami','FL','UNITED STATES','33144-4614','(305) 261-6262 ext.: 205','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 23:30:45',0,NULL,3,0,1,1,'/ ','eastar4'),(21854,626988474004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','rpri3539','ronpok25@gmail.com','Ron Prichard','4520 Koerner Rd. NE','Piedmont','OK','UNITED STATES','73078','(405) 373-1671','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 23:38:11',0,NULL,3,1,1,1,'/ ','cnfaner'),(21855,626990970004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','elwellm','elwellm@comcast.net','Elwell Weatherhead','2401 University Ave','Waukegan','IL','UNITED STATES','60085-3354','(847) 436-4586','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-15 23:50:23',0,NULL,3,1,1,1,'/ ','cnfaner'),(21856,842733242002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','mizzo34','mawmoses27@yahoo.com','Mark  Walker','582 School St.','Stoughton','MA','UNITED STATES','02072','(857) 225-2475','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-15 23:54:07',0,NULL,3,1,1,1,'/ ','buysia'),(21857,935406029012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','squint24','info@imegonline.com','Justin Jones','305 Elm St','Sevierville','TN','UNITED STATES','37862','(865) 335-7790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 00:03:42',0,NULL,3,1,1,1,'/ ','eastar4'),(21858,781433181008,180816092496,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'',26.99,'usa-view','erinsweeney11','erinsweeney8@gmail.com','erin Sweeney','14 Bayview ave','East Patchogue','NY','UNITED STATES','11772-6102','(631) 655-8586','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 01:22:02',0,NULL,7,0,18,0,NULL,'usa-view'),(21859,621649806003,130626363900,'Brand New Logitech Unifying Receiver for M505 M705 M905 etc mouse- 100% official',1,'RELO002',12.95,'cnfaner','entrega15','entrega15@aol.com','Jose Miguel Salinas','10921 N 153rd Ln','Surprise','AZ','UNITED STATES','85379-5326','(623) 261-4147','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 01:36:19',0,NULL,3,1,1,1,'/ ','cnfaner'),(21860,8881329357531240,111,'Sony TMR-BR100 3D Sync Transmitter',1,'TRSN001',26.99,'cnfaner','erinsweeney11','erinsweeney8@gmail.com','erin Sweeney','14 Bayview ave','East Patchogue','NY','UNITED STATES','11772-6102','',NULL,NULL,NULL,'2012-02-16 01:58:51',0,NULL,3,1,1,1,'/ ','Usa-view '),(21861,781444180008,180820610109,'Genuine Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'au-buy','psspider_2000','pasqualescotti@mac.com','Pasquale Scotti','2669 carriage way','Saint-Lazare','QC','CANADA','J7T 2B1','(514) 967-8731','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-16 02:03:11',0,NULL,3,1,11,1,'BJ01715684 ','au-buy\rWLDE002'),(21862,844924944011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',85,'eastar4','ariel_t666','arieltorreshds@hotmail.com','DTI, DE TODO IMPRESORAS','8627 NW 54th St<br># PSS-1349','Doral','FL','UNITED STATES','33166-3347','305 513 0441','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 02:27:38',0,NULL,3,1,1,1,'/ ','eastar4'),(21864,935473864012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','taffl','lctaff@taff.co','Lavonia Taff','905 Roaring Springs rd','Fort Worth','TX','UNITED STATES','76114-4413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 03:33:09',0,NULL,3,1,1,1,'/ ','eastar4'),(21865,681932800013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','kristin_motley','kss3y@mtmail.mtsu.edu','Kristin Samples','237 Drivers Ln','Gallatin','TN','UNITED STATES','37066-5906','(615) 838-7690','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 03:55:31',0,NULL,3,1,1,1,'LK198227123CN\r ','eastar4'),(21866,8881329368498864,111,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',17.99,'eastar4','fotocrafty','fotocr_etnl6859lgo@members.ebay.in','Pratap J','S-205, Pooja Residency, 39/103 C Main Road, <br>9th Cross, J.P. Nagar I Phase','Bangalore,','Karnataka ','INDIA','560078','',NULL,NULL,NULL,'2012-02-16 05:01:38',0,NULL,3,1,3,1,'RR658650553CN ','eastar4\rWLDE002 \r直接打款 令多打了运费\r记得告诉客户TRACKING NUMBER'),(21867,844968050011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','janmarnc','janmar@lexcominc.net','Janene M Roussell','124 Long Bow Dr','Lexington','NC','UNITED STATES','27292-7780','(336) 499-9116','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 05:12:58',0,NULL,3,1,1,1,'/ ','eastar4'),(21868,781490405008,180757093492,'Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',21.89,'au-buy','misl5730','mohammedizlam@hotmail.co.uk','Mohammed Islam','13 St Egberts Way','London','London','UNITED KINGDOM','E4 6QH','02085244992','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-16 06:03:15',0,NULL,3,1,11,1,'BJ01669323\r ','au-buy\rSCLO004'),(21869,935517459012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','nesterovdv','c0014e1@list.ru','Dmitry Nesterov','Cheremshanskaja, 151, kv. 32','Samara','Samara','RUSSIAN FEDERATION','443105','79270147601','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 06:47:43',0,NULL,3,1,3,1,'RR658650425CN\r ','eastar4\rGLOT001*2'),(21870,798426140001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'buysia','isaiah9.702','isaiahwhigham@gmail.com','isaiah whigham','7145 portia ct','las vegas','NV','UNITED STATES','89113-0246','(702) 300-9717','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-16 07:05:26',0,NULL,3,1,1,1,'/ ','buysia'),(21871,8881329380792701,111,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',0,'eastar4','hvyardsales','hvyards@yahoo.com','Robert Norris','105 Hone St<br>9th Cross, J.P. Nagar I Phase','Kingston','NY','UNITED STATES','12401-6334','(845) 901-2999',NULL,NULL,NULL,'2012-02-16 08:26:32',0,NULL,5,0,18,0,NULL,'录错地址了'),(21872,8881329380959088,111,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'',0,'eastar4','hvyardsales','hvyards@yahoo.com','Robert Norris','105 Hone St','Kingston','NY','UNITED STATES','12401-6334','(845) 901-2999',NULL,NULL,NULL,'2012-02-16 08:29:19',0,NULL,3,0,4,1,'YW868897053CN ','补货\r\rGLOT001*4    通知燕文截单 2.24\r'),(21873,935550177012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Brandon Thron','3382 PREBLE AVE','VENTURA','CA','UNITED STATES','93003-5036','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 09:08:36',0,NULL,3,1,1,1,'/ ','eastar4'),(21874,781536241008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','firemandan4277','tanner.4277@bigpond.com','Steven Tanner','4 Railway road<br>Ferntree Gully','Melbourne','Victoria','AUSTRALIA','3156','030438113426','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 09:13:03',0,NULL,3,1,11,1,'/ ','au-buy\rBALO001'),(21875,781551249008,180699060430,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',2,'GLOT001',89.98,'au-buy','alcowden','alexcalder1@bigpond.com','alexander calder','8/47 fairlight street<br>fairlight','sydney','New South Wales','AUSTRALIA','2094','0299070488','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 10:17:09',0,NULL,3,1,3,1,'RR658650329CN ','au-buy\rGLOT001'),(21876,681991010013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','imperfek_anjel','imperfek@tpg.com.au','Linda Trinh','13 Wheller st','Bossley pk','New South Wales','AUSTRALIA','2176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 10:17:31',0,NULL,3,1,3,1,'RR658650479CN\r ','eastar4\rMOSA004'),(21877,798470901001,110819588834,'New Original Logitech Unifying receiver for MX mouse and K340 K350 keyboard',1,'RELO002',12.97,'buysia','wfsc2008','wfsc2005@gmail.com','william souza','rocha pombo<br>number 119','sao paulo','sao paulo','BRAZIL','01525-010','(551) 196-4200 ext.: 55','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-16 10:36:22',0,NULL,3,1,11,1,'BJ01715685 ','buysia\rRELO002'),(21878,935576382012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','sul.vendas','sulvendas@gmail.com','Michael Pereira Silva','Rua Osório Correia 813','Cachoeirinha','Rio Grande do Sul','BRAZIL','94935-460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 10:41:52',0,NULL,3,1,11,1,'BJ01669290\r ','eastar4\rOTCN004*10'),(21879,845041724011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',48.48,'eastar4','sparta_200973','udinn@thebat.net','Nick Yudin','Dybenko street, 26 - 3 - 65','Moscow','Moscowskay oblast','RUSSIAN FEDERATION','125475','+7 9160446687','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 10:49:15',0,NULL,3,1,3,1,NULL,'eastar4\rHSJA013+HSJA011\r欧标\r再发一个New Jabra BT500v  Bluetooth Headset \r'),(21880,935584868012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','sheilap007','dspaquette@shaw.ca','Sheila Paquette','928 Lk Twintree Cres S.E.','Calgary','AB','CANADA','T2J2W3','(403) 278-0630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 11:10:27',0,NULL,3,1,3,1,'RR658650496CN\r ','eastar4\rGLOT001'),(21881,682006490013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',10,'HSNO019',379.8,'eastar4','gpaja','sami@golfpaja.com','Sami Siren','Laaksotie 119','Talma','Uusimaa','FINLAND','04240','+358503550210','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-02-16 11:39:49',0,NULL,3,1,3,1,'RR658650448CN\r ','eastar4\r欧标\rHSNO019'),(21882,935619346012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','effendiwakeel','wakeel_77@yahoo.com','Wakeeluddin Effendi','27 STEYNING CLOSE<br>NORTHGATE','CRAWLEY','West Sussex','UNITED KINGDOM','RH10 8HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 12:57:33',0,NULL,3,1,3,1,' RA184529702CN','eastar4uk\r英标\rHSJA002'),(21883,845084776011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',7,'MOAP001',118.93,'eastar4uk','proteinstore','store@proteinos.com','Protein Ltd.','18 Hewett Street','London','London','UNITED KINGDOM','EC2A 3NN','02072473999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 13:08:58',0,NULL,3,1,3,1,'RR658650743CN\r ','eastar4uk\rMOAP001'),(21884,845092174011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','willownboo','wpbfinancial@verizon.net','William Bowlin','826 Hall St','Clearwater','FL','UNITED STATES','33756-1110','(727) 430-0049','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 13:32:13',0,NULL,3,1,1,1,' LK193962806CN','eastar4'),(21885,935638043012,220908829691,'4 pairs of New 3D Active Shutter TV Glasses compatible 4 3D TV Sony  LG samsung',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 13:50:25',0,NULL,3,1,4,1,'YW868897495CN ','eastar4uk'),(21886,845097955011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','wisewapiti','johnmechler@gmail.com','John Mechler','725 Water Oak Dr','Seymour','TN','UNITED STATES','37865-3420','(865) 609-8202','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 13:53:58',0,NULL,3,1,1,1,'/ ','eastar4'),(21887,627145907004,140667903246,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',18.49,'cnfaner','pharao2000','pharao@zonnet.nl','Timo Sariwating','Medelsestraat Oost 22','TIEL','','NETHERLANDS','4004LG','+31 344 672080','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 14:29:19',0,NULL,3,1,3,1,'RR658650332CN ','cnfaner\rWLIN010'),(21888,845112792011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','hellan33','hellan3@gmail.com','Lars hellqvist','Fjärdhundragatan 22','uppsala','','SWEDEN','75337','0707884622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 14:32:29',0,NULL,3,1,3,1,'RR658650828CN ','eastar4uk\rGLOT001'),(21889,681309904013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','kimw0723','mrs_woody@hotmail.com','Kimberly Woodell','4869 Fells Cove Ave','Kissimmee','FL','UNITED STATES','34744-9250','(407) 529-8004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 14:38:45',0,NULL,3,1,1,1,'/ ','eastar4'),(21890,773311230007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','skexis76','ehshewry@googlemail.com','K Gillespie','37 Cascade St<br>Paddington','Sydney','New South Wales','AUSTRALIA','2021','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 14:47:47',0,NULL,3,1,11,1,NULL,'au-buy\rUM00001'),(21891,682084649013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','tealcsg','kmioc@inet.hr','Krasomir Mioč - Herceg','Vijenac Petrove gore 15','Osijek','Osječko-baranjska','CROATIA','31000','+38598386407','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-02-16 16:57:14',0,NULL,3,1,11,1,'BJ01669315 ','eastar4\r欧标\rHSNO019'),(21892,627198222004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','the-noisemaker','the-noisemaker@hotmail.com','Terry LeMaster','35 E Market St','Wabash','IN','UNITED STATES','46992-3124','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 17:38:35',0,NULL,3,1,1,1,'/ ','cnfaner\rHSNO032\r英标'),(21893,627203390004,140667905525,'New Replaceable Shell for logitech Mouse MX518',5,'SHLO004',64.95,'cnfaner','lat1125','vanquish25@sbcglobal.net','Jeff Twitty','2407 Little Creek CV','Cedar Park','TX','UNITED STATES','78613-5937','(512) 336-7802','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 17:55:23',0,NULL,3,1,1,1,'LK192372428CN\r ','cnfaner'),(21894,935750068012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',20.78,'eastar4uk','bits_n_bytes_malta','info@bitsandbytesmalta.com','Bits &amp; Bytes','3, St. Aloysius Square','Birkirkara','','MALTA','BKR1474','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 17:59:43',0,NULL,3,1,11,1,'BJ01669318\r ','eastar4uk\rOTCN004*10'),(21895,682107509013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','zuzu64ulker','picho64@mail.ru','Ulker Abbasova','U.Hacibeyov 36','Baku','','AZERBAIJAN','1000',' 505017703','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 17:59:48',0,NULL,3,1,11,1,NULL,'eastar4\rUM00042'),(21896,845206681011,320814060678,'New Double-Reinforced India Flower Transparent Dome Birdcage Stick Umbrella',1,'UM00051',24.99,'eastar4','caligirl02roses','shauna711_02@yahoo.com','Shauna Cote','1757 W Avenue J15<br>Apt 2','Lancaster','CA','UNITED STATES','93534-4636','(760) 375-2166','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 18:11:09',0,NULL,3,1,1,1,'LK193802999CN ','eastar4\r透明加厚面料印度花长柄伞\r黑色的'),(21897,935762126012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','lqwrq1','lovro.mihin@gmail.com','Lovro Mihin','Balogovec 54 Mačkovec','Čakovec','Međimurje','CROATIA','40000',' 3850914857799','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 18:26:13',0,NULL,3,1,3,1,'RR658650482CN ','eastar4\rGLOT001'),(21898,682124073013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','vansobz','vanso.bz@gmail.com','Ivan Bukhradze','5 Michurinsky ave., apt. 195','Moscow','Moscow','RUSSIAN FEDERATION','119192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 18:45:27',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(21899,845230202011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',21.9,'eastar4','pozaja','hampervina@gmail.com','drazen pozaic','b.magovca 54','zagreb','zagreb','CROATIA','10000','0981720678','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 18:53:41',0,NULL,3,1,11,1,'BJ01669297\r ','eastar4\rOTHP004'),(21900,845231042011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','aleksarn','alnyrup@gmail.com','Aleksander Risom Nyrup','Frederiksgade 6 3 TH','Aalborg','','DENMARK','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 18:56:33',0,NULL,3,1,11,1,'BJ01669309\r ','eastar4\rHSUE002'),(21901,627239664004,140630816480,'New Nokia HS-26W Bluetooch Headset HS 26W',1,'HSNO032',14.99,'cnfaner','am.giles75','am.giles75@ntlworld.com','Andrew Giles','Sibamas<br>Newbolt Road','Portsmouth','Hampshire','UNITED KINGDOM','PO6 4NS','07905104053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 19:36:22',0,NULL,3,1,3,1,'RA184509345CN\r ','cnfaner\rHSNO032\r英标'),(21902,935817339012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','cjs2s','mydogdied@y7mail.com','matthew valentine','76 Ross ave','Narrawallee','New South Wales','AUSTRALIA','2539','0244545667','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 19:48:52',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(21903,845297128011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','ewa.dolot','lidiachludzinska@wp.pl','Ewa Dolot','26 Bevendean Crescent','Brighton','East Sussex','UNITED KINGDOM','bn24ra','07933232836','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 20:45:34',0,NULL,3,1,11,1,'BJ01669295\r ','eastar4\rHBPH003'),(21904,845324619011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','n.balyanitsaua','n.balyanitsa@gmail.com','Nick Balyanitsa','Mezhigirskaya, 43','Kiev','','UKRAINE','04071',' 380979131381','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 21:35:15',0,NULL,3,1,11,1,'BJ01669306\r ','eastar4\rHSUE004'),(21905,682199738013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','hockeygems_slovakia','lubos_g@yahoo.com','Hockey Gems, s.r.o.','Sputnikova 2','Kosice','','SLOVAK REPUBLIC','04012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 21:58:53',0,NULL,3,1,11,1,'BJ01669301\r ','eastar4\rBTHU2005\r华硕 8pin 1.0 6cm '),(21906,935906140012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','izy4','israel.mcgregor@ge.com','Israel McGregor','15/99-103 Saddington street','St Marys','New South Wales','AUSTRALIA','2760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 22:20:26',0,NULL,3,1,3,1,'RR658650505CN\r ','eastar4\rGLOT001'),(21907,790162901007,170734557550,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'au-buy','eringracekellygreen','eringreen2009@hotmail.com','Erin Green','23 william street','WINGHAM','New South Wales','AUSTRALIA','2429','0265535886','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 23:05:34',0,NULL,3,1,11,1,'\r ','au-buy\rUM00042'),(21908,682225326013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','hennumg','gregg@sportsmanslodges.com','Gregg Hennum','2816 Spruce Ln NW','Baudette','MN','UNITED STATES','56623-3097','(218) 634-2259','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 23:28:59',0,NULL,3,1,1,1,'/ ','eastar4'),(21909,627321772004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','h8221211','h8221211.business@gmail.com','Hyunwoo Lee','3440 Rue Durocher APT 409','Montreal','QC','CANADA','H2X2E2','(514) 601-3378','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:51:47',0,NULL,3,1,3,1,'RR658650213CN ','cnfaner\rOTSO002\r'),(21910,790179221007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','starfishy33','starfishy_33@yahoo.com','Elise Dale','Unit 9 / 40 Florence Taylor Street','Greenway','Australian Capital Territory','AUSTRALIA','2900','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 00:09:29',0,NULL,3,1,11,1,'BJ01715700 ','au-buy\rRELO002'),(21911,682245744013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',2,'GPS0004',219.98,'eastar4','bridgetm2010','bridgetbrophy@hotmail.com','Bridget Brophy','12 Newbury Street','Portugal Cove-St.Philiips','NL','CANADA','A1M 0A6','(709) 727-8476','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 00:57:40',0,NULL,3,1,3,1,'RR658650377CN\r ','eastar4\rGPS0004'),(21912,8881329444914288,111,'For Philips Sonicare Flexcare Toothbrush Handle HX6930 - ',1,'HBPH002',55.99,'aliexpress','1006815477','fmidas@comcast.net','Faye Midas','2456 Crestview Drive South ','Salem','Oregon','UNITED STATES','97302','+503 602 2625',NULL,NULL,NULL,'2012-02-17 02:15:14',0,NULL,3,1,1,1,'LK196696340CN  ','\r 客户6950可以'),(21913,935993376012,220872377067,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',69.99,'eastar4uk','superblack700r','raptor_700r@live.com','Josh Gens','PO Box 601<br>614 4th St. Apt. 4','Nicollet','MN','UNITED STATES','56074-0601','(507) 327-2652','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 02:28:27',0,NULL,3,1,1,1,'/ ','eastar4uk'),(21914,8881329446153656,111,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',20.99,'eastar4','manokamma','guilhermeras@gmail.com','Guilherme Satana Amaral','rua p36, lt. 29, qd. P 107','Goiania,','Goias','BRAZIL','74543-490','6292654479',NULL,NULL,NULL,'2012-02-17 02:35:53',0,NULL,3,1,3,1,'RR658650465CN\r ','WLIN013\r客户打了3美金挂号 '),(21916,845448793011,320787383671,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',15.95,'eastar4uk','tyemaishuu3','tyemaishuu@gmail.com','Vivian Edwards','9432 Damascus RD','Damascus','MD','UNITED STATES','20872-1204','(301) 253-1630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 03:36:44',0,NULL,3,1,1,1,' LK194310196CN','eastar4uk\r向日葵长柄伞'),(21917,845461966011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','thing2397','siewthing2397@hotmail.com','soh siew thing','10E, Jalan Muar','Segamat','Johor','MALAYSIA','85000','0167172566','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 04:32:10',0,NULL,3,1,11,1,'BJ01669314 ','eastar4\rHSNO019'),(21918,8881329453459147,111,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',0,'eastar4','chyanime','chyanime92@yahoo.com','Chyenne Bertrand','710 S College Rd<br>Apt 73','Lafayette','LA','UNITED STATES','70503-3385','(337) 764-3063',NULL,NULL,NULL,'2012-02-17 04:37:39',0,NULL,3,1,1,1,'LK187294379CN ','补发的 \r改个地址'),(21919,845243962011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','9646gt','9646gt@gmail.com','christopher h adams','2609B Colfax Loop<br># B','Holloman Air Force Base','NM','UNITED STATES','88330-8404','(423) 464-2203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 04:50:31',0,NULL,3,1,1,1,'LK195601601CN\r ','eastar4'),(21920,682295158013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'eastar4','zard98','wineapple@gmail.com','jun soo Ko','San 46-1 KT, Unhak-dong<br>Cheoin-gu','Yongin-si','Gyeonggi-Do','KOREA,REPUBLIC OF','449-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 04:52:09',0,NULL,3,1,11,1,'BJ01715692\r ','eastar4\rWLIN014'),(21921,627389124004,140490658349,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',38.8,'cnfaner','leeraccoon','lee88alex@gmail.com','Alexander Lee','Volochaevskaya st. 18-117','Moscow','','RUSSIAN FEDERATION','111033','79671909500','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 05:55:08',0,NULL,3,1,3,1,'RR658650995CN\r ','cnfaner\rWWOT001'),(21922,627389841004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','yaroslav9336','dr.pedalet@mail.ru','Yaroslav Lebedev','Mesherskiy prospekt, dom 4, stroenie 18, chastniy sektor','Moscow','Moscow','RUSSIAN FEDERATION','119618','+7(903)170-8775','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 06:02:33',0,NULL,3,1,3,1,'RR658651001CN\r ','cnfaner\rLGAD001'),(21923,8881329459900628,111,'US ADAPTER',1,'POLO001',0,'eastar4uk','giamgaj','giamgaj@earthlink.net','Carl Hosoda','3802 Ezie St','San Jose','CA','UNITED STATES','95111-3512','(408) 593-1617',NULL,NULL,NULL,'2012-02-17 06:25:00',0,NULL,3,1,1,1,'LK196981557CN ','补发的 \r改个地址'),(21924,845485274011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','of_road','eduard@herguido.net','Edu Herguido Fo','Av. Vallmanya, 30-36','Alcarràs','Cataluña','SPAIN','25180','607981877','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 06:28:02',0,NULL,3,1,11,1,NULL,'eastar4\r欧标\rHSJA002'),(21925,845488786011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','kgraff-kz','kgraff77@gmail.com','Andrey Krassikov','Ryskylova 11 - 26','Karaganda','_UAES_NULL_','KAZAKHSTAN','100030',' 77017417669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 06:50:46',0,NULL,3,1,11,1,'BJ01715701\r ','eastar4\rTRSN001'),(21926,782012764008,180755522339,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'au-buy','vynaldo','stephen.vinall@gmail.com','Stephen Vinall','20 Seymour St<br>Hurstville Grove','Sydney','New South Wales','AUSTRALIA','2220','0295704014','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 07:35:14',0,NULL,3,1,11,1,'BJ01715675 ','au-buy\rHBPH009'),(21927,936068564012,220815928836,'Logitech RF Wireless Extender for Harmony 890 Pro 1000',1,'RCLO007',18.8,'eastar4uk','vision_impossible','pharket@gmail.com','Paul Harket','17 Hackworth Gardens, Hedge End<br>Grange Park','Southampton','Hampshire','UNITED KINGDOM','SO302WP','01489783782','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 07:23:29',0,NULL,3,1,3,1,' RA184519223CN','eastar4uk\rRCLO007'),(21928,845502041011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','kidda7','kiddamufc@aol.com','stuart smith','10 cringlebarrow close<br>boothstown','manchester','Lancashire','UNITED KINGDOM','m28 1yg','01617026073','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 07:52:51',0,NULL,3,1,3,1,' RA184529628CN','eastar4uk\rTRSN001'),(21929,782030140008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',57.99,'au-buy','greenrhino181','haydnm@westnet.com.au','Haydn Madigan','15 Fletcher Court','Port Pirie','South Australia','AUSTRALIA','5540','0410537924','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 08:55:19',0,NULL,3,1,3,1,'RA184508279CN\r ','au-buy\rGLOT005'),(21930,627430573004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','hlamoz','hlamoz-b16@yandex.ru','Julia Nesterova','Tvardovskogo st. 9-1-370','Moscow','','RUSSIAN FEDERATION','123458',' 89031734989','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 10:35:43',0,NULL,3,1,3,1,'RA184529631CN','cnfaner\rBALO007'),(21931,682355409013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','soares_tiko7','soares_tiko@hotmail.com','Tiago Soares de Carvalho de Souza','Rua Presidente Médici, Caminho 06, N°97. Águas Claras','Salvador','Bahia','BRAZIL','41310493','+55 (71) 8795 - 2475','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 11:16:18',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO016   paypal charge back\r'),(21932,782071530008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','leighhocking','leighhocking@hotmail.com','Leigh Hocking','Level 5, Central Plaza 2<br>66 Eagle Street','Brisbane','Queensland','AUSTRALIA','4001','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,3,1,11,1,NULL,'au-buy\rBALO001'),(21933,782078453008,180820610109,'Genuine Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'au-buy','rocky_26','ianburling04@gmail.com','Lolita Brennan','26 Darling Street','Ipswich','Queensland','AUSTRALIA','4305','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 11:58:13',0,NULL,3,1,11,1,NULL,'au-buy\rWLDE002'),(21934,681469967013,230724607810,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'eastar4','*jess.addicted.to.shopping*','jessicabarry84@hotmail.com','Jessica Barry','Unit 3, 82 Whitmore Street','Taringa','QLD','AUSTRALIA','4068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 12:04:11',0,NULL,3,1,11,1,NULL,'eastar4\rUM00053'),(21935,627460132004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','megamoog','lawrence.prinner@sbcglobal.net','Lawrence Prinner','46W980 Allen Rd','Hampshire','IL','UNITED STATES','60140-9701','(847) 683-2574','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 12:56:43',0,NULL,3,1,1,1,'LK196715980CN','cnfaner'),(21936,682394884013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','shvyryaev','victor_shvir@mail.ru','Victor Shvyryaev','Leningradskoe Shosse, 16A/2<br>Procter','Moscow','Moscow','RUSSIAN FEDERATION','125171','+79263356080','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 14:10:38',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(21937,798992397001,110826639948,'UNLOCKED Sierra Wireless MC8781 Card 7.2Mbps Mini PCI-E Module+3G WWan antenna',1,'WWSI005+ANCN001',40.99,'buysia','corda-projekt','info@corda-projekt.hr','Sandra Smrek','9 Južna obala 26','Zagreb','','CROATIA','10000','+38516539732','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-17 14:14:57',0,NULL,3,1,3,1,'RA184519461CN\r ','buysia\rWWSI005+ANCN001'),(21938,621363326003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.59,'cnfaner','closoya6pld','closoya55@sbcglobal.net','christopher s losoya','522 beatty dr','grand prairie','TX','UNITED STATES','75052-6407','(972) 266-0181','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 14:38:14',0,NULL,3,1,1,1,'LK196394446CN\r ','cnfaner'),(21939,936218092012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',24.99,'eastar4uk','harv1070','harv_bains@yahoo.co.uk','harvinder bains','148 bedford road','letchworth garden city','Hertfordshire','UNITED KINGDOM','sg6 4ea','01462674979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 15:13:21',0,NULL,3,1,3,1,NULL,'eastar4uk\rHSNO019\r英标'),(21940,622129358003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','reemashaka','reem.ashaka@yahoo.com','Reem Ashaka','2763 Fox Woods Ln','Rochester Hills','MI','UNITED STATES','48307-5912','(248) 804-3097','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 15:29:21',0,NULL,3,1,1,1,'LK196514149CN','cnfaner'),(21941,622136821003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','necars','dberg@charter.net','Danny Oberg','619 S Clay St','Grand Island','NE','UNITED STATES','68803-5844','(308) 380-1040','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 15:52:42',0,NULL,3,1,1,1,'LK196513355CN\r ','cnfaner'),(21942,627505414004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',25.8,'cnfaner','sinjeonghun','typingcat@gmail.com','Sin Jeong-hun PKMALL','413 S CENTRAL AVE<br>BOX A-801 typingcat','Glendale','CA','UNITED STATES','91204-1640','818 242 2426','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 15:59:11',0,NULL,3,1,3,1,'RA184519268CN\r ','cnfaner\r买了2个\r新地址\rJeong-hun Sin\rNDS FOSH 47th Floor, 63 Building\rYeouido-Dong, Yeongdeungpo-Gu\rSeoul, Seoul \r150763\rSouth Korea\r'),(21943,936279385012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','richardhalfpint','rlesser001@yahoo.com','richard lesser','442 Woodford Dr','debary','FL','UNITED STATES','32713-2145','(407) 952-8036','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 17:23:55',0,NULL,3,1,1,1,'LK196750880CN\r ','eastar4'),(21944,845655942011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','hyula','rudolf@laresser.com','Rudolf Laresser','Großtraberg 93','Traberg','','AUSTRIA','4183','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 17:45:14',0,NULL,3,1,3,1,' RA184519210CN','eastar4uk\rMOAP001'),(21945,936347725012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',39.99,'eastar4uk','mwptmatt','matt@eaweb.co.uk','Matthew Johnstone','29 Yeoman Close','Ipswich','Suffolk','UNITED KINGDOM','IP1 2QG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 19:20:27',0,NULL,3,1,3,1,' RA184529693CN','eastar4uk\r'),(21946,790544115007,170735464248,'New Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',21.99,'au-buy','babymuffin8','babymuffinhead16@btinternet.com','Frankie Roberts','49 New High Street<br>Headington','Oxford','Oxfordshire','UNITED KINGDOM','OX3 7AL','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-17 19:46:47',0,NULL,3,1,11,1,NULL,'au-buy\rUM00004'),(21947,936373152012,220449147548,'Samsung R18 R20 R25 Bluetooth Module 2.0 EDR+cable',1,'BTSA2003',9.88,'eastar4','markovyura','mark34@list.ru','Юра Марков','пр. Металлистов 25-2-1','Санкт Петербург','','RUSSIAN FEDERATION','195176','904 5170445','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 20:06:20',0,NULL,3,1,11,1,'BJ01669177\r ','eastar4\rBTSA2003'),(21948,936390026012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','neilam310','emailneilm@gmail.com','Neil Morris','310 walnut st','canton','GA','UNITED STATES','30115-7951','(678) 294-8459','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 20:33:43',0,NULL,3,1,1,1,'LK196869836CN\r ','eastar4'),(21949,936418562012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',19.98,'eastar4','rhino_242','ryan95842@gmail.com','Ryan M Lynch','10245 Main St #207','Bellevue','WA','UNITED STATES','98004','(425) 467-7071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 21:24:59',0,NULL,3,1,1,1,'LK196776745CN\r ','eastar4'),(21950,622246991003,130612786862,'Logitech RF Wireless Extender+ adapter for Harmony 890 Pro 1000',1,'RCLO007',26.9,'cnfaner','redstpi','kaf24v@aol.com','rodney taylor','8606 Country Place Dr','Tobyhanna','PA','UNITED STATES','18466-3362','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 21:31:55',0,NULL,3,1,1,1,'LK196425024CN','cnfaner'),(21951,845827571011,320679564112,'New Ultimate Ears MetroFi 170vi  Earphones with Voice',1,'HSUE001',13.5,'eastar4uk','aldeeran','maier.j@web.de','Jochen Maier','Leopoldstraße 5','Karlsruhe','','GERMANY','76133','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 21:32:53',0,NULL,3,1,11,1,'bj01714560 ','eastar4uk\rHSUE001'),(21952,790598211007,170775726989,'New HP MCE Media Center + Sony Remote Control RM-MCE20E White+IR Emitter Wire',1,'RMSN002',19.99,'au-buy','xlee34x','xxleethomasxx@yahoo.co.uk','Lee Thomas','36 Carnach Green','South Ockendon','Essex','UNITED KINGDOM','RM15 5PZ','0752517887','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-17 21:35:51',0,NULL,3,1,11,1,'BJ01669175\r ','au-buy\rRMSN002'),(21953,845841803011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','4webcafe','webspotja@gmail.com','Web Webspotja','4300 W 58th Pl','Los Angeles','CA','UNITED STATES','90043-3408','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 22:02:31',0,NULL,3,1,1,1,'LK196742265CN\r ','eastar4'),(21954,799197351001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','rosaelia2009','rosaelia_44@hotmail.com','JOSE ALBERTO MIGUEL GARCIA','425 E. Coma Ave. Suite 143','Hidalgo','TX','UNITED STATES','78557','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-17 22:06:20',0,NULL,3,1,1,1,'LK196595584CN\r ','buysia'),(21955,845849943011,320737041061,'3 pair 3D Ready Active Glasses 4 DLP-Link Projector',1,'GLOT005*3',96.99,'eastar4uk','09espen','espenhansen7@hotmail.com','Espen Hansen','Bergveien 20','Harstad','Norway','NORWAY','9408','004741164760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 22:21:52',0,NULL,3,1,3,1,'RA184508340CN\r ','eastar4uk\rGLOT005'),(21956,936451815012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',2,'GLOT001',89.78,'eastar4','mekwinn1','mekwinn@sbcglobal.net','Mark Kwinn','ReVerb<br>5455 Wilshire Blvd, Suite 2200','Los Angeles','CA','UNITED STATES','90036','(310) 467-3295','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 22:32:30',0,NULL,3,1,1,1,'LK196820271CN\r ','eastar4'),(21957,622270861003,130626363900,'Brand New Logitech Unifying Receiver for M505 M705 M905 etc mouse- 100% official',1,'RELO002',12.95,'cnfaner','orcuttr99','orcuttr@hotmail.com','Ryan Orcutt','1649 E 1860 N','Lehi','UT','UNITED STATES','84043-7431','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 22:57:12',0,NULL,3,1,1,1,'LK196534333CN\r','cnfaner'),(21958,845873107011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','252hillbilly133','robert_brown133@yahoo.com','robert brown','3887 fourway rd','hookerton','NC','UNITED STATES','28538-7072','(252) 548-5461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 23:22:47',0,NULL,3,1,1,1,'LK196858175CN\r ','eastar4'),(21959,845877027011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','davet1952','dave@servproburbank.com','Servpro of Burbank','12847 Arroyo St','Sylmar','CA','UNITED STATES','91342-5303','(818) 842-1400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 23:34:10',0,NULL,3,1,1,1,'LK196866295CN ','eastar4'),(21960,936484501012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',26.99,'eastar4uk','jimmyandlinzi','james.gingell@ntlworld.com','mr jimmy gingell','19<br>cheriton gardens','horwich bolton','Lancashire','UNITED KINGDOM','bl67ne','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 23:58:14',0,NULL,3,1,3,1,'RA184519299CN\r ','eastar4uk\rGLOT001'),(21961,845887302011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','shop-29','shop-29@hotmail.co.uk','Richard Brunskill','29 Whitestile Road','Brentford','Middlesex','UNITED KINGDOM','TW8 9NR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 00:04:51',0,NULL,3,1,3,1,'RA184519285CN\r ','eastar4uk\rUDAP001'),(21962,627670036004,140675757878,'New 3D Active Shutter TV Glasses Compatible 4 Samsung SSG -2100AB 2200AB 2200AR',1,'GLOT001',43.89,'cnfaner','rob_770','hola00@hotmail.com','Roberto Wusterhaus','Danhaven 21','Valby','','DENMARK','2500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 00:58:26',0,NULL,3,1,3,1,'RA184519308CN\r ','cnfaner\rGLOT001'),(21963,845912738011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.39,'eastar4','salimnathoo','salim.nathoo@allenovery.com','Salim Nathoo','Brousings<br>Warren Lane','Stanmore','Middlesex','UNITED KINGDOM','HA7 4LD','02089544625','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 01:33:10',0,NULL,3,1,11,1,'BJ01669172\r ','eastar4\rBTHP2112\rHP 8pin 0.8 3cm '),(21964,8881329530060595,111,'Free shiping & Tracking - New WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\" - ',1,'MOOE002',47.99,'aliexpress','1006838702','1@1.com','Tomasz Kwiecinski','Mjavannskleiva 65 ','Tvedestrand','Aust Agder','NORWAY','4900','004748014959',NULL,NULL,NULL,'2012-02-18 01:54:20',0,NULL,3,1,3,1,'RA184594839CN ','MOOE002 \r\r'),(21965,936521170012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','candcb','candcb1@gmail.com','Carolyn Booker','16418 La Louisiane Ct','Baton Rouge','LA','UNITED STATES','70817-6535','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 01:54:29',0,NULL,3,1,1,1,'LK197015431CN\r ','eastar4'),(21966,682610960013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','weaponx23hector','hectorweaponx@yahoo.com','HECTOR DE LA GARZA','2111 Daniel Boone Dr','SAN ANTONIO','TX','UNITED STATES','78238-5105','(210) 831-3489','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 02:04:15',0,NULL,3,1,1,1,'LK196774166CN\r ','eastar4'),(21967,682610899013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','sklhchee','gmrhymer555@hotmail.com','Kirsten Chee','21 Waterview Ave','Haywards Bay','New South Wales','AUSTRALIA','2530','0403555364','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 02:04:21',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(21968,936532441012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Prairie View Elementary','2606 W Johannsen Rd','Spokane','WA','UNITED STATES','99208-8425','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 02:34:29',0,NULL,3,1,1,1,'LK196649075CN\r ','eastar4'),(21969,622314180003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','xgwing','jsatt1489@aol.com','Jim Satterfield','22817 Banbury Cross','Elkhart','IN','UNITED STATES','46514-4837','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 02:35:15',0,NULL,3,1,1,1,'LK196722124CN\r ','cnfaner'),(21970,845937572011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','afnosaj','jason.beech@youngstown.af.mil','Jason Beech','2431 Farmstead Rd','Richfield','OH','UNITED STATES','44286-9376','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 03:08:21',0,NULL,3,1,1,1,'LK196893954CN\r ','eastar4'),(21971,799287013001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','bradleyw904','mariner821@comcast.net','Bradley White','4272 Key Largo Dr','Jacksonville','FL','UNITED STATES','32218-4478','(904) 536-2549','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 03:16:58',0,NULL,3,1,1,1,'LK196984805CN\r ','buysia'),(21972,627698655004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','jad200j','mrtuxedo@optonline.net','joel dupree','24 shade tree lane','riverhead','NY','UNITED STATES','11901','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 03:37:25',0,NULL,3,1,1,1,'LK197011032CN\r ','cnfaner'),(21973,936555704012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','andrevikingblood','andreserenade@gmail.com','Andre Filipe Hoegen Bark','Rua: Bolsao dos Papagaios , 140<br>Bairro: Centro','Pinhais','PARANÁ (PR)','BRAZIL','83320-360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 03:58:53',0,NULL,3,1,11,1,'BJ01669180\r ','eastar4\rWLAT007'),(21974,622328361003,130589288054,'New IBM/thinkpad Atheros AR5BXB72 AR5008  PCI-E CARD',2,'WLAT003',31.6,'cnfaner','phuoctanle272','phuoctan272@yahoo.com.vn','Phuoc Tan Le','9/10 Renown Ave, Wiley Park','Sydney','New South Wales','AUSTRALIA','2195','0414879579','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 04:01:25',0,NULL,3,1,3,1,'RA184519356CN\r ','cnfaner\rWLAT003'),(21975,799302399001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','vlagpvel','sylvain.fournier@videotron.ca','Sylvain Fournier','33, Du Grand-Sault','Québec','QC','CANADA','g1c2m1','(418) 666-4881','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-18 04:28:37',0,NULL,3,1,11,1,'BJ01669176\r ','buysia\rBALO007'),(21976,936564954012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','nicandbob1247h','nicandbob@hughes.net','Nicole Mattos','20447 Oakhill Rd','Madera','CA','UNITED STATES','93638-8190','(209) 564-1203','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 04:41:08',0,NULL,3,1,1,1,'LK197008400CN\r ','eastar4'),(21977,799313004001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',3,'RCLO007',80.97,'buysia','chongliu','gcliu@e-service.com.au','Chong Liu','2  Hillside  PL','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 05:23:10',0,NULL,3,1,3,1,'RA184523191CN ','buysia\rRCLO007'),(21978,0,220950831734,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',3.2,'eastar4uk','derenkoff','derenko@bk.ru','Andrey Derenko','Zheljabova, 13a','Novoshahtinsk','Rostovskaja oblast\'','RUSSIAN FEDERATION','346934','(988) 2578759','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 05:23:52',0,NULL,3,1,11,1,'\\ ','eastar4uk\rANTY002'),(21979,682651022013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','daniel.khanh','danielkhanh@me.com','Duy Nguyen','85A Michaels Avenue, Ellerslie','Auckland','','NEW ZEALAND','1051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 06:08:13',0,NULL,3,1,11,1,'\\ ','eastar4'),(21980,627719385004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','markkoss0','markkoss0@hotmail.com','Callison C/O Chia Ling Khoo','1420 5th Ave<br>Ste 2400','Seattle','WA','UNITED STATES','98101-1345','(206) 384-8278','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 06:22:07',0,NULL,3,1,1,1,'LK197222425CN\r ','cnfaner'),(21981,845982599011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','bebopski','sylvain.aubry@gmail.com','Sylvain AUBRY','18 RUE DU GIBET','MONTIGNY LES METZ','Lorraine','FRANCE','F57950','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 06:49:16',0,NULL,3,1,11,1,'\\ ','eastar4\rUDAP001'),(21982,790751146007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','pdacey','bpandjenzo@optusnet.com.au','PAUL DACEY','35 DUNBAR STREET','FRASER','Australian Capital Territory','AUSTRALIA','2615','0262584034','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-18 07:52:23',0,NULL,3,1,11,1,'\\ ','au-buy\rOTGR001'),(21983,936605767012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alinz','helenlin825@hotmail.com','An-Lun Lin','19 Roseville Avenue','Doncaster','Victoria','AUSTRALIA','3108','0398402465','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 07:56:53',0,NULL,3,1,11,1,'BJ01715676\r ','eastar4\rMOAP001'),(21984,8881329552451739,111,'地图伞',1,'UM00007',0,'eastar4','like-to-shop-around','lsmolica@sympatico.ca','Lesley Molica','1012 Sherman Cres','Pickering','ON','CANADA','L1X1P3','(905) 420-0969',NULL,NULL,NULL,'2012-02-18 08:07:31',0,NULL,3,1,11,1,'\\ ','补货\rUM00007 '),(21985,682672884013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','paulh3a1y','paulhealy@iinet.net.au','Paul Healy','CSC<br>Lvl1/516 Hay Street','Subiaco','Western Australia','AUSTRALIA','6008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 08:43:08',0,NULL,3,1,3,1,'RA184508058CN ','eastar4\rGLOT001*3'),(21986,843818381002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'buysia','talevib2303','talevib@gmail.com','tal levi','yehudit 3 apartment 2','bnei brak','','ISRAEL','51593','(972)775497190','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 09:20:04',0,NULL,3,1,3,1,'RA184508680CN\r ','buysia\rLGAD001'),(21987,627750761004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',18.9,'cnfaner','onatsmd','kancelaria@gstrans.sk','Stanislav MIHALKA','Hviezdoslavova 479','Senica','SLOVAKIA','SLOVAK REPUBLIC','90501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 09:40:00',0,NULL,3,1,3,1,'RA184508407CN ','cnfaner\rOTGR001'),(21988,627765033004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','tothdani-hu','rollandrockin@gmail.com','Daniel Toth','Tornacos 16','Nyíregyháza','Szabolcs-Szatmar-Bereg','HUNGARY','4551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 10:48:29',0,NULL,3,1,3,1,'RA184508441CN\r ','cnfaner\rCACN004'),(21989,799375270001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','dan69tay69','monkydet@hotmail.com','Daniel Taylor','106 s rambo','Dill city','OK','UNITED STATES','73641-9508','(405) 250-7901','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 10:50:39',0,NULL,3,1,1,1,'LK200171601CN\r ','buysia'),(21990,845762154011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','fredamey','fred_saley@yahoo.co.uk','MR FRED SALEY','24 JAVELIN COURT<br>WAKEHAMS GREEN DRIVE','CRAWLEY','West Sussex','UNITED KINGDOM','RH10 3RW','07960881964','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 11:16:11',0,NULL,3,1,3,1,'RA184508716CN\r ','eastar4uk\rMOAP001'),(21991,846060372011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',44.89,'eastar4','ramset2008','ramset2000@hotmail.com','Rafael Gomez Fernandez','Manuel Rubio Doval, 7','Dos Hermanas','Andalucía Ceuta y Melilla','SPAIN','41702','615831707','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 11:33:48',0,NULL,3,1,3,1,'RA184508852CN\r ','eastar4\rGLOT001'),(21992,936695418012,220886924074,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella',1,'UM00021',16.95,'eastar4uk','grub222','gruben@bigpond.net.au','Gary Ruben','60 Peppermint Grove','Knoxfield','Victoria','AUSTRALIA','3180','0398004130','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 12:29:56',0,NULL,3,1,11,1,NULL,'eastar4uk\r黑色的\rUM00021'),(21993,936696697012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',2,'OTCN003',9.98,'eastar4uk','spodism','alanhunter1308@hotmail.com','Alan Hunter','5 Whiffen Walk, East Malling','West Malling','Kent','UNITED KINGDOM','ME196TZ','01732522186','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 12:30:49',0,NULL,3,1,3,1,'RA184508906CN\r ','eastar4uk\rOTCN003'),(21994,936708703012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',4,'CASS001',25.16,'eastar4uk','wilfsky0161','wilfrado@sky.com','Stephen Williams','38 St Georges Crescent<br>Walkden','Manchester','Lancashire','UNITED KINGDOM','M283AN','07850209223','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 12:59:54',0,NULL,3,1,3,1,'RA184508733CN\r ','eastar4uk\rCASS001'),(21995,682534145013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',4,'TRTT002*10',340,'eastar4','123hpx','huascarsousa670@hotmail.com','sousa sistems comunications','7801 NW 37th St<br># SDQP-7409','doral','FL','UNITED STATES','33166-6503','809 238 5390','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 13:13:18',0,NULL,3,1,4,1,'YW868897473CN ','eastar4'),(21996,622437595003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','rgarber2','rgarber2@yahoo.com','Robert W. Garber II','2502 Fen View Cir','Island Lake','IL','UNITED STATES','60042-8828','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,'','cnfaner\recheck'),(21997,936735237012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4uk','danhayne','danielhayne@gmail.com','Daniel Hayne','20 Cotterill Road','Surbiton','Surrey','UNITED KINGDOM','kt67un','07765541777','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 14:00:11',0,NULL,3,1,3,1,'RA184508251CN\r ','eastar4uk\rOTCN003'),(21998,936741823012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',31.39,'eastar4uk','4721jamesg','j.grylls@sky.com','James Grylls','31 Honeygate','Luton','Bedfordshire','UNITED KINGDOM','LU2 7EP','07770222864','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 14:14:20',0,NULL,3,1,3,1,'RA184508659CN\r ','eastar4uk\rLGFI001'),(21999,846128205011,320395756118,'NEW CAB-2660-3FT BACK-TO-BACK WIC-2T TO WIC-1T 1T 2T ',2,'CASS002',19.98,'eastar4','zav59','andre.vaucamps@orange.fr','André Vaucamps','8 Domaine de la vigne<br>Rue des jardins','HAZEBROUCK','Nord-Pas-de-Calais','FRANCE','59190','06.80.30.20.80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 14:25:59',0,NULL,3,1,11,1,'\r ','eastar4\rCASS002'),(22000,846134967011,320394905532,'Acer Aspire 7110 7000 9300 Bluetooth Module 2.0 +cable',1,'BTAC2008',9.88,'eastar4','123stidolph','stids@blueyonder.co.uk','christopher stidolph','7 seton walk<br>simonside','south shields','Tyne and Wear','UNITED KINGDOM','ne34 9rq','0191423329','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 14:41:01',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2008\racer 4pin1.25 18cm  '),(22001,846137328011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','reksic2011','fox470@yandex.ru','Pavel Ishchishen','Suzdalskaya 38-2-124','Moscow','Moscow','RUSSIAN FEDERATION','111672','+79851162427','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 14:46:40',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA013\r欧标'),(22002,846167400011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',2,'WLDE001',19,'eastar4uk','ricknason','rick@nason.me.uk','Richard Nason','53, St. Austell Avenue','Macclesfield','Cheshire','UNITED KINGDOM','SK10 3NN','01625432991','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 15:48:14',0,NULL,3,1,3,1,'RA184508764CN\r ','eastar4uk\rWLDE001'),(22003,846158860011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',26.99,'eastar4uk','javierprado','javier_pr04@hotmail.com','javier prado','division azul 2, 16º-C','La Coruña','Galicia','SPAIN','15005','981272931','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 16:23:07',0,NULL,3,1,3,1,'RA184508225CN\r ','eastar4uk\rGLOT001'),(22004,622499439003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','sararn25','violetrn76@comcast.net','Sara Tipton','671 N Autumn Cir','Lindenhurst','IL','UNITED STATES','60046-7871','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 17:04:38',0,NULL,3,1,1,1,'LK200185424CN\r ','cnfaner'),(22005,846227474011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','wildfuss','gencheff@versanet.de','Josef Gencheff','Kock-und-Hunger Weg 1','Borken','','GERMANY','46325','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 17:36:01',0,NULL,3,1,3,1,'RA184508530CN\r ','eastar4uk\rGLOT001'),(22006,846232008011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','simplykitch','andysk1@hotmail.co.uk','Andy Brassett','12 Sampson Gardens','Ponsanooth Truro','Cornwall','UNITED KINGDOM','TR3 7RS','01872864407','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 17:44:08',0,NULL,3,1,3,1,'RA184508203CN ','eastar4uk\rSAFI001*3'),(22007,936874677012,220783475162,'New genuine Grohe Shower head holder made in Germany',1,'OTGR003',21.9,'eastar4','chrisr6057','chrisandkathyraymond@gmail.com','Chris Raymond','965 Via Fargo','Santa Maria','CA','UNITED STATES','93455-5059','(805) 478-1500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 18:09:24',0,NULL,3,1,1,1,'LK200270710CN\r ','eastar4'),(22008,846246361011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','maria.semina1984','maria.semina@mail.ru','Maria Semina','Zelenogradskaya 25-1-24','Moscow','Moscow','RUSSIAN FEDERATION','125475','79163302287','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 18:11:39',0,NULL,3,1,11,1,NULL,'eastar4uk\rTRSN001'),(22009,846255523011,320737995838,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',26.99,'eastar4uk','gledeczky','ledeczky@gmail.com','Ledeczky Gábor','Poroszlay út 68. 4/13<br>DC-LEDyNF Bt','Debrecen','Hungary','HUNGARY','4032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 18:28:07',0,NULL,3,1,3,1,'RA184508469CN ','eastar4uk\rGLOT001'),(22010,936888149012,220908829691,'4 pairs of New 3D Active Shutter TV Glasses compatible 4 3D TV Sony  LG samsung',1,'GLOT001*4',103.99,'eastar4uk','philstyl','phil.styl@gmail.com','Philippos Stylianopoulos','Vryandos 13','Thessaloniki','Greece','GREECE','55131','00306946943037','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 18:28:07',0,NULL,3,1,3,1,'RA184508509CN ','eastar4uk\rGLOT001*4'),(22011,682853443013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','eosyslov','eosyslov-mail@uniquitous.net','cheol-woong kim','#503 Anyang Megavalley, 799<br>Kwanyang, Dongan','Anyang','Kyoungki','KOREA,REPUBLIC OF','431-767','(010) 9367-4251','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:40:28',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP008'),(22012,936871581012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','sterlins10969','s.sterlin@gmail.com','Slava Sterlin','P.O.Box 3342','Haifa','Israel','ISRAEL','31033','(972)526808702','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:44:06',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA001'),(22013,791017694007,170746939505,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'au-buy','peoplespastor','revjcl@btopenworld.com','Rev James C Liddlwe','2 Paxstone Drive Harthill','Shotts','Strathclyde','UNITED KINGDOM','ML7 5RT','01501751869','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 18:53:05',0,NULL,3,1,11,1,NULL,'au-buy\rMOAP001'),(22014,936919885012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','derbert55','hammerdown55@hotmail.com','derrick keene','suite# 4432<br>2880 queen st east','brampton','ON','CANADA','l6s 6h4','(613) 920-4027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 19:15:55',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2012\racer 5pin1.25 6cm  '),(22015,846299124011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','l_trevizam','ltrevizam@me.com','Luis Trevizam','Rua Sargento Arnaldo Mangile, 261','Jundiai','Sao Paulo','BRAZIL','13216680','551196580011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 19:33:56',0,NULL,3,1,11,1,NULL,'eastar4\rUDAP001'),(22016,846306592011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',2,'TRSN001',55.98,'eastar4','henryf1946','henry.hartlove@yahoo.com','Henry F Hartlove','9308 Taborfield Ave','Orlando','FL','UNITED STATES','32836-8856','(443) 749-5449','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 19:44:17',0,NULL,3,1,1,1,'LK200252866CN\r ','eastar4'),(22017,782758941008,180730164137,'New DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',57.99,'au-buy','deepppsss','depptea10@hotmail.com','Ashvin','12 aurora court','springvale south','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-18 19:48:10',0,NULL,3,1,3,1,'RA184508614CN\r ','au-buy\rGLOT005'),(22018,627941836004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','57580','avibi10@gmail.com','Avi Bibi','Herzog<br>10','Kiriyt Ono','Israel','ISRAEL','55523','97236232535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 19:57:40',0,NULL,3,1,3,1,'RA184508146CN\r ','cnfaner\rOTGR001+OTGR002'),(22019,799629332001,110819588804,'New Original Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'buysia','0vycanismajoris0','william.hazardjr@gmail.com','William Hazard','68 Dorrance St<br># 132','Providence','RI','UNITED STATES','02903-2210','(757) 726-7490','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 20:00:27',0,NULL,3,1,1,1,'LK200196838CN\r ','buysia'),(22020,846314825011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','lime_green_tangerine','brfullr@hotmail.co.uk','Briony Fuller','Uni-Com (Global)<br>Enterprise Way','Edenbridge','Kent','UNITED KINGDOM','TN86EW','07846229280','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 20:02:24',0,NULL,3,1,3,1,'RA184508778CN\r ','eastar4uk\rMOAP001'),(22021,936948947012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','millerqc','rickm@ccapcable.com','richard meunier','1128 de la Durance','Quebec','QC','CANADA','G2N 1X2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 20:03:48',0,NULL,3,1,3,1,'RA184508631CN\r ','eastar4\rGLOT001*2'),(22022,782770795008,180767057234,'Original Logitech MX Revolution Mouse Mat 3M material',2,'SCLO003',11.32,'au-buy','sparhawk33','paulbreingan@westnet.com.au','Paul Breingan','7-9 Huntsmore Road','Minto','New South Wales','AUSTRALIA','2566','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-18 20:09:26',0,NULL,3,1,11,1,NULL,'au-buy\rSCLO003'),(22023,799638581001,110819588804,'New Original Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'buysia','tomera651234qwer','tomera65@gmail.com','Tomer Aronovsky','Tirosh 21/19','Nazareth Ilit','Israel','ISRAEL','17000','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-18 20:17:16',0,NULL,3,1,11,1,NULL,'buysia\rSCLO004'),(22024,627950033004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','llcroker','llcroker@hotmail.com','leslie croker','3612 Kipling dr','Orlando','FL','UNITED STATES','32808-7414','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-18 20:20:45',0,NULL,3,1,1,1,'LK200218048CN\r ','cnfaner'),(22025,791082021007,170775726989,'New HP MCE Media Center + Sony Remote Control RM-MCE20E White+IR Emitter Wire',1,'RMSN002',19.99,'au-buy','takiskgr1','takiskgr@hotmail.com','Panagiotis Kordas','Pratsika 26','Patras','','GREECE','26333','+302610310027','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 20:47:34',0,NULL,3,1,11,1,NULL,'au-buy\rRMSN002'),(22026,937005501012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Charles Shaw','2 Meadow Rd<br>Unit 2','PROVINCETOWN','MA','UNITED STATES','02657-1260','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 21:36:10',0,NULL,3,1,1,1,'LK200251485CN\r ','eastar4'),(22027,937006665012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','bobcode3','bobcode3@sbcglobal.net','Robert J. Zoanni','3475 4th St','Sparks','NV','UNITED STATES','89431-1223','(775) 356-5433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 21:37:09',0,NULL,3,1,1,1,'LK200254990CN\r ','eastar4'),(22028,628005768004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.49,'cnfaner','clickfm','itzikfm@gmail.com','itzik aharon','p.o.box 1235 bat-yam','bat-yam','israel','ISRAEL','59112','972522221115','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 23:08:34',0,NULL,3,1,3,1,'RA184508588CN\r ','cnfaner\rMOMI004'),(22029,937058628012,220785829016,'2 pairs 3D Active Shutter TV Glasses for Sharp Toshiba',1,'GLOT001*2',88.99,'eastar4','vumap1309','vvvt2909@yahoo.com','VU PHAN','2  KNOLLWOOD  COURT','BALLAJURA','Western Australia','AUSTRALIA','6066','0892495487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 23:26:27',0,NULL,3,1,3,1,'RA184508645CN\r ','eastar4\rGLOT001*2'),(22030,936454870012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','rdlight142','rdlight142@aol.com','Melissa Meneely','3024 W Medill Ave','Chicago','IL','UNITED STATES','60647-2821','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 23:48:06',0,NULL,3,1,1,1,'LK200204931CN\r ','eastar4\racer 8pin1.00 15cm '),(22031,791182493007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','bbugno','bugn4335@bears.unco.edu','Bruce Bugno','16640 Vincent Ave','Monument','CO','UNITED STATES','80132-8126','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-19 00:59:40',0,NULL,3,1,1,1,'LK200168372CN\r ','au-buy'),(22032,846463661011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','ipmaynard','ipmaynard@yahoo.com','Brent Maynard','1253 Honoco Rd','Aurora','NY','UNITED STATES','13026-9606','(607) 351-4737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 01:55:17',0,NULL,3,1,1,1,'LK200279798CN\r ','eastar4'),(22033,799773942001,110819588687,'New Original Logitech Harmony Remote USB Cable',1,'CALO001',3.87,'buysia','oslanir7575','sentinelsforce@yahoo.com','Oslanir Delisle','1730 nw 30th st','Miami','FL','UNITED STATES','33142-6167','(786) 525-9830','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-19 02:20:50',0,NULL,3,1,1,1,'LK200207120CN\r ','buysia'),(22034,844254101002,120770718021,'GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'buysia','shop_haggarty','disorient1@hotmail.com','Alex Kuhn','223A Bosler Ave','Lemoyne','PA','UNITED STATES','17043-1928','(717) 514-8730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 02:49:05',0,NULL,3,1,1,1,'LK200202096CN\r ','buysia'),(22035,622676921003,130596105709,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',18.98,'cnfaner','mleigh788','mhunley@my.apsu.edu','Megan Hunley','720 Commerce St','Clarksville','TN','UNITED STATES','37040','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-19 02:53:39',0,NULL,3,1,1,1,'LK200216753CN\r ','cnfaner'),(22036,937143681012,220922496581,'New In Box ZALMAN FG1000 FPS GUN Ergonomic Style Gaming USB Mouse',1,'MOZA001',39.99,'eastar4','darkghost01','d4rkgh0st.01@gmail.com','Carlos Manuel Jimenez Santana','7801 NW 37th St<br>Doral, FL 33166-6503 DO80Q41303N','Doral','FL','UNITED STATES','33166-6503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 03:41:57',0,NULL,3,1,1,1,'LK200265808CN\r ','eastar4'),(22037,937144107012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','te1979','te@pmtthai.com','Thanakorn Naparunghirun','499/1 PRACHAPATTHANA ROAD<br>THAPYAO LATKRABANG','BANGKOK','BA','THAILAND','10520','66812633331','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 03:43:53',0,NULL,3,1,3,1,'RA184508781CN\r ','eastar4\rOTSO002'),(22038,0,320845845013,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',0.49,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 03:54:53',0,NULL,3,0,18,0,'、 ','eastar4uk\r'),(22039,0,320845844508,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',0.5,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 04:04:14',0,NULL,3,0,18,0,'、 ','eastar4uk\r'),(22040,683024664013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','dibil','vinogradov777@yahoo.com','Artemiy Kononov','Matrosova 14, apt 16','Orehovo-Zuevo','','RUSSIAN FEDERATION','142600','(798) 515-3750 ext.: 4','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 04:35:28',0,NULL,3,1,3,1,'RA184508526CN\r ','eastar4\rLGAD001'),(22041,622695712003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','raalhumode','maldives@hotmail.com','Mohammed Niyad','6A Dhoonihuraa<br>Fareedhee Magu','Male\'','','MALDIVES','20257','+9607779992','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 04:41:30',0,NULL,3,1,3,1,'RA184508353CN ','cnfaner\rHBPH001'),(22042,835664796011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','blcom27','bedolajos@freemail.hu','Lajos Bedő','Radnoti u 44/c 3/8','Győr','','HUNGARY','9025','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 06:18:09',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLDE001'),(22043,846528201011,320618270639,'New 3.0 Bluetooth Module BCM92070MD BCM2070 24Mbps',1,'BTHP3000',13.97,'eastar4','shamitsingh','shamit@risingit.com.au','Shamit Singh','26 Cicada Street','THE PONDS','New South Wales','AUSTRALIA','2769','6141517984','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 06:31:34',0,NULL,3,1,11,1,NULL,'eastar4\rBTHP3000'),(22044,799845338001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','ljanco','rads2265@yahoo.com','Luis Jancowski','4251 Cedar Bluff Ln','Frisco','TX','UNITED STATES','75034-2666','(915) 613-3902','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-19 08:00:16',0,NULL,3,1,1,1,'LK200158738CN\r ','buysia'),(22045,791306976007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','charles_magnus','charles_magnus@hotmail.com','Charles Magnus','114 Benelong Rd','Cremorne','New South Wales','AUSTRALIA','2090','0421079909','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-19 09:42:52',0,NULL,3,1,11,1,NULL,'au-buy\rRELO002'),(22046,846583433011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','ingramvls','jean-francois.duminy@wanadoo.fr','Jean-François Duminy','102 Clos Chinon','Valenciennes','Nord-Pas-de-Calais','FRANCE','59300','03-27-42-20-95','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 09:45:13',0,NULL,3,1,11,1,NULL,'eastar4\rANCN001'),(22047,683096158013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','1errari','litvinenko@ya.ru','Stanislav Litvinenko','st. Prodolnaya 3 b / kv.86','Kharkov','Ukraine','UKRAINE','61085','(093) 699 77 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 10:35:49',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT008'),(22048,937268343012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','mengoo','yberhydro@gmail.com','Magnus Fredriksson','åsgatan 1','gamleby','','SWEDEN','59430','0046738090400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 10:44:39',0,NULL,3,1,11,1,NULL,'eastar4uk\rSCLO004'),(22049,846624516011,320679565914,'New Jabra BT320s Stereo Bluetooth ClipOn Earbud Headset',1,'HSJA003',14.99,'eastar4uk','majam_de','majam@t-online.de','AN Poelmann','Patersweg 75','Rhauderfehn','','GERMANY','26817','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 11:17:39',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSJA003\r欧标'),(22050,683118104013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','lowkode','rioze@gmx.net','Marko Liovic','Obere Donaustrasse 9-22','Vienna','','AUSTRIA','1020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 11:47:03',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(22051,846590488011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',44.89,'eastar4','andresb2h','b2hmusic@yahoo.com','Andres Selgoja','Kuldse Kodu 5 - 277','Pärnu','Pärnumaa','ESTONIA','80035','+372 566 86 499','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 12:10:20',0,NULL,3,1,3,1,'RA184508591CN\r ','eastar4\rGLOT001'),(22052,799941951001,110819588804,'New Original Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',5.9,'buysia','man1yak','andreybond@nm.ru','Andrey Bondarenko','165 Amboy Rd<br>Unit 710 - for \"3072\"','Morganville','NJ','UNITED STATES','07751','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-19 12:21:26',0,NULL,3,1,11,1,NULL,'buysia\rSCLO004\r新地址\rAndrey Bondarenko\rUlitsa Sovetskay 34, kvartira 7\rVsevolozhsk St-Peterburg region 188641\rRussian Federation\r等买家回复\r\r\r'),(22053,846664524011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','nazimabad','nhabbasi60@yahoo.ca','Nazir Abbasi','507 - 43 Thorncliffe Park Dr','East York','ON','CANADA','M4H 1J4','(416) 425-8222','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 12:37:20',0,NULL,3,1,11,1,NULL,'eastar4\rHSSA003'),(22054,846675262011,320826634741,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',35.99,'eastar4uk','ejdinnen','jim.dinnen@blueyonder.co.uk','jim dinnen','9 clough ave<br>walton park','preston','Lancashire','UNITED KINGDOM','pr5 4lq','01772627709','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 12:59:20',0,NULL,3,1,3,1,'RA184508234CN ','eastar4uk\rHBPH007'),(22055,845317695011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','kev.laundon','kevin_laundon@hotmail.com','Kevin  Laundon','C / Tarragona 7<br>buzon 6527','Teulada-Moraira','Comunidad Valenciana','SPAIN','03724','637120660','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 13:44:35',0,NULL,3,1,3,1,'RA184508027CN\r ','eastar4uk\rSAFI001*3'),(22056,937371601012,220816379757,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',26.99,'eastar4uk','kojaci','massa.ad@orange.fr','Adrien MASSARONI','18 rue du martin pêcheur<br>La grive','bourgoin jallieu','Rhône-Alpes','FRANCE','38300','06.16.70.96.52','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 14:01:23',0,NULL,3,1,3,1,'RA184508424CN ','eastar4uk\rGLOT001'),(22057,683181764013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','palomabianca2012','palomabianca@live.dk','AXEL POULSEN','BJERGEGADE 3,B','FREDERICIA','','DENMARK','7000',' 004535102807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 14:43:54',0,NULL,3,1,11,1,' ','eastar4\rOT00004'),(22058,846761375011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','anselmoas','anselmoas@yahoo.com.br','Sylvia Patricia Farias de Melo','Avenida do Contorno, 280 - bloco 43 casa 06','Jockey Club - São Gonçalo','Rio de Janeiro','BRAZIL','24743-100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 15:30:35',0,NULL,3,1,3,1,'RA184508044CN\r ','eastar4\rGLOT001'),(22059,937434937012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','ravb2000','ravibasra@hotmail.com','Ravi Basra','71 Hambledon Avenue<br>Bierley','Bradford','West Yorkshire','UNITED KINGDOM','BD4 6AX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 15:37:54',0,NULL,3,1,3,1,'RA184508035CN\r ','eastar4uk\rOTCN004*10'),(22060,937461791012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',2,'RELO002',16.78,'eastar4uk','green-growler','green.growler@gmail.com','martin harris','76 great ganett','welwyn garden city','hertfordshire','UNITED KINGDOM','al7 3de','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 16:12:02',0,NULL,3,1,3,1,' RA184508336CN','eastar4uk\rRELO002'),(22061,791519333007,170747501083,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.99,'au-buy','marantoni2010','mariouier@hotmail.com','marios iereidis','platonos 27<br>strovolos','nicosia','','CYPRUS','2040','0035799883603','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-19 16:31:06',0,NULL,3,1,11,1,NULL,'au-buy\rMOHP002'),(22062,937482869012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',3,'WLAP008',38.97,'eastar4uk','small.mac','smallmac@me.com','Werner Ramme','Untere Mauerstr. 3','Oschersleben','','GERMANY','39387','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 16:37:52',0,NULL,3,1,3,1,'RA184508177CN\r ','eastar4uk\rWLAP008'),(22063,846833610011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','droppedyota','ktobin2230@charter.net','kabala tobin','202 Fox Wood','Sanford','NC','UNITED STATES','27332','(910) 237-9351','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 17:05:55',0,NULL,3,1,1,1,'LK200266043CN\r ','eastar4'),(22064,937456141012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',89.4,'eastar4','ontario721','cabbage@rochester.rr.com','Walt Kowalczuk','721 Beach Ave','Rochester','NY','UNITED STATES','14612-2027','(585) 865-1772','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 17:11:35',0,NULL,3,1,1,1,'LK200307600CN\r ','eastar4\r再发一个New Philips Toothbrush Sonicare Travel Charger base \r'),(22065,683257406013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',2,'ADAK001',25.2,'eastar4','pccirkit','steve@pccirkit.com','PC Cirkit','2612 11th Ave','Greeley','CO','UNITED STATES','80631-8441','(970) 378-0081','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 17:14:14',0,NULL,3,1,1,1,'LK200280717CN\r ','eastar4'),(22066,628302816004,140667903886,'New Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card + Antenna*2',1,'WLAT010+ANTY001',13.9,'cnfaner','ferociousgto','dlmancheno@gmail.com','David Mancheno/Michelle Turner','1660 Brooks Ln','Oviedo','FL','UNITED STATES','32765-8627','(407) 314-2383','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-19 17:24:20',0,NULL,3,1,1,1,'LK200171805CN\r ','cnfaner'),(22067,844618832002,120844622194,'New Genuine iTech Clip II mini Multipoint Bluetooth Headset Blue',1,'HSIT004',39.9,'buysia','ravitmar','ravitmartinez@gmail.com','ravit martinez','Kibbuz Erez','Erez','Erez','ISRAEL','79150','972527995335','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-19 18:03:59',0,NULL,3,1,3,1,'RA184508472CN ','buysia\rHSIT004欧标'),(22068,622967114003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','paul02','paul.mari@gmail.com','Paul Mari','11 N Princeton Dr','Shelton','CT','UNITED STATES','06484-5153','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-19 18:30:41',0,NULL,3,1,1,1,'LK200180152CN\r ','cnfaner'),(22069,937620212012,220946749706,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','mobilehouse.dk','mobilehouse@live.dk','Charlotte Løvenskjold','Jydeholmen 33b , 4 sal','Vanløse','','DENMARK','2720','004524440001','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 18:50:14',0,NULL,3,1,11,1,NULL,'eastar4\rGPS0010'),(22070,846937969011,320628788243,'New IBM Atheros 5213A 802.11 a/b/g Mini PCI AR5BMB-44',1,'WLAT006',9.49,'eastar4','sauna-untensitzer','padex@gmx.net','Patrick Ament','Berliner Str. 84','Dresden','','GERMANY','01067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 18:52:59',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT006'),(22071,937630945012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','beatakrajewska','beata10021977@interia.pl','BEATA KRAJEWSKA','63 cranleigh road','london','London','UNITED KINGDOM','n15 3ah','07715178174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 18:58:37',0,NULL,3,1,3,1,'RA184508870CN\r ','eastar4uk\rGLSG001*2'),(22072,683364232013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','kaylawestmoreland','eastlesswater09@gmail.com','Kayla Westmoreland','407 Mary Lee Lane<br>Apt 301','Starkville','MS','UNITED STATES','39759','(601) 966-1374','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 19:38:47',0,NULL,3,1,1,1,'LK200288579CN\r ','eastar4'),(22073,846952215011,320721789253,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',44.89,'eastar4','pestillo92','pestillo92@hotmail.com','angel fernandez','c/maudes nº11 3ºF','Madrid','Madrid','SPAIN','28003','915542297','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:04:05',0,NULL,3,1,3,1,'RA184508296CN\r ','eastar4\rGLOT001'),(22074,847050550011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','drexeljames0410','jameslangel@mac.com','James Langel','117 S 13th St','Philadelphia','PA','UNITED STATES','19107-4807','(215) 601-5462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 20:42:54',0,NULL,3,1,1,1,'LK200268384CN\r ','eastar4'),(22075,937754514012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Doug Hellings','243 WOODLAND ACRES RD','PARIS','TN','UNITED STATES','38242-8138','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 20:51:30',0,NULL,3,1,1,1,'LK200162905CN\r ','eastar4'),(22076,937756422012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP002',12.99,'eastar4uk','lindajames2008','simtex35@hotmail.co.uk','Simon James Uwadiae','6 dulford walk<br>longsight','manchester','Greater Manchester','UNITED KINGDOM','m13 9ef','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 20:51:49',0,NULL,3,1,3,1,'RA184508075CN\r ','eastar4uk\rWLAP002'),(22077,683418504013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',8,'WLAP002',159.84,'eastar4','gothicbargaingear','corenetworks@hotmail.com','Patrick Welsh','41 bellflower Ave','Glasgow','Glasgow','UNITED KINGDOM','g53 7yd','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 21:02:34',0,NULL,3,1,3,1,'RA184508557CN\r ','eastar4\rWLAP002'),(22078,937770466012,220504388791,'2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable',1,'BTAC2111',12.39,'eastar4','geekg','kenneth.hann@gmail.com','Kenneth Hann','Hosmarinkuja 4 B 9','Espoo','.','FINLAND','02760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 21:08:27',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2111\rAcer 5pin1.25 3cm'),(22079,683432736013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','janis150988','astichs@gmail.com','Janis Astics','Hāpsalas iela 15-60','Riga','Latvia','LATVIA','LV-1005','(371) 28313827','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-02-19 21:29:42',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019\r欧标'),(22080,937801272012,220815932431,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',13.98,'eastar4uk','amir.gol','amirgol@bezeqint.net','Amir Gol','Yael Rom 13/11','Petah-Tiqva','','ISRAEL','49062','972-50-4014955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 21:48:25',0,NULL,3,1,11,1,NULL,'eastar4uk\rSHLO002'),(22081,847137156011,320827759270,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors',2,'PS00001',31.98,'eastar4uk','9095christina','tina96817@hotmail.com','christina thai','45-218 Wena St','kaneohe','HI','UNITED STATES','96744-2845','(808) 284-7664','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 22:49:28',0,NULL,3,1,1,1,'LK200304223CN\r ','eastar4uk\r一个黑的  一个珍珠白'),(22082,682635238013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','allanamyers42','persiankittyinfo@aol.com','matthew myers','123 W Bloomingdale Ave<br># 224','brandon','FL','UNITED STATES','33511-7400','(813) 433-6310','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 22:49:50',0,NULL,3,1,1,1,'LK200271468CN\r ','eastar4'),(22083,847149409011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.88,'eastar4','badboy628549297','aleman_axe_2005@hotmail.com','badel hernandez','c/diana 5<br>telde','las palmas','Canarias','SPAIN','35200','628549297','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 23:25:24',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2010\racer 5pin 1.25 3cm'),(22084,937864273012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','greck81','greck81@hotmail.com','Grygoriy Kutovy','15b<br>newcourt street','london','London','UNITED KINGDOM','nw87aa','07988061443','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 23:40:34',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2012\racer 5pin1.25 6cm'),(22085,847161099011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',60.45,'eastar4','greatcamping','peter.schilling@lutherheights.org.au','Helen Mibus','32 Rodrick Steet','Ipswich','Queensland','AUSTRALIA','4305','0754461135','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 23:43:47',0,NULL,3,1,3,1,'RA184508061CN\r ','eastar4\rWWSI006+ANCN001'),(22086,683429473013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','westsidesales2010','darrenjlevy@gmail.com','Darren Levy','10960 Wilshire Blvd<br>Ste 800','Los Angeles','CA','UNITED STATES','90024-3711','(310) 365-9819','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 00:03:29',0,NULL,3,1,1,1,'LK200270136CN\r ','eastar4'),(22087,783545073008,180758271107,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',5.9,'au-buy','jono_la26','laj01@iinet.net.au','Jonathon La','6 Vanguard Place','Currambine','Western Australia','AUSTRALIA','6028','0893054034','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 00:06:06',0,NULL,3,1,11,1,NULL,'au-buy\rSCLO005'),(22088,628519800004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','borealwireless','scott.astle@gmail.com','Scott Astle','#102, 346 Centre St','Kinuso','AB','CANADA','T0G1K0','(780) 775-2220','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 00:10:14',0,NULL,3,1,3,1,'RA184508804CN\r ','cnfaner\rOTCN004'),(22089,937868529012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','ericpeders09','ericpeders@yahoo.com','eric pedersen','130 NW 18th Ave<br>null','camas','WA','UNITED STATES','98607-1209','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 23:53:04',0,NULL,3,1,1,1,'LK200268469CN\r ','eastar4'),(22090,847192789011,320730088505,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',13.99,'eastar4uk','bumfarter69','bumfarter69@hotmail.com','anthony ellis','6 sorrel close','waterlooville','Hampshire','UNITED KINGDOM','po78pf','02392425546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 01:04:07',0,NULL,3,1,3,1,'RA184508676CN\r ','eastar4uk\rOTTP001'),(22091,800437158001,110806566468,'New Genuine Samsung WMN2050B1 Ultra Slim Wall Mount for 2011 LED 46\"-60\"',1,'MOSA008',68.99,'buysia','jrw8580','jrw8580@aol.com','Jonathan Walker','4520 grainary ave','tampa','FL','UNITED STATES','33624-2127','(727) 481-7071','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-20 01:15:16',0,NULL,3,1,1,1,'LK200178661CN\r ','buysia'),(22092,791897839007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','philip2683','jfsoares2@optusnet.com.au','Jose Soares','6 Warren Parade<br>Punchbowl','Sydney','New South Wales','AUSTRALIA','2196','0297031955','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 01:35:42',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR001'),(22093,679685056013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','tyler.brack','trap_133@hotmail.com','Tyler Brack','25 Bluefox Place','Lethbridge','AB','CANADA','T1H6E6','(403) 328-5039','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 03:32:40',0,NULL,3,1,11,1,NULL,'eastar4\rOT00004'),(22094,847258655011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','aqtaylor','abby.q.taylor@gmail.com','Abby Taylor','271 Yehlshire Dr','Galloway','OH','UNITED STATES','43119','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 04:07:14',0,NULL,3,1,1,1,'LK200242271CN\r ','eastar4'),(22095,800498262001,110827822425,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM92070 Half Mini PCI-E Card',1,'WLIN015',14.99,'buysia','bushrat2010','casey.lunn@gmail.com','Casey Lunn','249 Tuscany Way NW','Calgary','AB','CANADA','T3L 2Y8','(604) 781-9699','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-20 04:09:07',0,NULL,3,1,11,1,NULL,'buysia\rWLIN015'),(22096,937982965012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','101marty101','martin@apexcentral.com','Martin Suchta','34 Volitans Avenue','Mount Eliza','Victoria','AUSTRALIA','3930','0413596050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 04:32:16',0,NULL,3,1,3,1,'RA184508129CN\r ','eastar4\rOTSO002'),(22097,800506114001,110808693121,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors',1,'PS00001',25.99,'buysia','qduo9049','tiensi_kimquangduong_robot@yahoo.com','QUANG DUONG VU','8 Barnes cres','melbourne','Victoria','AUSTRALIA','3020','0423364486','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-20 04:44:11',0,NULL,3,1,11,1,NULL,'buysia\rPS00001\rlight silver\r'),(22098,791955749007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','smalltime0','tylerinwoodvale@gmail.com','Tyler Morris','26 Trappers Drive','Woodvale','Western Australia','AUSTRALIA','6026','0894097134','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 04:47:56',0,NULL,3,1,11,1,NULL,'au-buy\rRELO002'),(22099,783643603008,180812398629,'New Microsoft Wired Optical Wheel USB Compatible  Mouse White',1,'MOMI004',13.79,'au-buy','unityole','jack_tuboogee@hotmail.com','jack tu','#102 12153 78 Avenue','Surrey','BC','CANADA','V3W5B6','(604) 722-7798','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-20 05:25:49',0,NULL,3,1,11,1,NULL,'au-buy\rMOMI004'),(22100,938003124012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','phschweiz','phschweiz@aol.com','paul schweizer','4430 E Camelback Rd<br>Unit 43; Village at Camelback','Phoenix','AZ','UNITED STATES','85018-2834','(602) 466-3252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 05:59:30',0,NULL,3,1,1,1,'LK200259983CN\r ','eastar4'),(22101,938006442012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Rochelle Weber','1735 Portland Ave','Saint Paul','MN','UNITED STATES','55104-6844','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 06:17:48',0,NULL,3,1,1,1,'LK200214457CN\r ','eastar4'),(22102,683008633013,230641625366,'3 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*3',132.99,'eastar4','u4ea2003','u4ea@internode.on.net','Jim Wisely','10 Viewfield Crescent','Woongarrah','New South Wales','AUSTRALIA','2259','0243932093','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 06:35:11',0,NULL,3,1,3,1,'RA184508375CN ','eastar4\rGLOT001*3'),(22103,791993730007,170735485464,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',21.99,'au-buy','willcate','iamgoodwill@mac.com','William Cate','1/15 francis st<br>bondi beach','sydney','New South Wales','AUSTRALIA','2026','0292117811','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 08:06:26',0,NULL,3,1,11,1,NULL,'au-buy\rUM00012'),(22104,683602646013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'eastar4','boris.adlivankin','a_boris@inbox.ru','Boris Adlivankin','Butlerova str, 40, appt. 437','St.Petersburg','StPetersburg','RUSSIAN FEDERATION','195220','(921) 9307689','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 08:41:42',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN014'),(22105,938041284012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','yaffa5367','marakatabee@access4less.net','Sharrond Ingram','312 E Hatcher Rd<br>Apt 10','Phoenix','AZ','UNITED STATES','85020-5733','(213) 361-8401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 08:52:15',0,NULL,3,1,1,1,'LK200231163CN\r ','eastar4'),(22106,683606127013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','k0t1k','ms@xaker.ru','Alexandr Malykov','Krivenkova 7a, 120','Lipetsk','Lipetsk obl','RUSSIAN FEDERATION','398032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:01:46',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(22107,938043892012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','malangus','malangus@hotmail.com','Malcolm Angus','The Old Kennels, Market Flat Lane, Old Scriven','Knaresborough','North Yorkshire','UNITED KINGDOM','HG59JA','01423862930','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:02:40',0,NULL,3,1,3,1,'RA184508455CN\r ','eastar4\rHBPH007'),(22108,938044839012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','matthewbpearson','matthewbpearson1@tiscali.co.uk','M Pearson','CLAYTON EQUIPMENT<br>SECOND AVENUE','CENTRUM 100','BURTON UPON TRENT','UNITED KINGDOM','DE14 2WF','01283524475','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 09:04:10',0,NULL,3,1,3,1,'RA184508319CN\r ','eastar4uk\r\rOTGR001'),(22109,847329872011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',48.99,'eastar4','giroauctions','girodesigns@yahoo.com.au','Giro Pontecorvo','64 Carlton Parade<br>Torrensville','ADELAIDE','South Australia','AUSTRALIA','5031','0883524951','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:31:54',0,NULL,3,1,3,1,'RA184508574CN\r ','eastar4\rLGRM001'),(22110,628637546004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','vlal','achimescua@clicknet.ro','Alexandru Achimescu','P.O.Box 3-145','Bacau','','ROMANIA','600440','0040752300125','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:06:46',0,NULL,3,1,3,1,'RA184508821CN\r ','cnfaner\rBALO007'),(22111,847327141011,320826738279,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',2,'HSNO035',225.98,'eastar4','spgkionis','sgkionis@yahoo.gr','Spyros Gkionis','Polytexniou str.<br>Kato Assos','Assos Korinthias','Korinthia','GREECE','20006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:08:06',0,NULL,3,1,3,1,'RA184509359CN\r ','eastar4\rHSNO035'),(22112,847044306011,320645703558,'New DELL D630 D830 BCM4321 WiFi Mini PCI-E Card+antenna',1,'WLDE001+ANTY001',16.98,'eastar4','dennisfranssen','ebay@mekker.net','Dennis Franssen','Kinrooiersteenweg 40','Neeroeteren','','BELGIUM','3680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:21:37',0,NULL,3,1,11,1,NULL,'eastar4\rWLDE001+ANTY001'),(22113,628642709004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',21.9,'cnfaner','felix850621','vasilev_mbal@abv.bg','Vladimir Vasilev','Belomorski No 53<br>MBAL Dr.Atanas Dafovski pk 71 et 5','Kardzhali','KARDZHALI','BULGARIA','6600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:31:26',0,NULL,3,1,3,1,'RA184508835CN\r ','cnfaner\rOTHP004'),(22114,937565661012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','george1962linda','linda-higginson@sky.com','Linda Higginson','72 bromley rd','Congleton','Cheshire','UNITED KINGDOM','Cw121qa','01260270806','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 10:50:36',0,NULL,3,1,3,1,'RA184508795CN\r ','eastar4uk\rSAFI001'),(22115,800586249001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','jackiechan1961','art@esthy.ch','esther baltisberger','wachtweg 1','reinach','','SWITZERLAND','4153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:59:03',0,NULL,3,1,11,1,' ','buysia\rOTSB001\r'),(22116,938080528012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','g0osie','t0mie@hotmail.com','Thommy Sophabmixay','8 Strang Street','Hoppers crossing','Victoria','AUSTRALIA','3029','0425731958','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184509800CN\r ','eastar4\r这票EACHECK清了   但没有再下来   就用这个发吧'),(22117,628653869004,140490658302,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',1,'WWSI006',55.45,'cnfaner','hipermedia','hipermedia.split@gmail.com','Boris Ostojic','Kukuljeviceva 22','Split','SD','CROATIA','21000','+38598490509','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 11:29:22',0,NULL,5,0,18,0,NULL,'cnfaner\r买家要取消订单'),(22118,847369008011,320827754575,'New 4 Parking Sensor Car Reverse backup Radar kit w/ buzzer 10 colors available',1,'PS00002',14.99,'eastar4uk','micallef117','xib117@yahoo.co.uk','Charmaine Sciberras','Flat 1 Zantedeschia<br>Triq il- Qanpiena','Swatar','Malta','MALTA','BKR 13','0035621491441','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 11:47:45',0,NULL,3,1,11,1,'BJ01714466\r ','eastar4uk\rPS00002\r浅银色的'),(22119,628663595004,140630817200,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',34.99,'cnfaner','didiln1','didiln@gmail.com','David Levy Nahum','Hagra 4','Rehovot','','ISRAEL','76310','(972) 525-5767 ext.: 74','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 12:17:16',0,NULL,3,1,3,1,'RA184508693CN\r ','cnfaner\rCC00002'),(22120,844158313002,120844622171,'New GENUINE iTech Clip II mini Multipoint Bluetooth Headset Black',1,'HSIT002',39.9,'buysia','kostikas84','kostikas84@yahoo.gr','konstantinos kalogeras','paladiou 12','tripoli','greece','GREECE','22100','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-20 12:45:46',0,NULL,3,1,3,1,'RA184508897CN\r ','buysia\rHSIT002\r欧标'),(22121,623288287003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','sadr1349','adriaanse@gmail.com','Sam Adriaanse','Tweede kade 28','Gouda','','NETHERLANDS','2806PS','0031642068886','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 13:08:55',0,NULL,3,1,3,1,'RA184508305CN\r ','cnfaner\rBALO007'),(22122,683659443013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','samowens76','samuelowens@gmail.com','Samuel Owens','2/32 John Street','Brunswick East','Victoria','AUSTRALIA','3057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 13:26:31',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP002'),(22123,628684308004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.89,'cnfaner','miasnikov','stas.miasnikov@gmail.com','Stas Miasnikov','Mivtsa uvda<br>2810','Beer Sheva','Negev','ISRAEL','84462','0508387192','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 14:06:29',0,NULL,3,1,3,1,'RA184508415CN\r ','cnfaner\rLGAD001'),(22124,938176401012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','olliejingles','lizzyhess@gmail.com','Elizabeth Hess','1319 Ella T Grasso Blvd','New Haven','CT','UNITED STATES','06511-4258','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 15:25:37',0,NULL,3,1,1,1,'LK200217087CN\r ','eastar4\r蓝天白云长柄伞 '),(22125,847450092011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',11.54,'eastar4uk','matteegee','mattee@kuzodata.com','Matt Griffith','62 Queenswood Drive','Sheffield','South Yorkshire','UNITED KINGDOM','S6 1RJ','07516922441','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 15:35:01',0,NULL,3,1,3,1,'RA184508702CN\r ','eastar4uk\rOTHP005'),(22126,623324516003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','akila9643','akila@ganegoda.com','Akila Ganegoda','120/3, Barnes Place, Colombo 7','Colombo','-','SRI LANKA','-','94777577722','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 15:35:30',0,NULL,3,1,3,1,'RA184508194CN ','cnfaner\rMOOE002\rOEM'),(22127,792130329007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',32.99,'au-buy','gifwif7','cneil524@yahoo.com','Connie Neil','237 Dawsons Park Dr','Lexington','SC','UNITED STATES','29072-1924','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-20 15:42:04',0,NULL,3,1,1,1,'LK200156431CN\r ','au-buy'),(22128,938177123012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','calucian2','campan@gmail.com','Lucian Campan','Stefan Cel Mare Nr.1-3','Bucharest','Sector 1','ROMANIA','011736 ','004 0740 188 748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 15:26:29',0,NULL,3,1,11,1,NULL,'eastar4\rWLDE002'),(22129,792137338007,170784441949,'New Genuine Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card Over AR5008',1,'WLAT010',8.99,'au-buy','te241rus','te241@yandex.ru','Eugenia Tavyrikova','corp.601A,  room1','Zelenograd,','Moscow','RUSSIAN FEDERATION','124489','+7-915-246-68-48','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-20 15:57:01',0,NULL,3,1,11,1,NULL,'au-buy\rWLAT010'),(22130,847355913011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',33.98,'eastar4uk','neo_riga','ebay@neo.lv','Gundars Bedre','Daugavgrivas iela 45 (NEO)','Riga','','LATVIA','LV-1007','371-675-00360','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 15:43:19',0,NULL,3,1,3,1,'RA184508755CN\r ','eastar4uk\rMOAP001'),(22131,0,320845844479,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',0.02,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 16:07:44',0,NULL,3,0,18,0,'、 ','eastar4uk\r'),(22132,0,220950830943,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',2.72,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 16:09:10',0,NULL,3,0,18,0,'、 ','eastar4uk\r'),(22133,0,220950830179,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',1.57,'eastar4uk','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 16:10:36',0,NULL,3,0,18,0,'、 ','eastar4uk\r'),(22134,847518935011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',8,'MOAP001',135.92,'eastar4uk','lastybay','mikelast@mac.com','mike last','Office 20, Dainton Business Park<br>Heathfield','Newton Abbot','Devon','UNITED KINGDOM','TQ12 6RG','07979813430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 18:01:39',0,NULL,3,1,3,1,'RA184508490CN ','eastar4uk\rMOAP001'),(22135,938258123012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',139.95,'eastar4','dblezard','djb1@cisunix.unh.edu','David Blezard','15 Academic Way<br>University of New Hampshire','Durham','NH','UNITED STATES','03824-2602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 18:05:38',0,NULL,3,1,1,1,'LK200260417CN\r ','eastar4'),(22136,938291634012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','l.i.o.n.e.r','j.a.n.n.y@arcor.de','Evgenia Korchmenko','Mainzer Str. 165','Saarbrücken','','GERMANY','66121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 18:58:11',0,NULL,3,1,11,1,NULL,'eastar4\rRMSN002'),(22137,800771769001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','shimon1shimon','shimongozlan7@gmail.com','shimon gozlan','yaar odem 38/4','yokneam elit','israel','ISRAEL','20692','0504220466','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-20 19:07:29',0,NULL,3,1,3,1,'RA184508747CN\r ','buysia\rGPS0006'),(22138,847563073011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','bill001billy','w.keeble@ntlworld.com','william keeble','28, moray place<br>kirkintilloch','glasgow','East Dunbartonshire','UNITED KINGDOM','G663SR','01415780130','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 19:14:17',0,NULL,3,1,3,1,'RA184508605CN\r ','eastar4uk\rGLOT001'),(22139,938308566012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','goyo_pollo','greg_ewald@comcast.net','Greg Ewald','1059 Camino Ramon','San Jose','CA','UNITED STATES','95125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 19:20:53',0,NULL,3,1,1,1,'LK200197419CN\r ','eastar4'),(22140,847571388011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',2,'HSSA003',27.8,'eastar4','philgoodphil','philgood0@hotmail.com','Philippe Emond','1208 rue de st-jovite','Mont-Tremblant','QC','CANADA','J8E 3J9','(819) 687-9259','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 19:27:01',0,NULL,3,1,11,1,NULL,'eastar4\rHSSA003'),(22141,792274076007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','lilmissy3797','pandad@bigpond.net.au','Adrianne de Boers','40 Gowrie Avenue','Frankston South','Victoria','AUSTRALIA','3199','0397837274','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 20:15:10',0,NULL,3,1,11,1,NULL,'au-buy\rcute cat\rUM00033\r缺货没发货'),(22142,683803853013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','avav613613','avav613@gmail.com','עמיחי וידל','pob ת.ד. 16048<br>הפסגה hapisga','ירושלים jerusalem','','ISRAEL','91160','0548006305','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 20:20:11',0,NULL,3,1,11,1,'BJ01714457 ','eastar4\rADAK001'),(22143,938352702012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','marmatoes','mjmalliton@gmail.com','Marty Malliton','3759 Pallos Verdas Dr','Dallas','TX','UNITED STATES','75229-2741','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 20:23:47',0,NULL,3,1,1,1,'LK200253331CN\r ','eastar4'),(22144,623429792003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','coco57290','c.carratero@free.fr','SCHOLLER Maryse','1 rue Neuve','FLORANGE','Lorraine','FRANCE','57190','0382586694','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 20:29:32',0,NULL,3,1,3,1,'RA184508322CN\r ','cnfaner\rMOAP001'),(22145,683806910013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sergey.ssn','ssn@mail333.com','Sergey Syrenkov','st.Oktyabrskiy art. 340/2, 134','Nikolaev','Nikolaev','UKRAINE','54051','+380977877931','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 20:29:39',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019\r欧标'),(22146,792285381007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','kstinius','tinius@mindspring.com','Stephen Tinius','3820 39th St NW','Washington','DC','UNITED STATES','20016','(202) 537-6632','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-20 20:32:42',0,NULL,3,1,1,1,'LK200195554CN\r ','au-buy'),(22147,792300968007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.9,'au-buy','mlh2005','hudcon@bigpond.net.au','Marina  Huddleston','P.O Box  415<br>KENMORE','Brisbane','Queensland','AUSTRALIA','4069','0733743015','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 21:00:56',0,NULL,3,1,11,1,' ','au-buy\rOTGR001'),(22148,938385084012,220820867298,'New Grohe Copper Plating Multi function washer +hose',1,'OTGR006+OTGR002',48.9,'eastar4','idoalgom','ido.algom@gmail.com','Ido Algom','6 Asirey-Zion St.','Petah-Tiqwa','','ISRAEL','49519','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 21:14:52',0,NULL,3,1,3,1,'RA184508883CN\r ','eastar4\rOTGR006+OTGR002'),(22149,847639285011,320618273610,'New 3.0 Bluetooth BCM2070 Module+cable HP 5220m MINI311',1,'BTHP3002',19.98,'eastar4','albrechttechsolutions','tjalbrecht@gmail.com','Albrecht Technology Solutions','2118 Water Lilly Ln','Eagan','MN','UNITED STATES','55122-1930','(612) 710-8255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 21:17:48',0,NULL,3,1,1,1,'LK200219009CN\r ','eastar4\rHP 6pin1.0 3cm '),(22150,628843585004,140550602578,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',72.99,'cnfaner','wutangbiz','doru.anusca@gmail.com','Teodor Anusca','Str. Tineretului Nr.5 Ap.53','Floresti','Cluj','ROMANIA','407280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 21:27:55',0,NULL,3,1,3,1,'RA184508248CN ','cnfaner\rOTSO002'),(22151,847636701011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','silkflower3','kashalee3@gmail.com','tresa moore','22145 kenosha','oak park','MI','UNITED STATES','48237','(313) 437-2973','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 21:12:39',0,NULL,3,1,1,1,'LK200248606CN\r ','eastar4'),(22152,683618000013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',6,'CASS003',65.94,'eastar4','melatdel','melwinds@gmail.com','Melwin D\'souza','Suite 2, Ground Floor<br>460 Lower Heidelberg Rd','Melbourne','Victoria','AUSTRALIA','3084','0402385744','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 21:47:34',0,NULL,3,1,3,1,'RA184508849CN\r ','eastar4\rCASS003'),(22153,683841830013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',53.99,'eastar4','bertrandassoun','bertrand.hasson@gmail.com','Bertrand Assoun','Ben Gurion 42/10','hertzlia','Israel','ISRAEL','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 22:04:19',0,NULL,3,1,3,1,'RA184508367CN ','eastar4\rLGAD001'),(22154,847662604011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','shane.swing','kaznswing@live.com.au','shane sing','23 hogarth ave<br>mt warrigal','shellharbour','New South Wales','AUSTRALIA','2528','0401976285','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 22:07:53',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2022\racer 8pin1.00 15cm'),(22155,938437039012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','only_aviation','dcress@isomedia.com','David Cress','3464 Needham Rd','Lexington','OH','UNITED STATES','44904-9208','(419) 566-9341','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 22:53:12',0,NULL,3,1,1,1,'LK200231265CN\r ','eastar4'),(22156,938387192012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','jak1095','jak.spalding@gmail.com','Jak Spalding','366 Bideford Green<br>Linslade','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','Lu7 2tx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 23:20:56',0,NULL,3,1,3,1,'RA184508720CN\r ','eastar4uk\rWLAP008'),(22157,847699934011,320814026443,'NIB Genuine LG Premium Water Filter Gen11042FR-08 for Kenmore LG refrigerators',1,'LGFI001',51.99,'eastar4','10nijenchung','nijenchung@yahoo.com.br','NI JEN  CHUNG','RUA ABRAAO MIGUEL DO CARMO, <br>No. 101, AP. 83','SAO PAULO','SAO PAULO','BRAZIL','04306-090','55-11-8389-5939','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 23:31:02',0,NULL,3,1,3,1,'RA184508565CN\r ','eastar4\rLGFI001'),(22158,847702069011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','sandy_mbr','sandrix@windowslive.com','Martin Józsa','Garbiarska 48/49','Sered','Slovakia','SLOVAK REPUBLIC','92601','00421911910824','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 23:38:02',0,NULL,3,1,11,1,NULL,'eastar4uk\rCACN004'),(22159,683887292013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','rodriluisbra','rodriluis0801@hotmail.com','Rodrigo Araujo','Av Almirante Barroso, Alameda tatiana 3629 casa 28','Belém','Pará','BRAZIL','66613020',' 9183061110','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 00:58:28',0,NULL,3,1,3,1,'RA184508384CN ','eastar4\rGLOT001*2'),(22160,938484211012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',181.99,'eastar4','mhhpf1helen','mhhpf1@bigpond.com','Helen Farrell','51 Greenwood Drive','Kirwan','Queensland','AUSTRALIA','4817','0747554910','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 01:00:27',0,NULL,3,1,3,1,'RA184508628CN ','eastar4\rPSGL001*2'),(22161,792406337007,170784400998,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card+Tyco 2.4/5.0 GHz Antenna *3',1,'WLIN010+ANTY002',21.49,'au-buy','all_carbon','acurnow5@bigpond.com','Adrian Curnow','265 Bay St.','Port Melbourne','Victoria','AUSTRALIA','3207','0396818533','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 02:00:18',0,NULL,3,1,11,1,'\\ ','au-buy\rWLIN010+ANTY002'),(22162,623525954003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',3,'BALO007',34.5,'cnfaner','tygarbyte','bangahh@hotmail.com','Hue  Vang','AWI - Lvl 30, 580 George St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 02:17:10',0,NULL,3,1,3,1,'RA184508818CN\r ','cnfaner\rBALO007'),(22163,938511927012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','ljampietri','jampietri@yahoo.com.br','LEONARDO PAIVA','Av. Dr Rudge Ramos 520 - ap 34','SÃO BERNARDO DO CAMPO','SÃO PAULO','BRAZIL','09636000','551143314213','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 02:18:55',0,NULL,3,1,3,1,'RA184508512CN\r ','eastar4\rGLOT001'),(22164,628920032004,140482243074,'New  NOKIA BH-202 BLUETOOTH HEADSET offer track#',1,'HSNO006',14.88,'cnfaner','davidh441','dhooper441@yahoo.ca','David Hooper','441 Riverdale Ave.','Windsor','ON','CANADA','N8S4B7','(519) 944-3086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 02:22:53',0,NULL,3,1,3,1,'RA184508662CN\r ','cnfaner\rHSNO006\r美标'),(22165,938528922012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','dunkinskillz','orsatd@gmail.com','Daniel Orsatti','421 Andrews Rd','Mineola','NY','UNITED STATES','11501-1003','(516) 294-0876','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 03:08:51',0,NULL,3,1,1,1,'LK200224352CN\r ','eastar4'),(22166,623538825003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',5.99,'cnfaner','mambo957','marcalexandrefernandes@hotmail.com','marc fernandes','55 rue binette<br>appartement 6','st-eustache','QC','CANADA','j7p5t3','(450) 491-2989','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 03:18:17',0,NULL,3,1,3,1,'RA184508089CN\r ','cnfaner\rANTY002'),(22167,8881329794546236,111,'For Philips Sonicare Flexcare Toothbrush Handle HX6930 - ',1,'HBPH002',55.99,'aliexpress','1006867095 ','mnospm@gmail.com','Mindaugas Kubaitis','1341 N. Poinsettia PL APT 4 ','Los Angeles','California','UNITED STATES','90046','+1 323 3328731',NULL,NULL,NULL,'2012-02-21 03:22:26',0,NULL,3,0,1,1,'LK106460802CN ','没有6930 客户要6950 '),(22168,623545419003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',5,'WLIN013',89.45,'cnfaner','caseyblackburn','blackcj@synapseconnections.net','Casey Blackburn','2200 The Crossings Dr','Mckinney','TX','UNITED STATES','75069-0948','(214) 544-2405','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-21 03:51:23',0,NULL,3,1,1,1,'LK200537642CN\r ','cnfaner'),(22169,628914727004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',2,'GPS0010',64,'cnfaner','bino122','inrerj@yahoo.com.br','fabiano d silva','4283 expresso pista<br>Suíte P2593','Sarasota','FL','UNITED STATES','34238','(555) 810-0384','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-21 04:01:36',0,NULL,3,1,3,1,'RA184508185CN ','cnfaner\rGPS0010\r新地址\rFABIANO DA SILVA\rRUA ARMANDO DE ALBUQUERQUE 33 ,VILA ISABEL\rCEP: 20.560-130 , RIO DE JANEIRO -RJ\rBrazil\r'),(22170,623544090003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','f1nalsin','birdistheword@live.com.au','taylor williams','2 elmslie close','wodonga','Victoria','AUSTRALIA','3690','0260598455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 04:07:18',0,NULL,3,1,3,1,'RA184508132CN\r ','cnfaner\rBALO007'),(22171,800986397001,110808693121,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors',1,'PS00001',25.99,'buysia','rraviol','raviol@list.ru','Oleg Gavrilov','Voronova, 9A-37','Krasnoyarsk','Krasnoyarsk region','RUSSIAN FEDERATION','660112','+7(913)830-1354','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 04:22:58',0,NULL,3,1,11,1,NULL,'buysia\rPS00001\rlight silver'),(22172,8881329798773364,111,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',50,'ANCN001',100,'eastar4','akarama','garantitek@gmail.com','Mouin Abdallah','Uhlandstr. 2    Keine Nachbarschaftsabgabe','Kleinblittersdorf','','GERMANY','66271','',NULL,NULL,NULL,'2012-02-21 04:32:53',0,NULL,3,1,3,1,'RA184509889CN\r ','eastar4\r直接打款 \rANCN001'),(22173,784124793008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','bryanatk','bcatkins@people.net.au','Bryan Atkinson','86 Thylungra Rd, Park Ridge','Brisbane','Queensland','AUSTRALIA','4125','0738021455','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 04:26:20',0,NULL,3,1,11,1,NULL,'au-buy\rMOMI002'),(22174,0,130645663603,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',407.56,'cnfaner','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-21 04:44:53',0,NULL,3,1,18,0,'/ ','cnfaner'),(22175,800995031001,110827822599,'New IBM/thinkpad Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'buysia','econometer','econometer7@gmail.com','Jinho Kim','Jinro APT 711-901 Sungbookgu','Seoul','Jongranggu','KOREA,REPUBLIC OF','131-130','(02)3422-5880','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 05:17:39',0,NULL,3,1,11,1,' ','buysia\rWLAT003'),(22176,938564384012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','lynn120','tleonardson@gmail.com','Tansy Leonardson','440 N Winchester Blvd<br>Apt 120','Santa Clara','CA','UNITED STATES','95050-6349','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 05:23:13',0,NULL,3,1,1,1,'LK200373365CN\r ','eastar4'),(22177,792463362007,170762819519,'Brand new HP MCE Media Center Remote Control bigger + IR RECEIVER+IR Emitter',1,'OTHP004',21.9,'au-buy','sticky_llama','stickyllama.purchase@googlemail.com','Scott Burnett','Landgate Duty Desk - Rear Security<br>Keane Street','Midland','Western Australia','AUSTRALIA','6056','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 05:26:34',0,NULL,3,1,11,1,NULL,'au-buy\rOTHP004'),(22178,683950203013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','ayman908','hamzahjones@yahoo.com','Andrew Jones','85 Lyrebird Way<br>Thornlie','Perth','Western Australia','AUSTRALIA','6108','00894586316','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 05:35:45',0,NULL,3,1,3,1,'RA184508265CN\r ','eastar4\rGPS0006'),(22179,938574257012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Barbara Jerabek','6216 Mount Olivet Cres','Middle Village','NY','UNITED STATES','11379-1046','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 06:09:13',0,NULL,3,1,1,1,'LK200506251CN\r ','eastar4'),(22180,628959403004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',18.9,'cnfaner','meshcan','mehdi.ahmari@gmail.com','Mehdi Ahmari','720 104 Ave SW','Calgary','AB','CANADA','T2W 0A3','(403) 253-6960','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 06:15:23',0,NULL,3,1,3,1,'RA184508092CN\r ','cnfaner\rOTGR001'),(22181,938576683012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','fazz101','nickjfarrow@yahoo.com.au','Nick Farrow','44 Avon Road','Avonsleigh','Victoria','AUSTRALIA','3782','0359686919','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 06:22:35',0,NULL,3,1,3,1,'RA184508398CN ','eastar4\rGLOT001*2'),(22182,792477619007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',2,'CC00002',71.98,'au-buy','inozzie','winsum7@bigpond.com','Lisa Chawner','8 Cassegrain cl','Eleebana','New South Wales','AUSTRALIA','2282','0249468080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 06:47:08',0,NULL,3,1,3,1,'RA184508282CN ','au-buy\rCC00002'),(22183,683961008013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','catemurray','catie_murray@iinet.net.au','CATE MURRAY','PO BOX 206','MOUNT LAWLEY','WESTERN AUSTRALIA','AUSTRALIA','6929','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,11,1,NULL,'eastar4\rUM00042\recheck 清了  没下来单子'),(22184,847821868011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','heinhel','heinz.hauptmann@gmail.com','Heinz Hauptmann','Weinheberstraße 19','St.Pölten','','AUSTRIA','3100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 07:11:22',0,NULL,3,1,3,1,'RA184508101CN\r ','eastar4uk\rGLOT001*2'),(22185,847823373011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','cburnett42203','horsebranchfarm@gmail.com','cynthia burnett','423 us hwy 117','Burgaw','NC','UNITED STATES','28425','(910) 259-3818','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 07:23:01',0,NULL,3,1,1,1,'LK200631135CN\r ','eastar4'),(22186,783037501008,180820600484,'HP Wireless BCM94322 WLAN Half Mini PCI-E Card + Tyco 2.4/5.0GHz Antenna',1,'WLHP002+ANTY001',19.5,'au-buy','paradox_ct','paradox.ct@gmail.com','Tim Ellis','9 Bond St<br>Grey Lynn','Auckland','NORTH ISLAND','NEW ZEALAND','1021','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 07:43:03',0,NULL,3,1,11,1,NULL,'au-buy\rWLHP002+ANTY001'),(22187,847829884011,320687855790,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',21.9,'eastar4','counter_master','teoh89@gmail.com','Ahmad Shakeel bin Rosman','2/1231, Kampung Baru Sungai Karang,','Kuantan','Pahang','MALAYSIA','26100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 07:56:25',0,NULL,3,1,11,1,NULL,'eastar4\rOTHP004\r'),(22188,847835011011,320394929398,'Acer Aspire 5720 5720G  Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','maximlevitsky2012','maximlevitsky@gmail.com','Maxim Levitsky','Hathiya 7, Entrance A, Apartment 4<br>התחיה 7 כניסה א דירה 4','Bat-Yam','','ISRAEL','59531','+972548077082','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 08:15:49',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2022\racer 8pin1.00 15cm'),(22189,847843121011,320679565914,'New Jabra BT320s Stereo Bluetooth ClipOn Earbud Headset',1,'HSJA003',14.99,'eastar4uk','uteute01','wilfried.woida@t-online.de','Wilfried Woida','Korbmacherstr.19','Stuhr','','GERMANY','28816','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 08:50:48',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSJA003\r欧标'),(22190,784183409008,180755479601,'New Ultimate Ears MetroFi 170vi Earphones with Voice Capability',1,'HSUE001',23.99,'au-buy','tbswebtech','info@tbswebsites.net','Tayler Stevenson','2 Highgrove Circuit','Peregian Springs','Queensland','AUSTRALIA','4573','0437320577','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 09:24:11',0,NULL,3,1,11,1,' BJ01714474\r','au-buy\rHSUE001\r澳标'),(22191,8881329818271163,111,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',0,'eastar4','sapan1602','sapan24@gmail.com','Sapan Shah','Lvl 1,141 Robertson Street<br>Fortitude Valley','Brisbane','Queensland','AUSTRALIA','4006','',NULL,NULL,NULL,'2012-02-21 09:57:51',0,NULL,3,1,11,1,'BJ01714437\r ','只补发一个耳机  \rHSNO019 '),(22251,684296260013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','bimal.kaul','bimalkaul@gmail.com','Bimal Kaul','6 Pintaclo Way<br>Canning Vale','Perth','Western Australia','AUSTRALIA','6155','0478406094','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 04:01:50',0,NULL,3,1,3,1,'RA184509107CN\r ','eastar4\rGLOT001*2'),(22192,846363879011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','radionet2002','ebay@ebay.winkler-nbg.de','Roland Winkler','Nördlinger Str. 9/11','Nürnberg-Eibach','','GERMANY','90451','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 10:04:31',0,NULL,3,1,3,1,'RA184509226CN\r ','eastar4uk\rOTES001'),(22193,847873608011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',42.99,'eastar4','zay9999','iva5@list.ru','Volodymyr Iignatolia','Un. Lenincev 14 f.9','Dnipropetrovsk','','UKRAINE','49066','+30933945828','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-02-21 10:48:03',0,NULL,3,1,3,1,'RA184509230CN\r ','eastar4\rHSNO019+CCNO001'),(22194,629010808004,140626376683,'NEW Logitech Wireless Laser Mouse M505 plus receiver',1,'MOLO008',35.4,'cnfaner','johanseggers','j.seggers@ziggo.nl','johan seggers','boskamp 1','vries','','NETHERLANDS','9481jd','05925439333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 11:41:35',0,NULL,3,1,3,1,'RA184509685CN\r ','cnfaner\rMOLO008\r黑色的  box 没有黑色\r买家同意换银色的'),(22195,801079055001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','arminbock','schicks-her@gmx.net','Armin Bock','Talblick 7','Deuerling','','GERMANY','93180','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 11:42:12',0,NULL,3,1,11,1,'BJ01714430\r ','buysia\rBALO007'),(22196,792553087007,170730545430,'Genuine Logitech Harmony 515 Universal Remote Control',1,'RCLO004',39.99,'au-buy','clash973','clash@mail.ru','Andrey Chernyshev','Avtovskaya st. 7-28','Saint-Petersburg','','RUSSIAN FEDERATION','198096','+7 921 9442332','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 12:06:10',0,NULL,3,1,3,1,'RA184509314CN\r ','au-buy\rRCLO004'),(22197,938671941012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','falmatsea','falmatsea@gmail.com','Mr. Alen Mulic','San Salvador, Flat NRU. 7<br>Triq Depiro','SLIEMA','','MALTA','SLM 2033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 12:20:20',0,NULL,3,1,11,1,'BJ01714428\r ','eastar4uk\rOTGR001'),(22198,784233417008,180821302244,'100% New Genuine Atheros AR9287 BGN 300M Half PCI-E card',1,'WLAT007',11.99,'au-buy','ssf1987','ssf_10@hotmail.com','Soon Sien Fong','Daily Delights Restaurant<br>No.1 Jalan Hidayat 25/85, Taman Sri Muda','Shah Alam','Selangor','MALAYSIA','40400','6123688885','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 12:36:47',0,NULL,3,1,11,1,'BJ01714433\r ','au-buy\rWLAT007'),(22199,845601674002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','sickoftypen','crmat@embarqmail.com','Claude Mattox','1101 Court','Wathena','KS','UNITED STATES','66090-1241','(785) 989-4832','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 13:00:24',0,NULL,3,1,1,1,'LK200860773CN\r ','buysia'),(22200,684037672013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jimmythecannon','hendy_gross@web.de','Hendrik Groß','Burgstraße 6','Meckenheim','','GERMANY','53340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 13:36:43',0,NULL,3,1,11,1,'BJ01714438\r ','eastar4\rCACN004'),(22201,847931577011,320618271608,'New 3.0 Bluetooth Module BCM92070MD+cable  HP CQ42  G42',1,'BTHP3001',19.98,'eastar4','anime009','anime009@msn.com','Jaeho,Seo(010-8864-7293)','#701 Dongil Technotown<br>330-6 Dogsan-dong, Geumcheon-gu','Seoul','','KOREA,REPUBLIC OF','153-011','(010) 886-4729 ext.: 3','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 13:56:31',0,NULL,3,1,11,1,'BJ01714431\r ','eastar4\rBTHP3001\rHP 5pin1.0 20cm'),(22202,847934711011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',66.99,'eastar4uk','mystic_maus','snijderswouter@gmail.com','Wouter Snijders','Molenvliet 34','Klundert','','NETHERLANDS','4791 GA','0168-402491','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 14:06:40',0,NULL,3,1,3,1,'RA184507185CN\r ','eastar4uk\rHSPH008'),(22203,792594169007,170735464388,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',2,'UM00008',55.98,'au-buy','joywilliams1234','joywilliams1982@hotmail.com','Joy Francis','24 Burkett Terrace','Bertram','Western Australia','AUSTRALIA','6167','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 14:15:39',0,NULL,3,1,3,1,'RA184509288CN\r ','au-buy\rUM00008'),(22204,938713284012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',2,'WLAT009',19.96,'eastar4','roycunderwood','roy@royunderwood.com','Roy Underwood','23151 Crossley Ave','Hazel park','MI','UNITED STATES','48030-1668','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 14:19:48',0,NULL,3,1,1,1,'LK200921509CN\r ','eastar4'),(22205,623655998003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','jbarton_03','jbarton03@gmail.com','Jacob Barton','133 Sai Crescent','Ottawa','ON','CANADA','K1G 5P2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 14:49:56',0,NULL,5,0,18,1,NULL,'cnfaner\rSHLO009\r已退款'),(22206,938742391012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','gmol7983','gvmolina@gmail.com','Gilbert Molina','40 Hunt Ave Apt 20A','Stratford','NJ','UNITED STATES','08084','(201) 259-4638','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 15:30:42',0,NULL,3,1,1,1,'LK200934286CN\r ','eastar4'),(22207,844677560011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','theo70a','ted.smith@theoden.com','Ted Smith','4640 S Wright Way','Morrison','CO','UNITED STATES','80465','(720) 934-5230','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 15:30:48',0,NULL,3,1,1,1,'LK200942177CN\r ','eastar4uk'),(22208,684067843013,230724607810,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'eastar4','allyonca','sebastgirl@gmail.com','Alyona Volkova','quarter 3a<br>house №5, apartment №21','Lytkarino','Moscow  region','RUSSIAN FEDERATION','140083','+79857818812','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 15:35:20',0,NULL,3,1,11,1,'BJ01714429\r ','\reastar4\rUM00053'),(22209,847968674011,320800724933,'4 pairs 3D Active shutter Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 15:39:32',0,NULL,3,1,4,1,'YW867610893CN ','eastar4uk\r一共买了8副'),(22210,847978782011,320800724933,'4 pairs 3D Active shutter Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*4',103.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 16:06:45',0,NULL,3,1,17,0,NULL,'eastar4uk'),(22211,938763204012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','flykite','ed.castrege@villanova.edu','EDWARD J. CASTREGE','753 Thorndale Rd','ALDAN','PA','UNITED STATES','19018-4327','(610) 622-0705','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 16:19:29',0,NULL,3,1,1,1,'LK200931276CN\r ','eastar4'),(22212,629081611004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','rinatkasimov','rinat.kasimov@gmail.com','Rinat Kasimov','Govorova d 46 kv 420','Tomsk','','RUSSIAN FEDERATION','634057','+79234083709','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 16:41:16',0,NULL,3,1,11,1,'BJ01714471\r ','cnfaner\rBALO007'),(22213,848003457011,320730085266,'Logitech RF Wireless Extender+emitter 4 Harmony 890',1,'RCLO007+POLO001+RCLO008*4',20.9,'eastar4uk','chazandmave','andy.voules@icm-continuity.co.uk','Andrew Voules','166 Broad Hinton<br>Twyford','Reading','Berkshire','UNITED KINGDOM','RG10 0XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 17:00:46',0,NULL,3,1,3,1,'RA184509328CN\r ','eastar4uk\rRCLO007+POLO001+RCLO008*4'),(22214,848001897011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',73.98,'eastar4','thunderc','bakira_st@yahoo.com','Stergios Tourtouropoulos','Kountouriotou 94<br>(Next to Praktiker), Pilea','Thessaloniki','Macedonia','GREECE','55535','+306945580828','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 17:03:13',0,NULL,3,1,12,0,'3125433850\r ','eastar4\rWWSI004\r客户打了22美金\r泡重318\r'),(22215,684095028013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','adamzan498999','adamzan@op.pl','Adam Zaniewicz','56 Cassiobury Ave','Feltham','Middlesex','UNITED KINGDOM','TW149JF','07828332436','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 17:03:22',0,NULL,3,1,11,1,'BJ01714440\r ','eastar4\rHSNO019\r英标'),(22216,845699076002,120855594265,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver2',1,'SHLO010',12.99,'buysia','gleger','gleger07@hotmail.com','Georges-Etienne Leger','263 Commercial AVE','Timmins','ON','CANADA','P4N 2X5','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-21 17:23:31',0,NULL,3,1,11,1,'BJ01714470\r ','buysia\rSHLO010\r'),(22217,938790392012,220922496581,'New In Box ZALMAN FG1000 FPS GUN Ergonomic Style Gaming USB Mouse',2,'MOZA001',79.98,'eastar4','kubicide','rkubis@comcast.net','Robert Kubis','14105 SW Paddock Ct','Beaverton','OR','UNITED STATES','97008-6769','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 17:15:03',0,NULL,3,1,1,1,'LK200940193CN ','eastar4'),(22218,938807782012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','sdloy07','fiddlefaddle@wedeliverwellness.com','Steven Loy','15507 Dover RD','Upperco','MD','UNITED STATES','21155-9539','(443) 955-0112','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 17:51:21',0,NULL,3,1,1,1,'LK200934961CN\r ','eastar4'),(22219,938824186012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lesia1265','lmoyers@woh.rr.com','Lesia Moyers','2661 Medway New Carlisle Rd','Medway','OH','UNITED STATES','45341','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 18:20:09',0,NULL,3,1,1,1,'LK200925678CN\r ','eastar4'),(22220,684129243013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','radgiv','radgiv87@gmail.com','Radgiv Mirzaliev','Nagibina str.<br>37, room 80.','Rostov-on-Don','','RUSSIAN FEDERATION','344068','0078632960655','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 18:38:00',0,NULL,3,1,11,1,'BJ01714434\r ','eastar4\rWLAP002'),(22221,846432140011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','arthuss','arthuss@yahoo.fr','FRANCOIS jean-marc','3, avenue des sciences','CHELLES','Île-de-France','FRANCE','77500','01.01.01.01.01','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 19:08:27',0,NULL,3,1,11,1,'\\ ','eastar4\rBTAS3002\r3.0 ASUS 6PIN 12CM '),(22222,801244489001,110808693326,'New Jabra BT320s Stereo Bluetooth Clip-On Earbud Headset  BT 320s',1,'HSJA003',23.69,'buysia','galay2007','egalay@gmail.com','eran galay','hilel zechria 20','petach tikva','','ISRAEL','49573','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 19:09:23',0,NULL,3,1,11,1,NULL,'buysia\rHSJA003\r欧标'),(22223,792724926007,170785421224,'New Apple Macbook Air Software Reinstall Driver 8GB USB pen key',1,'UDAP002',34.99,'au-buy','aletsyanapaula','aletsy138@sbcglobal.net','Sergio Lopez','3212 Isla Banderas Way','El paso','TX','UNITED STATES','79925','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 19:22:01',0,NULL,3,1,1,1,'LK200879372CN\r ','au-buy'),(22224,848079038011,320730549120,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',26.99,'eastar4uk','upton4red','chrisbadhams@hotmail.co.uk','Chris Badhams','10 Purcell Avenue','Nuneaton','Warwickshire','UNITED KINGDOM','CV11 4SN','07850572291','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 19:26:36',0,NULL,3,1,3,1,'RA184509036CN\r ','eastar4uk\rGLOT001'),(22225,621672425004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','goorack','gorecki@me.com','Bartosz Gorecki','Ulanska 16/203','Katowice','śląskie','POLAND','40877','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 19:57:29',0,NULL,3,1,3,1,'RA184509274CN\r ','cnfaner\rCACN004'),(22226,629152724004,140675757170,'4 pairs of New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001*4',174.99,'cnfaner','zxcvgavrilov','alzxcv@rambler.ru','Gavrilov Aleksangr','Gorkogo 42','Cherepovets','ru','RUSSIAN FEDERATION','162614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 19:59:28',0,NULL,3,1,3,1,'RA184509212CN\r ','cnfaner\rGLOT001*4'),(22227,684186013013,230409301632,'100% NEW 3FT SMART SERIAL CABLE WIC-2T back to back',2,'CASS001',19.98,'eastar4','graymalkin57','bgerenday@inbox.com','BENEDICT J GERENDAY','2112 12TH AVE','PARKERSBURG','WV','UNITED STATES','26101-6151','(740) 236-8101','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 20:55:56',0,NULL,3,1,1,1,'LK200969634CN\r ','eastar4'),(22228,938919921012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','idansaidi1985','idansaidi@gmail.com','Idan Saidi','Yamit 41<br>Neve Dkalim','Rishon Le Zion','Gush Dan','ISRAEL','75675','+972526890895','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:59:00',0,NULL,3,1,11,1,'BJ01714436\r ','eastar4\rMOAP001'),(22229,938938564012,220759518194,'New Genuine Logitech Harmony 628 Remote Control',1,'RCLO006',28.99,'eastar4uk','vakninyoram','meitalyoram@gmail.com','Yoram Vaknin','46 Harduf st<br>Apt No. 14','Tirat Carmel','Israel','ISRAEL','39041','+972 54 6400802','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 21:27:24',0,NULL,3,1,3,1,'RA184509305CN\r ','eastar4uk\rRCLO006'),(22230,848159354011,320730088581,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',33.9,'eastar4uk','mromeo1970','mromeo1964@yahoo.com','mareth midouin','65 springbrook rd','Nanuet','NY','UNITED STATES','10954-4423','(845) 290-6045','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 21:54:11',0,NULL,3,1,1,1,'LK200965779CN ','eastar4uk'),(22231,848169136011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',15.96,'eastar4','itsacowboything','kriskauf123@yahoo.com','Krissy Kaufmann','18 E Church Rd','Plymouth Meeting','PA','UNITED STATES','19462-7138','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 22:18:07',0,NULL,3,1,1,1,'LK200939283CN\r ','eastar4'),(22232,938970868012,220816379674,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT001*3',78.99,'eastar4uk','alexferg75','jendud_85@hotmail.co.uk','Jen Duddle','12 devon road<br>hensingham','whitehaven','Cumbria','UNITED KINGDOM','ca28 8pj','01946599100','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4uk\r如果客户的钱清了，给他退款  撤单'),(22233,938973194012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','philipgreen99','piratez_99@hotmail.com','Matthew Green','7 Fairmont Terrace<br>North Road','Sherborne','Dorset','UNITED KINGDOM','DT9 3JS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 22:30:43',0,NULL,3,1,3,1,'RA184509331CN\r ','eastar4uk\rMOMI002'),(22234,629208902004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','n2ref','bob_nav@msn.com','BOBBY E NAVARRO','747 Riverside Ave','Sugarloaf','CA','UNITED STATES','92386','(909) 890-8831','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-21 22:39:06',0,NULL,3,1,1,1,'LK200861646CN\r ','cnfaner'),(22235,938976832012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',13.98,'eastar4uk','christian-martin2012','christian.calderas77@gmail.com','Christian Calderon','310 queens road<br>basement flat','London','London','UNITED KINGDOM','se14 5jn','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4uk'),(22236,801360135001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'buysia','crickmore_kent','crickmores@gmail.com','Sebastian Crickmore','15 Tilley Court','Caboolture','Queensland','AUSTRALIA','4510','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-21 23:17:13',0,NULL,3,1,11,1,'BJ01714468\r ','buysia\rRCLO007'),(22237,938993157012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','ZAYRA V SHMUELS','7521 W TREASURE DR','NORTH BAY VILLAGE','FL','UNITED STATES','33141-4117','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 23:20:03',0,NULL,3,1,1,1,'LK200958367CN\r ','eastar4'),(22238,848193148011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','mem777709','michemajcen@gmail.com','Michelle Majcen','15/33 Kensington Road','South Yarra','Victoria','AUSTRALIA','3141','030411737381','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:37:18',0,NULL,3,1,11,1,'BJ01714473\r ','eastar4\rUDAP001'),(22239,792851910007,170758626468,'New Altec Lansing Backbeat Plus UHP206  Earphones for iPod  iPhone music player',1,'HSAL002',18.99,'au-buy','1050j','spiritrider11@earthlink.net','James Mannel','6641 S 30th St','Lincoln','NE','UNITED STATES','68516-4665','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 23:50:38',0,NULL,3,1,1,1,'LK200863151CN\r ','au-buy'),(22240,939004769012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',83.97,'eastar4','youtube12345','1a1z2s2x@gmail.com','ALAIN LAVARNWAY','1303.SOUTH FOX LN','Oregon City','OR','UNITED STATES','97045','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 23:54:05',0,NULL,3,1,1,1,'LK200912590CN\r ','eastar4\r一共买了三个'),(22241,848208896011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.99,'eastar4','dhimitris2009','jimntan@gmail.com','Dhimitris Danis','Grammu 60','Igumenitsa','Thesprotia','GREECE','46100','2665028535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:55:49',0,NULL,3,1,11,1,'BJd714391\r ','eastar4\rHSNO004\r欧标'),(22242,792858105007,170747501083,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.99,'au-buy','poppyxr6','mrs_asprov@bigpond.com.au','Andriana Asprov','66<br>Turrella Street','Turrella','New South Wales','AUSTRALIA','2205','0295974045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 00:08:52',0,NULL,3,1,11,1,'BJ01714467\r ','au-buy\rMOHP002'),(22243,629245744004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','amlgomes','arlindo.gomes@gmail.com','ARLINDO MANUEL LOPES GOMES','RUA ALEXANDRE CASTRO SOARES, N.125','ESMORIZ (OVR)','OVAR','PORTUGAL','3885-434','(351) 919600786','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 01:19:26',0,NULL,3,1,3,1,'RA184509291CN\r ','cnfaner\rHSNO005\r欧标'),(22244,623845972003,130626363912,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.95,'cnfaner','mpitz0','mpitz0@comcast.net','maria pitzmeyer','5135 Suffield Ct','skokie','IL','UNITED STATES','60077-1822','(847) 966-6104','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-22 01:27:36',0,NULL,3,1,1,1,'LK200821925CN\r ','cnfaner'),(22245,848249997011,320635320208,'New Intel 5300 AGN Wireless Mini PCI-E Card+3 antenna',1,'WLIN010+ANTY002',21.49,'eastar4','bloodycliff','cliffsmatrix@aol.com','clifton andrews','905 julian st','marshfield','MO','UNITED STATES','65706-1170','(417) 844-5223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 02:09:33',0,NULL,3,1,1,1,'LK200961658CN\r ','eastar4'),(22246,848250712011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','blackflashboris','blackflash15@gmail.com','Boris Shumov','Astrakhanskaya<br>9A - 60','Krasnoyarsk','Siberia','RUSSIAN FEDERATION','660037','+79082077677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 02:12:01',0,NULL,3,1,11,1,'BJ01714463\r ','eastar4\rWLAT001+ANTY002'),(22247,801416304001,110819588479,'Logitech RF Wireless Extender for Harmony 890 Pro 1000 & 1100 remote',1,'RCLO007',26.99,'buysia','kibrus','kkaminski@shaw.ca','Ken Kaminski','3251 Wavecrest Drive','Nanaimo','BC','CANADA','V9T 5W9','(250) 756-2184','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-22 02:32:19',0,NULL,3,1,11,1,'BJ01714435\r ','buysia\rRCLO007'),(22248,848263650011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',2,'HSJA010',53,'eastar4','debbobraines2005','debbob2009@live.com','DEBRA NOTTINGHAM','PO Box 297<br>13433 N. 470 RD.','TAHLEQUAH','OK','UNITED STATES','74465-0297','(918) 431-0011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 02:59:09',0,NULL,3,1,1,1,'LK201192320CN\r ','eastar4'),(22249,939069639012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','mmaubin705','mmaubin@vianet.ca','Marc Aubin','2854 Fleetwood Drive','Azilda','ON','CANADA','P0M1B0','(705) 561-8994','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 03:03:56',0,NULL,3,1,3,1,'RA184509098CN\r ','eastar4\rGLOT001*2'),(22250,8881329881075308,111,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',0,'au-buy','thaisy48','handy48@hotmail.com','Duc Nghia Duong','16 The Avenue<br>Caroline Springs','Melbourne','Victoria','AUSTRALIA','3023','0403139709',NULL,NULL,NULL,'2012-02-22 03:24:35',0,NULL,3,1,3,1,'RA184509115CN\r ','OTGR001\r补发的 '),(22252,848285313011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','birdmodify','birdy_t02@hotmail.com','Kittipong Preboonpoon','99/185 Moo 4, Soi 25, CasaVille Ratchaphuek-Changwatthana, <br>Ratchaphuek Road, Tumbol Klongkoi,','Amphur Pakkred, Nonthaburi','NO','THAILAND','11120','66890039181','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 04:18:51',0,NULL,3,1,11,1,'BJ01714464\r ','eastar4\rHSJA002'),(22253,848294534011,320618274660,'New 3.0 Bluetooth BCM2070 Module+cable for HP 5310M',1,'BTHP3004',19.98,'eastar4','isaiah438819','isaiah4343@hotmail.com','Jing Shi','2814 Westchester Ct','Saint Charles','MO','UNITED STATES','63303-3864','(573) 239-4246','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 05:03:23',0,NULL,3,1,1,1,'LK201201741CN\r ','eastar4\rHP 8pin1.0 8cm'),(22254,848305060011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.39,'eastar4','j37537','ab7f@comcast.net','John N. Stein','4415 Boise Ct','Vancouver','WA','UNITED STATES','98661-6313','(360) 258-1067','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 05:55:44',0,NULL,3,1,1,1,'LK201202044CN\r ','eastar4\racer 4pin1.25 6cm'),(22255,848302350011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','maxstrob','hawkmech@laplaza.org','Max Stroback','210 Bendix St<br>Unit 1','Taos','NM','UNITED STATES','87571-5266','(575) 758-4433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 05:41:49',0,NULL,3,1,1,1,'LK201220003CN\r ','eastar4'),(22309,848802111011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','jamesjabajames','jamesjaba1@hotmail.com','james jaba','Ilotulitustie 11-15 b 41','Helsinki','Helsinki','FINLAND','00930','+358505710184','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 04:47:54',0,NULL,3,1,11,1,'BJ01714416\r ','eastar4uk\rTRSN001'),(22256,8881329893824298,111,'New GENUINE NOKIA BH-900 ',1,'HSNO019',0,'eastar4uk','parkker11','tapiohimberg@gmail.com','tapio himberg','alakorkalontie 395','Rovaniemi','','FINLAND','96700','+358-400-694171',NULL,NULL,NULL,'2012-02-22 06:57:04',0,NULL,3,1,11,1,'BJ01714439\r ','只补发一个耳机\rHSNO019 '),(22257,684324095013,230393137066,'2.1 Acer Aspire 4520 4520G Bluetooth Module EDR+cable',1,'BTAC2115',12.39,'eastar4','fulcrum1972','fabian_cotter@hotmail.com','Fabian Cotter','7/105-113<br>Stapleton Street','Pendle Hill, Sydney','New South Wales','AUSTRALIA','2145','0451194600','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 07:09:16',0,NULL,3,1,11,1,'BJ01714432\r ','eastar4\rBTAC2115\racer 5pin1.25 20cm'),(22258,848324480011,320612442028,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'HSNO005+CCNO001',15.89,'eastar4','mshokralla2012','maikfawzy@yahoo.com','maged shokralla','1059 glastonbury rd','Nashville','TN','UNITED STATES','37217-5041','(615) 243-9276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 07:39:32',0,NULL,3,1,1,1,'LK201226213CN\r ','eastar4'),(22259,629304290004,140675757780,'New 3D Active Shutter TV Glasses Compatible for LG AG-S110 AGS110',1,'GLOT001',43.89,'cnfaner','monika2460b','monika2460@aim.com','THADDEUS STEELE','4150 READING RD','CINCINNATI','OH','UNITED STATES','45229','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-22 07:49:59',0,NULL,3,1,1,1,'LK201295960CN ','cnfaner'),(22260,939139921012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','9inchjock','timcfall@gmail.com','Ashdon McFall','41 monksdale road<br>Oldfield park','BATH','BATH','UNITED KINGDOM','BA2 2JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 07:59:30',0,NULL,3,1,3,1,'RA184524501CN\r ','eastar4uk\rWLAT009'),(22261,848218913011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','goaterer','theoffice@markashton.co.uk','Mark S Ashton','3 morton crescent<br>ferrybridge road','castleford','West Yorkshire','UNITED KINGDOM','WF10 4UZ','01977552419','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 08:33:16',0,NULL,3,1,3,1,'RA184509186CN\r ','eastar4uk\rUDAP001'),(22262,848333951011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','route66weasel','thebirches@hotmail.com','Stephen Brown','The Birches<br>Fox Street, Ardleigh','Colchester','Essex','UNITED KINGDOM','CO7 7PP','07976984925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 08:19:27',0,NULL,3,1,3,1,'RA184509190CN\r ','eastar4uk\rRELO003'),(22302,8881329961528388,111,'Free shipping & Tracking # - New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 - ',1,'GPS0010',26.99,'aliexpress','1006911644','miroslav.hanes@yahoo.ie','Miroslav Hanes','97 old kilmainham village ','Kilmainham','Dublin 8','IRELAND','D8','+00353 85124 6513',NULL,NULL,NULL,'2012-02-23 01:45:28',0,NULL,3,1,3,1,'RA184509994CN\r ','GPS0010 '),(22263,8881329902173723,111,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Tyco 2.4/5.0GHz Antenna *3 - ',1,'WLAT001+ ANTY002',15.99,'aliexpress','1006906224','emi6600@yahoo.com','Emanuel Nastase','Backhaustrasse 28 ','Philippsburg','Karlsruhe','GERMANY','76661','+0049 01577 5143713',NULL,NULL,NULL,'2012-02-22 09:16:13',0,NULL,3,1,3,1,'RA184509022CN ','WLAT001+ ANTY002 '),(22264,8881329902319236,111,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N - ',1,'WLIN013',17.99,'aliexpress','1006916471','jtakimoto@inter7.jp','Junya TAKIMOTO','	2-8-8, Miyakono, Oami-Shirasato-machi ','Sanbu-gun','Chiba-ken','JAPAN','	299-3236','+81 475 2302',NULL,NULL,NULL,'2012-02-22 09:18:39',0,NULL,3,1,3,1,'RA184509019CN ','WLIN013 '),(22265,784678948008,180757093963,'New Logitech Harmony Remote USB Cable for 880 890',1,'CALO001',3.87,'au-buy','mancjonny','mancjonny@hotmail.com','JONATHAN CRAWFORD','33 BILLY LANE<br>CLIFTON','MANCHESTER','Greater Manchester','UNITED KINGDOM','M27 8FS','07725626110','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 11:20:22',0,NULL,3,1,11,1,'BJ01714424\r ','au-buy\rCALO001'),(22266,939122764012,220815928524,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',12.8,'eastar4uk','ilgiz_d','ilgiz.duseev@gmail.com','Ilgiz Duseev','Lebedeva st. 87, flat 92','Tomsk','Tomsk region','RUSSIAN FEDERATION','634021','+79528910273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 11:37:21',0,NULL,3,1,11,1,'BJ01714415\r ','eastar4uk\rANCN003'),(22267,784702001008,180758271107,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',5.9,'au-buy','jayman20v','wazizbra@hotmail.com','John T','64 mcarthur st guildford','sydney','New South Wales','AUSTRALIA','2161','0405385113','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 12:41:24',0,NULL,3,1,11,1,'BJ01714422\r ','au-buy\rSCLO005'),(22268,848418939011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','aaurre','aitorpeli@hotmail.es','aitor aurre','barrio radillo 147','viérnoles','Cantabria','SPAIN','39315','625397336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 13:20:46',0,NULL,3,1,3,1,'RA184509169CN\r ','eastar4uk\rGLOT001'),(22269,848428871011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','gorgotzolas','golitsos@gmail.com','George Golias','IOLKOY 8 & FILIKIS ETAIRIAS','NEA IONIA','ATTICA','GREECE','14234','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 13:50:19',0,NULL,3,1,3,1,'RA184509929CN\r ','eastar4uk\rGLOT001*2'),(22270,684406976013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',198.8,'eastar4','michel_egorov','maket888@gmail.com','DMITRIY POPOV','ul. Spartakovskaya, dom 19 korp. 2, kv. 25<br>ул.Спартаковская, дом 19 корп. 2, кв. 25','Moscow','RUSSIA','RUSSIAN FEDERATION','105066','+7 (905) 7183878','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 14:11:21',0,NULL,3,1,3,1,'RA184510003CN\r ','eastar4\rWLAP008'),(22271,784744110008,180772181803,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'au-buy','alisutsweet2012','alisutsweet@yahoo.co.uk','alison sutcliffe','77 burnleys mill road','gomersal','West Yorkshire','UNITED KINGDOM','bd19 4ph','01274879349','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 14:51:48',0,NULL,3,1,11,1,'BJ01714423\r ','au-buy\rHBPH003'),(22272,629398035004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','gcsbike','gcopeseeley@yahoo.com','Garrett','4283 Keith Ln','Chico','CA','UNITED STATES','95973-7623','(530) 680-1033','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-22 15:03:22',0,NULL,3,1,1,1,'LK201565415CN\r ','cnfaner'),(22273,684423109013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','swiss-lp-records','planetbut@gmail.com','Jean-Marc Buttex','Ch fauvette 4 bis','Lausanne','','SWITZERLAND','1012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 15:11:21',0,NULL,3,1,11,1,'BJ01714419\r ','eastar4\rWLAP002'),(22274,848464255011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','impexnorway','j.skaale@online.no','Jon Skaale','Wilses gate 4 A','OSLO','','NORWAY','N-0178','+47 90910669','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 15:22:58',0,NULL,3,1,11,1,'BJ01714425\r ','eastar4uk\rWLAT008'),(22275,938820037012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','sneakyone2oo4','sneak2oo4@gmail.com','Hussein Hadaidih','Nyborgvej 307 1th d3','Odense SØ','','DENMARK','5220','35101870','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 15:26:34',0,NULL,3,1,3,1,'RA184509985CN\r ','eastar4uk\rGLOT005'),(22276,623999582003,130495603351,'New Logitech MX1000  Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','petesworld2009','peter_stoimenov@hotmail.com','Peter Stoimenov','146 St. Urbain Dr.','Vaughan','ON','CANADA','L4H 2W7','(905) 267-0161','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 15:29:27',0,NULL,3,1,3,1,'RA184509963CN\r ','cnfaner\rBALO007'),(22277,939304504012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','fotomoto11','7775676@gmail.com','Mikhail Larin','9-Parkovaya dom 30 k 22','Moscow','','RUSSIAN FEDERATION','105077','(985)7775676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 16:06:48',0,NULL,3,1,3,1,'RA184509932CN\r ','eastar4\rGLOT001'),(22278,684445053013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',85,'eastar4','sun_swim','rchodacki@gmail.com','Richard Chodacki','12814 S 38th Pl','Phoenix','AZ','UNITED STATES','85044-3867','(602) 412-3696','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 16:25:07',0,NULL,3,1,1,1,'LK201588800CN\r ','eastar4'),(22279,848492450011,320828187221,'New Antiglare Flat Rear View Mirror 300MM W/Compass & Thermometer just Click On',1,'RVM0002',16.99,'eastar4','ezhuk2009','ezhuk@inbox.lv','jevgenijs zuks','Aronsona 18/9 street','Kraslava','','LATVIA','LV5601','003716239680','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 16:29:29',0,NULL,3,1,11,1,'BJ01714401\r ','eastar4\rRVM0002'),(22280,793118784007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',52.99,'au-buy','azertydart','jeromem75@gmail.com','jerome Maily','Micro Focus House<br>2 East Bridge Street','Belfast','Antrim','UNITED KINGDOM','BT1 3NQ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 16:29:47',0,NULL,3,1,3,1,'RA184509977CN\r ','au-buy\rRCLO007+POLO001+RCLO008*4'),(22281,624025467003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','fernandogno2006','fernando@berneck.com.br','Fernando Gnoatto','Rua Pedro Viriato Parigot de Souza , 1861  apt1801<br>Mossunguê','Curitiba','Paraná','BRAZIL','81200-100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 16:58:45',0,NULL,3,1,3,1,'RA184509243CN\r ','cnfaner\rMOOE002\rOEM'),(22282,939336382012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4uk','madmanwithafryingpan','uk.dropship@yahoo.co.uk','Vince Pike (iLuno)','Unit 71A, BSS House<br>Cheney Manor Industrial Est','Swindon','Wiltshire','UNITED KINGDOM','SN2 2PJ','07766708552','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 17:10:13',0,NULL,3,1,3,1,'RA184509950CN\r ','eastar4uk\rOTCN003'),(22283,629450124004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','sierak13','sierakowski@gmail.com','David Sierakowski','6900 Lake Woodlands Dr<br>Apt 639','The Woodlands','TX','UNITED STATES','77382-2844','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-22 17:52:04',0,NULL,3,1,1,1,'LK201552368CN\r ','cnfaner'),(22284,846216646002,120853616250,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones',1,'HSAL002',18.99,'buysia','eldar2710','rachel5363@walla.com','rachel ketler','shimon avidan 14','Rishon le zion','israel','ISRAEL','75339','039580471','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-22 18:28:38',0,NULL,3,1,11,1,'BJ01714426\r ','buysia\rHSAL002\r欧标'),(22285,939423980012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','glebm2010','dulp@mail.ru','Galab Mayurow','Halale Egoz 21/11','Lod','','ISRAEL','71455','(972)52859-1076','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 19:52:57',0,NULL,3,1,11,1,'BJ01714418\r ','eastar4\rWLAT009'),(22286,939420684012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',19.98,'eastar4','inferiorbunny21','ecayambe@yahoo.com','Eddie Y Cayambe','VMAQ-3<br>Psc Box 8060','Cherry Point','NC','UNITED STATES','28533','(718) 902-1539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 19:54:01',0,NULL,3,1,1,1,'LK201597381CN\r ','eastar4\r一共买了两个'),(22287,793252365007,170784482004,'100% New Atheros AR5B195 Wireless + Bluetooth Half Mini PCI-E Card',1,'WLIN016',14.99,'au-buy','wydrap666','wydrap@poczta.onet.pl','PAWEL WYDRA','3403 W Colette Ct','mequon','WI','UNITED STATES','53092-2308','(414) 241-6256','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 20:23:01',0,NULL,3,1,1,1,'LK201565755CN\r ','au-buy'),(22288,629518478004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','cruzerov','mahdal5@seznam.cz','René Mahdal','Podlesí 4937','Zlín','Czech republic','CZECH REPUBLIC','76005','+420604920010','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 20:43:08',0,NULL,3,1,17,0,NULL,'cnfaner\rCACN004'),(22289,939473128012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','nocturnus.couture','nocturnus_couture@live.ca','kelly  Drummond-Hay','12826 73 ave','Surrey','BC','CANADA','v3w 9c1','(604) 618-4261','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 20:49:58',0,NULL,3,1,11,1,'BJ01714405\r ','eastar4\rUM00006'),(22290,684548888013,230397406106,'10 pcs CentreCom AT-210T Ethernet Transceiver AUI/RJ45',1,'TRTT002*10',85,'eastar4','socks_of_the_future','mr.mannypants@gmail.com','Manny Shah','105 W 1st St<br>Rcn','Boston','MA','UNITED STATES','02127-1109','(617) 670-2904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 20:51:11',0,NULL,3,1,1,1,'LK201620227CN\r ','eastar4'),(22291,629523701004,140583482966,'New GENUINE NOKIA BH-700 BLUETOOTH HEADSET track#',1,'HSNO028',18.25,'cnfaner','dm-mania','mania5.74@mail.ru','Eduard Yuraga','30 let Pobedy 94/173','Tyumen','RU','RUSSIAN FEDERATION','625051','(905) 822 - 3463','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 21:01:27',0,NULL,3,1,3,1,'RA184509257CN\r ','cnfaner\rHSNO028\r欧标'),(22292,629519158004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.8,'cnfaner','cruzerov','mahdal5@seznam.cz','René Mahdal','Podlesí 4937','Zlín','Czech republic','CZECH REPUBLIC','76005','+420604920010','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 21:02:30',0,NULL,3,1,3,1,'RA184509861CN\r ','cnfaner\rCACN004\r一共4个'),(22293,939502856012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Kathleen M. Young','9839 W Coon Lake Rd','Webberville','MI','UNITED STATES','48892-9001','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 21:40:35',0,NULL,3,1,1,1,'LK201584808CN\r ','eastar4'),(22294,939504289012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Carla Fortunato','5823 NEWTON DR<br># Sklz Ste 130','CARLSBAD','CA','UNITED STATES','92008-7361','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 21:43:25',0,NULL,3,1,1,1,'LK201711055CN\r ','eastar4'),(22295,939497416012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','whidbey_bill','wm_allan@comcast.net','William H Allan','5265 Bounty Loop','Freeland','WA','UNITED STATES','98249-9628','(360) 544-8485','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 21:52:15',0,NULL,3,1,1,1,'LK201623458CN\r ','eastar4'),(22296,939516623012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','socago2012','socago@earthlink.net','sanford Landry','3581 Andreas Hills Dr','Palm Springs','CA','UNITED STATES','92264-9605','(760) 323-4857','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 22:15:37',0,NULL,3,1,1,1,'LK201606812CN\r ','eastar4'),(22297,848684242011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','bo_fr','bostjan.fras@t-2.net','Bostjan Fras','Robiceva 64','Limbus','','SLOVENIA','2341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 22:19:45',0,NULL,3,1,11,1,'BJ01714420\r ','eastar4\rTRSN001'),(22298,848698081011,320441946859,'2.1 HP TX2500 TX2500z TX2z Bluetooth Module EDR+cable',1,'BTHP2112',12.39,'eastar4','lgorek','ebay@bufu.pl','Jakub Karwala','Kopernika 84','Dabrowa Tarnowska','Malopolska','POLAND','33-200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 22:51:11',0,NULL,3,1,11,1,'BJ01714417\r ','eastar4\rBTHP2112\rHP 8pin 0.8 3cm '),(22299,939554595012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',36,'eastar4uk','shabidu3021','donaldst@nb.sympatico.ca','Donald Steeves','230 Mapleton Road Apt 3021','Moncton','NB','CANADA','E1C 0H6','(506) 389-1121','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 23:32:16',0,NULL,3,1,3,1,'RA184509946CN\r ','eastar4uk\rWWSI006+ANCN001'),(22300,846384555002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','jdgrabber','jdsteingraber@yahoo.com','Joshua Steingraber','28 Verdun Dr','Reading','PA','UNITED STATES','19605-7009','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-23 00:23:49',0,NULL,3,1,1,1,'LK201602991CN\r ','buysia'),(22301,848735659011,320441946366,'2.1 HP DV6000 DV6000t DV6000Z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','rissattijean','rissatti.jean@gmail.com','Jean Rissatti','1776 Park Ave Ste 4 # 323','Park City','UT','UNITED STATES','84060-0770','(435) 901-4365','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 00:55:02',0,NULL,3,1,1,1,'LK201604581CN\r ','eastar4\rHP 8pin 1.25 18cm \r送螺丝\r'),(22303,939606874012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','jetoews54','jean.toews@shaw.ca','jean  toews','54 Edgebank Circle NW','Calgary','AB','CANADA','T3A 4S4','(403) 208-3443','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 02:12:25',0,NULL,3,1,3,1,'RA184509915CN\r ','eastar4\rHBPH007'),(22304,782071530008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','leighhocking','leighhocking@hotmail.com','Leigh Hocking','Level 5, Central Plaza 2<br>66 Eagle Street','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 02:15:48',0,NULL,3,1,11,1,'BJ01714421\r ','au-buy\rBALO001'),(22305,8881329963901029,111,'LCD Screen for logitech harmony 885/895',10,'SCLO001',90,'eastar4uk','sethos.x','exactservice@t-online.de','Matthias Quester','Buckower Damm 255a','Berlin','','GERMANY','12349','',NULL,NULL,NULL,'2012-02-23 02:25:01',0,NULL,3,1,3,1,'RA184509172CN\r ','SCLO001\r直接打款 '),(22306,624199439003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','cheflawrence620','lawrencealcantara@yahoo.com','lawrence alcantara','57 pearl st Pasig Greenland Village Rosario','Pasig City','NCR','PHILIPPINES','1609','6326282949','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 02:30:49',0,NULL,3,1,3,1,'RA184507208CN\r ','cnfaner\rSHLO009'),(22307,683856885013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','phonzonappy','alphonsodaveiga@gmail.com','Alphonso Woodbury','6520 Fir Tree Cir','englewood','OH','UNITED STATES','45322-3607','(937) 836-9149','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 03:08:13',0,NULL,3,1,1,1,'LK201872115CN\r ','eastar4'),(22308,939629647012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','simulation_one','simonesetti7@gmail.com','Simone de Almeida','Rua Guido Mencacci, 101<br>Jardim Astro','Sorocaba','São Paulo','BRAZIL','18017-152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 03:24:08',0,NULL,3,1,11,1,'BJ01714394\r ','eastar4\rUM00010'),(22310,624228687003,130626402767,'New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',2,'GLOT001',87.78,'cnfaner','seymour15','sandio55@rochester.rr.com','Sandra Osterwise','3 Alpine Knl','Fairport','NY','UNITED STATES','14450-1721','(585) 425-7443','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184506922CN\r ','cnfaner\rGLOT001\r已付款'),(22311,939662371012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Emma Bailey','2180 BRYANT ST<br>STE 201','SAN FRANCISCO','CA','UNITED STATES','94110-2166','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 05:33:43',0,NULL,3,1,1,1,'LK201875607CN\r ','eastar4'),(22312,939663808012,220816317096,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',28.99,'eastar4','grannygirl2009','pgcain@cox.net','Patricia G. Cain','312 Turkey Crk<br>10763 NW 62nd Terrace','Alachua','FL','UNITED STATES','32615','(386) 418-0615','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 05:43:17',0,NULL,3,1,1,1,'LK201881602CN\r ','eastar4\r红色的'),(22313,801941920001,110822404524,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET BH 202',1,'HSNO006',14.98,'buysia','noppakun_dkb','a_noppakun@hotmail.com','Noppakun plaole','54/1 m.8 donkraboung<br>banpong','default','RI','THAILAND','70110','66874447748','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-23 06:22:18',0,NULL,3,1,11,1,'BJ01714402\r ','buysia\rHSNO006\r美标'),(22314,8881329982543314,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW ',1,'WLIN014',18.99,'eastar4','mdk0047dongkwon','mdk0047@gmail.com','Dong Kwon Min','Go Yang 114-8<br>CCFARM choongchung 충청농장','New Il San','ga-jwa dong Kyung Ki','KOREA, SOUTH','411-410','',NULL,NULL,NULL,'2012-02-23 07:35:43',0,NULL,3,1,11,1,'BJ01714397\r ','eastar4\rWLIN014\r没有下来 '),(22315,8881329983130825,111,'New 3Dconnexion SpacePilot USB 3D Connexion MOUSE',2,'MOLO010',260,'eastar4uk','surfacer454','tim.gulland@fluidformdesign.co.uk','Fluidform Design Ltd.','Unit G3 Beeding CloseSouthern Cross Trading EstateBognor Regis,','West Sussex','PO22 9TS','UNITED KINGDOM','','',NULL,NULL,NULL,'2012-02-23 07:45:30',0,NULL,3,1,4,1,'YW867610941CN ','eastar4uk\rMOLO010\r直接打得款 '),(22316,8881329984747584,111,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',0,'eastar4uk','nickeha','nicklas.hallenborg@home.se','Nicklas Hallenborg','Enskiftesvägen 28','Eslöv','Skåne','SWEDEN','S-24135','+707500734',NULL,NULL,NULL,'2012-02-23 08:12:27',0,NULL,3,1,3,1,'RA184509875CN\r ','eastar4uk\rGLOT001\r补发的 '),(22317,785108853008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','o.galeev','oleg_zi@mail.rb.ru','Олег Галеев','Ю.Гагарина, 10 - 49<br>a/ya 34','Уфа','Республика Башкортостан','RUSSIAN FEDERATION','450073','+79033102413','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 08:22:53',0,NULL,3,1,3,1,'RA184509901CN\r ','au-buy\rLGAD001'),(22318,793466822007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','planologia','gustavo.roque@planologia.com','GUSTAVO ENGUICA','Rua das Sardinheiras, nr 23','Almada','Setubal','PORTUGAL','2820-462','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 08:28:44',0,NULL,3,1,11,1,'BJ01714400\r ','au-buy\rBALO007'),(22319,785109888008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','eeplaksin','ardalion@rambler.ru','Евгений Плаксин','Боровая, 34, 95','Кострома','','RUSSIAN FEDERATION','156003','79206401300','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 08:38:30',0,NULL,3,1,3,1,'RA184509892CN\r ','au-buy\rLGAD001'),(22320,793475505007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',19.99,'au-buy','amanda050403','dekela@optusnet.com.au','Amanda J Dekel','110 Macleay Cres','Tingalpa','Queensland','AUSTRALIA','4173','0413438072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 09:08:37',0,NULL,3,1,4,1,'YW867611280CN\r\r ','au-buy\rUM00033\rshoes  鞋子的    再加3 x shoes 1x pink love and 1 little tower   一共6把\r\r换地址\rAmanda Dekel\r33 corporate Dr\rCANNON HILL 4170\rAustralia   \r'),(22321,848855329011,320826738279,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',112.99,'eastar4','plevel.damjan','damjan.plevel@aldata.com','Damjan Plevel','Tržaška 515','Brezovica pri Ljubljani','','SLOVENIA','1351','386 2000 705','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 09:26:15',0,NULL,3,1,3,1,'RA184509858CN\r ','eastar4\rHSNO035\r欧标'),(22322,624262371003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','bully2001','kwa2809@googlemail.com','Klaus Wald ;   c/o ADAMS Blitzschutz-Systeme GmbH','im Lossenfeld 1','Willstätt - Sand','','GERMANY','77731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 09:29:53',0,NULL,3,1,3,1,'RA184509844CN','cnfaner\rHSJA001\r欧标'),(22323,629679963004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','namiqsadiqov_19842012','namiqsadiqov_1984@box.az','Sadigov Namig','Ganja pr.27 home 139','Baki','Azerbaijan','AZERBAIJAN','AZ1126',' 0703716603','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 09:56:23',0,NULL,3,1,3,1,'RA184509827CN\r ','cnfaner\rHSNO005\r欧标'),(22324,8881329992075225,111,' New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE  ',1,'HSUE002',0,'eastar4uk','jakk53','jakk53@live.co.uk','Jack Rogers','Flat D401, Newarke Point<br>8 Newarke Close','Leicester','Leicestershire','UNITED KINGDOM','LE2 7GZ','',NULL,NULL,NULL,'2012-02-23 10:14:35',0,NULL,3,1,3,1,'RA184509795CN\r ','EASTAR4UK\rHSUE002\r补发的 '),(22325,785137535008,180821302244,'100% New Genuine Atheros AR9287 BGN 300M Half PCI-E card',1,'WLAT007',11.99,'au-buy','human-3sf','3sf@mail.ru','Petr Shatalov','Tereshkovoi 34/3 - 34','Lipetsk','Lipetsk','RUSSIAN FEDERATION','398000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 10:27:41',0,NULL,3,1,11,1,'BJ01714409\r ','au-buy\rWLAT007'),(22326,785140330008,180819791725,'New Fire-Pad Professional FPS Gaming Game Surface Mouse Pad',1,'MOFP001',6.5,'au-buy','4711dab','dbinyon@mysoul.com.au','dennis binyon','4 Alward Ave','Clayton South','Victoria','AUSTRALIA','3169','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 10:38:55',0,NULL,3,1,11,1,'BJ01714404\r ','au-buy\rMOFP001'),(22327,939756208012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','mx5634','an15hg@hotmail.com','Anish Gami','14 Bovingdon Avenue','wembley','Middlesex','UNITED KINGDOM','HA9 6DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-23 11:53:41',0,NULL,3,1,3,1,'RA184509760CN\r ','eastar4uk\rMOMI002'),(22328,848965316011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','lopesandrer','andrericardolopes@gmail.com','André Ricardo Lopes','Rua Antonio Toselli, 58 A','Cosmópolis','SP','BRAZIL','13150-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 15:15:01',0,NULL,3,1,11,1,'BJ01714379\r ','eastar4\rUDAP001'),(22329,939836034012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','fabianovidiu','fabian.ovidiu@yahoo.com','Fabian Ovidiu Adrian','Almasului, nr. 6, ap. 20','Cluj-Napoca','','ROMANIA','400663','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 15:37:40',0,NULL,3,1,11,1,'BJ01714412 ','eastar4uk\rWLAT009'),(22330,848964538011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','sergeant673','sgt747@aol.com','larry uvino','15 Spiral Ln','levittown','NY','UNITED STATES','11756-3808','(516) 369-7371','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 15:13:40',0,NULL,3,1,1,1,'LK202613275CN ','eastar4'),(22331,629769671004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','littledan9','dan@littledan.com','Daniel Little','1430 Warren Ave','Williamsport','PA','UNITED STATES','17701-2618','(570) 506-3260','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-23 16:42:32',0,NULL,3,1,1,1,'LK202303472CN ','cnfaner'),(22332,940020332012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','dave.mcnulty','daveandpaws1@yahoo.com','david mcnulty','38 vale street<br>kelvin grove','brisbane','Queensland','AUSTRALIA','4059','0733152412','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 21:09:24',0,NULL,3,1,11,1,'BJ01714403\r ','eastar4\rOTGR002'),(22333,622437595003,130490216477,'New Logitech Charging Cradle L-LG7 for Harmony 880 890',1,'CRLO001',13.9,'cnfaner','rgarber2','rgarber2@yahoo.com','Robert W. Garber II','2502 Fen View Cir','Island Lake','IL','UNITED STATES','60042-8828','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-23 21:26:58',0,NULL,3,1,1,1,'LK202263036CN ','cnfaner'),(22334,849156541011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','ufedor_1976','ufedor1976@yandex.ru','Sergey Fedyakov','ulitsa Stroiteley<br>7k2, 94','Moscow','','RUSSIAN FEDERATION','119311','(919)7736462','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 21:31:42',0,NULL,3,1,11,1,'BJ01714407\r ','eastar4\rHBPH009'),(22335,940034203012,220670644089,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',19.9,'eastar4','arsho','arshavir6@yahoo.gr','ARSAVIR KOUGIOUMTZIAN','ETOLIKOU 23','PIRAEUS','','GREECE','18545','00306944347444','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 21:33:21',0,NULL,3,1,11,1,'BJ01714411\r ','eastar4\rOTGR001'),(22336,940037105012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','sandraz1963','sandraczerbetto@gmail.com','Sandra Zerbetto','Brasil, 336','Americana','SP','BRAZIL','13465-000','91235951','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 21:36:15',0,NULL,3,1,11,1,'BJ01714414\r ','eastar4\rUM00008'),(22337,940059746012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',83.97,'eastar4','youtube12345','1a1z2s2x@gmail.com','Mecta Corporation','19799 SW 95TH AVE','TUALATIN','OR','UNITED STATES','97062-7584','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 22:21:03',0,NULL,3,1,1,1,'LK202592010CN ','eastar4'),(22338,793803483007,170730544690,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'au-buy','stamatis2006','stamchor@gmail.com','Stamatis Choremis','6 b, Chalepa str.<br>P. Psichico','Athens','Attica','GREECE','154 52','00306944552477','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 22:51:23',0,NULL,3,1,11,1,'BJ01713719\r ','au-buy\rBALO007'),(22339,940062447012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Arlene Robbins','2200 Mission College Blvd<br>RNB-6-76, 6th fl, pole D11','Santa Clara','CA','UNITED STATES','95054-1537','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 22:26:35',0,NULL,3,1,1,1,'LK202610977CN ','eastar4'),(22340,940061274012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Greg Bearss','1343 ALBERT PIKE RD','Hot Springs National Park','AR','UNITED STATES','71913-4132','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 22:24:29',0,NULL,3,1,1,1,'LK202566964CN ','eastar4'),(22341,684975918013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','juliomazzi65','juliomazzi@uol.com.br','Julio Cesar Requena Mazzi','Rua Lamartine Ventura, 140 Apto 5<br>Jd. Wallace Simonsen','São Bernardo do Campo','São Paulo','BRAZIL','09770-470','11-4122-3591','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 00:35:20',0,NULL,3,1,3,1,'RA184509773CN\r ','eastar4\rLGAD001'),(22342,624505664003,130553090501,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',4,'WWSI004',143.96,'cnfaner','geirani','geirani@frisurf.no','Geir Arve Nielsen','Einangvegen 16 D','Sunndalsora','Nordmore','NORWAY','6600','90582232','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 00:41:22',0,NULL,3,1,3,1,'RA184509787CN\r ','cnfaner\rWWSI004'),(22343,849248682011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','bigdee0','darren@vw4motion.fsnet.co.uk','darren lee','10 malden green avenue','worcester park','Surrey','UNITED KINGDOM','kt47sq','02083354193','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 01:50:08',0,NULL,3,1,3,1,'RA184509813CN\r ','eastar4uk\rSAFI001*2\r'),(22344,785489624008,180758271107,'Original Logitech MX1100 Mouse Mat 3M material',1,'SCLO005',5.9,'au-buy','greg.mo','ggreggles@gmail.com','Greg Smith','40 Birdwood Street<br>Parkdale','Melbourne','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 02:02:21',0,NULL,3,1,11,1,'BJ01714380\r ','au-buy\rSCLO005'),(22345,8881330049078739,111,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','lile-enterprises','lileenterprises@yahoo.com','Elizabeth Sherman','4387 lincoln ave','saint joseph','MI','UNITED STATES','49085-8712','',NULL,NULL,NULL,'2012-02-24 02:04:38',0,NULL,3,1,1,1,'LK202267497CN ','cnfaner \r做的单子'),(22346,8881330049965845,111,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim ',2,'UM00001',39.98,'au-buy','pvroome2012','pvroome@optusnet.com.au','Vanessa Roome','4 Lukela Ave','Budgewoi','New South Wales ','AUSTRALIA','2262','',NULL,NULL,NULL,'2012-02-24 02:19:25',0,NULL,3,1,3,1,'RA184507171CN\r ','au-buy\rUM00001\r蓝色和紫色 \r做的单子  缺一把粉的，有紫的和黄的'),(22347,8881330050212096,111,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','marce77-29','hjohanningc@hotmail.com','HERBERT JOHANNING','3705 NW 115th AveUnit 1','DORAL','FL','UNITED STATES','33178-4842 ','',NULL,NULL,NULL,'2012-02-24 02:23:32',0,NULL,3,1,1,1,'LK202422015CN ','eastar4\rGPS0007\r系统没有下来\r'),(22348,785496429008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','lilyandtaco','danielle.scorer@gmail.com','Danielle Scorer','5 Helpmann street','Wantirna south','Victoria','AUSTRALIA','3152','0412598369','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 02:27:05',0,NULL,3,1,11,1,'BJ01714410\r ','au-buy\rUM00043'),(22349,785496846008,180821253462,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card+Tyco 2.4/5.0 GHz Antenna*3',1,'WLIN011+ANTY002',18.99,'au-buy','matt_praeger','mattp@soton.ac.uk','Matthew Praeger','12 Snowberry Crescent<br>Denvilles','Havant','Hampshire','UNITED KINGDOM','PO9 2FG','07944906800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 02:28:42',0,NULL,3,1,11,1,'BJ01714406 ','au-buy\rWLIN011+ANTY002'),(22350,8881330050687835,111,'Genuine Logitech Harmony 515 Universal Remote Control',1,'RCLO004',39.99,'au-buy','sanay-sanay','sanay.sanay@gmail.com','Olexandr Kavylin','V. Chornovola 14/16 33','Rivne','Rivne ','UKRAINE','33000','',NULL,NULL,NULL,'2012-02-24 02:31:27',0,NULL,3,1,3,1,'RA184509725CN\r ','au-buy\rRCLO004 \r买家要发票\r做的单子'),(22351,8881330050808170,111,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','sshssh65','sshssh@inbox.ru','Sergey Shavkin','ul. Tsiolkovskigo, d.17, kv.35','Krasnogorsk','Moscow district','RUSSIAN FEDERATION','143406 ','',NULL,NULL,NULL,'2012-02-24 02:33:28',0,NULL,5,0,18,1,'\r ','EASTAR4\rWLIN014\r没下来  暂停发货 paypal有问题'),(22352,8881330052022505,111,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','karemyrcomputer','yrcomputer@yahoo.com','KAREM M ABDULLAH','4121 David Dr','METAIRIE','LA ','UNITED STATES','70003-3422','(504) 888-9177',NULL,NULL,NULL,'2012-02-24 02:53:42',0,NULL,3,1,1,1,'LK202704201CN ','EASTAR4\r直接打得款 '),(22353,849277848011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','keko2214','kareem_farge_2012@hotmail.com','karim mabrouk','3749 85th St<br>Queens Apt 44','jackson heights','NY','UNITED STATES','11372-7316','(646) 807-5419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 03:25:26',0,NULL,3,1,1,1,'LK202540777CN ','eastar4'),(22354,849286827011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','mrcatfarmer','gdavis1100@yahoo.com','George davis','809 Richard ave','watervliet','MI','UNITED STATES','49098','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 04:00:06',0,NULL,3,1,1,1,'LK202592712CN ','eastar4'),(22355,785547095008,180762085522,'New lady paris tower dot w/trim Sun Rain Stick Umbrella',1,'UM00028',22.99,'au-buy','joe-stan','joe.stancliff@gmail.com','joseph stancliff','15013 shaw rd','tampa','FL','UNITED STATES','33625-5528','(813) 982-7494','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 06:12:18',0,NULL,5,1,18,1,NULL,'au-buy\r红色的\r已退款并退了$5补偿金'),(22356,793916408007,170748039367,'UNLOCKED Sierra Wireless MC8781 Air Card 3G HSUPA/HSDPA/UMTS Mini PCI-E Module',1,'WWSI005',36.99,'au-buy','justme4507','evanlambie@gmail.com','evan lambie','p.o.box840','bribie island','Queensland','AUSTRALIA','4507','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 06:03:13',0,NULL,3,1,11,1,'BJ01714381\r ','au-buy\rWWSI005'),(22357,793918998007,170728921700,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',20.99,'au-buy','schwarzdf','schwarzdf@gmail.com','Frances Schwarz','51 Duff St<br>Turramurra','Sydney','New South Wales','AUSTRALIA','2074','020479196065','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 06:20:46',0,NULL,3,1,11,1,'BJ01714395\r ','au-buy\rHSUE003\r澳标'),(22358,802404685001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','bdebont','bendebont@gmail.com','Ben de Bont','2219 2nd Ave<br>Apt 602','Seattle','WA','UNITED STATES','98121-2045','(425) 503-0096','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-24 06:10:40',0,NULL,3,1,1,1,'LK202580467CN ','buysia'),(22359,940217504012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',96.99,'eastar4','rs97023','george.pliakos@gmail.com','GEORGE PLIAKOS','EYRIPOY 5','LARISA','LARISA','GREECE','41335','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 06:45:22',0,NULL,3,1,3,1,'RA184509711CN','eastar4\rGLSG009'),(22360,8881330067789625,111,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',14.99,'eastar4','msftman19','mike@fiorina.net','Michael Fiorina','264 Appleton St','Arlington','MA','UNITED STATES','02476','7813161957',NULL,NULL,NULL,'2012-02-24 07:16:29',0,NULL,3,0,1,1,'LK202619667CN ','EASTAR4\rWLDE002\r\r没有下来  邮箱也没有下来'),(22361,8881330068510443,111,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',85,'eastar4','joschka2512','ebay@atca.de','Richard Krause','Goslarsche Strasse 29','Wolfenbüttel','','GERMANY','38304','',NULL,NULL,NULL,'2012-02-24 07:28:30',0,NULL,3,1,3,1,'RA184509756CN\r ','eastar4\rTRTS001*10 \r没有下来  邮箱也没有'),(22362,8881330069586555,111,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','loredanasecman','forminte_loredana@yahoo.com','loredana secman','21 adelphi warf suites<br>adelphi quay','waterford','Waterford','IRELAND','wd','0872768420',NULL,NULL,NULL,'2012-02-24 07:46:26',0,NULL,3,1,11,1,'BJ01714398\r ','eastar4\rHSNO016\r英标\r系统 和邮箱都没有下来'),(22363,629999262004,140667903814,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card + A pair of Antenna',1,'WLAT009+ANTY001',11.9,'cnfaner','obolshakov','obone@mail.wplus.net','Oleg Bolshakov','Antonova-Ovseenko st., 11/2/112','St.Petersburg','StPetersburg','RUSSIAN FEDERATION','193168',' 79110903601','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 07:58:04',0,NULL,3,1,3,1,'RA184509742CN\r ','cnfaner\rWLAT009+ANTY001'),(22364,8881330070441410,111,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','demonnn75','realfassion@inbox.lv','Dmitrijs Roslovs','Eizensteina 77-3','Riga','Latvia','LATVIA','LV-1079','37126959145',NULL,NULL,NULL,'2012-02-24 08:00:41',0,NULL,3,1,3,1,'RA184509668CN\r ','eastar4\rLGRM001\r系统和邮箱都没有下来 '),(22365,8881330070716148,111,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','nadavgil ','nadavmc@gmail.com','Mor Asayag Or Nadav gil','Hayasmin 5 Orot','Or-akiva','','ISRAEL','30600','972524389734',NULL,NULL,NULL,'2012-02-24 08:05:16',0,NULL,3,1,3,1,'RA184509739CN\r ','EASTAR4\rLGAD001\r系统和邮箱都没有下来 '),(22366,8881330071147308,111,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','heik25','heichszeich@aol.com','Heiko Bleyl','R.-Breitscheid-Str.-21','Zschorlau','','GERMANY','08321','01738516916',NULL,NULL,NULL,'2012-02-24 08:12:27',0,NULL,3,1,11,1,'BJ01714396\r ','EASTAR4UK\rRELO003 \r系统和邮箱都没有下来'),(22367,793951071007,170728982479,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'au-buy','sirscammalot','samsondrose@hotmail.com','Samson Rose','10 Jales Street<br>Sunnybank Hills','Brisbane','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 08:55:22',0,NULL,3,1,3,1,'RAm45809671C ','au-buy\rGPS0004'),(22368,940254127012,220930022498,'New 4 Parking Sensor Car Reverse backup Radar kit w/ buzzer 10 colors available',1,'PS00002',24.99,'eastar4','round001mike','michael.gleyzer@gmail.com','Michael Gleyzer','Post Box 9147, Kiryat Yuvel Post Office','Jerusalem','Israel','ISRAEL','91090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 09:21:45',0,NULL,3,1,11,1,NULL,'eastar4\rPS00002\r珍珠白'),(22369,849359390011,320698812095,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',55.9,'eastar4','57580','avibi10@gmail.com','Avi Bibi','Herzog<br>10','Kiriyt Ono','Israel','ISRAEL','55523','97236232535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 09:32:58',0,NULL,3,1,3,1,'RA184509623CN ','eastar4\rOTGR001+OTGR002+OTGR003'),(22370,793959563007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',20.9,'au-buy','nikola2545','basomak@tpg.com.au','Basoski Nikola','88 Blamey Cr','Campbell','Australian Capital Territory','AUSTRALIA','2612','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 09:33:29',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR001'),(22371,940259377012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','anastasios-sofia','anastasios7@in.gr','anastasios mihailidis','tantalou 5<br>polihni','thesaloniki','greece','GREECE','56429','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 09:39:09',0,NULL,3,1,11,1,'BJ01714392 ','eastar4\rBTAC2013\racer 5pin1.25 15cm '),(22372,8881330077956607,111,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Tyco 2.4/5.0GHz Antenna *3 - ',1,'WLAT001+ANTY002',15.99,'aliexpress','1006960475','1@1.com','1006960475','Lagunovskaya 65-a, 76 ','Yaransk','Kirov region','RUSSIAN FEDERATION','612260','79127229117',NULL,NULL,NULL,'2012-02-24 10:05:56',0,NULL,3,1,3,1,'RA184509699CN','WLAT001+ANTY002 '),(22373,624546826003,130598387349,'3 pairs of New Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*3',199.99,'cnfaner','zappeastusa4','zappusa4@gmail.com','Andrei Fourth','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-24 10:27:23',0,NULL,3,1,4,1,'YW867611103CN ','cnfaner\rGLSG001*3\rItem #130598387349\r产品号写在包装上'),(22374,849374699011,320812368138,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',7.99,'eastar4uk','rtexcs','rtexcomputerservices@gmail.com','Ramunas Tiknius','16 Gleann na Carraige','Edenderry','Offaly','IRELAND','default','0879525737','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 10:28:53',0,NULL,3,1,3,1,'RA184509610CN ','eastar4uk\rOT00002'),(22375,685095264013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','bynmst','byn1970@list.ru','Yuriy Barmin','str.Valihanova 155 - 1','Temirtau','Karaganda','KAZAKHSTAN','101407','87003248347','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 11:20:51',0,NULL,3,1,11,1,NULL,'eastar4\rUM00033'),(22376,8881330082730848,111,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102 ',1,'GPS0006',0,'eastar4','gaodonto10','gaodonto@gmail.com','Guilherme Martins','SQN 213 BLOCO A APA 102','BRASILIA','DF','BRAZIL','70872010','00556181210794',NULL,NULL,NULL,'2012-02-24 11:25:30',0,NULL,3,1,11,1,NULL,'eastar4\rGPS0006\r只补发一个电池充电器 Battery charger'),(22377,940303527012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','makhoulster','elias.makhoul@gmail.com','Elias  Makhoul','809 Ave Lajoie','Dorval','QC','CANADA','H9P1G7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:04:09',0,NULL,3,1,11,1,NULL,'eastar4\rOTCN004*10'),(22378,849413612011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','msw1478','msw1478@gmail.com','Mattias Greenbaum','Seedri 43<br>Karla küla,  tel: 5182061,','Rae vald','Harjumaa,','ESTONIA','75301','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 12:41:10',0,NULL,3,1,11,1,NULL,'eastar4uk\rRELO003'),(22379,849417265011,320786223079,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',89.99,'eastar4','cfish5','craigwhiting@usa.net','Craig Whiting','11 Apurla Ct<br>Karana Downs','Brisbane','Queensland','AUSTRALIA','4306','0416287637','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:52:24',0,NULL,3,1,3,1,'RA184507211CN\r ','eastar4\rKBVI001\r黑色的'),(22380,849427041011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','oineus','nausch@gmail.com','Horst Nausch','Josefstädterstr.3/24','Wien','','AUSTRIA','A  1080','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 13:25:36',0,NULL,3,1,3,1,'RA184507018CN\r ','eastar4uk\rOTSO002'),(22381,940332482012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','jjmadrock','jgd@tcs-ltd.net','John Day','TCS<br>Admin House, North Street','Droitwich','Worcestershire','UNITED KINGDOM','WR98JB','01905794169','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 13:28:07',0,NULL,3,1,3,1,'RA184509402CN\r ','eastar4uk\rOTCN004*10'),(22382,940337903012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','productsofpixel','zcemb68@ucl.ac.uk','Rakesh Ram','82 Swanage Waye<br>Hayes','Middlesex','London','UNITED KINGDOM','UB4 0NZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 13:39:32',0,NULL,3,1,3,1,'RA184507066CN\r ','eastar4uk\rWLAT009'),(22383,624666415003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','hawks618','benjamin.sevcik@gmail.com','Benjamin Sevcik','618 41st St','Downers Grove','IL','UNITED STATES','60515-2248','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-24 15:19:59',0,NULL,3,1,1,1,'LK203951955CN ','cnfaner'),(22384,849473873011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','mariopinho','marioangelo@gmail.com','MARIO PINHO','R. CONSELHEIRO LAFAIETE, 1925','BELO HORIZONTE - MG','-','BRAZIL','31035-560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 15:29:44',0,NULL,3,1,11,1,NULL,'eastar4\rANCN001'),(22385,685158578013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','eternitydesigncorp','info@eternitymodern.com','Paul Lum','213-5920 No. 6 Road','Richmond','BC','CANADA','V6V1Z1','(604) 232-1218','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 15:38:57',0,NULL,3,1,3,1,'RA184507083CN\r ','eastar4\rGPS0006'),(22386,940391049012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','ykc1800','ykc@kernelhk.com','Mr. Yuen Kai-cheung','Flat B, 14/F, Block 2, Site 7,<br>Hunghom, Kowloon,','default','','HONG KONG','default','(852)9041-4576','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 15:47:57',0,NULL,3,1,3,1,'RA184509645CN\r ','eastar4\rPSGL001\r新地址\rMr. Yuen Kai-cheung\rFlat B, 14/F, Block 2, Site 7,\rWhampoa Garden,\rHunghom, Kowloon,\rHong Kong\r(852)9041-4576\r'),(22387,785707319008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','maiconluiz27','maiconluiz@gmail.com','Maicon Luiz de Souza','Rua Sao Bertoldo, 263','Sao Paulo','Sao Paulo','BRAZIL','08070380','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 15:49:56',0,NULL,3,1,3,1,'RA184509420CN\r ','au-buy\rLGAD001'),(22388,849516900011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',10,'CASS003',68.9,'eastar4uk','athemis81','andreast@gmail.com','andreas themistocleous','14 Brunswick Lodge, 199 Ewell Road','Surbiton','Surrey','UNITED KINGDOM','kt6 6bb','07920825961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 17:03:21',0,NULL,3,1,3,1,'RA184507070CN\r ','eastar4uk\rCASS003'),(22389,940468626012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','wlschwartz3dvz','wlschwartzz@yahoo.com','Wm Schwartz','14844 S 30th St','Phoenix','AZ','UNITED STATES','85048-8714','(773) 848-7246','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 18:20:59',0,NULL,3,1,1,1,'LK204147072CN ','eastar4'),(22390,940492076012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','rgoswell','roger@xanadude.org','Roger Goswell','145 Bemersley Road<br>Ball Green','Stoke-On-Trent','Staffordshire','UNITED KINGDOM','ST68AS','01782545012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 18:58:09',0,NULL,3,1,3,1,'RA184507145CN\r ','eastar4uk\r英标\rHSJA002'),(22391,940508389012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','raybyungsigkim','kkhkku1@naver.com','Moon\'s Wings Yasimin kim','3047 Hartley bridge RD','Macon','GA','GEORGIA','31216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 19:25:31',0,NULL,3,1,11,1,NULL,'eastar4\rOTCN004*10'),(22392,785814457008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','getsim123','getsimandreas@hotmail.com','GETSIM       ANDREAS','IPPOKRATOYS       42','ARTEMIDA','ATTIKI','GREECE','19016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 19:40:49',0,NULL,3,1,3,1,'RA184509504CN\r ','au-buy\rLGAD001'),(22393,940546295012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','theuman','dwacek@yahoo.com','Dan Wacek','6274 Mears Rd','Cygnet','OH','UNITED STATES','43413-9754','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 20:27:21',0,NULL,3,1,1,1,'LK204138552CN ','eastar4'),(22394,630201052004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','graphido','orhunaktekin@hotmail.com','ORHUN AKTEKIN','DIGITAL PANORAMA (KOC)<br>UNALAN MAH. AYAZMA CAD. CAMLICA IS MERKEZI B1 BLOK KAT:3  NO:23','ISTANBUL','USKUDAR','TURKEY','34700','+90 216 454 00 77','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 20:48:10',0,NULL,3,1,3,1,'RA184504895CN\r ','cnfaner\rBALO007'),(22395,940576811012,220459526352,'Acer TM 4280 4230 2490 Bluetooth Module 2.0 EDR+cable',1,'BTAC2021',9.88,'eastar4','bgdnsmnv','semenov@inet.ua','Bogdan Semenov','Vishniyakovskaya 5, app 114','Kiev','Kievskaya','UKRAINE','02140','+380681836801','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 21:21:27',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2021\racer 8pin1.00 8cm'),(22396,940574951012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','tonewheelmonster','tonewheelmonster@yahoo.com','Kyle Coffey','1714 Riverside Dr<br>Apt B','Salisbury','MD','UNITED STATES','21801-7006','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 21:21:52',0,NULL,3,1,1,1,'LK204147316CN ','eastar4'),(22397,685285037013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','rmax1863','ron.maxfield@bigpond.com','Ron Maxfield','158 Nangar Road','Canowindra','New South Wales','AUSTRALIA','2804','0263441974','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 21:38:26',0,NULL,3,1,3,1,'RA184507097CN\r ','eastar4\rGLOT001*2'),(22398,849665998011,320826738279,'New Advanced Multipoint Ergonomic Design Nokia Bluetooth Headset BH-904 w/U-hook',1,'HSNO035',112.99,'eastar4','02goodman','uts40@hotmail.com','joseph youkhana','9 lycett ave','west hoxton','New South Wales','AUSTRALIA','2171','0415855855','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 21:48:25',0,NULL,3,1,3,1,'RA184507154CN\r ','eastar4\rHSNO035\r澳标'),(22399,940597391012,220769088331,'2 pairs of New genuine Samsung 3D Active Glasses SSG-2100AB for 2010 3D TVs',1,'GLSG001*2',141.99,'eastar4','ferleo85','ferrg270785@hotmail.com','fernando garcia','1390 S Highway 40<br>Unit 13','heber city','UT','UNITED STATES','84032-3850','(435) 901-9244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 22:01:29',0,NULL,3,1,1,1,'LK204142733CN ','eastar4'),(22400,685298426013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',3,'GPS0006',179.97,'eastar4','kzam05','teo.z05@gmail.com','Matt Zamora','18642 cape sable dr','boca raton','FL','UNITED STATES','33498-6374','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 22:19:18',0,NULL,3,1,4,1,'YW867611136CN ','eastar4'),(22401,940611426012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','rase7968','ryan_ase@hotmail.com','ryan aselstyne','1664 skeena pl','kamloops','BC','CANADA','v2e 2p3','(250) 682-1041','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 22:27:37',0,NULL,3,1,3,1,'RA184507035CN\r ','eastar4\rGLOT001*2'),(22402,940634448012,220581067419,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2002',9.88,'eastar4','sergeyspb78','fbg98@yandex.ru','Sergey Demidov','yl. Dimitrova dom 16 korp 2 kv 85','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192239','+7(921)997-47-46','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 23:28:36',0,NULL,3,1,11,1,NULL,'eastar4\rBTLE2002\rS10-2 8pin 1.0 8cm 五线连接'),(22403,940646865012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','bente48','bente.dahl@shell.com','Bente Reinertsen','Karistoe 23<br>4045 Hafrsfjord','Stavanger','Hafrsfjord','NORWAY','4045','+47 99322012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 23:57:33',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(22404,849728103011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','boobsie_96','rstuck2@carolina.rr.com','Robert A Stuck','3790 Sedgewick Dr SW','Concord','NC','UNITED STATES','28027-9201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 00:32:53',0,NULL,3,1,1,1,'LK204109176CN ','eastar4'),(22405,849730839011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','deelife0','dlife112@hotmail.com','Faiz  Dahoe','Lattropbrink 15','Enschede','','NETHERLANDS','7544XG','(053) 4769533','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 00:43:53',0,NULL,3,1,11,1,NULL,'eastar4\r欧标\rHSJA013'),(22406,849751767011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',2,'GPS0010',39.98,'eastar4uk','marxiecorporation','marxiecorp@gmail.com','Ozspy Brunswick - Martin Gomulya','Shop 1, 259 Sydney Road','Brunswick','Victoria','AUSTRALIA','3056','0434379637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 01:59:14',0,NULL,3,1,3,1,'RA184509455CN\r ','eastar4uk\rGPS0010'),(22407,630279901004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','2flbeachbums','ekol@aol.com','Terri Kolaska','32 Rio Pinar Trl','Ormond Beach','FL','UNITED STATES','32174-4325','(386) 682-2550','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-25 02:06:37',0,NULL,3,1,1,1,'LK203916423CN ','cnfaner'),(22408,685353853013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','mythical-mum2009','mythical-mum@hotmail.com','Mrs Williams','202 Alexandra Street','East Albury','New South Wales','AUSTRALIA','2640','0260234171','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 02:19:21',0,NULL,3,1,11,1,NULL,'eastar4\rUM00010\r象牙色的\r客户愿意等3.12'),(22409,624858636003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','ascs44','ascs@san.rr.com','Joseph Roys','4121 worsch way','San Diego','CA','UNITED STATES','92130-2214','(858) 792-7594','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-25 03:02:48',0,NULL,3,1,1,1,'LK203908815CN ','cnfaner'),(22410,940701685012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','dmm21046','briscoanddixie@yahoo.com','David Mrgich','17360 Norland Way','Shrewsbury','PA','UNITED STATES','17361-3300','(240) 535-2551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 03:40:25',0,NULL,3,1,1,1,'LK204140180CN\r ','eastar4'),(22411,685385089013,230412694885,'2.1 Bluetooth Module cablefor DELL mini10 10v 1010 1011',1,'BTDE2102',12.39,'eastar4','asciisensei','kagatosr@gmail.com','James Dodd','420 Elsmere Dr','Riverside','CA','UNITED STATES','92506-5611','(951) 258-0436','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 05:13:52',0,NULL,3,1,1,1,'LK204118500CN ','eastar4'),(22412,849808759011,320730084143,'Genuine  Jabra BT500V Bluetooth Headset BT 500V',1,'HSJA011',18.99,'eastar4uk','82jeff82','jeffrey_marriner@yahoo.com.au','Jeffrey Marriner','82 Sterling Drive','Keilor East','Victoria','AUSTRALIA','3033','0434130708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 06:07:59',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSJA011\r澳标'),(22413,685413891013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','zachariou2005','pentaraschr@cytanet.com.cy','Elena Zachariou','Zinas Kanther  8<br>Chloraka','Paphos','Cyprus','CYPRUS','8221','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 08:35:14',0,NULL,3,1,3,1,'RA184507052CN\r ','eastar4\rGLOT001*2'),(22414,849867592011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','siremile','mremile33@gmail.com','Emile Tsalihin','Hamacabim 84g11','Shoham','','ISRAEL','60850','972506323356','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 10:14:06',0,NULL,3,1,11,1,NULL,'eastar4\rADAK002'),(22415,847478947002,120844622131,'New GENUINE i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',46.99,'buysia','rostlened','rostlen@gmail.com','Rostislav Ostrovsky','Katz Street 50/7','Petach-Tikva','','ISRAEL','49374','0502009677','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-25 10:50:04',0,NULL,3,1,3,1,'RA184509549CN\r ','buysia\rHSIT001\r欧标'),(22416,685434661013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','gcou7689','gcoulson68@gmail.com','Gordon Coulson','1 Brooklea Pl<br>Ferndale','Perth','Western Australia','AUSTRALIA','6148','0448714519','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 11:09:00',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN014'),(22417,849883068011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','collins323','collins.g71@googlemail.com','Gary Collins','3 Farm Drive<br>Cyncoed','Cardiff','Cardiff','UNITED KINGDOM','CF23 6HQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 11:02:47',0,NULL,3,1,3,1,'RA184509433CN\r ','eastar4uk\rLGAD001'),(22418,940834755012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Heidi Scheier','1120 S Cady Mall - Intdsb 256K<br>Asu - Graduate College','Tempe','AZ','UNITED STATES','85287-1003','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 11:23:21',0,NULL,3,1,1,1,'LK204157715CN ','eastar4'),(22419,940835686012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Gabriel Sanchez / Enkarga','7081 NW 82ND AVE','MIAMI','FL','UNITED STATES','33166-2749','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 11:25:15',0,NULL,3,1,1,1,'LK204128881CN ','eastar4'),(22420,940836341012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','M.A.Stevens','31 LAURI DR<br># 5B','CHARLESTOWN','RI','UNITED STATES','02813-3604','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 11:27:34',0,NULL,3,1,1,1,'LK204119672CN ','eastar4'),(22421,849922436011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','paulntrace','paul@ptjm.fsnet.co.uk','paul meakin','43 riverglade','cardiff','Cardiff','UNITED KINGDOM','CF159SP','02920813757','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 12:56:10',0,NULL,3,1,3,1,'RA184509393CN\r ','eastar4uk'),(22422,685480901013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','baurulino','ericcasti@gmail.com','Ericson Castilho','Av. Nossa Senhora de Fátima, 5-125, apartament 22<br>Jardim América','Bauru','São Paulo','BRAZIL','17017-337','14 38796126','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 13:36:54',0,NULL,3,1,3,1,'RA184509583CN\r ','eastar4\rLGAD001'),(22423,940886863012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',24.99,'eastar4','angina-ru','nastenka5400@yandex.ru','Anastasya Rupasova','prospekt Prosvescheniya, d.20, kv.221','St. Petersburg','','RUSSIAN FEDERATION','194358',' 89516446337','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 13:39:01',0,NULL,3,1,11,1,NULL,'eastar4\rUM00010\r 象牙色的\r客户愿意等'),(22424,940896981012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','our_snake_river','janetputnam@earthlink.net','Janet Putnam','5 Crown Ridge Rd','Wellesley','MA','UNITED STATES','02482-4601','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 14:02:08',0,NULL,3,1,1,1,'LK204120083CN ','eastar4'),(22425,794525799007,170784482004,'100% New Atheros AR5B195 Wireless + Bluetooth Half Mini PCI-E Card',1,'WLIN016',14.99,'au-buy','ninjagull','ninjagull@bigfoot.com','Ian Foulger','37 Lymington Avenue','Leigh-on-Sea','Essex','UNITED KINGDOM','SS9 2AU','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-25 14:21:04',0,NULL,3,1,11,1,NULL,'au-buy\rWLIN016'),(22426,849958479011,320441575422,'2.1 Acer Aspire 7720 7720G 7720Z Bluetooth Module+cable',1,'BTAC2124',12.39,'eastar4','scl_1976','stephane_claudel@laposte.net','stephane claudel','Quai de la liberation<br>Le Nautiléa H41','Port saint louis du rhone','Provence-Alpes-Côte d\'Azur','FRANCE','13230','0442457506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 14:23:42',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2124\racer 8pin1.00 15cm '),(22427,685494005013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','boazyaacov','boaz208@walla.com','boaz yaacov','hashiryon 12','rosh haain','','ISRAEL','48043','+972543130730','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 14:24:08',0,NULL,3,1,3,1,'RA184509597CN\r ','eastar4\rGPS0006'),(22428,685497585013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','yanik1301','medzo_productionz@hotmail.com','Yanik Durand','40 37e Avenue','Ste-marthe-sur-le-lac','QC','CANADA','j0n1p0','(450) 623-1194','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 14:37:08',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP002'),(22429,685498735013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',1,'WLAP002',19.98,'eastar4','marx_and_engels','designverkauf@gmail.com','Patrick Jonkman','Da Costastraat 45','Enschede','OV','NETHERLANDS','7514 CS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 14:39:19',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP002'),(22430,685503397013,230657633130,'KODAK Wi-Fi Card 4 EasyShare Camera printer dock',1,'WLKO001',25.99,'eastar4','sixpennysales','ebayjay21@yahoo.com','Jason Iannotti','18 Averill Pl','Branford','CT','UNITED STATES','06405-3801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 14:54:34',0,NULL,3,1,1,1,'LK204093520CN\r ','eastar4'),(22431,794541448007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','jonclark1180','jon.clark@hotmail.com','Jon Clark','1269 Sandhills Rd','New Hamburg','ON','CANADA','N3A 3B1','(519) 696-3225','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-25 14:55:28',0,NULL,3,1,3,1,'RA184509570CN\r ','au-buy\rPSGL001*2'),(22432,685513876013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','negaobm','lipebmatos@hotmail.com','Felipe Barros','AV BARAO DO RIO BRANCO 5350<br>AP 302 BLOCO C','Juiz de Fora','Minas Gerais','BRAZIL','36026-500','3232130794','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 15:25:53',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(22433,849994305011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',2,'TRTS001*10',170,'eastar4','dpatelus','dpatelus@hotmail.com','DIGESH PATEL','459 Bellbrook Ln','Lawrenceville','GA','UNITED STATES','30045-9306','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 15:41:03',0,NULL,3,1,4,1,'YW867611184CN','eastar4  '),(22434,685526379013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','belyakov1987','ver2hi@mail.ru','Алексей Беляков','?? ???????? ?26 ?1 ??35','??????','','RUSSIAN FEDERATION','117624','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 16:03:33',0,NULL,3,1,11,1,'BJ01713670\r ','eastar4\rUM00042\r新地址\rАлексей Беляков\rул.изюмская д.26 к.1 кв35\rмосква 117624\rRussian Federation'),(22435,625016630003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','jonnybegood89','jonnyagnarhaugen@msn.com','Jonny Haugen','Lindgaards Gate 38','Sandefjord','Vestfold','NORWAY','3213','+4793425137','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 16:09:25',0,NULL,3,1,3,1,'RA184509535CN\r ','cnfaner\rSHLO009'),(22436,850009743011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','rmac2190','rmac2190@comcast.net','Ronald  MacAdam','3032 NE Quayside LN','Miami Shores','FL','UNITED STATES','33138-2258','(305) 899-8737','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 16:12:45',0,NULL,3,1,1,1,'LK204064293CN ','eastar4'),(22437,850016158011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','ferretwrestling','csdaniel@virginmedia.com','Chris S Daniel','83 Chelmsford Avenue Chase Cross<br>Romford','Essex','Essex','UNITED KINGDOM','RM5 3UX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 16:25:47',0,NULL,3,1,3,1,'RA184509362CN\r ','eastar4uk\rMOAP001'),(22438,850032010011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',5.89,'eastar4uk','dersetzer','info@gunda.org','Rainer Gunda','Von-Halem-Str. 46','Hamburg','','GERMANY','21035','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 16:53:26',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLAT008'),(22439,850047667011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','stirpe5','stirpe5@aol.com','Anthony Stirpe','131 East 83rd Street<br>Unit 7F','New York','NY','UNITED STATES','10028','(917) 573-5975','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 17:21:30',0,NULL,3,1,1,1,'LK204216250CN ','eastar4uk'),(22440,847631887002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','darkforce318','kmaznd767@hotmail.com','xuehai gao','8933 david allen ct','Las Vegas','NV','UNITED STATES','89149-4442','(413) 330-7927','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-25 17:22:15',0,NULL,3,1,1,1,'LK203946368CN ','buysia'),(22441,625046280003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','txbargainshopper','boatmanjoshua@yahoo.com','Joshua A. Boatman','4044 Shore Front Dr','Fort Worth','TX','UNITED STATES','76135','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-25 17:33:43',0,NULL,3,1,1,1,'LK203958834CN ','cnfaner'),(22442,941026707012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','cougar-dychen','cougardychen@hotmail.co.uk','kim jenkins','unit 19 equity trade centre<br>hobley drive','swindon','wilts','UNITED KINGDOM','SN3 4NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 18:03:16',0,NULL,3,1,3,1,'RA184507137CN\r ','eastar4uk\rHSJA010\r英标'),(22443,850077479011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'eastar4','shotgunslade','dannall@mindspring.com','daniel   nall','80 Random Rd','princeton','NJ','UNITED STATES','08540-4066','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 18:11:42',0,NULL,3,1,1,1,'LK204090608CN ','eastar4'),(22444,850102227011,320395756160,'NEW CAB-SS-2626 BACK-TO-BACK WIC-2T TO WIC-2T 2T 1T',7,'CASS001',69.93,'eastar4','ralph2107','ralphthonissen@hotmail.com','Ralph Thönissen','Mariastraat 16G','Reuver','','NETHERLANDS','5953NL','31774748584','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 18:57:57',0,NULL,3,1,3,1,'RA184509464CN\r ','eastar4\rCASS001'),(22445,803134770001,110808692986,'New Jabra BT 500V Over The Ear Bluetooth Headset BT 500V',2,'HSJA011',57,'buysia','asaf456','asfi454@gmail.com','asaf cohen','homat smohel<br>amamzi 8/8','jerusalem','israel','ISRAEL','93123','0525313300','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-25 19:03:20',0,NULL,3,1,3,1,'RA184507242CN\r ','buysia\rHSJA011\r欧标'),(22446,786293409008,180810744292,'New Super Panoramic Antiglare Convex Rear View Mirror 270mm just Click On',1,'RVM0001',14.99,'au-buy','22508064','billc1933@hotmail.co.uk','william cunnington','20 walsham close','stevenage','Hertfordshire','UNITED KINGDOM','sg28ss','01438814942','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-25 19:09:33',0,NULL,3,1,11,1,NULL,'au-buy\rRVM0001'),(22447,685617659013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','louisvui','hdcheong@gmail.com','Silvia Mok','33 / 22 Crystal Street','Waterloo','New South Wales','AUSTRALIA','2017','0283992629','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 19:50:44',0,NULL,3,1,11,1,NULL,'eastar4\rOT00004'),(22448,685648967013,230695501279,'3 pairs 3D Active shutter Glasses for SHARP LC-40LE835U',1,'GLOT001*3',132.99,'eastar4','coltschick1987','bakkensx6@yahoo.com','Tracey Bakken','PO Box 265','Wibaux','MT','UNITED STATES','59353-0265','(406) 796-2933','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 21:08:03',0,NULL,3,1,1,1,'LK204037151CN ','eastar4'),(22449,850191772011,320730548788,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',52.99,'eastar4uk','farid-0','sabeti.farid@sunrise.ch','Farid Sabeti','Zugerstrasse 19a','Baar','','SWITZERLAND','CH - 6340','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 21:21:00',0,NULL,3,1,3,1,'RA184509447CN\r ','eastar4uk\rGLOT001*2'),(22450,794753927007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','balth232','balth@msn.com','Jack Simpson','1/114 Blamey Crescent<br>Campbell ACT 2612','Campbell','Australian Capital Territory','AUSTRALIA','2612','0401601292','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 21:37:20',0,NULL,3,1,11,1,NULL,'au-buy\rRELO002'),(22451,850214702011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','carlamarie2011','medusamadge@gmail.com','Carla Pietrosanto','9149 Spirit Canyon Ave','Las Vegas','NV','UNITED STATES','89149-3233','(702) 622-8524','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 22:17:02',0,NULL,3,1,1,1,'LK204082650CN ','eastar4'),(22452,685685461013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',1,'OTCN001',5.98,'eastar4','tigan_123','adrianpieprzowski@googlemail.com','Adrian Pieprzowski','75<br>Woodwater Lane','Exeter','Devon','UNITED KINGDOM','Ex2 5NQ','07542071666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 22:56:52',0,NULL,3,1,11,1,NULL,'eastar4\rOTCN001'),(22453,941206267012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','arsenalgavin','gavin@gmycroft.orangehome.co.uk','Gavin Mycroft','3 gardeners court<br>london road','Luton','Bedfordshire','UNITED KINGDOM','lu1 3sj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:01:16',0,NULL,3,1,3,1,'RA184509481CN\r ','eastar4uk\rHSJA010\r英标'),(22454,625167305003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',47.99,'cnfaner','javier197900','javier197900@hotmail.com','javier baena carrera','avenida meridiana num 320 piso 9º5ª','barcelona','Cataluña','SPAIN','08027','627356606','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 23:02:38',0,NULL,3,1,3,1,'RA184509495CN\r ','cnfaner\rMOOE002\rOEM'),(22455,850239202011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','ricardo168','ricardo168@aol.com','Richard Hetherington','Forge House<br>Goudhurst Road','Marden','Kent','UNITED KINGDOM','TN12 9NG','01622831098','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:03:29',0,NULL,3,1,3,1,'RA184509416CN\r ','eastar4uk\rLGAD001'),(22456,625080910003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','holly48shop','hollywatson@hotmail.com','holly watson','67417 Highway 51','fluker','LA','UNITED STATES','70436','(985) 215-9365','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-25 23:05:01',0,NULL,3,1,1,1,'LK203903795CN ','cnfaner\r'),(22457,941212350012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','doerrbd2012','doerrbd@yahoo.com','bryan doerr','5965 haag rd','Lansing','MI','UNITED STATES','48911-4746','(517) 230-6593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 23:09:00',0,NULL,3,1,1,1,'LK204058443CN ','eastar4'),(22458,685690904013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','onamission25','hawksfordja@usa.redcross.org','james hawksford','2482 Windsor Ln','woodbury','MN','UNITED STATES','55125','(651) 245-8770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 23:24:38',0,NULL,3,1,1,1,'LK204053018CN ','eastar4'),(22459,786423056008,180772181803,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'au-buy','stewartverrells','sverrells@ozemail.com.au','stewart Verrells','118 Wyralla Road','Miranda','New South Wales','AUSTRALIA','2228','0295249424','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 23:45:49',0,NULL,3,1,11,1,NULL,'au-buy\rHBPH003'),(22460,941262054012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','ioannis_ed','iegremos@hol.gr','IOANNIS GREMOS','PERIKLEOYS 159','PETROYPOLIS','ATTIKI / AHTENS','GREECE','13231','00302105023092','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 01:18:15',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2013\racer 5pin1.25 15cm '),(22461,625202451003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',3,'HSJA001',71.4,'cnfaner','diggerdude67','prelimo@prelimo.com','CHRIS CURTIS','6538 Highbury Rd','huber heights','OH','UNITED STATES','45424-3017','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-26 01:37:01',0,NULL,3,1,1,1,'LK203950433CN ','cnfaner'),(22462,794870366007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','xebrecito','xebrecito@gmail.com','david mendez lopez','jose maria hernansaez 14 bajo cafe bar carballiño','la coruña','Galicia','SPAIN','15009','647774052','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 03:27:33',0,NULL,3,1,3,1,'RA184509566CN\r ','au-buy\rPSGL001*2'),(22463,685748432013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','abrandt30','bundie30@hotmail.com','Allen Brandt','25745 County Road 129','Roseau','MN','UNITED STATES','56751-8667','(218) 424-7844','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 03:28:13',0,NULL,3,1,1,1,'LK204031057CN ','eastar4'),(22464,786499291008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','peterwilliamburton','peterwburton@gmail.com','Margaret Burton','PO Box 4308','EAST GOSFORD','New South Wales','AUSTRALIA','2250','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'au-buy'),(22465,847909255002,120841235378,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'buysia','riverlime2010','timeismoney2020@hotmail.com','Anil Waithe TT008704','3775 NW 77th St','miami','FL','UNITED STATES','33147-4434','(868) 791-4000','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-26 04:35:05',0,NULL,3,1,1,1,'LK203975700CN ','buysia'),(22466,625236196003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',5.99,'cnfaner','nanasg1','mrmrswhogue@yahoo.com','Walter/Raquel Hogue','820 N 1st Ave<br>Apt 607','pasco','WA','UNITED STATES','99301-5365','(509) 547-8508','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-26 04:43:01',0,NULL,3,1,1,1,'LK203923384CN ','cnfaner'),(22467,941338999012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','etownpumpkin','sandker350@gmail.com','joshua sandker','84 chelsea cir','clementon','NJ','UNITED STATES','08021-4223','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 05:46:10',0,NULL,3,1,1,1,'LK204074070CN ','eastar4\racer 5pin1.25 15cm'),(22468,794907511007,170730545053,'Logitech RF Wireless Extender plus emitter for Harmony 890 Pro 1000 & 1100 remot',1,'RCLO007+POLO001+RCLO008*4',52.99,'au-buy','floppystag','mastersnoopy@hotmail.com','James Smith','3/5 Davo Court<br>Burleigh Gardens','Gold Coast','Queensland','AUSTRALIA','4220','0755934773','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 06:27:18',0,NULL,3,1,3,1,'RA184509376CN\r ','au-buy\rRCLO007+POLO001+RCLO008*4'),(22469,941352089012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','fionap81','fionampratt@yahoo.com.au','fiona pratt','15 ashgate drive','doreen','Victoria','AUSTRALIA','3754','0397174353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 06:47:15',0,NULL,3,1,11,1,NULL,'eastar4\rMOAP001'),(22470,630719865004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','pelvin','jim.pelvin@gmail.com','Jim Pelvin','110 Tilley Drive','Fredericton','NB','CANADA','E3B5L1','(506) 440-8865','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 08:59:27',0,NULL,3,1,3,1,'RA184509637CN\r ','cnfaner\rMOLO001'),(22471,630747101004,140516093345,'New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh',1,'BALO007',11.5,'cnfaner','yehielad1','yehielad@ayehiel.com','yehiel Admoni','shoale Shimshon 2/4','Beit Shemsh','','ISRAEL','99025',' 972776631003','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 10:37:17',0,NULL,3,1,3,1,'RA184525688CN ','cnfaner\rBALO007'),(22472,941433880012,220511922379,'IBM ThinkPad X200 3G GPS WWAN antenna MC8781',1,'ANCN002',17.5,'eastar4','maxmodul','ht@ttronic.de','Heinz Tillack','Herdgasse 25','Burgrieden','','GERMANY','88483','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 10:49:22',0,NULL,3,1,11,1,NULL,'eastar4\rANCN002'),(22473,941439341012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','rucoil','500c500@gmail.com','Timoshenko Ruslan','Jerusalem 74 / apt 11','Bat-Yam','','ISRAEL','59412','0524262157','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 10:58:08',0,NULL,3,1,3,1,'RA184509521CN\r ','eastar4\rHBPH001'),(22474,850453541011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','tvm2007','minhtran@anphucorp.com.vn','Tran Van Minh','Cong Ty Co Phan An Phu<br>Lau 14, Centec Tower, 72-74 Nguyen thi Minh Khai, Q.3','Ho Chi Minh City','','VIET NAM','70000','0903698810','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 11:07:46',0,NULL,3,1,11,1,NULL,'eastar4\rANCN001'),(22475,848040954002,120853616310,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',26.88,'buysia','davidsng','d_sng@hotmail.com','David Sng','Aljunied Crescent ,Blk 108, #10-18','default','','SINGAPORE','380108','98293172','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-26 12:01:45',0,NULL,3,1,11,1,NULL,'buysia\rHSAL001\r美标'),(22476,850516481011,320844153563,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',97.99,'eastar4uk','kevin456tennis','kevin0255@hotmail.com','Kevin Smith','3 Cherry Tree Court','FLEETWOOD','Lancashire','UNITED KINGDOM','FY76BU','01253876441','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 13:19:59',0,NULL,3,1,3,1,'RA184509606CN\r ','eastar4uk\rPSGL001*2'),(22477,848088727002,120856119986,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',147.99,'buysia','tax$$','mike287@cogeco.ca','Michael Kennedy','202- 2055 Appleby Line','Burlington','ON','CANADA','L7L 7H1','(905) 335-8239','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-26 13:45:59',0,NULL,3,1,3,1,' RA184509654CN\r','buysia\rPSGL001*2'),(22478,685913677013,230546640426,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET+car charger',1,'HSNO016+CCNO001',15.49,'eastar4','tamo3103','a-s-hakim@gmx.de','Ahmad Shah Hakim','Karl-Marx-Ring 24','München','','GERMANY','81735','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 14:34:38',0,NULL,3,1,11,1,' ','eastar4\rHSNO016+CCNO001'),(22479,685930880013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','philtyrrell','gig1969@amnet.net.au','Phil Tyrrell','61 Mississippi Drive','Mandurah','Western Australia','AUSTRALIA','6210','0895349661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 15:17:05',0,NULL,3,1,3,1,'RA184507049CN\r ','eastar4\rGLOT001*2'),(22480,630844249004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',50.99,'cnfaner','carlosmarcelomarcelo','cmcf@uol.com.br','carlos marcelo cardoso fernandes','SQS 313 Bloco J Ap. 501','brasilia','distrito federal','BRAZIL','70382100','055 6199599818','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 15:24:41',0,NULL,3,1,3,1,'RA184509518CN\r','cnfaner\rLGFI001'),(22481,630856328004,140516085214,'New Logitech Harmony 628 Universal Remote Control',1,'RCLO006',45.99,'cnfaner','jburdzy','jburdzy@sympatico.ca','Jeff Burdzy','2152-25 Viking Lane','Toronto','ON','CANADA','M9B0A1','(647) 273-8989','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 15:49:06',0,NULL,3,1,3,1,'RA184509552CN\r ','cnfaner\rRCLO006'),(22482,941615725012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Kerrie Gottschalk','10700 Walrond Ave','Kansas City','MO','UNITED STATES','64137-1757','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 16:06:38',0,NULL,3,1,1,1,'LK203999286CN ','eastar4'),(22483,850634515011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','george-1958','george1958@poczta.fm','Marcin Kleszczewski','2 Patch Place<br>Milford Road','Yeovil','Somerset','UNITED KINGDOM','BA21 4QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 16:29:45',0,NULL,3,1,3,1,'RA184509380CN\r ','eastar4uk\rGLOT001'),(22484,941652882012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','rotorswa','carolpb@msn.com','Carol Brown','1553 Hawthorne Ln','Glenview','IL','UNITED STATES','60025-2260','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 16:51:57',0,NULL,3,1,1,1,'LK204042001CN ','eastar4'),(22485,786820526008,180821253462,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card+Tyco 2.4/5.0 GHz Antenna*3',1,'WLIN010+ANTY002',18.99,'au-buy','josebalta72','josebalta@netscape.net','Jose Caballero','9651 Janet Rose CT','Manassas','VA','UNITED STATES','20111-2537','(703) 969-3098','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 17:30:31',0,NULL,3,1,1,1,'LK203974341CN ','au-buy'),(22486,786831546008,180757094449,'Original New Replaceable Shell for logitech MX Air Mouse',1,'SHLO001',14.99,'au-buy','h4rdtr4nce','christoph.jensky@gmail.com','Christoph Jensky','Römlingweg 14','Essen','','GERMANY','45277','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 17:44:29',0,NULL,3,1,11,1,NULL,'au-buy\rSHLO001\r'),(22487,848251660002,120865585703,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',5,'GPS0010+ADPT001',189.95,'buysia','municipaltruck','ebay@municipaltrucks.com','Rogelio Gonzalez','PO Box 86<br>1120 East Produce RD','Hidalgo','TX','UNITED STATES','78557-0086','(956) 843-9661','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-26 18:00:16',0,NULL,3,1,4,1,'YW867611092CN ','buysia\rGPS0010+ADPT001'),(22488,686083137013,230720748676,'Apple PowerBook G4 G5 AirPort Extreme WiFi Card A1026',21,'WLAP002',419.58,'eastar4','camille92150','camille92@noos.fr','Gauthier Eric','10 avenue Alexandre Maistrasse','suresnes','Ile-de-France','FRANCE','92150','01 73 64 23 33','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 19:18:13',0,NULL,3,1,4,1,'YW867611125CN ','eastar4'),(22489,941831673012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',12.99,'eastar4uk','elapse0030','ellapse@gmail.com','PANAGIOTIS PULOPULOS','MANDILARA 9','PREVEZA','PREVEZA','GREECE','48100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 19:33:47',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLAP008'),(22490,625563733003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','thelambdidit2','theliondidit2@verizon.net','Frank Barreiro','5301 Pilots Pl','New Port Richey','FL','UNITED STATES','34652-3060','(727) 849-2341','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-26 19:49:55',0,NULL,3,1,1,1,'LK203904164CN ','cnfaner'),(22491,941877905012,220886923853,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',15.95,'eastar4uk','bernardat','bernard.timings@btinternet.com','C Gaultier','5 Church Hill<br>Stretton on Dunsmore','Rugby','Warwickshire','UNITED KINGDOM','CV23 9NA','07976818936','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 20:18:01',0,NULL,3,1,3,1,'RA184507004CN\r ','eastar4uk\rUM00010\r象牙色的'),(22492,941903649012,220901465642,'Original Apple AirPort Extreme WiFi Card 54M',26,'WLAP002',337.74,'eastar4uk','camille92150','camille92@noos.fr','Gauthier Eric','10 avenue Alexandre Maistrasse','suresnes','Ile-de-France','FRANCE','92150','01 73 64 23 33','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 20:47:42',0,NULL,3,1,4,1,'YW867611125CN ','eastar4uk\rWLAP002'),(22493,686142877013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',2,'HSNO019',75.96,'eastar4','nerminarnautovic','azra_nermin@live.se','Nermin Arnautovic','MANGÅRDSGATAN 14','Gislaved','SWEDEN','SWEDEN','33235','+46708282339','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 20:49:53',0,NULL,3,1,3,1,'RA184507123CN\r ','eastar4\rHSNO019\r欧标'),(22494,787051808008,180730201427,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',46.99,'au-buy','sheonac','clive_colloff@hotmail.com','Sheona Colloff','25 High Street, West End','Woking','Surrey','UNITED KINGDOM','GU24 9PL','01276485762','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 21:56:51',0,NULL,3,1,3,1,'RA184509478CN\r ','au-buy\rHBPH007'),(22495,941975316012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','damir.zg','damirzg@gmail.com','Damir Kuleš (Antun Kuleš)','Podvršje 2','Zagreb','Zagreb','CROATIA','10000','+385 98 9217828','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 22:17:05',0,NULL,3,1,11,1,NULL,'eastar4uk\rSCLO002'),(22496,850980091011,320773536297,'Original Lowrance iFinder PhD GPS+WAAS handheld GPS Receiver',1,'GPS0005',55.99,'eastar4uk','numscull123','daveshe47@hotmail.com','DAVID BULLOCK','1 FORDBRIDGE LANE<br>SOUTH NORMANTON','ALFRETON','Derbyshire','UNITED KINGDOM','DE55 2DP','07869123230','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 23:09:58',0,NULL,3,1,3,1,'RA184507225CN\r ','eastar4uk\rGPS0005'),(22497,850993041011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','cfox6107','capt1eye@hotmail.com','craig fox','8411 belmont valley st','las vegas','NV','UNITED STATES','89123','(702) 375-1432','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 23:38:57',0,NULL,3,1,1,1,'LK204012720CN ','eastar4'),(22498,787110845008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','chrisp8551',' cpickles@eastlink.ca','Chris Pickles','208 Charlotte St.<br>David Butts Realty','Sydney','NS','CANADA','B1P 1C5','(902) 565-7426','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 00:06:35',0,NULL,3,1,3,1,'RA184507021CN\r ','au-buy\rLGAD001'),(22499,803979735001,110827288137,'New Logitech Cradle L-LG7 for Harmony remote 880 890 + US AC adapter',1,'CRLO001+POLO001',16.99,'buysia','xenolyte515','vijay.verma@live.com','Vijay Verma','4 knightswood Cres','brampton','ON','CANADA','l7a3r1','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-27 01:01:19',0,NULL,3,1,11,1,' ','buysia\rCRLO001+POLO001'),(22500,625696778003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','serge_k001','serge.kholodar@gmail.com','Serge Kholodar','535 The East Mail apr 418','Toronto','ON','CANADA','M9B 4A4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 01:25:25',0,NULL,3,1,3,1,'RA184507106CN\r ','cnfaner\rSHLO009\r'),(22501,8881330307827130,111,'Mini Spy Vehicle Realtime Tracker For GSM/GPRS/GPS System Tracking Device TK102',2,'GPS0006',117.98,'cnfaner','janie262012','janie.analise@yahoo.com','janie figueroa','240 173rd st','hammond','IN','UNITED STATES','46324-2510','',NULL,NULL,NULL,'2012-02-27 01:57:07',0,NULL,3,1,1,1,'LK203934245CN ','做的单子 '),(22524,942237283012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','ianw2617','gillwalton@virginbroadband.com.au','Ian Walton','5 Donna Close<br>Dingley','Melbourne','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 10:57:28',0,NULL,3,1,3,1,'RA184506499CN\r ','eastar4\rPSGL001'),(22502,851049639011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','stasney3092','stasneydane@tds.net','Jeffrey Stasney','214 Statz Ln','Dane','WI','UNITED STATES','53529-9608','(608) 850-3078','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 01:59:22',0,NULL,3,1,1,1,'LK204040442CN ','eastar4'),(22503,8881330308376871,111,'Free shipping - 4 pair of New Genuine for Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) - ',1,'PSGL001*4',287.99,'aliexpress','1006978242','psb164@mail.ru','Postanogov Sergey','Fedorovskaya 1 ap. 316 ','Saratov','Saratov','RUSSIAN FEDERATION','410018','+7 - 9063124044',NULL,NULL,NULL,'2012-02-27 02:06:16',0,NULL,3,1,3,1,'RA184507110CN\r ','PSGL001*4 '),(22504,787157348008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','czachman','paul_zachariasz@excite.com','Paul Zachariasz','1754 Rosslyn Rd.','Thunder Bay','ON','CANADA','P7K 1J3','(807) 577-4919','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 02:11:01',0,NULL,3,1,3,1,'RA184507239CN\r ','au-buy\rLGAD001'),(22505,804007001001,110819086559,'Brand New Logitech Rechargeable Li-Ion Battery L-LB2 1700mAh for Logitech MX1000',1,'BALO007',11.6,'buysia','jwhite00-half','w.jason.white@fuse.net','William White','6229 Fairwind Dr','West Chester','OH','UNITED STATES','45069-1380','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-27 02:11:23',0,NULL,3,1,1,1,'LK211087621CN\r ','buysia'),(22506,8881330308760624,111,'Free shipping & Tracking # - New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 - ',1,'GPS0010',32.99,'aliexpress','1006990309 ','gtani@tin.it','guido tani','piazza virgilio 4 20123','milan','italy','ITALY','20123','+0039 393 9115997',NULL,NULL,NULL,'2012-02-27 02:12:40',0,NULL,3,1,3,1,'RA184506295CN\r ','GPS0010 '),(22507,625712198003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','1ncomputers','carlosv707@yahoo.com','juan  vega','970 Keegan Dr','santa rosa','CA','UNITED STATES','95407-6783','(707) 623-4557','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 02:22:18',0,NULL,3,1,1,1,'LK211096699CN\r ','cnfaner'),(22508,847750064011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','davepatel007','dave007007@gmail.com','dave patel','1615 s roane st','harriman','TN','UNITED STATES','37748-7540','(631) 219-3584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 02:23:32',0,NULL,3,1,1,1,'LK204094627CN ','eastar4'),(22509,686271780013,230729621562,'Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n  BlueToo',1,'ANTY002',6.99,'eastar4','robinsoc76','robinsoc@rogers.com','Cliff Robinson','1560 Roger Stevens Dr<br>PO Box 113','Kars','ON','CANADA','K0A 2E0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 02:45:35',0,NULL,3,1,11,1,NULL,'eastar4\rANTY002'),(22510,942103984012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','anugangotra2012','anugangotra@gmail.com','ANU GANGOTRA','14 AVALANCHE CRES.','BRAMPTON','ON','CANADA','L6P1M4','(905) 794-9777','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 02:51:20',0,NULL,3,1,11,1,' ','eastar4\rHSNO005'),(22511,942106326012,220877931254,'New HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',19.99,'eastar4','joes-beanfield','kecarmi@yahoo.com','Kevin Carmichael','4850 Berkeley Walk Pt','Berkeley Lake','GA','UNITED STATES','30096-6193','(770) 729-6254','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 02:54:28',0,NULL,3,1,1,1,'LK204080937CN ','eastar4'),(22512,851081143011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','speedya1','petearis@sbcglobal.net','William Peter Aris','2925 Hunters Place','Kalamazoo','MI','UNITED STATES','49048','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 03:16:41',0,NULL,3,1,1,1,'LK204288353CN ','eastar4'),(22513,942133515012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','jamelgar1','jmelgar1@gmail.com','Jorge Melgar','1805 S 23rd St','Rogers','AR','UNITED STATES','72758-5640','(479) 721-5021','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 04:08:12',0,NULL,3,1,1,1,'LK210970610CN ','eastar4'),(22514,8881330316667967,111,'New-Fashion-Full-Transparent-dome-J-handle-Manual-Opening-Sun-Umbrella-',1,'UM00053',19.99,'aliexpress','1007007658','kimberley.lay@laybrothers.com.au','Kimberley Lay','Lay Brothers Pty Ltd 23-29 David Street<br>+61 03 97916399','Dandenong','Victoria','AUSTRALIA','3175','61411700388',NULL,NULL,NULL,'2012-02-27 04:24:27',0,NULL,3,1,3,1,'RA184507168CN\r ','UM00053 '),(22515,942138669012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','leeddabong','xxheexx@gmail.com','MI HEE LEE','39-601 1F, Yongdu-dong, Dongdaemun-gu','Seoul','Seoul','KOREA,REPUBLIC OF','130-817',' 821071157095','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 04:25:22',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT007'),(22516,851107349011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','nguyen.tuan','tuannquoc@gmail.com','Nguyen Quoc Tuan (0908222187)','8th Floor, Itaxa Building, 126 Nguyen Thi Minh Khai Str., Ward 6, District 3rd<br>B7 Nguyen Oanh Str., Ward 17th, Go Vap Dist,','Ho Chi Minh City','','VIET NAM','70000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 04:58:08',0,NULL,3,1,3,1,'RA184507256CN\r ','eastar4\rLGRM001'),(22517,631211076004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','antbison','antbison@yahoo.com','Mark Arjoon','26202 Valley Point Ln','newhall','CA','UNITED STATES','91321-2238','(661) 312-1776','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 06:30:55',0,NULL,3,1,1,1,'LK211106113CN ','cnfaner'),(22518,942171688012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','waglagon11','bubbagervais@hotmail.com','Steven Gervais','box 486','Lumby','BC','CANADA','V0E2G0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 06:52:10',0,NULL,3,1,11,1,'BJ01714248\r ','eastar4\rUM00008'),(22519,851131516011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','handtcellular','handtcellular@bellsouth.net','LARRY HELMS','2801 Mall Dr<br>Ste 16','FLORENCE','AL','UNITED STATES','35630-1526','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 06:44:20',0,NULL,3,1,1,1,'LK211200578CN ','eastar4'),(22520,942181422012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',3,'ANTY001',17.97,'eastar4','dec302003','albeert0@yahoo.com','Albert Choi','1185 Bennett Ct','Fremont','CA','UNITED STATES','94536-4030','(510) 910-1948','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 07:32:32',0,NULL,3,1,1,1,'LK211191385CN ','eastar4'),(22521,8881330330426486,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Natalie Martinez','749 Gresham Ave SE','Atlanta','GA','UNITED STATES','30316-3838','(503) 722-4468',NULL,NULL,NULL,'2012-02-27 08:13:46',0,NULL,3,1,1,1,'LK191139203CN ','补发的 \r改个地址'),(22522,8881330331334461,111,'接边蕾丝透明伞',1,'UM00042',0,'eastar4','tommyds23','tommyds23@hotmail.com','Tomorrow Smith','222 Ridge Dr','Manhattan','KS','UNITED STATES','66502-3827','(785) 410-3044',NULL,NULL,NULL,'2012-02-27 08:28:54',0,NULL,3,1,1,1,'LK179042104CN','补发的  改个地址 '),(22523,625788544003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.89,'cnfaner','efvitaly','coinsholder@gmail.com','Vitaly Efimovsky','Tsentralnaya 30-100','Troitsk','Moskovskaya oblast','RUSSIAN FEDERATION','142190','+79161831805','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:39:30',0,NULL,3,1,3,1,'RA184506264CN\r ','cnfaner\rWLIN013'),(22525,804145755001,110832702509,'2 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*2',197.99,'buysia','coopersilia','csd@list.ru','Atachkin Ilia','Gagarina 85-225','Zhukovskiy','Moskow Region','RUSSIAN FEDERATION','140182','+79197646975','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-27 11:30:11',0,NULL,3,1,3,1,'RA184506216CN\r ','buysia\rGLSG008*2'),(22526,686373282013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','jfortunatojohn','jefortunato@hotmail.com','JOHN E. FORTUNATO','2050 CESSNA DR<br>OneNumber - JF50025','VACAVILLE','CA','UNITED STATES','95688-8712','915 588 6842','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 11:33:53',0,NULL,3,1,1,1,'LK212318065CN\r ','eastar4\r新地址\rJOHN E. FORTUNATO\rPSC 561 Box 1403, FPO AP 96310-0015 \rUNITED STATES\r915 588 6842'),(22527,795716886007,170775726989,'New HP MCE Media Center + Sony Remote Control RM-MCE20E White+IR Emitter Wire',1,'RMSN002',19.99,'au-buy','watashiki','becky.harvey@gmail.com','Rebecca Harvey','55 Bishop Manor Road<br>Westbury-On-Trym','BRISTOL','Bristol','UNITED KINGDOM','BS10 5BB','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 12:19:56',0,NULL,3,1,11,1,'BJ01714258\r ','au-buy\rRMSN002'),(22528,851231911011,320826634815,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',12.99,'eastar4uk','deliciousmcgoodness','deliciousgoodness@dsl.pipex.com','K A Holdbrook-Smith','24 Church Road','Frimley','Surrey','UNITED KINGDOM','GU16 7AE','07967319376','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 12:54:25',0,NULL,3,1,3,1,'RA184504864CN\r ','eastar4uk\rHBPH009'),(22529,686391839013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','giancarloghirotti','gian91195380@hotmail.com','Giancarlo Ghirotti','Rua Professor Diomedes, 764 - São Vicente<br>Policia Rodoviaria Federal','Boa Vista','Roraima','BRAZIL','69303-450','95 91195380','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 12:56:10',0,NULL,3,1,3,1,'RA184506349CN\r ','eastar4\rLGAD001'),(22530,851234310011,320826743842,'New in box GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'eastar4','pass*will','mjth@amug.org','Michael J Helminiak','4502 N 31st Pl','Phoenix','AZ','UNITED STATES','85016-5017','(602) 955-2534','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 12:58:35',0,NULL,3,1,1,1,'LK211546163CN\r ','eastar4'),(22531,942282206012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','thelordsbaby','prince3000@live.com','Omar Pineda','11980 SW 217th St','GOULDS','FL','UNITED STATES','33170-2827','(786) 397-3702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 13:07:22',0,NULL,3,1,1,1,'LK211546279CN\r ','eastar4'),(22532,625831927003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','droopy3333','avokoulouyan@hotmail.com','avedis koulouyan','2 avenue louis breguet','velizy','Île-de-France','FRANCE','78140','06.12.72.25.99','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 13:12:40',0,NULL,3,1,3,1,'RA184506370CN\r ','cnfaner\rHSJA012\r欧标\rsilver'),(22533,942293795012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','sonnenblume.0209','gisela-gorka@gelsennet.de','gisela lyssy','horsterstrasse 247','gelsenkirchen','','GERMANY','45899','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 13:37:30',0,NULL,3,1,11,1,'BJ01714263\r ','eastar4\rBTAC2012\racer 5pin1.25 6cm   '),(22534,851260253011,320786773805,'New Jabra JX10 Series II 2 Wireless Bluetooth headset Red',1,'HSJA013',12.99,'eastar4uk','diasmi*designs','diane1234@blueyonder.co.uk','Diane Smith','New North Academy<br>32 Popham Road','Islington','London','UNITED KINGDOM','N1 8SJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 14:11:11',0,NULL,3,1,3,1,'RA184506508CN\r ','eastar4uk\rHSJA013\r英标\r红色的'),(22535,625849716003,130626860613,'New Germany Grohe hand Shower Head+Grohe hose+holder',1,'OTGR001+OTGR002+OTGR003',54.9,'cnfaner','sl500guy','rgoble1384@aol.com','R Goble','9341 Tartan View Dr','Fairfax','VA','UNITED STATES','22032-1207','(703) 298-3374','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 14:24:27',0,NULL,3,1,1,1,'LK211495824CN\r ','cnfaner'),(22536,625858681003,130653453709,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',37.9,'cnfaner','bulticos','marcos6l6@uol.com.br','marcos eduardo goncalves','RUA PARANAPIACABA, 132 AP4<br>VILA PIRES','SANTO ANDRE','São Paulo','BRAZIL','09195-660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 14:59:19',0,NULL,3,1,3,1,'RA184506335CN\r ','cnfaner\rGPS0010+ADPT001'),(22537,849658691011,320826743842,'New in box GSM Classic Mobile Cellular Retro Vintage Brick Phone',1,'OTPH003',119.99,'eastar4','negativeg','bondbuyer@yahoo.com','George Schoenstein','202 Brighton Cir','Devon','PA','UNITED STATES','19333-1041','(610) 240-9861','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-27 15:13:12',0,NULL,3,1,1,1,'LK211531098CN\r ','eastar4'),(22538,941217244012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','r1964oleg','r1964@gala.net','OLEG RUSAKOV','SVETLANOVSKI<br>62-1-367','S PETERBURG','s peterburg','RUSSIAN FEDERATION','195269','89052506990','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 15:43:00',0,NULL,3,1,11,1,'BJ01714251\r ','eastar4\rBTAC2015\racer 6pin1.25 23cm'),(22539,848846766002,120856120086,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'buysia','cfranco09','franzx14@comcast.net','carlos franco','8 Heritage Rd','Dracut','MA','UNITED STATES','01826-4300','(978) 957-2609','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-27 17:26:30',0,NULL,3,1,1,1,'LK211531067CN\r ','buysia'),(22540,851348351011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',2,'HSUE003',42.7,'eastar4','a0mzsiriwan','aigojung@hotmail.com','DBT Air-NatAom','2589 Quality Ct<br>Ste 304','Virginia Beach','VA','UNITED STATES','23454-5324','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-27 17:32:15',0,NULL,3,1,1,1,'LK211527703CN\r ','eastar4'),(22541,942443203012,220946749706,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','pedrograma','pedro.grama@hotmail.com','pedro grama','rua dos lapidários lt 13','marinha grande','leiria','PORTUGAL','2430-101',' 964557019','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 18:32:05',0,NULL,3,1,11,1,'BJ01714255\r ','eastar4\rGPS0010'),(22542,848895548002,120841235378,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'buysia','eorione','enrique@orione.com.ar','Bernardo German Hussing','201 CRANDON BLVD<br>TIDEMARK B. APT 1236','KEY BISCAYNE','FL','UNITED STATES','33149-1575','(786) 362-5342','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-27 18:41:01',0,NULL,3,1,1,1,'LK211505288CN\r ','buysia'),(22543,804321419001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','henrywiebe','henry.wiebe@yahoo.com','Henry Wiebe','Box 1828','La Crete','AB','CANADA','T0H2H0','(780) 841-1860','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-02-27 18:42:44',0,NULL,3,1,3,1,'RA184506423CN\r ','buysia\rGPS0006'),(22544,942466034012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4uk','ian_net','ian.on.the.net@ntlworld.com','Ian Charles Gilbert','18 Luke Street','Eynesbury , St. Neots','Cambridgeshire','UNITED KINGDOM','PE19 2TP','01480350918','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 19:06:08',0,NULL,3,1,3,1,'RA184506352CN\r ','eastar4uk\rOTCN003'),(22545,942473777012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.95,'eastar4uk','nataljagriscenko','natalja.griscenko@gmail.com','Natalja Griscenko','57 Century Avenue<br>Oldbrook','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK6 2UL','4477192702','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 19:15:44',0,NULL,3,1,3,1,'RA184506366CN\r ','eastar4uk\rUM00043'),(22546,686521437013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','lishettetia','drunkbangsmoke@hotmail.com','Lishette Hogg','1051 High street','Reservoir','Victoria','AUSTRALIA','3073','0424530630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 19:16:54',0,NULL,3,1,11,1,'BJ01714260\r ','eastar4\rUM00042'),(22547,625959452003,130458358340,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET track#',2,'HSNO008',27.76,'cnfaner','fcopier','frank.copier@gmail.com','Frank Copier','Esther de Boer v Rijkln 16','BUSSUM','','NETHERLANDS','1403GD','035-6913363','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 19:43:59',0,NULL,3,1,3,1,'RA184506397CN\r ','cnfaner\rHSNO008\r欧标'),(22548,631422692004,140626375035,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',14.1,'cnfaner','mandich2011','mandichortho@gmail.com','Marie-Alice Mandich','901-9940 112 St NW','Edmonton','AB','CANADA','T5K1L8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 20:01:46',0,NULL,3,1,3,1,'RA184506321CN\r ','cnfaner\rOTCN005'),(22549,787535851008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',1,'BALO009',7.99,'au-buy','mr-who.7711','mrwho@mrwho.ru','Alexander Kazantsev','Jitnaya street 10 - 91','Moscow','','RUSSIAN FEDERATION','119049','+79266987711','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 20:23:32',0,NULL,3,1,11,1,'BJ01714261\r ','au-buy\rBALO009'),(22550,851490880011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','956koen','vdhkoen@hotmail.com','Koen Vanderhaegen','Kasteellaan 349 (zwarte deur)','Gent','','BELGIUM','9000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 21:13:19',0,NULL,3,1,11,1,'BJ01714253\r ','eastar4uk\rMOAP001'),(22551,851515191011,320801186995,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',13.95,'eastar4uk','266374266374','vellakim96@hotmail.com','pauline vella','Scorgem house<br>Triq ix-Xghir','zebbug','malta','MALTA','zbg 05','0035627461771','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 21:56:51',0,NULL,3,1,11,1,'BJ01714256\r ','eastar4uk\rUM00040'),(22552,631478534004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','sommerherbst04','jens1@fantasymail.de','Jens Czura','Bahnhofstr. 7','Ortrand','','GERMANY','01990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:23:05',0,NULL,3,1,3,1,'RA184506406CN\r ','cnfaner\rHSJA011\r欧标'),(22553,942603272012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','leandromdsilva','leandromacieldasilva@gmail.com','Felipe da Silva Ribeiro','Av do Expedicionários, n° 125 apto 603, Ed. Marville B','Vitória','Espírito Santo','BRAZIL','29090-490','552798508805','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:36:35',0,NULL,3,1,11,1,'BJ01714250\r ','eastar4\rMOMI002'),(22554,631483973004,140584764543,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',22.99,'cnfaner','wahlsv1','wahlsv@hotmail.com','Svein Olav Wahlberg','Alfred Tronsdal vei 18','Trondheim','Sor Trondelag','NORWAY','7033','73933127','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:39:12',0,NULL,3,1,3,1,'RA184506437CN\r ','cnfaner\rOTTP001'),(22555,787614607008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','bluerider1983','chmeyer83@googlemail.com','Christian Meyer','Elly-Heuss-Knapp-Straße 4','Stuhr-Brinkum','','GERMANY','28816','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 22:57:32',0,NULL,3,1,3,1,'RA184506281CN\r ','au-buy\rLGAD001'),(22556,787623818008,180762062511,'New lady lotus leaves outdoor sun/rain stick Umbrella   6 colors available',1,'UM00002',24.99,'au-buy','merce0000','anthony.mercer@police.vic.gov.au','Anthony MERCER','Unit 1 / 108 Warrandyte Road','Ringwood','Victoria','AUSTRALIA','3134','0433314306','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-27 23:21:44',0,NULL,3,1,11,1,'BJ01713652\r ','au-buy\rUM00002\r紫色的\r'),(22557,942636484012,220946749706,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','akafadam','vjekov@net.hr','Vjekoslav Vurnek','Krčelićeva 10','Zagreb','Zagreb','CROATIA','10000','00385922987287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 23:56:36',0,NULL,3,1,11,1,'BJ01714252\r ','eastar4\rGPS0010'),(22558,942625972012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',17.5,'eastar4','sanchofromrancho','alexirius@gmail.com','Alexander Ezhov','ulitsa Teplyj Stan, dom 9, korpus 7, kv. 27','Moscow','Moscow','RUSSIAN FEDERATION','117465','+79031128726','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 23:29:16',0,NULL,3,1,11,1,'BJ01714254\r ','eastar4\rWLHP002'),(22559,686635903013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','shanina2007','jahevius@hotmail.com','shany mcguire','207 stuart street','indianola','MS','UNITED STATES','38751','(662) 303-5704','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 00:23:15',0,NULL,3,1,1,1,'LK211537422CN\r ','eastar4'),(22560,851577079011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',26.99,'eastar4uk','jt9763','vhappy888@gmail.com','Jin Teh','15 Kent St','Knoxfield','Victoria','AUSTRALIA','3180','0387190004','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 00:35:36',0,NULL,3,1,3,1,'RA184506454CN\r ','eastar4uk\rGLOT001'),(22561,851605455011,320773581988,'4 pairs 3D Active shutter Glasses for Sony TDG-BR250',1,'GLOT001*4',103.99,'eastar4uk','gixxer_400','gixxer_400@hotmail.com','Matt Pincott','14 Four Acres','Stevenage','herts','UNITED KINGDOM','sg1 3pj','01438214264','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 02:04:54',0,NULL,3,1,3,1,' RA184506318CN\r','eastar4uk\rGLOT001*4'),(22562,8881330395046097,111,'Brand New AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',46,'aliexpress','Anton Kondrashin','scorpion_ant@mail.ru','Evgeny Kondrashin','st. Sovetskaya, 8 - 45',' Lytkarino','Moscow Region','RUSSIAN FEDERATION','140080','+7 926 224 61 52',NULL,NULL,NULL,'2012-02-28 02:10:46',0,NULL,3,1,3,1,'RA184506278CN\r ','LGAD001 \r通过paypal付的款'),(22563,942717111012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','goldruppet','pmgoldrup@3web.com','Peter Goldrup','Box 81','Water Valley','AB','CANADA','T0M 2E0','(403) 637-0029','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 03:57:39',0,NULL,3,1,3,1,'RA184506445CN\r ','eastar4\rHBPH007'),(22564,942731007012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','mhhersch','matthew.hersch@gmail.com','Matthew Hersch','222 W Rittenhouse Sq<br>Apt 604','Philadelphia','PA','UNITED STATES','19103-5701','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 04:42:47',0,NULL,3,1,1,1,'LK211861528CN\r ','eastar4'),(22565,686698525013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',88.99,'eastar4','pleineimage','contact@pleine-image.com','PLEINE IMAGE - Eric MICHEL','Z.A. de Vilsain','CHATEAUDUN','Centre','FRANCE','28200','0237983841','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 04:52:41',0,NULL,3,1,3,1,'RA184506410CN\r ','eastar4'),(22566,942445310012,220961399509,'New HDD Hard Drive Caddy SATA SATA2 for Apple MacBook /MacBook Pro (Special hole',1,'CACN005',21.99,'eastar4','mbrown22006','mbrown2@gmail.com','Michael Brown','514 Walter st se','Albuquerque','NM','UNITED STATES','87102-3948','(505) 359-0666','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 05:13:07',0,NULL,3,1,1,1,'LK211824366CN\r ','eastar4'),(22567,631572273004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'cnfaner','koffeelady09','koffeelady@comcast.net','Barbara Spelzini','320 Marie Dr','Charles Town','WV','UNITED STATES','25414-5875','(304) 813-4383','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-28 05:16:29',0,NULL,3,1,1,1,'LK211874637CN\r ','cnfaner'),(22568,631572710004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',18.9,'cnfaner','frankyanime123','franky_pak@yahoo.com','Franky Pak','421 W Wells St','San Gabriel','CA','UNITED STATES','91776-3230','(626) 695-8830','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-28 05:19:04',0,NULL,3,1,1,1,'LK211826490CN\r ','cnfaner'),(22569,796138176007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','maxisshoping','warren.pope@bigpond.com','Maxine Pope','1/34<br>Leanyer Drive','Leanyer','Northern Territory','AUSTRALIA','0812','0889271414','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 05:38:09',0,NULL,3,1,11,1,'BJ01714257\r ','au-buy\rRELO002'),(22570,942772131012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',111.96,'eastar4','youtube12345','1a1z2s2x@gmail.com','Kimsey Pollard','791 Atlantic Drive<br>Georgia Institute of Technology','Atlanta','GA','UNITED STATES','30332-0001','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 07:49:14',0,NULL,3,1,1,1,'LK212317079CN\r ','eastar4'),(22571,851687802011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',36.99,'eastar4','hipermedia','hipermedia.split@gmail.com','Boris Ostojic','Kukuljeviceva 22','Split','SD','CROATIA','21000','+38598490509','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 07:53:31',0,NULL,3,1,11,1,'BJ01714262\r ','eastar4\rWWSI004'),(22572,942780827012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','older_s','ignat_s@yahoo.com','Valery Ihnatsyeu','Rokossovsky ave. 18/1-157','Minsk','','BELARUS','220094','29-6680346','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:25:27',0,NULL,3,1,11,1,'BJ01714259\r ','eastar4\rHSNO005\r欧标\r只发耳机   客户不要电源了'),(22573,851701196011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','simonlimsg','simlim@gmail.com','Lim Chong Seng','Blk 608 Clementi West St 1<br>#08-84','default','','SINGAPORE','120608','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 08:45:54',0,NULL,3,1,3,1,'RA184506304CN\r ','eastar4uk\rLGAD001'),(22574,942787413012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','ecskev','kevinmesnard@hotmail.com','Kevin Mesnard','21 Cromwell Avenue','Billericay','Essex','UNITED KINGDOM','CM12 0AE','07775811549','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 08:47:41',0,NULL,3,1,3,1,'RA184506383CN\r ','eastar4uk\rOTCN004*10'),(22575,942806267012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','James Lee','1300 64TH ST','EMERYVILLE','CA','UNITED STATES','94608-1107','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 09:56:28',0,NULL,3,1,1,1,'LK212278106CN\r ','eastar4'),(22576,686750064013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','pritchbj','bjpritch@hotmail.com','Benjamin Pritchard','92 Huon Creek Road','Wodonga, Vic','Victoria','AUSTRALIA','3690','0400805874','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 10:12:32',0,NULL,3,1,11,1,'BJ01713692\r ','eastar4\rUM00042'),(22577,938970868012,220816379674,'3 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2200AR',1,'GLOT001*3',78.99,'eastar4uk','alexferg75','jendud_85@hotmail.co.uk','Jen Duddle','12 devon road<br>hensingham','whitehaven','Cumbria','UNITED KINGDOM','ca28 8pj','01946599100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 10:12:37',0,NULL,5,0,18,0,NULL,'eastar4uk\r不兼容客户的电视  需要退款撤单'),(22578,938976832012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',13.98,'eastar4uk','christian-martin2012','christian.calderas77@gmail.com','Christian Calderon','310 queens road<br>basement flat','London','London','UNITED KINGDOM','se14 5jn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 10:12:43',0,NULL,3,1,3,1,'RA184506613CN\r ','eastar4uk\rOTHP004'),(22579,942810976012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Ann Grae Martin','1905 NUECES ST<br>APT 412','AUSTIN','TX','UNITED STATES','78705-5587','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 10:13:52',0,NULL,3,1,1,1,'LK212315413CN\r ','eastar4'),(22580,686770201013,230751520347,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',37.99,'eastar4','lecyberbob','ebay@cyberbob.ch','BAza Jose-Antonio','25bis rue Pestalozzi','Geneve','CH','SWITZERLAND','1202','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 11:50:19',0,NULL,3,1,12,1,'3126012304','eastar4\rGPS0010+ADPT001\r欧标\r客户打运费了'),(22581,787821023008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','azrac','thomas.chappell@uqconnect.edu.au','Tom Chappell','164 Evelyn St','Grange','Queensland','AUSTRALIA','4051','0738564258','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 12:03:11',0,NULL,3,1,11,1,'BJ01713686\r ','au-buy\rMOMI002'),(22582,796234598007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',2,'OTGR001',41.8,'au-buy','dhongtw','dhong5@gmail.com','Darren Hong','161 Bridge Road','Glebe','New South Wales','AUSTRALIA','2037','0412446999','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 12:11:24',0,NULL,3,1,17,0,NULL,'au-buy'),(22583,787824260008,180781265388,'New Grohe handheld Shower Head big water output w/Massage function',1,'OTGR005',22.9,'au-buy','dhongtw','dhong5@gmail.com','Darren Hong','161 Bridge Road','Glebe','New South Wales','AUSTRALIA','2037','0412446999','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 12:13:10',0,NULL,3,1,3,1,'RA184506556CN\r ','au-buy\rOTGR005\rNew Grohe Multi Function hand Shower Head has Seven pattens no water pipe\rOTGR001 \r2个'),(22584,787827926008,180827119114,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',8.99,'au-buy','flourpowerpunk','slj.spurs@talk21.com','Simon James','Kenilworth<br>15 Marine Road','Barmouth','Gwynedd','UNITED KINGDOM','LL42 1NW','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-28 12:27:00',0,NULL,3,1,11,1,'BJ01713653\r ','au-buy\rRCHP001'),(22585,851766557011,320786774053,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',4,'CC00002',91.96,'eastar4uk','renato.ghiro','renato.ghiro2008@gmail.com','Renato Ghiro','Rua Doutor Antônio Jorge Franco, 115 apartamento 122','São Bernardo do Campo','SP / São Paulo','BRAZIL','09810-050','(+5511) 72587757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 12:33:13',0,NULL,3,1,3,1,'RA184506675CN\r ','eastar4uk\rCC00002'),(22586,851780406011,320730087234,'New IBM/ThinkPad Mini PCI Atheros 5213A AR5BMB CARD',1,'WLAT006',7.49,'eastar4uk','johnw9514','johnfwhite@wanadoo.fr','John White','35 Woodlands Road','Altrincham','Cheshire','UNITED KINGDOM','WA15 8EZ','01619268817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 13:13:18',0,NULL,3,1,3,1,'RA184506600CN\r ','eastar4uk\rWLAT006'),(22587,796236682007,170784463759,'NIB 100% Genuine IBM/thinkpad Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',15.9,'au-buy','azkaay','a.zkay.s@gmail.com','Yiannis Antonopoulos','13 Glengellen Street','Zillmere','Queensland','AUSTRALIA','4034','610468960950','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 13:29:30',0,NULL,3,1,11,1,'BJ01713730\r ','au-buy\rWLAT003 看客户要不要盒\r子\r客户说可以不要盒子'),(22588,942878973012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',46.99,'eastar4','rhlarose','boblsenior@yahoo.com','Robert Larose','8210 Marsh Glen Ct','Tampa','FL','UNITED STATES','33647-3056','(813) 829-7286','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 13:58:45',0,NULL,3,1,1,1,'LK212320784CN\r ','eastar4'),(22589,787860492008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','rolfe52','blackandproud52@hotmail.co.uk','Nigel Rolfe','52 Sheppard Avenue','Liverpool','Merseyside','UNITED KINGDOM','L162LD','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-28 14:05:14',0,NULL,3,1,3,1,'RA184506511CN\r ','au-buy\rLGAD001'),(22590,942893241012,220928853352,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4 2 colors',1,'GRUG001',119.99,'eastar4uk','den384r','den384@rambler.ru','Denis Shebarshov','Babarykinsky<br>Mekhanizatorov st.13','Verkhneuralsk','RU','RUSSIAN FEDERATION','457691','+79080666955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 14:12:35',0,NULL,3,1,5,1,'CP246990633CN\r\r ','eastar4uk\rGRUG001\r黑色的   地址不清 退回来\r新要的地址\rDenis Shebarshov\rBabarykinsky\rMekhanizatorov st.13\rChelyabinsk region\rVerkhneuralsk \rRU (index) 457691\rRUSSIAN FEDERATION\r+79080666955\r\r'),(22591,631670504004,140651987151,'New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008',99.9,'cnfaner','jboi7469','j.boiron@trio-solaire.com','josselyn boiron','15 bld la fayette<br>#1804','longueuil','QC','CANADA','j4k0b2','514 929 2506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 14:19:28',0,NULL,3,1,3,1,'RA184506539CN\r ','cnfaner\rGLSG008'),(22592,942903017012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','rasta5_10','smilesjason@googlemail.com','Jason Smiles','21 Bouldrewood Road','Benfleet','Essex','UNITED KINGDOM','SS7 5UA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 14:36:05',0,NULL,3,1,3,1,'RA184506689CN\r ','eastar4uk\r英标\rHSJA002'),(22593,804711052001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'buysia','bruno_falcon2012','bruno_falcon@terra.com.br','Barbara Betania','Rua:Rubens Golçalves de Fretitas  N 591','Praia Grande','São Paulo','BRAZIL','11703-130',' 34711346','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-28 14:38:33',0,NULL,3,1,3,1,'RA184506692CN\r ','buysia\rGPS0006'),(22594,942912754012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','dmitry_ru','d.a.79@mail.ru','Dmitry Polyakov','st. Lenina 56 - 36','Magnitogorsk','Chelyabinskaya','RUSSIAN FEDERATION','455023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:00:10',0,NULL,3,1,3,1,'RA184506658CN\r ','eastar4\rPSGL001'),(22595,851824682011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',2,'ADAK002',25.2,'eastar4','gear6468','ion.dumitrache@gmail.com','ION DUMITRACHE','Str. Drumetului nr. 24C, sector 3','Bucharest','Romania','ROMANIA','031891','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:13:05',0,NULL,3,1,3,1,'RA184505388CN ','eastar4\rADAK002+WLIN014\r再发一个New Intel Centrino Advanced N WiMAX 6250 622ANXHMW'),(22596,851835598011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','raychi7','rakubishin@gmail.com','Rachel Kubishin','119 E 13th St','Durango','CO','UNITED STATES','81301-5130','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 15:48:16',0,NULL,3,1,1,1,'LK212308457CN\r ','eastar4'),(22597,686832760013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','gear6468','ion.dumitrache@gmail.com','ION DUMITRACHE','Str. Drumetului nr. 24C, sector 3','Bucharest','Romania','ROMANIA','031891','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:48:58',0,NULL,8,1,17,0,NULL,'eastar4'),(22598,851839047011,320679575575,'NEW UNLOCKED ERICSSON F3507G 3G GPS Card DELL 5530',1,'WWOT001',26.99,'eastar4uk','kyrophase','n0165813@yahoo.com','David Brown','C/O Selman Marine Design<br>7a Alder road - Broad Meadow Ind est','Dumbarton','West Dunbartonshire','UNITED KINGDOM','G82 2EL','01436310500','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 15:50:43',0,NULL,3,1,3,1,'RA184506573CN\r ','eastar4uk\rWWOT001'),(22599,942938279012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','tino432','tino_x@web.de','Tino Bätge','am Schnarsleber Weg 53a','Irxleben','','GERMANY','39167','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:59:54',0,NULL,3,1,11,1,'BJ01713683\r ','eastar4\rWLDE002'),(22600,851780245011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','flexikru','flexi@tut.by','Alexey Kruchok','Melnikaite, 16-117','Minsk','','BELARUS','220004','+ 375291131838','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 16:04:12',0,NULL,3,1,11,1,'BJ01713691\r ','eastar4\rTRSN001'),(22601,942962228012,220917833326,'New 8 pcs Professional Piano Tuning Tool Kit Musical Instruments',1,'OT00001',62.99,'eastar4','murray_mason','murray@destinationsetc.com.au','Murray Mason','77B Comer Street','Como','Western Australia','AUSTRALIA','6152','0894741461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 16:48:05',0,NULL,3,1,3,1,'RA184506542CN\r ','eastar4\rOT00001\r钢琴调音工具 8件套'),(22602,851896247011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','lizalunina2012','lizalunina@gmail.com','Elizaveta Lunina','Bluhera avenue 52-72','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195067','9818630870','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 17:52:29',0,NULL,3,1,11,1,'BJ01713697\r ','eastar4\rUM00040'),(22603,943004149012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','margaretcurley','curley@nycap.rr.com','MM Curley Sanborn','4 Massachusetts Court','Rexford','NY','UNITED STATES','12148','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 18:11:38',0,NULL,3,1,1,1,'LK212340568CN\r ','eastar4'),(22604,804800912001,110822404425,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',23.9,'buysia','tasover','tasover@gmail.com','Anastasios Veresses','kalamon 3','Athens','Aegaleo','GREECE','12244','+306972150602','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-28 18:15:47',0,NULL,3,1,11,1,'BJ01713688\r ','buysia\rHSNO003\r欧标'),(22605,851945499011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','markknighton0','mark_knighton@yahoo.com','Mark Knighton','Gingsjovagen 13','Hallingsjo','Vst Got','SWEDEN','43064','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:16:27',0,NULL,3,1,11,1,'BJ01713690\r ','eastar4\rCCZG001'),(22606,686918002013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','fullmetalmax1987','maximchellak@gmail.com','Maxim Chellak','Irit 5/11','Tel Aviv Yaffo','Tel Aviv Yaffo','ISRAEL','68047','0547808699','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:39:26',0,NULL,3,1,3,1,'RA184506587CN\r ','eastar4\rGLSG009*3'),(22607,851967251011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','intelly09','intellige_nt@mail.ru','Anastasiya Mitronova','26 Bazhana ave, ap. 198','Kyiv','','UKRAINE','02140',' 00380677915559','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 20:02:36',0,NULL,3,1,3,1,'RA184506595CN\r ','eastar4\rGLOT001*2'),(22608,851978497011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',26.99,'eastar4uk','385goran123','gseretin@gmail.com','Goran Seretin','2.  Rudeški ogranak  18.','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 20:09:29',0,NULL,3,1,3,1,'RA184506644CN\r ','eastar4uk\rGLOT001'),(22609,851978725011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','intelly09','intellige_nt@mail.ru','Anastasiya Mitronova','26 Bazhana ave, ap. 198','Kyiv','','UKRAINE','02140',' 00380677915559','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 20:13:33',0,NULL,3,1,11,1,'BJ01713693\r ','eastar4uk\rTRSN001'),(22610,851991721011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','ericjvigil','andywilliams155@gmail.com','Eric Vigil','955 E Windsor Dr','Gilbert','AZ','UNITED STATES','85296-4229','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 20:32:10',0,NULL,3,1,1,1,'LK212254878CN\r ','eastar4'),(22611,943104927012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','qualish4000','gokul_@hotmail.com','Gokul Udaiwal','100 Harold Street','Brampton','ON','CANADA','L6Y 1E6','(905) 455-2518','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 20:39:26',0,NULL,3,1,11,1,'BJ01713684\r ','eastar4\rWLAT009'),(22612,851997903011,320786774053,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',22.99,'eastar4uk','dainjik77','dainiic_mazais@inbox.lv','Dainis Kolodko','Pionieru iela 30','Jaunolaine','Rigas rajons','LATVIA','2127','+37129489006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 20:39:43',0,NULL,3,1,11,1,'BJ01713685\r ','eastar4uk\rCC00002'),(22613,631800280004,140667903751,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card',1,'WLAT009',10.9,'cnfaner','renekatoll','rene.katoll@gmx.de','Rene Katoll','Nübelfeld 30A','Quern','','GERMANY','24972','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 20:41:03',0,NULL,3,1,3,1,'RA184506627CN\r ','cnfaner\rWLAT009'),(22614,943120106012,220815931272,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',36.99,'eastar4uk','rnjhair5zvw','rnjhair@aol.com','Robert P Hair','375 E Jefferson St','Frankenmuth','MI','UNITED STATES','48734-9404','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 21:03:07',0,NULL,3,1,1,1,'LK212381620CN\r ','eastar4uk'),(22615,943130923012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','rincewind2110','zdenko.sos@email.t-com.hr','Zdenko Šoš','Trnsko 28','Novi Zagreb','Zagreb','CROATIA','10 020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 21:30:36',0,NULL,3,1,3,1,'RA184506661CN\r ','eastar4\rGLOT001'),(22616,686970737013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','kym39','mykeydee1957@yahoo.com.au','Kym Wallace','Unit 2<br>576 Norman Road','North Rockhampton','Queensland','AUSTRALIA','4701','0749140741','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(22617,943155256012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',27.99,'eastar4uk','anny-bell','a.rushworth@yahoo.co.uk','Anna Rushworth','62 Stanway Road<br>Benhall','Cheltenham','Gloucestershire','UNITED KINGDOM','GL51 6BZ','01242210385','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 22:02:53',0,NULL,3,1,3,1,'RA184506525CN\r ','eastar4uk\rLGRM001'),(22618,631839409004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','jalexse1','jaseese@hotmail.com','James Seese','294 Garden Rd','River Ridge','LA','UNITED STATES','70123-1954','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-28 22:27:13',0,NULL,3,1,1,1,'LK212217141CN\r ','cnfaner'),(22619,849537850002,120844622171,'New GENUINE iTech Clip II mini Multipoint Bluetooth Headset Black',1,'HSIT002',39.9,'buysia','alonr_123','rusoa@zahav.net.il','alon russo','mevza-nachson<br>1','reson-lezion','il','ISRAEL','75445','972-050-3413955','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-28 22:42:56',0,NULL,3,1,3,1,'RA184505391CN ','buysia\rHSIT002\r欧标 \r蓝色\r\r'),(22620,631860000004,140667905660,'NEW Replaceable Shell for logitech Performance MX Mouse M950',1,'SHLO002',17.99,'cnfaner','johnnyboy','johntsk@yahoo.com','John Tan','N0.20 Jalan SS22/47A','PJ','Selangor','MALAYSIA','47400','0126382875','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 23:42:12',0,NULL,3,1,3,1,'RA184506732CN\r ','cnfaner\rSHLO002'),(22621,788154678008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','metroplex-au','backuponway@gmail.com','Tony Ko','2 Eton Street','Toowong','Queensland','AUSTRALIA','4066','0733354000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 01:02:08',0,NULL,3,1,11,1,'BJ01713689\r ','au-buy\rMOMI002'),(22622,788156340008,180816092496,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'',24.99,'usa-view','vcampos50','victorcampos@astchile.cl','victor campos','7339 NW 54th St<br>Ste 095830','miami','FL','UNITED STATES','33166-4831','5626713776','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-29 01:11:53',0,NULL,5,1,1,1,'LK212221472CN\r ','usa-view\rTRSN001'),(22623,687029202013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','kkrin3375','konstantinos.krinos@gmail.com','Konstantinos Krinos','Temeni Aigio','Aigio','Achaia','GREECE','25100',' 00306984185688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 01:15:13',0,NULL,3,1,3,1,'RA184506701CN\r ','eastar4\rMOSA004'),(22624,943246752012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',36,'eastar4uk','jazzypatmetheny','tritone-amp@hotmail.com','Mike Foo','2/61 Preston Street<br>COMO','Perth','Western Australia','AUSTRALIA','6152','08 64601959','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 01:57:42',0,NULL,3,1,3,1,'RA184506635CN\r ','eastar4uk\rWWSI006+ANCN001'),(22625,8881330481081834,111,'Sony TMR-BR100 3D Sync Transmitter',1,'TRSN001',24.99,'cnfaner','vcampos50','victorcampos@astchile.cl','victor campos','7339 NW 54th StSte 095830','miami','FL','UNITED STATES','33166-4831','',NULL,NULL,NULL,'2012-02-29 02:04:41',0,NULL,7,0,18,0,NULL,NULL),(22626,943259342012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','gnest','gnesteby@gmail.com','Gary Nesteby','3375 Armar Dr','Marion','IA','UNITED STATES','52302-4702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 02:29:37',0,NULL,3,1,1,1,'LK212321201CN\r ','eastar4'),(22627,943264336012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','sinchare','sinchare@yahoo.com.au','Charlene Sin','Tracey Brunstrom and Hammond<br>Level 12, 15 Blue St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 02:40:30',0,NULL,3,1,11,1,'BJ01713694\r ','eastar4\rUM00005'),(22628,943266363012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',2,'OTCN004*10',33.4,'eastar4','securitydepot123','eoncacorp@gmail.com','Donny Wang','3610 Nashua Dr. Unit 12','Mississauga','ON','CANADA','L4V1X9','(416) 831-6282','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 02:47:51',0,NULL,3,1,11,1,'BJ01713687\r ','eastar4\rOTCN004*10'),(22629,805023085001,110819588535,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET  BH 900',1,'HSNO019',37.98,'buysia','bdaz3821','tonotxx@msn.com','Bernardo Díaz','1303 queretaro plaza','Dallas','TX','UNITED STATES','75211','(214) 875-0960','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-29 02:53:11',0,NULL,3,1,1,1,'LK212650423CN\r ','buysia'),(22630,796618618007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',4,'OTGR001',83.6,'au-buy','bro_tan09','bro2003@bigpond.com.au','brian harrison','28 sturgeon st','ormiston','Queensland','AUSTRALIA','4160','0738212545','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 03:40:22',0,NULL,3,1,3,1,'RA184506560CN\r ','au-buy\rOTGR001'),(22631,0,320854557680,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',1.08,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:07:13',0,NULL,3,0,18,0,'\r RA184519679CN ','eastar4'),(22632,0,320854553071,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.4,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:07:16',0,NULL,3,0,18,0,'RA184519679CN ','eastar4'),(22633,0,230751439156,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',3.83,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 try on road','Raleigh','NC','UNITED STATES','27607','(919) 662-2234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:13:51',0,NULL,3,0,18,0,'RA184519679CN  ','eastar4'),(22634,0,220960833571,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',2.4,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:13:53',0,NULL,3,0,18,0,'RA184519679CN  ','eastar4'),(22635,0,220960832256,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',9.57,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:13:59',0,NULL,3,0,18,0,'RA184519679CN  ','eastar4'),(22636,0,320854554354,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',10.29,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:14:05',0,NULL,3,0,18,0,'RA184519679CN  ','eastar4'),(22637,0,230751096562,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',14.97,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:14:11',0,NULL,3,0,18,0,'RA184519679CN  ','eastar4'),(22638,0,220960830749,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',8.84,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:21:35',0,NULL,3,0,18,0,'RA184519679CN   ','eastar4'),(22639,0,220960837061,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',3.82,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:21:42',0,NULL,3,0,18,0,'RA184519679CN   ','eastar4'),(22640,0,230751094104,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',4.36,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:21:47',0,NULL,3,0,18,0,'RA184519679CN   ','eastar4'),(22641,0,230751095365,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',6.88,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:21:54',0,NULL,3,0,18,0,'RA184519679CN   ','eastar4'),(22642,0,230751097486,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',5.92,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:24:39',0,NULL,3,0,18,0,'RA184519679CN   ','eastar4'),(22643,0,220960835197,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',10.82,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:24:46',0,NULL,3,0,18,0,'RA184519679CN    ','eastar4'),(22644,0,320854551601,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',4.85,'eastar4','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 04:21:29',0,NULL,3,0,18,0,'RA184519679CN     ','eastar4'),(22645,943302599012,220816316678,'NEW Autopop 3-section Sun umbrella w/Paris Eiffel tower',1,'UM00015',24.99,'eastar4','nayap123','karlsoir@hotmail.com','CAROLE RIOS','CARRER CANIGO 8','ESCALA','Girona','SPAIN','17130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 04:44:44',0,NULL,5,0,18,0,NULL,'eastar4\rUM00015\r客户要撤单'),(22646,626460572003,130606122477,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',4,'ANTY002',23.96,'cnfaner','apokalipse_the_overclocker','apokalipse@gmail.com','Chris Larkin','11 Brett Court<br>Cheltenham','Melbourne','Victoria','AUSTRALIA','3192','0395849497','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 04:45:44',0,NULL,3,1,3,1,'RA184506746CN\r ','cnfaner\rANTY002'),(22647,796644745007,170758647866,'New Genuine Sturdy Samsung WMN2050C Ultra Slim Wall Mount for 2011 LED TV 65\"',1,'MOSA010',69.99,'au-buy','murray668','abe@unwired.com.au','john murray','42 gargery st<br>Ambavale','sydney','New South Wales','AUSTRALIA','2560','0410135353','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 05:36:37',0,NULL,3,1,3,1,'RA184506750CN\r ','au-buy\rMOSA010'),(22648,943319333012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',5,'PSGL001',374.95,'eastar4','telehd','seolime@ya.ru','Uriy Vladimirovich Brizhan','Chertanovskaya 30-3-77','Moscow','','RUSSIAN FEDERATION','117525','(495) 502 - 6203','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 05:56:11',0,NULL,3,1,3,1,'RA184506715CN\r ','eastar4\rPSGL001'),(22649,943319251012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','mx4life85','mx4life85@gmail.com','Taylor Ulrich','102 Cheyenne Dr<br>Apt L','Greensboro','NC','UNITED STATES','27410-6503','(704) 516-3962','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 05:56:52',0,NULL,3,1,1,1,'LK212700924CN\r ','eastar4'),(22650,626476750003,130608487119,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',50.99,'cnfaner','lunathemoonlight','akorina@net.hr','Jelena Halavanja','Naselje Josipa Franka 6b','Slavonski Brod','Croatia','CROATIA','35000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 06:47:56',0,NULL,3,1,3,1,'RA184506729CN\r ','cnfaner\rSAFI001'),(22651,943340821012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','bikerjac34','jackymcleod@sky.com','Jacky Mcleod','Royal Umpire caravan Park<br>Southport Road','Croston','Lancashire','UNITED KINGDOM','Pr26 9jb','07783169250','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 07:32:47',0,NULL,3,1,3,1,'RA184506851CN\r ','eastar4uk\r英标\rHSJA002'),(22652,852217420011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','boo-cloud','louisewincott@aol.com','Louise Wincott','David Hall Publishing Ltd<br>2 Stephenson Close','Daventry','Northamptonshire','UNITED KINGDOM','NN11 8RF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 07:42:26',0,NULL,3,1,3,1,'RA184506777CN\r ','eastar4uk\rMOAP001'),(22653,943352738012,220713846407,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',2,'HSNO019',49.98,'eastar4uk','vip222rudolf','rudi.schider@aon.at','Rudolf SCHIDER','Unterwasser 57','WAIDRING','','AUSTRIA','6384','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 08:25:09',0,NULL,3,1,3,1,'RA184506803CN\r ','eastar4uk\r欧标\rHSNO019'),(22654,796682083007,170785414219,'New Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP003',25.99,'au-buy','demented36','sideride_@hotmail.com','GREG HAWKER','33 Woorak st<br>Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 08:37:32',0,NULL,3,1,11,1,'BJ01713656\r ','au-buy\rWLAP003\r'),(22655,8881330505195592,111,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','elwellm','elwellm@comcast.net','Elwell Weatherhead','2401 University Ave','Waukegan','IL','UNITED STATES','60085-3354','(847) 436-4586',NULL,NULL,NULL,'2012-02-29 08:46:35',0,NULL,3,0,3,1,'RA184506998CN\r ','cnfaner\rHSJA011\r补发的 '),(22656,8881330505674625,111,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',0,'au-buy','sierrared','sierrared1447@yahoo.com','lori pelcher','1447 birchim ln','bishop','ca','UNITED STATES','93514-7627','(760) 937-7919',NULL,NULL,NULL,'2012-02-29 08:54:34',0,NULL,3,1,3,1,'RA184504881CN\r ','au-buy\rHBPH009\r补发的\r'),(22657,8881330506483109,111,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',0,'cnfaner','robertpdros','rosejmarshall@hotmail.com','rosemary Marshall','2 / 21 Hampden Road','Armadale','Victoria','AUSTRALIA','3143','61395002880',NULL,NULL,NULL,'2012-02-29 09:08:03',0,NULL,3,0,3,1,'RA184506763CN\r ','cnfaner\rHBPH007\r补发的\r '),(22658,687119599013,230393482183,'2.1 HP ZD8000 X6000 NX9600 Bluetooth Module+ cable',4,'BTHP2102',49.56,'eastar4','stocknawe','montanalandscape@live.com','Debra Llera','4725 53rd Ave SW','Great Falls','MT','UNITED STATES','59404-4920','(406) 899-0749','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 09:09:21',0,NULL,3,1,1,1,'LK212705379CN\r ','eastar4\rHP 8pin 1.0 3cm 线序反 '),(22659,943371069012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Philip Clough','3080 CALLE ROSALES','SANTA BARBARA','CA','UNITED STATES','93105-2846','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 09:29:15',0,NULL,3,1,1,1,'LK213241059CN ','eastar4'),(22660,943371934012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Jennifer Delmonaco','336 1ST ST','Aspinwall','PA','UNITED STATES','15215-3102','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 09:33:27',0,NULL,3,1,1,1,'LK213210618CN ','eastar4'),(22661,943373503012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','MARIA KEELER','3676 HEDGEWOOD DR','WINTER PARK','FL','UNITED STATES','32792-3028','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 09:39:58',0,NULL,3,1,1,1,'LK213207786CN ','eastar4'),(22662,943378119012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',6,'CASS001',37.74,'eastar4uk','comms2k','jm012c5343@blueyonder.co.uk','James McLean','25 Sunningdale Close, Handsworth Wood','Birmingham','West Midlands','UNITED KINGDOM','B201LH','07710639420','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 09:52:24',0,NULL,3,1,3,1,'RA184504011CN\r ','eastar4uk\rCASS001'),(22663,852261101011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','jezmark','jezmarkphotography@gmail.com','Marek Jezierski','6 Newcombe Place','Lurnea','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 10:30:59',0,NULL,3,1,3,1,'RA184504095CN\r ','eastar4\rLGRM001'),(22664,625149175003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','dnstuff','6029005@gmail.com','Maksim Charankou','Esenina street 123-223','Minsk','','BELARUS','220051','+375291062978','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 10:24:38',0,NULL,3,1,3,1,'RA184504100CN\r','cnfaner\rOTES001'),(22665,943396278012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','rubenesquie','ebay@roubin.org','Andrew Roubin','16 Carrington Place<br>Carindale','Brisbane','Queensland','AUSTRALIA','4152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 10:53:01',0,NULL,3,1,3,1,'RA184504056CN\r','eastar4\rGLOT001'),(22666,943395328012,220815929125,'NEW AKE BC 188 Inside hide PCMCIA to eSATA SATA Cardbus',1,'ADAK002',8.25,'eastar4uk','tolilo','ts-scholz@gmx.de','Thomas Scholz','Wuppertalstr. 62','Leverkusen','','GERMANY','51381','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 10:51:04',0,NULL,3,1,11,1,'BJ01713675\r ','eastar4uk\rADAK002'),(22667,788306030008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',12.12,'au-buy','lawlzx','laurenhall8284@hotmail.com','Lauren Hall','22 Broadhurst Ave','Reservoir','Victoria','AUSTRALIA','3073','0423870770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 11:14:35',0,NULL,3,1,11,1,'BJ01713658\r ','au-buy\rSHLO009'),(22668,788318395008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','zafi123','peter-lugert@t-online.de','Peter Lugert','Nikolaistr. 1a','Mering','','GERMANY','86415','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-29 11:59:16',0,NULL,3,1,3,1,'RA184504042CN\r ','au-buy\rLGAD001'),(22669,632013359004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.8,'cnfaner','electronicsman380','trunovmaks@gmail.com','Maksim Trunov','S.Gritsevtsa street,<br>12-a, 30','Kharkov','Kharkovskaya','UKRAINE','61172','+380671380380','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 13:19:10',0,NULL,3,1,3,1,'RA184504201CN\r ','cnfaner\rWLAP008'),(22670,687167801013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','richie*rdp','rawrich56@yahoo.com','Richie Phillips','108 chris lail way','maryville','TN','UNITED STATES','37801-9619','(865) 379-7864','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 13:04:20',0,NULL,3,1,1,1,'LK213149788CN ','eastar4'),(22671,687168327013,230456770114,'New Atheros AR5B95 AR9285 Half  Mini PCI-E card+antenna',1,'WLAT009+ANTY001',11.98,'eastar4','guitmz','gui.tmz@gmail.com','Guilherme Thomazi','Antonio Molina, 3-105','Bauru','Sao Paulo','BRAZIL','17030670',' 551488128299','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 13:07:06',0,NULL,3,1,11,1,'BJ01713703\r ','eastar4\rWLAT009+ANTY001'),(22672,852316759011,320665222636,'NEW GENUINE NOKIA BH-106 BLUETOOTH HEADSET BH 106',1,'HSNO004',18.99,'eastar4','chatzimoschou','haroula08@gmail.com','Anna Chatzimoschou','Papanastasiou 75','Keratsini','Attiki','GREECE','18756',' 00306937412043','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 13:27:55',0,NULL,3,1,11,1,'BJ01713666\r ','eastar4\rHSNO004\r欧标'),(22673,687182589013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','vatzikas','va_ba@hotmail.com','VASILIS VATZIKAS','LESVOU 10','VARI','ATTIKI / ATHENS / VARI','GREECE','16672','+0306947129674','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 14:00:38',0,NULL,3,1,11,1,'BJ01713704\r ','eastar4\rBTAC2014\racer 5pin1.25 20cm'),(22674,788363211008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','chongo_au','tyrellmf@gmail.com','Tyrell Swartz','52 Dutton Crescent','Hamersley','Western Australia','AUSTRALIA','6022','0894476295','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 14:19:51',0,NULL,3,1,11,1,'BJ01713669\r ','au-buy\rMOMI002'),(22675,852333873011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',26.99,'eastar4uk','sjaak.debanaan','vincent.dejonge@hotmail.com','Vincent De Jonge','Zilvermos 68','HOUTEN','','NETHERLANDS','3994LE','0031307070166','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 14:40:31',0,NULL,3,1,3,1,'RA184504025CN\r ','eastar4uk\rGLOT001'),(22676,943494096012,220864660795,'New News Paper 3-Section Rain Sun Umbrella',1,'UM00038',19.99,'eastar4','luowen882000','luow1@yahoo.com','Wen Luo','7650 McCallum Blvd<br>Apt 903','Dallas','TX','UNITED STATES','75252-6388','(347) 421-4740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 15:16:33',0,NULL,3,1,1,1,'LK213187110CN ','eastar4'),(22677,631887004004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',4,'HSNO005',55.16,'cnfaner','donatebloodtoday','mcarfano@tampabay.rr.com','mark carfano','2654 Midland Ct','PALM HARBOR','FL','UNITED STATES','34684-4531','(727) 271-5378','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-29 15:18:58',0,NULL,3,1,1,1,'LK212909377CN ','cnfaner'),(22678,943508943012,220815930629,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',13.98,'eastar4uk','johanlindstrom76','johan.of.lindstrom@gmail.com','Johan Lindström','Klareborgsgatan 7','Gothenburg','Sweden','SWEDEN','41461','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 15:52:00',0,NULL,3,1,11,1,'BJ01713674\r ','eastar4uk\rOTHP004'),(22679,687215785013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','brfsa','fred.the.master@gmail.com','Frederico de Souza Araujo','2100/1238, Ramkhamhaeng 24/2<br>K.S. Apartment, Room 311','Huamark','Bangkok','THAILAND','10240','(66)860588264','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 16:00:29',0,NULL,3,1,11,1,'BJ01713673\r ','eastar4\rCACN004'),(22680,943317740012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','bernardm71bernard','bernardber123@googlemail.com','Bernard Młotkiewicz','37lacey green<br>Balderton','Newark','Nottinghamshire','UNITED KINGDOM','NG24 3NJ','07892818012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 15:51:54',0,NULL,3,1,3,1,'RA184506936CN\r ','eastar4uk\rHSJA002\r英标'),(22681,943518192012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','marcoaribars','marcoariba@hotmail.com','Marco Antonio Ribeiro da Silva','Rua Domingos Seguezio 271/208','Porto Alegre','Rio Grande do Sul','BRAZIL','91360-040','5551 99672067','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 16:19:52',0,NULL,3,1,11,1,'BJ01713657\r ','eastar4\rUM00008'),(22682,852391538011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','ki_auctions4','ki_auctions@q.com','Kiley Beminio','211 Luicks Ln N','Belmond','IA','UNITED STATES','50421-1729','(515) 444-6044','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 16:37:46',0,NULL,3,1,1,1,'LK213156355CN ','eastar4'),(22683,852395761011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','regtorrez','reginaldo.torrez@gmail.com','REGINALDO TORREZ','RUA ARMANDO ITALO SETTI, 1120 BLOCO 4 APTO 61','Sao Bernardo do Campo','Sao Paulo','BRAZIL','09760-281','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 16:48:13',0,NULL,3,1,3,1,'RA184504087CN\r ','eastar4\rLGRM001'),(22684,849857495002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','bergybrg14','berg1sj@cmich.edu','Steven Berg','2112 24th Ave S','Escanaba','MI','UNITED STATES','49829-1941','(906) 399-0897','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-29 16:59:50',0,NULL,3,1,1,1,'LK212970904CN ','buysia'),(22685,805239778001,110826639618,'New IBM Sierra Unlocked MC8775 WWAN PCI-E Card +3G WWan antenna',1,'WWSI002+ANCN001',33.88,'buysia','frlosen','jfc@jfc.sk','Ing. Jozef Frlicka','Svabinskeho 20','Bratislava','Slovak republic','SLOVAK REPUBLIC','85101','+421903267972','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-29 17:05:39',0,NULL,3,1,11,1,'BJ01713680\r ','buysia\rWWSI002+ANCN001'),(22686,631647975004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','viktorys-lt','viktorys@inbox.ru','Irma Maslauskiene','Zeimiu takas 6 - 3','Jonava','','LITHUANIA','LT-55132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 17:13:02',0,NULL,3,1,3,1,'RA184504073CN\r ','cnfaner\rHSJA002\r欧标'),(22687,788386627008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','mix-x2011','rusy-sch@mail.ru','ruslan schabunin','buschst-41','duisburg','','GERMANY','47166','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-29 17:30:51',0,NULL,3,1,3,1,'RA184506896CN\r ','au-buy\rLGAD001'),(22688,943563785012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','ydbarnes1','ydbarns@gmail.com','yvonne barnes','14 buckingham court fulham close','crawley','West Sussex','UNITED KINGDOM','RH11 9AY','01293405960','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 17:37:41',0,NULL,3,1,3,1,'RA184506975CN\r ','eastar4uk\r英标\rHSJA002'),(22689,852424999011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','npriyan','priyan203@yahoo.com','Priyananth Nadarajah','Executive Engineer\'s Office(RDA) ,Road Development Authority ( RDA ),<br>Service Road, Puttalam,','Puttalam','Northwestern Province','SRI LANKA','61300 - LK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 17:49:16',0,NULL,3,1,11,1,'BJ01713678\r ','eastar4\rHSJA002'),(22690,852431556011,320441575533,'2.1 Acer Extensa 4620 4620z 4220 Bluetooth Module cable',1,'BTAC2104',12.39,'eastar4','rtronixllc','gil@rtronix.com','RTRONIX','PO Box 824<br>425 E. Main Ave.','Robstown','TX','UNITED STATES','78380-0824','(361) 438-3632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 17:59:36',0,NULL,3,1,1,1,'LK213158935CN ','eastar4\racer 4pin1.25 6cm'),(22691,626629836003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',37.99,'cnfaner','6patulllka','dima_cat@mail.ru','Dmitry Sholukhov','Morozova str. 7 kv 58','Taganrog','Rostovskaya oblast','RUSSIAN FEDERATION','347931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:14:29',0,NULL,3,1,3,1,'RA184504189CN\r ','cnfaner\rWWSI005+ANCN001'),(22692,852430270011,320786773728,'New iTech Clip II mini Multipoint Bluetooth Headset blue',1,'HSIT004',21.99,'eastar4uk','evaggeza','zevage@hotmail.com','Zacharias Evagelopoulos','Xantzopoulou 3','Lamia','Ftiotida','GREECE','35100','6972015055','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 17:58:42',0,NULL,3,1,11,1,'BJ01713671\r ','eastar4uk\rHSIT004'),(22693,626634961003,130645332978,'Brand new HP MCE Media Center Receiver+ IR emitte',1,'OTHP005',18.5,'cnfaner','kevinsmith510','kevinsmith510@hotmail.com','Kevin','7133 S Johnson St','Littleton','CO','UNITED STATES','80128-4131','(801) 682-3874','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-29 18:25:22',0,NULL,3,1,1,1,'LK212947106CN ','cnfaner'),(22694,687260296013,230678127185,'New SAMSUNG SSG-3700CR Rechargeable 3D Glasses',1,'GLSG008',99.99,'eastar4','jym-1965','j.y.m@videotron.ca','Jean-Yves Morin','80 Lapointe #2','Longueuil','QC','CANADA','J4G 1H3','(514) 572-5222','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:09:09',0,NULL,3,1,3,1,'RA184506865CN\r ','eastar4\rGLSG008'),(22695,852480120011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','svalkama2012','saku.valkama@luukku.com','Saku Valkama','Järvensivunkuja 5B','Tuusula','Tuusula','FINLAND','04300',' 00358405247447','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 19:25:25',0,NULL,3,1,11,1,'BJ01713660\r ','eastar4\rHSNO019\r欧标'),(22696,943634170012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','ryan-power','ryan-power@hotmail.co.uk','ryan power','23 hawthorn roan<br>abronhill','cumbernauld','North Lanarkshire','UNITED KINGDOM','g67 3lx','01236729979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 19:31:49',0,NULL,3,1,3,1,'RA184504060CN\r ','eastar4uk\rHSJA010\r英标'),(22697,632129014004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','sadiq230','tanweersadiq@yahoo.com','tanweer sadiq','8315 liberia ave','manassas','VA','UNITED STATES','20110-4619','(703) 393-1890','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-29 19:36:00',0,NULL,3,1,1,1,'LK212922170CN ','cnfaner'),(22698,943638010012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','i.marlovic','imarlovi@gmail.com','Ivan Marlović','Trg dr. Ante Starčevića 26','Velika Gorica','','CROATIA','10410','016226180','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 19:38:29',0,NULL,3,1,3,1,'RA184506953CN\r ','eastar4\rPSGL001'),(22699,852492241011,320787383262,'New Lady Wedding fasion Pure Red Sun stick Umbrella',1,'UM00022',13.95,'eastar4uk','1990vanja','vanja_mine@hotmail.com','Vanja Miné Rasmussen','Kristiansgøta 1<br>Faroe Islands','Hoyvík','','DENMARK','188','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 19:41:09',0,NULL,3,1,11,1,'BJ01713663\r ','eastar4uk\rUM00022'),(22700,632133171004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',39.78,'cnfaner','tsmith12766','tsmith12766@yahoo.com','Tracy Smith','13102 Candlewood Glen Ln','Houston','TX','UNITED STATES','77014-1941','(281) 794-9601','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-29 19:45:04',0,NULL,3,1,1,1,'LK212915457CN ','cnfaner'),(22701,943646475012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','mrkotenko','nunga@mail.ru','Ivan Kotenko','prospect Bolshevikov d.35, korpus 3, kv.35','St. Petersburg','','RUSSIAN FEDERATION','193232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 19:53:24',0,NULL,3,1,3,1,'RA184504127CN\r ','eastar4\rPSGL001\r'),(22702,943650881012,220824004354,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',88.99,'eastar4','tigr1945','mail@zubilo.com','Luk\'yanenko Vladimir','Polochkaya 1/26','DONETSK','Donetskaya','UKRAINE','83047','(380)63 305-79-68','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 19:57:35',0,NULL,3,1,3,1,'RA184504144CN\r ','eastar4\rGLOT001*2'),(22703,852510680011,320698292671,'New SAMSUNG WEP250 Bluetooth Headset WEP 250',1,'HSSA003',13.9,'eastar4','kamran.asad','watc1987@gmail.com','Kamran Esedullayev','Yeni Guneshli qesebesi, Massiv AB. Bina 50A. menzil 44','Baku','Azerbaijan','AZERBAIJAN','AZ1133','+994518191446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:09:58',0,NULL,3,1,11,1,'BJ01713667\r ','eastar4\rHSSA003'),(22704,849965675002,120841235559,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',29.99,'buysia','libratosor','bricetuning_77@hotmail.fr','brice cattelan','421e rue du docteur Lheritier','dammarie les lys','Île-de-France','FRANCE','77190','0874523457','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-29 20:20:50',0,NULL,3,1,11,1,'BJ01713679 ','buysia\rTRSN001'),(22705,852524024011,320574703315,'NEW GENUINE NOKIA BH-203 BLUETOOTH HEADSET BH 203',1,'HSNO007',13.98,'eastar4','microlabm13','ima-makc@yandex.ru','Максим Иванов','ул.Псковская, д48корп3 кв.218','Великий Новгород','Новгородская область','RUSSIAN FEDERATION','173015','89116479700','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:29:58',0,NULL,3,1,11,1,'BJ01713665\r ','eastar4\rHSNO007\r欧标'),(22706,687323888013,230641244789,'New lady Piano Anti-UV Rain Parasol Stick Umbrella pink',1,'UM00010',24.99,'eastar4','ekat2009','ekaterom@gmail.com','Ekaterina Romanenko','42/3/44, Ul. Budapeshtskaya','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','192071','7 921 644 3595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:34:21',0,NULL,3,1,11,1,'BJ01713858 ','eastar4\rUM00010\r粉红色的\r'),(23524,811832551001,110808693121,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors',1,'PS00001',25.99,'buysia','yoav.levy','yoav.levy1@gmail.com','Yoav Levy','13 Habarbur st.','Netanya','Israel','ISRAEL','42754','+972-54-7331778','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-13 08:31:30',0,NULL,3,1,11,1,'BJ01714161 ','buysia\rPS00001\rChampagne'),(22707,943680205012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:40:33',0,NULL,3,1,3,1,'RA184504135CN\r ','eastar4\rPSGL001'),(22708,632161254004,140680154335,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',74.99,'cnfaner','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:51:26',0,NULL,3,1,3,1,'RA184504158CN\r','cnfaner\rPSGL001'),(22709,943687401012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','live2hunt247','troyboy_2005@yahoo.com','Troy W Roper','4365 Rhodes Rd','Rhodes','MI','UNITED STATES','48652-9732','(989) 879-8805','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 20:51:48',0,NULL,3,1,1,1,'LK213169181CN ','eastar4'),(22710,852550270011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','bluepaperz','phillips_james@hotmail.com','James Phillips','24 Stephenson Avenue','Grantham','Lincolnshire','UNITED KINGDOM','NG31 8QA','07932084825','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 21:13:31',0,NULL,3,1,3,1,'RA184506905CN\r ','eastar4uk\rLGAD001'),(22711,805401088001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'buysia','hawaiigolf','hkgcakk2@hawaiiantel.net','Hiroshi Utashiro','8902 Kalanianaole Hwy','Honolulu','HI','UNITED STATES','96825-2821','(808) 232-5668','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-02-29 21:35:06',0,NULL,3,1,1,1,'LK212982482CN ','buysia'),(22712,687353753013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','fr.bueno','eng.frb@gmail.com','Fabricio Bueno','QE 38 Bl. D Ap. 105 Euzebio P. Araujo. II<br>Guara II','Brasilia','Distrito Federal','BRAZIL','71070-604','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 21:46:44',0,NULL,3,1,3,1,'RA184506967CN\r ','eastar4\rGLOT001*2'),(22713,943328692012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','philippe6129','plagasse@wanadoo.fr','Lagasse Philippe','11A allée du Bicentenaire','Genech','Nord-Pas-de-Calais','FRANCE','59242','0320348366','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 22:05:52',0,NULL,3,1,11,1,'BJ01713701\r ','eastar4\rWLDE002'),(22714,852580450011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','mrpwilcox','paulwilcox1978@yahoo.co.uk','Paul Wilcox','The Gables<br>Churchend, Twyning','Tewkesbury','Gloucestershire','UNITED KINGDOM','GL52 8SQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 22:10:40',0,NULL,3,1,3,1,'RA184506825CN\r ','eastar4uk\rLGAD001'),(22715,943759127012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','pbro7682','peterwbrown@sbcglobal.net','Peter Brown','2280 Strap Miner Trl','Cool','CA','UNITED STATES','95614','(530) 823-2621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 22:56:51',0,NULL,3,1,1,1,'LK213130720CN ','eastar4'),(22716,943762833012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.39,'eastar4','82fast','mclyons111@gmail.com','Michael Lyons','5150 Palm Valley Rd<br>Ste 103','Ponte Vedra Beach','FL','UNITED STATES','32082-4630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 23:06:30',0,NULL,3,1,1,1,'LK213113341CN ','eastar4'),(22717,852606493011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','841ak','anilvkamat@hotmail.com','A V KAMAT','3 PROSPECT PLACE','BROMLEY','Kent','UNITED KINGDOM','BR2 9HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 23:10:53',0,NULL,3,1,3,1,'RA184504192CN\r ','eastar4uk\rLGAD001'),(22718,943731384012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'eastar4','helicopter_don','don@dcfp.com','Donald Norrington','PO Box 501<br>959 Northside road','Sutherlin','OR','UNITED STATES','97479-0501','(541) 459-5297','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 23:33:10',0,NULL,3,1,1,1,'LK213153561CN ','eastar4'),(22719,943786974012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','markman_101','zbogcha@rogers.com','Zoltan Bogcha','22 La Cassandra Drive','Maple','ON','CANADA','L6A 3X2','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(22720,687398549013,230641567591,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR100',1,'GLOT001*2',116.98,'eastar4','witchanddan','bunny2@sympatico.ca','Daniel M Higgins','103363 Grey Road 18','Owen Sound','ON','CANADA','N4K 5N8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 00:18:51',0,NULL,3,1,3,1,'RA184504113CN\r','eastar4\rGLOT001*2'),(22721,786499291008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','peterwilliamburton','peterwburton@gmail.com','Margaret Burton','PO Box 4308','EAST GOSFORD','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 00:41:59',0,NULL,3,1,11,1,'BJ01713702\r ','au-buy\rBALO001'),(22722,632235857004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','guylou37','dany33@videotron.ca','Guylaine Perron','909 Gauthier','Laterriere','QC','CANADA','G7N1H1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 01:06:37',0,NULL,3,1,3,1,'RA184506919CN\r ','cnfaner\rHSJA002\r美标'),(22723,788654837008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','alexis.nobre','nobrefam@iinet.net.au','Alexis Nobre','Retravision<br>445 Hay Street','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 01:10:31',0,NULL,3,1,11,1,'BJ01713706\r ','au-buy\rBALO001'),(22724,687419053013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','claudiajp10','claudiajp@globo.com','Claudia j. Sanná','R Dr Mario Freire 245<br>Morumbi','Sao Paulo','São Paulo','BRAZIL','05692-110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 01:50:24',0,NULL,3,1,3,1,'RA184504039CN\r ','eastar4\rLGAD001'),(22725,797099841007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','mattyj2002','matt.j@internode.on.net','Matt Johnston','PKF House , level 2 , 139 Frome Street','Adelaide','South Australia','AUSTRALIA','5000','0874211400','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 02:07:42',0,NULL,3,1,11,1,'BJ01713681\r ','au-buy\rRELO002'),(22726,943829226012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','sambeckett12','duteycs@gmail.com','Chris Dutey','4018 Fawnhill Ln','Cincinnati','OH','UNITED STATES','45205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 02:13:41',0,NULL,3,1,1,1,'LK213108939CN ','eastar4\racer 5pin1.25 6cm '),(22727,687427914013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','harsham1212','harsham121@yahoo.com','Harsha Meemaduma','No. 8A<br>Rahula Cross Road','Matara','Southern Province','SRI LANKA','81000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 02:27:19',0,NULL,3,1,11,1,'BJ01713672\r ','eastar4\rHSNO022'),(22728,8881330569095869,111,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M',1,'OT00002',12.99,'au-buy','hobbitpkg','pgamble@uow.edu.au','Patrick Gamble','25 Cordeaux Road','Figtree','New South Wales ','AUSTRALIA','2525','',NULL,NULL,NULL,'2012-03-01 02:31:35',0,NULL,3,1,11,1,'BJ01713676\r ','au-buy\rOT00002\r\r '),(22729,8881330569855583,111,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',12.8,'eastar4uk',' macorpcltd  ','baz.lawrence@macorpcltd.co.uk','baz lawrence','mac or pc ltd324 holyhead road','coventry West Midlands','','UNITED KINGDOM','cv5 8lh','',NULL,NULL,NULL,'2012-03-01 02:44:15',0,NULL,3,1,3,1,'RA184504175CN\r ','EASATR4UK\r系统没下来\rANCN003'),(22730,943843161012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','pagoo388','mark.pagani@yahoo.com','samantha','29 columbus ave','havertown','PA','UNITED STATES','19083-3326','(610) 717-2190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 02:53:41',0,NULL,3,1,1,1,'LK213087258CN ','eastar4'),(22731,8881330571058248,111,'100% New Atheros AR5B195 Wireless + Bluetooth Half Mini PCI-E Card',1,'WLIN016',14.99,'au-buy','canya2006','canya2009@gmail.com','José Seguí Coll','Hotel Cotillo BeachAvda. A los Lagos, s/n','El Cotillo - La Oliva - Fuerteventura, Canarias','','SPAIN','35650','',NULL,NULL,NULL,'2012-03-01 03:04:18',0,NULL,3,1,11,1,'BJ01713705\r ','au-buy\rWLIN016\r '),(22732,632266162004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',3,'WLAP002',62.7,'cnfaner','herbthai','mr.premax@gmail.com','Vachirapong Pharharoonvaridha','8/337 Moo 9, Indy Bangna, Bangna Garden rd.,<br>Bang Bo','Samut Prakan','SP','THAILAND','10560','(668)6778-9965','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 03:25:54',0,NULL,3,1,3,1,'RA184506848CN\r ','cnfaner\rWLAP002'),(22733,687441546013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','rhawbert','rhawbert@gmail.com','Rhawbert Costa Assuncao','Av. Roma, 380<br>APT.1403  BL.04 Resid. Eldorado','Goiania','GO','BRAZIL','74367-630','00556284515234','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 03:28:36',0,NULL,3,1,3,1,'RA184506817CN\r ','eastar4\rLGAD001'),(22734,943856601012,220806892285,'New lady Painting  Rain Sun Parasol Stick Umbrella',1,'UM00014',24.99,'eastar4','jacobklanooo','jakeshonor2@optusnet.com.au','Jacob Klan','14 Yarram Crt','Frankston','Victoria','AUSTRALIA','3199','0414778489','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 03:34:24',0,NULL,3,1,11,1,'BJ01713662\r ','eastar4\rUM00014'),(22735,852692974011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','denicabasta','business_brian@hotmail.com','Kraibrian Uswawechmongkol','202/3 MU.4 , Klongsongtonnun, Kheharomklao, Ladkrabang','Bangkok','','THAILAND','10520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 03:44:10',0,NULL,3,1,11,1,'BJ01713709\r ','eastar4\rHSUE002'),(22736,626804743003,130490601966,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',2,'WLHP002',23.8,'cnfaner','dyrimrules','cybotrules@gmail.com','Ben Brown','12 Flowers Drive','Catherine Hill Bay','New South Wales','AUSTRALIA','2281','0249762720','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 04:16:11',0,NULL,3,1,3,1,'RA184506834CN\r ','cnfaner\rWLHP002'),(22737,687452316013,230751483355,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',9.99,'eastar4','onkytonkman','jnaim.music@gmail.com','Joseph Naim','7 Kenneth Street, Braybrook','Melbourne','Victoria','AUSTRALIA','3019','0393524808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 04:24:39',0,NULL,3,1,11,1,'BJ01713668\r ','eastar4\rRCHP001'),(22738,943882242012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','kdon1134','kadon@talktalk.net','kenneth don','17 brookside place','carlisle','Cumbria','UNITED KINGDOM','ca27jw','01228542192','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 05:09:20',0,NULL,3,1,3,1,'RA184506879CN\r ','eastar4uk\rHSJA010\r英标'),(22739,687465252013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','janecpa','janecpa@tds.net','Jane Skelton','1104 22nd St','Monroe','WI','UNITED STATES','53566','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 05:43:14',0,NULL,3,1,1,1,'LK213382290CN ','eastar4'),(22740,788728398008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',5,'MOMI002',68.95,'au-buy','hisanswer','hisanswer77@hotmail.com','Jung Soo Kim','Bates Smart architects<br>243 Liverpool Street','East Sydney','New South Wales','AUSTRALIA','2010','0422214405','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 06:05:15',0,NULL,3,1,3,1,'RA184506940CN\r ','au-buy\rMOMI002'),(22741,943895205012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','jjan2165','jljansen12@gmail.com','Jamie Jansen','1919 12th Ave SE','Puyallup','WA','UNITED STATES','98372','(360) 480-0953','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 06:09:16',0,NULL,3,1,1,1,'LK213363891CN ','eastar4\rPSGL001'),(22742,797158619007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',20.9,'au-buy','homebazzar3','mare3@optusnet.com.au','Maryanne Rizk','51 Tomah Street','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 06:21:14',0,NULL,3,1,11,1,'BJ01713661\r ','au-buy\rOTGR001'),(22743,943899813012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.39,'eastar4','emumyth','emumyth@juno.com','joe anthony urias','417 Burcham Ave','US','TX','UNITED STATES','78221','(210) 392-3810','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(22744,687472687013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','gkurdun','kurdun@busines-star.ru','Grigory Kurdun','Radujnaya 15/1','Vladivostok','Primorsky krai','RUSSIAN FEDERATION','690041','79147056050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 06:36:17',0,NULL,3,1,11,1,'BJ01713664\r ','eastar4\rOTGR005'),(22745,687474476013,230501434306,'Acer Aspire One 751 AO751h  Bluetooth Module EDR 2.0',1,'BTAC2014',9.88,'eastar4','andrew_deda','andrew_exe@hotmail.com','Andrei Dedkov','112 Osborne path','Newton','MA','UNITED STATES','02459-3543','(248) 730-6699','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 06:56:48',0,NULL,3,1,1,1,'LK213353214CN ','eastar4\racer 5pin1.25 20cm '),(22746,797169285007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','conniej87','constance_joachim@hotmail.com','Constance joachim','34 Tamarama St','Tamarama','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 07:17:45',0,NULL,3,1,11,1,'BJ01713659\r ','au-buy\rUM00040'),(22747,626831678003,130653453709,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',37.9,'cnfaner','deepseawatch','deepsea027@hotmail.com','Van Nguyen','141 Gracewood Crescent','Ottawa','ON','CANADA','K1T 0J5','(613) 220-1160','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 07:30:16',0,NULL,3,1,3,1,'RA184506984CN\r ','cnfaner\rGPS0010+ADPT001'),(22748,797171984007,170750956649,'New 3-section Auto on/off Cute penguin Sun/Rain Umbrella w/Enlarged Surface',2,'UM00046',43.98,'au-buy','poul4bikes','bpjensend@gotalk.net.au','Poul Jensen','178 King ST','Molong','New South Wales','AUSTRALIA','2866','0263669403','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 07:30:46',0,NULL,3,1,3,1,'RA184505462CN ','au-buy\rUM00046'),(22749,687484133013,230531260419,'40 Pin to 44 Pin 3.5 to 2.5 Laptop IDE Hard Drive Cable',5,'OTCN001',29.9,'eastar4','cwaash','ashley@winsoft.net.au','Ashley Hodgetts','1605 Henry Lawson Drive','Mudgee','New South Wales','AUSTRALIA','2850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 07:58:25',0,NULL,3,1,11,1,'BJ01713677\r ','eastar4\rOTCN001'),(22750,943926634012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 08:28:53',0,NULL,3,1,11,1,'BJ01713682\r ','eastar4\rBTAC2015\racer 6pin1.25 23cm '),(22751,805573490001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'buysia','alenamolla','alenaramazanovna@mail.ru','Alena Budaeva','Borovskoye shosse','Moskow','Moskow','RUSSIAN FEDERATION','119634','892-661-6199','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184504161CN\r ','buysia\rGPS0006'),(22752,8881330593957131,111,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',337.99,'eastar4','vyachin','vyachin@mail.ru','Vyachin Dmitry','Ulitza Malaya Naberegnayadom 3, kvartira 57','Moscow','','RUSSIA','125362','+79160250607',NULL,NULL,NULL,'2012-03-01 09:25:57',0,NULL,3,1,6,1,'EE651291516CN\r ','EASTAR4\r'),(22753,943943530012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',27.99,'eastar4uk','wigley50','wigley_50@hotmail.com','Colin Weeks','4 St Albans Close','Kettering','Northants','UNITED KINGDOM','NN15 5EB','01536358532','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 09:32:38',0,NULL,3,1,3,1,'RA184504317CN\r ','eastar4uk\rLGRM001'),(22754,687513275013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','rgnassau2012','rgnassau@aol.com','RYAN GILBERT','1200 NW 192nd Ter','Pembroke Pines','FL','UNITED STATES','33029-4511','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 10:46:55',0,NULL,3,1,1,1,'LK213892531CN\r ','eastar4'),(22755,788792477008,180758270999,'NIB genuine Philips SHS4843 Flexible Earhook Headphones Blue durable Bass Pipe',1,'HSPH005',19.99,'au-buy','02.carla','carla_devil@msn.com','Carla howard','19 osgathorpe road<br>Gladesville','Sydney','New South Wales','AUSTRALIA','2111','0298163135','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 10:50:46',0,NULL,3,1,11,1,'BJ01713707\r ','au-buy\rHSPH005\r澳标'),(22756,943979729012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','communikatephones','katyprice2005@aol.com','katy price','46 lion street<br>hay-on-wye','hereford','Herefordshire','UNITED KINGDOM','hr3 5aa','01497822968','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 11:36:40',0,NULL,3,1,3,1,'RA184504263CN\r ','eastar4uk\rHSJA002\r英标 '),(22757,686455176013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','dhurust','erguncavuslar@gmail.com','aysun yesilyurt','bagdat cad. 504 d3<br>bostanci','istanbul','','TURKEY','34744','+902163800390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 11:52:44',0,NULL,3,1,11,1,'BJ01713711\r ','eastar4\rCACN004'),(22758,943987059012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','bushpilotpete','pakaiser1970@yahoo.com','Peter Kaiser','6745 Avenue A','New Orleans','LA','UNITED STATES','70124-2122','(985) 686-9168','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 11:58:52',0,NULL,3,1,1,1,'LK213965052CN\r ','eastar4'),(22759,943998071012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','enemyour','kaz_dr@mail.ru','Yuriy Ushakov','Burova 22-51','Ust\'-Kamenogorsk','Kazakhstan','KAZAKHSTAN','070019','87232263808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 12:38:10',0,NULL,3,1,11,1,'BJ01713720\r ','eastar4\rUM00008'),(22760,852823260011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','contax111','fugitive11@msn.com','Mark Koch','730 Avenue A,  Apt 105','Snohomish','WA','UNITED STATES','98290','(425) 334-1050','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 12:39:18',0,NULL,3,1,1,1,'LK213940603CN\r ','eastar4'),(22761,632363900004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',3,'HSNO005',41.37,'cnfaner','yanni756922','romanyyanni@yahoo.com','yanni roumany','84 Highland Ave<br>Apt C1','jersey city','NJ','UNITED STATES','07306-5815','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 13:13:33',0,NULL,3,1,1,1,'LK213774129CN\r ','cnfaner'),(22762,852838092011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','veklons','valdemars.eklons@gmail.com','Valdemars Eklons','Indrika str, 4-4','Riga','Latvia','LATVIA','LV-1004','+371 28688111','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 13:25:22',0,NULL,3,1,11,1,'BJ01713712\r ','eastar4uk\rRELO003'),(22763,687549007013,230678127185,'New SAMSUNG SSG-3700CR Rechargeable 3D Glasses',1,'GLSG008',99.99,'eastar4','jboi7469','j.boiron@trio-solaire.com','josselyn boiron','15 bld la fayette<br>#1804','longueuil','QC','CANADA','j4k0b2','514 929 2506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 13:33:25',0,NULL,3,1,3,1,'RA184504379CN\r ','eastar4\rGLSG008'),(22764,944033078012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Ryan Hart Soliwoda','1036 SMETHWYCK PL','BENSALEM','PA','UNITED STATES','19020-4804','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 14:12:28',0,NULL,3,1,1,1,'LK213977413CN\r ','eastar4'),(22765,626913455003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','tention66626','wesley_smith_1993@hotmail.co.uk','wesley smith','107 woodward Road','Dagenham','Essex','UNITED KINGDOM','RM9 4ST','02085170566','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 14:44:15',0,NULL,3,1,3,1,'RA184504215CN\r ','cnfaner\rHSJA001\r英标'),(22766,944031530012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Louise Adamson/DXB 7644','18221 150th Ave<br>Springfield Gardens','Jamaica','NY','UNITED STATES','11413-4010','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 14:10:19',0,NULL,3,1,1,1,'LK213940400CN\r ','eastar4'),(22767,944050454012,220765484379,'Unlocked NEW Sierra Wireless WWAN MC8790 PCI-E HSUPA 3G',5,'WWSI006',170,'eastar4uk','jeroen2012azerty','jeroen@azerty.nl','Jeroen te Wierik','Kotterstraat 14','Raalte','','NETHERLANDS','8102 HZ','0572-328128','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 14:59:56',0,NULL,3,1,3,1,'RA184504348CN\r ','eastar4uk\rWWSI006'),(22768,687592372013,230678127185,'New SAMSUNG SSG-3700CR Rechargeable 3D Glasses',1,'GLSG008',99.99,'eastar4','eltarkus37','valas37@hotmail.com','Jonathan Comtois','1010 rang nord riviere chicot','Saint-cuthbert','QC','CANADA','j0k2c0','(450) 836-3528','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 16:18:24',0,NULL,3,1,3,1,'RA184504382CN\r ','eastar4\rGLSG008'),(22769,852897211011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','danielhernandez8180','daniel_hernandez8180@live.com','Daniel Hernandez','7687 Kilarney Ln Apt #81','Citrus Heights','CA','UNITED STATES','95610','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 16:40:56',0,NULL,3,1,1,1,'LK213931853CN\r ','eastar4'),(22770,852925492011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','bolduc945','bolduc05@hotmail.com','Bolduc Alain','945 du Fédéral','Sherbrooke','QC','CANADA','J1H 5A6','(819) 823-6828','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 17:15:30',0,NULL,3,1,11,1,'BJ01713710\r ','eastar4\rHSUE002'),(22771,687611347013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','schwaahed','darwinmjohnson@gmail.com','Darwin Johnson','115 W 29th St<br>Ste 807','New York','NY','UNITED STATES','10001-5106','(718) 636-1057','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 17:21:54',0,NULL,3,1,1,1,'LK213913320CN\r ','eastar4'),(22772,626956829003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','nosws6','zx12rdog@gmail.com','Steven Elam','po box 242','hampstead','NC','UNITED STATES','28443-0242','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 17:25:10',0,NULL,3,1,1,1,'LK213758466CN\r ','cnfaner'),(22773,944113850012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','jimani9_on_vashon','jimani9@comcast.net','James Jensen','14326 Glen Acres Rd SW','Vashon','WA','UNITED STATES','98070','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 17:25:43',0,NULL,3,1,1,1,'LK213915246CN\r ','eastar4'),(22774,852924075011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','vorlons69','reddragon@lycos.com','Kenneth Worley','201 Briarwood Dr','Douglassville','PA','UNITED STATES','19518-1509','(610) 917-3359','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 17:42:06',0,NULL,3,1,1,1,'LK213942286CN\r ','eastar4'),(22775,852949367011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','laleafrederic','fperonnet@sfr.fr','frederic peronnet','8 rue du carroir','issoudin','Centre','FRANCE','36100','0607459242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 18:11:01',0,NULL,3,1,3,1,'RA184504277CN\r ','eastar4uk\rSAFI001*3'),(22776,944138810012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','padel1s','padel2s@yahoo.gr','padelis papargiris','krimeas 66','glyfada','athens','GREECE','16562','(697)3797607','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 18:08:09',0,NULL,3,1,11,1,'BJ01713718\r ','eastar4\rMOAP001'),(22777,626985542003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','ccro4529','cucrowe@comcast.net','Charlie Crowe','4531 S Indian River Dr','fort pierce','FL','UNITED STATES','34982','(772) 461-6091','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 18:46:45',0,NULL,3,1,1,1,'LK213812900CN\r ','cnfaner'),(22778,632471230004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',2,'HSJA002',39.78,'cnfaner','similton.t','t.similton@live.com','Tareska Similton','6514 Rockwell Blvd W','Charlotte','NC','UNITED STATES','28269-2053','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 19:16:42',0,NULL,3,1,1,1,'LK213694350CN\r ','cnfaner'),(22779,852992274011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','oggybarnard','adamsimpson11@yahoo.com.au','adam simpson','34 Admers Wood<br>Vigo Village','Meopham','Kent','UNITED KINGDOM','DA13 0SP','01732824066','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 19:19:26',0,NULL,3,1,3,1,'RA184504351CN\r ','eastar4uk\rLGAD001'),(22780,944220546012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','sideshow_jules','sideshowjules@gmail.com','Julian Edgell','320 McEachern Cres','Orleans','ON','CANADA','K1E3K3','(613) 841-3356','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 20:17:28',0,NULL,3,1,3,1,'RA184504396CN\r ','eastar4\rPSGL001'),(22781,944240014012,220708794349,'New IBM Atheros AR5BXB6 AR5424 MINI PCI-E Card+antenna',1,'WLAT005+ANTY001',11.89,'eastar4','petertettelaar','peter@tettelaar.nl','Peter Tettelaar','Ligusterstraat 21','Den Haag','','NETHERLANDS','2563VA','0031703635675','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 20:46:50',0,NULL,3,1,11,1,'BJ01713721\r ','eastar4\rWLAT005+ANTY001'),(22782,853067963011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',88.99,'eastar4','hick.44','hick44@hotmail.com','Jeremy Hickey','65 Gregg Crt','Kitchener','ON','CANADA','n2a4b9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 21:24:43',0,NULL,3,1,3,1,'RA184504405CN\r ','eastar4\rGLOT001*2'),(22783,632526099004,140490323358,'New SAMSUNG WMN1000A ULTRA SLIM WALL MOUNT LED TV',1,'MOOE001',44.9,'cnfaner','vitiza','vigilgato@hotmail.com','Víctor Vigil Gato','Camino de las Magnolias, 265','Gijón','Asturias','SPAIN','33203','645977960','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 21:28:40',0,NULL,3,1,3,1,'RA184504229CN\r ','cnfaner\rMOOE001\rOEM'),(22784,853074120011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','artursbl50','artursbl35@hotmail.co.uk','Arturs Bluzma','29 Highfield Gardens','Margate','Kent','UNITED KINGDOM','CT9 5QU','01843224253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 21:35:23',0,NULL,3,1,3,1,'RA184504246CN\r ','eastar4uk\rGPS0010'),(22785,805890208001,110826639785,'New UNLOCKED Sierra Wireless MC8780 7.2Mbps 3G Mini PCI-E Module+3G WWan antenna',1,'WWSI004+ANCN001',39.99,'buysia','aidan.purcell','aidanpurcell@yahoo.ie','Master Aidan Purcell','10 Clonaslee<br>Gurthlandroe','Nenagh','Tipperary','IRELAND','roi','0860863031','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-01 22:10:46',0,NULL,3,1,3,1,'RA184504878CN\r ','buysia\rWWSI004+ANCN001'),(22786,627070500003,130596105709,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',18.98,'cnfaner','harleygirlmay','may2008xxoo@yahoo.com','Winson Wong C/O Prudential Overall Supply','1429 N Milpitas Blvd','Milpitas','CA','UNITED STATES','95035','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 22:30:10',0,NULL,3,1,1,1,'LK213765351CN\r ','cnfaner\r'),(22787,632548988004,140675757780,'New 3D Active Shutter TV Glasses Compatible for LG AG-S110 AGS110',1,'GLOT001',43.89,'cnfaner','ateotthonod','maxxautohaz@gmail.com','tarkany laszlo','sarlo u.5','szeged','csongrad','HUNGARY','6726','0036302574398','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 22:37:37',0,NULL,3,1,3,1,'RA184504303CN\r ','cnfaner\rGLOT001'),(22788,944318298012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',27.99,'eastar4uk','leighdizzy','leigh1202@hotmail.co.uk','leigh limerick','61 toorack road','harrow','Middlesex','UNITED KINGDOM','ha3 5hs','07725910801','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 23:07:59',0,NULL,3,1,3,1,'RA184504334CN\r ','eastar4uk\rLGRM001'),(22789,687755532013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','drfish1211','dprokofieff@yahoo.com','Doug Prokofieff','6590 Bayview dr','Excelsior','MN','UNITED STATES','55331-9704','(612) 301-0713','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 23:50:07',0,NULL,3,1,1,1,'LK213929228CN\r ','eastar4'),(22790,847651033011,320394931547,'Acer Extensa 5220 5620 5620Z Bluetooth Module 2.0+cable',1,'BTAC2006',9.88,'eastar4','vitota0','vitor.barreiro@gmail.com','Vitor Barreiro','Rua D. António Ferreira Gomes, Nº 49<br>4420-105 S. Cosme Gondomar','Gondomar','Portugal','PORTUGAL','4420','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 23:46:03',0,NULL,3,1,11,1,'BJ01713729\r ','eastar4\racer 4pin1.25 15cm \rBTAC2006'),(22791,944342586012,220459993122,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',9.88,'eastar4','forthedishwasher','donttelldallas@yahoo.com','stuart mank II','261 Oyster River Rd','Warren','ME','UNITED STATES','04864-4248','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 00:12:31',0,NULL,3,1,1,1,'LK213882993CN\r ','eastar4'),(22792,853140706011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','ductri123','ducnguyen13240@yahoo.com','Duc Tri Nguyen','13215 Veterans Memorial dr','Houston','TX','UNITED STATES','77014-1601','(281) 583-9773','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 00:18:26',0,NULL,3,1,1,1,'LK213878092CN\r ','eastar4'),(22793,805936872001,110822404553,'New GENUINE NOKIA BH-204 BLUETOOTH HEADSET BH 204',1,'HSNO008',13.98,'buysia','nick-ka-76','nick76gr@hotmail.gr','Nikolaos Tselempis','Alkinoy 14B','Kavala','','GREECE','65403','6972607470','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-02 00:23:31',0,NULL,3,1,11,1,'BJ01713708\r ','buysia\rHSNO008\r欧标'),(22794,789134062008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',42.99,'au-buy','beehel','brihel44@bigpond.com','brian hardman','42  hewitt drive','grovedale','Victoria','AUSTRALIA','3216','0352430679','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 00:58:08',0,NULL,3,1,3,1,'RA184504232CN\r ','au-buy\rGLOT001'),(22795,944358377012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','18oct03','joethecabinetmaker@comcast.net','Joseph Burton','103 E Lillian St<br>po 236','Hebron','MD','UNITED STATES','21830','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 01:01:37',0,NULL,3,1,1,1,'LK213886519CN\r ','eastar4'),(22796,632586632004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.89,'cnfaner','laissa.soares','soares.laissa@gmail.com','Laissa Soares','SCLN 115, bloco A, sala 213','Brasília','Distrito Federal','BRAZIL','70772-510','556182388000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 01:33:41',0,NULL,3,1,3,1,'RA184504250CN\r ','cnfaner\rLGAD001'),(22797,797593880007,170728988806,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET',1,'HSNO019',39.99,'au-buy','swoo3807','woodssj69@hotmail.com','Steven Woods','P.O. Box 1045<br>Morphett Vale','Adelaide','South Australia','AUSTRALIA','5162','0432231400','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 02:12:49',0,NULL,3,1,3,1,'RA184504285CN\r ','au-buy\rHSNO019\r澳标'),(22798,8881330654932211,111,'New HP MCE Media Center Remote Control big+ IR RECEVE',1,'OTHP004',21.9,'eastar4','er0fey','er0f@mail.com','Andrey Erofeev','1Kozhuhovskij proezd dom19 korpus2 kv3','Москва','','RUSSIAN FEDERATION','115280 ','',NULL,NULL,NULL,'2012-03-02 02:22:12',0,NULL,3,1,11,1,'BJ01713715\r ','eastar4\rOTHP004 '),(22799,8881330655970173,111,'Item title:3 pairs 3D Active shutter Glasses for Sony TDG-BR100',1,'GLOT001*3',78.99,'eastar4uk','braakman2653','r.braakman4@upcmail.nl','R. Braakman','Gersthove 7','Diemen ','HM','NETHERLANDS','1112','',NULL,NULL,NULL,'2012-03-02 02:39:30',0,NULL,3,1,3,1,'RA184504294CN\r ','EASTAR4UK\r没下来\rGLOT001*3 '),(22800,944417032012,220759518517,'New Logitech H555 Headset 981-00026 Stereo for laptop',1,'HSLO001',22.99,'eastar4uk','jara2212','steven@prague-airport-transfers.co.uk','Stepan Jara','141/105 Porchland 2, Moo 11<br>Soi Chaiyapeuk 3, Nongpreu','Banglamung, Chonburi','Thailand','THAILAND','20150','66834320254','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 03:55:15',0,NULL,3,1,11,1,'BJ01713714\r ','eastar4uk\rHSLO001'),(22801,805996319001,110808693265,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.99,'buysia','daddyg1508','daddyg1@earthlink.net','Willie Gordon','508 Meadow Lake Dr','Columbia','SC','UNITED STATES','29203-2420','(803) 754-0217','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-02 03:56:09',0,NULL,3,1,1,1,'LK214286975CN\r ','buysia'),(22802,789181750008,180762062511,'New lady lotus leaves outdoor sun/rain stick Umbrella   6 colors available',1,'UM00002',24.99,'au-buy','cmcea2','camcarmc@bigpond.com','Carlie  McEachern','58 Newton cct','Thurgoona','New South Wales','AUSTRALIA','2640','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 03:57:11',0,NULL,3,1,11,1,'BJ01713722\r ','au-buy\rUM00002\rmaroon\r'),(22803,853218267011,320394916388,'Acer Aspire 5570 5570Z Bluetooth Module EDR 2.0+cable',1,'BTAC2015',9.88,'eastar4','dbao1981','baodepei@gmail.com','Depei Bao','695 Tasman Dr<br>Apt 3220','Sunnyvale','CA','UNITED STATES','94089-1694','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 04:45:50',0,NULL,3,1,1,1,'LK214242206CN\r ','eastar4\racer 6pin1.25 23cm '),(22804,853228141011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','mrkmrk1010','mrkmrk10@hotmail.com','Mohammed AL Maktoum','Palm Jumairah frond k street','Dubai','UAE','UNITED ARAB EMIRATES','00971','00971508801111','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 05:28:09',0,NULL,3,1,3,1,'RA184504325CN\r ','eastar4\rGPS0007'),(22805,687830646013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','shanj74-27','shopgirl02@live.com','Shannon Jenkin','25 Rebellion Circuit','Beaumont Hills','New South Wales','AUSTRALIA','2155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 05:47:52',0,NULL,3,1,11,1,'BJ01713723\r ','eastar4\rUM00042'),(22806,944454834012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','windspeedjz','windspeed@gmail.com','Ching Chong Wee','Blk 207 Bishan St 23 #15-397','default','','SINGAPORE','570207','97962350','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 06:33:38',0,NULL,3,1,11,1,'BJ01713717\r ','eastar4\rMOMI002'),(22807,944462912012,220886923591,'New lady lotus leaves outdoor sun/rain stick Umbrella',1,'UM00002',14.95,'eastar4uk','n3omy','my_thi_le@hotmail.com','My Le','2715 E Broadway (Back Door WEST side)<br>n/a','Vancouver','BC','CANADA','V5M 1Y7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 07:12:06',0,NULL,5,1,18,1,NULL,'eastar4uk\rUM00002\r蓝色的\r荷叶边伞\r是否要其他色的\r客户要撤单  退钱'),(22808,944466943012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','blissfulcouture','tony@bazemoreconsulting.com','Blissful Couture','3409 N Utah St','Arlington','VA','UNITED STATES','22207','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 07:25:56',0,NULL,3,1,1,1,'LK214369431CN\r ','eastar4'),(22809,853259762011,320855036556,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista small',1,'RCHP002',8.99,'eastar4','kabunaaj','k.abunaaj@yahoo.com','Kamal Abunaaj','Dourwaza Engineering<br>P.O.Box 28102 Safat','Kuwait','Kuwait','KUWAIT','13141','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 07:57:51',0,NULL,3,1,11,1,'BJ01713728\r ','eastar4\rRCHP002'),(22810,806041632001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','igrmichr','igrmic@gmail.com','Božidar Graber','Iločka 28','Bjelovar','','CROATIA','43000','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-02 08:07:05',0,NULL,3,1,3,1,'RA184504970CN\r ','buysia\rGPS0006'),(22811,806048772001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','igrmichr','igrmic@gmail.com','Ivica Grmic','Ilocka 39','Bjelovar','','CROATIA','43000','38598545454','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-02 08:09:28',0,NULL,3,1,3,1,'RA184504983CN\r ','buysia\rGPS0006'),(22812,944479395012,220825062136,'New 3.0 Bluetooth BCM2070 Module+cable Lenovo E46A E46L',1,'BTLE3001',19.98,'eastar4','dmglobenko','globendi@rambler.ru','Dmitry Globenko','Musa Djalil str., 27-2, flat 521','Moscow','Moscow','RUSSIAN FEDERATION','115580','+7(915)1439935','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:16:02',0,NULL,3,1,11,1,'BJ01713726\r ','eastar4\rBTLE3001'),(22813,944487099012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','28554','saksit11111@hotmail.com','saksit kiratipan','333/22 kingkaew 14/1<br>rajatheva bangplee','samut prakarn','','THAILAND','10540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:46:20',0,NULL,3,1,3,1,'RA184504935CN\r ','eastar4\rPSGL001'),(22814,944489346012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','aidanramsayaidan','aidan.ramsay@gmail.com','Aidan Ramsay','8-25/29 Alfred St','Ramsgate Beach','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:54:09',0,NULL,3,1,3,1,'RA184504921CN\r ','eastar4\rGLOT001'),(22815,8881330678737258,111,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4',' bb210569-2008  ','berthier.bruno@sfr.fr','Bruno BERTHIER','5 rue du viognier','MAGALAS ','','FRANCE','34480','',NULL,NULL,NULL,'2012-03-02 08:58:57',0,NULL,5,0,18,0,' ','多录了'),(22817,853283386011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','10syf','syf7991@yahoo.com','MARY SHEHATA','6807 Forest Ave<br>Apt 1L','ridgewood','NY','UNITED STATES','11385-4451','(718) 386-8021','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 09:33:33',0,NULL,3,1,1,1,'LK214416397CN\r ','eastar4\r黑色的'),(22816,944487957012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','bb210569-2008','berthier.bruno@sfr.fr','Bruno BERTHIER','5 rue du viognier','MAGALAS','Languedoc-Roussillon','FRANCE','34480','0681796173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:48:45',0,NULL,3,1,3,1,'RA184504949CN\r ','eastar4\rPSGL001'),(22818,8881330686447828,111,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*2',0,'eastar4','wills811','sharonkwills@gmail.com','Sharon Wills','2451 Bankston Cir','Snellville','GA','UNITED STATES','30078-5726','(770) 736-0518',NULL,NULL,NULL,'2012-03-02 11:07:27',0,NULL,3,1,3,1,'RA184505913CN ','GLOT001*2\r补货 \r就补发两副 ，不是四副'),(22819,938080528012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','g0osie','t0mie@hotmail.com','Thommy Sophabmixay','8 Strang Street','Hoppers crossing','Victoria','AUSTRALIA','3029','0425731958','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 11:44:06',0,NULL,5,0,18,0,NULL,'eastar4'),(22820,632701432004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.89,'cnfaner','landrover.shandaevskiy','sambia-auto@mail.ru','Vadim Shandaevskiy','Borzova Str, 58D-10','Kaliningrad','','RUSSIAN FEDERATION','236023','+7 906 2375926','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 12:04:06',0,NULL,3,1,3,1,'RA184505578CN ','cnfaner\rLGAD001'),(22821,797754496007,170784472672,'New Genuine IBM/ThinkPad Mini PCI Atheros 5213A 802.11 a/b/g AR5BMB-44 Card',1,'WLAT006',9.49,'au-buy','martishaw','martiz@clara.co.uk','martin shaw','17<br>florence way','alton','Hampshire','UNITED KINGDOM','GU34 1UG','07733231310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 12:58:54',0,NULL,3,1,11,1,'BJ01713757 ','au-buy\rWLAT006'),(22822,687926938013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','pasqualeleuzzi','patleuzzi@att.net','Pasquale Leuzzi','30 Easton st','Stony Point','NY','UNITED STATES','10980-2702','(845) 947-2360','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 14:10:12',0,NULL,3,1,1,1,'LK220118698CN\r ','eastar4'),(22823,687928753013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','agentk6_123','agentk6@gmail.com','Kent Howlett','11 Degilbo st','Maryborough','Queensland','AUSTRALIA','4650','0432122426','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 14:20:15',0,NULL,3,1,3,1,'RA184505414CN ','eastar4\rGLOT001*4'),(22824,797337684007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','irini05','tsisot@gmail.com','Sotirios Tsitsimpikos','36 Navarinou Str.','Kamatero','Attica','GREECE','13451','2102313025','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 14:39:34',0,NULL,3,1,3,1,'RA184505745CN ','au-buy\rPSGL001*2'),(22825,944621010012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',33.7,'eastar4uk','hugues1145','med.old@free.fr','hugues lhuillier','29 rue Salluste','Strasbourg','Alsace','FRANCE','67200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 15:16:41',0,NULL,3,1,3,1,'RA184505839CN ','eastar4uk\rGLOT005'),(22826,853404798011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','getgod','ivokik@gmail.com','Ivo Ivanov','Bastion<br>10','Gorinchem','','NETHERLANDS','4207GE','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 15:37:57',0,NULL,3,1,11,1,'BJ01713732 ','eastar4uk\rCACN004'),(22827,632763403004,140667903666,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Antenna *3',1,'WLAT001+ANTY002',15.89,'cnfaner','uzer111','vitalya@tut.by','Alshevsky Vitalij','18-28, Kuzmy Chornogo st.','Minsk','','BELARUS','220012','(37529) 181-3448','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 16:14:02',0,NULL,3,1,3,1,'RA184505119CN\r ','cnfaner\rWLAT001+ANTY002'),(22828,853425573011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','sector-g','martinuwegruenanger@hotmail.com','Martin Grunanger','Flat 2<br>213 Devons Road','London','London','UNITED KINGDOM','E3 3QX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 16:25:09',0,NULL,3,1,3,1,'RA184505958CN ','eastar4uk\rRELO003'),(22829,944652759012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Leonard E. Malkin','140 E 72nd St<br># 8A','New York','NY','UNITED STATES','10021-4268','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 16:26:39',0,NULL,3,1,1,1,'LK220132315CN\r ','eastar4'),(22830,943468638012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','2065pogo','jimponderc@gmail.com','Jim Ponder','2065 Evanor Ln','Cincinnati','OH','UNITED STATES','45244-2915','(513) 266-1722','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 16:45:15',0,NULL,3,1,1,1,'LK220074215CN\r ','eastar4\racer 4pin1.25 8cm'),(22831,632773537004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','jayz89jason','lovelifelovemusic@hotmail.com','Jason Gold','20 st mungo\'s whynd','Alloa','Clackmannan','UNITED KINGDOM','FK10 1LQ','07909227487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 16:48:04',0,NULL,3,1,3,1,'RA184505808CN ','cnfaner\rHBPH003'),(22832,627298230003,130554636475,'NIB i.Tech SolarVoice 908 Bluetooth Headset Solar Power',1,'HSIT001',45.99,'cnfaner','duke_rs17','duke17rs@hotmail.com','Rolland Smith','303 4th St S','Nampa','ID','UNITED STATES','83651-3726','(419) 690-6587','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-02 17:05:26',0,NULL,3,1,1,1,'LK220015755CN\r ','cnfaner'),(22833,853449364011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','2011alexi12372','alexi12372@gmail.com','aleksey martinenko','shayatim 2-26','ashdod','darom','ISRAEL','77441','0526082818','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 17:17:02',0,NULL,3,1,11,1,'BJ01713779 ','eastar4\rUM00040'),(22834,687981872013,230658778017,'Original Yamaha AV Remote control RAV255 WE45880 EU',1,'RCYA001',43.99,'eastar4','joseph1850','joseph.eyheramendy@wanadoo.fr','Joseph','Eyheramendy<br>7 Rue Donatello','Courbevoie','Ile-de-France','FRANCE','92400','0625322358','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 17:14:26',0,NULL,3,1,3,1,'RA184505405CN ','eastar4\rRCYA001'),(22835,944696258012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','basilfedotov29','basilfedotov@gmail.com','Fedotov  Vasily','Glazunova 6/11 - 2','Nizhny Novgorod','Nizhegorodskaya oblast','RUSSIAN FEDERATION','603062','+79200146106','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 17:48:56',0,NULL,3,1,3,1,'RA184505989CN ','eastar4\rGLOT001*2'),(22836,850869730002,120844622267,'New GENUINE Philips SHB6102 Bluetooth Stereo Headset  SHB6102',1,'HSPH001',74.89,'buysia','mvrvergara','mvrvergara@hotmail.com','Marcos Vergara','Avenida SAP, 188','São Leopoldo','RS','BRAZIL','93022-718','+555196192852','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-02 18:14:56',0,NULL,5,0,18,1,NULL,'buysia\rHSPH001\r美标\r缺货已退款'),(22837,944714533012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Cara Crafton','2307 DUNLAVY ST','HOUSTON','TX','UNITED STATES','77006-1707','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 18:23:08',0,NULL,3,1,1,1,'LK220123185CN\r ','eastar4'),(22838,853485738011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','avl77andre','losev7777@gmail.com','Andre Losev','Simferopolskaya st, d.21, kv.64','Klimovsk','Moskovskaya oblast','RUSSIAN FEDERATION','142184','(903)133-4623','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 18:28:16',0,NULL,3,1,11,1,'BJ01713749 ','eastar4\rWLIN011'),(22839,944737850012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',27.99,'eastar4uk','t666hay','hayward.ta@sky.com','Tracy Hayward','17 victoria road, capel-le-ferne','folkestone','Kent','UNITED KINGDOM','ct18 7lr','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 19:00:32',0,NULL,3,1,3,1,'RA184506009CN ','eastar4uk\rLGRM001'),(22840,683961008013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','catemurray','catie_murray@iinet.net.au','CATE MURRAY','PO BOX 206','MOUNT LAWLEY','WESTERN AUSTRALIA','AUSTRALIA','6929','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 19:14:30',0,NULL,5,0,18,0,NULL,'eastar4\r'),(22841,944748844012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Ken Faulkenberry','1331 OCEAN BLVD<br>STE 201','SAINT SIMONS ISLAND','GA','UNITED STATES','31522-4237','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 19:17:17',0,NULL,3,1,1,1,'LK220111845CN\r ','eastar4'),(22842,944796398012,220966250605,'2 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*2',197.99,'eastar4','xan-go','vipstartgo@gmail.com','Popsuy Maxim','Niznevolzkaya nabereznaya 1-14','Nizhniy Novgorod','','RUSSIAN FEDERATION','603001','+7915 934-0055','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 20:37:28',0,NULL,3,1,3,1,'RA184505493CN ','eastar4\rGLSG008*2'),(22843,944828654012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','hollinj','jim@hostingsystems.co.uk','Jim Hollinshead','Blakewell Cottage, Clewlows Bank','Stoke On Trent','Staffordshire','UNITED KINGDOM','ST99LN','01782503940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 21:30:48',0,NULL,3,1,3,1,'RA184505842CN ','eastar4uk\rHSJA002\r英标'),(22844,688080986013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','epidator','ebay@pruter.net','Uwe Pruter','Waldallee 10','Königs Wusterhausen','','GERMANY','15712','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 21:40:42',0,NULL,3,1,11,1,'BJ01713752 ','eastar4\rWLAP008'),(22845,798008108007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','cinkon','soda@wp.pl','Marcin Cichocki','0/1<br>15 Napiershall St.','Glasgow','Glasgow (City of)','UNITED KINGDOM','G20 6HQ','7825758168','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'au-buy'),(22846,944874824012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',3,'PSGL001',224.97,'eastar4','cdix5589','chrisnoxid@gmail.com','Christopher Dixon','17827 111st. N.W.','Edmonton','AB','CANADA','T5X 6J3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 23:05:48',0,NULL,3,1,3,1,'RA184505520CN ','eastar4\rPSGL001'),(22847,853634235011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','s.gilbert10','frank.1960@hotmail.co.uk','frank gilbert','halton fabrications ltd<br>picow farm road','runcorn','Cheshire','UNITED KINGDOM','wa7 4jb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 23:19:42',0,NULL,3,1,3,1,'RA184505873CN ','eastar4uk\rLGAD001'),(22848,853649825011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','execgeek','kbaggs@yahoo.com','Kevin Baggs','10-1055 Riverwood Gate','Port Coquitlam','BC','CANADA','V3B 8C3','(604) 537-4690','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 00:00:03',0,NULL,3,1,11,1,'BJ01713743 ','eastar4\rWLIN011'),(22849,688126638013,230688874079,'New Apple Steve Jobs 8GB USB Flash Drive',2,'UDAP004',45.98,'eastar4','indyblueyes1','nascarlover146217@yahoo.com','Kristi Lester','8244 Forward Pass Rd','Indianapolis','IN','UNITED STATES','46217-4422','(317) 985-9074','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 00:23:43',0,NULL,3,1,1,1,'LK220096992CN\r ','eastar4'),(22850,851045090002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','anthonygreenwood05','anthonygreenwood105@gmail.com','Anthony Greenwood','27 Luisa Street','Edmonton','Queensland','AUSTRALIA','4869','0740455408','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 00:36:47',0,NULL,3,1,3,1,'RA184505785CN ','buysia'),(22851,944916158012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','biyeume','chn.super@yahoo.com','NINH CHU','2 KATHLEEN CT','SUNSHINE','Victoria','AUSTRALIA','3020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 01:05:48',0,NULL,3,1,11,1,'BJ01713758 ','eastar4\rUM00008'),(22852,688143935013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',4,'UM00042',79.96,'eastar4','huntindabay','sti_nick@hotmail.com','Nick  Coddington','4A Derna Rd','Ashburton','Victoria','AUSTRALIA','3147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 01:48:27',0,NULL,5,0,18,1,NULL,'eastar4\rUM00042\r由于缺货\r客户要求退钱   已退钱'),(22853,632944406004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','jhooper-2012','hooperj13@gmail.com','Jessie Hooper','4900 Fox Run Rd','Buckner','KY','UNITED STATES','40010-8808','(502) 758-4574','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-03 02:16:29',0,NULL,3,1,1,1,'LK220049034CN\r ','cnfaner'),(22854,627466039003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','jakell_04','jakell04@yahoo.com','Glenn Morley','11 Middle st','Sanford','ME','UNITED STATES','04073-3847','(207) 219-1828','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-03 02:54:51',0,NULL,3,1,1,1,'LK219992113CN\r ','cnfaner'),(22855,851087178002,120841235263,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',109.99,'buysia','drewotto','jtabor3489@msn.com','Judy Thorpe','2004 13th St SW','Austin','MN','UNITED STATES','55912-1726','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 03:14:36',0,NULL,3,1,1,1,'LK220040503CN\r ','buysia'),(22856,806466861001,110819588741,'New Original Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'buysia','tolyask','tolyaskrg@gmail.com','Anatoliy Kozhayev','ulitsa Satybaldina, 11/2-66','Karaganda','Karagandinskaya oblast','KAZAKHSTAN','100024','7212339924','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 04:06:11',0,NULL,3,1,11,1,'BJ01713775 ','buysia'),(22857,944975349012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','sergeyk6887','korolc@mail.ru','Sergey Korolkov','ul. Lenina 105a kv.11','Neya','Kostromskaya obl','RUSSIAN FEDERATION','157330','(909)256-6212','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 04:26:37',0,NULL,3,1,3,1,'RA184505564CN ','eastar4\rPSGL001'),(22858,853734496011,320816532173,'4 pairs of New SAMSUMG SSG-3500CR 3D Lunettes Actives Rechargeable Glasses',1,'GLSG010*4',295.99,'eastar4','hsv_sv89','hsv2001@iinet.net.au','Marcus Katalinic','28 Stanley Crescent','Mount Martha','Victoria','AUSTRALIA','3934','0402700361','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 05:23:41',0,NULL,3,1,4,1,'YW867611361CN\r ','eastar4\rGLSG010*4'),(22859,688185475013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','solodx21','dalexbor@gmail.com','Boris Dolgushin','ul. LOMONOSOVA, dom 12, kv. 53','MIRNY-12','Arkhangelskaya oblast','RUSSIAN FEDERATION','164170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 05:30:29',0,NULL,3,1,11,1,'BJ01713763 ','eastar4\rWLAP008'),(22860,851118422002,120868118494,'New Philips Sonicare Flexcare Toothbrush Handle HX6930 + travel charger',1,'HBPH002+HBPH003',86.99,'buysia','toddllf','toddcoue@gmail.com','Todd C Ouellette','104 Country Club Ln','Muscle Shoals','AL','UNITED STATES','35661-2979','(256) 710-8811','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 05:36:30',0,NULL,3,1,1,1,'LK220035123CN\r ','buysia \r换成6950'),(22861,624228687003,130626402767,'New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',2,'GLOT001',87.78,'cnfaner','seymour15','sandio55@rochester.rr.com','Sandra Osterwise','3 Alpine Knl','Fairport','NY','UNITED STATES','14450-1721','(585) 425-7443','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-03 06:39:11',0,NULL,3,1,1,1,'LK220056021CN\r ','cnfaner'),(22862,945006615012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',2,'UM00001',39.98,'eastar4','petrolhead355','elfs@internode.on.net','tammy elphinstone (lions)','145 old surry rd','burnie','Tasmania','AUSTRALIA','7320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 06:46:48',0,NULL,3,1,11,1,'BJ01713767 ','eastar4\rUM00001'),(22863,688203068013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','hroman-sk','roman@havelka.sk','Roman Havelka','Slnečnicová 529','Hviezdoslavov','Slovakia','SLOVAK REPUBLIC','93041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 07:50:19',0,NULL,3,1,11,1,'BJ01713762 ','eastar4\rBTLE3001'),(22864,945024310012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','l1zz1e','efrancis@fastmail.fm','Elizabeth N. Francis','35 Brisbane Road','Ebbw Vale','Queensland','AUSTRALIA','4304','610414241865','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 08:02:30',0,NULL,3,1,11,1,'BJ01713783 ','eastar4uk\rOTGR001'),(22865,945029489012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002+ANTY001',12.99,'eastar4','cymenvig','cymenvig@gmail.com','8th Light - Cymen Vig','656 W Randolph St<br>Ste 5E','Chicago','IL','UNITED STATES','60661-2165','(773) 360-0641','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 08:25:46',0,NULL,3,1,1,1,'LK220095731CN\r ','eastar4'),(22866,945035081012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','arkadygrigorev','arcadius@rambler.ru','Arkady Grigoriev','Nizhegorodskaya 13a-149','Moscow','Moscow','RUSSIAN FEDERATION','109029','+79161245521','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 08:53:15',0,NULL,3,1,3,1,'RA184505723CN ','eastar4\rPSGL001\r\r\r'),(22867,633011156004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.8,'cnfaner','bastelwalter','bastelwalter@arcor.de','Walter Kitzinger','Berliner Str.128','Bruchsal','','GERMANY','76646','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 09:15:04',0,NULL,3,1,3,1,'RA184505595CN ','cnfaner\rWLAP008'),(22868,853789204011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',36.99,'eastar4','hipermedia','hipermedia.split@gmail.com','Boris Ostojic','Kukuljeviceva 22','Split','SD','CROATIA','21000','+38598490509','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 09:19:25',0,NULL,3,1,11,1,'BJ01713750 ','eastar4\rWWSI004'),(22869,789739613008,180821320427,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card+Tyco 2.4/5.0GHz Antenna',1,'WLAT001+ANTY002',15.95,'au-buy','wahhaung','rexieching@optusnet.com.au','REXIE CHING','4 DICKINSON STREET<br>HADFIELD','MELBOURNE','Victoria','AUSTRALIA','3046','61393235673','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 10:01:23',0,NULL,3,1,11,1,'BJ01713639\r ','au-buy\rWLAT001+ANTY002'),(22870,789743403008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','petered_64','tenjho_4@hotmail.com','Attn: Peter Murphy','95 Hallen Close','Swinger Hill','Australian Capital Territory','AUSTRALIA','2606','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 10:16:02',0,NULL,3,1,11,1,'BJ01713751 ','au-buy\rBALO001'),(22871,688240016013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','ronumar','kubangp@rambler.ru','Александр Макаренко','ул.Светлая д.10 кв.1','п.Октябрьский','Краснодарский край','RUSSIAN FEDERATION','353244','+79183877672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 10:48:04',0,NULL,3,1,11,1,'BJ01713769 ','eastar4\rUM00009'),(22872,853824594011,320730549149,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',2,'GLOT001',53.98,'eastar4uk','pavelozzo','cezarpavelescu@hotmail.com','Cezar Pavelescu','Aleea Stanila nr.6, bl. H10, sc. A, ap. 18, sector 3','Bucharest','SAI','ROMANIA','032709',' 0722546208','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 11:03:52',0,NULL,3,1,3,1,'RA184505825CN ','eastar4uk\rGLOT001'),(22873,945096600012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Nancy Raymond','4424 Wedgewood Dr','Alton','IL','UNITED STATES','62002-6941','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 11:44:12',0,NULL,3,1,1,1,'LK220134656CN\r ','eastar4'),(22874,687242285013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',49.99,'eastar4','silence-87','silence87@gmail.com','Inna Tihomirova','Pskovskaya street , 48-3-224','Velikiy Novgorod','novgorodskay oblast','RUSSIAN FEDERATION','173009','89022834332','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 12:15:56',0,NULL,3,1,3,1,'RA184505621CN ','eastar4\rLGAD001'),(22875,853851018011,320742963659,'NIB Genuine Philips SPZ5000 PC Webcam Instant You Tube',1,'PHVE001',21.99,'eastar4uk','cloudgroover','ghengishaun@hotmail.com','Shaun Sanderson Inc.','1 Maple Close','Brentwood','Essex','UNITED KINGDOM','cm13 2ea','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 12:19:34',0,NULL,3,1,3,1,'RA184505581CN ','eastar4uk\rPHVE001'),(22876,806597178001,110827822360,'New Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card Over AR5008',2,'WLAT010',17.98,'buysia','eekhoorn_mike','maikel@tronic.nl','Maikel Roetgerink','St. Annabrinkstraat 33','Delden','','NETHERLANDS','7491XD','0031612173057','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 12:42:41',0,NULL,3,1,11,1,'BJ01713741 ','buysia\rWLAT010'),(22877,853868590011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',52.99,'eastar4uk','kitrinomauros','babisaslanidis@gmail.com','Babis Aslanidis','Stefanou Sarafi 54','Agia Varvara','Athens','GREECE','12351',' 6974073291','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 13:10:04',0,NULL,3,1,3,1,'RA184505811CN ','eastar4uk\rGLOT001*2'),(22878,688284119013,230695960165,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',86.9,'eastar4','ieatmyowndandruff','b_bobaloobob@hotmail.com','Robert Reedyk','200 Montreal st','Kingston','ON','CANADA','K7L3G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 13:39:29',0,NULL,3,0,3,1,'RA184505706CN ','eastar4\rHBPH001+HBPH003'),(22879,853890237011,320787383550,'NEW Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',13.95,'eastar4uk','topick81','topick@yandex.ru','Konstantin Topolnitsky','Sergryeva-Tsenskogo, 14','Vinnitsa','','UKRAINE','21034','00380674302738','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 14:00:05',0,NULL,3,1,11,1,'BJ01713764 ','eastar4uk\rUM00004'),(22880,633081509004,140676374143,'New Grohe handheld Shower Head big water output+hose',1,'OTGR005+OTGR002',38.9,'cnfaner','giladco9','gilad403@walla.co.il','Gilad Cohen','44 Hadekel st.<br>p.o. box 27','Lapid','','ISRAEL','73133','972528508403','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 14:15:10',0,NULL,3,1,3,1,'RA184505365CN ','cnfaner\rOTGR005+OTGR002'),(22881,627624353003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','bigg-brother','peterhajder@yahoo.com','Peter Hajder','400 Woodview Cir<br>Apt B','Elgin','IL','UNITED STATES','60120-7170','(630) 625-2146','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-03 15:40:32',0,NULL,3,1,1,1,'LK220033900CN\r ','cnfaner'),(22882,945214171012,220592392461,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002+ANTY001',12.99,'eastar4','hvh_prive','hvharselaar@gmail.com','Hendrik van Harselaar','Pullstraat 29','Amersfoort','','NETHERLANDS','3814VA','0610911742','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 16:11:25',0,NULL,3,1,11,1,'BJ01713755 ','eastar4\rWLHP002+ANTY001'),(22883,688326075013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','herbie-024','hermandevries@hetnet.nl','H.J. de Vries','Slingerkogelstraat<br>6','Nijmegen','','NETHERLANDS','6515GG','0625251476','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 16:01:27',0,NULL,3,1,11,1,'BJ01713746 ','eastar4\rWLAT010'),(22884,853970109011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','mldaries','michaeldaries@gmail.com','Michael D\'Aries','21 Country Club Ln','East Hanover','NJ','UNITED STATES','07936-2502','(973) 476-9017','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 16:44:12',0,NULL,3,1,1,1,'LK220094197CN\r ','eastar4'),(22885,854011839011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','aleckonanony2012','aleckonanony@yahoo.com','Narine Hacoupian','Komitas , 38/2','Yerevan','','ARMENIA','0037',' 003793219423','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 17:57:39',0,NULL,3,1,11,1,'BJ01713744 ','eastar4\rTRSN001'),(22886,945283838012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','cristaorti','cristiortan@yahoo.co.uk','cristian ortan','10 the grove','potters bar','Hertfordshire','UNITED KINGDOM','en6 5lj','07967163171','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 18:02:28',0,NULL,3,1,3,1,'RA184505480CN ','eastar4uk\rOTGR001+OTGR002'),(22887,854013687011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','mrask2012','jami3333@gmail.com','MOSHE RASK','16 HAHARZIT','HOLON','','ISRAEL','58457',' 0523525258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 18:08:25',0,NULL,3,1,11,1,'BJ01713753 ','eastar4\rCCZG001'),(22888,789959066008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','cilliani123','coolkidirish@gmail.com','Cillian Irish','11 Glendower Court','Ballincollig','Cork','IRELAND','','0214873554','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 18:39:51',0,NULL,3,1,3,1,'RA184505604CN ','au-buy\rLGAD001'),(22889,688392502013,230655991704,'New Bride White pure lace Wedding Marriage Sun Umbrella',1,'UM00032',21.99,'eastar4','w1werrew2010','w1werrew@yandex.ru','Alexandr Smehota','Milchakova 7','Rostov-on-Don','','RUSSIAN FEDERATION','344090','+79043471352','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 18:35:23',0,NULL,3,1,11,1,'BJ01713776 ','eastar4\rUM00032'),(22890,945343505012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','anastasia_mashkova','your2011paradise@yandex.ru','Анастасия Машкова','Б. Затонская, 55','Саратов','','RUSSIAN FEDERATION','410031','89603585676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 19:20:19',0,NULL,3,1,11,1,'BJ01713787 ','eastar4\rUM00005'),(22891,854072276011,320851655957,'New GENUINE NOKIA HS 11W BLUETOOTH HEADSET',1,'HSNO023',9.9,'eastar4uk','a117335a','asmalinin@gmail.com','Andrey Malinin','Vavilova, 73 - 24','Moscow','','RUSSIAN FEDERATION','117335','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 19:31:15',0,NULL,3,1,11,1,'BJ01713735 ','eastar4uk\r欧标\rHSNO023'),(22892,854071957011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','tim_20395','t_whitmore@mac.com','Tim Whitmore','27 Princess Road','Crawley','Western Australia','AUSTRALIA','6009','0403430586','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 19:37:31',0,NULL,3,1,11,1,'BJ01713773 ','eastar4\rUDAP001'),(22893,688423803013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',4,'WLAP008',79.52,'eastar4','lametal410','bukhakin13@gmail.com','Hyeon-sik Yoon','No.311, Living Castle, 27-11, Noryangjin 2-dong, Dongjak-gu','Seoul','','KOREA,REPUBLIC OF','156-052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 19:46:18',0,NULL,3,1,3,1,'BJ01713747 ','eastar4\rWLAP008'),(22894,854117167011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','gkny3000','george@sabini.net','George Sabini','2428 33rd St','Astoria','NY','UNITED STATES','11102-1137','(203) 820-5801','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 20:42:55',0,NULL,3,1,1,1,'LK220112562CN\r ','eastar4'),(22895,945420000012,220886977344,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',27.99,'eastar4uk','bunnco','john@johnfuller.org.uk','John Fuller','The Old Hall Coach House<br>Brooke','NORWICH','Norfolk','UNITED KINGDOM','NR15 1LB','441508558280','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 21:20:59',0,NULL,3,1,3,1,'RA184505992CN ','eastar4uk\rLGRM001'),(22896,945453294012,220759518181,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',3.39,'eastar4uk','danetnath1967','yyoda67@hotmail.com','Daniel Guilbault','8960 St-Michel<br>appartement # 211','Montreal','QC','CANADA','h1z3g4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 22:14:21',0,NULL,3,1,11,1,'BJ01713742 ','eastar4uk\rCALO001'),(22897,627781065003,130626860819,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'cnfaner','lhancock81','lisa.hancock@aggiemail.usu.edu','Lisa Hancock','241 N 300 E<br>Apt 7','Logan','UT','UNITED STATES','84321-4100','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-03 22:29:02',0,NULL,3,1,1,1,'LK220026489CN\r ','cnfaner'),(22898,854174677011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','melshark1','elsharkawi@comcast.net','Mohamed El-Sharkawi','14604 SE 79th Dr','Newcastle','WA','UNITED STATES','98059-9202','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 22:33:40',0,NULL,3,1,1,1,'LK220144579CN\r ','eastar4'),(22899,798548983007,170735464248,'New Sunflower Bloom 3-section Folding Sun/Rain Umbrella',1,'UM00004',21.99,'au-buy','nathanspeak1','nathanspeak@live.co.uk','nathan speak','5 Devon street','Darwen','Lancashire','UNITED KINGDOM','BB3 2JZ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 22:36:14',0,NULL,3,1,11,1,'BJ01713766 ','au-buy\rUM00004'),(22900,806896771001,110808693295,'New Jabra BT250V FreeSpeak Bluetooth Headset  BT 250V',1,'HSJA001',23.9,'buysia','smyth1944','eileen.smyth3@btinternet.com','Eileen Smyth','11 The Meadows<br>Kilmore Village','Crossgar','Down','UNITED KINGDOM','BT30 9Gt','02844830770','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-03 22:48:26',0,NULL,3,1,11,1,'BJ01713740 ','buysia\rHSJA001\r英标'),(22901,854186667011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','bridger2205','golfer-rb@tiscali.co.uk','Richard Bridger','51 Queens Road','Clacton on sea','Essex','UNITED KINGDOM','CO15 1AB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 22:59:28',0,NULL,3,1,3,1,'RA184505860CN ','eastar4uk\rLGAD001'),(22902,854188215011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','rocustiger','gold.gold@t-online.de','Erna Gold','Dahlienweg 4','Schirmitz','','GERMANY','92718','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 23:03:34',0,NULL,3,1,11,1,'BJ01713748 ','eastar4uk\rMOAP001'),(22903,945501616012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','nandinha100','acabou@hotmail.it','Pedro cavalaro','4 mandarin close','bridgwater','Somerset','UNITED KINGDOM','TA6 5QY','07584074048','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 23:57:33',0,NULL,3,1,3,1,'RA184504436CN ','eastar4uk\rHSJA002\r英标'),(22904,940641834012,220816384053,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001*2',52.99,'eastar4uk','xiko23','d_maligno23@hotmail.com','antonio perez monterroso','c/carrera 15 3 a','antequera','Andalucía Ceuta y Melilla','SPAIN','29200','637379154','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 00:04:31',0,NULL,3,1,3,1,'RA184505895CN ','eastar4uk\rGLOT001*2'),(22905,945499360012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','uvaisulgarni10','uvaisulgarni@gmail.com','Uvaisul Garni Poovanmadathil','10 Exmouth Street','Tower Hamlets','London','UNITED KINGDOM','E1 0ph','07740816109','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 23:51:59',0,NULL,3,1,3,1,'RA184504440CN ','eastar4uk\rHSJA002\r英标'),(22906,790150118008,180767057234,'Original Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',5.66,'au-buy','goodboy_au','goodboy_au@hotmail.com','Fadi jabbori','2  Shelley  Pl','Wetherill Park','New South Wales','AUSTRALIA','2164','0421800026','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 01:42:44',0,NULL,3,1,11,1,'BJ01713759 ','au-buy\rSCLO003'),(22907,854250420011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','twiggy246','lisapmck1@yahoo.ca','Lisa McKinney','185 Westmorland Road','Saint John','NB','CANADA','E2J 2E8','(506) 693-4552','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 02:05:14',0,NULL,3,1,3,1,'RA184505635CN ','eastar4\rLGRM001'),(22908,851611829002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','donsig01','dsignori@gmail.com','Donald Signorino','21 Brittany Dr','Bayville','NJ','UNITED STATES','08721-2482','(732) 606-1644','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-04 02:37:01',0,NULL,3,1,1,1,'LK220042138CN\r ','buysia'),(22909,854266905011,320791297772,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'eastar4','cdsup1','sbsteveb@gmail.com','Steven Blackney','25 Rosebud Crescent<br>Broadmeadows','Melbourne','Victoria','AUSTRALIA','3047','0383076519','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 02:59:50',0,NULL,3,1,11,1,'BJ01713580\r ','eastar4\rMOLA001'),(22910,945564623012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',27.78,'eastar4','byrdhouse27','ora.byrd@gmail.com','Ora Byrd','27 Hare Rd','Hampton','VA','UNITED STATES','23666-4720','(757) 232-0297','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-04 03:05:23',0,NULL,3,1,1,1,'LK220116207CN\r ','eastar4'),(22911,790215571008,180755522395,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',67.99,'au-buy','rene_bouman0','gnb@bigpond.com','Gerrit Bouman','36 Craig Ave','Tyabb','Victoria','AUSTRALIA','3913','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 06:26:58',0,NULL,3,1,3,1,'RA184505618CN ','au-buy\rHBPH001'),(22912,627879138003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',79.9,'cnfaner','best_repair_in_kz','spv73@km.ru','Pavel Suslov','Gorka Druzhby, 36, 33.','Temirtau','Karagandy','KAZAKHSTAN','101401','+77773304563','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 06:29:12',0,NULL,3,1,3,1,'RA184505533CN ','cnfaner\rOTES001'),(22913,798691475007,170764043239,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',69.99,'au-buy','pumpkinmusic','tracey.crow@bigpond.com','Tracey Crow','15 Davies Drive','Shepparton East','Victoria','AUSTRALIA','3631','0358291213','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 07:28:55',0,NULL,3,1,3,1,'RA184505683CN ','au-buy\rPSGL001'),(22914,688603279013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','andrewskippy','skippydonovan@hotmail.com','andrew donovan','160 monaco st<br>broadbeach waters','gold coast','Queensland','AUSTRALIA','4218','0755384156','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 07:30:17',0,NULL,3,1,3,1,'RA184505547CN ','eastar4\rGLOT001*2'),(22915,945633562012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT001*3',132.99,'eastar4','ggma1948','lynette.naylor1@optusnet.com.au','Lyne Naylor','162<br>Durham st','Bathurst','New South Wales','AUSTRALIA','2795','026332612100','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(22916,854335121011,320858966310,'3 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*3',293.99,'eastar4','pho1688','pho1688@yahoo.com.au','phuoc long pho','28 WOODRUFF AVE<br>MARIBYRNONG','melbourne','Victoria','AUSTRALIA','3032','0993183888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 07:46:58',0,NULL,3,1,3,1,'RA184505459CN ','eastar4\rGLSG008*3'),(22917,798700198007,170747501083,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.99,'au-buy','speedy0599','eoin247@gmail.com','Eoin Murphy','The Essington, unit 303/26,Pacific Street<br>Newcastle','Newcastle','New South Wales','AUSTRALIA','2300','0405245261','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 08:03:56',0,NULL,3,1,11,1,'BJ01713770 ','au-buy\rMOHP002'),(22918,945651298012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','sleepy2472010','mikael.berggren99@gmail.com','Mikael Berggren','Gökstigen 9','Sjöbo','','SWEDEN','27539','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 08:31:50',0,NULL,3,1,3,1,'RA184505445CN ','eastar4uk\rRCMA001'),(22919,945652405012,220462732570,'IBM X200T X200 Tablet 3G GPS WWAN antenna MC8781',1,'ANCN003',20.99,'eastar4','d4433d','right083@gmail.com','MYEONGGU JO','1025-1 , Naei-dong , Miryang-si<br>NEWOPTICS LTD','Gyeongsangnam-do','Korea','KOREA,REPUBLIC OF','627-803','+82-10-2552-4884','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 08:35:46',0,NULL,3,1,11,1,'BJ01713734 ','eastar4\rANCN003'),(22920,688631466013,230717843699,'2 pcs of New LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refriger',1,'LGFI001*2',99.99,'eastar4','peteharpark','peter@pcsoft.com.au','Peter Kenneally','Suite 4<br>22 Somerset Avenue','Narellan','New South Wales','AUSTRALIA','2567','0402057910','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 09:35:04',0,NULL,3,1,3,1,'RA184505944CN ','eastar4\rLGFI001*2'),(22921,798742015007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','robinmina','rmina@iinet.net.au','Robin Mina','28 Kingfisher Loop','Willetton','Western Australia','AUSTRALIA','6155','0892595506','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 10:00:26',0,NULL,3,1,3,1,'RA184505666CN ','au-buy\rPSGL001*2'),(22922,688645409013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','hhheeeennnkkk','epost105@hotmail.com','HH elgersma','Charlotte de Bourbonstraat 92','den haag','','NETHERLANDS','2595 vm','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 10:20:01',0,NULL,3,1,11,1,'BJ01713737 ','eastar4\rWLAT010'),(22923,798760056007,170758647866,'New Genuine Sturdy Samsung WMN2050C Ultra Slim Wall Mount for 2011 LED TV 65\"',1,'MOSA010',69.99,'au-buy','carlosc1975','ccespedes11@gmail.com','Carlos  Cespedes','607 Polding St ','Bossley Park','New South Wales','AUSTRALIA','2176','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 10:41:38',0,NULL,3,1,3,1,'RA184505516CN ','au-buy\rMOSA010'),(22924,945710422012,220966250846,'4 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*4',387.99,'eastar4','narinnasss','nassuy@optusnet.com.au','Magic Nails ( Laura Vo )','19a Arndale Shopping Centre<br>17-27 Cinderella Drive, Springwood','Logan','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 10:44:41',0,NULL,3,1,4,1,'YW867611350CN\r ','eastar4\rGLSG008*4'),(22925,945713123012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','grahamp642011','gp_castlesuk@btconnect.com','Graham Preston','1 Dicks Garth Road<br>Menston','Ilkley','West Yorkshire','UNITED KINGDOM','ls29 6hf','7853182787','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 10:49:55',0,NULL,3,1,3,1,'RA184505768CN ','eastar4uk\rMOMI002'),(22926,945725840012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',5.99,'eastar4uk','neonerdas','neoner@gmail.com','Jurgis Audrius Gurskas','Smalines 7-15','Vilnius','','LITHUANIA','06226','+37069318765','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 11:13:32',0,NULL,3,1,11,1,'BJ01713738 ','eastar4uk\rWLAT009'),(22927,688668567013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','anwerusa646','anwerusa@yahoo.com','Mohammad A Hossain','15501 90th Ave<br>Apt 5E','Jamaica','NY','UNITED STATES','11432-3809','(646) 339-1092','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-04 11:27:01',0,NULL,3,1,1,1,'LK220115762CN\r ','eastar4'),(22928,798810635007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.99,'au-buy','fhoze2010','marko.andersson@gmail.com','Marko Andersson','Muurarintie 9 D 17','Jyvaskyla','','FINLAND','40520','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 12:25:58',0,NULL,8,1,17,0,' ','au-buy'),(22929,798812612007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','fhoze2010','marko.andersson@gmail.com','Marko Andersson','Muurarintie 9 D 17','Jyvaskyla','','FINLAND','40520','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 12:29:10',0,NULL,3,1,3,1,'RA184505374CN ','au-buy\rUM00040\rNew Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella\rUM00053\r1个\r'),(22930,854469996011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','kcwu222','kcwu222@hotmail.com','Kin-Chung Wu','7 Badsey Fields Lane, Badsey','Evesham','Worcestershire','UNITED KINGDOM','WR11 7EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 12:55:05',0,NULL,3,1,3,1,'RA184505856CN ','Peastar4uk\rMOAP001'),(22931,790197845008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'au-buy','phunxx','lucianolongo@uol.com.br','Luciano Longo','Rua Lino Coutinho 75 - Apto 31 Torre 2<br>Ipiranga','Sao Paulo - SP','São Paulo','BRAZIL','04207000','551181755239','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 12:59:12',0,NULL,3,1,3,1,'RA184505697CN ','au-buy\rLGAD001'),(22932,687228954013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','yerikshpak','yerik_shpak@walla.com','Yaroslav Shpak','Bialik 1828','Ashdod','Ashdod','ISRAEL','77632','0508182089','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 13:02:04',0,NULL,3,1,11,1,'BJ01713778 ','eastar4\rUM00033'),(22933,854479368011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',52.99,'eastar4uk','divihe2009','teamgirl@telefonica.net','Diolinda Vieitez Herrera','Angel Guimera, 48, 1º, 1º','Suria','Cataluña','SPAIN','08260','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 13:07:18',0,NULL,3,1,3,1,'RA184505900CN ','eastar4uk\rGLOT001*2'),(22934,807175637001,110831128283,'New Grohe Multi Function hand Shower Head Made in Germany 7 pattens',1,'OTGR001',19.9,'buysia','huyly01','huyly@bigpond.com','Huy Ly','20 Aboud Ave','Kingsford','New South Wales','AUSTRALIA','2032','0296972212','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-04 13:20:16',0,NULL,3,1,11,1,'BJ01713765 ','buysia\rOTGR001'),(22935,945808923012,220913328002,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',7.99,'eastar4uk','hatredbael','webmaster@ohmygore.com','MONTANARY Jean-Michel','65bis Avenue Paul Vaillant Couturier','GENTILLY','Île-de-France','FRANCE','94250','0661103802','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 13:42:22',0,NULL,3,1,11,1,'BJ01713771 ','eastar4uk\rMOHP002'),(22936,851838095002,120868118790,'New Philips Toothbrush Sonicare Travel Charger base EU PLUG',1,'HBPH003',19.5,'buysia','louisalexandregiroux','louisgiroux@me.com','louis-alexandre giroux','meritor outlook avenue','peaceheaven','East Sussex','UNITED KINGDOM','bn108xe','1273587367','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-04 13:55:27',0,NULL,3,1,11,1,'BJ01713756 ','buysia\rHBPH003'),(22937,945831839012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','jem6ndy','ebay.eric@laposte.net','DOISNE Cindy','10 allée de houx','Souesmes','Centre','FRANCE','41300','0624680792','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 14:18:00',0,NULL,3,1,11,1,'BJ01713760 ','eastar4\rBTAC2012\racer 5pin1.25 6cm  '),(22938,628020896003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','bigsarge13','bigsarge96@verizon.net','patrick kelley','2486 Rudy Rd','harrisburg','PA','UNITED STATES','17104','(717) 421-1450','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-04 14:39:49',0,NULL,3,1,1,1,'LK220028710CN\r ','cnfaner'),(22939,854533727011,320730086763,'New GENUINE NOKIA BH-203 BLUETOOTH HEADSET',1,'HSNO007',9.49,'eastar4uk','violetshower','sue_e_webb@yahoo.co.uk','Susan Webb','59 Highland Road','Amersham','Buckinghamshire','UNITED KINGDOM','HP7 9AY','01494729820','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 14:41:31',0,NULL,3,1,3,1,'RA184504453CN ','eastar4uk\rHSNO007\r英标'),(22940,798893496007,170731735539,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones long cable Red',1,'HSPH002',29.99,'au-buy','11luda','climacool69@gmail.com','Deniss Isakovs','Riga Dzelzavas 19/1 - 3<br>Riga Dzelzavas 19/1 - 3','Riga','','LATVIA','LV-1084','26616530','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 14:53:43',0,NULL,3,1,11,1,'BJ01713745 ','au-buy\rHSPH002\r欧标'),(22941,633522839004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','babyguezz','loonywolfie@yahoo.com','wong winnie','blk 271b<br>sengkang  central 06-273','default','','SINGAPORE','542271','94888624','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:23:12',0,NULL,3,1,3,1,'RA184505649CN ','cnfaner\rHSJA011\r英标'),(22942,854567761011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',2,'CCZG001',15.96,'eastar4','tcarriero','tcarriero@charter.net','Tony Carriero','94 Hillside Ln','Monroe','CT','UNITED STATES','06468-3309','(203) 459-9986','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-04 15:29:51',0,NULL,3,1,1,1,'LK220101131CN\r ','eastar4'),(22943,633527611004,140662512216,'New I.Tech Clip Music 802i 802 FM Stereo Bluetooth Headset Earphone for iPhone',1,'HSIT005',55.99,'cnfaner','tsiam01','dtsiampouris@yahoo.gr','Dimitrios Tsiampouris','3 Chr. Lada str','Athina','Attiki','GREECE','10237','+302103333600','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:41:57',0,NULL,3,1,3,1,'RA184505309CN ','cnfaner\rHSIT005\r欧标\r'),(22944,854609028011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.99,'eastar4','silverio8','silverio_esparza@yahoo.com','silverio esparza','826 dublin dr','Lemoore','CA','UNITED STATES','93245-4154','(559) 589-4237','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-04 16:30:39',0,NULL,3,1,1,1,'LK220118830CN\r ','eastar4'),(22945,633559606004,140490636042,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',38.9,'cnfaner','zmail004','zmail04@gmail.com','Zohar Nachshon','56th Harofe st. (app. 28)<br>Ahuza','Haifa','Israel','ISRAEL','34367','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 16:33:38',0,NULL,3,1,3,1,'RA184505476CN ','cnfaner\rOTGR001+OTGR002'),(22946,628077557003,130608487119,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',50.99,'cnfaner','zezao2k','ze_mauricio@yahoo.com','Jose Mauricio B Lima','Rua Flavio Canesin, 650, lote1015<br>Rec. das Acacias','Ribeirao Preto','São Paulo','BRAZIL','14098-558','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 16:39:10',0,NULL,3,1,3,1,'RA184505737CN ','cnfaner\rSAFI001'),(22947,633585962004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',25.99,'cnfaner','mnirun7','mnirun@yahoo.com','Nirun Mankong','79/1 Moo 2 Teparuk Rd.,','default','SP','THAILAND','10270','+66897992900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 17:18:01',0,NULL,3,1,3,1,'RA184505799CN ','cnfaner\rHSAL001\r美标'),(22948,945991926012,220886271520,'New Microsoft Wired Optical Wheel Mouse White',2,'MOMI004',17.98,'eastar4uk','stephanie_mourot','stephanie_mourot@hotmail.com','Stephanie Mourot','Flat 2.4<br>14-16 Leeke Street','London','London','UNITED KINGDOM','WC1X 9HJ','02078371977','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 17:34:05',0,NULL,3,0,3,1,'RA184504422CN ','eastar4uk\rMOMI004'),(22949,946025228012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',16.99,'eastar4uk','dunkanemaklaude','drasute@hotmail.co.uk','Mrs D Markuniene','4 St Mary\'s Road','LONDON','London','UNITED KINGDOM','E13 9AD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 18:01:59',0,NULL,3,1,3,1,'RA184505975CN ','eastar4uk\rHSJA010\r英标'),(22950,946074578012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','quenchat','quentinchatenet@gmail.com','Quentin Chatenet','43 rue Sylvain Dornon','Salles','Aquitaine','FRANCE','33770','0628235096','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 18:41:19',0,NULL,3,1,11,1,'BJ01713774 ','eastar4\rBTAC2005\racer 4pin1.25 8cm'),(22951,626351857003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',217.98,'cnfaner','tjels','telshaug@gondtc.com','Tamra Elshaug','306 8th St NW','Devils Lake','ND','UNITED STATES','58301-2020','(701) 662-8305','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-04 19:56:47',0,NULL,3,1,1,1,'LK220020384CN\r ','cnfaner\r2个'),(22952,946184899012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',1,'HSNO019+CCNO001',25.99,'eastar4uk','ernohakala1984','ernohakala@gmail.com','Erno Hakala','Härkisuontie 38','Kokemäki','Oletus','FINLAND','32800','0440848765','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 20:06:54',0,NULL,3,1,11,1,'BJ01713733 ','eastar4uk\rHSNO019+CCNO001'),(22953,854868763011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','tthirud','truls@thirud.cc','Truls Thirud','Nils Lauritssonsvei 10','Oslo','','NORWAY','0854','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 20:24:54',0,NULL,3,1,11,1,'BJ01713731 ','eastar4uk\rRELO003'),(22954,633736096004,140651987151,'New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',2,'GLSG008',199.8,'cnfaner','s2925794','sharonkatz@bezeqint.net','sharon katz','Shderot hanasi hertzog 56/2','mahalot-tarshiha','-','ISRAEL','21070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 20:33:54',0,NULL,5,0,18,0,NULL,'cnfaner\rGLSG008'),(22955,628253506003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','integramicro','liat@netmessage.net','Liat Levinson','97 Greenpoint Ave<br>C/O Integra Microsystems, Inc','Brooklyn','NY','UNITED STATES','11222-6586','(917) 806-0115','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-04 20:40:24',0,NULL,3,1,1,1,'LK220023638CN\r ','cnfaner'),(22956,946246718012,220816379561,'2 pair 3D TV Activ Shutter Glasses 4 SAMSUNG SSG-2100AB',1,'GLOT001*2',52.99,'eastar4uk','eppoes','eppoes@aol.com','Gary Epstein','53 Woodland Drive','Hove','East Sussex','UNITED KINGDOM','BN3 6DH','01273708715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 21:04:56',0,NULL,3,1,3,1,'RA184505935CN ','eastar4uk\rGLOT001*2\r新地址\rGary Epstein\r168 Church Road\rHove\rEast Sussex\rBN3 6DH\rUNITED KINGDOM\r01273708715\r\r'),(22957,946268048012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','pitapuss','jenny.worron@sky.com','jenny worron','carrama rambledown lane','west chiltington','West Sussex','UNITED KINGDOM','rh202nw','01798817572','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 21:27:59',0,NULL,3,1,3,1,'RA184505961CN ','eastar4uk\r英标\rHSJA002'),(22958,799269178007,170739867756,'ew Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'au-buy','rimo777','mednikov@pisem.net','Michael Mednikov','Podvoyskogo str., 29-1-188','St.-Petersburg','','RUSSIAN FEDERATION','193231','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 21:43:11',0,NULL,3,1,11,1,'BJ01715491 ','au-buy\rWLIN014\rBracket of MINI HALF WLAN/WIFI/WIRELESS CARD to PCI-E\rMOCN001\r1个'),(22959,854942632011,320730086414,'New DELL D630 D830 BCM4321 300Mbp WiFi Mini PCI-E Card',1,'WLDE001',9.5,'eastar4uk','gpa.8018','gubik.peter@gmail.com','Péter Gubik','Vilmos u. 19.','Pécs','Baranya','HUNGARY','7625','(36)309-363890','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 21:51:15',0,NULL,3,1,11,1,'BJ01713739 ','eastar4uk\rWLDE001'),(22960,633780140004,140675756400,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001*2',87.99,'cnfaner','chefklass','mynetflixaccountchris@live.ca','chris klassen','4480 Viewmont ave','victoria','BC','CANADA','v8z 5l1','(250) 885-8778 ext.: 2508858778','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 21:55:11',0,NULL,3,1,3,1,'RA184505710CN ','cnfaner\rGLOT001*2'),(22961,854910039011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','urs4dalo','connorracingteam@hotmail.com','Chadric Stevens','1819 Dewey St<br>rear','Hollywood','FL','UNITED STATES','33020-6017','(954) 347-5683','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-04 21:55:56',0,NULL,3,1,1,1,'LK220095983CN\r ','eastar4'),(22962,946295051012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',72.88,'eastar4','rasing123','fred.rasing@hetnet.nl','Fred Rasing','Moeder Teresalaan 31<br>(alleen huisadres)','Utrecht','','NETHERLANDS','3527 WB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:05:41',0,NULL,3,1,3,1,'RA184505555CN ','eastar4\rGLOT001\r再发一副BR100眼镜'),(22963,854982923011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','redoffice2012','redoffice@aol.com','Teresa Nurmi','17970 Blackbird Dr','Reno','NV','UNITED STATES','89508-8854','(775) 677-0919','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-04 23:02:15',0,NULL,3,1,1,1,'LK220143397CN\r ','eastar4\r\r新地址\rTeresa Nurmi\r1207 Dewberry Drive\rChesapeake VA 23320\rUNITED STATES\r(775) 677-0919\r\r'),(22964,946355976012,220455480428,'HP NC4400 TC4200 TC4400 Bluetooth Module EDR 2.0 +cable',1,'BTHP2007',9.88,'eastar4','megamindx4','kplee@seniorstrategies411.com','Keith Lee','4330 Buckingham Dr','Gurnee','IL','UNITED STATES','60031-6241','(847) 654-1504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 00:11:55',0,NULL,3,1,1,1,'LK220083455CN\r ','eastar4\rHP 8pin 1.0 23cm '),(22965,686970737013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','kym39','mykeydee1957@yahoo.com.au','Kym Wallace','Unit 2<br>576 Norman Road','North Rockhampton','Queensland','AUSTRALIA','4701','0749140741','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 00:18:17',0,NULL,3,1,11,1,'BJ01713777 ','eastar4\rUM00033\r发一把带点点的或心型的'),(22966,946366650012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lockjammer','ejejej@sbcglobal.net','Efren Jake','1420 1/2 Hazelwood Ave','Los Angeles','CA','UNITED STATES','90041-3413','(323) 257-3880','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 00:23:48',0,NULL,3,1,1,1,'LK220087721CN\r ','eastar4'),(22967,689086861013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','alainbernier2','alainbernier@cablevision.qc.ca','alain bernier','7, rue trempe','rouyn-noranda','QC','CANADA','j0y1c0','(819) 759-4935','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 00:27:41',0,NULL,3,1,3,1,'RA184505428CN ','eastar4\rGLSG009*3'),(22968,946381516012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Mary Stone','1112 Careswell St','Marshfield','MA','UNITED STATES','02050-5638','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 00:59:17',0,NULL,3,1,1,1,'LK220158079CN ','eastar4'),(22969,688959140013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','popsallnutt2012','popsallnutt@yahoo.com','herbert allnutt','220 burmaster dr','Columbia','SC','UNITED STATES','29229-4310','(803) 518-9051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 01:09:30',0,NULL,3,1,1,1,'LK220119305CN\r ','eastar4'),(22970,8881330913086517,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',1,'UM00008',24.99,'aliexpress','1007135445','mashaiv2010@mail.ru','Maria Stashkevich','Korablestroileli 32 k3 kv194 ','Sankt-Petersburg','Sankt-Petersburg','RUSSIAN FEDERATION','199397','+8911 726 9118',NULL,NULL,NULL,'2012-03-05 02:04:46',0,NULL,3,1,3,1,'RA184505326CN ','UM00008 '),(22971,8881330913318903,111,'Free shiping & Tracking - New Genuine Sturdy Samsung WMN2050C Ultra Slim Wall Mount for 2011 LED TV 65\" - ',1,'MOSA010',64.99,'aliexpress','1007128957','1@1.com','Robin Moran','	5/50 Hastings street Scarborough ','Perth','Western Australia','AUSTRALIA','6019','0407016056/+61 08 92000034',NULL,NULL,NULL,'2012-03-05 02:08:38',0,NULL,3,1,3,1,'RA184505771CN ','MOSA010 '),(22972,8881330913546210,111,'Free shiping & Tracking - New WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\" - ',1,'MOOE002',47.99,'aliexpress','1007135067','rh@nobrend.ru','Ruslan Khayretdinov','Pudovkina st. 5 - 58 ','Moscow','Moscow','RUSSIAN FEDERATION','119285','79100000256/+7 926 2294790',NULL,NULL,NULL,'2012-03-05 02:12:26',0,NULL,3,1,3,1,'RA184505927CN ','MOOE002 '),(22973,8881330913720603,111,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card ',1,'WLAT001',13.99,'aliexpress','1007108990','swordas@yandex.ru','Vyacheslav','Slobodka House 26 apartment 15 ','Bogorodskoe','Sergiev-Posad','RUSSIAN FEDERATION','141342','+7 905 5135033',NULL,NULL,NULL,'2012-03-05 02:15:20',0,NULL,3,1,3,1,'RA184505887CN ','WLAT001 '),(22974,946426244012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'eastar4','beano1938','beano1938@shaw.ca','Chi Timperley','316 Moyne Drive','West Vancouver','BC','CANADA','V7S 1J5','(604) 921-6623','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 02:34:05',0,NULL,3,1,3,1,'RA184505652CN ','eastar4\rPSGL001*3'),(22984,946477885012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','tycho1551','tycho155@netscape.net','Michael Epstein','3441 77th PL SE','Mercer Island','WA','UNITED STATES','98040-3445','(425) 269-5211','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 04:52:03',0,NULL,3,1,1,1,'LK220434505CN\r ','eastar4'),(22975,689143417013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','rmarhome','rmarhome@yahoo.com','Roman Marchevsky','1640 S Lancaster Ln','Libertyville','IL','UNITED STATES','60048-4845','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 03:24:02',0,NULL,3,1,1,1,'LK220130963CN ','eastar4'),(22976,689143123013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','smithers475','ben.wjbkb@gmail.com','Ben Smith','3 Cooper Way','Albany','Western Australia','AUSTRALIA','6330','0427080807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 03:24:43',0,NULL,3,1,3,1,'RA184505670CN ','eastar4\rGLOT001*2'),(22977,689140442013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','mayanmercado','paladin_c@hotmail.com','Oscar Obando','10914 NW 33rd St<br>Ste 115','DORAL','FL','UNITED STATES','33172-5062','(305) 594-7675','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 03:26:31',0,NULL,3,1,1,1,'LK220182475CN\r ','eastar4'),(22978,689145120013,230695960165,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',86.9,'eastar4','pierremarotte123','pemette@hotmail.com','pierre123 marotte','5A st-augustin','lévis','QC','CANADA','g6v6a6','(418) 265-7983','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 03:29:37',0,NULL,3,0,3,1,'RA184505754CN ','eastar4\rHBPH001+HBPH003'),(22979,855091642011,320596245149,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','mickyandrzej','commandermick@hotmail.com','Micky Laszuk','114 Royal Avenue.','Hamilton','ON','CANADA','L8S 2C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 03:20:35',0,NULL,3,1,11,1,'BJ01713583\r ','eastar4\rHSUE004'),(22980,8881330918796604,111,'New ULTIMATE EARS METRO.FI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'eastar4','mickyandrzej','commandermick@hotmail.com','Micky Laszuk','114 Royal Avenue.','Hamilton','ON','CANADA','L8S 2C5','',NULL,NULL,NULL,'2012-03-05 03:39:56',0,NULL,5,0,18,0,' ','录重了 '),(22981,946462748012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','mbd1017','mikedepetrillo@gmail.com','Michael DePetrillo','6311 Tchoupitoulas St','New Orleans','LA','UNITED STATES','70118-5745','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 04:03:40',0,NULL,3,1,1,1,'LK220434267CN\r ','eastar4'),(22982,855106137011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','senya65','lizvlad@msn.com','souboch, andrei','5115 152nd St<br>null','OAK FOREST','IL','UNITED STATES','60452-2357','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 04:04:28',0,NULL,3,1,1,1,'LK220434324CN\r ','eastar4'),(22983,946472295012,220783449113,'NIB Jabra PRO 9460 Duo wireless bluetooth headset',1,'HSJA009',257,'eastar4','s_mickail','smickail@gmail.com','Sameh Mickail','5 Des Nenuphars','Blainville','QC','CANADA','J7C5V3','(514) 945-8500','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 04:31:54',0,NULL,3,1,3,1,'RA184505330CN\r ','eastar4\rHSJA009'),(22985,946477761012,220966250846,'4 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*4',387.99,'eastar4','average_buyer_or_seller','agambotto@themissinglink.com.au','Alex Gambotto','9-11 Dickson Ave','Artarmon','New South Wales','AUSTRALIA','2064','0284368585','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(22986,807765276001,110832702660,'4 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*4',487.99,'buysia','average_buyer_or_seller','agambotto@themissinglink.com.au','Alex Gambotto','9-11 Dickson Ave','Artarmon','New South Wales','AUSTRALIA','2064','0284368585','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-05 05:42:46',0,NULL,5,0,18,0,NULL,'buysia\r已退款'),(22987,852435392002,120865585479,'New 44 Pin Female to Female Mini IDE Cable for PC 30 cm',1,'OTCN002',5.98,'buysia','ttonicnor','tonicnor@mail.ru','Anton Redkin','ul. N. Krupskaya, dom. 143, kv. 52','Barnaul','Altai Krai','RUSSIAN FEDERATION','656031','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-05 06:54:41',0,NULL,3,1,11,1,'BJ01713772 ','buysia\rOTCN002'),(22988,8881330931047858,111,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',3,'LGAD001',148,'eastar4','claudiajp10','claudiajp@globo.com','Claudia j. Sanná','R Dr Mario Freire 245<br>Morumbi','Sao Paulo','São Paulo','BRAZIL','05692-110','',NULL,NULL,NULL,'2012-03-05 07:04:07',0,NULL,3,1,3,1,'RA184505312CN ','LGAD001\r直接打款\rEASTAR4 '),(22989,8881330931588061,111,'Free shiping & Tracking - New WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\" - ',1,'MOOE002',47.99,'aliexpress','1007163490','tkvam@me.com','Torbjorn Kvam','Krillasveien 82 ','Asker','Akershus','NORWAY','1392','+47 93007700',NULL,NULL,NULL,'2012-03-05 07:13:08',0,NULL,3,1,3,1,'RA184505224CN\r ','MOOE002 '),(22990,946513978012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Katie A Kiepura','1426 E Emmerson Ln','Mount Prospect','IL','UNITED STATES','60056-2604','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 07:30:31',0,NULL,3,1,1,1,'LK226570230CN\r ','eastar4'),(22991,8881330937775527,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',1,'UM00008',22.49,'aliexpress','1007165179','stephcoton@gmail.com','Stephanie Coton','4 Waitui Cres Waiwhetu','Lower Hutt','Wellington','NEW ZEALAND','5010','+64 04 9341593',NULL,NULL,NULL,'2012-03-05 08:56:15',0,NULL,3,1,3,1,'RA184503722CN\r ','UM00008 '),(22992,852462293002,120844622295,'New GENUINE ULTIMATE EARS METRO.FI METROFI 150 EARPHONE UE150 UE',1,'HSUE004',13.49,'buysia','9342luc','lukecote@bell.net','luc cote','28<br>daubigny','levis','QC','CANADA','g6v4t1','(418) 837-6264','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-05 08:57:19',0,NULL,3,1,11,1,'BJ01713579\r ','buysia\rHSUE004\r美标'),(22993,944495055012,220806897821,'New lady lace trim sun/rain stick Umbrella Ivory',1,'UM00011',24.99,'eastar4','shadem','seb.b@live.com.au','Sebastian Bujnowski','PO BOX 419','Rydalmere','New South Wales','AUSTRALIA','1701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 09:36:31',0,NULL,3,1,11,1,'BJ01712818 ','eastar4\rUM00011\r黑色的  客户愿意等'),(22994,855189836011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','sumai7','simba_316@hotmail.com','Sumai Khayat','26 Weoley Castle road<br>Weoley castle','Birmingham','West Midlands','UNITED KINGDOM','B29 5PZ','07841534853','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 09:55:21',0,NULL,3,1,3,1,'RA184505175CN\r ','eastar4uk\rMOAP001'),(22995,855192225011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','123rene007','ozp60kup@yahoo.co.uk','JURAJ KACENGA','13 City House<br>420 London Road','Croydon','London','UNITED KINGDOM','CR0 2NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 10:04:15',0,NULL,3,1,3,1,'RA184505215CN\r ','eastar4uk\rMOAP001'),(22996,689219087013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','joeclchan','joeclchan@yahoo.com','Chan Chaw Liang','Block 755 Woodlands Avenue 4 #12-293 Singapore 730755','default','','SINGAPORE','730755','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 10:23:07',0,NULL,3,1,3,1,'RA184505238CN\r ','eastar4\rGPS0006'),(22997,628431465003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',3,'GLOT001',131.67,'cnfaner','19750131','nadelkin@mail.ru','Иван Наделкин','Газетная,67,36','Екатеринбург','','RUSSIAN FEDERATION','620104','(908)6333053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 10:53:49',0,NULL,3,1,3,1,'RA184505167CN\r ','cnfaner\rGLOT001'),(22998,799520548007,170735464388,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',27.99,'au-buy','nelliem77','nellie77@bigpond.com','Nellie Miojevic','60/352 Canterbury Road','St Kilda','Victoria','AUSTRALIA','3182','0395348228','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-05 10:54:43',0,NULL,3,1,11,1,'BJ01713635\r ','au-buy\rUM00008'),(22999,946574974012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','pianiste33','pmeriguet@numericable.fr','Philippe Mériguet','78 rue François de Sourdis','Bordeaux','Aquitaine','FRANCE','33000','06 60 59 86 50','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 11:05:17',0,NULL,3,1,3,1,'RA184505343CN\r ','eastar4\rPSGL001'),(23000,628474132003,130617205284,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',2,'SAFI001*2',197.98,'cnfaner','firehawk100','firehawk@emirates.net.ae','Abdulla Almulla','P.O.Box 12331','Dubai','United Arab Emirates','UNITED ARAB EMIRATES','AE','011971506512552','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 11:32:50',0,NULL,3,1,3,1,'RA184505272CN\r ','cnfaner\rSAFI001*2'),(23001,946597753012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',1,'CASS001',25.76,'eastar4uk','brianpjdillon','briandillon@eircom.ie','Brian Dillon','22 Redwood Rise<br>Kilnamanagh','Tallaght','Dublin','IRELAND','24','0851745288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 12:12:31',0,NULL,3,1,11,1,'BJ01713647\r ','eastar4uk\rCASS001+CASS002+CASS003\r再发一条NEW CAB-6060\r两条NEW CAB-2660\r'),(23002,633992839004,140680154335,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',70.99,'cnfaner','jomartincir','jomartincir@gmail.com','Jorge Martinez Fernandez','Jaen, 20','Rubi','Cataluña','SPAIN','08191','644547565','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 13:21:10',0,NULL,3,1,3,1,'RA184505207CN\r ','cnfaner\rPSGL001'),(23003,946641044012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','mazmez88','mezmaz88@gmail.com','Mazen Mezher','207 Danzig street','Toronto','ON','CANADA','M1E 2L5','(416) 287-0622','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 14:05:47',0,NULL,3,1,11,1,'BJ01713638\r ','eastar4\rWLAT009'),(23004,628525283003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',23.8,'cnfaner','bully2001','kwa2809@googlemail.com','Klaus Wald ;   c/o ADAMS Blitzschutz-Systeme GmbH','im Lossenfeld 1','Willstätt - Sand','','GERMANY','77731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 15:10:54',0,NULL,3,1,3,1,'RA184505184CN\r ','cnfaner\rHSJA001\r欧标'),(23005,634023953004,140652878860,'Original Apple AirPort Extreme Wireless WiFi Card 54M A1026',1,'WLAP002',20.9,'cnfaner','bipper76','phil@plecavalier.com','Philippe LeCavalier','2341 Bedell Road','Kemptville','ON','CANADA','K0G1J0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 15:19:38',0,NULL,3,1,3,1,'RA184505153CN\r ','cnfaner\rWLAP002'),(23006,946679024012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Joel Blanchet','80 LAKESHORE DR','EASTCHESTER','NY','UNITED STATES','10709-5210','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 15:35:22',0,NULL,3,1,1,1,'LK226903842CN\r ','eastar4'),(23007,946684310012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','hiuryhp','hiuryp@gmail.com','Hiury Pereira','Rua Cormorão, 143 - Bloco P, APT 42<br>V.P.M. da Nobrega','Campinas','São Paulo','BRAZIL','13061-351','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 15:45:01',0,NULL,3,1,11,1,'BJ01713642\r ','eastar4uk\rSHLO005\r新地址\rHiury Pereira\rRua Comendador Jeronimo de Campos Freire, 529 - Bloco A, APTO 32\rJd. Interlagos\rCampinas São Paulo\r13033 490\rBrazil\r'),(23008,946691068012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Meredith Fisher','1717 N Decatur Rd NE<br>Unit 409','Atlanta','GA','UNITED STATES','30307-1063','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 15:59:54',0,NULL,3,1,1,1,'LK226845420CN\r ','eastar4'),(23009,855340624011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','chris193mk','christian@dewitt193.de','Christian de Witt','Promenadenweg 19B','Essen','','GERMANY','45219','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 16:46:37',0,NULL,3,1,3,1,'RA184505136CN\r ','eastar4uk\rOTSO002'),(23010,946719116012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','davego33','davego33@hotmail.com','Dave Oliphant','10256 Farmdale St','Firestone','CO','UNITED STATES','80504','(303) 219-6380','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 16:54:26',0,NULL,3,1,1,1,'LK226874939CN\r ','eastar4'),(23011,855350335011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','5300king','shirstep@rogers.com','Stephen King','P.O. Box 384','Washago','ON','CANADA','L0K 2B0','(705) 689-1544','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 17:08:30',0,NULL,3,1,11,1,'BJ01713645\r ','eastar4\rHSNO019'),(23012,946750158012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','snipes2107','wes_hildebrand@hotmail.com','Wes Hildebrand','43 Lynnwood Bay','Altona','MB','CANADA','R0G 0B1','(204) 324-5506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 17:50:21',0,NULL,3,1,3,1,'RA184505255CN\r ','eastar4\rGLOT001*2'),(23013,791202850008,180781221355,'New Jabra JX10 Series II 2 Wireless Bluetooth headset  Sliver +AC  adapter',1,'HSJA012',18.98,'au-buy','yoxino','tomas.suchanek@gmail.com','Tomas Suchanek - EMERSON Energy Systems','Piestanska 1202/44','Nove Mesto nad Vahom','','SLOVAK REPUBLIC','915 28','+421911148005','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-05 18:10:47',0,NULL,3,1,11,1,'BJ01713641\r ','au-buy\rHSJA012\rsliver\r欧标\r'),(23014,855386510011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','richie1100151','richieb1965@live.co.uk','richard burrell','91 norwich drive upton<br>upton','wirral','Merseyside','UNITED KINGDOM','ch494gj','01516789012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 18:11:34',0,NULL,3,1,11,1,'BJ01713643\r ','eastar4\rHSJA002\r英标'),(23015,621737986003,130620867014,'New Logitech Digital IO Writing Pen+ notebook',1,'NTLO001+NTLO002',52.99,'cnfaner','garciamuscl','garciamuscle@hotmail.com','alexandre da silva garcia','r candido brasil estrela n 291','sao jose do rio preto','sao paulo','BRAZIL','15054220','17 32152876','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 18:10:43',0,NULL,3,1,3,1,'RA184505357CN\r ','cnfaner\rNTLO001+NTLO002'),(23016,855400544011,320857834787,'Original Apple PowerBook G4 AirPort Extreme WiFi Card A1026',8,'WLAP002',167.92,'eastar4','gothicbargaingear','corenetworks@hotmail.com','Patrick Welsh','41 Bellflower Ave<br>South Park Village','Glasgow','Glasgow (City Of)','UNITED KINGDOM','g53 7yd','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 18:35:04',0,NULL,3,1,3,1,'RA184505065CN\r ','eastar4\rWLAP002\r客户要发airport的'),(23017,808041674001,110826639589,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'buysia','smithalb21','smithalb21@hotmail.com','Albert Smith','800 S Wells St<br>Apt 1228','Chicago','IL','UNITED STATES','60607-4540','(847) 717-7612','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-05 19:12:19',0,NULL,3,1,1,1,'LK226825853CN\r ','buysia'),(23018,689400907013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','cariboutrail709','wallacegeorgie@nl.rogers.com','wallace clarke','1516 thorburn rd.','Portugal Cove / St. Philips','NL','CANADA','a1m 1m8','(709) 895-6912','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 19:56:25',0,NULL,3,1,3,1,'RA184505079CN\r ','eastar4\rGPS0004'),(23019,855519535011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',1,'HSJA011',28.5,'eastar4','shagaitwo4','ganboldotgon@yahoo.com','ganbold otgon','7110 Rock Ridge Ln<br>Apt K','alexandria','VA','UNITED STATES','22315-5142','(703) 868-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 21:39:27',0,NULL,3,1,1,1,'LK226884692CN\r\r ','eastar4'),(23020,855574079011,320730085153,'Logitech MX1000 Mouse special Bluetooth Version',1,'MOLO005',35.9,'eastar4uk','dolhay','denke@denkesys.com','Denes Dolhay','Gaál j. 20/A','Budapest','','HUNGARY','1122','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 23:36:48',0,NULL,3,1,3,1,'RA184503413CN\r ','eastar4uk\rMOLO005\r旧的'),(23021,855585660011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','nickmiya','miyafrancis@gmail.com','Carol Francis','523 Patriots Way','Rockton','IL','UNITED STATES','61072-3021','(815) 608-6735','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 00:10:17',0,NULL,3,1,1,1,'LK226864741CN\r ','eastar4'),(23022,946995459012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','emarcio2011','edilbertomarcio@ig.com.br','Edilberto Marcio','Rua Santa Maria Rosselo, 363','Campinas','São Paulo','BRAZIL','13087-503','55 (19) 9166-4429','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 01:00:14',0,NULL,3,1,3,1,'RA184505140CN\r ','eastar4\rGLOT001'),(23023,628725101003,130626363912,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.95,'cnfaner','the_waterboy','tbmusgrave@yahoo.com','Thomas Musgrave','2740 Grosmont Place','cumming','GA','UNITED STATES','30041','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-06 01:08:06',0,NULL,3,1,1,1,'LK226834617CN\r ','cnfaner'),(23024,8881330997180433,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons -',1,' UM00008',22.49,'aliexpress','1007167843','miraculous.kitten@yandex.ru','Gusev Ilya Aleksandrovich','Kommunisticheskay 22-12 ','Balakovo','Saratov region','RUSSIAN FEDERATION','413865','+7 937 2579672',NULL,NULL,NULL,'2012-03-06 01:26:20',0,NULL,3,1,3,1,'RA184503740CN\r ','UM00008 '),(23025,855612977011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','igorthetrust','igorthe@terra.com.br','igor rafael','rua vicente batista neto 389<br>JD angelica','carapicuiba','São Paulo','BRAZIL','06365-210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 01:29:06',0,NULL,3,1,3,1,'RA184505198CN\r ','eastar4\rLGRM001'),(23026,8881330997381732,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',1,'UM00008',22.49,'aliexpress','1007167855','miraculous.kitten@yandex.ru','Kozmerchuk Darya','Volgskay 1-8 ','Balakovo','Saratov region','RUSSIAN FEDERATION','413800','+7 927 1093144',NULL,NULL,NULL,'2012-03-06 01:29:41',0,NULL,3,1,3,1,'RA184503753CN\r ','UM00008 '),(23027,8881330997542642,111,'Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card - ',1,'WLIN010',17.99,'aliexpress','1007169770','nikdy@vistcom.ru','Nikolay Dynin','	Sheksninskaya st. 42-100 ','Volgograd','Volgogradskay obl.','RUSSIAN FEDERATION','400117','+0117 902 3870931',NULL,NULL,NULL,'2012-03-06 01:32:22',0,NULL,3,1,3,1,'RA184505122CN\r ','WLIN010 '),(23028,8881330997712680,111,'NEW Sunflower Bloom 3-section Folding Sun/Rain Umbrella - ',1,'UM00004',19.79,'aliexpress','1007177039','acmgil@yahoo.com.br','Abigail Clemente M Gil','	R Sete de Setembro,894 apto71 Centro','Limeira','Sao Paulo','BRAZIL','13480-151','+55 19 34416957',NULL,NULL,NULL,'2012-03-06 01:35:12',0,NULL,3,1,3,1,'RA184505269CN\r ','UM00004 '),(23029,791419990008,180810757015,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',4,'GPS0010',131.96,'au-buy','x_k3lli_x','k3lli@live.com.au','Hang Cao','171 Stockmans Way<br>Kensington','Melbourne','Victoria','AUSTRALIA','3031','61434555345','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-06 01:44:33',0,NULL,3,1,3,1,'RA184505082CN\r ','au-buy\rGPS0010'),(23030,855642296011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','heeju','huiju_wi@hotmail.com','Jaeyoung Jin','12 stratus pl','calamvale','Queensland','AUSTRALIA','4116','0458658645','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 02:59:18',0,NULL,3,1,11,1,'BJ01713637\r ','eastar4\rWLIN011'),(23031,947050026012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Donald W Kouba','14872 Menard Ave','Oak Forest','IL','UNITED STATES','60452-1127','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 03:29:52',0,NULL,3,1,1,1,'LK227195703CN\r ','eastar4'),(23032,634264107004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.89,'cnfaner','mitrovicigor','serb_4xs_thatsme@hotmail.com','Igor Mitrovic','26 Brister Street<br>Angle Park','Adelaide','South Australia','AUSTRALIA','5010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 03:50:52',0,NULL,3,1,3,1,'RA184505290CN\r ','cnfaner\rLGAD001'),(23033,689553134013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','glastron-gtx','slach35@hotmail.com','Stephane lachance','3077 rue de la Rivièra','st-augustin de desmaures','QC','CANADA','g3a2l9','(418) 998-7725','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 04:12:40',0,NULL,3,1,3,1,'RA184505286CN\r ','eastar4\rLGAD001+LGRM001\r再发一副LG magic motion remote AN-MR200'),(23034,855664313011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','glastron-gtx','slach35@hotmail.com','Stephane lachance','3077 rue de la Rivièra','st-augustin de desmaures','QC','CANADA','g3a2l9','(418) 998-7725','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 04:16:08',0,NULL,3,1,17,0,'RA184505286CN\r ','eastar4'),(23035,855679399011,320564630453,'NEW AKE Inside hide PCMCIA to eSATA SATA Cardbus BC188',1,'ADAK002',12.6,'eastar4','johnsinuk','jsinistaj@gmail.com','John Sinistaj','32 highgate grove','Ashburton','Victoria','AUSTRALIA','3147','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 05:20:28',0,NULL,3,1,11,1,'BJ01713644\r ','eastar4\rADAK002'),(23036,855696749011,320812367464,'2 pair NIB Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses  3300 GR',1,'GLSG009*2',116.99,'eastar4uk','s2925794','sharonkatz@bezeqint.net','sharon katz','Shderot hanasi hertzog 56/2<br>P.O box 7058','mahalot-tarshiha','-','ISRAEL','21070','97249997178','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 06:45:27',0,NULL,3,1,3,1,'RA184505241CN\r ','eastar4uk\rGLSG009*2'),(23037,689580583013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','puskasjozsef','jozsefpus@gmail.com','Puskas Joseph','Tancsics 16','Nemesbikk','BORSOD-ABAUJ-ZEMPLEN','HUNGARY','3592','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 07:02:51',0,NULL,3,1,11,1,'BJ01713640\r ','eastar4\r欧标\rHSNO022\r银色的'),(23038,855711191011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','ramiezer','rami.ezer@gmail.com','Rami Ezer','Mapo 10','Kiryat Ata','Israel','ISRAEL','28032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 07:49:51',0,NULL,3,0,11,1,'BJ01713648\r ','eastar4\r'),(23039,689603144013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','igormorev76-ru','igormorev76@gmail.com','Igor Morev','Kaul, 13/1','Tula','','RUSSIAN FEDERATION','300007','(920)753-2509','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 09:20:08',0,NULL,3,1,11,1,'BJ01713636\r ','eastar4\rHSNO016\r欧标'),(23040,689622231013,230546640363,'New GENUINE NOKIA BH-600 BLUETOOTH HEADSET BH 600',1,'HSNO016',13.94,'eastar4','mwchumak','mw109@mail.ru','Mihail Chumak','K.Marksa 115/2-68','Magnitogorsk','Cheljabinskaja obl','RUSSIAN FEDERATION','455037',' 89028976266','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:52:13',0,NULL,3,1,11,1,'BJ01713568\r ','eastar4\rHSNO016\r欧标'),(23041,689623265013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'eastar4','a532009','andre_u@mail.ru','Andrey Afanasyev','Yubileynaya 87-73','Togliatti','Samara reg','RUSSIAN FEDERATION','445057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:53:48',0,NULL,3,1,3,1,'RA184503974CN\r ','eastar4\rGPS0006'),(23042,947165929012,220572910849,'New GENUINE NOKIA HS-12W BLUETOOTH HEADSET HS 12W',1,'HSNO025',57.95,'eastar4','gomerik18','orlovgena@mail.ru','Orlov Gennadiy','Tatyana Baramzina 28-46','Izhevsk','The Udmurt Republic','RUSSIAN FEDERATION','426067','89641831688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:54:41',0,NULL,5,1,18,1,NULL,'eastar4\rHSNO025\r欧标\r由于缺货需要退款\r已经退款'),(23043,855766520011,320820765935,'New Nokia Easy-to-use Bluetooth Headset BH-301 w/Fashion Conscious 5 colors',1,'HSNO036',19.99,'eastar4uk','ronbobo53','ronkaemling@gmx.net','Ronald Kämling','Zehdenicker Str.22b','Liebenwalde','','GERMANY','16559','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 11:17:15',0,NULL,3,1,11,1,'BJ01713564\r ','eastar4uk\rHSNO036\r欧标'),(23044,689629326013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','wquinteiro','willianquinteiro@gmail.com','Willian quinteiro','Rua Alameda das Tulidas 1353 Caixa postal 1082<br>Colina Verde','Rondonópolis','Mato Grosso','BRAZIL','78740460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 11:23:21',0,NULL,3,1,3,1,'RA184503784CN ','eastar4\rLGAD001'),(23045,855767744011,320812367978,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100 SHB 9100',1,'HSPH008',66.99,'eastar4uk','pyeonggy','pyeonggy@empal.com','Pyeong-kang Hur','331 Seohyeon-dong<br>Bundang-gu','Seongnam-si','Kyeonggi-do','KOREA,REPUBLIC OF','463-820','82-10-4181-9230','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 11:25:39',0,NULL,3,1,3,1,'RA184503869CN\r ','eastar4uk\rHSPH008'),(23046,634340152004,140516496368,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',6,'TRTS001*10',504,'cnfaner','gigadata','gigadataus@gmail.com','Beyin IT','39 Plymouth St<br>Fl 1st Ste D','Fairfield','NJ','UNITED STATES','07004-1633','(862) 234-5966','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-06 11:28:44',0,NULL,3,1,4,1,'YW870146892CN\r ','cnfaner\rTRTS001*10'),(23047,800059449007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','vikstr07','crisvik1@bigpond.com','Vicki Sherlock','7 Yirra Cres','Rosebery','Northern Territory','AUSTRALIA','0832','0889313073','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-06 11:40:54',0,NULL,3,0,3,1,'RA184505017CN\r ','au-buy\rPSGL001*2'),(23048,628837762003,130553090501,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',35.99,'cnfaner','regdone','regdone@gmx.net','Steffen Enke','Grüner Weg 11','Dresden-Gohlis','','GERMANY','01156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 11:49:49',0,NULL,3,1,3,1,'RA184503798CN\r ','cnfaner\rWWSI004'),(23049,947184841012,220917833601,'New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009',96.99,'eastar4','turbobeef','craigvahldieck@yahoo.com.au','Craig Vahldieck','9 Chisholm ct','Golden Grove','South Australia','AUSTRALIA','5125','0431644070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 11:51:16',0,NULL,3,1,3,1,'RA184505034CN\r ','eastar4\rGLSG009'),(23050,947187193012,220713846320,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET+carcharger',1,'HSNO005+CCNO001',10.88,'eastar4uk','suggsforprimeminister','amandabilly2000@yahoo.co.uk','amanda weston','19 rydons way','redhill','Surrey','UNITED KINGDOM','rh1 6es','07751226784','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 11:57:40',0,NULL,3,1,3,1,'RA184503991CN\r ','eastar4uk\rHSNO005+CCNO001'),(23051,947204842012,220922467202,'New Nokia Easy-to-use Bluetooth Headset BH-301 w/Fashion Conscious',1,'HSNO036',37.99,'eastar4','makqq','voltservice@gmail.com','Andriy Makovetskiy','st. Velichkovskogo, 30/13  pbox #729<br>+38 (063) 3151512','Lviv','Lvivska','UKRAINE','79002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 12:54:03',0,NULL,3,1,11,1,'BJ01713560\r ','eastar4\rHSNO036\r纯棕色的'),(23052,947214962012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','efihsystems67','efihsystems@gmail.com','efi hason','39','mochav peduyim','מושב פדויים','ISRAEL','85108','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 13:15:21',0,NULL,3,1,11,1,'BJ01713571\r ','eastar4\rOTCN004*10'),(23053,855805535011,320701015963,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT001*2',88.99,'eastar4','sevyro','sever_pencu@yahoo.com','sever pencu','emil botta no. 3E','zalau','salaj','ROMANIA','450045','0040723551673','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 13:16:15',0,NULL,3,1,3,1,'RA184503767CN ','eastar4\rGLOT001*2'),(23054,855820418011,320700572592,'New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001',43.99,'eastar4uk','hillsidehobbies','pat_wass@hotmail.com','Pat Wass','Penrallt<br>403 Mansfield Road','Breadsall','Derbyshire','UNITED KINGDOM','DE214FT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 13:58:54',0,NULL,3,1,3,1,'RA184504008CN\r ','eastar4uk\rGLSG001'),(23055,947232286012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'eastar4','landyromeu22','landyromeu@yahoo.es','orlando roche romeu','8851 nw 119th st<br>unit 6213','hialeah gardens','FL','UNITED STATES','33018','(305) 456-8304','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 14:02:01',0,NULL,3,1,1,1,'LK227782292CN\r ','eastar4'),(23056,808405903001,110810482702,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'buysia','faro.321','fabianroude@hotmail.com','Fabian Roude','111 Sweetwater Hills Dr','Longwood','FL','UNITED STATES','32779-2447','(407) 617-2935','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-06 14:44:01',0,NULL,3,1,1,1,'LK227616145CN\r ','buysia\r美标'),(23057,855846170011,320812367704,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',53.99,'eastar4uk','redolf','gaiscedach_redrum@hotmail.com','Daniel Aschenbrenner','Paul-Gerhardt-Str.6','Roding','','GERMANY','93426','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 15:08:20',0,NULL,3,1,3,1,'RA184503930CN\r ','eastar4uk\rGPS0011\r旧的'),(23058,852746050002,120855593935,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',4,'PSGL001',287.96,'buysia','tiandah','dancing_fool_14@hotmail.com','Myra Hasenclever','RR2 site 6 box34','Grande Prairie','AB','CANADA','T8V 2Z9','(780) 538-3507','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-06 15:20:44',0,NULL,3,1,6,1,'EE651291564CN ','buysia\rPSGL001'),(23059,943899813012,220628654659,'2.1 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2101',12.39,'eastar4','emumyth','emumyth@juno.com','joe anthony urias','417 Burcham Ave','US','TX','UNITED STATES','78221','(210) 392-3810','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 15:38:29',0,NULL,3,1,1,1,'LK227781535CN\r ','eastar4'),(23060,947273521012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',139.95,'eastar4','youtube12345','1a1z2s2x@gmail.com','Dakota Benedek','375 PEARL ST','BROOKLYN','NY','UNITED STATES','11201-3706','(503) 923-1343','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 15:42:41',0,NULL,3,1,1,1,'LK227782845CN\r ','eastar4'),(23061,855863284011,320828184970,'New Antiglare Flat Rear View Mirror 300MM W/Compass & Thermometer just Click On',1,'RVM0002',10.29,'eastar4uk','lpop9556','charllo@aol.com','Lloyd Pope','351 Miller School RD','Charlottesville','VA','UNITED STATES','22903','(208) 315-2519','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 15:49:18',0,NULL,3,1,1,1,'LK227784934CN\r ','eastar4uk'),(23062,855866533011,320730085700,'New Atheros AR5B95 AR9285 Half Mini PCI-E+ANTENNA',5,'WLAT009+ANTY001',39.95,'eastar4uk','yobbaray','jon@theednies.com','Ozmo','Unit 6, Clive Ct<br>Bartholomews Walk','ELY','Cambridgeshire','UNITED KINGDOM','CB7 4EA','01353664487','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 15:57:33',0,NULL,3,1,3,1,'RA184503807CN\r ','eastar4uk\rWLAT009+ANTY001'),(23063,634405991004,140680154335,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',2,'PSGL001',141.98,'cnfaner','black_baron','tm@mail.ru','Ilya Chebotkov','Ostrovityanova 4 app.31','Moscow','','RUSSIAN FEDERATION','117513','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 16:04:03',0,NULL,3,1,3,1,'RA184505096CN\r ','cnfaner\rPSGL001'),(23064,628901293003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',27.59,'cnfaner','ojg77','ogatlin@att.net','Otis Gatlin','467 Hummingbird Ln','Bolingbrook','IL','UNITED STATES','60440-4975','(773) 354-1430','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-06 16:16:37',0,NULL,3,1,1,1,'LK227588532CN\r ','cnfaner'),(23065,689721350013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',5,'HSNO019',189.9,'eastar4','vtuc5626','tuckervj@ccrsb.ca','Valerie Tucker','Chignecto-Central Reg Sch Brd<br>60 Lorne Street','Truro','NS','CANADA','B2N3K3','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-03-06 17:07:57',0,NULL,3,1,3,1,'RA184503665CN\r ','eastar4\rHSNO029\r'),(23066,855903796011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','lylegl','are436@hotmail.com','Lyle E Gluck','1711 NW 86th Ave','Plantation','FL','UNITED STATES','33322','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 17:18:35',0,NULL,3,1,1,1,'LK227804846CN\r ','eastar4'),(23067,853145869002,120856120178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',275.99,'buysia','digi_world360','yosh401@gmail.com','Steven Ferrazzano','26 OAK ST','cranston','RI','UNITED STATES','02910-3011','(401) 431-3280','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-06 17:20:39',0,NULL,3,1,4,1,'YW870146870CN\r ','buysia\rPSGL001*4'),(23068,852975449011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','itsacowboything','kriskauf123@yahoo.com','Krissy Kaufmann','18 E Church Rd','Plymouth Meeting','PA','UNITED STATES','19462-7138','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 17:40:46',0,NULL,3,1,1,1,'LK227782139CN\r ','eastar4'),(23069,947343490012,220806861411,'New lady lotus leaves sun/rain stick Umbrella maroon',1,'UM00002',24.99,'eastar4','tulnikova_s','tulnikova.svetlana@yandex.ru','Светлана Тульникова','street Lukinskaja the house 5 apartment 524','Moscow','','RUSSIAN FEDERATION','119634','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 18:07:56',0,NULL,3,1,11,1,'BJ01713576\r ','eastar4\rUM00002'),(23070,855933013011,320473739259,'NEW CAB-6060 Back to Back  WIC-1T TO WIC-1T 1T DTE DCE',2,'CASS003',21.98,'eastar4','tyronsin2010','tysing@gmail.com','Tyrone Singleton','8049 Dorinda Ave','Las Vegas','NV','UNITED STATES','89147-5040','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-06 18:13:54',0,NULL,3,1,1,1,'LK227777920CN\r ','eastar4'),(23071,634452889004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.89,'cnfaner','viniciusfleal','viniciusfl@gmail.com','Vinícius Leal','Martins Ribeiro street,  n.12, apt.812<br>Flamengo','Rio de Janeiro','Rio de Janeiro','BRAZIL','22231-150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 18:25:30',0,NULL,3,1,3,1,'RA184503775CN ','cnfaner\rLGAD001'),(23072,947360728012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Loh Wan Ping','17230 NE Sacramento St<br>Ste VP0029136','Portland','OR','UNITED STATES','97230-5940','(345) 345-2334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 18:29:25',0,NULL,3,1,1,1,'LK227789137CN\r ','eastar4'),(23073,947368607012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','nismosx','homeswithpam@yahoo.com','Pamela Wilferd','3643 Calico Cove Ct.','Las Vegas','NV','UNITED STATES','89147','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 18:42:14',0,NULL,3,1,1,1,'LK227776368CN\r ','eastar4'),(23074,947368330012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Donna J. Thurson','9010 W 123rd St','Palos Park','IL','UNITED STATES','60464-1759','(503) 124-7868','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 18:43:00',0,NULL,3,1,1,1,'LK227791008CN\r ','eastar4'),(23075,947386880012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','telehd','seolime@ya.ru','Uriy Vladimirovich Brizhan','Chertanovskaya 30-3-77','Moscow','','RUSSIAN FEDERATION','117525','(495) 502 - 6203','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 19:06:53',0,NULL,3,1,3,1,'RA184505025CN\r ','eastar4\rPSGL001*4'),(23076,634473222004,140680154335,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',70.99,'cnfaner','jomartincir','jomartincir@gmail.com','Jorge Martinez Fernandez','Jaen, 20','Rubi','Cataluña','SPAIN','08191','644547565','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 19:17:43',0,NULL,3,1,3,1,'RA184503965CN\r ','cnfaner\rPSGL001'),(23077,947396930012,220966989378,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',23.99,'eastar4uk','thomsonvip1','george.harbisher@ntlworld.com','george    b harbisher','6 westfield place,  acomb','york','north yorkshire','UNITED KINGDOM','yo243hw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 19:21:41',0,NULL,3,1,3,1,'RA184503890CN ','eastar4uk\rGPS0010+ADPT001'),(23078,947397547012,220705652000,'New GENUINE NOKIA BH-103 BLUETOOTH HEADSET',2,'HSNO003',27.9,'eastar4uk','albakri1','albakri1@hotmail.com','MOHAMED ALBAKRI','73 ZAMBEZIE DRIVE','EDMONTON','London','UNITED KINGDOM','N9 0FT','07985117217','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 19:23:06',0,NULL,3,1,3,1,'RA184503909C ','eastar4uk\rHSNO003\r英标'),(23079,689787427013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',88.99,'eastar4','danielmi73','daniel.milshtein@gmail.com','hila danny milshtein','balfur 3/6','rishon lezion','','ISRAEL','75314','97254931232','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 19:47:56',0,NULL,3,1,3,1,'RA184505105CN\r ','eastar4\rGLOT001*2'),(23080,855994499011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',2,'OTSO002',95.78,'eastar4uk','nymmit','ostiy@web.de','Steffen Glöde','Friedhofsweg 11','Rostock','','GERMANY','18057','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 19:56:38',0,NULL,3,1,3,1,'RA184503427CN\r ','eastar4uk\rOTSO002'),(23081,855993451011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','georgitzik6','billgeo13@gmail.com','Vasileios Georgitzikis','Rodou 79','Patras','N Achaias','GREECE','26223','+30 6993704330','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 19:59:01',0,NULL,3,1,11,1,'BJ01713570\r ','eastar4uk\rCACN004'),(23082,791781496008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'au-buy','susa-9','susana.zarotsky@gmail.com','Aron Zarotsky','Anna Frank 45/28','Bat Yam','IL','ISRAEL','59627','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-06 20:06:46',0,NULL,3,1,3,1,'RA184503926CN\r ','au-buy\rLGAD001'),(23083,947461835012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','plexicfreak','plasticfreak@web.de','Sebastian Müller hofkapellmeister','Luisenstrasse 41','Berlin','','GERMANY','10117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 20:55:52',0,NULL,3,1,11,1,'BJ01713563\r ','eastar4\rMOAP001'),(23084,947474292012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','ptom4700','bryan4700@gmail.com','Geffrey Miller','3078 Uxbridge Woods Ct','Charlotte','NC','UNITED STATES','28205-6287','(704) 361-4983','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 21:14:41',0,NULL,3,1,1,1,'LK227799151CN\r ','eastar4'),(23085,947481868012,220455487095,'HP DV9200 DV9800 DV9900 Bluetooth Module 2.0 EDR+cable',1,'BTHP2011',9.88,'eastar4','kamussss','drmatoscairus@hotmail.com','Luis Matos','Eps Y-12841 8260 N. W 14th St. Doral','Miami','FL','UNITED STATES','33126','809 581 1912','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 21:26:55',0,NULL,3,1,1,1,'LK227761394CN\r ','eastar4\rHP 8pin 1.25 25cm '),(23086,947494949012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','zherutis','karolis199@gmail.com','Karolis Jurgutis','Sukileliu 79-39','Kaunas','','LITHUANIA','49235','+37061437967','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 21:50:17',0,NULL,3,1,11,1,'BJ01713569\r ','eastar4uk\rMOMI002'),(23087,947502360012,220890236088,'Logitech G7 Rechargeable Battery MX revolution mous',1,'BALO009',5.99,'eastar4uk','lebrun_mikael','amnezik@gmail.com','Mikaël LEBRUN','30 boulevard Camille saint Saëns<br>(apt. 54)','LOGNES','Île-de-France','FRANCE','77185','0160067150','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 22:03:58',0,NULL,3,1,11,1,'BJ01713574\r ','eastar4uk\rBALO009'),(23088,947505393012,220713846344,'New GENUINE NOKIA BH-202 BLUETOOTH HEADSET',1,'HSNO006',9.39,'eastar4uk','martyn.lfc','mf007i0619@blueyonder.co.uk','Martyn Flew','58 Lulworth Crescent<br>Downend','Bristol','Avon','UNITED KINGDOM','BS166RZ','01179083203','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 22:09:00',0,NULL,3,1,3,1,'RA184503824CN ','eastar4uk\rHSNO006\r英标'),(23089,946711957012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',2,'HSNO005',27.78,'eastar4','dtcchief','dtcphilpa@hotmail.com','Doris Philhower','2763 W 10th St','Erie','PA','UNITED STATES','16505-4155','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 22:19:53',0,NULL,3,1,1,1,'LK227804687CN\r ','eastar4'),(23090,856080471011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','tobert75','mail@tobert75.de','Tobias Weber','Südstr. 4','Möhnesee','','GERMANY','59519','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 22:21:44',0,NULL,3,1,11,1,'BJ01713573\r ','eastar4\rWLIN011'),(23091,947278783012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',1,'CASS001',62.9,'eastar4uk','ubikeladi.inc','ubikeladi.inc.spam@gmail.com','Mohd Zaidi Dohat','No. 7, Lintang Murni 5<br>Taman Desa Murni, Sungai Dua','Butterworth','Penang','MALAYSIA','13800','0435617236','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 22:55:20',0,NULL,3,1,3,1,'RA184503815CN\r ','eastar4uk\rCASS001\r一共买了十条\r加个电话号码\r60124288534\r\r'),(23092,629047439003,130608968286,'New Sony TMR-BR100 3D Sync Transmitter 4 HX800 HX810 HX909 LX900 NX810 3D Glasse',1,'TRSN001',27.59,'cnfaner','disun1982','kilily_sun@hotmail.com','Di Sun','365 Murray Ross Pkwy Unit#15','Toronto','ON','CANADA','M3J3T7','(416) 939-0661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 23:08:28',0,NULL,3,1,3,1,'RA184505051CN\r ','cnfaner\rTRSN001'),(23093,947539717012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','snaluori1','snaluori1@hotmail.com','Geoffrey Thomassin','16 rue de la chaille','Roulans','Franche-Comté','FRANCE','25640','0675674750','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 23:18:23',0,NULL,3,1,3,1,'RA184503841CN ','eastar4\rGLOT001'),(23094,947553749012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',149.98,'eastar4','lawnboy16','b.wall@shaw.ca','Bill R Wall','29 McGee Cres.','Saskatoon','SK','CANADA','S7L 4M6','(306) 384-0392','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 23:57:20',0,NULL,3,1,3,1,'RA184503886CN\r ','eastar4\rPSGL001'),(23095,856127118011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',26.5,'eastar4','digicable','sham.bohari@gmail.com','noorhisham bohari','78 bedok north road #12-242','default','','SINGAPORE','460078','90933153','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 00:27:12',0,NULL,3,1,11,1,'BJ01713567\r ','eastar4\rHSJA010'),(23096,689891333013,230641258273,'New lady lace trim sun/rain stick Umbrella red',1,'UM00011',24.99,'eastar4','lxs83','avtame@hotmail.com','Alexis Tame','Cheltenham Primary School<br>Charman Rd','Cheltenham','Victoria','AUSTRALIA','3192','0407705608','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 00:54:21',0,NULL,3,1,11,1,'BJ01713577\r ','eastar4\rUM00011'),(23097,8881331083267126,111,'New prolee 24K Ultra light w/Carbon Fiber ribs Sun Rain Umbrella - ',2,'UM00021',48.58,'aliexpress','1007192809','lorna.carroll@bigpond.com','Lorna Carroll','12 Gum Hill Drive Langwarrin <br>Melbourne','Victoria','','AUSTRALIA','3910','+061 03 97709145',NULL,NULL,NULL,'2012-03-07 01:21:07',0,NULL,3,1,3,1,'RA184503736CN\r ','UM00021 两把黑色的 '),(23098,689901602013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','771shaun','shaundriesen@optusnet.com.au','Shaun Driesen','Suite 6<br>431 Burke Road','Glen Iris','Victoria','AUSTRALIA','3146','0398226999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 01:35:14',0,NULL,3,1,3,1,'RA184503957CN\r ','eastar4\rGLSG009*3'),(23099,947594235012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'eastar4','connor125','d_sherlock@csicable.net','dustin sherlock','1307 8th st sw','jamestown','nd','UNITED STATES','58401-4508','(701) 269-8748','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 01:49:01',0,NULL,3,1,1,1,'LK227844235CN\r ','eastar4'),(23100,689902976013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',175.99,'eastar4','izzo14','iozzo14@yahoo.com','chris iozzo','717 charlton st','southbridge','MA','UNITED STATES','01550-1377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 01:49:14',0,NULL,3,1,1,1,'LK227782805CN\r ','eastar4'),(23101,947603617012,220826598356,'100% Brand New Original HP Wireless mobile 2.4G mouse ',1,'MOHP001',19.9,'eastar4','igorlira','igor-lira@hotmail.com','Igor Pontes Lira','Rua Damasceno Girão, 1890 - LJ 01, Jardim América','Fortaleza','Ceará','BRAZIL','60410-444','(85)34944060','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 02:15:06',0,NULL,3,1,11,1,'BJ01713634\r ','eastar4\rMOHP001'),(23102,689297208013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','bsengir','saumurer@videotron.ca','Roch Saumure','11 De Pont-Rouge','Gatineau','QC','CANADA','J8P 7T5','(819) 669-9964','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 02:57:36',0,NULL,3,1,11,1,'BJ01713572\r ','eastar4\rUM00041'),(23103,634612501004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',50.99,'cnfaner','reginado-fiel','reginaldoalv@uol.com.br','Reginaldo Alves de Souza','Rua Pestana, 116 - V. Guacá','São Paulo','São Paulo','BRAZIL','02433-070','11-20990263','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 02:53:48',0,NULL,3,1,3,1,'RA184503838CN\r ','cnfaner\rLGFI001\r\r'),(23104,629112119003,130490976154,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',17.89,'cnfaner','gutekwroc','gutekwroc@yahoo.com','Przemyslaw Gonciarz','50 Creek Rd','Huntington','NY','UNITED STATES','11743-2023','(631) 943-0199','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 04:07:50',0,NULL,3,1,1,1,'LK227980315CN\r ','cnfaner'),(23105,8881331094709588,111,'4 Parking Sensor  light silver',1,'',0,'buysia','qduo9049','tiensi_kimquangduong_robot@yahoo.com','QUANG DUONG VU','8 Barnes cres','melbourne','Victoria','AUSTRALIA','3020','0423364486',NULL,NULL,NULL,'2012-03-07 04:31:49',0,NULL,3,1,3,1,'RA184502452CN\r ','buysia\r补发部件 只发四个探测头\r图片中7号颜色（浅银色）'),(23106,689949603013,230412690701,'2.0 New ASUS Bluetooth Module BT-183 +cable G1S A6 Z92',1,'BTHU2005',9.88,'eastar4','andrew4','andrew54935@hotmail.com','andrew schneider','N7520 Sandy Beach Rd','taycheedah','wi','UNITED STATES','54935-2742','(920) 913-8439','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 05:12:11',0,NULL,3,1,1,1,'Lk227972858CN ','eastar4\r华硕 8pin 1.0 6cm  '),(23107,8881331103310891,111,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',0,'eastar4','vicky_b7','vickygrenier83@hotmail.ca','Vicky Grenier','851, rue du boisé','Granby','QC','CANADA','J2J 2X4','(450) 378-4168',NULL,NULL,NULL,'2012-03-07 06:55:10',0,NULL,3,1,3,1,'RA184505048CN\r ','GLOT001\r补货 '),(23108,634654127004,140626376987,'Sony Ericsson HBH-DS970 Bluetooth headset',1,'HSSE010',63.99,'cnfaner','sewajunior2012','sewajunior@yahoo.fr','Koamivi AMEDIFOU SEWA','2221 Houma Blvd<br>Apt 225','Metairie','LA','UNITED STATES','70001-6531','(504) 335-8243','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 07:15:34',0,NULL,3,1,1,1,'LK228080619CN\r\r ','cnfaner'),(23109,800500301007,170730544640,'3DConnexion SpacePilot USB Intelligent 3D Motion Controller mouse',1,'MOLO010',208.99,'au-buy','aj1050','atifjamil81@gmail.com','Atif Jamil','1-B Myall Road','Mount Colah','New South Wales','AUSTRALIA','2079','0294775569','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 07:15:37',0,NULL,3,1,4,1,'YW870146881CN','au-buy\rMOLO010'),(23110,942114215012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','rizla306','rizla3066@hotmail.com','ben lord','36 summerseat close<br>salford','manchester','Greater Manchester','UNITED KINGDOM','M5 3JQ','07871637304','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 07:08:43',0,NULL,3,1,11,1,'BJ01713562\r','eastar4\rBTAC2005\racer 4pin1.25 8cm \r'),(23111,800510194007,170764043239,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',66.49,'au-buy','wombatbay','lindsay.hess@trulyis.me','Lindsay Hess','24 Pine County Place','Bellbowrie','Queensland','AUSTRALIA','4070','0732028072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 07:42:52',0,NULL,3,1,3,1,'RA184503705CN\r ','au-buy\rPSGL001'),(23112,947693093012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','ohallifax','oliver@hallifax.co.uk','Oliver Hallifax','6 North  Gardens','London','London','UNITED KINGDOM','SW19 2NR','07963834295','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 07:47:14',0,NULL,3,1,3,1,'RA184503855CN ','eastar4uk\rSAFI001'),(23113,629144337003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','andysakana','ajowu@ucdavis.edu','Amanda Wu','44 Lariat Ct','Walnut Creek','CA','UNITED STATES','94596-6633','(510) 962-1012','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 07:53:28',0,NULL,3,1,1,1,'LK228084292CN\r ','cnfaner'),(23114,808793188001,110819589029,'New Replaceable Shell for logitech MX Air Mouse',1,'SHLO001',14.99,'buysia','oodabearsoo','steveschneider8678@yahoo.com','Steve Schneider','17112 William St','Lansing','IL','UNITED STATES','60438-1380','(708) 895-5147','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 07:41:17',0,NULL,3,1,1,1,'LK228084173CN\r ','buysia'),(23115,634666572004,140584810434,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',21.9,'cnfaner','t.rex!','tj@purdie.com','Trevor Purdie','Imp. de la Crêta 4','Neyruz','','SWITZERLAND','1740','41263227429','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 08:24:21',0,NULL,3,1,3,1,'RA184503988CN\r ','cnfaner\rOTGR005'),(23116,947704000012,220917833039,'2 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*2',191.99,'eastar4','usaevali','usaev_ali@mail.ru','Али Усаев','Дахадаева, 11,','Дербент','Республика Дагестан','RUSSIAN FEDERATION','368601','+7(909)4805810','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 08:26:58',0,NULL,3,1,3,1,'RA184503872CN\r ','eastar4\rGLSG009*2'),(23117,947704597012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',7.99,'eastar4uk','paddyhal','miss_pody@hotmail.com','Mark Collins','Unit 48 Weaver Ind Est<br>Blackburne St','Liverpool','Merseyside','UNITED KINGDOM','L19 8JA','07771730837','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 08:27:22',0,NULL,3,1,3,1,'RA184503719C','eastar4uk\rRELO002'),(23118,808799316001,110826639527,'New Bracket of MINI HALF WLAN/WIFI/WIRELESS CARD to PCI-E',1,'MOCN001',3.98,'buysia','rhak9080','liton2k@gmail.com','Md. Rezaul Hossain','House 146/1, Road - 2, Block - A,<br>Section - 12,','Dhaka','Pallabi','BANGLADESH','1216','8801822829015','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 08:12:28',0,NULL,3,1,11,1,'BJ01713633\r ','buysia\rMOCN001'),(23119,947710732012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','miklesat123','miklesat@yahoo.com','Mikhail Zakharov','Novorossiyskay Str 30-1-217','Moscow','','RUSSIAN FEDERATION','109559','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 08:49:46',0,NULL,3,1,11,1,'BJ01713566\r ','eastar4uk\rOTGR001'),(23120,800531443007,170785414219,'New Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP003',24.69,'au-buy','jeniinej','info@thermatech.com.au','Carlton & Jeni Bone','PO Box 1154<br>Robina DC','Gold Coast','Queensland','AUSTRALIA','4226','0755260092','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 09:08:43',0,NULL,3,1,11,1,'BJ01713578\r ','au-buy\rWLAP003'),(23121,856263521011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','artemvyatkin123','artemvyatkin@gmail.com','Artem Vyatkin','2-Zheleznodorozhnaya str. 6-61','Irkutsk','Irkutskaya oblast','RUSSIAN FEDERATION','664005','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 09:12:05',0,NULL,3,1,11,1,'BJ01713575\r ','eastar4\rBTAS3002\r3.0 ASUS 6PIN 12CM  '),(23122,808815792001,110834780805,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',3.99,'buysia','vf_trading','vftrading@gmail.com','Fedor Vlassov','222 Escuela Ave<br>Apt 55','Mountain View','CA','UNITED STATES','94040','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 09:24:31',0,NULL,3,1,1,1,'LK228104805CN\r ','buysia'),(23123,856275023011,320730084108,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',8.99,'eastar4uk','paulgooddy','gooddypm@btinternet.com','Paul Gooddy','1 Hayes Street<br>Thatto Heath','St Helens','Merseyside','UNITED KINGDOM','WA10 3RF','01744753500','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 09:29:14',0,NULL,3,1,3,1,'RA184503679CN\r ','eastar4uk\rWLDE002'),(23124,792037066008,180821320427,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card+Tyco 2.4/5.0GHz Antenna',1,'WLAT001+ANTY002',15.15,'au-buy','tkmair','toni@quiana.com.au','Toni Mair','18 Lucky Bay Road<br>Secret Harbour','Perth','Western Australia','AUSTRALIA','6173','0416532545','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 09:38:38',0,NULL,3,1,11,1,'BJ01713785\r ','au-buy\rWLAT001+ANTY002'),(23125,800532776007,170756314192,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',18.99,'au-buy','anastasijaart','anastasija_art@hotmail.com','Anastasija Strokina','Dzegužu 7 - 22','Riga','','LATVIA','LV 1007','+371-297-300-04','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 09:14:03',0,NULL,3,1,11,1,'BJ01713797 ','au-buy\rUM00053'),(23126,689993543013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','levros7','leyoodro7@gmail.com','Lev Rosenblum','POB (post office box) 62125','tel aviv','','ISRAEL','61620','0546450012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 09:42:49',0,NULL,3,1,11,1,'BJ01713581\r ','eastar4\rCACN004'),(23127,689995418013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','rvbcons','daniel.saleh001@gmail.com','Daniel Saleh','8559 NW 198th Ter','Hialeah','FL','UNITED STATES','33015-6957','(954) 552-4556','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 09:51:22',0,NULL,3,1,1,1,'LK228446990CN\r ','eastar4'),(23128,689999511013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','shinjixgpl','trev@tinet.fut.es','Tomàs Reverter Morelló - SRITIC','Av. Països Catalans 5-7 (Inqui)','Tarragona','Cataluña','SPAIN','43007','620032293','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 10:14:01',0,NULL,3,0,11,1,'BJ01714383\r ','eastar4\rCACN005\r要换成New HDD Hard Drive Caddy SATA SATA2 for Apple MacBook /MacBook Pro (Special holes mount securely)\r客户补差价\r已入库'),(23129,947735889012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',74.99,'eastar4','ianw2617','gillwalton@virginbroadband.com.au','Ian Walton','5 Donna Close<br>Dingley','Melbourne','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 10:20:03',0,NULL,3,1,3,1,'RA184503651CN\r ','eastar4\rPSGL001'),(23130,0,220969584125,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',5.99,'eastar4uk','silentscream2302','zamskyebay@yahoo.com','Lada Zamsky','Pri Megadim str 16/5<br>POB 6980','Maale Adumim','ISRAEL','ISRAEL','98480','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 10:22:47',0,NULL,3,1,11,1,'BJ01714393\r ','eastar4uk\rHBPH003\r英标和欧标各一个'),(23131,800507917007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','jlia44','jing88629@hotmail.com','Jing Liang','1 Rena Court<br>Mulgrave','Melbourne','Victoria','AUSTRALIA','3170','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 10:47:01',0,NULL,3,1,11,1,'BJ01713792\r ','au-buy\rRELO002'),(23132,853493711002,120841235378,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'buysia','blefone','luke_richmond111@hotmail.com','Luke Richmond','26 Walter Way','Hamersley','Western Australia','AUSTRALIA','6022','0892469421','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 11:05:00',0,NULL,3,1,3,1,'RA184503682CN\r ','buysia\rGPS0007'),(23133,856318748011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','philkiter','phil@web-creator.co.uk','Phil Colbert','521 Newchurch Road<br>Newchurch','Rawtenstall','Lancashire','UNITED KINGDOM','BB49HH','07786965926','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 11:56:47',0,NULL,3,1,3,1,'RA184503475CN\r ','eastar4uk\rLGAD001'),(23134,853539157002,120869125980,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'buysia','georgie3000pr','sony3000pr@yahoo.com','JORGE LEBRON','VISTAS DEL CONVENTO<br>ST. 4  # 2E10','FAJARDO','PR','UNITED STATES','00738','(787) 646-8829','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 12:02:36',0,NULL,3,1,1,1,'LK228461728CN\r ','buysia'),(23135,792081772008,180755522339,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.04,'au-buy','mojo15001','jmynwa@gmail.com','Joanne Mottram','Level 14, 37 St Georges Terrace','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 12:22:10',0,NULL,3,1,11,1,'BJ01714385\r ','au-buy\rHBPH009'),(23136,947792655012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube12345','1a1z2s2x@gmail.com','Robert Ingebretsen','16507 38th Ave SE','Bothell','WA','UNITED STATES','98012-5406','(503) 722-1578','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 13:06:49',0,NULL,3,1,1,1,NULL,'eastar4'),(23137,947797537012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','srpeaton','cristian.recabarren.madrid@gmail.com','Arturo Hoffstadt','311 Lincoln, APT. E<br>SOCORRO, NM 87801','Socorro','NM','UNITED STATES','87801','575 418 0435','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 13:15:43',0,NULL,3,1,1,1,NULL,'eastar4'),(23138,792100345008,180761131351,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',2,'UM00041',37.98,'au-buy','84mel84','mel_18ish@hotmail.com','Melanie Bayntun','18 Grasstree Cres','KIRKWOOD','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 13:17:59',0,NULL,3,1,3,1,'RA184503603CN\r ','au-buy\rUM00041'),(23139,629209665003,130608487119,'NIB SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',50.99,'cnfaner','vendetta0811','huylinh1108@yahoo.com','tran huy linh','1163.budapest.sasvár utca 90','budapest','pest','HUNGARY','1163','06309609018','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 13:33:51',0,NULL,3,1,3,1,'RA184503532CN\r ','cnfaner\rSAFI001'),(23140,947809651012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','charlesmori7','charles.morissette@genivar.com','charles morissette','540 Jarry','Ste-Marie-Madeleine','QC','CANADA','J0H 1S0','(450) 778-1558','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 13:46:10',0,NULL,3,1,3,1,'RA184503550CN\r ','eastar4\rGLOT001*2'),(23141,856373106011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','dfnbr1981','daniel.negrao@hotmail.com','Daniel Negrao','Koselstr. 5','Frankfurt am Main','','GERMANY','60318','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 14:31:08',0,NULL,5,1,18,1,'RA184503594CN\r ','eastar4uk\rOTSO002\r\rhave sent'),(23142,947834783012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',4,'GLOT001',179.56,'eastar4','strhea74','strhea1@gmail.com','Stuart Rhea','1576 Killdeer Trl','Murray','KY','UNITED STATES','42071-4573','(270) 978-6257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 14:47:11',0,NULL,3,1,1,1,'LK228418512CN\r ','eastar4'),(23143,947834430012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube12345','1a1z2s2x@gmail.com','Kevin Hester','999 N Egret Bay Blvd<br>Clear Creek Community Church','League City','TX','UNITED STATES','77573-2632','(345) 345-1113','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 14:47:32',0,NULL,3,1,1,1,NULL,'eastar4'),(23144,947839611012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Sheila Walker','3601 Newark St NW','Washington','DC','UNITED STATES','20016-3179','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 15:00:10',0,NULL,3,1,1,1,'LK228458600CN\r ','eastar4'),(23145,947841212012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',5,'MOAP001',139.95,'eastar4','alainspuds','nightwalkeralain@yahoo.com','Julie R. Cowley','3251 UPLAND DR','SALT LAKE CITY','UT','UNITED STATES','84109-3799','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 15:02:49',0,NULL,3,1,1,1,NULL,'eastar4'),(23146,947848003012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Quanika Jackson','1910 Kenilworth Ave<br>Apt 1','Berwyn','IL','UNITED STATES','60402-5223','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 15:21:33',0,NULL,3,1,1,1,'LK228447947CN\r\r ','eastar4'),(23147,947855775012,220762518849,'New Atheros AR9287 Wireless BGN 300M Half PCI-E Card',1,'WLAT007',13.95,'eastar4','piyabute','piyabute@yahoo.com','Piyabute Fuangkhon','125/203 Soi Ramintra 103/3<br>Ramintra Road','Kannayao','Bangkok','THAILAND','10230','(668)1255-1626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 15:35:25',0,NULL,3,1,11,1,'BJ01713793\r ','eastar4\rWLAT007'),(23148,629244226003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','a.f.','wiesedeppe@sbcglobal.net','Albertus Wiesedeppe','360 Oakwood Trail','Fairview','TX','UNITED STATES','75069','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 15:47:39',0,NULL,3,1,1,1,'LK228418526CN\r ','cnfaner'),(23149,947865771012,220713846414,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET+carcharger',2,'HSNO019+CCNO001',53.98,'eastar4uk','sundy786','sundaskhan@hotmail.co.uk','kashif khan','55 gibwood road','northenden','Greater Manchester','UNITED KINGDOM','m224bs','07961046587','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 15:57:28',0,NULL,3,1,3,1,'RA184503529CN\r ','eastar4uk\rHSNO019+CCNO001'),(23150,856410437011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','neverbuck9','angusdays2@yahoo.com','Charles Robinson','380 Cedar Swamp Rd','Coventry','CT','UNITED STATES','06238-1072','(860) 742-6499','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 16:00:16',0,NULL,3,1,1,1,'LK228430840CN\r ','eastar4'),(23151,853635592002,120868118307,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'buysia','memig0623singapore','memig@umich.edu','Mitsu Emig','19 St. Thomas Walk<br>#28-21 Grange Heights','default','','SINGAPORE','238144','+1-646-546-5947','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 16:23:50',0,NULL,3,1,11,1,' BJ01714387\r','buysia\rHBPH009'),(23152,947890516012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',4,'GLOT001',179.56,'eastar4','uroojzil','urooj995@hotmail.com','Arif Sheikh','5499 Doctor Peddle Cre','Mississauga','ON','CANADA','L5M0K7','(905) 990-5454','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 16:48:24',0,NULL,3,1,3,1,'RA184503696CN\r ','eastar4\rGLOT001'),(23153,800691816007,170731735539,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones long cable Red',1,'HSPH002',28.49,'au-buy','rodrigoadias','diasrodri@gmail.com','Rodrigo Alves Dias','Rua Guaçui 271<br>Ap 204','Juiz de Fora','Minas Gerais','BRAZIL','36025-190','(055)3299845746','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 16:59:19',0,NULL,3,1,11,1,'BJ01714386\r ','au-buy\rHSPH002\r美标\r'),(23154,947896637012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','joshkaspar2004','joshkaspar@yahoo.com','Josh Kaspar','236 Eagle Pass Dr','New Braunfels','TX','UNITED STATES','78130-3030','(830) 743-7313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 17:00:11',0,NULL,3,1,1,1,'LK228408529CN\r ','eastar4'),(23155,947907182012,220872406392,'4 pair3D Active Shutter TV Glasses 4 Samsung SSG-2200AR',1,'GLOT001*4',175.99,'eastar4','trussgirl78','lisapoole1015@rogers.com','Lisa Poole c/o London Roof Truss','1941 Gore Road','London','ON','CANADA','N5W 6B9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:18:52',0,NULL,3,1,3,1,'RA184503461CN\r ','eastar4\rGLOT001*4'),(23156,947921748012,220455488077,'HP TX2500 TX2500z TX2z Bluetooth Module 2.0 EDR+cable',1,'BTHP2012',9.88,'eastar4','antarchadan','alfredogbonilla@terra.es','Alfredo González Bonilla','Avda. Islas Canarias, 5 - Rest.  La Repikada<br>Costa Teguise - LANZAROTE - Canary Islands','TEGUISE - Las Palmas de G.C. -','Canarias','SPAIN','35508','667467899','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:46:10',0,NULL,3,1,11,1,'BJ01713794\r ','eastar4\rBTHP2012\rHP 8pin 0.8 3cm '),(23157,800741870007,170748039367,'UNLOCKED Sierra Wireless MC8781 Air Card 3G HSUPA/HSDPA/UMTS Mini PCI-E Module',1,'WWSI005',35.14,'au-buy','elektroblitz2000','hdettmer@t-online.de','Hartmut Dettmer','Hamburger Weg 6','Delmenhorst','','GERMANY','27751','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 18:31:09',0,NULL,3,1,11,1,'BJ01713799\r ','au-buy\rWWSI005'),(23158,809019759001,110808692776,'2 pcs of New LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerat',1,'LGFI001*2',99.99,'buysia','leshiy66alex','leshiy66@walla.com','Alex Kukin','mango 5/69','ashdod','','ISRAEL','77485','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 18:41:48',0,NULL,3,1,3,1,'RA184503563CN\r ','buysia\rLGFI001*2'),(23159,947956831012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','New Mexico State University','1200 S Horseshoe<br>Foster Hall Room 120 Biology Dept.','Las Cruces','NM','UNITED STATES','88003-1234','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 18:44:49',0,NULL,3,1,1,1,'LK228467337CN\r ','eastar4'),(23160,809018387001,110808693121,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors',1,'PS00001',25.99,'buysia','nesherlee02','rudy@balboarecords.com','rodolfo olvera','10900 washington blvd','culver city','CA','UNITED STATES','90232-4025','(310) 204-3792','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-07 18:45:20',0,NULL,3,1,1,1,'LK228449293CN\r ','buysia\rpearl white'),(23161,947959754012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Joann Kolonelos','1465 RAVENWOOD ST','ANN ARBOR','MI','UNITED STATES','48103-2656','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 18:49:32',0,NULL,3,1,1,1,NULL,'eastar4'),(23162,856500817011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','misseer','e-kstra@hotmail.com','Mis Rasmussen','Fjembevej 9','9300 Sæby','Nordjyllan','DENMARK','9300','+4524757957','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 18:54:48',0,NULL,3,1,11,1,'BJ01714384\r ','eastar4\rHSJA002\r欧标'),(23163,629339639003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','fisherman-5071','kevinbrickwood@sd28.bc.ca','Kevin Brickwood','241 Kinchant St.','Quesnel','BC','CANADA','V2J2R3','(250) 983-6902','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 20:14:33',0,NULL,3,1,3,1,'RA184503515CN\r ','cnfaner\rGPS0004'),(23164,948022344012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.88,'eastar4','witru2010','wit0962@gmail.com','Victor Gratsilev','pr Udarnikov  d27 korp1 kv276','Saint Petersburg','ru','RUSSIAN FEDERATION','195279','+79112109199','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 20:19:30',0,NULL,3,1,11,1,'BJ01714390\r ','eastar4\rBTLE2001'),(23165,948044282012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Office Manager','55 S Atlantic St<br>Broderick Architects Ste 301','SEATTLE','WA','UNITED STATES','98134-1223','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 20:51:45',0,NULL,3,1,1,1,NULL,'eastar4'),(23166,948050585012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','jellyvibe','cclayton@sky.com','Christopher Clayton','28 North Oval','Dudley','West Midlands','UNITED KINGDOM','DY3 1XJ','07977262645','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 21:00:29',0,NULL,3,1,3,1,'RA184503546CN\r ','eastar4uk\rHSJA002\r欧标'),(23167,634883049004,140667903666,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Antenna *3',1,'WLAT001+ANTY002',15.89,'cnfaner','oldtechnician','rdyball@tpg.com.au','Roy Dyball','1011 Orara Way','Nana Glen','New South Wales','AUSTRALIA','2450','0266543617','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 21:07:37',0,NULL,3,1,3,1,'RA184503577CN\r ','cnfaner\rWLAT001+ANTY002'),(23168,948072833012,220915186026,'New 3-section Manual Opening Umbrella with l Oliver Green & Horse Pattern',1,'UM00052',13.95,'eastar4uk','paulwright1','eleanorwright526@btinternet.com','eleanor wright','1 vean rd','camborne','Cornwall','UNITED KINGDOM','tr14 7ta','01209610838','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 21:36:23',0,NULL,3,1,3,1,'RA184503594CN\r ','eastar4uk\rUM00052'),(23169,800865448007,170784472672,'New Genuine IBM/ThinkPad Mini PCI Atheros 5213A 802.11 a/b/g AR5BMB-44 Card',1,'WLAT006',9.02,'au-buy','panorama93','panorama93@gmail.com','Mr Donal U MacCraith','44 Esmond Road','Kilburn','London','UNITED KINGDOM','NW6 7HE','07941383633','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 21:58:43',0,NULL,3,1,11,1,'BJ01713790\r ','au-buy\rWLAT006'),(23170,948087849012,220763388868,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',3.55,'eastar4uk','lars051288','hupo.lars@gmail.com','Lars Nielsen','Neergårdsvej 10 st. th','Roskilde','','DENMARK','4000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 22:06:32',0,NULL,3,1,11,1,'BJ01713788\r ','eastar4uk\rANCN001'),(23171,856624498011,320787483311,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',19.99,'eastar4','chocobear2011','calmtheheart@yahoo.com','Gabriel  Lightheart','P O Box 92','Roberts Creek','BC','CANADA','V0N2W0','(604) 740-8087','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 22:26:09',0,NULL,3,1,11,1,'BJ01714389\r ','eastar4\rHBPH009'),(23172,800892992007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','rajk1985','rajk@iinet.net.au','Rajiv Kumar','UNIT 2<br>116 RAMSGATE ROAD','RAMSGATE','New South Wales','AUSTRALIA','2217','61447888898','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 23:01:46',0,NULL,3,1,11,1,'BJ01713786\r ','au-buy\rRELO002'),(23173,792381365008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'au-buy','bratso','alanbratt@aapt.net.au','alan bratt','24 airlie st','corowa','New South Wales','AUSTRALIA','2646','0260332951','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 23:07:54',0,NULL,3,1,3,1,'RA184503585CN\r ','au-buy\rLGAD001'),(23174,634922687004,140700677527,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','mannyv623','mannyv@q.com','manny viray','6610 w cinnabar ave','glendale','AZ','UNITED STATES','85302-1085','(623) 241-4249','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 23:10:18',0,NULL,3,1,1,1,'LK228421851CN\r ','cnfaner'),(23175,634929271004,140626374917,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004',16.5,'cnfaner','tkslee','auction@tklee.com','Tsan-Kuang Lee','1751 Princeton Dr.','State College','PA','UNITED STATES','16803','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-07 23:38:04',0,NULL,3,1,1,1,'LK228424889CN\r ','cnfaner'),(23176,800915515007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','pixie-apples','kirstencarroll86@gmail.com','Kirsten Carroll','Unit 21<br>227-229 Nepean street','Greensborough','Victoria','AUSTRALIA','3088','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 00:11:19',0,NULL,3,1,11,1,'BJ01713789\r ','au-buy\rRELO002'),(23177,945633562012,220807295631,'3 pair 3D Active Shutter Glasses for Samsung SSG-2100AB',1,'GLOT001*3',132.99,'eastar4','ggma1948','lynette.naylor1@optusnet.com.au','Lyne Naylor','162<br>Durham st','Bathurst','New South Wales','AUSTRALIA','2795','026332612100','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 01:00:54',0,NULL,3,1,3,1,'RA184503634CN\r ','eastar4\rGLOT001*3'),(23178,8881331169068921,111,'Brand New AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.39,'aliexpress','1007227782','eevrensel@gmail.com','ekrem evrensel','nuh nuh naci yazgan chest disease hospital talas yolu','kayseri','Kayseri','TURKEY','38042','+90 352 4379850',NULL,NULL,NULL,'2012-03-08 01:11:08',0,NULL,3,1,3,1,'RA184503400CN\r ','LGAD001  还买了一个 AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV    LGRM001 合并订单后   '),(23179,809196436001,110834780748,'2PCS Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna Wireless 802.11 a/b/g/n',1,'ANTY001',3.59,'buysia','evildelul','evildelul@hotmail.com','Juan Luis Garcia Pachon','Padre Chano 12','LOS SANTOS DE MAIMONA','Extremadura','SPAIN','06230','654937820','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-08 01:12:46',0,NULL,3,1,11,1,'BJ01713791\r ','buysia\rANTY001'),(23180,8881331169262897,111,'Free shipping & Tracking - AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV - ',1,'LGRM001',40.49,'aliexpress','1007226570','eevrensel@gmail.com','ekrem evrensel','nuh nuh naci yazgan chest disease hospital talas yolu','kayseri','kayseri','TURKEY','38042','+90 352 4379850',NULL,NULL,NULL,'2012-03-08 01:14:22',0,NULL,3,0,17,0,'RA184503400CN\r ',NULL),(23181,948170139012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lourdes73','lourdmartin7@aol.com','Lourdes Martinez','1157 Fulton Ave<br># 1','Bronx','NY','UNITED STATES','10456-4301','(914) 450-0105','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 01:34:36',0,NULL,3,1,1,1,'LK228441811CN\r ','eastar4'),(23182,690291204013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','denziniene1','denziniene@yahoo.com','Dan Enziniene','7517 adams st','Darien','IL','UNITED STATES','60561-4412','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 01:54:12',0,NULL,3,1,1,1,'LK228429183CN\r ','eastar4'),(23183,792455731008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',20.89,'au-buy','frisonitopiamaly','christal.ho@pacstrategy.com.au','Christal Ho','1/19 Bortfield Drive','Chiswick','New South Wales','AUSTRALIA','2046','0402055144','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 03:22:36',0,NULL,3,1,11,1,'BJ01714388\r ','au-buy\rUM00043'),(23184,948209130012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',2,'HSJA001',47.8,'eastar4','brndimcc','brndimcc@hotmail.com','Brandi McConnell','546 Atwood St<br>Apt 2','Longmont','CO','UNITED STATES','80501-5548','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 03:28:57',0,NULL,3,1,1,1,'LK228546114CN\r ','eastar4'),(23185,690316165013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mercury895','rene@ualberta.ca','Danny Aceytuno','Apt. 313 8515 112th St NW','Edmonton','AB','CANADA','T6G 1K7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 03:38:01',0,NULL,3,1,11,1,'BJ01714382\r ','eastar4\rCACN004'),(23186,690322173013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','kudder89','justin_kudrna@yahoo.com','Justin Kudrna','29101 Highway 83','wilton','ND','UNITED STATES','58579-9505','(701) 400-5137','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 04:08:31',0,NULL,3,1,1,1,'LK228561289CN\r ','eastar4'),(23187,856737677011,320844153563,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',86.99,'eastar4uk','cragerpro','waterskiski@aol.com','Protech - Scott Crager','3199 Plummers Dr<br>Ste 4','Chico','CA','UNITED STATES','95973-9506','(530) 624-4639','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 04:20:05',0,NULL,3,1,1,1,'LK228580570CN\r ','eastar4uk'),(23188,856742498011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','dlovett3','dlovett3@yahoo.com','Darlean lovett','2690 JOYCE AVE','columbus','OH','UNITED STATES','43211-3714','(614) 843-5459','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 04:38:27',0,NULL,3,1,1,1,'LK228622703CN\r ','eastar4'),(23189,629466691003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','stellarlightxs','niagaradaniel20@hotmail.com','Daniel Brousseau','934 des jardins','sainte-julie','QC','CANADA','j3e1l8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 04:40:20',0,NULL,3,1,3,1,'RA184503617CN\r ','cnfaner\rSHLO009'),(23190,800992596007,170735485649,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern   5 patterns',1,'UM00033',18.99,'au-buy','eadr6562','effie.adraktas@gmail.com','Effie Adraktas','54 Sevenoaks Road','Burwood East','Victoria','AUSTRALIA','3151','0410425197','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 05:04:33',0,NULL,3,1,11,1,'BJ01713798\r ','au-buy\rUM00033\rLittle Tower'),(23191,945609087012,220824007940,'3 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*3',78.99,'eastar4uk','djbaber76','d.baber@bigpond.com','Dwayne Baber','1/604 Burwood Highway','Vermont South','Victoria','AUSTRALIA','3133','0398025042','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 05:09:20',0,NULL,3,1,3,1,'RA184503625CN\r ','eastar4uk\rGLOT001*3'),(23192,948239824012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','notrouble_de','viv@melancolic.de','Olaf Bussmann','Herbeder Strasse 132','Witten','','GERMANY','58455','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 05:24:29',0,NULL,3,1,11,1,'BJ01713795\r ','eastar4\rWLDE002'),(23193,8881331186806562,111,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',0,'eastar4','mick42101','ramila55@hotmail.com','MAHENDRA lad','55 mill street','wolverhampton','West Midlands','UNITED KINGDOM','wv14 0hn','07759444730',NULL,NULL,NULL,'2012-03-08 06:06:46',0,NULL,3,1,11,1,'BJ01713796\r ','acer 6pin1.25 23cm\rBTAC2015\r只补发一条线 '),(23194,8881331187919912,111,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',2,'WWSI004',0,'eastar4','thunderc','bakira_st@yahoo.com','Stergios Tourtouropoulos','Kountouriotou 94<br>(Next to Praktiker), Pilea','Thessaloniki','Macedonia','GREECE','55535','+306945580828',NULL,NULL,NULL,'2012-03-08 06:25:19',0,NULL,3,1,12,1,'3126067560 ','WWSI004\r补发的 \r记得告诉客户单号\rStergios Tourtouropoulos\rKountouriotou 94\rPilea, 55535\rThessaloniki\rGREECE\r+306945580828\r'),(23195,801026580007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',131.09,'au-buy','aysen1','oaguilar@tpg.com.au','Oscar Helmut Aguilar','4 Chaucer St.','Wetherill Park','New South Wales','AUSTRALIA','2164','0296044910','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 07:58:22',0,NULL,3,1,3,1,'RA184503489CN\r ','au-buy\rPSGL001*2'),(23196,856791737011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','alfred20050_12','allanellin@fsmail.net','Alfred Ellin','55 Waterhouse Lane','Chelmsford','Essex','UNITED KINGDOM','CM1 2TE','01245250874','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 08:29:29',0,NULL,3,1,3,1,'RA184503501CN\r ','eastar4uk\rLGAD001'),(23197,948260969012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',218.99,'eastar4','di_st','di-maus@bk.ru','Vyacheslav Tochilov','Maloyaroslaveckaya 3-45','Kaluga','','RUSSIAN FEDERATION','248012','+79206152221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 08:32:37',0,NULL,3,1,3,1,'RA184503492CN\r ','eastar4\rPSGL001*3'),(23198,8881331196483564,111,'NEW Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators - ',1,'LGFI001',44.99,'aliexpress','1007251018','kermie.k@xtra.co.nz','Graeme King','20 waireka Road RD4 ','New Plymouth','New Zealand','NEW ZEALAND','4374','+64 6 7510300',NULL,NULL,NULL,'2012-03-08 08:48:03',0,NULL,3,1,3,1,'RA184503395CN\r ','LGFI001 '),(23199,801040609007,170728978814,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',42.74,'au-buy','baleno1970','rick.rickyu@gmail.com','Mr Rick Yu','P.O. Box 64','Kilmore','Victoria','AUSTRALIA','3764','0357821432','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 08:57:32',0,NULL,3,1,3,1,'RA184503435CN\r ','au-buy\rLGRM001'),(23200,629507011003,130626402767,'New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',2,'GLOT001',87.78,'cnfaner','forbiden_fruit','vmalyutin@mail.ru','Vadislav Malyutin','Raspletina str., 32-28','Moscow','Russia','RUSSIAN FEDERATION','123103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 09:25:32',0,NULL,3,1,3,1,'RA184503206CN\r ','cnfaner\rGLOT001'),(23201,629456862003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',53.8,'cnfaner','qqmonline','qqmqqm@gmail.com','Jason','2 Daisy Ct','Box Hill North','Victoria','AUSTRALIA','3129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 10:25:47',0,NULL,3,1,3,1,'RA184502418CN\r ','cnfaner\rMOAP001'),(23202,948317138012,220755246668,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',9.39,'eastar4uk','lizaw111','liza.narracott@gmail.com','Liza Narracott','Yew Tree Cottage<br>Jarvis Street','Eckington','Worcestershire','UNITED KINGDOM','WR10 3AS','01531892972','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 10:30:48',0,NULL,3,1,3,1,'RA184503081CN\r ','eastar4uk\r英标\rHSNO022'),(23203,856354004011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','gradus72','gradus1972@rambler.ru','Radik Gareev','Magistralnaya, d.13, kv.52','Priyutovo Bashkortostan','','RUSSIAN FEDERATION','452017','917-497-7504','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 10:31:20',0,NULL,3,1,11,1,'BJ01713821\r ','eastar4\rUM00040'),(23204,792561684008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.1,'au-buy','slaveone_2','nguyen55@tpg.com.au','Nguyen Le Tran','78 Hardie St, Mascot','Sydney','New South Wales','AUSTRALIA','2020','0293175402','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 11:07:16',0,NULL,3,1,11,1,'BJ01713823\r ','au-buy\rMOMI002'),(23205,635057299004,140635369210,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',67.99,'cnfaner','cors2010sales','claudiorodrigues2002@gmail.com','Claudio Rodrigues','Rua Bernardo Dornbusch, casa 1068','Jaraguá do Sul','Santa Catarina','BRAZIL','89256-100','55 47 3276-6451','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 11:34:33',0,NULL,3,1,3,1,'RA184503152CN\r ','cnfaner\rOTSO004'),(23206,856842081011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','shelterhan','prime85@naver.com','Jin-han LEE','607, Naksan-ri, Haepyeong-myeon','Gumi','','KOREA,REPUBLIC OF','730-872','010-9137-0582','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 11:37:36',0,NULL,3,1,11,1,'BJ01713833\r ','eastar4\rWLAT003'),(23207,948344823012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','adonisuk','milkyblueboy@aol.com','GARY HOPE','56 WELBECK ST<br>WHITWELL','WORKSOP','Nottinghamshire','UNITED KINGDOM','S80 4TW','01909808766','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 11:59:45',0,NULL,3,1,3,1,'RA184503135CN\r ','eastar4uk\rHSJA002\r英标'),(23208,856852198011,320707682465,'NEW GENUINE NOKIA BH-100 BLUETOOTH HEADSET BH 100',1,'HSNO030',11.99,'eastar4','pethorami','p.mensing@web.de','Peter Th. Mensing','Schlangenbader Str. 32c','Berlin','','GERMANY','14197','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 12:09:54',0,NULL,3,1,11,1,'BJ01713824\r ','eastar4\rHSNO030\r欧标'),(23209,854051900002,120855593935,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',2,'PSGL001',143.98,'buysia','benjaminazoulay','benjamin.azoulay022@sympatico.ca','Benjamin Azoulay','625 Bisaillon','Laval','QC','CANADA','h7x4e8','(514) 880-2811','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-08 12:18:34',0,NULL,3,1,3,1,'RA184503055CN\r ','buysia\rPSGL001'),(23210,948353010012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','johnson3147','jjonson@mchsi.com','jim johnson','164 Drew St','Marseilles','IL','UNITED STATES','61341','(815) 795-7606','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 12:23:05',0,NULL,3,1,1,1,'LK229131192CN\r ','eastar4'),(23211,948353246012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','hicky.the.eagle','oyvhol@broadpark.no','Oeyvind Holmen','Grimsvollen 7','Kristiansand','','NORWAY','4616','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 12:25:01',0,NULL,3,1,11,1,'BJ01713828\r ','eastar4\rBTAC2013\racer 5pin1.25 15cm '),(23212,856880871011,320402073547,'HP DV6000 DV6000t DV6000z Bluetooth Module 2.0+cable',1,'BTHP2010',9.88,'eastar4','kfrlb01','kfrlb01@yahoo.com','Regina Beach','1021 Columbia Dr','Decatur','GA','UNITED STATES','30030-4721','(678) 891-2597','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 13:36:27',0,NULL,3,1,1,1,'LK229094781CN\r ','eastar4\rHP 8pin 1.25 18cm '),(23213,690426074013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','modernartwrks','emieldegroot@gmail.com','Emiel de Groot','statensingel 49A1','Rotterdam','','NETHERLANDS','3039 LC','0614798316','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:43:01',0,NULL,3,1,11,1,'BJ01713830\r ','eastar4\rWLAP008'),(23214,629557566003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','alperbh','alper@alternatifbilgisayar.com.tr','ALPER BASARANHINCAL','GAZI CAD. ELIF ISHANI<br>KAT 2 NO 11','CORUM','MERKEZ','TURKEY','19100','+905524416281','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:49:39',0,NULL,3,1,3,1,'RA184502545CN\r ','cnfaner\rMOAP001'),(23215,943786974012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','markman_101','zbogcha@rogers.com','Zoltan Bogcha','22 La Cassandra Drive','Maple','ON','CANADA','L6A 3X2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:31:57',0,NULL,3,1,3,1,'RA184503020CN\r ','eastar4\rPSGL001*4'),(23216,635103048004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.89,'cnfaner','ale928721','alessandro-siepierski@hotmail.com','alessandro siepierski','rua chile nº62 - jardim america','cariacica','Espirito Santo - ES','BRAZIL','29140-160','0312732264790','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:56:07',0,NULL,3,1,3,1,'RA184503118CN\r ','cnfaner\rLGAD001'),(23217,856910251011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',42.99,'eastar4','bah-sete','ek_1010@hotmail.com','Evaldo Kruger','8216 Harvest Bend Ln<br>Apt 44','Laurel','MD','UNITED STATES','20707','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 14:59:22',0,NULL,3,1,1,1,'LK229097638CN\r ','eastar4'),(23218,948429850012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','sandyyeo2211','sandyyeo22@yahoo.com','Sandy Yeo','Blk 293 Choa Chu Kang Ave 3 #12-238','default','','SINGAPORE','680293','+65 9747 2221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 15:42:55',0,NULL,3,1,11,1,'BJ01713834\r ','eastar4\rHSJA001'),(23219,948429804012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Greg Hahn','18650 GLENWOOD LN','BROOKFIELD','WI','UNITED STATES','53045-1030','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 15:44:12',0,NULL,3,1,1,1,NULL,'eastar4'),(23220,856921523011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','scottlw','scott@my-messages.co.uk','Scott Williams','7 St Peters Road','Old Woking','Surrey','UNITED KINGDOM','GU229JG','01483722642','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 15:33:29',0,NULL,3,1,3,1,'RA184503064CN\r ','eastar4uk\rCACN004'),(23221,856939041011,320730548812,'2 pairs 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001*2',50.99,'eastar4uk','gosp7','gosp7@yahoo.com','Mpotaitis Lazaros','Alkiviadou 1','Alexandroupoli','Greece','GREECE','68100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 16:09:51',0,NULL,3,1,3,1,'RA184503104CN\r ','eastar4uk\rGLOT001*2'),(23222,635156459004,140675757878,'New 3D Active Shutter TV Glasses Compatible 4 Samsung SSG -2100AB 2200AB 2200AR',1,'GLOT001',43.89,'cnfaner','903rosey','tattit@suddenlink.net','Roosevelt Fuller','612 Laurel Rd','Athens','TX','UNITED STATES','75751-3302','(903) 292-1230','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-08 17:56:59',0,NULL,3,1,1,1,'LK229047279CN\r ','cnfaner'),(23223,690506549013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','paulewes','paul_m_hughes@yahoo.com','Paul Hughes','10 Albany Road','Walton on Thames','Surrey','UNITED KINGDOM','KT12 5QF','01932702971','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 18:10:57',0,NULL,3,1,3,1,'RA184503095CN\r ','eastar4\rGPS0004'),(23224,948511989012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','nickledd','nickledd@cox.net','Robert McCulloch/Claireann Headley','10 Lane St<br>Apt 7','Kent','CT','UNITED STATES','06757-1323','(760) 842-8427','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 18:22:41',0,NULL,3,1,1,1,'LK229097496CN\r ','eastar4\rPAYPAL 付款有问题'),(23225,857008180011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',19.5,'eastar4','3elementos','mm@olaxka.com','Sumisan Atn. Miguel Martínez','Edificio Aguila Rekalde 59','San Sebastián - Guipuzcoa','País Vasco','SPAIN','20018','943210002','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 18:49:38',0,NULL,3,1,11,1,'BJ01713835\r ','eastar4\rHBPH003'),(23226,857058888011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','jungler4u','lior4u@gmail.com','Lior Cohen','haturmos 10<br>haturmos 10','Rishon Lezion','israel','ISRAEL','75722','+972523027777','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 19:57:03',0,NULL,3,1,3,1,'RA184503016CN\r ','eastar4uk\rSAFI001*3'),(23227,857099893011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','manemano','ribetano@hotmail.com','Manuel Valderas Puertas','C/Ermita 17 2º A<br>Maracena','Granada','Andalucía Ceuta y Melilla','SPAIN','18200','617795235','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 21:03:55',0,NULL,3,1,11,1,'BJ01713829\r ','eastar4\rUDAP001'),(23228,801382781007,170735485699,'New News Paper 3-Section Rain Sun Floding Umbrella   newspaper',1,'UM00038',18.99,'au-buy','dearmiss4u','dearmiss@optusnet.com.au','Karen-Maree Andrews','1 Seymour St','Dundas Valley','New South Wales','AUSTRALIA','2117','61298714742','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 22:45:12',0,NULL,3,1,11,1,'BJ01713820\r ','au-buy\rUM00038'),(23229,792867450008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',11.51,'au-buy','ssjimmy3','jimmy_hughes82@hotmail.com','James','Unit 4, 8 Meagher Road','Ferntree Gully','Victoria','AUSTRALIA','3156','0419503970','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 22:55:18',0,NULL,3,1,11,1,'BJ01713826\r ','au-buy\rSHLO009'),(23230,635268050004,140700677527,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET track#',1,'HSNO019',37.68,'cnfaner','158goodwin','bigdady2123@hotmail.com','Travis Goodwin','158 Pleasant View Rd','Blythewood','SC','UNITED STATES','29016-9677','(803) 467-1442','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-08 22:59:07',0,NULL,3,1,1,1,'LK228964075CN\r ','cnfaner'),(23231,854350817002,120872829143,'New in box SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',68.99,'buysia','srmarchetti','arqsrm@uol.com.br','SERGIO RICARDO MARCHETTI','RUA WASHINGTON LUIZ, 90<br>APTO 92','SUZANO','SÃO PAULO','BRAZIL','08675040','0551174610685','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-08 23:51:27',0,NULL,3,1,3,1,'RA184503149CN\r ','buysia\rOTSO004'),(23232,948709202012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','arthurgolfer35','rossmaureentaylor@bigpond.com','arthur taylor','76 Tradewinds ave','Paradise Point','Queensland','AUSTRALIA','4216','0755771353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 00:19:38',0,NULL,3,1,11,1,'BJ01713831\r ','eastar4\rOTGR002'),(23233,946477761012,220966250846,'4 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*4',387.99,'eastar4','average_buyer_or_seller','agambotto@themissinglink.com.au','Alex Gambotto','9-11 Dickson Ave','Artarmon','New South Wales','AUSTRALIA','2064','0284368585','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 00:21:56',0,NULL,5,0,18,0,NULL,'eastar4\rGLSG008*4\r已经退款 撤单'),(23234,8881331256239865,111,'Free shipping & Tracking # - New Altec Lansing Backbeat Plus UHP206 Noise Isolation for iPod & iPhone & music players - ',2,'HSAL002',23.38,'aliexpress','1007237835','ermoskin@yandex.ru','Andrey Ermoshkin','ul.Gagarina,50/1 k52','Ufa','RB','RUSSIAN FEDERATION','450105','+8 3472 301245',NULL,NULL,NULL,'2012-03-09 01:23:59',0,NULL,3,1,3,1,'RA184502934CN','HSAL002 \r客户说要确定可用性\r'),(23235,809691216001,110819588778,'New Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.39,'buysia','vanko-2000','wcleaning@hotmail.com','IVAN KUTSAR','13593 HIGHWAY 65','Houstonia','MO','UNITED STATES','65333-2732','(916) 662-4089','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-09 01:43:33',0,NULL,3,1,1,1,'LK229053186CN\r ','buysia'),(23236,857213994011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',59.99,'eastar4','pichesito','jmc_1254@hotmail.com','Juan Manuel Cardenas','317 Heffernan Ave<br>PMB 10897-2790','Calexico','CA','UNITED STATES','92231','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 01:50:57',0,NULL,3,1,1,1,'LK229101814CN\r ','eastar4'),(23237,948747164012,220695326722,'2.1 Bluetooth cable Module screw 4 Lenovo Ideapad S10-2',1,'BTLE2102',12.39,'eastar4','grimrot','chris@formidablefrog.com','Christopher Stanford','4609 Landover Crest Dr','Raleigh','NC','UNITED STATES','27616-9022','(919) 217-4259','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 02:06:07',0,NULL,3,1,1,1,'LK229138142CN\r ','eastar4\r8pin 1.0 8cm 五线连接'),(23238,948749674012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','hilltopfarm56','jweeber@hotmail.com','James Weeber','57564 County Road 115','Goshen','IN','UNITED STATES','46528-9079','(574) 875-5069','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 02:13:53',0,NULL,3,1,1,1,'LK229085484CN\r ','eastar4'),(23239,857223093011,320721445680,'New watermelon anti-UV sun/rain parasol stick umbrella',1,'UM00012',21.99,'eastar4','sinchare','sinchare@yahoo.com.au','Charlene Sin','Tracey Brunstrom and Hammond<br>Level 12, 15 Blue St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 02:20:29',0,NULL,3,1,11,1,'BJ01713822\r ','eastar4\rUM00012'),(23240,792931893008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.1,'au-buy','ghon9409','honeys_two@yahoo.com.au','Gregory Honey','PO Box 972','Gordonvale','Queensland','AUSTRALIA','4865','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 02:31:15',0,NULL,3,1,11,1,'BJ01713832\r ','au-buy\rMOMI002'),(23241,792934320008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'au-buy','wazzabibby','wazza85@hotmail.com','warwick bibby','10 yarra close','cooloongup','Western Australia','AUSTRALIA','6168','0400857258','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 02:38:36',0,NULL,3,1,3,1,'RA184503121CN\r ','au-buy\rLGAD001'),(23242,948783749012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','bdmeehan','dianam814@gmail.com','Diana Meehan','1010 Raintree Ln','Siloam Springs','AR','UNITED STATES','72761','(479) 524-8635','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 03:55:22',0,NULL,3,1,1,1,'LK229481635CN\r ','eastar4'),(23243,857269125011,320730085638,'New Atheros AR5008 802.11N Wireless CARD+ANTENNA*3',1,'WLAT001+ANTY002',9.99,'eastar4uk','dgaguine','dgaguine@blueyonder.co.uk','David Gaguine','4 Bantree Court','Bradford','West Yorkshire','UNITED KINGDOM','BD10 0SG','01274610045','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 05:09:23',0,NULL,3,1,3,1,'RA184503078CN\r ','eastar4uk\rWLAT001+ANTY002'),(23244,856217962011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','pure_pleazure','nuklid@gmx.de','Christoph Heitzmann','Gerbestrasse 8c','Einsiedeln','','SWITZERLAND','8840','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 05:27:26',0,NULL,3,1,3,1,'RA184503033CN\r ','eastar4uk\rGLOT001'),(23245,8881331275022454,111,'New Replaceable Shell 4 logitech remote control 890 pro',1,'SHLO007',15.99,'eastar4uk','nrt1111','nrt1111@hotmail.com','Neil Taylor','12/9 Seven Hills Road','Baulkham Hills','New South Wales ','AUSTRALIA','2153 ','',NULL,NULL,NULL,'2012-03-09 06:37:02',0,NULL,3,1,11,1,'BJ01713825\r ','EASTAR4UK\r系统没有下来\rSHLO007 '),(23246,690718797013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','wiredworld1','iverson.db@hotmail.com','David Iverson','78 Ardmore Rd<br>Herne Bay','Auckland','','NEW ZEALAND','1001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 06:39:02',0,NULL,3,1,11,1,'BJ01713827\r ','eastar4\rWLAP008'),(23247,948828393012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',287.99,'eastar4','fjcatherine','fjcat@earthlink.net','F.J. and Catherine Abaya','7031 210th St SW<br>Apt B','US','WA','UNITED STATES','98036-7377','(206) 769-7350','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 07:05:41',0,NULL,3,1,1,1,'LK229522437CN\r ','eastar4'),(23248,948832547012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',125.99,'eastar4uk','bigern2572','neil.duffy@boc.com','Neil  Duffy','17 Harrington Avenue, Stockwood','Bristol','Cambridgeshire','UNITED KINGDOM','BS148JU','01275830416','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 07:33:30',0,NULL,3,1,4,1,'YW870147043CN\r ','eastar4uk\rOTSO004*4'),(23249,801518515007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.86,'au-buy','maree794','maree.jennings@optusnet.com.au','Maree Jennings','12 Wanganui Street','Kippa-Ring','Queensland','AUSTRALIA','4021','0732040824','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 07:39:53',0,NULL,3,1,11,1,'BJ01713819\r ','au-buy\rOTGR001'),(23250,857306538011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',50.99,'eastar4uk','dwsedwsee','grandamra@yahoo.gr','kostas tsobanoglou','antheon 8,<br>peraia','thessaloniki','','GREECE','57019','(0030) 23920 23311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 08:22:43',0,NULL,3,1,3,1,'RA184503166CN\r ','eastar4uk\rGLOT001*2'),(23251,690244687013,230717820578,'New In Box SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',51.99,'eastar4','lefteris1882','lefteris82@hotmail.com','LEFTERIS MPEKATOROS','EVROU 154','PIRAEUS','','GREECE','18544','00306974759745','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 08:26:48',0,NULL,3,1,3,1,'RA184503197CN\r ','eastar4\rSAFI001'),(23252,0,220969552882,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',1.99,'eastar4uk','vistuerd','david.vistuer@ntlworld.com','David A Vistuer','17 Beadon Road','Bromley','Kent','UNITED KINGDOM','BR2 9AS','07894908293','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 08:29:59',0,NULL,3,1,3,1,'RA184503183CN\r ','eastar4uk\rOTCN003'),(23253,0,320861802671,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',26.61,'eastar4uk','ajoftonteg','ajmnj@hotmail.co.uk','Alan  Jones','9 Llanberis Close<br>Tonteg','Pontypridd','Rhondda Cynon Taff','UNITED KINGDOM','CF381HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 08:52:13',0,NULL,3,1,3,1,'RA184503210CN\r ','eastar4uk\rLGRM001'),(23254,0,220969549454,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',19.99,'eastar4uk','waidute99','waidute@yahoo.com','Vaidile Burokaite','18 Blunden close<br>Dagenham','London','Essex','UNITED KINGDOM','RM81YG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 09:20:15',0,NULL,3,1,3,1,'RA184503254CN\r ','eastar4uk\rCC00002'),(23255,690739640013,230567439533,'New Intel 5300 AGN Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'eastar4','crowley_098','crowley_098@internode.on.net','Ryan Crowley','Beach Glass<br>1/6 Shearer Drive Seaford','Adelaide','South Australia','AUSTRALIA','5169','0421385815','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 09:22:09',0,NULL,3,1,11,1,'BJ01713818\r ','eastar4\rWLIN010'),(23256,948861523012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',141.99,'eastar4','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 09:30:02',0,NULL,3,1,3,1,'RA184503245CN\r ','eastar4\rPSGL001*2'),(23257,948670177012,220716106718,'New WIFLY-CITY IDU-2850UG-U20 plus Wireless USB Adapter',1,'ANWI001',55.9,'eastar4','vis_et_yok','luckowl@yahoo.es','Armando Efrén Díaz García','Alava 49  -1-  2ºIzda','Gijón','Asturias','SPAIN','33210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 09:38:07',0,NULL,3,1,3,1,'RA184503223CN\r ','eastar4\rANWI001'),(23258,8881331286091382,111,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',0,'au-buy','urmila60','urmila_sharma@hotmail.com','Urmila Sharma','148 Minchin Drive','Minchinbury','New South Wales','AUSTRALIA','2770','0432077486',NULL,NULL,NULL,'2012-03-09 09:41:31',0,NULL,3,1,3,1,'RA184503237CN\r ','au-buy \rOTGR001\r补发的'),(23259,8881331287281078,111,'Logitech MX1000 Wireless Laser Cordless Mouse - ',1,'MOLO001',59.39,'aliexpress','1007277820','p-alavin@yandex.ru','Aleksandr Panin','Sibiryakov-Gvardeitsev st.44/4, 50 ','Novosibirsk','Novosibirskaya oblast','RUSSIAN FEDERATION','630024','+7913 776 1717',NULL,NULL,NULL,'2012-03-09 10:01:21',0,NULL,3,1,3,1,'RA184502775CN ','MOLO001 '),(23260,809811340001,110837937789,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'buysia','mariakhvv','maria.bmg86@yahoo.com','Maria Bakina','ul.Vologodskaya,dom10,kv.79','Khabarovsk','ru','RUSSIAN FEDERATION','680015','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-09 10:17:32',0,NULL,3,1,11,1,NULL,'buysia\rUM00040'),(23261,857339709011,320800724949,'NIB 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001',25.99,'eastar4uk','tosh316','igotworms@hotmail.co.uk','terence carolan','228<br>Ballsgrove','Drogheda','Louth','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 10:26:26',0,NULL,3,1,3,1,'RA184502497CN\r ','eastar4uk\rGLOT001'),(23262,948890491012,220448710888,'Acer travelmate 3002 Bluetooth Module 2.0 EDR+cable',1,'BTAC2024',9.88,'eastar4','d.pasotti','icetuner@hotmail.com','Διαμαντής-Μιχαήλ Παζόττι','Ακτή Θεμιστοκλέους 342','Πειραιάς','Αττική','GREECE','18539','2104513859','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 10:55:39',0,NULL,3,1,11,1,NULL,'eastar4\rBTAC2024\racer 8pin1.25 10cm'),(23263,629859595003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',2,'GLOT001',87.78,'cnfaner','boy_in_shorts','wollin1@gmail.com','Andrey Shubin','Tverskaya str.<br>75-40','Tomsk','','RUSSIAN FEDERATION','634041','+7-952-801-3680','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 10:56:48',0,NULL,3,1,3,1,'RA184502965CN ','cnfaner\rGLOT001'),(23264,0,320861815098,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',7.99,'eastar4uk','45oakdale','csg2222@yahoo.com','Chester Gelband','241 Central Park West','New York','NY','UNITED STATES','10024','(212) 496-9299','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 11:08:03',0,NULL,3,1,1,1,'LK231077637CN\r ','eastar4uk'),(23265,801579442007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',254.59,'au-buy','jninmps','jninios@hotmail.com','Ioannis Ninios','4 Apsley Place Taren Point','Sydney','New South Wales','AUSTRALIA','2229','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 11:34:38',0,NULL,3,1,4,1,'YW870147080CN ','au-buy\rPSGL001*4'),(23266,857363800011,320800724907,'2 pairs 3D Active Shutter TV Glasses 4 Panasonic TC-P50ST30',1,'GLOT001*2',50.99,'eastar4uk','pierjudy','pierjudy@hotmail.com','Pierre Gallant','26 james lane','tide head','NB','CANADA','e3n 4r1','(506) 329-0220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 11:50:53',0,NULL,3,1,3,1,'RA184502611CN\r ','eastar4uk\rGLOT001*2'),(23267,857364192011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','sveta_orly','orlyadj@gmail.com','Svetlana Adjidersky','Zeev Lieber<br>15/4','Netania','','ISRAEL','42524','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-03-09 11:51:03',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019'),(23268,948913325012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','raphael_lp','raphael_lp@yahoo.com','Raphael Petyan','18 Moshe Shapira st.','Netanya','','ISRAEL','42240','(054) 433-2214','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 12:08:40',0,NULL,3,1,11,1,NULL,'eastar4\rOTGR001+OTGR002'),(23269,0,320861810619,'New GENUINE NOKIA HS 4W BLUETOOTH HEADSET',1,'HSNO022',4.99,'eastar4uk','petergoddijn','pgoddijn@gmail.com','Peter Goddijn','Herenstraat 105','Bussum','','NETHERLANDS','1406 PC','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 12:38:20',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSNO022\r欧标\r银色的'),(23270,948925095012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',25.99,'eastar4uk','kakto10','nazakis@otenet.gr','PROKOPIOS NAZIRIS','THOUKIDIDOU 16','THESSALONIKI','προεπιλογή','GREECE','55134','00306973229223','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 12:44:01',0,NULL,3,1,11,1,NULL,'eastar4uk\rGLOT001'),(23271,635416486004,140667905525,'New Replaceable Shell for logitech Mouse MX518',1,'SHLO004',12.99,'cnfaner','oxigenka','19081992a@gmail.com','Dmitry Kukoare','proezd Solnechniy 7, kv. 290','Tyumen','','RUSSIAN FEDERATION','625022','89220098288','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 12:38:57',0,NULL,3,1,3,1,'RA184503002CN','cnfaner\rSHLO004'),(23272,0,220969574987,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.99,'eastar4uk','lotrimar','sasa.andrijasevic@zg.t-com.hr','Sasa Andrijasevic','Jure Kastelana 26','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 13:07:14',0,NULL,3,1,11,1,NULL,'eastar4uk\rSCLO002'),(23273,690791837013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','jgre82643','jason.green@snclavalin.com','jason green','76 farrell drive','mount pearl','NL','CANADA','a1n 3g1','(709) 427-4826','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 13:16:05',0,NULL,3,1,3,1,'RA184502885CN','eastar4\rGPS0004'),(23274,801610832007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','loleaa','alexlolev@hotmail.com','Alex Lolev','41 B Irvine street','peppermint grove','Western Australia','AUSTRALIA','6011','0434925742','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 13:18:30',0,NULL,3,1,11,1,NULL,'au-buy\rRELO002'),(23275,690795579013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',2,'OT00004',15.6,'eastar4','deanlangsam','deanla@gmail.com','Bar Wizman','2/8 HaMa\'arav st.','Eilat','Eilat','ISRAEL','88000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 13:27:54',0,NULL,3,1,11,1,NULL,'eastar4\rOT00004'),(23276,801621465007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','candelles','nathan.th@optusnet.com.au','Bory Krouch','392 Ross St','Port Melbourne','Victoria','AUSTRALIA','3207','0422305957','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 13:52:30',0,NULL,3,1,3,1,'RA184502832CN ','au-buy\rPSGL001*2'),(23277,0,220969567035,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',24,'eastar4uk','ajie','stamma@bellsouth.net','charmaine sibblies','10492 SW 187th Ter','cutler bay','FL','UNITED STATES','33157-6727','(305) 233-6279','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 13:55:34',0,NULL,3,1,1,1,'LK231158358CN\r ','eastar4uk'),(23278,690801609013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','thomasvanderwillik','thomas@speedfoto.nl','Thomas van der Willik','Pijperhof 3','RAAMSDONKSVEER','','NETHERLANDS','4941WR','0162517399','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 13:51:53',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(23279,948959130012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',55.99,'eastar4','allanarmada93','armada.allan@gmail.com','Allan Armada','55 Millbrook Avenue','Bertram','Western Australia','AUSTRALIA','6167','6146640254','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 14:17:34',0,NULL,3,1,3,1,'RA184503356CN ','eastar4\rKBFF001'),(23280,629902847003,130490602003,'HP Broadcom BCM94322 bcm4322 half mini PCI-E card+2 an',1,'WLHP002+ANTY001',12.9,'cnfaner','panarigm','panariga@gmail.com','Oleksandr Kadkalenko','Vasilkovskaya 40a, apt. 56','Kiev','Kiev','UKRAINE','03022','+380672390505','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 14:25:26',0,NULL,3,1,3,1,'RA184502801CN\r ','cnfaner\rWLHP002+ANTY001'),(23281,948959298012,220946749706,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32.65,'eastar4','akafadam','vjekov@net.hr','Vjekoslav Vurnek','Krčelićeva 10','Zagreb','Zagreb','CROATIA','10000','00385922987287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 14:11:27',0,NULL,3,1,11,1,NULL,'eastar4\rGPS0010'),(23282,948974672012,220816379729,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2100AB',1,'GLOT001',25.99,'eastar4uk','mikeskender','michaelskender@hotmail.com','Michael Skender','13 Lord Byron Str.<br>Aglantzia','Nicosia','','CYPRUS','2123','0035796222740','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 14:59:26',0,NULL,3,1,11,1,NULL,'eastar4uk\rGLOT001'),(23283,948993475012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','40025lusitania','mike40025@vale-view.co.uk','Davis Coaches(Mike Ede)','Hilltop Garage<br>Cuckoo Row','Minchinhampton','Gloucestershire','UNITED KINGDOM','GL6 9HA','07581047241','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 15:33:43',0,NULL,3,1,3,1,'RA184502656CN\r ','eastar4uk\rHSJA010\r英标'),(23284,690830816013,230501420572,'NEW AKE BC168 Inside hide PCMCIA to Two USB 2.0 Ports',1,'ADAK001',12.6,'eastar4','psvo','peter.svoboda@gmx.com','Peter Svoboda','Lidvägen 11A','Jarfalla','Järfälla','SWEDEN','17740','+46-8-58033088','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 15:36:55',0,NULL,3,1,11,1,NULL,'eastar4\rADAK001'),(23285,949007839012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','verna a kalinski','7945 N 41st St','longmont','CO','UNITED STATES','80503-8843','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 16:05:09',0,NULL,3,1,1,1,'LK231089365CN\r ','eastar4'),(23286,629945440003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','per.langoey','per.la@bluezone.no','Per Langøy','Moreneveien 21','Nedre Eiker','Solbergmoen','NORWAY','3058','+4790063681','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 16:56:58',0,NULL,3,1,3,1,' RA184502917CN','cnfaner\rHSJA012\r欧标\rsilver'),(23287,949038194012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','celicagt4parts-hu','celicagt4parts@gmail.com','Turbucz László','Virág 103','Paks','Tolna','HUNGARY','7030',' 36209470468','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 17:07:27',0,NULL,3,1,11,1,NULL,'eastar4uk\r欧标\rHSJA002'),(23288,949039610012,220816317096,'NewAutofold Solid Durable16K businss Man stick Umbrella',1,'UM00020',28.99,'eastar4','highs_kill','work_stuff@mail.ru','Aleksandr Tarabrin','akademicheskaya, d 9, kv 9','Redkino','RU','RUSSIAN FEDERATION','171261',' 79038021759','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 17:09:20',0,NULL,3,1,11,1,NULL,'eastar4\rUM00020'),(23289,949031024012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',71.99,'eastar4','agentwizardsfan','green2ja@hotmail.com','Jeff Green','4412 Washington Blvd','Arlington','VA','UNITED STATES','22201-4776','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 17:30:43',0,NULL,3,1,1,1,'LK231067317CN\r ','eastar4'),(23290,949082324012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Monica G. Luchak','750 9TH ST NW<br>STE 650','WASHINGTON','DC','UNITED STATES','20001-4793','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 18:27:47',0,NULL,3,1,1,1,'LK231068516CN\r ','eastar4'),(23291,949084617012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',6.99,'eastar4uk','pure_nz_328','condor328@hotmail.com','Horvath Istvan','Hatar ut 28.','Dunaujvaros','Fejer Megye','HUNGARY','2400','+36306422266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 18:30:53',0,NULL,3,1,11,1,'BJ01712806\r ','eastar4uk\rWLAT009'),(23292,857531628011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','8033461','spyrospyros@yahoo.gr','Spyros Tselios','Μυκηνών 3 Βριλήσσια (Mykinon 3 Vrilissia)','Athens','Βριλήσσια (Vrilissia)','GREECE','15235','(0030)694-6688058','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 18:40:46',0,NULL,3,0,11,1,NULL,'eastar4'),(23293,949099316012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','akvanetltd','vgeorgiev@akvanet.com','Vasil Georgiev','G.M.Dimitrov 54 fl.4','Sofia','','BULGARIA','1125','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 18:56:43',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSJA002\r欧标'),(23294,857563533011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','154hawkeye','mpmitton@telus.net','Michael Mitton','154 - 7293 Moffatt Road','Richmond','BC','CANADA','V6Y 3E4','(604) 277-0265','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 19:37:26',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019'),(23295,857563040011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','shakirov61','shakiroman2@gmail.com','RAMIL SHAKIROV','PR. SUUMBIKE D.72 KV.92','Naberezhnye Chelny','TATARSTAN','RUSSIAN FEDERATION','423821','89625759908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 19:39:09',0,NULL,3,1,3,1,'RA184502761CN ','eastar4uk\rOTES001'),(23296,810023203001,110819588834,'New Original Logitech Unifying receiver for MX mouse and K340 K350 keyboard',1,'RELO002',12.97,'buysia','m1xcool','mxcool@gmail.com','Maksim Morozov','Sitsi 28/30 - 16','Tallinn','Harjumaa','ESTONIA','10313','37255656444','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-09 19:55:23',0,NULL,3,1,11,1,NULL,'buysia\rRELO002'),(23297,793261030008,180816092496,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',4,'',99.96,'usa-view','humbertodia','gerencia@diazpaiz.com','CARLOS DIAZ','7801 NW 37th St<br>Section 2294/GUA','DORAL','FL','UNITED STATES','33166-6503','305 592 0839','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-09 19:56:12',0,NULL,5,1,1,1,'LK230818916CN\r ','usa-view\r\r发货了，点不了'),(23298,857605664011,320730083893,'Brand new HP MCE Media Center Remote Control+ IR emitte',1,'OTHP005',11.54,'eastar4uk','agmandktb','dyserth@btinternet.com','Andrew Moore','5 Rhodfa Conwy','Dyserth','Denbighshire','UNITED KINGDOM','LL18 6LS','07725987893','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 20:52:12',0,NULL,3,1,3,1,'RA184502925CN','eastar4uk\rOTHP005'),(23299,857606075011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','lambertrose','deshavaughn@att.net','Vaughn DeSha','5236 S Grand Blvd','Saint Louis','MO','UNITED STATES','63111','(314) 704-6653','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 20:53:49',0,NULL,3,1,1,1,'LK231057840CN\r ','eastar4'),(23300,854744312002,120869127236,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',5,'MOHP002',64.95,'buysia','465ruisseau','lauzon_mike52@hotmail.com','LAUZON MICHEL','6171 blvd bourque','sherbrooke','QC','CANADA','J1N 1H2','(819) 674-0670','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-09 21:01:19',0,NULL,3,1,3,1,'RA184502789CN ','buysia'),(23301,949179871012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','librenvio','ebay@librenvio.com','Daniel Gómez Alcañiz','Avda. Casalduch, 37, 2ºD','Castellón de la Plana','Comunidad Valenciana','SPAIN','12005','605202776','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 21:10:21',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT009'),(23302,949199044012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','mmmszwedo','mmm.szwedo@wp.pl','iwona szwedo','21 buzzard road','luton','Bedfordshire','UNITED KINGDOM','lu40uf','07535560581','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 21:47:24',0,NULL,3,1,3,1,'RA184502982CN ','eastar4uk\rHSJA010\r英标'),(23303,949204948012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','otis0123','otilioperez@hotmail.com','Otilio Perez','calle las flores,edf las flores,no 21,portal 5,bajo 13','la linea de la concepcion','Andalucía Ceuta Y Melilla','SPAIN','11300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 22:00:15',0,NULL,3,1,11,1,' ','eastar4\rBTAC2015\racer 6pin1.25 23cm'),(23304,635620215004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.89,'cnfaner','salaso2008','formosabjorn@hotmail.com','Bjorn Formosa','Eutuxia<br>Triq Hadd in-Nies','Zabbar','Malta','MALTA','ZBR3552','0035679209420','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 23:51:01',0,NULL,3,1,3,1,'RA184503311CN\r ','cnfaner\rLGAD001'),(23305,949256709012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',71.99,'eastar4','twak7','twaker@comcast.net','Daniel Mullen','8119 Cadet Rd','Machesney Park','IL','UNITED STATES','61115','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 00:06:18',0,NULL,3,1,1,1,'LK231057646CN\r ','eastar4'),(23306,691004144013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','andrealice2011','aa-andrealice@hotmail.com','Andre Luiz Lima','Rua Terceira - 40 / MARAMBAIA<br>Conj. Cohab Gleba 2','BELÉM','PARA','BRAZIL','66623-180','91 32434547','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 00:17:12',0,NULL,3,1,3,1,'RA184502903CN ','eastar4\rGPS0006'),(23307,691022592013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','1dldon','donbarb@gondtc.com','Don Sowatzki','838 11th ST SE','Devils Lake','ND','UNITED STATES','58301-7601','(701) 662-5159','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 01:54:34',0,NULL,3,1,1,1,'LK231065758CN\r ','eastar4'),(23308,949296018012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Getty Images','6300 Wilshire Blvd<br>Attn Johnathan Ruggiero Ste 1600','LOS ANGELES','CA','UNITED STATES','90048-5227','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 02:15:30',0,NULL,3,1,1,1,'LK231087594CN\r ','eastar4'),(23309,801933774007,170775726989,'New HP MCE Media Center + Sony Remote Control RM-MCE20E White+IR Emitter Wire',1,'RMSN002',19.99,'au-buy','nofate17','jabez.webb@gmail.com','Jabez Webb','3/21 James Street','Box Hill','Victoria','AUSTRALIA','3128','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 02:51:04',0,NULL,3,1,11,1,NULL,'au-buy\rRMSN002'),(23310,949307717012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','ANA CRISTINA ZUÑIGA Z','2511 NW 72ND AVE','MIAMI','FL','UNITED STATES','33122-1303','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 02:54:16',0,NULL,3,1,1,1,'LK231035597CN\r ','eastar4'),(23311,857743307011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','alor7','gusloraine@hotmail.com','Angus Loraine','203-4804 Glacier Lane','Whistler','BC','CANADA','V0N 1B4','6049070704','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 03:35:42',0,NULL,3,1,11,1,NULL,'eastar4\rHSUE002'),(23312,810199300001,110827822277,'New Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'buysia','ceramicbutterfly','taninchulchue@yahoo.com','Tanin chulchue','53/35 kunalai bangyai<br>saothonghin','Nontaburi','NO','THAILAND','11140','66818138581','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-10 03:56:50',0,NULL,3,1,11,1,NULL,'buysia\rWLAT008'),(23313,630127525003,130620867014,'New Logitech Digital IO Writing Pen+ notebook',1,'NTLO001+NTLO002',52.99,'cnfaner','ninoz83','ninoz@tpg.com.au','Ninos Baba','218 Victoria st','Wetherill Park','New South Wales','AUSTRALIA','2164','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 04:25:24',0,NULL,3,1,3,1,'RA184502846CN ','cnfaner\rNTLO001+NTLO002'),(23314,854904190002,120868118107,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.79,'buysia','markb1289','m_bialy14@hotmail.com','Mark Bialy','20 Jessica Drive','St.Catharines','ON','CANADA','L2M6V7','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-10 04:31:12',0,NULL,3,1,11,1,NULL,'buysia\rMOMI004'),(23315,801959288007,170731735297,'4 pair New 3D Active Shutter TV Glasses special for SAMSUNG SSG-2100AB',1,'GLOT001*4',167.99,'au-buy','coalfalls','jarvist@bigpond.com','Shirley Baker, Brown','16 Ellenborough Street','Ipswich','Queensland','AUSTRALIA','4305','0732818386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 04:33:48',0,NULL,3,1,4,1,'YW870147102CN ','au-buy\rGLOT001*4'),(23316,949346906012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','20quasar05','lidijabocan@hotmail.com','Lidija Dobrovolny','25 Ipswich Crescent<br>Girrawheen','Perth','Western Australia','AUSTRALIA','6064','0893432394','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 05:25:39',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(23317,949347304012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','leandromdsilva','leandromacieldasilva@gmail.com','Leandro Maciel da Silva','Cícero Dias de Oliveira, nº3 casa A<br>Jardim Camburi','Vitória','Espírito Santo','BRAZIL','29090-250','552798508805','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 05:26:25',0,NULL,3,1,11,1,NULL,'eastar4\rMOMI002'),(23318,801972465007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',254.59,'au-buy','fas105','johsu@bigpond.net.au','John Difazio','PO Box 4053','Barrack Heights','New South Wales','AUSTRALIA','2528','0242977340','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 05:45:06',0,NULL,3,1,4,1,'YW870147091CN ','au-buy\rPSGL001*4\r详细地址\r105 Captain Cook Drive\rBarrack Heights NSW 2528\rAustralia\r0242977340\r\r\r'),(23319,810235074001,110837938896,'Super Light Bubble Pattern Windproof Rain/Sun Umbrella w/24 Skeleton',1,'UM00049',24.99,'buysia','mo03dayr','01kons@mail.ru','alexandr konstantinov','3/20 ul. Generalova , kv. 20','Murmansk','Murmanskaya obl','RUSSIAN FEDERATION','183010','78152238046','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-10 07:06:43',0,NULL,3,1,11,1,NULL,'buysia\rUM00049'),(23320,691087819013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ileximmf','aleximmf@gmail.com','Alexey Simonenko','Altufievskoe highway<br>h 12, appartment 297','Moscow','','RUSSIAN FEDERATION','127562','(926) 557-5582','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 07:59:57',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(23321,949387668012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',8.99,'eastar4uk','lowkahkhang','kahkhang@gmail.com','Low Kah Khang','BLK 467B Admiralty Drive #12-155','default','','SINGAPORE','752467','93900577','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 08:54:04',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLHP002'),(23322,949421777012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','park6447','idlest2000@yahoo.co.kr','Park Doo Bum','B02 101 LG-GreenBill<br>185-1 Kwean-Dong Sosa-Gu','Gyeonggi','Bucheon','KOREA,REPUBLIC OF','422-827','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 10:12:42',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLIN013'),(23323,793508167008,180827787004,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',99.99,'au-buy','bradsd89','brad-davies@live.com.au','brad davies','269 dempsey st north rockhampton','North Rockhampton','Queensland','AUSTRALIA','4701','0413664128','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 10:11:04',0,NULL,3,1,3,1,'RA184503268CN ','au-buy\rGPS0011'),(23324,793532430008,180827156330,'New HDD Hard Drive Caddy SATA SATA2 4 Apple MacBook / Pro Special design',1,'CACN005',21.99,'au-buy','robertbischof','ebay@robertbischof.com','Robert Bischof','8 Arkana Dr.','Noosa Heads','Queensland','AUSTRALIA','4567','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 11:34:10',0,NULL,3,1,11,1,NULL,'au-buy\rCACN005'),(23325,691137319013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',44.99,'eastar4','farrari2000','tdr@live.nl','Theo de Reuver','Heraut 4','OSS','','NETHERLANDS','5346WG','0624152666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 11:54:52',0,NULL,3,1,3,1,'RA184502364CN\r ','eastar4\rGLOT005'),(23326,949464335012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','rgoswell','roger@xanadude.org','Roger Goswell','145 Bemersley Road<br>Ball Green','Stoke-On-Trent','Staffordshire','UNITED KINGDOM','ST68AS','01782545012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 12:11:05',0,NULL,3,1,3,1,'RA184502863CN ','eastar4uk\rHSJA002\r英标'),(23327,691142134013,230393481722,'2.1 HP CQ45 Pavilion DV4 DV7 Bluetooth Module EDR+cable',2,'BTHP2107',24.78,'eastar4','rober8763','robert.fischer@luxinet.fr','robert fischer','38 rue des vosges','bergbieten','Alsace','FRANCE','67310','06 07 10 67 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 12:14:09',0,NULL,3,1,11,1,' ','eastar4\rHP 8pin 1.0 23cm \rBTHP2107'),(23328,857884563011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',1,'GPS0010',19.99,'eastar4uk','alison-r9','s.roberts37@ymail.com','Tony Roberts','37 stocks loke','cawston','Norfolk','UNITED KINGDOM','nr10 4bs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 12:27:35',0,NULL,3,1,3,1,'RA184502695CN\r ','eastar4uk\rGPS0010'),(23329,949474025012,220501826259,'2.1 Acer Aspire 5520 5520G 5530 Bluetooth Module+cable',1,'BTAC2125',12.39,'eastar4','christianboy62','xeniosx@mtnmail.com.cy','Xenios Xeni','20 Stavros Stylianides str.<br>Strovolos','Nicosia','','CYPRUS','2024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 12:36:49',0,NULL,3,1,11,1,NULL,'eastar4\racer 8pin1.00 18cm \rBTAC2125'),(23330,810344754001,110831128283,'New Grohe Multi Function hand Shower Head Made in Germany 7 pattens',1,'OTGR001',19.9,'buysia','nir.miz','nir.mizra@gmail.com','NIR MIZRACHI','Simeon bar Yochai 4','Rishon LeZiyyon','','ISRAEL','75282','972502345792','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-10 13:22:03',0,NULL,3,1,11,1,NULL,'buysia\rOTGR001'),(23331,948938632012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',275.99,'eastar4','ajml44yi0','ajml4@comcast.net','ANDREW LEE','183 Percival Dr','West Barnstable','MA','UNITED STATES','02668-1222','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 13:39:00',0,NULL,3,1,1,1,'LK231006264CN\r ','eastar4'),(23332,809994512001,110836854678,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern',1,'UM00033',19.99,'buysia','gradus72','gradus1972@rambler.ru','Radik Gareev','Magistralnaya, d.13, kv.52','Priyutovo Bashkortostan','','RUSSIAN FEDERATION','452017','917-497-7504','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-10 13:47:13',0,NULL,3,1,11,1,NULL,'buysia\rUM00033\rcolored dots'),(23333,635777313004,140549644810,'New HP MCE Media Center Remote Control+big IR RECEVE',1,'OTHP004',21.9,'cnfaner','w1z4rd0v1d','wizardovid@googlemail.com','Brian Fraser','70 MyLadys Road','Belfast','Antrim','UNITED KINGDOM','bt6 8fb','02895810900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 13:51:07',0,NULL,3,1,3,1,'RA184502894CN ','cnfaner\rOTHP004'),(23334,691178550013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','sceejay1851','sceejay12@hotmail.com','Steven johnson','4759 Vista St','Philadelphia','PA','UNITED STATES','19136-4112','(267) 934-8384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 14:26:26',0,NULL,3,1,1,1,'LK231086792CN\r ','eastar4\r美标'),(23335,949518628012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','quickplug','louis-xavier.falardeau.1@ens.etsmtl.ca','Louis-Xavier Falardeau','544 avenue Maple','Saint-Lambert','QC','CANADA','J4P 2S7','(450) 812-9441','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 14:22:59',0,NULL,3,1,11,1,NULL,'eastar4\rMOAP001'),(23336,949542669012,220501825899,'2.1 Acer Aspire 4720 4720G 4720Z Bluetooth Module+cable',1,'BTAC2115',12.39,'eastar4','brewmaster1550','gorrrl01@students.ipfw.edu','Ryan Gorrell','15 Ln 350 B Big Otter Lk','Fremont','IN','UNITED STATES','46737','(260) 316-2461','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 15:09:57',0,NULL,3,1,1,1,'LK231089357CN\r ','eastar4\racer 5pin1.25 20cm '),(23337,810386732001,110837938896,'Super Light Bubble Pattern Windproof Rain/Sun Umbrella w/24 Skeleton',1,'UM00049',24.99,'buysia','ds.molotkov','ss_zeus@hotbox.ru','Dmitry Molotkov','Veshnyakovskaya street, 19-319','Moscow','Russia','RUSSIAN FEDERATION','111539',' 89104417189','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-10 15:10:22',0,NULL,3,1,11,1,'BJ01713856\r ','buysia\rUM00049\r桔色'),(23338,949571447012,220966989378,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',23.99,'eastar4uk','legenddarcy2009','legenddarcy@yahoo.ie','David Darcy','72 Loughconn Road','Ballyfermot','Dublin','IRELAND','default','0871358677','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 16:06:59',0,NULL,3,1,3,1,'RA184502744CN\r ','eastar4uk\rGPS0010+ADPT001\r英标'),(23339,691211428013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'eastar4','dirtdogssc','letdirtdogs@comporium.net','Benjy Gold','Let The Dirt Dogs Do It!<br>773 Beachwood Cove Dr.','Tega Cay','SC','UNITED STATES','29708-8222','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 16:13:09',0,NULL,3,1,1,1,'LK231069896CN\r ','eastar4\r美标'),(23340,949577813012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','pvn2005','pvn2005@web.de','André Gottwald','Berliner Str. 30','Eppertshausen','','GERMANY','64859','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 16:18:16',0,NULL,3,1,11,1,NULL,'eastar4\rMOAP001'),(23341,949612112012,220759428059,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',4.99,'eastar4uk','kahudruk','exsec@blueyonder.co.uk','paul stenson','36 Spout Way<br>Malinslee','Telford','Shropshire','UNITED KINGDOM','TF3 2HD','01952282088','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 17:19:10',0,NULL,3,1,3,1,'RA184502506CN\r ','eastar4uk\rOTCN003'),(23342,949636645012,220665411123,'Newunlocked Ericsson F3607GW DELL 5540 3G GPS WWAN Card',1,'WWOT003',47.99,'eastar4','mamitzu','spopa15@yahoo.com','Nicolae Popa','1401 Grand Concourse<br>Apt 4H','Bronx','NY','UNITED STATES','10452-6733','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 18:03:38',0,NULL,3,1,3,1,'RA184502537CN\r ','eastar4\rWWOT003\r新地址\rRazvan Ionescu Dem. Teodorescu 11D etaj 1 apartament 5 sector 3 Bucuresti 030915 Romania +40 (726) 170 281 '),(23343,858048841011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',68.99,'eastar4','flexikru','flexi@tut.by','Aliaksei Kruchok','ul. Beruta, 4/3,  35','Minsk','','BELARUS','220092','+375291131838','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 18:10:33',0,NULL,3,1,3,1,'RA184502404CN\r ','eastar4\rOTSO004'),(23344,944318797012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','yamashita.wal','wal_yamashita@hotmail.com','Walkiria Yamashita','Av. Brasilia, 146 - Shp 3 Americas - B-3<br>Jardim das Americas','Cuiaba','Mato Grosso','BRAZIL','78060-601','(65)3023-5813','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 18:19:08',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN016'),(23345,949665608012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','juergenseverloh','juergen@mts.net','Juergen Severloh','650 Broadway Avenue West','Winnipeg','MB','CANADA','R3C0X3','(204) 786-1502','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 18:37:14',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(23346,949693203012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',125.99,'eastar4uk','jimmtstott1989','jimmystott89@live.co.uk','jimmy stott','22 cemetery road south','manchester','Lancashire','UNITED KINGDOM','m279th','07817312800','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 19:17:43',0,NULL,3,1,3,1,'RA184502191CN ','eastar4uk\rOTSO004*3\r客户付的是三副的钱\r发三幅就行了'),(23347,949715684012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',44.89,'eastar4','bassgiles','gilesdonn@verizon.net','Donnell Giles','2805 Granite Rd','woodstock','MD','UNITED STATES','21163-1127','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 19:52:26',0,NULL,3,1,1,1,'LK231125536CN\r ','eastar4'),(23348,691313663013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','brodriges4','brodriges@rambler.ru','Denis Talochkin','Bulvar Pobedy 36-63','Voronezh','Voronezhskaya obl','RUSSIAN FEDERATION','394077','7 (910) 348 - 1688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:10:31',0,NULL,3,1,3,1,'RA184502727CN\r ','eastar4\rGLSG009*3'),(23349,858125220011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','dapl1959','daniel.plouffe@connexim.ca','Plouffe Daniel','5201 Catherine','La Plaine','QC','CANADA','J7M 1W5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:11:53',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA002'),(23350,691313116013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','mercedesbilgin','bilgin.yabanok@hotmail.co.uk','bilgin yabanok','maidstone road','sidcup kent','Kent','UNITED KINGDOM','da14 5bg','07710317927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:17:06',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019\r英标\r'),(23351,858138183011,320812367818,'New I.Tech Clip Music 802i FM Stereo Bluetooth Headset Earphone for iPhone',1,'HSIT005',29.99,'eastar4uk','spgousias123','spgousias@yahoo.gr','Spyros Gousias','7, Mavrovouniou street','CHAIDARI','Athens','GREECE','12461','+306942061823','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 20:37:04',0,NULL,3,1,3,1,'RA184502449CN\r ','eastar4uk\rHSIT005'),(23352,630384420003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','thelambdidit2','theliondidit2@verizon.net','Frank Barreiro','5301 Pilots Pl','New Port Richey','FL','UNITED STATES','34652-3060','(727) 849-2341','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-10 20:54:30',0,NULL,3,1,1,1,'LK230801218CN\r ','cnfaner\r'),(23353,949757539012,220816389147,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','rinat555rinat','rinat193911@walla.com','rinat shemesh','hugo ernest 18','holon','','ISRAEL','58516','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 20:58:13',0,NULL,3,1,11,1,NULL,'eastar4uk\rSHLO005'),(23354,635948434004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',1,'HSNO005',13.79,'cnfaner','misiek1220','jacekwaw69@wp.pl','Stanislaw Pańpak','lordsbridge farm<br>wimpole road','cambrige','Cambridgeshire','UNITED KINGDOM','cb237ae','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:41:14',0,NULL,3,1,3,1,'RA184502877CN ','cnfaner\rHSNO005\r英标'),(23355,691363816013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',2,'OT00004',15.6,'eastar4','olegoleg971','oleg.triger@mail.ru','oleg triger','2828w28str ap3b<br>brooklyn','new york','NY','UNITED STATES','11224','(718) 372-0680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 22:23:10',0,NULL,3,1,1,1,'LK231138835CN\r ','eastar4'),(23356,858202820011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','danceminister','showanna.sharae@yahoo.com','Showanna Butler','12635 S Lincoln St<br>Apt 11','Calumet Park','IL','UNITED STATES','60827-5663','(708) 955-5714','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 22:38:17',0,NULL,3,1,1,1,'LK231109082CN\r ','eastar4'),(23357,858214795011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',4,'OTSO004',171.96,'eastar4uk','mikeh080874','eating@hotmail.co.uk','Michael Henderson','59 Younger Gardens','St Andrews','Fife','UNITED KINGDOM','KY16 8AB','01334472315','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 23:08:16',0,NULL,3,1,4,1,'YW870147135CN ','eastar4uk\rOTSO004'),(23358,949830549012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',88.99,'eastar4','albwong5','albert_wong_yc@hotmail.com','ALBERT WONG','5696 river grove ave,','MISSISSAUGA','ON','CANADA','L5M 3V7','(905) 567-0169','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 23:41:48',0,NULL,3,1,3,1,' RA184502792CN','eastar4\rGLOT001*2'),(23359,793857614008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','taliesinwb','wayneb71@tpg.com.au','Wayne Bateup  Nova Multimedia','Unit 1 41 - 45<br>Tennant St Fyshwick','Canberra','Australian Capital Territory','AUSTRALIA','2609','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 23:49:13',0,NULL,3,1,11,1,NULL,'au-buy\rMOMI002'),(23360,688596013013,230717843796,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Lace Trim',1,'UM00042',19.99,'eastar4','books_and_clothes123','booksandclothes@hotmail.com','Mira Macdonald','36 Lee road','Winmalee','New South Wales','AUSTRALIA','2777','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 01:25:39',0,NULL,3,1,11,1,NULL,'eastar4\rUM00042'),(23361,858268428011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','dhauze','fkitdeena@live.com','Deena Hauze','2787 Crimson Hawks','Indiana','PA','UNITED STATES','15705-2787','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 01:48:23',0,NULL,3,1,1,1,'LK231088833CN\r ','eastar4'),(23362,802435983007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','gincharoony','tammy.grayden@yahoo.com.au','Tammy Grayden','86 Strickland Street','South Perth','Western Australia','AUSTRALIA','6151','0893680163','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 01:50:59',0,NULL,3,1,11,1,NULL,'au-buy\rUM00040'),(23363,858273423011,320460449681,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',85,'eastar4','iron_encino_man','amillan85@gmail.com','Antonio Millan','111 Buscomb Ave, Henderson','Auckland','Auckland','NEW ZEALAND','0610',' 6498370188','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 02:02:52',0,NULL,3,1,3,1,'RA184502381CN\r ','eastar4\rTRTS001*10'),(23364,949892140012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','sky_power1','lijiangli@yahoo.com','Jiang Li','65 Seminole Way','Short Hills','NJ','UNITED STATES','07078-1216','(917) 545-6539','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 02:16:53',0,NULL,3,1,1,1,'LK231112104CN\r ','eastar4uk'),(23365,802444690007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','mysteex','alsu.ecommerce@gmail.com','Alexis SUSSER','113A Carpenter Street','BRIGHTON','Victoria','AUSTRALIA','3186','0407658164','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 02:24:25',0,NULL,3,1,3,1,'RA184502735CN\r ','au-buy\rPSGL001*2'),(23366,802440660007,170784441949,'New Genuine Atheros AR9281 802.11N Wireless WiFi Mini PCI-E Card Over AR5008',1,'WLAT010',8.99,'au-buy','cragv01','craig@dataretriever.com.au','Craig Veness','46 Torbay St','Macleod','Victoria','AUSTRALIA','3085','0414554724','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 02:13:07',0,NULL,3,1,11,1,NULL,'au-buy\rWLAT010'),(23367,802446596007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',20.9,'au-buy','gelaene','drgmoreland@hotmail.com','Gillian Moreland','89 Elvys Avenue<br>Yattalunga','NSW','New South Wales','AUSTRALIA','2251','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 02:33:02',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR001'),(23368,802450703007,170762346554,'Genuine DENON RC-970 Remote Control  RC  970',1,'RCDE002',49.9,'au-buy','twerpytwidle','twerpy74@bigpond.com','Mellita Hinchcliffe','36 Kingsgate Drive','Tinbeerwah','Queensland','AUSTRALIA','4563','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 02:47:57',0,NULL,3,1,3,1,'RA184503339CN ','au-buy\rRCDE002'),(23369,636026048004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.89,'cnfaner','mamoud2010mamoud','mamudsuma@yahoo.com','Mamoud kalokoh','200 K St NW<br>Apt 602','Washington','DC','UNITED STATES','20001-5506','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-11 02:54:20',0,NULL,3,1,3,1,'RA184502395CN\r ','cnfaner\rLGAD001'),(23370,858288542011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','zoupzoup','henry.bromfield@gmail.com','Henry Bromfield','Unit 4<br>350 Columbia St West','Waterloo','ON','CANADA','N2L 6E8','2269891369','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 03:06:43',0,NULL,3,1,11,1,NULL,'eastar4\rHSUE002'),(23371,949924234012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','catrue13','catrue@mac.com','Coby True','7268 Jacobs Trail','Navarre','FL','UNITED STATES','32566','(850) 225-7733','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 03:57:55',0,NULL,3,1,1,1,'LK231116494CN\r ','eastar4'),(23372,793951635008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'au-buy','pvb3','philvbrown@gmail.com','phil brown','19 Petrel place<br>Massey','Auckland','','NEW ZEALAND','0614','0064098328666','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-11 04:51:28',0,NULL,3,1,3,1,'RA184503325CN ','au-buy\rLGAD001'),(23373,636046529004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',24.99,'cnfaner','cutter_man','edana.biddle@yahoo.com','Edana M Biddle','5384 Quiet Cove Rd','Anacortes','WA','UNITED STATES','98221-8444','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-11 05:00:58',0,NULL,3,1,1,1,'LK230791688CN\r ','cnfaner'),(23374,949948337012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','tsonter2009','tsonter@hotmail.com','Lazaros Economou','TZAVELLA 1-3<br>HALANDRI','ATHENS','ATTIKA','GREECE','152 31','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 05:30:08',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT009'),(23375,802497440007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','lot2mills','rbowie@britafe.vic.edu.au','robert bowie','14 Skene st.','Kennington','Victoria','AUSTRALIA','3550','0354431419','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 06:28:32',0,NULL,3,1,3,1,'RA184502829CN ','au-buy\rPSGL001*2'),(23376,691468136013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','nordenstamdog','je@fagerborgelektro.no','Jon Erik  Nordenstam','Sjøstrandveien 30A','Vollen','','NORWAY','1391','0047 90863553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 06:33:16',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(23377,802500205007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',2,'RELO002',27.98,'au-buy','gwhlee','geoffrey.wh.lee@gmail.com','Geoffrey Lee','14 Huntingfield Drive','Doncaster East','Victoria','AUSTRALIA','3109','0417696139','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 06:42:51',0,NULL,3,1,11,1,NULL,'au-buy\rRELO002'),(23378,793973417008,180827876552,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB SOUND CARD',1,'OTSB001',22.99,'au-buy','superboygc','hayward84@live.com.au','STEVEN HAYWARD','2/25 Flamingo Key<br>Broadbeach Waters','Gold Coast','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 06:45:07',0,NULL,3,1,11,1,NULL,'au-buy\rOTSB001\r'),(23379,858352153011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','kariffjan','il-93@yandex.ru','Ilnur Garifullin','Koshtoyantsa st., 2, ap.49','Moscow','77','RUSSIAN FEDERATION','119454','(925) 057 - 2230','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 07:26:32',0,NULL,3,1,11,1,NULL,'eastar4\rMOCN001'),(23380,949991956012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','fergusadam','fergusladam@gmail.com','Fergus L Adam','6 Forest Crescent','ashtead','surrey','UNITED KINGDOM','KT21 1JU','07961194336','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 08:23:16',0,NULL,3,1,3,1,'RA184502483CN\r ','eastar4uk\rSAFI001'),(23381,949999552012,220966989378,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',2,'GPS0010+ADPT001',47.98,'eastar4uk','vidaspx','vidas@otenet.gr','ATHENS VOICE Georgia Skamaga','22, Harilaou Trikoupi str.<br>Athens','Greece','','GREECE','106 79','00302103617360','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 08:44:48',0,NULL,3,1,3,1,'RA184502470CN\r ','eastar4uk\rGPS0010+ADPT001'),(23382,0,220969568687,'New in box Iqua bluetooth Smart Badge BHS-608 BHS 608',1,'HSIQ001',17.99,'eastar4uk','delta.r.c','colin.john.oldham@gmail.com','Colin Oldham','27 Frewen Drive','Sapcote','Leicestershire','UNITED KINGDOM','LE9 4LF','07791902899','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 09:15:39',0,NULL,3,1,3,1,'RA184502466CN\r ','eastar4uk\r英标\rHSIQ001'),(23383,691507485013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','bejczil0011','bejczil001@gmail.com','Krisztina Szabo','Petofi Sandor utca 48.','Bejcgyertyanos','Vas megye','HUNGARY','9683','00000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 09:41:19',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019\r欧标'),(23384,794047368008,180777151020,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.05,'au-buy','stevie_wonder_be','vdmaeles@yahoo.com','Van De Maele Steven','Moleneed 12','Serskamp','','BELGIUM','9260','0473950175','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-11 10:33:28',0,NULL,3,1,11,1,NULL,'au-buy\rSCLO002'),(23385,858304307011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',51.98,'eastar4uk','ashtonw84','ashton.welch01@gmail.com','Ashton Welch','Unit 4 / 5 Livingstone St','Yeerongpilly','Queensland','AUSTRALIA','4105','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 10:33:45',0,NULL,3,1,3,1,'RA184502642CN\r ','eastar4uk\rGLOT001'),(23386,0,320861802266,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30,'eastar4uk','ramcitysales','ramcitysales@hotmail.co.uk','Dawn Daffern','54 Carlton Road','Redhill','Surrey','UNITED KINGDOM','RH12BX','07971124383','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 11:36:35',0,NULL,3,1,3,1,'RA184502625CN\r ','eastar4uk\rLGAD001'),(23387,950095956012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',69.9,'eastar4','ljubljana04tadeja','tadeja.04@gmail.com','TADEJA LOVRENČIČ','HERMANA POTOČNIKA 34','LJUBLJANA','','SLOVENIA','1000','00386 41 724 632','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 12:09:49',0,NULL,3,1,3,1,'RA184503308CN ','eastar4\rHBPH001'),(23388,950111815012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',2,'RELO002',15.98,'eastar4uk','billg2103','billgorman49@hotmail.com','William Gorman','Kincraig<br>Banklands','Newburgh','Fife','UNITED KINGDOM','KY14 6DN','01337840040','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 12:36:17',0,NULL,3,1,3,1,'RA184502568CN\r ','eastar4uk\rRELO002'),(23389,691568624013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','apodolsky','angel@alanpoint.ru','Alexey Podolsky','Nasedkina Str, 21-4','Cherepovets','Vologodskaya obl','RUSSIAN FEDERATION','162600','(953) 504-9516','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 12:43:08',0,NULL,3,1,11,1,'BJ01713861 ','eastar4\rCACN004\r'),(23390,691571280013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','papa351','hansvoneicken@arcor.de','Hans-Kurt von Eicken','Spindelweg 6','Ramstein','','GERMANY','66877','06371465098','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 12:52:50',0,NULL,3,1,3,1,'RA184503271CN ','eastar4\rLGAD001'),(23391,630604763003,130620866926,'New Logitech Digital IO Writing Pen',1,'NTLO002',39.99,'cnfaner','2011lucija5','natasa.versec@gmail.com','nataša veršec ljubej','pot na kopitnik 10','rimske toplice','','SLOVENIA','3272','00386031544838','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 12:57:22',0,NULL,3,1,3,1,'RA184502850CN ','cnfaner\rNTLO002'),(23392,810886231001,110826639527,'New Bracket of MINI HALF WLAN/WIFI/WIRELESS CARD to PCI-E',1,'MOCN001',3.98,'buysia','thinkingman22','extrakala@yahoo.com','Kaloyan Belchev','ul. Pirotska 171A','Sofia','Sofia grad','BULGARIA','1309','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-11 13:00:06',0,NULL,3,1,11,1,NULL,'buysia\rMOCN001'),(23393,858502441011,320557739300,'2.1 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2104',12.39,'eastar4','sync_master_2006','alpkiraz@hotmail.com','alp kiraz','Merkez Efendi Mah. 3905 Sok. Menekse Apt. B-Blok No:4 Kat:4 Daire : 7 MANİSA','MANİSA','MANİSA','TURKEY','45000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 13:20:01',0,NULL,3,1,11,1,'BJ01713859 ','eastar4\rBTAC2104\racer 4pin1.25 6cm '),(23394,691585906013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',2,'HSNO022',29.96,'eastar4','gamesisme','alohawoody78@yahoo.com','WOODROW EPP','PO Box 613<br>405 Main St.','WAITSBURG','WA','UNITED STATES','99361-0613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 13:30:23',0,NULL,3,1,1,1,'LK231062495CN\r ','eastar4'),(23395,810902926001,110837937730,'Auto On Gentelman Cat Rain/Sun J-handle Umbrella w/14 Skeleton',1,'UM00050',24.99,'buysia','polyanya2012','polyanya@mail.ru','Polina Kolchanova','Universitetsky prospekt 5,apt 509','Moscow','Moscow','RUSSIAN FEDERATION','119296','(964)593-3384','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-11 13:34:36',0,NULL,3,1,11,1,'BJ01713561\r ','buysia\rUM00050\r白色\r未发货\r'),(23396,950145388012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',12.49,'eastar4uk','linwood195','woody195@hotmail.co.uk','Jack Brett','42 East Way','Lewes','East Sussex','UNITED KINGDOM','BN7 1NG','01273476998','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 13:37:45',0,NULL,3,1,3,1,'RA184502608CN\r ','eastar4uk\rOTHP003'),(23397,636183765004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','macinpc','riderz@mac.com','John Chan','Blk 509 Bedok North Street 3<br>#04-103','Singapore','Singapore','SINGAPORE','460509','65-96283626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 13:58:25',0,NULL,3,1,3,1,'RA184503299CN ','cnfaner\rCACN004'),(23398,691597712013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','neglerefekete','heyyoad@gmail.com','Yoad Fekete','Harimon 37 St.','Ramat Hasharon','','ISRAEL','47251','(972) 528-5975 ext.: 63','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 14:00:13',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(23399,810925617001,110831128283,'New Grohe Multi Function hand Shower Head Made in Germany 7 pattens',1,'OTGR001',19.9,'buysia','bayarvis2009','arvisbay@inbox.lv','Arvis Apsitis','Anitas street 1-6','Riga','','LATVIA','LV-1015','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-11 14:13:35',0,NULL,3,1,11,1,NULL,'buysia\rOTGR001'),(23400,950212827012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',275.99,'eastar4','centraid','victopatri@videotron.ca','Martin D\'Anjou','1009 Principale','St-Agapit de Lotb','QC','CANADA','G0S1Z0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 15:25:06',0,NULL,3,1,3,1,'RA184502713CN\r ','eastar4\rPSGL001*4'),(23401,858593323011,320721446540,'New Map Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00007',24.99,'eastar4','spineddmitriy','spine.shop20perm@gmail.com','Дмитрий Щербаков','Karpinskogo 77-285','Perm','Permskiy krai','RUSSIAN FEDERATION','614022','+79519345996','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 15:53:49',0,NULL,3,1,11,1,NULL,'eastar4\rUM00007'),(23402,858587340011,320546685165,'New bulk GENUINE NOKIA BH-800 BLUETOOTH HEADSET BH 800',1,'HSNO017',19.68,'eastar4','khodarov','hodarov@mail.ru','Konstantin Aleynikov','40 let pobedy 4-208','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454100','+79514660924','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 16:02:22',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO017\r欧标\r黑色的'),(23403,858619677011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','ruthybabes2011','ruth.mcgready@dsl.pipex.com','Ruth McGready','R.B. Steele<br>44 Byres Road','Kilwinning','North Ayrshire','UNITED KINGDOM','KA13 6JU','07515653064','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 16:28:37',0,NULL,3,1,3,1,'RA184502599CN\r ','eastar4uk\rRELO003'),(23404,802769996007,170783809542,'UNLOCKED Sierra Wireless MC8780 Air Card 7.2Mbps 3G HSUPA/HSDPA/UMTS Mini PCI-E',1,'WWSI004',36.99,'au-buy','bawi4','1009@gmx.at','kristina held f. gessmann','am buchzagl 3','kiefersfelden','','GERMANY','83088','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-11 16:37:46',0,NULL,3,1,11,1,NULL,'au-buy\rWWSI004'),(23405,950285062012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','elviskra1975','elviskra75@gmail.com','SLAWOMIR KRAINSKI','105<br>WINSLOW ROAD','BROMYARD','Herefordshire','UNITED KINGDOM','HR7 4UG','05603280254','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 16:53:16',0,NULL,3,1,3,1,'RA184502700CN\r ','eastar4uk\rSAFI001'),(23406,636274936004,140626375805,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',6.3,'cnfaner','thogaar','thalesst@gmail.com','Thales Torquato','R: Sá Ferreira nº 184 apto:303<br>copacabana','Rio de Janeiro','RJ','BRAZIL','22071-100','(55)(21) 3435-9932','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:13:21',0,NULL,3,1,3,1,'RA184503285CN ','cnfaner\rMOFP001'),(23407,691705638013,230717843839,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',19.99,'eastar4','mixalok','m.reinberg@yandex.ru','MIKHAIL REYNBERG','100, Sotsialisticheskaya street, apt 15','Michurinskiy rayon, selo Zavoronezhskoe','','RUSSIAN FEDERATION','393749','9156710647','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:34:22',0,NULL,3,1,11,1,' ','eastar4\rUM00041'),(23408,858673165011,320820765935,'New Nokia Easy-to-use Bluetooth Headset BH-301 w/Fashion Conscious 5 colors',1,'HSNO036',19.99,'eastar4uk','mohsin_798798','mohsin_798@hotmail.co.uk','MOHSIN ABDULLAH','75 DIXON AVENUE','GLASGOW','Glasgow (City of)','UNITED KINGDOM','G428EW','07973330697','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 17:37:23',0,NULL,3,1,3,1,'RA184502758CN\r ','eastar4uk\rHSNO036'),(23409,950337513012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',125.99,'eastar4uk','forsyth19gail','gailwhyte12@btinternet.com','Gail Whyte','19 Muirfield Road','Dundee','Dundee (City of)','UNITED KINGDOM','DD3 8NW','01382810028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 17:45:41',0,NULL,5,0,18,0,NULL,'eastar4uk\rOTSO004*4\r客户同意 先撤单 退款  然后再买  用165.99GBP'),(23410,691718098013,230429731636,'2.0 Bluetooth Module cable DELL mini 10 10v 1010 1011',1,'BTDE2002',9.88,'eastar4','cardenr','ric.carden@gmail.com','Richard Carden','16 Greenfield Crescent','Brighton','West Sussex','UNITED KINGDOM','BN1 8HJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:52:27',0,NULL,3,1,11,1,NULL,'eastar4\rBTDE2002'),(23411,950375786012,220901458029,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',30.99,'eastar4uk','nir9','nrapellas@yahoo.gr','NIKOLAOS RAPELLAS','26 VERIAS STR','ILION','ATHENS','GREECE','13122','+306972524444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 18:18:53',0,NULL,3,1,3,1,'RA184502660CN\r ','eastar4uk\rLGFI001'),(23412,691714881013,230488711602,'New Atheros AR9281 802.11N Wireless WiFi over AR5008',1,'WLAT010',8.99,'eastar4','kartechev_alex','kartechev_alex@mail.ru','Aleksandr Kartechev','Mashinostroitelnaya 82 63','Mariupol','Donetsk','UKRAINE','87551','0678585610','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:54:51',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT010'),(23413,691744034013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',2,'GLOT001*4',379.97,'eastar4','papakitty514','mario.venne@sympatico.ca','Mario Venne','88 Gibeault','Montreal','QC','CANADA','H1A4H2','(514) 642-3417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 18:31:23',0,NULL,3,1,6,1,'EE651291555CN ','eastar4\rGLOT001*4'),(23414,691749801013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','digitalljaekore','jamil.alioui@alambicbicephale.com','Jamil Alioui','23, Avenue de Cour','Lausanne','Other','SWITZERLAND','1007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 18:32:02',0,NULL,3,1,3,1,'RA184503342CN ','eastar4\rGPS0006'),(23415,858746900011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','10tonvelo','pabbay10@googlemail.com','Robert Miller','235 Glasgow Road<br>Flat 1/L','Glasgow','South Lanarkshire','UNITED KINGDOM','G72 0YS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 18:40:07',0,NULL,3,1,3,1,'RA184502673CN\r ','eastar4uk\rRELO003'),(23416,691769395013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',2,'CASS003',21.98,'eastar4','gg10736','ge.gaffney@gmail.com','Gerard Gaffney','56 Mulcaire Manor','Newport','Tipperary','IRELAND','default','0862220337','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 18:56:00',0,NULL,3,1,11,1,NULL,'eastar4\rCASS003\rCAB-6060'),(23417,630823820003,130490219804,'New US Logitech Harmony AC Power Adapter 720 880 890',1,'POLO001',6.89,'cnfaner','t.rex2000','marco@themicocci.com','Marco Micocci','83 Nottingham Pl','Boynton Beach','FL','UNITED STATES','33426-8428','(954) 931-7480','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-11 19:37:18',0,NULL,3,1,1,1,'LK230798377CN\r ','cnfaner'),(23418,855883361002,120869126117,'Apple Steve Jobs 8GB USB Flash Drive',2,'UDAP004',80.47,'buysia','hskalic','h.skalic@gmx.net','Hasan Skalic','Landstr.69','Hard','','AUSTRIA','6971','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-11 19:49:16',0,NULL,3,1,3,1,'RA184502996CN ','buysia\rUDAP004\rNew Apple Macbook Air Software Reinstall Driver\r1个\rUDAP002\r一共3个'),(23419,948731315012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',38,'eastar4uk','falcont637','falcont@falcont.karoo.co.uk','Thomas Feetham','37 Burden Road','Beverley','Humberside','UNITED KINGDOM','Hu17 9LA','01482864099','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 20:03:12',0,NULL,3,1,3,1,'RA184502571CN\r ','eastar4uk\rMOLO001'),(23420,858856692011,320820765666,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',15.99,'eastar4uk','sergii_golub','sg7@ukr.net','Sergii Golub','Prospekt Chervonozoryanuy, building 126 G, flat 49','Kiev','','UKRAINE','03118','380634419033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 20:13:06',0,NULL,3,1,3,1,'RA184502024CN\r ','eastar4uk\rTRSN001+OTSO004*4\r再发4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl\r分两票发 客户要求    客户打了35英镑 '),(23421,950521531012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',125.99,'eastar4uk','sergii_golub','sg7@ukr.net','Sergii Golub','Prospekt Chervonozoryanuy, building 126 G, flat 49','Kiev','','UKRAINE','03118','380634419033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 20:17:40',0,NULL,3,1,17,0,'RA184502072CN\r\r ','eastar4uk'),(23422,950555431012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Ruth O\'Brien','3433 Heards Ferry Dr','Tampa','FL','UNITED STATES','33618-2920','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 20:52:49',0,NULL,3,1,1,1,'LK231050585CN\r ','eastar4'),(23423,950559296012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','ANDREW WEIBEL','1225 GREEN BAY ST','SAN DIEGO','CA','UNITED STATES','92154-2926','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 20:57:02',0,NULL,3,1,1,1,NULL,'eastar4'),(23424,950562932012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Tony Plaut','808 Summit Ave SW','Mount Vernon','IA','UNITED STATES','52314-1045','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 21:01:07',0,NULL,3,1,1,1,'LK231071634CN\r ','eastar4'),(23425,950566462012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Brian Hogencamp','502A LIBERTY ST','SAN FRANCISCO','CA','UNITED STATES','94114-2829','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 21:26:42',0,NULL,3,1,1,1,'LK231068927CN\r ','eastar4'),(23426,950588191012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Richard Hollingsworth','716 Blackmoor Gate Ln','Saint Augustine','FL','UNITED STATES','32084-1879','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 21:28:54',0,NULL,3,1,1,1,'LK231089330CN\r ','eastar4'),(23427,950589982012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',125.99,'eastar4uk','mike.brookes','mikebrookes@sky.com','Donna Brookes','15 Bengairn Close','Wigan','Lancashire','UNITED KINGDOM','WN13YW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 21:31:05',0,NULL,3,1,4,1,'YW870147205CN\r ','eastar4uk\rOTSO004*4\r客户补了20英镑  '),(23428,950589901012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Eric','585 FERN DR','ALTUS','OK','UNITED STATES','73521-7416','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 21:31:35',0,NULL,3,1,1,1,'LK231081424CN\r ','eastar4'),(23429,800046773007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',20.9,'au-buy','wogget86','piantasam@bigpond.com','sam pianta','1364 lackrana road','lackrana','Tasmania','AUSTRALIA','7255','0427882426','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-11 22:07:24',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR001'),(23430,950629350012,220749207932,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',69.9,'eastar4uk','dep07180','roland.proksa@gmx.de','Roland Proksa','Rübker Bruch 5','Neu Wulmstorf','','GERMANY','21629','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 22:27:40',0,NULL,3,1,3,1,'RA184502585CN\r ','eastar4uk\rRCMA001'),(23431,950642300012,220455488862,'HP Pavilion DV5 HDX X16 Bluetooth Module 2.0 EDR+cable',1,'BTHP2013',9.88,'eastar4','doka2233','zdravko.dokuzovic@sb.t-com.hr','Zdravko Dokuzovic','Aleja Miroslava Krleze 65.','Slavonski Brod','','CROATIA','35000','+38535255220','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:50:35',0,NULL,3,1,11,1,NULL,'eastar4\rBTHP2013\rHP 6pin 1.0 12cm '),(23432,950648597012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','wkohler888','wkohler88@comcast.net','William Kohler','3 Homer Ln','Menlo Park','CA','UNITED STATES','94025-6319','(650) 854-8537','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 23:01:41',0,NULL,3,1,1,1,'LK231075636CN\r ','eastar4'),(23433,691918154013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','mattyqld-2007','m.watts@uq.edu.au','Matthew Watts','1/52 Bellevue Tce','St Lucia','Queensland','AUSTRALIA','4067','0733653539','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 23:09:23',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004\r新地址\rMatthew Watts\r26/38 Lissner St\rToowong QLD 4066\rAustralia.\r'),(23434,858980959011,320844153563,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',86.99,'eastar4uk','dj5699','bucovina70@msn.com','puiu stroe','2427 leisure lake dr','dunwoody','GA','UNITED STATES','30338-5318','(770) 652-5607','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 23:15:57',0,NULL,3,1,1,1,'LK231189806CN\r ','eastar4uk'),(23435,950655320012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',2,'MOLO001',76,'eastar4uk','iquacker','ifaberman@comcast.net','Ira Faberman','Iftron Technologies, Inc.<br>1813 Sunset Place Unit A','Longmont','CO','UNITED STATES','80501','(303) 378-8726','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 23:16:13',0,NULL,3,1,1,1,'LK231125173CN\r ','eastar4uk'),(23436,800939346007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',49.39,'au-buy','tanya9060','tanya33375@hotmail.com','Tanya Jacobsen','no. 15 , Mayfair Street<br>Currumbin Waters','Gold Coast','Queensland','AUSTRALIA','4223','0755350368','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'au-buy'),(23437,8881331514602458,111,'Free shipping & Tracking # - New Microsoft Wired Optical Wheel Mouse Black - ',1,'MOMI004',12.59,'aliexpress','1007285621','grizzly-moroz@rambler.ru','Maroz Siarhei','	pr-t Rokossovskogo dom 132, kv. 192 ','Minsk','Belarus','BELARUS ','220101','+375 33 3238610',NULL,NULL,NULL,'2012-03-12 01:10:02',0,NULL,3,1,3,1,'RA184502951CN','已入库  客户要的白色的 MOMI002  地址已和客户核实 是belarus\r'),(23438,950712277012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',8.99,'eastar4uk','paul3z5y','paul@xciv.org','Paul Civati','36 Sunnymede Avenue','Carshalton','Surrey','UNITED KINGDOM','SM5 4JF','2086429768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 01:22:21',0,NULL,3,1,3,1,'RA184502687CN\r ','eastar4uk\rWLHP002'),(23439,8881331515971747,111,'Free shipping & Tracking # - New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 - ',2,'GPS0010',59.38,'aliexpress','1007289894','rotex1@wp.pl','Piter Rotenstein','ul.Centralna 15a ','Police','Przesocin','POLAND','72-010','501383041',NULL,NULL,NULL,'2012-03-12 01:32:51',0,NULL,3,1,3,1,'RA184502979CN ','GPS0010   申报为gift 小于25$'),(23440,8881331516452139,111,'New Atheros AR5B95 AR9285 802.11B/G/N Half Mini PCI-E Card + A pair of Tyco 2.4/5.0GHz Antenna - ',1,'WLAT009+ ANTY001',11.99,'aliexpress','1007297881','s-devine@utvinternet.com','Seamus Devine','	Ashgrove, Ballintlea South, ','Cratloe','Co CLARE','IRELAND','','+353 87 2262033',NULL,NULL,NULL,'2012-03-12 01:40:52',0,NULL,3,1,3,1,'RA184502948CN ','已入库 WLAT009+ ANTY001 '),(23441,950727103012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','nettyatlantis1','annette.oertle@my.jcu.edu.au','Annette Oertle','151 Russell<br>Street','Edge Hill','Queensland','AUSTRALIA','4870','6107320085','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 01:52:28',0,NULL,3,1,11,1,NULL,'eastar4\rUM00008'),(23442,8881331517317881,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',1,'UM00008',24.99,'aliexpress','1007330899','bridekom@mail.ru','Zinaida Kalabina','Lenina d10 kv56 ','Tuapse','Krasnodar edge','RUSSIAN FEDERATION','352800','+7 928 4528571',NULL,NULL,NULL,'2012-03-12 01:55:17',0,NULL,3,1,3,1,'RA184503458CN\r ','UM00008 '),(23443,950728190012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','royalblue7','bluevoodoo@insightbb.com','J.E Henderson','7209 Boxwood Rd','Louisville','KY','UNITED STATES','40222-4101','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 01:59:31',0,NULL,3,1,1,1,'LK231052856CN\r ','eastar4'),(23444,691994042013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','smer7637','salmerchant786@aol.com','SALIM MERCHANT','307 ZANDERSON AVE','JOURDANTON','TX','UNITED STATES','78026','(210) 872-9645','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 02:59:26',0,NULL,3,1,1,1,'LK231046952CN\r ','eastar4'),(23445,803194273007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','tnzz','thuyen@graduate.uwa.edu.au','Thuyen Nguyen','26 Kilarney Heights','Kallaroo','Western Australia','AUSTRALIA','6025','0422481386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 03:14:05',0,NULL,3,1,3,1,'RA184502523CN\r ','au-buy\rPSGL001*2'),(23446,8881331525976408,111,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',2,'HSAL001',48,'cnfaner','socalrealtypros','steveandpeggy4evr@gmail.com','Steve Rogers','15835 Sagewood Ct','Riverside','CA','UNITED STATES','92504','',NULL,NULL,NULL,'2012-03-12 04:19:36',0,NULL,3,1,3,1,'RA184502378CN\r ',' cnfaner\rHSAL001\r美标\r'),(23447,692017534013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','alexgornatti','alexgorna@gmail.com','Carlos Alexandre P Gornatti','Av. Francisco Petuco, 340 apto 207<br>Bairro Boa Vista','Porto Alegre','RS','BRAZIL','90520620','(+55)51 81802590','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 04:58:26',0,NULL,3,1,3,1,'RA184502421CN\r ','eastar4\rLGAD001'),(23448,692018998013,230641224575,'Transparent Dome Rain Sun Umbrella with blue trim',1,'UM00001',19.99,'eastar4','kelvinpui','kelvinpui@gmail.com','Ginny Leng','39 Jalan BU1/1A Bandar Utama','Petaling Jaya','Selangor','MALAYSIA','47800','0169775657','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 05:00:55',0,NULL,3,1,11,1,NULL,'eastar4\rUM00001\r粉红色的'),(23449,950803303012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Mark Wellner','82 CARPENTER ST','RED BANK','NJ','UNITED STATES','07701-5551','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 05:32:15',0,NULL,3,1,1,1,'LK231705915CN\r ','eastar4'),(23450,794689568008,180781265262,'New Grohe Multi Function hand Shower Head made in Germany+ 59\" Grohe hose',1,'OTGR001+OTGR002',40.9,'au-buy','daveyboygreen06','daveyboywho@hotmail.com','David M Hooper','28/135 Macquarie St<br>Teneriffe','Brisbane','Queensland','AUSTRALIA','4005','0415939104','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 05:50:31',0,NULL,3,1,3,1,'RA184502510CN\r ','au-buy\rOTGR001+OTGR002'),(23451,692036089013,230719934713,'3 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*3',286.99,'eastar4','jas123_to','jasonmarkos@hotmail.com','jason markos','2 lombard st','fairfield west','New South Wales','AUSTRALIA','2165','0292789277','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 06:59:44',0,NULL,3,1,3,1,'RA184502554CN\r ','eastar4\rGLSG009*3\r14号客户给的正确的地址\r191 welling drive mount Annan new south wales Australia 2567 '),(23452,692049360013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','garoad','wonnyum@gmail.com','Won-Young Sohn','11F, Doung-Gung BLDG, 736-17, Yeoksam-dong<br>Gangnam-gu','Seoul','','KOREA,REPUBLIC OF','135-080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 08:27:20',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP008'),(23453,8881331541341488,111,'CAB6060',70,'CASS003',790,'eastar4','newdimension2011','netco2011@hotmail.co.uk','New Dimension','8 Coniston GardensIlford','Essex','','UNITED KINGDOM','IG45LU','',NULL,NULL,NULL,'2012-03-12 08:35:41',0,NULL,3,1,12,1,'3126024101 ','CASS001+CASS003\r再发50条 CAB 2626  \rdeclare 30USD\r实重16.1   泡重8.2'),(23454,803264144007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.38,'au-buy','detinman','nathanhead1@bigpond.com','Nathan Head','7 Toni Court','Morayfield','Queensland','AUSTRALIA','4506','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 08:40:13',0,NULL,3,1,11,1,NULL,'au-buy\rRELO003'),(23455,950849620012,220806892088,'NEW Sunflower Bloom 3-section Folding umbrella',1,'UM00004',21.99,'eastar4','mrozkiewicz','mrozkiewicz@hotmail.com','Marta Mrozkiewicz','12 Warwick Crt<br>Bellbird Park','Ipswich','Queensland','AUSTRALIA','4300','0413854580','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 08:54:54',0,NULL,3,1,11,1,NULL,'eastar4\rUM00004'),(23456,950849693012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',87.99,'eastar4','zimitri10','zimitrius@gmail.com','Vitali Katsalaptsenko','veeru 18 - 85','Maardu','Harjumaa','ESTONIA','74113','+37256653412','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 08:56:21',0,NULL,3,1,3,1,'RA184502435CN\r ','eastar4\rGLOT005*2'),(23457,692058942013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ckeyfli2012','ckeyfli@yahoo.com','Coşkun KEYFLİ','ISDEMIR A.S. Surekli Dokumler Mudurlugu Payas','Iskenderun','HATAY','TURKEY','31219',' 05335524469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 09:28:28',0,NULL,3,1,11,1,'BJ01713623\r ','eastar4\rCACN004'),(23458,794740637008,180777151020,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',5.05,'au-buy','paulw410','paulr410@msn.com','Paul Roser','23 Milson St','Charlestown','New South Wales','AUSTRALIA','2290','0249432151','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 09:45:10',0,NULL,3,1,11,1,'BJ01713867\r ','au-buy\rSCLO002'),(23459,794744530008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.39,'au-buy','doofbrad','brad_hodgkinson@hotmail.com','Brad Hodgkinson','7 Raphael street','Coombabah','Queensland','AUSTRALIA','4216','0422302191','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 09:59:09',0,NULL,3,1,11,1,'BJ01713869\r ','au-buy\rBALO001'),(23460,8881331546569197,111,'New Blade Runner Saber LED Flash Light Umbrella Safety',1,'UM00031',0,'eastar4uk','kitten2077','becca_pritchard@hotmail.com','Rebecca Pritchard','The Mecca, 72 Market Hall<br>Tenants Street','Derby','Derbyshire','UNITED KINGDOM','DE1 2DB','07933989973',NULL,NULL,NULL,'2012-03-12 10:02:49',0,NULL,3,1,3,1,'RA184502293CN\r ','UM00031\r补货\r红色的 \r'),(23461,950870617012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','lloydyboy2003','plloyd@diagnosticsolutions.co.uk','Peter Lloyd','60 Ancaster Road','Liverpool','Merseyside','UNITED KINGDOM','L17 9QF','07768517206','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 10:05:45',0,NULL,3,1,3,1,'RA184502333CN\r ','eastar4uk\rHSJA002\r英标'),(23462,950873697012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',2,'HSJA002',27.2,'eastar4uk','darlayabbey','aftab_ahmed@onetel.com','Aftab Ahmed','1 Haydock Close<br>Branston','Burton upon Trent','Staffordshire','UNITED KINGDOM','DE14 3GW','07973900034','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 10:13:50',0,NULL,3,1,3,1,'RA184502231CN\r ','eastar4uk\rHSJA002\r英标\r一共买了三个'),(23463,636625124004,140671480653,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',24.99,'cnfaner','pokoreev','big-matrix@yandex.ru','Alexandr Pokoreev','Frunze str. 16 home','Mariupol','Donetskiy region','UKRAINE','87506','80629413775','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 10:14:53',0,NULL,3,1,3,1,'RA184502245CN\r ','cnfaner\rHSAL001\r欧标'),(23464,950877480012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',209.99,'eastar4','telehd','seolime@ya.ru','Uriy Vladimirovich Brizhan','Chertanovskaya 30-3-77','Moscow','','RUSSIAN FEDERATION','117525','(495) 502 - 6203','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 10:26:26',0,NULL,3,1,3,1,'RA184502228CN\r ','eastar4\rPSGL001*3'),(23465,950873096012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','darlayabbey','aftab_ahmed@onetel.com','Aftab Ahmed','1 Haydock Close<br>Branston','Burton upon Trent','Staffordshire','UNITED KINGDOM','DE14 3GW','07973900034','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 10:12:28',0,NULL,3,1,17,0,'RA184502231CN\r ','eastar4uk'),(23466,692079064013,230724607810,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'eastar4','blondie_baguette','kerstin_boutique@rocketmail.com','Kerstin Vintila','PO Box 6158','UNSW SYDNEY','New South Wales','AUSTRALIA','1466','0295934527','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 11:01:19',0,NULL,3,1,11,1,'BJ01713620\r ','eastar4\rUM00053'),(23467,950892755012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',7.99,'eastar4uk','trsidious','sidious@talktalk.net','colin tomys','6<br>store terrace','easington lane','Tyne and Wear','UNITED KINGDOM','dh5 0jz','01915268120','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 11:11:52',0,NULL,3,1,3,1,'RA184502188CN\r ','eastar4uk\rRELO002'),(23468,692078755013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','gangefors','gangefors@gmail.com','Stefan Gangefors','Örnvägen 74 lgh 1001','LUND','','SWEDEN','22731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 10:59:13',0,NULL,3,1,11,1,'BJ01713625\r ','eastar4\rCACN004'),(23469,859212273011,320801186995,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',13.25,'eastar4uk','tonnikala','juurela@gmail.com','Antti Juurela','ILMARISENKATU 13A1','MIKKELI','','FINLAND','50130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 11:56:34',0,NULL,3,1,11,1,'BJ01713618\r ','eastar4uk\rUM00040'),(23470,692093581013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',2,'CACN004',25.88,'eastar4','jorje222','jorje2@gmail.com','Georgiy Kalishkin','Rijskaya 18, 122','Kiev','UA','UKRAINE','04060','(38068) 125 - 2308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 12:06:28',0,NULL,3,1,11,1,'BJ01713626\r ','eastar4\rCACN004'),(23471,636652955004,140635369210,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',67.99,'cnfaner','ryokogawa','ricardo.yokogawa@gmail.com','Ricardo Yukio Yokogawa','Rua Conselheiro Elias de Carvalho, number 849<br>Bairro Vila santa catarina','São Paulo','São Paulo','BRAZIL','04373-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 12:14:40',0,NULL,3,1,3,1,'RA184502316CN\r ','cnfaner\rOTSO004'),(23472,794791448008,180793383706,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'au-buy','harrmankardon','john_bof@hotmail.com','John Bof','16 Merchant ave, Thomastown','melbourne','Victoria','AUSTRALIA','3074','0394665019','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 12:33:10',0,NULL,3,1,11,1,'BJ01713631\r ','au-buy\rOT00002'),(23473,950946163012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.25,'eastar4uk','mysteryofyou','loving_positive@mail.ru','ELENA AKHMADEEVA','Afanasieva street 11-96','USSURIYSK','PRIMORSKY KRAI','RUSSIAN FEDERATION','692511','(950) 295 - 5993','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:35:13',0,NULL,3,1,11,1,'BJ01713871\r ','eastar4uk\rUM00043'),(23474,859246233011,320812367704,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',53.99,'eastar4uk','srghgukl','ooogusarov@rambler.ru','valerij gusarov','line 24 street ,house 46','Ivanovo','Ivanovo Region','RUSSIAN FEDERATION','153031','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:37:05',0,NULL,3,1,3,1,'RA184502280CN\r ','eastar4uk\rGPS0011+GPS0005\r再发一个Original Lowrance iFinder PhD GPS+WAAS handheld GPS Receiver'),(23475,859250988011,320773536297,'Original Lowrance iFinder PhD GPS+WAAS handheld GPS Receiver',1,'GPS0005',53.99,'eastar4uk','srghgukl','ooogusarov@rambler.ru','valerij gusarov','line 24 street ,house 46','Ivanovo','Ivanovo Region','RUSSIAN FEDERATION','153031','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:51:05',0,NULL,3,1,17,0,'RA184502280CN\r ','eastar4uk'),(23476,631111665003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','robbst','robbstsh@yahoo.com.br','roberto santos','av prefeito dulcidio cardoso 1700 apt 203<br>barra da tijuca','rio de janeiro','rio de janeiro','BRAZIL','22630-020','552181480862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 13:52:08',0,NULL,3,1,3,1,'RA184502347CN\r ','cnfaner\rMOAP001'),(23477,631095607003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','miffau','mslaby@epsi.pl','Michal Rudnicki','Pza. de las Cortes 2<br>Planta 4a','Madrid','Madrid','SPAIN','28014','684058748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:37:51',0,NULL,3,1,3,1,'RA184502174CN\r\r ','cnfaner\rRELO002'),(23478,859282520011,320704213287,'NEW LOGITECH NANO USB RECEIVER4 performance M705 mouse',1,'RELO003',7.5,'eastar4uk','zengazenga','nelson.boavida@live.com.pt','Nelson Boavida','Rua Luis Camoes, 317<br>Bairro Conde Monte Real','Tires','Sao Domingos de Rana','PORTUGAL','2785-147','00351917654321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 15:06:27',0,NULL,3,1,11,1,'BJ01713864\r ','eastar4uk\rRELO003'),(23479,811632742001,110836854678,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern',1,'UM00033',19.99,'buysia','lisagadwoodxoxo33','lisagadwood@yahoo.com','Lisa Gadwood','14867 Maywood St','Southgate','MI','UNITED STATES','48195','(734) 255-5455','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-12 15:17:23',0,NULL,3,1,1,1,'LK231680900CN\r ','buysia\rcolor dot'),(23480,811691299001,110807072440,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'buysia','zhor-glub','maologik@yahoo.ca','Otis marc-andre','120 Radisson app 9','Sept-iles','QC','CANADA','G4R 4M1','','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-12 17:30:48',0,NULL,3,1,11,1,'BJ01713866\r ','buysia\rOT00002'),(23481,631186226003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',6,'HSJA001',142.8,'cnfaner','j.schex','j.schex@yahoo.com','Joshua Schexnayder','2556 Kismet St','Marrero','LA','UNITED STATES','70072-5453','(504) 452-9433','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-12 18:00:17',0,NULL,3,1,1,1,'LK231709183CN\r ','cnfaner'),(23482,951104339012,220561315006,'100% NEW 3FT Back to Back DCE/DTE DB60 Crossover Cable',3,'CASS003',32.97,'eastar4','popye95','mushtaq95@gmail.com','Mushtaq Ahmad','4/47, Macquarie Rd,','Auburn','New South Wales','AUSTRALIA','2144','0423729578','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 18:47:45',0,NULL,3,1,11,1,'BJ01713624\r ','eastar4\rCASS003'),(23483,859480273011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','anniecrunders','ann.mills73@virginmedia.com','Ann Mills','13 Northway<br>Penenden Heath','Maidstone','Kent','UNITED KINGDOM','ME14 2ET','01622356843','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 20:54:46',0,NULL,3,1,3,1,'RA184502355CN\r ','eastar4uk\rSAFI001*2'),(23484,692073897013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',44.99,'eastar4','schnorr','maicon.schnorr@hotmail.com','Maicon Schnorr','Rua das Hortensias<br>241','Arroio do Meio','Rio Grande do Sul','BRAZIL','95940-000','99081446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 20:58:08',0,NULL,3,1,3,1,'RA184502214CN\r ','eastar4\rGLOT005'),(23485,803586051007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',2,'OTGR001',39.72,'au-buy','darrylw69','darrylw69@aol.com','Darryl Hanscom','3132 Capitol Ave','Warren','MI','UNITED STATES','48091-1935','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 20:58:41',0,NULL,3,1,1,1,'LK231695918CN\r ','au-buy'),(23486,951206443012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','euro-modedistribution.inc','euromode@me.com','stephane dahan','2256 avenue hampton','montreal','QC','CANADA','h4a2k6','(514) 655-2632','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 21:02:33',0,NULL,3,1,11,1,'BJ01713870\r ','eastar4\rOTGR001+OTGR002'),(23487,859491344011,320814097984,'Double-Reinforced India Flower Transparent Dome Birdcage Stick Umbrella',1,'UM00051',15.15,'eastar4uk','peeraer_a','an_peeraer@live.be','an peeraer','looiweg 42','rijkevorsel','','BELGIUM','2310','+3233147714','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 21:11:12',0,NULL,3,1,11,1,'BJ01715290\r ','eastar4uk\rUM00051\r高贵紫罗兰'),(23488,859498084011,320828187318,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',2,'PSGL001',87.98,'eastar4uk','chriis75','chriis75@gmail.com','Christophe Perrusson','26 avenue marcelin berthelot<br>appartement 256 -5e étage','Chatillon','Ile-de-France','FRANCE','92320','+33609685033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 21:22:24',0,NULL,3,1,3,1,'RA184502320CN\r ','eastar4uk\rPSGL001'),(23489,859513359011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',99.99,'eastar4uk','mintflip','mintflip2003@yahoo.com','Andrew Gourlay','49 Henderson Street','Thurso','Highland','UNITED KINGDOM','KW14 7LD','01847890387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 21:50:08',0,NULL,3,1,3,1,'RA184502276CN\r ','eastar4uk\rGLOT001*4'),(23490,859522044011,320441567812,'2.1 Acer Aspire 5735 5735Z 5738Z Bluetooth Module+cable',1,'BTAC2105',12.39,'eastar4','ikidalcastelmissio','ikimissio@uol.com.br','Luiz Missio','SGAN 914 ASA NORTE CONJUNTO H EDIFICIO MONTE CARLO BLOCO C AP 36<br>ASA NORTE AO LADO DO LEONARDO DA VINCI','BRASÍLIA','Distrito Federal','BRAZIL','70790-140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 22:05:17',0,NULL,3,1,11,1,'BJ01713862 ','eastar4\rBTAC2105\racer 4pin1.25 8cm '),(23491,803624207007,170801967475,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',43.99,'usa-view','cfcardona09','morritochulo@hotmail.com','Carlos Francisco Cardona Arenas','1510 Sadlon Ave','Clearwater','FL','UNITED STATES','33756-2154','(727) 712-6122','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-12 22:07:40',0,NULL,5,1,1,1,'LK231692633CN\r ','usa-view\r已发货\r'),(23492,631297576003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','11alec12','plp@pelletierelectrique.ca','PIERRE-LUC PELLETIER','57<br>PLACE CARRIER','RIVIERE-DU-LOUP','QC','CANADA','G5R 5P3','(418) 863-6808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 22:33:38',0,NULL,3,1,3,1,'RA184502302CN\r ','cnfaner\rCRLO001+POLO001'),(23493,692329438013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','london1100','p1nk_bl0ndi3@hotmail.com','Dorota Smolarz','809 Saddle Cres.','Mississauga','ON','CANADA','L4Y 2V9','(416) 616-5704','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 22:53:36',0,NULL,3,1,11,1,'BJ01713621\r ','eastar4\rUM00033'),(23494,951277145012,220448678780,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',9.88,'eastar4','kepabilbo','pedrosusi@hotmail.com','PEDRO AMELIBIA SARRALDE','C/  TRASTAMARA  Nº  8   PISO  1º  IZQUIERDA','CALAHORRA','La Rioja','SPAIN','26500','661384224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 23:11:34',0,NULL,3,1,11,1,'BJ01713865\r ','eastar4\rBTAC2012\racer 5pin1.25 6cm  '),(23495,951280887012,220763388953,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',16.99,'eastar4uk','matty8384','madmonkey27@gmail.com','Mathew Parsons','30 SHIREGATE<br>METHERINGHAM','LINCOLN','Lincolnshire','UNITED KINGDOM','LN4 3DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 23:20:12',0,NULL,3,1,3,1,'RA184502165CN\r ','eastar4uk\rWLAP008'),(23496,795119309008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',40.99,'au-buy','mazmirza','mhbaig52@hotmail.co.uk','Mirza Baig','52 St Heliers Avenue','Hounslow','Middlesex','UNITED KINGDOM','Tw3 3sj','07877979465','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 00:17:52',0,NULL,3,1,3,1,'RA184502259CN\r ','au-buy\rLGAD001'),(23497,692361286013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','didbrotha','digitnsm@gmail.com','Didier Renault','121 Sufian St','Pembroke','ON','CANADA','K8A6W6','(613) 735-8395','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 00:52:52',0,NULL,3,1,11,1,'BJ01713622\r ','eastar4\rCACN004'),(23498,803691335007,170730544640,'3DConnexion SpacePilot USB Intelligent 3D Motion Controller mouse',1,'MOLO010',208.99,'au-buy','dominic_71','dominikschleipen@yahoo.co.uk','Dominik Schleipen','13B, Block 46, City One Shatin<br>New Territories East','default','','HONG KONG','default','85264438921','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 01:20:07',0,NULL,3,1,6,1,'EE651291578CN ','au-buy\rMOLO010'),(23499,8881331602022045,111,'Free shipping & Tracking # - Lowrance Airmap600C Upgraded Color Display GPS+WAAS Receiver - ',1,'GPS0012',143.99,'aliexpress','1007349708','afp82@hotmail.com','Daniela Oliveira','Rua: Polydoro Bittencourt, n: 20 ,Bairro: Boa Viagem ','Salvador','Bahia','BRAZIL','40414340','+55 71 88187516',NULL,NULL,NULL,'2012-03-13 01:27:02',0,NULL,3,1,3,1,'RA184503444CN ','GPS0012 '),(23500,8881331602512760,111,'Free Shipping & Tracking # -New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW - ',2,'WLIN014',37.98,'aliexpress','1007358001','inmy72@gmail.com','In Man Hwang','Aon Korea Inc. 20th Floor Kukdong Bldg. 60-1, Chungmuro3-ga, Jung-gu','Seoul','Seoul','SOUTH KOREA','100-705','+82 2 22602649',NULL,NULL,NULL,'2012-03-13 01:35:12',0,NULL,3,1,3,1,'RA184503387CN\r ','WLIN014 '),(23501,951327298012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',275.99,'eastar4','lindakev','lindabraga@live.ca','Linda Braga','22 Wayne Ave','Cambridge','ON','CANADA','N1R5S4','(519) 267-1480','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 01:33:47',0,NULL,3,1,3,1,'RA184502262CN\r ','eastar4\rPSGL001*4'),(23502,636924370004,140516160152,'New Marantz RC3001 PC Programmable Remote & RF Extender',1,'RCMA001',117,'cnfaner','rhorvath','rhorvath@iname.com','Reinhard Horvath','3 Ch. de la Coulee','Lac Beauport','QC','CANADA','G3B1G5','(418) 849-0645','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 02:43:13',0,NULL,3,1,3,1,'RA184502143CN ','cnfaner\rRCMA001'),(23503,636926573004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','slipyouapickle','scrimpy1@att.net','david leca','6132 cherrelyn way','carmichael','CA','UNITED STATES','95608','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 02:57:00',0,NULL,3,1,1,1,'Lk232054283CN ','cnfaner'),(23504,859629349011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','bobby.b.bobbert','krwang@gmail.com','Kuan Wang','82 Princess Dr','North Brunswick','NJ','UNITED STATES','08902-4105','(732) 322-2107','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:03:11',0,NULL,3,1,1,1,'LK232528338CN ','eastar4\r3.0 ASUS 6PIN 12CM  '),(23505,0,140717907710,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',8.02,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 03:04:54',0,NULL,3,0,18,0,NULL,'cnfaner\r自己人拍的'),(23506,0,130660699848,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',7.22,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 03:05:00',0,NULL,3,0,18,0,NULL,'cnfaner\r自己人拍的'),(23507,0,130660698404,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',23.97,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 02:49:53',0,NULL,3,0,18,0,NULL,'cnfaner\r自己人拍的'),(23508,0,140717907295,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',26.82,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 03:17:36',0,NULL,3,0,18,0,NULL,'cnfaner\r自己人拍的'),(23509,0,130660700375,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',9.42,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 03:46:58',0,NULL,3,0,18,0,NULL,'cnfaner\r自己人拍的'),(23510,0,140717907234,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',0.01,'cnfaner','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','Pickup','2012-03-13 03:47:05',0,NULL,3,0,18,0,' ','cnfaner\r自己人拍的'),(23511,0,220974163892,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',5.99,'eastar4uk','666chicobaby','melissatate666@msn.com','Melissa Tate','214 Amelia Street','Kennington','London','UNITED KINGDOM','SE17 3AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 04:08:38',0,NULL,3,1,3,1,'RA184502126CN ','eastar4uk\rHBPH003\r英标'),(23512,692411010013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','1691208107','ebay.com.au@violaceo.us','Harold  Fry','3 / 10 Cromwell Road','South Yarra','Victoria','AUSTRALIA','3141','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 04:27:13',0,NULL,3,1,11,1,'BJ01713863 ','eastar4\rCACN004'),(23513,951387334012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','canadaolive','jenritter@cox.net','Jennifer Ritter','13821 Typee Way','Irvine','CA','UNITED STATES','92620-3275','(949) 246-2887','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 04:31:57',0,NULL,3,1,1,1,'LK232216834CN ','eastar4'),(23514,636944328004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','geotrvl','jsanfuentes@yahoo.com','John Sanfuentes','38 W Penn St','Philadelphia','PA','UNITED STATES','19144-2960','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 04:38:54',0,NULL,3,1,1,1,'Lk232071454CN ','cnfaner'),(23515,692413640013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','damienc1956','damienc1@hotmail.com','damien j comerford','3 Beatrice Street','Ashfield Sydney','New South Wales','AUSTRALIA','2131','0410559221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 04:43:08',0,NULL,3,1,11,1,'BJ01713860 ','eastar4\rCACN004'),(23516,636781526004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',12.59,'cnfaner','nadun8009','djnadsa@gmail.com','Nadun Wijetilleke','70, Wanatha Road, Gangodawila,Nugegoda','Nugegoda','','SRI LANKA','10250','0094758519822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 04:53:05',0,NULL,3,1,3,1,'RA184502130CN ','cnfaner\rHSAL002\r美标'),(23517,636947251004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','ohlangford','orlandolangford@hotmail.com','Orlando Langford','2600 University Ave. Lot#119','Williston','ND','UNITED STATES','58801','(701) 264-0129','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'cnfaner\recheck'),(23518,859675712011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',44.89,'eastar4','dimnsk','multicheck1@gmail.com','Dmitriy Evdokimov','Kotovskogo St.22-17','Novosibirsk','Novosibirskaja Region','RUSSIAN FEDERATION','630108','+7913-938-2253','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 06:43:11',0,NULL,3,1,3,1,'RA184502112CN ','eastar4\rGLOT001'),(23519,795214641008,180810778773,'New in box 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001',40.84,'au-buy','sparkybird47','hgibson3@gmail.com','Leanne Gibson','1/16 Jade Avenue','Goonellabah','New South Wales','AUSTRALIA','2480','2266243315','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 07:01:57',0,NULL,3,1,3,1,'RA184502205CN ','au-buy\rGLOT001'),(23520,951425792012,220815929300,'New Atheros AR5B95 AR9285 B/G/N Half Mini PCI-E card',1,'WLAT009',6.99,'eastar4uk','hexed010','a_j_lawless@hotmail.com','Andrew Lawless','7 Danwood Close<br>Denton','Manchester','Lancashire','UNITED KINGDOM','M34 7SD','01613201645','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 07:41:50',0,NULL,3,1,3,1,'RA184501307CN\r ','eastar4uk\rWLAT009'),(23521,951428631012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Applied Minds, LLC','1209 GRAND CENTRAL AVE','GLENDALE','CA','UNITED STATES','91201-2425','(503) 722-4468','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 07:52:08',0,NULL,3,1,1,1,'LK232542167CN ','eastar4'),(23525,951439741012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.79,'eastar4','oskarannas','oskarannas@hotmail.com','Oskar Annas','Adelsgatan 2','Visby','Gotland','SWEDEN','62157','46736968348','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 08:37:42',0,NULL,3,1,11,1,'BJ01713854 ','eastar4\rMOMI002'),(23522,631402582003,130466041485,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',37.99,'cnfaner','bob1308-0117','airfalcon@list.ru','Vladimir Shtirts','19/2-251<br>Skobelevskaya  st.','Moscow','','RUSSIAN FEDERATION','117624','+79265571931','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 08:03:22',0,NULL,3,1,3,1,'RA184502157CN ','cnfaner\rWWSI005+ANCN001'),(23523,692444579013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','grafdoskinaz','grafbelousov@gmail.com','Vladimir Belousov','61 Strelkovaya str.','Rostov-on-Don','Rostov','RUSSIAN FEDERATION','344016','+7 928 2261606','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 08:27:22',0,NULL,3,1,11,1,'BJ01713857 ','eastar4\rCACN004'),(23526,951441220012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','markdfoster','mark.donald.foster@googlemail.com','Mark  Foster','Pond House,<br>6 The Chestnuts','Kirtlington','Oxfordshire','UNITED KINGDOM','OX53UB','01869351027','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 08:48:06',0,NULL,3,1,3,1,'RA184501094CN\r ','eastar4uk\rHSJA002\r英标'),(23527,859703317011,320688311668,'New Apple 8GB USB PEN KEY FLASH DRIVE',1,'UDAP001',21.99,'eastar4uk','jaythetaff','jay.owen@hotmail.co.uk','James Owen','Copperstone House<br>East Pelcomb Farm','Haverfordwest','Pembrokeshire','UNITED KINGDOM','SA62 6HP','07872963262','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 08:50:00',0,NULL,3,1,3,1,'RA184501179CN\r ','eastar4uk\rUDAP001'),(23528,795239458008,180761131351,'Clear Transparent Dome Birdcage Rain Sun Umbrella with Zebra Trim',1,'UM00041',18.99,'au-buy','toni29toni','saranne@bigpond.com','Toni Latham, Mindshop Australia','Suite 10<br>25 Claremont Street','South Yarra','Victoria','AUSTRALIA','3141','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 08:54:42',0,NULL,3,1,11,1,'BJ01713855\r ','au-buy\rUM00041'),(23529,803795276007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',49.39,'au-buy','juz4ben','sis_snake@hotmail.com','Justine Drake','Level 1, 23 Wentworth Street','Parramatta','New South Wales','AUSTRALIA','2150','0425335501','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 09:00:13',0,NULL,3,1,3,1,'RA184502069CN\r ','au-buy\rLGFI001'),(23530,951138048012,220448680514,'Acer Aspire 5920 5920G Bluetooth Module EDR 2.0+cable',1,'BTAC2013',9.88,'eastar4','hbaykiwi1970','shaneduley@live.com','Shane Duley','3 wilmington court<br>helensvale','Gold Coast','Queensland','AUSTRALIA','4212','0420790118','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 09:15:41',0,NULL,3,1,11,1,'BJ01713844\r ','eastar4\rBTAC2013\racer 5pin1.25 15cm'),(23531,636988166004,140675757780,'New 3D Active Shutter TV Glasses Compatible for LG AG-S110 AGS110',1,'GLOT001',39.5,'cnfaner','sobbay','sobge.es@gmail.com','Gerardo Cubillo','C/ Andres de Urdaneta 6-C, 4ºA','Madrid','Madrid','SPAIN','28045','651819324','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 09:48:10',0,NULL,3,1,3,1,'RA184502090CN\r ','cnfaner\rGLOT001'),(23532,0,170802050238,'Philips Sonicare Elite 7500/HX7500 toothbrush handle',1,'HBPH007',24.99,'au-buy','appinrabbit','hobb01_@hotmail.com','Ian Hobson','14 Macquariedale Road','APPIN','New South Wales','AUSTRALIA','2560','0246311367','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 09:51:01',0,NULL,3,1,11,1,'BJ01713842\r ','au-buy\rHBPH007'),(23533,859722620011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','samiluna13','julijamandic05@gmail.com','Julija Mandic','Izmedju dolaca 16','Mokosica,','','CROATIA','20236','0038598304602','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 10:01:08',0,NULL,3,1,11,1,'BJ01713852\r ','eastar4\rUM00040'),(23534,856745667002,120844622416,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',21.35,'buysia','gs8960','gs8960@gmail.com','George Sarantidis - E.E.T.A.A. SA','Millerou 73-77','Athens','Attiki','GREECE','10436','+306932240337','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-13 10:14:36',0,NULL,3,1,11,1,'BJ01712848\r ','buysia\rHSUE003\r欧标'),(23535,951468093012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','elbiplus48','lz1eh@abv.bg','Norsk London Spot','Unit 2, Willow road 	Section 3567','Slough','Berkshire','UNITED KINGDOM','SL3 0BS','056 3475209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 10:15:36',0,NULL,3,1,3,1,'RA184502109CN\r ','eastar4uk\rHSJA002\r英标'),(23536,8881331633827266,111,'2.0 Bluetooth Module + cable for DELL mini9 mini 9 910',1,'BTDE2001',0,'eastar4','forthedishwasher','donttelldallas@yahoo.com','stuart mank II','261 Oyster River Rd','Warren','ME','UNITED STATES','04864-4248','',NULL,NULL,NULL,'2012-03-13 10:17:07',0,NULL,3,1,3,1,' RA184501125CN\r','EASTAR4\rBTDE2001 \r补货'),(23537,951469210012,220930022607,'New 4 Parking Sensor LED Car Reverse backup Radar kit 3M alert 10 colors availab',1,'PS00001',25.99,'eastar4','kklwin7','kyawko7@gmail.com','Kyaw Ko Lwin','PO Box-17114, DUSUP Pipeline Office<br>Jebel Ali Ind.1','Dubai','Dubai','UNITED ARAB EMIRATES','-','+971504508274','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 10:22:40',0,NULL,3,1,11,1,'BJ01714162 ','eastar4\rPS00001\r黑色的'),(23538,0,180840049068,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',6.99,'au-buy','brentlister84','brentleelister@gmail.com','BRENT LISTER','6944 Quebec St','Vancouver','BC','CANADA','V5X3G5','7782275755','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 10:26:09',0,NULL,3,1,11,1,'BJ01712850\r ','au-buy\rHBPH003'),(23539,951472404012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',2,'CASS001',12.59,'eastar4uk','333cmb','c.beckett@talk21.com','C. Beckett','57 Swanlow Lane','Winsford','Cheshire','UNITED KINGDOM','CW7 1JD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 10:30:30',0,NULL,3,1,3,1,'RA184502038CN\r ','eastar4uk\rCASS001\r再发一个Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna\r'),(23540,859732378011,320619142324,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',21.35,'eastar4','sebastgoh','sebastgoh@yahoo.com.sg','Sebast Goh','234 Bishan Street 11 #05-118','default','','SINGAPORE','570234','(+65) 9005 3051','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 10:36:21',0,NULL,3,1,11,1,'BJ01712847\r ','eastar4\rHSUE003'),(23541,859733223011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','k800lau','francislau54@hotmail.com','Francis Lau','6 Wakemans Hill Avenue<br>Kingsbury','London','London','UNITED KINGDOM','NW9 0TY','07956267314','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 10:43:21',0,NULL,3,1,3,1,'RA184501148CN\r ','eastar4uk\rOTSO004'),(23542,858397937011,320693999572,'New BroadCom BCM94313 BCM2070 Wifi Bluetooth PCI-E Card',1,'WLIN015',14.99,'eastar4','3dmultimedia','andribanez@terra.es','ANDRES IBAÑEZ MULLOR (3DMULTIMEDIA)','FRANCESC SOLER I PUIDOLLERS, 117 BJ6','SANT VICENÇ DE CASTELLET','Cataluña','SPAIN','08295','658796301','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 10:45:28',0,NULL,3,1,11,1,'BJ01712846\r ','eastar4\rWLIN015'),(23543,0,220974194114,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.11,'eastar4uk','turningblanks','qms@nb.sympatico.ca','Darrell Lapointe','262 York Street','Bathurst','NB','CANADA','E2A 1H1','(506) 548-9894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 10:58:53',0,NULL,3,1,11,1,'BJ01712851\r ','eastar4uk\rPOLO001'),(23544,637002257004,140626376143,'New GENUINE NOKIA BH-302 BLUETOOTH HEADSET',1,'HSNO014',16.2,'cnfaner','sabancom','scom@bezeqint.net','shai saban','hanegev 1','kiriat malachi','','ISRAEL','972','0524025025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 10:59:51',0,NULL,5,1,3,1,'RA184501050CN\r ','cnfaner\rHSNO014\r欧标'),(23545,859753354011,320698771084,'NIB 2011 SONY 3D Active Glasses TDG-BR250 rechargeable',1,'OTSO004',68.99,'eastar4','dezasm','dezaosm@gmail.com','André Luis Vidal Almeida','Rua Presidente Vargas, 452','Manoel Viana','Rio Grande do Sul','BRAZIL','97640-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 11:46:33',0,NULL,3,1,3,1,'RA184501029CN\r ','eastar4\rOTSO004'),(23546,951502791012,220748684512,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',12.49,'eastar4uk','dymetrie','richardebond@gmail.com','Richard Bond','7 Harley Court<br>Blake Hall Road','Wanstead','London','UNITED KINGDOM','E11 2QG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 12:02:57',0,NULL,3,1,3,1,'RA184501077CN\r ','eastar4uk\rOTHP003'),(23547,692494460013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','raiekmoha','zanex_99@hotmail.com','Raiek Mohamed Garah','meling bygge felt 1<br>norge','Bømlo','Bremnes','NORWAY','5430','48369636','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 12:40:54',0,NULL,3,1,11,1,'BJ01713849\r ','eastar4\rHSNO019\r欧标'),(23548,951521752012,220815932431,'Replaceable Shell 4 logitech Performance MX Mouse M950',1,'SHLO002',13.98,'eastar4uk','trondmathiesen','trond.mathiesen@lifi.no','Trond Mathiesen','Skogliveien 6','Sylling','Buskerud','NORWAY','3410','(047) 32856575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 12:57:01',0,NULL,3,1,11,1,'BJ01713851\r ','eastar4uk\rSHLO002\r'),(23549,859780778011,320691197193,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA013',19.98,'eastar4','murat1983murat','muratdulkar@hotmail.com','Murat Dulkar','Solheims vn 85 a<br>1473','Lørenskog','Lørenskog','NORWAY','1473','004793499820','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 13:18:25',0,NULL,3,1,11,1,'BJ01713846\r ','eastar4\rHSJA013\r欧标'),(23550,637033241004,140662512555,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',2,'MOHP002',25.8,'cnfaner','magicstarinfo','magichoracio@hotmail.com','HORACIO ORESTES DOS SANTOS','RUA ANTONIO FRANCO POMPEU  82','BARRA BONITA','SÃO PAULO','BRAZIL','17340000','55-14-36410047','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 13:22:34',0,NULL,3,1,3,1,'RA184501085CN\r ','cnfaner\rMOHP002'),(23551,803877995007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','hvfs1','ponunow@hotmail.com','Hannah Salt','15 Karumba Street','Warana','Queensland','AUSTRALIA','4575','0412326221','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 13:37:24',0,NULL,3,1,11,1,'BJ01713853\r ','au-buy\rUM00001'),(23552,951564446012,220448700087,'Acer Aspire 5520 5520G 5530 Bluetooth Module 2.0+cable',1,'BTAC2023',9.88,'eastar4','wolle4462','peter4462@web.de','Wolfgang Schädig','Marliring 30','Lübeck','','GERMANY','23566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:46:13',0,NULL,3,1,11,1,'BJ01713837\r ','eastar4\rBTAC2023\racer 8pin1.00 18cm'),(23553,812127398001,110701886028,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB  CARD',1,'OTSB001',24.99,'buysia','knutpaulsen','knut.paulsen@obos.no','Knut Paulsen','Kalbakkveien 17','Oslo','Oslo','NORWAY','0953','+4748183474','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:50:37',0,NULL,3,1,11,1,'BJ01712845\r ','buysia\rOTSB001'),(23554,692531886013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','sss19762010','ebay1976@mail.ru','Vadim Samsonov','Chertigasheva 120-128','Abakan','Khakasia','RUSSIAN FEDERATION','655017','+79083262030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 15:02:21',0,NULL,3,1,3,1,'RA184501196CN\r ','eastar4\rLGAD001'),(23555,856845993002,120841707694,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'buysia','ess-oh-ess','kathrin.pein@web.de','Kathrin Schlei','Leharstr. 29 C','Hamburg','','GERMANY','22145','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-13 15:23:06',0,NULL,3,0,3,1,'RA184501151CN\r ','buysia\rLGAD001'),(23556,692542337013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','vidar-k','vidklo@online.no','Vidar Klo','Sedalen 2','default','Vaksdal','NORWAY','5725','+4791576256','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 15:39:01',0,NULL,3,1,11,1,'BJ01713843\r ','eastar4\rHSNO022\r欧标'),(23557,949512113012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',2,'PSGL001',143.98,'eastar4','nivalen2012','nivalen@mail.ru','Nikolay Lebedev','Saharovo, Sadovaya st.,d.4 kv.20','Tver','Tver Region','RUSSIAN FEDERATION','170904','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 16:26:59',0,NULL,3,1,3,1,'RA184501046CN\r ','eastar4\rPSGL001'),(23558,859860325011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',19.99,'eastar4','noel_arauz','noelarauz@gmail.com','Noel Arauz','120 Sycamore ave.','South San Francisco','CA','UNITED STATES','94080','(650) 834-5302','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 16:40:36',0,NULL,3,1,1,1,'LK232562192CN\r ','eastar4'),(23559,859868666011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',19.5,'eastar4','bludphart','cordmahoff@hotmail.com','Cord Mahoff','413 Onyx Dr','Palm Springs','CA','UNITED STATES','92264-8367','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 16:57:18',0,NULL,3,1,1,1,'LK232554721CN ','eastar4'),(23560,859866056011,320730481273,'New 24K Ultra light w/Carbon Fiber ribs Sun umbrella',2,'UM00021',53.98,'eastar4','ipad32','klex3@yandex.ru','Aleksey Valerevich Korchev','Ostrovityanova street, house 9/3, apartment 26','Moscow','','RUSSIAN FEDERATION','117198','+7985-923-7558','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 16:58:32',0,NULL,3,1,3,1,'RA184502041CN\r ','eastar4\rUM00021\r深蓝色和咖啡色'),(23561,951623969012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','ktoruner1','ktoruner@epdk.org.tr','Kutay Toruner','EPDK Muhsin Yazicioglu Cad. No:51/C Yuzuncu Yil','Ankara','-','TURKEY','06530',' 00905053246045','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 17:05:01',0,NULL,3,1,11,1,'BJ01712849\r ','eastar4\rTRMX003'),(23562,951635629012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',141.99,'eastar4','dr.freedom','free-dom@mail.ru','Aleksandr Polotsky','Bogdanova<br>8.  2.','Moskva','Moskva','RUSSIAN FEDERATION','119618','89192061571','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 17:28:02',0,NULL,3,1,3,1,'RA184501015CN\r ','eastar4\rPSGL001*2'),(23563,951647598012,220759518786,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',7.99,'eastar4uk','erwin4025','e.a.p@planet.nl','Erwin Pelsmaeker','Zonnedauw 127','Tiel','','NETHERLANDS','4007VD','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 17:44:49',0,NULL,3,1,11,1,'BJ01712844\r ','eastar4uk\rRELO002'),(23564,637111214004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',2,'OTGR002',41.8,'cnfaner','042002_123','mikecoff@optonline.net','michael coffey','2501 7th St','east meadow','NY','UNITED STATES','11554-3107','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 18:04:32',0,NULL,3,1,1,1,'LK232431033CN ','cnfaner'),(23565,859892236011,320738961119,'New 3.0 Bluetooth BCM92070 Module+cable Asus N53 G53',1,'BTAS3002',19.98,'eastar4','sevlah','hugotalves@gmail.com','Hugo Alves','Rua D. Elisa Guimarães, 141','Maia','','PORTUGAL','4425-068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 18:09:11',0,NULL,3,1,11,1,'BJ01713838\r ','eastar4\rBTAS3002\r3.0 ASUS 6PIN 12CM  '),(23566,0,320865570513,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.11,'eastar4uk','robbest72','robbest72@aol.com','ROBERT BEST','203 A<br>KINSON ROAD','BOURNEMOUTH','Dorset','UNITED KINGDOM','BH10 5HB','01202381051','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 18:31:13',0,NULL,3,1,3,1,'RA184501205CN\r ','eastar4uk\rSCLO002'),(23567,637127056004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','randyhencken','randy_hencken@yahoo.com','Randolph Hencken','3769 39th ave','Oakland','CA','UNITED STATES','94619','(619) 865-3000','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-13 18:47:57',0,NULL,3,1,1,1,'LK232465301CN ','cnfaner'),(23568,631558440003,130626363919,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.95,'cnfaner','gatacar','cathy@tabuaholdings.com','Graham Carter','21 Falcon St<br>Parnell','Auckland','Auckland','NEW ZEALAND','1024','(027) 604-7373','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 18:59:30',0,NULL,3,1,3,1,'RA184501134CN\r ','cnfaner\rRELO002'),(23569,858685933011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','ra.uminho','ra.azevedo@hotmail.com','Rui Azevedo','Rua Pombal Nº26  6ºESQFRT<br>Azurem','Guimarães','Portugal','PORTUGAL','4800-026','918511463','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 19:29:34',0,NULL,3,1,11,1,'BJ01713847\r ','eastar4uk\rCACN004'),(23570,951721402012,220949094847,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',128.99,'eastar4uk','nimbusc','martin.pingel@btinternet.com','Martin Pingel','34 Darren View','Crickhowell','Powys','UNITED KINGDOM','NP81DS','01873810108','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 19:40:20',0,NULL,3,1,3,1,'RA184501032CN\r ','eastar4uk\rPSGL001*3'),(23571,951730521012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',19.98,'eastar4','outlaw25386','outlawcrew253@yahoo.com','roshane anderson','1699 Nelson Ave<br>Apt 2','bronx','NY','UNITED STATES','10453-7069','(347) 284-8752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 19:55:06',0,NULL,3,1,1,1,'LK232525668CN ','eastar4'),(23572,951733915012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',87.99,'eastar4','michiganshaun','phillisw@trinity-health.org','shaun','983 chads way','charlotte','MI','UNITED STATES','48813-8758','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 20:03:56',0,NULL,3,1,1,1,'LK232549125CN\r ','eastar4'),(23573,859986859011,320816532145,'4 pair New in box Genuine Samsung SSG-3300GR 3D Active Shutter Smart Glasses',1,'GLSG009*4',379.99,'eastar4','biggnarledman69','biggnarledman69@hotmail.com','rick cote','518 5th avenue west','meadow lake','SK','CANADA','s9x 1a9','(306) 240-5365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 20:27:28',0,NULL,3,1,6,1,'EE651291618CN\r ','eastar4\rGLSG009*4'),(23574,951753637012,220763389203,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',36,'eastar4uk','sepmise','m.seydaack@gmx.de','Michael Seydaack','Neustrasse 40','Dinslaken','','GERMANY','46535','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 20:28:38',0,NULL,3,1,3,1,'RA184501236CN\r ','eastar4uk\rWWSI006+ANCN001'),(23575,951780339012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',165.99,'eastar4uk','bevalancam','cameron06@sky.com','Beverley Smith','15 Weston House, 40 Ruddington Way<br>Newtown','Birmingham','West Midlands','UNITED KINGDOM','B19 2QJ','01213592618','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 21:09:33',0,NULL,3,1,4,1,'YW870147216CN\r ','eastar4uk\rOTSO004*4'),(23576,860017912011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','meersone','meerson@walla.com','Eli Meerson','P.O.Box 280','Modiin','','ISRAEL','71711','972-778120003','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 21:19:32',0,NULL,3,1,11,1,'BJ01713845\r ','eastar4\rHSJA002'),(23577,691440047013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',44.99,'eastar4','leandromott','leandro_mott@yahoo.com.br','Leandro Silva Mott','Rua Jasmim, 28, 1502-B','Campinas','SP','BRAZIL','13087-460','+551997788646','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 21:35:04',0,NULL,3,1,3,1,' RA184501063CN\r','eastar4\rLGAD001'),(23578,951801156012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',71.99,'eastar4','jcrimports','johanramirezz@hotmail.com','jcr imports','7355 NW 54th St','Miami','FL','UNITED STATES','33166-4831','(561) 602-2067','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 21:44:48',0,NULL,3,1,1,1,'LK232568717CN\r ','eastar4'),(23579,857046419002,120868118790,'New Philips Toothbrush Sonicare Travel Charger base EU PLUG',1,'HBPH003',19.5,'buysia','638419781','kulipop@yahoo.com','Marina Popkova','3 Krasnogvardeyskaya st. House 3 ap. 122','Moscow','Moscow','RUSSIAN FEDERATION','123317','0079175245562','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-13 22:01:48',0,NULL,3,1,3,1,'RA184501704CN\r ','buysia\rHBPH003\r2个\r'),(23580,951821586012,220913328002,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',7.99,'eastar4uk','scrappydoo1994','sharon01@btinternet.com','dawn adams','7 the bungalows kettleby lane  , Wrawby','brigg','Lincolnshire','UNITED KINGDOM','DN208SU','01652652941','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 22:21:53',0,NULL,3,1,3,1,'RA184502086CN\r ','eastar4uk\rMOHP002'),(23581,812359958001,110826639785,'New UNLOCKED Sierra Wireless MC8780 7.2Mbps 3G Mini PCI-E Module+3G WWan antenna',1,'WWSI004+ANCN001',39.99,'buysia','lenko4stuff','lenkostudios@gmail.com','Len Fassett','PO Box 4594<br>188 Ballston Ave','Saratoga Springs','NY','UNITED STATES','12866','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-13 23:03:10',0,NULL,3,1,1,1,'LK232471806CN ','buysia'),(23582,637224735004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','sk8er_steven','sk8er_steven@hotmail.com','steven antonacci','1496, boulevard des seigneurs','terrebonne','QC','CANADA','J6X 1E9','(514) 260-6069','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 23:29:28',0,NULL,3,1,3,1,'RA184501103CN\r ','cnfaner\rHSJA002\r美标'),(23583,860089812011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',45.99,'eastar4','mulya36','sggally@hotmail.com','Sandra Gally','Mulya Station<br>Louth Rd','Cobar','New South Wales','AUSTRALIA','2835','0425246452','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 00:07:08',0,NULL,3,1,3,1,'RA184502055CN\r ','eastar4\rLGRM001'),(23584,692728384013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',68.5,'eastar4','xalicesandra','ayelai@live.com','ali arndt','2551 128th ave','allegan','MI','UNITED STATES','49010-9235','(269) 355-0339','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 00:15:20',0,NULL,3,1,1,1,'LK232533151CN\r ','eastar4'),(23585,951872336012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','palc2830','paul.jule@gmail.com','Paul-Jules ALCHIE','24 rue du puymaurin','Toulouse','Midi-Pyrénées','FRANCE','31400','0673369847','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 00:28:52',0,NULL,3,1,11,1,'BJ01714211\r ','eastar4\rWLAT009'),(23586,8881331688975413,111,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh - ',1,'BALO001',11.99,'aliexpress','1007372588','purchase@soeby.eu','Lars Soeby','Oerslev Stationsvej 63 ','Ringsted','Denmark','DENMARK','DK-4100','+45 51579598',NULL,NULL,NULL,'2012-03-14 01:36:15',0,NULL,3,1,3,1,'RA184501117CN\r ','BALO001\r '),(23595,8881331699998395,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',0,'eastar4','youtube12345','1a1z2s2x@gmail.com','Charles Shaw','2 Meadow Rd<br>Unit 2','PROVINCETOWN','MA','UNITED STATES','02657-1260','(503) 722-4468',NULL,NULL,NULL,'2012-03-14 04:39:58',0,NULL,3,1,1,1,'LK233383215CN ','eastar4\rMOAP001\r补发的'),(23587,860136125011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','2008alberto_123','2008alberto@live.com','alberto lopez','114 pine st','greenwich','CT','UNITED STATES','06830-5949','(914) 482-3953','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 02:35:00',0,NULL,3,1,1,1,'LK232584017CN\r ','eastar4'),(23588,951925062012,220688992700,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',39.9,'eastar4','tech4lessfl','rsimon@abctelecom.com','Randy Simon','9901 NW 11th St','Plantation','FL','UNITED STATES','33322-4867','(954) 328-1000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 02:57:48',0,NULL,3,1,1,1,'LK232721702CN\r ','eastar4'),(23589,8881331694176094,111,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET +car charger',1,'',0,'eastar4','lepsiskiai','klajoklis.vaiduoklis@gmail.com','Juras Jankevicius','Juozapaviciaus 19a-6','Kaunas','','LITHUANIA','45252','861686908',NULL,NULL,NULL,'2012-03-14 03:02:56',0,NULL,3,0,3,1,'RA184501182CN\r ','eastar4\r补货\r已入库\rHSNO005+CCNO001 '),(23590,857149504002,120869125980,'100% NEW ASUS LAMBORGHINI Wireless Bluetooth Mouse',1,'MOLA001',36.9,'buysia','tommy8797','lisaduvalca@aol.com','Lisa Duval','12 Greene Pl','New Windsor','NY','UNITED STATES','12553-8200','(845) 563-0441','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-14 03:03:01',0,NULL,3,1,1,1,'LK232873138CN\r ','buysia'),(23591,951801910012,220502333404,'2.1 HP 8710w nw9440 nx9420 Bluetooth Module EDR +cable',1,'BTHP2105',12.39,'eastar4','ippok55','ippok57@yahoo.gr','Ippokratis Kotakis','Malakasi 14-16, Agios Elefterios, Agios Elefterios<br>Agios Elefterios','Athens','','GREECE','11143','305974403506','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 03:13:59',0,NULL,3,1,11,1,'BJ01713841\r ','eastar4\rBTHP2105\rHP 8pin 1.0 20cm '),(23592,948946485012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',23.9,'eastar4','lazarminator','brkljavko@yahoo.com','Jordan Markovic','7-21-19','Aktau','Mangystau','KAZAKHSTAN','130000','+77015251104','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 03:35:54',0,NULL,3,1,11,1,'BJ01713850\r ','eastar4\rHSJA001'),(23593,692781254013,230537741704,'2.1 HP DV6700 DV6700t DV6700z Bluetooth ModuleEDR+cable',1,'BTHP2110',12.39,'eastar4','f752g70','nardienka@hotmail.com','Ferdinand Gjini','24 Hearthside ave','Richmond Hill','ON','CANADA','L4E5E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 04:02:08',0,NULL,3,1,11,1,'BJ01713839\r ','eastar4\rBTHP2110\rHP 8pin 1.25 18cm '),(23594,860161868011,320612439918,'New GENUINE NOKIA BH 900 BLUETOOTH HEADSET +car charger',1,'HSNO019+CCNO001',42.99,'eastar4','grampales','leshoeflich@gmail.com','Lester Hoeflich','12 Airy Dr','Spencerport','NY','UNITED STATES','14559-1161','(585) 755-6700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 04:11:39',0,NULL,3,1,1,1,'LK232694750CN\r ','eastar4'),(23596,860175434011,320701012069,'New 3D TV Active Shutter Glasses for SAMSUNG SSG-2200AR',1,'GLOT001',39.99,'eastar4','smgy70','sarfm@freemail.hu','Sarf Miklós','Kossuth utca 15.','Velence','Hungary','HUNGARY','2481','+36303967427','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 05:51:18',0,NULL,3,1,11,1,'BJ01713848\r ','eastar4\rGLOT001'),(23597,692795990013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',44.99,'eastar4','andresles','seldom@ngs.ru','Andrey Slesarenko','15 Bronny<br>52','Novosibirsk','Novosibirskaya oblast','RUSSIAN FEDERATION','630022','+79139859038','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 06:27:43',0,NULL,3,1,3,1,'RA184502015CN\r ','eastar4\rGLOT005'),(23598,857203498002,120868118790,'New Philips Toothbrush Sonicare Travel Charger base EU PLUG',1,'HBPH003',19.5,'buysia','638419781','kulipop@yahoo.com','Marina Popkova','3 Krasnogvardeyskaya st. House 3 ap. 122','Moscow','Moscow','RUSSIAN FEDERATION','123317','0079175245562','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-14 07:40:33',0,NULL,3,0,17,0,'RA184501704CN\r ','buysia'),(23599,804277608007,170730545430,'Genuine Logitech Harmony 515 Universal Remote Control',1,'RCLO004',37.99,'au-buy','clash973','clash@mail.ru','Andrey Chernyshev','Avtovskaya st. 7-28','Saint-Petersburg','','RUSSIAN FEDERATION','198096','+7 921 9442332','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-14 08:01:35',0,NULL,3,1,3,1,'RA184501253CN\r ','au-buy\rRCLO004'),(23600,860204692011,320826634741,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',32.99,'eastar4uk','azouzr','razouz@bgu.ac.il','rony Azouz','8 Efroni St.','Lehavim','Israel','ISRAEL','85338','077-3513397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 07:49:14',0,NULL,3,1,3,1,'RA184501165CN\r ','eastar4uk\rHBPH007'),(23601,951996095012,220572891204,'New genuine Intel WiMAX 6250 622AGXHRU wifi',1,'WLIN001',22.99,'eastar4','haloxy','tadmef@gmail.com','Dmytro Tarasyuk','Zodchih str.<br>h.62, ap.323','Kyiv','','UKRAINE','03170','+380(67)4035883','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 08:15:50',0,NULL,3,1,11,1,'BJ01714213\r ','eastar4\rWLIN001'),(23602,0,320866263366,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',22.01,'eastar4uk','patrickcalongy','calongy@yahoo.com','PATRICK SENADZO','52 GORDON ROAD<br>CARDIFF','CARDIFF','Cardiff','UNITED KINGDOM','CF24 3AL','07411480772','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 08:16:17',0,NULL,3,1,3,1,'RA184501240CN\r ','eastar4uk\rGLOT001'),(23603,951997887012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',68.99,'eastar4','777sm777','sm007@inbox.ru','Alexandr Kostin','Ul. Zagorodnay, D.48, korp.3, K.50','Kolpino','RU','RUSSIAN FEDERATION','196652','79052647417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 08:23:53',0,NULL,3,1,3,1,'RA184501222CN\r ','eastar4\rPSGL001'),(23604,951999619012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'eastar4','rromkaa','krisjanson@inbox.lv','Romans Krisjansons','Ratsupites iela 3-64','Riga','LVA','LATVIA','LV-1067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 08:33:08',0,NULL,3,1,3,1,'RA184501219CN\r ','eastar4\rOTSO004*2'),(23605,0,320866263489,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.06,'eastar4uk','kunnn','radmakmania@hotmail.com','Yada A.tikumporn','8/61 Seri-onnut village Sukumvit77 rd.<br>Prawet Bangkok','default','BA','THAILAND','10250','66846705024','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 08:49:01',0,NULL,3,1,11,1,'BJ01712842\r ','eastar4uk\rSCLO002'),(23606,0,180840774133,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',24.99,'au-buy','melinda849','mindyhoskins@hotmail.com','Melinda Hoskins','34 Asher Street','GEORGETOWN','New South Wales','AUSTRALIA','2298','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 09:03:43',0,NULL,3,1,11,1,'BJ01712805\r ','au-buy\rGLOT001'),(23607,952010597012,220806892970,'NEW Auto folding parasol sun umbrella w/lace black+red',1,'UM00006',24.99,'eastar4','procutsports','pro.cut@hotmail.com','Pro cut sports','16 Blue Haze Crescent','Banora Point','New South Wales','AUSTRALIA','2486','0411154523','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 09:13:40',0,NULL,3,1,11,1,'BJ01714212\r ','eastar4\rUM00006'),(23608,804290220007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','benough1','benough@gmail.com','Ben Stevens','100 Bennelong Parkway<br>Homebush Bay','SYDNEY','New South Wales','AUSTRALIA','2127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 09:18:23',0,NULL,3,1,11,1,'BJ01712804\r ','au-buy\rRELO002'),(23609,692827829013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','avital_d','david@idr-tech.com','David Avital','Trumpeldor 6','Kfar saba','IL','ISRAEL','44442','972523679100','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 09:22:21',0,NULL,3,1,11,1,'BJ01712808\r ','eastar4\rWLIN014'),(23610,804297117007,170784482004,'100% New Atheros AR5B195 Wireless + Bluetooth Half Mini PCI-E Card',1,'WLIN016',14.24,'au-buy','ballessss','ballesss@gmail.com','Alejandro Ballesta','C Ricardo Marcos 21/6 3ºC','SANTA MARTA DE TORMES (Salamanca)','Castilla y León','SPAIN','37900','655118914','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-14 09:23:46',0,NULL,3,1,11,1,'BJ01712841\r ','au-buy\rWLIN016'),(23611,860228154011,320571842902,'Bracket of half intel 5300 6250 wireless card to pci-e',1,'MOCN001',3.98,'eastar4','piyabute','piyabute@yahoo.com','Piyabute Fuangkhon','125/203 Soi Ramintra 103/3<br>Ramintra Road','Kannayao','Bangkok','THAILAND','10230','(668)1255-1626','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 09:26:01',0,NULL,3,1,11,1,'BJ01712840\r ','eastar4\rMOCN001'),(23612,952014651012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','clarkside1','clarke_james@hotmail.com','James Clake','46 Webbs RD<br>London','London','London','UNITED KINGDOM','sw11 6sf','02079243650','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 09:26:35',0,NULL,3,1,3,1,'RA184501298CN\r ','eastar4uk\rHSJA002\r英标'),(23613,860238502011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','d0nalds','aravan@inbox.lv','Dmitrijs Taukulis','Plavnieku 9-52','Riga','','LATVIA','LV-1021','+37129419082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 10:02:38',0,NULL,3,1,11,1,'BJ01712833 ','eastar4uk\rGLOT001\r客户要分开发\r申报十美金'),(23614,860236651011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','d0nalds','aravan@inbox.lv','Dmitrijs Taukulis','Plavnieku 9-52','Riga','','LATVIA','LV-1021','+37129419082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 10:00:44',0,NULL,3,1,11,1,'BJ01712827 ','eastar4uk\rGLOT001\r客户要分开发\r申报十美金'),(23615,952031181012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','iank2979','joe90flies@ntlworld.com','IAN KAVANAGH','1 overton close','london','London','UNITED KINGDOM','nw100qb','02086210799','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 10:22:40',0,NULL,3,1,3,1,'RA184501602CN ','eastar4uk\rHSJA010\r英标'),(23616,631768227003,130620865343,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',5,'GPS0006',454.95,'cnfaner','m-grizzly','cherkashinm@mail.ru','Mikhail Cherkashinm','Prostornaya 146-41','Ekaterinburg','Sverdlovskaya','RUSSIAN FEDERATION','620076',' 89632729353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 10:33:27',0,NULL,3,1,6,1,'EE667257937CN ','cnfaner\rGPS0006\rNew Super-energy 12000 mAh li-ion Battery for GPS tracker TK102\rGPS0010\r5个\r'),(23617,857247458002,120853616250,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones',1,'HSAL002',12.99,'buysia','sakitjiwaz','gugun_y@yahoo.com','gugun rahman','Gedung Wisma Antara 12th Floor<br>Jalan Medan Merdeka Selatan No.17','Jakarta Pusat','DKI Jakarta','INDONESIA','10110','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-14 10:41:32',0,NULL,3,1,11,1,'BJ01712829 ','buysia\rHSAL002\r欧标\r'),(23618,795776138008,180762062511,'New lady lotus leaves outdoor sun/rain stick Umbrella   6 colors available',1,'UM00002',23.74,'au-buy','yoyotraveller86','starflyer12@hotmail.com','Moya Lythgo','6 Fergie St','Fitzroy North','Victoria','AUSTRALIA','3068','0406048637','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 12:15:37',0,NULL,3,1,11,1,'BJ01712811 ','au-buy\rUM00002\rmaroon'),(23619,860268056011,320786773728,'New iTech Clip II mini Multipoint Bluetooth Headset blue',1,'HSIT004',19.99,'eastar4uk','maheen5994','mmoshefdjou@btinternet.com','mohammed moshefdjou','62  BECKETT ROAD','COULSDON','Surrey','UNITED KINGDOM','CR5  1RZ','01737552490','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 12:17:38',0,NULL,3,1,3,1,'RA184501426CN ','eastar4uk\rHSIT004\r蓝色的'),(23620,952083832012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','objjet','objeturg@gmail.com','EERO KOPLIMETS','VOIMLA TEE 7-17','JARVA-JAANI','JARVAMAA','ESTONIA','73301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 12:59:35',0,NULL,3,1,11,1,'BJ01712832 ','eastar4\rWLAT009'),(23621,952090686012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'eastar4','paulocdj','paulocdj@gmail.com','Paulo Cesar Davet Junior','Rua Brasilpinho, 279<br>Kobrasol','São José','Santa Catarina','BRAZIL','88102-300','(55 48) 9626-8605','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 13:20:52',0,NULL,3,1,3,1,'RA184501275CN ','eastar4\rOTSO004*2'),(23622,692887355013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','jemaknight','angusmckinnon@me.com','Angus McKinnon','30 Clarkson Place','Kenmore HIlls','Queensland','AUSTRALIA','4069','61401853860','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 13:53:08',0,NULL,3,1,11,1,'BJ01712817 ','eastar4\rCACN004'),(23623,692889383013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',2,'WLIN014',37.98,'eastar4','patumsukem','tkcomputer@hotmail.com','TKCOM COMPUTER (THAILAND) CO., LTD. #MR.PATUM SUKEM','189/6 SOI SAPANKWA PRACHARADSAI2 ROAD,<br>PRACHARADSAI2 ROAD,','BANGSUE','BANGKOK','THAILAND','10800','0819396003','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 14:00:57',0,NULL,3,1,11,1,'BJ01712812 ','eastar4\rWLIN014'),(23624,637327724004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',44.99,'cnfaner','itmask','indrek@mk.ee','Indrek Tobre','Kannikese 33-47','Tartu','Tartumaa','ESTONIA','50408','(372) 53494842','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 14:01:48',0,NULL,3,1,3,1,'RA184501390CN ','cnfaner\rGLOT005'),(23625,860321712011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tizedesh','bucsko@gmail.com','Bosznay Gabor','Ondi út 10/B Fszt.2','Szerencs','BAZ','HUNGARY','3900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 14:26:29',0,NULL,3,1,11,1,'BJ01712836 ','eastar4\rHSJA002\r欧标'),(23626,860336134011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','zilvinas1111','zilvinasmazvila@yahoo.com','Bogdan Kustan','S.Staneviciaus 64-24','Vilnius','Vilniaus','LITHUANIA','07113','37060758653','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 15:01:05',0,NULL,3,1,11,1,'BJ01712838 ','eastar4uk\rRELO003'),(23627,812611911001,110819588741,'New Original Logitech MX Revolution Mouse Mat 3M material',3,'SCLO003',11.7,'buysia','hydronaut','apacan@hotmail.com','Andrew Pacan','286 Court Street','Newmarket','ON','CANADA','L3Y 3S5','(905) 259-7933','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-14 15:16:17',0,NULL,3,1,11,1,'BJ01712837 ','buysia\rSCLO003'),(23628,631825994003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','wysandys','wysandys@gmail.com','Sandra Schwartz','PO Box 99<br>205 W Meek Street','Wayne','OK','UNITED STATES','73095-0099','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-14 15:18:52',0,NULL,3,1,1,1,'LK233198394CN ','cnfaner'),(23629,0,220975062443,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',5.99,'eastar4uk','91fordtruck','fabritechstr8axel@hotmail.com','Derek Lorentz','102 E 19th St<br>Apt 102','Minneapolis','MN','UNITED STATES','55403-3763','(651) 399-1598','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 15:35:25',0,NULL,3,1,1,1,'LK233384621CN ','eastar4uk'),(23630,857346401002,120868118790,'New Philips Toothbrush Sonicare Travel Charger base EU PLUG',1,'HBPH003',19.5,'buysia','gericom1414','donaldesmond@yahoo.com','donald desmond','heinrich str 111','darmstadt','','GERMANY','64283','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-14 15:40:30',0,NULL,3,1,11,1,'BJ01712828 ','buysia\rHBPH003'),(23631,804360213007,170748039228,'NEW UNLOCKED ERICSSON F3507G GPS 3G Mini PCI-E with HSDPA UMTS',1,'WWOT001',38.76,'au-buy','woods_stuart1982','woodss_82@bigpond.com','Stuart Woods','1 Perceval Street','Sunbury','Victoria','AUSTRALIA','3429','0397406157','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 15:50:48',0,NULL,3,1,3,1,'RA184501633CN ','au-buy\rWWOT001'),(23632,952156023012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','radostev6868','radostev68@mail.ru','Michail Radoctev','Marshala Zaharova dom12 kor1 kv90','Sankt-Peterburg','Russia','RUSSIAN FEDERATION','198328',' 89216485268','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 16:01:06',0,NULL,3,1,11,1,'BJ01712813 ','eastar4\rUM00034'),(23633,952183152012,220806889802,'New Japan Rainbow Sun/Rain stick Umbrella w/24 skeleton',1,'UM00008',27.99,'eastar4','dizarika','dizarika1@mail.ru','Yekaterina Peshkova','52 Ermekov ST #140','Karaganda','','KAZAKHSTAN','100009','7(7212)475326','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 16:57:52',0,NULL,3,1,11,1,'BJ01712814 ','eastar4\rUM00008'),(23634,692960511013,230507838291,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',8.99,'eastar4','the_real_video','vmotiu@msn.com','ovidiu motiu','p.o. box 593','tieton','WA','UNITED STATES','98947','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 17:57:38',0,NULL,3,1,1,1,'LK233365097CN ','eastar4'),(23635,952257772012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',87.99,'eastar4','apoelfclambas','pambosg11@yahoo.gr','PANAYIOTA AVRAAMIDOU','LIMNOU 17A\', MOUTAGIAKA','LIMASSOL','cyprus','CYPRUS','4527','0035796519518','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 19:08:34',0,NULL,3,1,3,1,'RA184501372CN ','eastar4\rGLOT005*2\r黑色的'),(23636,952262892012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',68.99,'eastar4','scot_can','jmeldrum@bellsouth.net','JOHN MELDRUM','19644-72A AVE','LANGLEY','BC','CANADA','V2Y3E5','(604) 530-8298','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 19:17:32',0,NULL,3,1,3,1,'RA184501338CN ','eastar4\rPSGL001'),(23637,952275928012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','dkyabe2012','jesper@small-fish.dk','Jesper Jensen','Toldbodgade 55B<br>1353 Copenhagen K','Copenhagen','Denmark','DENMARK','DK','(045)40910164','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 19:36:16',0,NULL,3,1,11,1,'BJ01712826 ','eastar4\rMOAP001'),(23638,812730794001,110837938251,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'buysia','ale!x','alpargatamutante@hotmail.com','Aleix Trepat Lozano','Padilla 245, 3R 2A','Barcelona','Cataluña','SPAIN','08013','647908287','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-14 19:36:57',0,NULL,3,1,11,1,'BJ01712816 ','buysia\rUM00053'),(23639,637520734004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.8,'cnfaner','bastelwalter','bastelwalter@arcor.de','Walter Kitzinger','Berliner Str.128','Bruchsal','','GERMANY','76646','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 20:41:51',0,NULL,3,1,3,1,'RA184501505CN ','cnfaner\rWLAP008'),(23640,693033074013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','georg77cz','georg77@gmail.com','Jiri Orsag','Jaromirova 18','Praha 2','','CZECH REPUBLIC','128 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 20:46:25',0,NULL,3,1,11,1,'BJ01712825 ','eastar4\rCACN004'),(23641,952335872012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'eastar4','vennierick','rdavis51@amtelecom.net','rick davis','64 cedar cresent','providence bay','ON','CANADA','p0p1t0','(705) 377-4676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 21:10:46',0,NULL,3,1,3,1,'RA184501267CN ','eastar4\rOTSO004*2'),(23642,637565781004,140667905525,'New Replaceable Shell for logitech Mouse MX518',1,'SHLO004',12.99,'cnfaner','palletguy80','palletguy@sbcglobal.net','Steve Martins','3129 N Valley St','Visalia','CA','UNITED STATES','93291-8646','(559) 623-5411','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-14 22:51:59',0,NULL,3,1,1,1,'LK233198173CN ','cnfaner'),(23643,952404345012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','der_wedsor','lukas.wede@googlemail.com','Lukas Wede','Wittstocker Straße 19','Berlin','','GERMANY','10553','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 23:24:35',0,NULL,3,1,11,1,'BJ01712831 ','eastar4\rBTAC2015\racer 6pin1.25 23cm'),(23644,631995033003,130554588383,'NEW Logitech battery 890 880 950mA',1,'BALO001',10.9,'cnfaner','scottbros828','scottbrosroofing@gmail.com','chuck john scott','1313 Sylvania Ave','Riverton','NJ','UNITED STATES','08077-2714','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-14 23:28:34',0,NULL,3,1,1,1,'LK233243915CN ','cnfaner'),(23645,800939346007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',49.39,'au-buy','tanya9060','tanya33375@hotmail.com','Tanya Jacobsen','no. 15 , Mayfair Street<br>Currumbin Waters','Gold Coast','Queensland','AUSTRALIA','4223','0755350368','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 23:40:49',0,NULL,3,1,3,1,'RA184501430CN ','au-buy\rLGFI001'),(23646,693102708013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',2,'GPS0006',119.98,'eastar4','claudiabarajas','claudiabarajas7@hotmail.com','Claudia Barajas','414 2nd ST PMB 75114','calexico','CA','UNITED STATES','92231','(760) 701-2440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 00:36:00',0,NULL,3,1,1,1,'LK233365477CN ','eastar4'),(23647,952429427012,220748684600,'New Grohe MultiFunction hand Shower Head+Grohe hose 59\"',1,'OTGR001+OTGR002',20.9,'eastar4uk','aneeshnath','aneeshtaranath@hotmail.com','aneesh taranath','42 B Greenside road','Croydon,Greaterr London','London','UNITED KINGDOM','CR0 3PL','07960623762','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 00:47:31',0,NULL,3,1,3,1,'RA184501559CN ','eastar4uk\rOTGR001+OTGR002'),(23648,693107696013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','mbpenz','mbpenz@comcast.net','Mark Penzenstadler','9632 Washburn Ave S','bloomington','MN','UNITED STATES','55431-2461','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 00:59:29',0,NULL,3,1,1,1,'LK233370242CN ','eastar4'),(23649,804686176007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',254.59,'au-buy','henriinsydney','perscomp@optusnet.com.au','Henri de Gorter','22 Yanderra Grove','Cherrybrook','New South Wales','AUSTRALIA','2126','0299450385','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 01:30:43',0,NULL,3,1,4,1,'YW870147242CN ','au-buy\rPSGL001*4'),(23650,951378852012,220917856643,'2 pairs New in Box Genuine  LG 3D Active Shutter Glasses AG-S110',1,'LGGL002*2',225.99,'eastar4','skinutbyw','skinutbrent@yahoo.ca','Brent Weitzel','407 St.Andrews Cres','Stony Plain','AB','CANADA','T7Z 1K5','(780) 919-2307','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 01:33:57',0,NULL,3,1,3,1,'RA184501655CN ','eastar4\rLGGL002*2'),(23651,8881331776659414,111,'10 pcs AUI Ethernet 10Base-T RJ45 CentreCOM 210TS - ',1,'TRTS001*10',76.99,'aliexpress','1007389977','1@1.com','Konstantin Smorodinov','Mosfilmovskaya 24-46 ','Moscow','Moscow','RUSSIAN FEDERATION','119285','+7 903 1398766',NULL,NULL,NULL,'2012-03-15 01:57:39',0,NULL,3,1,3,1,'RA184501718CN  ','TRTS001*10 已发货'),(23652,637608965004,140516171775,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',10,'WLAP008',198,'cnfaner','artshaper','osx86@sixflow.net','won-taek seo','Office 201, 39-6, Baekjegobun-ro 27-gil, Songpa-gu','seoul','','KOREA,REPUBLIC OF','138-837','82-10-7312-2154','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 02:04:21',0,NULL,3,1,3,1,'RA184501593CN','cnfaner\rWLAP008\r确认已付款，但没有收到付款信'),(23653,8881331777078214,111,'New HP MCE Media Center Remote Control big+ IR RECEVE - ',1,'OTHP004',22.99,'aliexpress','1007391385','r.heringer.it@gmail.com','	Rodrigo Heringer Mendonca','Rua da Bahia, 2277 (CAMG, 5 Andar - Posto 362)','	Belo Horizonte','MG','BRAZIL','30160012','25316248/+55 31 87480959',NULL,NULL,NULL,'2012-03-15 02:04:38',0,NULL,3,1,3,1,'RA184503373CN ','OTHP004 已发货'),(23654,8881331777218332,111,'Free shipping & Tracking # - Lowrance Waterproof IFinder Hunt Handheld GPS + WAAS Receiver - ',1,'GPS0011',76.99,'aliexpress','1007398750','tower-marketing@yandex.ru','Sergey Karpenko','yl. ZARUBINA 163, kv. 3, ','Saratov','Saratovskaya oblast','RUSSIAN FEDERATION','410005','+7 927 9100995',NULL,NULL,NULL,'2012-03-15 02:06:58',0,NULL,3,1,3,1,'RA184503360CN ','GPS0011 已发货'),(23655,8881331777239995,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Sarah Kaja','3205 DESCANSO DR APT 405','LOS ANGELES,','CA','UNITED STATES','90026-6201','',NULL,NULL,NULL,'2012-03-15 02:07:19',0,NULL,3,1,3,1,'RA184501341CN‘ ','eastar4\r直接打款 \rMOAP001'),(23656,8881331777431476,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Tim Stoesz','2806 32nd Street','San Diego,',' CA','UNITED STATES',' 92104','',NULL,NULL,NULL,'2012-03-15 02:10:31',0,NULL,3,1,3,1,'RA184501315CN ','eastar4\r直接打款 \rMOAP001 '),(23657,8881331777850583,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Cameron Kipp','2912 HELENA ST','HOUSTON,','TX','UNITED STATES','77006-3304','',NULL,NULL,NULL,'2012-03-15 02:17:30',0,NULL,3,1,3,1,'RA184501576CN ','eastar4\r直接打款 \rMOAP001  '),(23658,8881331778018742,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com',' Kristen Staggs','580 Manzanita Ave Suite 9','Chico,','CA','UNITED STATES',' 95926','',NULL,NULL,NULL,'2012-03-15 02:20:18',0,NULL,3,1,3,1,'RA184501457CN ','eastar4\r直接打款 \rMOAP001   '),(23659,8881331778171086,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Rebecca Jennings','1318 S. Beverly Glen Bl #1','Los Angeles,','CA','UNITED STATES','90024','',NULL,NULL,NULL,'2012-03-15 02:22:51',0,NULL,3,1,3,1,'RA184501386CN ','eastar4\r直接打款 \rMOAP001    '),(23660,8881331778456131,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',3,'MOAP001',78,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Richard D. Kirshberg','3547 Beverly Ridge Dr','Sherman Oaks,',' CA','UNITED STATES','91423','',NULL,NULL,NULL,'2012-03-15 02:27:36',0,NULL,3,1,3,1,'RA184501465CN ','eastar4\r直接打款 \rMOAP001     '),(23661,8881331778616882,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Steven Anderson','3736 North Bay Dr','Racine,',' WI','UNITED STATES','53402','',NULL,NULL,NULL,'2012-03-15 02:30:16',0,NULL,3,1,3,1,'RA184501369CN ',' eastar4\r直接打款 \rMOAP001    '),(23662,8881331778761429,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Jorge Pro','14415 SW 88TH ST APT G109','Miami,','FL','UNITED STATES','33186','',NULL,NULL,NULL,'2012-03-15 02:32:41',0,NULL,3,1,3,1,'RA184501580CN ',' eastar4\r直接打款 \rMOAP001     '),(23663,8881331778890508,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Edward Woznicki','5821 Jennifer Cir','Anchorage,',' AK','UNITED STATES','99504-4345','',NULL,NULL,NULL,'2012-03-15 02:34:50',0,NULL,3,1,3,1,'RA184501545CN ','eastar4\r直接打款 \rMOAP001    '),(23664,8881331779050397,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','lily rodriguez 2-4379','8400 NW 25TH Street Suite 110','Doral,',' FL','UNITED STATES',' 33122','',NULL,NULL,NULL,'2012-03-15 02:37:30',0,NULL,3,1,3,1,'RA184501355CN ','eastar4\r直接打款 \rMOAP001   '),(23665,8881331779189984,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Jeremy Clough','100 MARKET ST UNIT 203','PORTSMOUTH,','NH','UNITED STATES','03801-3760','',NULL,NULL,NULL,'2012-03-15 02:39:49',0,NULL,3,1,3,1,'RA184501562CN ','eastar4\r直接打款 \rMOAP001    '),(23666,796134052008,180827876552,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB SOUND CARD',1,'OTSB001',22.99,'au-buy','heaven251182','s_t_a_l_k_e_r82@mail.ru','Vladimir Podsvirov','5 The Hollies<br>Sidmouth Street','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU5 2JU','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 03:12:37',0,NULL,3,1,11,1,'BJ01712809 ','au-buy\rOTSB001'),(23667,8881331781865577,111,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','snepe23','snepe2_eyn6899mit@members.ebay.com','Aliyeva Saida','Yusif Imanov str, 23A','Binaqadi','','BILECERI','1117','',NULL,NULL,NULL,'2012-03-15 03:24:25',0,NULL,3,1,3,1,'RA184501443CN ','cnfaner\rOT00002 \r正确地址\rAliyeva Saida\rYusif Imanov-street, 23A\rBaku 1117\rAzerbaijan\r'),(23668,804719940007,170730545430,'Genuine Logitech Harmony 515 Universal Remote Control',1,'RCLO004',39.99,'au-buy','lnit5291','lyndon.nitschke@gmail.com','lyndon nitschke','2/3 little oxford street','collingwood','Victoria','AUSTRALIA','3066','0410850969','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 03:27:07',0,NULL,3,1,3,1,'RA184501514CN ','au-buy\rRCLO004'),(23669,952485599012,220675199421,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',16.7,'eastar4','kajeandra','shadowking48@gmail.com','Kajeandra Ravichandiran','114 Combe Ave','North York','ON','CANADA','M3H4J9','(416) 844-6474','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 03:29:22',0,NULL,3,1,11,1,'BJ01712835 ','eastar4\rOTCN004*10'),(23670,0,220974160087,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',24.95,'eastar4uk','aziat09','ilanb100@gmail.com','ilan binness','4 ben zvi street','givatayim','','ISRAEL','53632','92-50-9716984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 03:45:34',0,NULL,3,1,3,1,'RA184501491CN ','eastar4uk\rHBPH007\r客户打了三英镑'),(23684,857696494002,120853616753,'New in box Logitech MX1000 MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',66,'buysia','catmanix','psybercase@newwavecomm.net','Larry J Case','17363 James Dr','Dexter','MO','UNITED STATES','63841-8232','(573) 624-4159','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 07:57:32',0,NULL,3,1,1,1,'LK233636254CN ','buysia'),(23671,952505342012,220815929764,'NEW CAB-2626-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 2T',2,'CASS001',12.85,'eastar4uk','333cmb','c.beckett@talk21.com','C. Beckett','57 Swanlow Lane','Winsford','Cheshire','UNITED KINGDOM','CW7 1JD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 04:52:09',0,NULL,3,1,3,1,'RA184501324CN ','eastar4uk\rCASS001+ANCN001+ANTY001\r再发一个Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna\r一个3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530\r\r'),(23672,0,220974194086,'NEW in box AuthenTec BioReader slide sensor base',1,'OTAU001',2.99,'eastar4uk','333pjb','p.beckett@talk21.com','Patrick Beckett','57 Swanlow Lane','Winsford','Cheshire','UNITED KINGDOM','CW7 1JD','01606552209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 05:09:59',0,NULL,3,1,3,1,'RA184501474CN ','eastar4uk\rOTAU001\rAuthenTec 指纹仪 指纹加密识别器'),(23673,804742533007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','becsaddler','becnbenbarnes@hotmail.com','Bec Saddler','7<br>Southbank Road','Trevallyn','Tasmania','AUSTRALIA','7250','0419992579','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 05:26:18',0,NULL,3,1,11,1,'BJ01712815 ','au-buy\rUM00040'),(23674,693161141013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','habibmustafa2010','mustafa5858@live.de','saban yildiz','adolf-englerstr1','duisburg','','GERMANY','47166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 05:57:47',0,NULL,3,1,3,1,'RA184501284CN ','eastar4\rLGAD001'),(23675,637646411004,140676374154,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'cnfaner','am.giles75','am.giles75@ntlworld.com','Andrew Giles','Sibamas<br>Newbolt Road','Portsmouth','Hampshire','UNITED KINGDOM','PO6 4NS','07905104053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 06:07:07',0,NULL,3,1,3,1,'RA184501412CN ','cnfaner\rHBPH007'),(23676,0,320865555568,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',42,'eastar4uk','*trader60','sean.hamidi@yahoo.com','S Hamidi','27 Avignon','Newport Coast','CA','UNITED STATES','92657-1010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 06:19:29',0,NULL,3,1,1,1,'LK233560153CN ','eastar4uk'),(23677,796171256008,180810778773,'New in box 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001',41.99,'au-buy','aidanramsayaidan','aidan.ramsay@gmail.com','Aidan Ramsay','8-25/29 Alfred St','Ramsgate Beach','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 06:32:50',0,NULL,3,1,3,1,'RA184501488CN ','au-buy\rGLOT001'),(23678,693170044013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',44.99,'eastar4','josephyin2011','ykd60@live.cn','keding yin','1730 n cardinal rd','azle','TX','UNITED STATES','76020-6516','(469) 328-5597','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 06:41:56',0,NULL,3,1,1,1,'LK233580113CN ','eastar4'),(23679,952527016012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',2,'TRMX003',19.98,'eastar4','roziali58','rozita2001as2000@yahoo.com','rozita Askari','5993 E Pacific Coast Hwy<br>Apt 6','Long Beach','CA','UNITED STATES','90803-4965','(714) 732-0730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 06:48:24',0,NULL,3,1,1,1,'LK233581961CN ','eastar4'),(23680,812947091001,110834780805,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',3.99,'buysia','srii3019','sorenriise@hotmail.com','soren riise','1073 broadway ave','san jose','CA','UNITED STATES','95125','(408) 334-4850','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 06:49:43',0,NULL,3,1,1,1,'LK233653822CN ','buysia'),(23681,632070577003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','ilichtmaher','igor@limsolutions.com','Igor Lichtmaher','16352 Spartan Cir','Huntington Beach','CA','UNITED STATES','92649-2526','(714) 875-2134','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-15 06:55:42',0,NULL,3,1,1,1,'LK233580626CN ','cnfaner'),(23682,952531236012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',24.99,'eastar4','ercanskose01','ercanskose@gmail.com','ERCAN SARIKÖSE','MUHITTIN USTUNDAG CD. NO:23 KOSUYOLU<br>RESPITEK SAGLIK URUNLERI','ISTANBUL','KADIKOY','TURKEY','34718','5432230101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 07:12:17',0,NULL,3,1,11,1,'BJ01712830 ','eastar4\rHSJA001'),(23683,0,220974189068,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',28.6,'eastar4uk','jj_72','jovanjankovic@hotmail.com','Jovan Jankovic','Furutorpsgatan 56A','Helsingborg','SKANE','SWEDEN','25227','+46736969899','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 07:31:33',0,NULL,3,1,3,1,'RA184501531CN ','eastar4uk\rLGAD001'),(23685,952543378012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','jgbert','jg_bertrand@hotmail.com','Jean-Gabriel Bertrand','Résidence Le St-Saens Bat 5A','HYERES-LES-PALMIERS','Provence-Alpes-Côte d\'Azur','FRANCE','83400','04.94.38.64.26','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:05:05',0,NULL,3,1,11,1,'BJ01712843 ','eastar4\rWLAT009'),(23686,0,220974160067,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',20.63,'eastar4uk','andy58ie','andy@seo-studio.co.uk','andy horne','76 clark rd','ditchingham','Norfolk','UNITED KINGDOM','nr352qq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 08:06:19',0,NULL,3,1,3,1,'RA184501620CN ','eastar4uk\rLGRM001'),(23687,860721960011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','ku2kov','dkutukov@mail.ru','Dmitry Kutukov','prospekt Andropova 29-2-124','Moscow','Russia','RUSSIAN FEDERATION','115487','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:07:58',0,NULL,3,1,11,1,'BJ01712839 ','eastar4\rWLAT003'),(23688,860732131011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'eastar4','derfla3101980','derfla420@yahoo.com','alfred aguila','22 Shadow Grove Ln','Holbrook','NY','UNITED STATES','11741-5610','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-15 08:50:53',0,NULL,3,1,1,1,'LK233650755CN ','eastar4'),(23689,952555533012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',39.99,'eastar4','murat_orh','murat.orhan@gefco.net','murat orhan','onyedi agustos caddesi onyedi agustos mahallesi Gefco arac lolistik merkezi kosekoy','kocaeli','kosekoy','TURKEY','41100',' 9005325767455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:53:16',0,NULL,3,1,11,1,'BJ01712821 ','eastar4\rGLOT001'),(23690,952562395012,220748684624,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',10.49,'eastar4uk','neos8','neos88@tpg.com.au','Ie Kok Soen','GPO BOX 3248','CANBERRA','Australian Capital Territory','AUSTRALIA','2601','61401144841','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 09:20:39',0,NULL,3,1,11,1,'BJ01715314\r ','eastar4uk\rOTGR002'),(23691,796212979008,180781265388,'New Grohe handheld Shower Head big water output w/Massage function',1,'OTGR005',22.9,'au-buy','tiffany243','trio@adam.com.au','Ben Trio','26 Parcoola Avenue','Hope Valley','South Australia','AUSTRALIA','5090','0883959252','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 09:46:20',0,NULL,3,1,11,1,'BJ01715309\r ','au-buy\rOTGR005'),(23692,0,170802050069,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',33.56,'au-buy','gbbgreen','bjoern_ralfs@web.de','Björn Ralfs','Südergraben 39','Flensburg','','GERMANY','24937','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 09:57:39',0,NULL,3,1,11,1,'BJ01715313\r ','au-buy\rLGAD001'),(23693,693203093013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',2,'WLAP008',39.76,'eastar4','jeffreyr101','jeffreyr@aol.com','Jeffrey Ray','130 Express St','Dallas','TX','UNITED STATES','75207','(214) 741-6660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 10:06:02',0,NULL,3,1,1,1,'LK233956179CN\r ','eastar4'),(23694,860751603011,320820766166,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',14.99,'eastar4uk','noo_way','j198013@hotmail.com','DAVID MEISEN','964 Martinique Dr','CHULA VISTA','CA','UNITED STATES','91913-3124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 10:09:27',0,NULL,3,1,1,1,'LK233994897CN\r ','eastar4uk'),(23695,693208174013,230452696985,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET HS 4W',1,'HSNO022',14.98,'eastar4','navdeep108','singhnavdeep108@gmail.com','Navdeep Singh','2/9, Ostia Court','Thomastown','Victoria','AUSTRALIA','3074','0478185025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 10:33:14',0,NULL,3,1,11,1,'BJ01713528\r ','eastar4\rHSNO022\r澳标'),(23696,0,220974194206,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.27,'eastar4uk','trickymedic864','trickymedic@yahoo.com','Rick waldrop','119 Taylor Rd','union','SC','UNITED STATES','29379-8567','(864) 424-9388','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 11:14:09',0,NULL,3,1,1,1,'LK233974376CN\r ','eastar4uk\rPOLO001'),(23697,796237350008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','rowey757','roscoe757@hotmail.com','Ross Rowe','19 Marriott Drive','Keysborough','Victoria','AUSTRALIA','3173','0397986610','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 11:17:49',0,NULL,3,1,11,1,'BJ01713530\r ','au-buy\rBALO001'),(23698,860781659011,320730551325,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E card',1,'WLIN016',12.59,'eastar4uk','hhalukkulak','halukkulak@gmail.com','Hüseyin Haluk Kulak','Cigdem Mahallesi 1583.Sokak<br>No:3/14 Sedir Sitesi','Ankara','Cankaya','TURKEY','06520','+90 532 778 97 61','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 11:53:39',0,NULL,3,1,11,1,'BJ01713534\r ','eastar4uk\rWLIN016'),(23699,0,180840049314,'100% New Genuine Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',3.99,'au-buy','rl170457','rl1704@bigpond.com','Ray Lennon','11 Everest Avenue','Morphettville','South Australia','AUSTRALIA','5043','0417831120','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 11:54:25',0,NULL,3,0,11,1,'BJ01713535\r ','au-buy\rWLAT008'),(23700,693228496013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','krknro','kfs@centurytel.net','Kelli Santhuff','208 E Jefferson St','Potosi','MO','UNITED STATES','63664-1913','(573) 438-3296','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 12:13:54',0,NULL,3,1,1,1,'LK233954924CN\r ','eastar4\r绿色的'),(23701,637723558004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','lutskymichael','lutsky.michael@gmail.com','Lutsky Michael','Shlomo Cohen 9/1','Ashkelon','','ISRAEL','78651','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 13:27:56',0,NULL,3,1,3,1,'RA184501995CN\r ','cnfaner\rLGAD001'),(23702,952642736012,220815932341,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',3.39,'eastar4uk','iain.kyle17','ik258@bath.ac.uk','Iain Kyle','Westwood Accommodation, Derhill Terrace D5.07<br>University of Bath','Bath','Somerset','UNITED KINGDOM','BA2 7JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 13:33:15',0,NULL,3,1,3,1,'RA184501987CN ','eastar4uk\rSCLO002'),(23703,804864664007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',254.59,'au-buy','chrispullen','chrispullen48@live.com.au','christine pullen','12 karrawa gdns','port kennedy','Western Australia','AUSTRALIA','6172','0895246293','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 13:45:19',0,NULL,3,1,4,1,'YW870147286CN\r ','au-buy\rPSGL001*4'),(23704,0,220975062471,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.06,'eastar4uk','rainnybon','imgoodmerchant@hotmail.com','Stefan Solow','Borgerstraat 141','Amsterdam','','NETHERLANDS','1053RA','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 13:48:19',0,NULL,3,1,11,1,'BJ01713532\r ','eastar4uk\rPOLO001'),(23705,813063553001,110808693295,'New Jabra BT250V FreeSpeak Bluetooth Headset  BT 250V',1,'HSJA001',23.9,'buysia','marleyrebel2011','johndoebbler84@gmail.com','John Doebbler','1319 Cavern Trl','San Antonio','TX','UNITED STATES','78245-1440','(210) 618-4140','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 14:27:39',0,NULL,3,1,1,1,'LK233939992CN\r ','buysia'),(23706,0,180840048810,'New ATA33 40 Pin to 40 Pin 3.5\" male to female Desktop IDE Hard Drive Cable 30cm',1,'OTCN002',0.99,'au-buy','robinsonto','tonyrobinson@waitrose.com','Mr A S Robinson','2 St Christophers Drive<br>Oundle','Peterborough','Cambridgeshire','UNITED KINGDOM','PE8 4HU','01832272333','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 14:44:08',0,NULL,3,1,11,1,'BJ01713531\r ','au-buy\rOTCN003\rSKU号错了'),(23707,952682614012,220748684577,'New Grohe Multi Function hand Shower Head no water pipe',1,'OTGR001',10.99,'eastar4uk','donc223','donsam@bigpond.net.au','Don Cameron','29 Haven Close','Norman Gardens','Queensland','AUSTRALIA','4701','0749266916','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 15:17:14',0,NULL,3,1,11,1,' BJ01713529\r','eastar4uk\rOTGR001'),(23708,860854621011,320740490162,'2 pair3D Active Shutter TV Glasses 4 Samsung SSG-2100AB',1,'GLOT001*2',77.99,'eastar4','xycomguy','pderbyshire@derbyshire.ca','Paul Derbyshire','121 Erie Ave South','Fisherville','ON','CANADA','N0A1G0','(905) 779-0754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 15:26:16',0,NULL,3,1,3,1,'RA184501956CN\r ','eastar4\rGLOT001*2'),(23709,804903820007,170751822504,'4 pairs of FUTURECINEMA DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005*4',167.99,'au-buy','fatcowvcd','jsharple@optushome.com.au','jeanette l. sharples','9 wren  crt','Werribee','Victoria','AUSTRALIA','3030','0397423638','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 15:35:19',0,NULL,3,1,4,1,'YW870147290CN\r ','au-buy\rGLOT005*4'),(23710,693277486013,230561466203,'NEW UNLOCKED ERICSSON F3507G 3G GPS  DELL 5530+antenna',1,'WWOT001+ANCN001',44.8,'eastar4','kkbordim','kbordim@hotmail.com','Katiano Bordim','Rua Tocantins, 4907 - centro','Rolim de Moura','Rondonia','BRAZIL','76940000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 15:45:31',0,NULL,3,1,3,1,'RA184500010CN\r ','eastar4\rWWOT001+ANCN001'),(23711,952708577012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',39.99,'eastar4','izatjames','izatj@hotmail.com','Izat James','Stolpehoj 52. 1. tv','Gentofte','','DENMARK','2820','004531955195','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 16:22:20',0,NULL,3,1,11,1,'BJ01713527\r ','eastar4\rGLOT001'),(23712,952714307012,220915146749,'New Auto On Gentelman Cat Rain/Sun J-handle Umbrella w/14 Skeleton',1,'UM00050',24.99,'eastar4','miron26-ru','atc_raduga@mail.ru','Владимир Мироненко','улица Гагарина 26 квартира 27','Невинномысск','Ставропольский край','RUSSIAN FEDERATION','357100',' 89286331088','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 16:33:56',0,NULL,3,1,11,1,'BJ01713557\r ','eastar4\rUM00050'),(23713,952714763012,220966989378,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 plus AC adapter',1,'GPS0010+ADPT001',23.99,'eastar4uk','lvagale','vagtsuk@hotmail.com','EVAGGELOS TSOUKIS','IPPOKRATOUS 38','MYRINA','','GREECE','81400','00302254025425','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 16:35:27',0,NULL,3,1,11,1,'BJ01714158 ','eastar4uk\rGPS0010+ADPT001'),(23714,860880685011,320730086313,'NEW CAB-6060-3FT BACK-TO-BACK CABLE FOR WIC-1T TO 1T',3,'CASS003',20.67,'eastar4uk','pukkasweetwicked','fitbin@hotmail.com','Paul Wright','144 Kingsground','Eltham','London','UNITED KINGDOM','SE95EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 16:35:43',0,NULL,3,1,3,1,'RA184501868CN\r ','eastar4uk\rCASS003'),(23715,813093366001,110819588741,'New Original Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',3.9,'buysia','tpfareavip','thiagopimenta@live.com','Thiago Pimenta Fernandes','R. Cicero Ferreira 147 ap.201<br>Serra','Belo horizonte','Minas Gerais','BRAZIL','30220040','(031) 923-3131 ext.: 0','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 16:40:55',0,NULL,3,1,11,1,'BJ01713553\r ','buysia\rSCLO003'),(23716,860889656011,320730549128,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',1,'GLOT001',25.99,'eastar4uk','spbnjy123','dropbucket@hotmail.co.uk','Stephen Boyle','39 Skylands Rise<br>Torhead Farm','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 8TS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 16:55:10',0,NULL,3,1,3,1,'RA184501854CN\r ','eastar4uk\rGLOT001'),(23717,860889630011,320786773805,'New Jabra JX10 Series II 2 Wireless Bluetooth headset Red',1,'HSJA013',12.99,'eastar4uk','derekhab','derek.habberfield@koolgang.co.uk','Derek Habberfield','12 Ffordd Taliesin','Swansea','Swansea','UNITED KINGDOM','SA27DF','01792520375','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 16:55:31',0,NULL,3,1,3,1,'RAm84501871CN ','eastar4uk\rHSJA013\r英标'),(23718,950990308012,220901458172,'New SAMSUNG Magic Water Filter WSF-100 for Samsung Refrigerator',1,'SAFI002',33.99,'eastar4uk','whiskyloverdavid','davidwalker459@gmail.com','david walker','43 moss avenue<br>ashton','preston','Lancashire','UNITED KINGDOM','pr21sh','01772732904','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 17:19:27',0,NULL,3,1,3,1,'RA184502007CN\r ','eastar4uk\rSAFI002'),(23719,860905249011,320730086228,'NEW CAB-2660-3FT BACK-TO-BACK CABLE FOR WIC-2T TO 1T',2,'CASS002',12.58,'eastar4uk','lyndseybrown548','lbrown548@gmail.com','lyndsey Brown','105 Flat 0/2 Skisa Street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G23 5DA','07861739759','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 17:29:14',0,NULL,3,1,3,1,'RA184501837CN\r ','eastar4uk\rCASS002'),(23720,0,220974193915,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.01,'eastar4uk','gooselooseagain','gooseistooloose@hotmail.co.uk','bobby hales','52 leigh road<br>east ham','london','London','UNITED KINGDOM','e6 2as','02074748932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 17:51:54',0,NULL,3,1,3,1,'RA184501973CN','eastar4uk\rANCN001'),(23721,860941497011,320826634884,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',13.99,'eastar4uk','24383558','paulhinch@hotmail.com','paul hinch','28 Dumfries avenue<br>Crownhill','Plymouth','Devon','UNITED KINGDOM','PL5 3SU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 18:41:47',0,NULL,3,1,3,1,'RA184501885CN\r ','eastar4uk\rOTGR005'),(23722,952445905012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','lazarossemos','aekpenhaek25@hotmail.com','PANAGIOTIS ZAVITSANOS','ETHNIKIS ANTISTASEOS 45(KARDAMITSIA)','GR','','GREECE','45500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:12:06',0,NULL,3,1,3,1,'RA184501911CN\r ','eastar4\rPSGL001*2\r'),(23723,693360128013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',67.99,'eastar4','gigio-boy','building@veloxmail.com.br','GIOVANI RIBEIRO CALDELLAS','AVENIDA RIO BRANCO, 1266, APT 301, PRAIA DO CANTO','VITÓRIA','ESPÍRITO SANTO','BRAZIL','29055-642','02799621971','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:29:47',0,NULL,3,1,3,1,'RA184501942CN\r ','eastar4\rMOSA004'),(23724,952790712012,220886923190,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',17.95,'eastar4uk','sk_weya','weyainfo@gmail.com','Veronika Olesnanikova','Trnavska 1358/18','Zilina','Slovakia','SLOVAK REPUBLIC','01008','+421907388798','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 19:13:52',0,NULL,3,1,11,1,'BJ01713559\r ','eastar4uk\rUM00008'),(23725,952815765012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','mikirrin2','mikesoler@hotmail.es','Sergio Espinosa','Luis Vives,1','Beniarjo','Comunidad Valenciana','SPAIN','46722','962800452','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:40:33',0,NULL,3,1,11,1,'BJ01713556\r ','eastar4\rBTAC2022\racer 8pin1.00 15cm'),(23726,952829725012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','lmcc4737','lmcclint@czn.com','MICHAEL MCCLINTON','9308 WINDING BROOK WAY','ELK GROVE','CA','UNITED STATES','95624-4091','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 20:01:02',0,NULL,3,1,1,1,'LK233977956CN\r ','eastar4'),(23727,0,170802050530,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',9.99,'au-buy','rbrown3972','signaturerobertjeffreybrown@yahoo.com.au','Robert Brown','33 Kullaroo Rd','Summerland Point','New South Wales','AUSTRALIA','2259','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 20:21:42',0,NULL,3,1,11,1,'BJ01713558\r ','au-buy\rUM00001\rpink'),(23728,952846621012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','bigeon246','ianhighpeak@yahoo.co.uk','ian comer','2 marsh lane','new mills','Derbyshire','UNITED KINGDOM','sk224pn','01663746874','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 20:23:56',0,NULL,3,1,3,1,'RA184501845CN\r ','eastar4uk\rHSJA002\r英标'),(23729,813248282001,110827288137,'New Logitech Cradle L-LG7 for Harmony remote 880 890 + US AC adapter',1,'CRLO001+POLO001',16.99,'buysia','deathcomesforus','a_light_within_the_darkness@yahoo.com.au','Chris Stevenson','28/10 Belgrave rd','Indooroopilly','Queensland','AUSTRALIA','4068','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 21:16:36',0,NULL,3,1,11,1,'BJ01713533\r ','buysia\rCRLO001+POLO001'),(23730,632286916003,130626402767,'New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001',39.5,'cnfaner','mbendasoli','marcelobendasoli@terra.com.br','Marcelo Bendasoli Silva','Aluisio Azevedo, 385 Apto 162','São Paulo','São Paulo','BRAZIL','02021030','+55 11 31506016','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:17:23',0,NULL,3,1,3,1,'RA184501770CN\r ','cnfaner\rGLOT001'),(23731,861041983011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',38.99,'eastar4','pilcomt272010','pilcomt27@hotmail.com','LUIS ALBERTO SAAVEDRA','5470 W Military Dr<br>Apt 516','SAN ANTONIO','TX','UNITED STATES','78242-1249','(210) 789-4675','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 21:27:53',0,NULL,3,1,1,1,'LK234031515CN\r ','eastar4'),(23732,861043313011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','bagratt','bagrat_tunyan@ksg06.harvard.edu','Bagrat Tunyan','27 Holmdale Road<br>Flat 2','London','London','UNITED KINGDOM','NW6 1BJ','07823335556','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 21:31:19',0,NULL,3,1,3,1,'RA184501939CN\r ','eastar4uk\rOTSO004'),(23733,637883874004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','piotr8432','aipid@hotmail.com','Grzegorz Leś','Korczaka 47/12','Kłodzko','dolnośląskie','POLAND','57-300','880116750','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:47:22',0,NULL,3,1,3,1,'RA184501960CN\r ','cnfaner\rLGAD001'),(23734,637889040004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',46.9,'cnfaner','ricardofranzese','ricardofran@bol.com.br','Ricardo Franzese','Rua oswaldo cochrane 94/82','Santos','São Paulo','BRAZIL','11040-110','55-13-33223598','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 22:00:41',0,NULL,3,1,3,1,'RA184501908CN','cnfaner\rLGFI001'),(23735,637902254004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',1,'MOMI004',13.6,'cnfaner','nremt_55','wallydabulbul@gmail.com','dan carpenter','330 Coosaw Way<br>Unit 27','Ridgeland','SC','UNITED STATES','29936-4968','(254) 702-5941','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-15 22:39:14',0,NULL,3,1,1,1,'LK233908880CN\r ','cnfaner'),(23736,952923710012,220950190945,'3 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*3',200.99,'eastar4','clk_55','hai_la@yahoo.com','Hai T La','531 Sharon Rd','Arcadia','CA','UNITED STATES','91007-7953','(626) 660-5531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 22:40:07',0,NULL,3,1,1,1,'LK233953019CN\r ','eastar4\rPSGL001*3'),(23737,861076899011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',20,'TRTS001',139.8,'eastar4uk','j.applegame','japplegame@gmail.com','Evgeny Grigoryan','Birulyovskaya, 48, corp. 1<br>apt. 113','Moscow','','RUSSIAN FEDERATION','115547','+79262800464','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 22:44:26',0,NULL,3,1,3,1,'RA184500964CN\r ','eastar4uk\rTRTS001'),(23738,861081976011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','robofmaldon','rob.bennett@gmx.co.uk','Robert Bennett','15 Gate Street Mews','Maldon','Essex','UNITED KINGDOM','CM9 5EF','01621842622','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 22:54:14',0,NULL,3,1,3,1,'RAm84501823CN ','eastar4uk\rMOAP001'),(23739,813293887001,110819589113,'New Replaceable Shell for logitech remote control 890 pro',1,'SHLO007',29.9,'buysia','windfalls99','amiller@alumni.ucalgary.ca','Andrew H. Miler','24 Cartwright Road','Lumby','BC','CANADA','V0E 2G6','(250) 212-2831','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-15 23:04:09',0,NULL,3,1,11,1,'BJ01713554\r ','buysia\rSHLO007'),(23740,813285504001,110808692953,'NEW Jabra BT 500 Over The Ear Bluetooth Headset BT 500',1,'HSJA010',26.5,'buysia','pink01jada','jada_210@hotmail.com','JADA ROBINSON','1136 S Wilton St','PHILADELPHIA','PA','UNITED STATES','19143-4207','(267) 312-0018','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-15 23:06:24',0,NULL,3,1,1,1,'LK233920568CN\r ','buysia'),(23741,861098365011,320618274660,'New 3.0 Bluetooth BCM2070 Module+cable for HP 5310M',1,'BTHP3004',19.98,'eastar4','henrywang000','jtoshiba@iinet.net.au','henry wang','211 blacktown rd<br>blacktown','sydney','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 23:39:59',0,NULL,3,1,11,1,'BJ01713555\r ','eastar4\rBTHP3004\rHP 8pin1.0 8cm'),(23742,805175124007,170752343664,'New Grohe Multi Function hand Shower Head + 59\" Grohe hose+ holder  Made in GER',1,'OTGR001+OTGR002+OTGR003',56.9,'au-buy','kalithea1950','mary.koukos@hotmail.com','Mary Koukos','235 West Botany St','Rockdale','New South Wales','AUSTRALIA','2216','0295923593','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 01:59:42',0,NULL,3,1,3,1,'RA184501925CN\r ','au-buy\rOTGR001+OTGR002+OTGR003\r'),(23743,693485944013,230717843942,'New 3-section Manual Opening Umbrella with Beautiful Horse Pattern',1,'UM00052',21.99,'eastar4','tygar5000','donnasavage5@bigpond.com','Donna Savage','38 Kookaburra Drive<br>Greenfields','Mandurah','Western Australia','AUSTRALIA','6210','0895869678','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 02:01:23',0,NULL,3,1,11,1,'BJ01714174 ','eastar4\rUM00052'),(23744,8881331864224307,111,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',0,'cnfaner','frankyanime123','franky_pak@yahoo.com','Franky Pak','421 W Wells St','San Gabriel','CA','UNITED STATES','91776-3230','(626) 695-8830',NULL,NULL,NULL,'2012-03-16 02:17:04',0,NULL,3,1,3,1,'RA184500916CN\r ','cnfaner\rOTGR001\r补发的 '),(23745,8881331865430310,111,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',0,'cnfaner','harleygirlmay','may2008xxoo@yahoo.com','Winson Wong C/O Prudential Overall Supply','1429 N Milpitas Blvd','Milpitas','CA','UNITED STATES','95035','',NULL,NULL,NULL,'2012-03-16 02:37:10',0,NULL,3,1,3,1,'RA184500978CN\r ','cnfaner\rHSJA013\r美标\r补发的 '),(23746,8881331871460738,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','mahyar katirachi','10338 Eastborne Ave','LOS ANGELES,','CA','UNITED STATES','90024-5350','',NULL,NULL,NULL,'2012-03-16 04:17:40',0,NULL,3,1,3,1,'RA184501806CN\r ','eastar4\r直接打款 \rMOAP001     '),(23747,8881331871628278,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Francel Emilio Acevedo Suárez - Liberty Express, C.A.','8074 NW 66 STREET','MIAMI,','FL','UNITED STATES','33166','',NULL,NULL,NULL,'2012-03-16 04:20:28',0,NULL,3,1,3,1,'RA184501810CN\r ','eastar4\r直接打款 \rMOAP001      '),(23748,8881331871652420,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Francel Emilio Acevedo Suárez - Liberty Express, C.A.','8074 NW 66 STREET','MIAMI,','FL','UNITED STATES','33166','',NULL,NULL,NULL,'2012-03-16 04:20:28',0,NULL,5,0,18,0,NULL,' 重复了'),(23749,953037280012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',68.99,'eastar4','casp3990','caspersonrussell@yahoo.com','Russell  Casperson','3333 Se 89th St','Oklahoma City','OK','UNITED STATES','73135','(405) 590-2228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 04:21:28',0,NULL,3,1,1,1,'LK234149338CN\r ','eastar4'),(23750,8881331871872283,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Evan Baker','8820 WILSHIRE BLVD STE 340','BEVERLY HILLS, ','CA','UNITED STATES','90211-2619','',NULL,NULL,NULL,'2012-03-16 04:24:32',0,NULL,3,1,3,1,'RA184501899CN\r ','eastar4\r直接打款 \rMOAP001      '),(23751,8881331872033159,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Mathiou Zaky','P.O. Box 1660','Sunset Beach,',' CA','UNITED STATES','90742','',NULL,NULL,NULL,'2012-03-16 04:27:13',0,NULL,3,1,3,1,'RA184501766CN\r ','eastar4\r直接打款 \rMOAP001      '),(23752,8881331872270191,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','9312 SE Sherriane CT','Apt 1','Portland,','OR','UNITED STATES',' 97222','',NULL,NULL,NULL,'2012-03-16 04:31:10',0,NULL,5,0,18,1,' ','eastar4\r直接打款 \rMOAP001   \r客户要求退款撤单'),(23941,8881332141264403,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',52,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Sharon Whalen','1320 South State Street ','Springfield,','illinois','UNITED STATES','62704','',NULL,NULL,NULL,'2012-03-19 07:14:24',0,NULL,3,1,3,1,'RA184500301CN ','MOAP001 \reastar4\r直接打款 \r  '),(23753,8881331872443359,111,' NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Henry Osorio','155 MEADOWVIEW CT','LANGHORNE,','PA ','UNITED STATES','19047-1013','',NULL,NULL,NULL,'2012-03-16 04:34:03',0,NULL,3,1,3,1,'RA184501797CN\r ','eastar4\r直接打款 \rMOAP001     '),(23754,813397619001,110836854678,'Clear Transparent Dome Birdcage Rain Sun Umbrella with cute pattern',1,'UM00033',19.99,'buysia','myownperson137','bo_bear17@hotmail.com','Amy Jordan','6 Sleepy Hollow Ct','Little Rock','AR','UNITED STATES','72205-4659','(501) 247-2653','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-16 06:03:48',0,NULL,3,1,1,1,'LK234339646CN ','buysia\r买家没有回复\r随机发'),(23755,0,230761515560,'40 Pin 3.5\" desktop male to female IDE Hard Drive Cable',1,'OTCN003',1.04,'eastar4','brinstar117','brinstar117@hotmail.com','Jason Chan','40504 Verne St','Fremont','CA','UNITED STATES','94538-3345','(510) 656-2370','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 07:31:33',0,NULL,3,1,1,1,'LK234324859CN\r ','eastar4'),(23756,0,220975062113,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',21.02,'eastar4uk','railroadtycoon3','stuartpower@hotmail.com','Stuart Power','67 Glebe Way','Hornchurch','Essex','UNITED KINGDOM','RM113RR','07966717567','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 08:15:32',0,NULL,3,1,3,1,'RA184500981CN\r ','eastar4uk\rGLOT001'),(23757,693547222013,230696519889,'Philips Sonicare Pro Results MINI HX6021 toothbrush head',2,'HBPH008',25.98,'eastar4','jonarnem','jonarne@multinet.no','jon arne madsø','markaplassen 140<br>7054','ranheim','','NORWAY','7054','+4797502676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 08:19:26',0,NULL,3,1,11,1,'BJ01713552\r ','eastar4\rHBPH008'),(23758,953091225012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',68.99,'eastar4','28554','saksit11111@hotmail.com','saksit kiratipan','333/22 kingkaew 14/1<br>rajatheva bangplee','samut prakarn','','THAILAND','10540','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 08:42:35',0,NULL,3,1,3,1,'RA184500995CN\r ','eastar4\rPSGL001'),(23759,0,220975062419,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',5.99,'eastar4uk','paulmidd','paulmiddlehurst@tiscali.co.uk','Paul Middlehurst','6 Grange Farm Drive','sheffield','South Yorkshire','UNITED KINGDOM','s26 2gy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 08:43:15',0,NULL,3,1,3,1,'RA184501001CN\r ','eastar4uk\rHBPH003'),(23760,796669878008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',21.99,'au-buy','bettievintage','ourteaparty@gmail.com','Penelope Gable','11/59 Queens Road','Melbourne','Victoria','AUSTRALIA','3004','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 08:53:04',0,NULL,3,1,11,1,'BJ01713551\r ','au-buy\rUM00043'),(23761,8881331888251539,111,'NOKIA BH-900补发一个耳挂',1,'HSNO019',0,'eastar4','thing2397','siewthing2397@hotmail.com','soh siew thing','10E, Jalan Muar','Segamat','Johor','MALAYSIA','85000','0167172566',NULL,NULL,NULL,'2012-03-16 08:57:31',0,NULL,5,0,18,0,' ','不补发了'),(23762,0,180840774186,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',32.95,'au-buy','jackatganges','jackatganges63@gmail.com','John Grint','10 Paddock Gardens','Attleborough','Norfolk','UNITED KINGDOM','NR17 2EW','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 08:59:51',0,NULL,3,1,11,1,'BJ01713550\r ','au-buy\rLGRM001\r'),(23763,805274076007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',6,'OTGR001',125.4,'au-buy','bro_tan09','bro2003@bigpond.com.au','brian harrison','28 sturgeon st','ormiston','Queensland','AUSTRALIA','4160','0738212545','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 09:45:18',0,NULL,3,1,3,1,'RA184500385CN\r ','au-buy\rOTGR001'),(23764,953121185012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','ravb2000','ravibasra@hotmail.com','Ravi Basra','71 Hambledon Avenue<br>Bierley','Bradford','West Yorkshire','UNITED KINGDOM','BD4 6AX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 10:29:24',0,NULL,3,1,3,1,'RA184500743CN\r ','eastar4uk\rOTCN004*10'),(23765,0,220975062511,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',1,'eastar4uk','123crash99','crashcradock@bigpond.com','William  Cradock','21 Grenadier Grove','Gulf View Heights','South Australia','AUSTRALIA','5096','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 10:38:58',0,NULL,3,1,11,1,NULL,'eastar4uk\rSCLO002'),(23766,632409026003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',46.99,'cnfaner','amguin','amamam@gmail.com','Akarawat Arthimokyothin','1291/1 Shinawatra Tower2(14) Phaholyothin Rd.,','phayathai','Bangkok','THAILAND','10400','+66813727733','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 10:54:14',0,NULL,3,1,3,1,'RA184500791CN\r ','cnfaner\rMOOE002\rOEM'),(23767,693577307013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','trideer','ahmetsulek@gmail.com','Ahmet Sulek','Olukbeli Sokak No:52 Daire:5 Florya/Bakirkoy','Istanbul','','TURKEY','34154',' 00905326466244','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:04:16',0,NULL,3,1,11,1,NULL,'eastar4\rCACN004'),(23768,0,180840774169,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',24.99,'au-buy','avsales400','av.ebaysales@gmail.com','Jason  Crerar','40 Acropolis Drive','Legana','Tasmania','AUSTRALIA','7277','0363302585','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 10:53:43',0,NULL,3,1,11,1,NULL,'au-buy\rGLOT001'),(23769,638035631004,140562546490,'New Grohe Multi Function hand Shower Head no water hose',1,'OTGR001',18.9,'cnfaner','chriskiang','jasonnie29@live.com.au','chris kiang','shop 1/128 Terralong st kiama','wollongong','New South Wales','AUSTRALIA','2533','0242322944','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:23:20',0,NULL,3,1,3,1,'RA184500686CN\r ','cnfaner\rOTGR001'),(23770,813471948001,110836856334,'New lady lace trim sun/rain stick Umbrella',1,'UM00011',24.99,'buysia','krknro','kfs@centurytel.net','Kelli Santhuff','208 E Jefferson St','Potosi','MO','UNITED STATES','63664-1913','(573) 438-3296','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-16 11:34:55',0,NULL,3,1,1,1,'LK235678447CN\r ','buysia\rpink'),(23771,861288359011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',38.99,'eastar4','fabianoezure2012','fabianoezure@hotmail.com','Fabiano Ezure','Rua 1001, nr 490 - apto 2301','Baneario Camboriu','SC','BRAZIL','88330756',' 554733631086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 12:05:04',0,NULL,3,1,11,1,NULL,'eastar4\rLGRM001'),(23772,693586693013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','marksjaunzems10','marksjaunzems@gmail.com','Marks Jaunzems','AIZPILS?TAS 33-57 Daugavpils Latvia','Daugavpils','','LATVIA','LV5417','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:48:01',0,NULL,3,1,3,1,'RA184500434CN\r ','eastar4\rLGAD001'),(23773,953159299012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UM00001',19.99,'eastar4','victoriapinkhair','victoriawilson89@gmail.com','Victoria Wilson','5 Balsam court','Cranbourne North','Victoria','AUSTRALIA','3977','0408822623','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 12:30:58',0,NULL,3,1,11,1,NULL,'eastar4\rUM00001'),(23774,0,320867778683,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41,'eastar4','domin53','dominik@tarabanski.com','Dominik Tarabanski','Warszauera 3','Krakow','Malopolskie','POLAND','31-057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 13:07:29',0,NULL,3,1,3,1,'RA184500448CN\r ','eastar4\rLGAD001'),(23775,953174985012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',8.99,'eastar4uk','oliversoddsandbobs','oliveralcock@me.com','Oliver Alcock','131 Bramley Lane<br>Hipperholme','Halifax','West Yorkshire','UNITED KINGDOM','HX3 8JJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 13:14:31',0,NULL,3,1,3,1,'RA184500880CN\r ','eastar4uk\rWLHP002'),(23776,858284033002,120855593935,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',68.99,'buysia','kovikosh','kovik@tut.by','VIKTAR KASTSIUCHENKA','Orlovskaya str., 28D, flat 36','Brest','','BELARUS','224028','+375299020715','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-16 14:31:40',0,NULL,3,1,3,1,'RA184500672CN\r ','buysia\rPSGL001'),(23777,636947251004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'cnfaner','ohlangford','orlandolangford@hotmail.com','Orlando Langford','2600 University Ave. Lot#119','Williston','ND','UNITED STATES','58801','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-16 14:48:51',0,NULL,3,1,1,1,'LK235670134CN ','cnfaner'),(23778,861344835011,320441946742,'2.1 HP NX7300 NX7400 Bluetooth Module EDR + cable',1,'BTHP2101',12.39,'eastar4','bluefiremedia','bkinsley@loftware.com','Brian Kinsley','166 Corporate Drive<br>c/o Loftware, Inc.','Portsmouth','NH','UNITED STATES','03801','(603) 812-8133','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 14:49:17',0,NULL,3,1,1,1,'\\ ','eastar4\rBTHP2101\rHP 8pin 1.0 3cm '),(23779,638025761004,140644120633,'NIB genuine Philips SHQ4000 Sports Sweat Proof Headphones  long cable red',1,'HSPH002',31.9,'cnfaner','drartis','arturaspeckys@gmail.com','arturas peckyss','bangu 19a-2','klaipeda','','LITHUANIA','91250','+37046493463','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 15:04:26',0,NULL,3,1,3,1,'RA184500845CN\r ','cnfaner\rHSPH002'),(23780,813544133001,110837938896,'Super Light Bubble Pattern Windproof Rain/Sun Umbrella w/24 Skeleton',1,'UM00049',24.99,'buysia','bun0902','vszumla@bart.gov','Vanessa   Szumlas','1250 Page Ct','Pinole','CA','UNITED STATES','94564-2724','(510) 464-6851','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-16 15:26:44',0,NULL,3,1,1,1,'LK235684898CN\r ','buysia'),(23781,693640710013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',147.99,'eastar4','ernbog','ernbog@hotmail.com','Ernestas Bogusevicius','Pazeru g. 28','Garliava','Kauno r','LITHUANIA','53257','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 15:32:06',0,NULL,3,1,3,1,'RA184500363CN\r ','eastar4\rGLOT001*4'),(23782,0,320867780520,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',10.49,'eastar4','karls4914','karlsimmons66@yahoo.com','Karl Simmons','7501 Chesterfield Dr<br>Apt 713','Dallas','TX','UNITED STATES','75237-3484','(214) 803-1660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 15:37:27',0,NULL,3,1,1,1,'LK235689334CN ','eastar4'),(23783,0,220975062455,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.06,'eastar4uk','luckyhappy12','mawindeehongphan@gmail.com','mawindee hongphan','99/432 ,Phaholyothin Rd. Soi Klongluang10<br>Klongnueng','Klongluang','Patumthanee','THAILAND','12120','8865836392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 16:24:22',0,NULL,3,1,11,1,NULL,'eastar4uk\rPOLO001'),(23784,953273515012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','thundercat337','lee.trujillo83@gmail.com','Lee Trujillo','9545 Wentworth St','Sunland','CA','UNITED STATES','91040-1626','(323) 371-6871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 17:10:42',0,NULL,3,1,1,1,'LK235651356CN ','eastar4'),(23785,953283000012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',3.98,'eastar4','zero-qi','benjamin.brisson@gmail.com','Benjamin Brisson','Dell computers, Innovation House<br>Cherrywood Science Park','Loughlinstown','Dublin','IRELAND','D18','0877471780','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 17:35:56',0,NULL,3,1,11,1,NULL,'eastar4\rANTY001'),(23786,861438683011,320596607503,'New Canon solar handheld calculator LS-10DT',1,'OTCA001',55.66,'eastar4','yngwarr','dovgelli@mail.ru','Igor Dovgeli','Admirala Lazareva, 19-1-51','Moscow','','RUSSIAN FEDERATION','117042','+7(926)007-3471','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 18:29:23',0,NULL,3,1,3,1,'RA184500540CN\r ','eastar4\rOTCA001+HSJA013\r欧标\r再发两个\rNew Jabra JX10 Series II 2 Wireless Bluetooth headset\r'),(23787,861440906011,320733868089,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',33.99,'eastar4','serpg','serp1@bk.ru','Puchkov Sergey','Plavskiy pr-d 2-6','Moscow','Russia','RUSSIAN FEDERATION','117042','(903) 9654293','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 18:34:35',0,NULL,3,1,11,1,NULL,'eastar4\rWWSI004'),(23788,953326898012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',39.99,'eastar4','serenkiy303','alfa303@mail.ru','Sergey Golovchenko','Komsomolskaya st. 115','Armavir','RU','RUSSIAN FEDERATION','352900','+79184923066','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 18:51:42',0,NULL,3,1,11,1,NULL,'eastar4\rGLOT001'),(23789,861475513011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',38.99,'eastar4','rfrancoisr','rfrancoisr@hotmail.com','Francois Rivest','18 De Serres','Terrebonne','QC','CANADA','J6Y1W3','(450) 965-7161','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 19:33:43',0,NULL,3,1,11,1,NULL,'eastar4\rLGRM001'),(23790,861464838011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','pkoromanpanagiotis','pkoroman@yahoo.com','Panagiotis Koromantzos','8, Psaron str','Kifisia','Attiki','GREECE','14561','(210)6255707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 19:16:34',0,NULL,3,1,3,1,'RA184500598CN\r ','eastar4uk\rSAFI001*2'),(23791,693730855013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',67.99,'eastar4','jorgito15238','anerizmoraga@hotmail.com','Jorge Anériz Moraga','Calle Fotógrafo Joaquín Giráldez R.<br>47','Utrera (Sevilla)','Andalucía Ceuta y Melilla','SPAIN','41710','653986498','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 19:48:56',0,NULL,3,1,3,1,'RA184500805CN\r ','eastar4\rMOSA004'),(23792,953371401012,220807247879,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',39.99,'eastar4','pinkhappyhill','smtca@msn.com','Susan Miller','41 Happy Hill Rd','Vernon','VT','UNITED STATES','05354-9487','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 20:04:32',0,NULL,3,1,1,1,'LK235672325CN ','eastar4'),(23793,638186602004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.29,'cnfaner','brockra360','brockra@comcast.net','Raymond A Brockel','16314 83rd Way SE','Yelm','WA','UNITED STATES','98597-9474','(360) 458-3328','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-16 20:17:30',0,NULL,3,1,1,1,'LK235651736CN ','cnfaner'),(23794,953395659012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','richonplonge','richardgaly@free.fr','Richard GALY','63 rue Gabriel Péri','SAINT CYR L\'ECOLE','Île-de-France','FRANCE','78210','01.30.45.23.34','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 20:45:36',0,NULL,3,1,11,1,NULL,'eastar4\rWLDE002'),(23795,0,230761511148,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',37.01,'eastar4','tamtrades','tsvrede@yahoo.com','Tracy Markham','PO Box 1784','Fallbrook','CA','UNITED STATES','92088','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 21:07:21',0,NULL,3,1,1,1,'LK235644633CN ','eastar4'),(23796,861529976011,320635323192,'New Intel IBM lenovo 5300 AGN Network Mini PCI-E Card',1,'WLIN011',16.99,'eastar4','tobias2353','towo4000@freenet.de','Tobias Wolf','Alpenstraße 20 f','Untermeitingen','','GERMANY','86836','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 21:14:28',0,NULL,3,1,11,1,NULL,'eastar4\rWLIN011'),(23797,953419613012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',147.99,'eastar4','vincroy','vincent.roy@cableamos.com','Vincent Roy','922 avenue Cyr','Amos','QC','CANADA','J9T2V9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 21:29:24',0,NULL,3,1,3,1,'RA184500712CN\r ','eastar4\rGLOT001*4'),(23798,693770581013,230729621562,'Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n  BlueToo',1,'ANTY002',4.99,'eastar4','suprtek','psteib7@aol.com','Phil Steiber','13270 Alta Dena Dr','Colorado Springs','CO','UNITED STATES','80908-3490','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 21:31:00',0,NULL,3,1,1,1,'LK235660738CN ','eastar4\rANTY002'),(23799,0,320867780159,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',3.25,'eastar4','dienthuy','thuy7000@yahoo.com','Thuy Nguyen','11951 Firebird Dr','houston','TX','UNITED STATES','77099-4050','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 22:01:29',0,NULL,3,1,1,1,'LK235630413CN ','eastar4'),(23800,953436777012,220775175793,'New TP-LINK TL-WN821N USB WIRELESS N 300M Wifi Dongle',1,'OTTP001',23.9,'eastar4','kenpat0','kaddison@internode.on.net','Addison Ken','11 Tecoma Road','Palmwoods','Queensland','AUSTRALIA','4555','0754450730','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 22:01:36',0,NULL,3,1,11,1,NULL,'eastar4\rOTTP001'),(23801,861555592011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','badrobot54','p-worrall1@sky.com','paul worrall','18,blenheim road','burntwood','Staffordshire','UNITED KINGDOM','ws72hz','07707932641','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 22:09:23',0,NULL,3,1,3,1,'RA184500496CN\r ','eastar4uk\rOTSO004'),(23802,805571364007,170800299382,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'usa-view','19jaeh89','avenajonathan@yahoo.com','Jonathan Avena','14720 Roscoe Blvd<br>Apt 25','panorama city','CA','UNITED STATES','91402-4159','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-16 22:12:23',0,NULL,5,0,18,0,NULL,'usa-view'),(23803,861571986011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','sdfoate','sdfoate@charter.net','Scott Foate','6217 Walden Way','Madison','WI','UNITED STATES','53719','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 22:48:45',0,NULL,3,1,1,1,'LK235679796CN ','eastar4'),(23804,796990074008,180793383706,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'au-buy','kimberly_2101','kmathes2@une.edu.au','Kimberly Matheson','10 Hermitage Place','Muswellbrook','New South Wales','AUSTRALIA','2333','0409323041','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 23:04:03',0,NULL,3,1,11,1,NULL,'au-buy\rOT00002'),(23805,693797685013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',147.99,'eastar4','orhan3ky','orhandost2010@hotmail.com','rae anne zreika','18 laverack cresent','south granville','nsw','AUSTRALIA','2142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 23:04:17',0,NULL,3,1,3,1,'RA184500831CN\r ','eastar4\rGLOT001*4'),(23806,953506836012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UM00001',19.99,'eastar4','sinchare','sinchare@yahoo.com.au','Charlene Sin','Tracey Brunstrom and Hammond<br>Level 12, 15 Blue St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 01:13:08',0,NULL,3,1,11,1,NULL,'eastar4\rUM00001\r黑色的'),(23807,638267652004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',24.5,'cnfaner','americastaffing','americastaffing@yahoo.com','Vanessa Medrano','5005 Crestwood Dr','Cibolo','TX','UNITED STATES','78108-2183','(830) 387-4393','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-17 01:54:23',0,NULL,3,1,1,1,'LK235654454CN ','cnfaner'),(23808,953527149012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',1,'WLHP002',8.99,'eastar4uk','pocketwatchcomputer','university@btinternet.com','Philip Burrows','218 Cooks Lane','Kingshurst','West Midlands','UNITED KINGDOM','B37 6NH','01217701096','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 02:17:42',0,NULL,3,1,3,1,'RA184500876CN\r ','eastar4uk\rWLHP002'),(23809,813800903001,110834780805,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',4.99,'buysia','raguu','rick.green@roadrunner.com','Richard A. Green','2574 Windmill Way','Palm Springs','CA','UNITED STATES','92262-8802','(619) 654-4796','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-17 02:28:19',0,NULL,3,1,1,1,'LK235668263CN ','buysia'),(23810,797056402008,180820610109,'Genuine Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',2,'WLDE002',23.98,'au-buy','tennillecameron','cameron@barroni.com','Cameron Patterson','22 Macpherson Street<br>clapham','Adelaide','South Australia','AUSTRALIA','5062','0430278104','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 03:08:45',0,NULL,3,1,11,1,NULL,'au-buy\rWLDE002'),(23811,0,230761930959,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista small',1,'RCHP002',5.75,'eastar4','alexioi','bbmagic3@yahoo.com.hk','Au Alex','Flat H, 12/F, Royal Terrace, 933 King\'s Road, Quarry Bay<br>Hong Kong','default','','HONG KONG','default','(852)94231120','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 03:52:27',0,NULL,3,1,11,1,NULL,'eastar4\rRCHP002'),(23812,953554206012,220649635596,'NEW GENUINE NOKIA BH-200 BLUETOOTH HEADSET BH 200',1,'HSNO005',13.89,'eastar4','sheraz123456','sheraztariq@hotmail.com','Sheraz Tariq','1007- 49 Silverstone Drive','Toronto','ON','CANADA','M9V 3G2','(416) 829-6354','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 03:57:20',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO005'),(23813,861660519011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','mastaofsex','babybank2001@gmail.com','timothy elliott','840 railroad st','st.charles','KY','UNITED STATES','42453','(813) 389-8939','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 04:01:28',0,NULL,3,1,1,1,'LK235679235CN ','eastar4'),(23814,861663109011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','engineer_cory','corybruckner@hotmail.com','Cory Bruckner','7805 Paint Creek Dr','Ypsilanti','MI','UNITED STATES','48197-6001','(734) 483-9228','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 04:13:29',0,NULL,3,1,1,1,'LK235667183CN','eastar4'),(23815,693862019013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sbforit100x100','sbforit@gmail.com','Сергей Баканов','г. Иркутск, ул. Красных Мадьяр, д.80','Иркутск','','RUSSIAN FEDERATION','664047','89027605128','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2012-03-17 04:16:56',0,NULL,3,1,11,1,NULL,'eastar4\rHSNO019\r欧标'),(23816,953559686012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','richardhiorns','richardhiorns@aol.com','Richard Hiorns','37 Kiver Road','London','London','UNITED KINGDOM','N19 4PE','02072813488','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 04:21:01',0,NULL,3,1,3,1,'RA184500893CN\r ','eastar4uk\rWLIN013+WLAT008\r再发一个Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb'),(23817,0,220974194240,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',2.99,'eastar4uk','richardhiorns','richardhiorns@aol.com','Richard Hiorns','37 Kiver Road','London','London','UNITED KINGDOM','N19 4PE','02072813488','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 04:53:47',0,NULL,8,1,17,0,NULL,'eastar4uk\r'),(23818,861680183011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',38.99,'eastar4','machocloud','jcloud123@sbcglobal.net','jeffery cloud','19411 Diversion Dr','tomball','TX','UNITED STATES','77375-7684','(281) 255-0052','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 05:47:14',0,NULL,3,1,1,1,'LK235715683CN ','eastar4'),(23819,0,230761936116,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',1.5,'eastar4','serg_mefisto','sergmefisto@gmail.com','Sergey Moiseev','pr.Mira 9/2 - 102','Omsk','Omskaya obl','RUSSIAN FEDERATION','644050','960-990-0351','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 05:50:03',0,NULL,3,1,11,1,NULL,'eastar4\rANTY001'),(23820,861681388011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'eastar4','lucien.310','lkroytor@roadrunner.com','LUCIEN KROYTOR','16616 LAUREN WAY','ENCINO','CA','UNITED STATES','91436-4830','(310) 699-1155','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-17 06:04:32',0,NULL,3,1,1,1,'LK235699504CN ','eastar4'),(23821,861675552011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','shashkinama','sybil@list.ru','Mary Molchanova','Mira 13-6','Saratov','Saratovskaia oblast','RUSSIAN FEDERATION','410052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 06:20:56',0,NULL,3,1,11,1,NULL,'eastar4\rUM00040'),(23822,953596915012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.66,'eastar4','aganin51','pivogon@mail.ru','Aleksei Aganin','Korolenko 35-a, 69','Kazan','Tatarstan','RUSSIAN FEDERATION','420044','(843)5239213','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 07:26:14',0,NULL,3,1,11,1,NULL,'eastar4\rMOMI002'),(23823,0,220974186887,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',43.5,'eastar4uk','123_val','val.belingher@gmail.com','Valeriu BELINGHER','36 av Joseph Vidal<br>bat 5 B','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13008','0660156530','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 07:29:34',0,NULL,3,1,3,1,'RA184500575CN\r ','eastar4uk\rPSGL001'),(23824,0,230761987025,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',0.01,'eastar4','alikkach','pro22000@mail.ru','Aleksey Kachmar','Dobrovolskogo 128a, apt 40','Odessa','Odessa','UKRAINE','65111','+380674890616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 08:13:29',0,NULL,3,1,11,1,NULL,'eastar4\rANCN001'),(23825,0,220975821262,'NEW LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',19.49,'eastar4uk','jayson1506','jojofto23@hotmail.com','Jayson Laureta','10 Drayton Street','Sunshine','Victoria','AUSTRALIA','3020','0403279688','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 08:14:52',0,NULL,3,1,11,1,NULL,'eastar4uk\rLGFI001'),(23826,0,320865575789,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',7.19,'eastar4uk','9166100411','dmitry.dolzhenko@gmail.com','Dmitry Dolzhenko','89-103 Vavilova street','Moscow','Central','RUSSIAN FEDERATION','117335','+7-916-610-0411','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 09:04:56',0,NULL,3,1,11,1,NULL,'eastar4uk\rWLIN014'),(23827,693937252013,230717820578,'New In Box SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',43.99,'eastar4','mxd60','duong@grignon.inra.fr','Xuan-Duong Mai','1b rue de la fontaine des gobelins','Guyancourt','Ile-de-France','FRANCE','78280','0130815308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 11:54:40',0,NULL,3,1,3,1,'RA184500641CN\r ','eastar4\rSAFI001'),(23828,0,320865575643,'New Altec Lansing Backbeat Plus UHP206 Earphones Compatible w/iPhone ipod mp3mp4',1,'HSAL002',4.99,'eastar4uk','jean4.2b','worawit.lalit@gmail.com','Worawit Lalitkiattikool','130/46 T.Bansuan<br>A. Muang','default','CB','THAILAND','20000','66819031973','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 11:55:37',0,NULL,3,1,11,1,NULL,'eastar4uk\rHSAL002'),(23829,953684208012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','supercoop74','madandycoop@googlemail.com','andrew cooper','36 field court','kilburn belper','Derbyshire','UNITED KINGDOM','de56 0jz','07795513297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 12:16:40',0,NULL,3,1,3,1,'RA184500828CN\r ','eastar4uk\rHSJA002\r英标'),(23830,0,220974189935,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',20,'eastar4uk','2009ssp','ssp@acanac.net','Sylvain St-Pierre','1791 Lyall','Montréal','QC','CANADA','H1N 3G2','(514) 251-2802','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 12:30:10',0,NULL,3,1,11,1,NULL,'eastar4uk\rLGRM001'),(23831,0,130665893550,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',2.99,'cnfaner','rani.hod','rani.hod+ebay@gmail.com','Rani Hod','School of Computer Science<br>Tel Aviv University, P.O.B. 39040','Tel Aviv','','ISRAEL','69978','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 12:35:08',0,NULL,3,1,3,1,'RA184500730CN\r ','cnfaner\rRCHP001'),(23832,0,120878271479,'3G WWan antenna compatibled for MC8780 MC8790 F3507G GTM378 GTM380 M250 DELL5530',1,'ANCN001',0.21,'buysia','alikkach','pro22000@mail.ru','Aleksey Kachmar','Dobrovolskogo 128a, apt 40','Odessa','Odessa','UKRAINE','65111','+380674890616','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-17 13:15:02',0,NULL,3,1,11,1,NULL,'buysia\rANCN001'),(23833,953654786012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','parsuchok','bohonovich@gmail.com','Konstantin Bohonovich','223012 Belarus GP Machulischi<br>Molodegnaya str. 27-4','Machulischi','Minskaya obl','BELARUS','223012','+375296444698','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 13:17:59',0,NULL,3,1,3,1,'RA184500814CN\r ','eastar4\rPSGL001*2'),(23834,953727468012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',3,'HSJA002',40.8,'eastar4uk','tracie22','tbeamish9@hotmail.com','Tracie Beamish','C/O Biffa Waste Services<br>Queen Street','Leeds','West Yorkshire','UNITED KINGDOM','LS26 8AL','01132867121','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 14:04:58',0,NULL,3,1,3,1,'RA184500690CN\r ','eastar4uk\rHSJA002\r英标'),(23835,953736291012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'eastar4','sany7391','sanyhoeung@gmail.com','Sany Hoeung','198 Liverpool Rd','Kilsyth sth','Victoria','AUSTRALIA','3137','0423390803','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 14:33:30',0,NULL,3,1,3,1,'RA184500709CN\r ','eastar4\rOTSO004*2'),(23836,861841802011,320721398551,'New Jabra BT500 BT 500 wireless Bluetooth Headset',1,'HSJA010',24.59,'eastar4','keithkleonard','keithmleonard4@hotmail.co.uk','Keith Leonard','4 Mead Way<br>Balderton','Newark','Nottinghamshire','UNITED KINGDOM','NG24 3GA','01636684093','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 14:45:56',0,NULL,3,1,11,1,NULL,'eastar4\rHSJA010\r英标'),(23837,805870317007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','mister.daniel.nascimento','mrd007brasil@gmail.com','Daniel Gonzaga do Nascimento','Rua Euclides Pantaleão da Costa, 166<br>Parque das Paineiras','São Paulo','São Paulo','BRAZIL','03694030','+551181604995','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-17 16:01:28',0,NULL,3,1,3,1,'RA184500536CN\r ','au-buy\rLGFI001'),(23838,0,110843210558,'New US Logitech Harmony AC Power Adapter',1,'POLO001',0.99,'buysia','oiu','tlir@earthlink.net','Richard Tuthill','1515 NW Circle Blvd','Corvallis','OR','UNITED STATES','97330-1304','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-17 16:37:02',0,NULL,3,1,1,1,'LK235643037CN ','buysia'),(23839,861908581011,320497204399,'NEW Atheros AR5008 802.11N 300M PCI-E+ 3 antenna',1,'WLAT001+ANTY002',15.99,'eastar4','thebooblik','s_wadim@mail.ru','Vadim Sizonenko','flat 16; 10; Mira street','Efremov, Chernyatino','Tulskaya','RUSSIAN FEDERATION','301844','+79051162575','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 17:05:11',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT001+ANTY002'),(23840,861916048011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','charityleelee','clkish0405@aol.com','Charity Kishineff','9365 Sierra Spring Way','Elk Grove','CA','UNITED STATES','95624-3981','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 17:24:59',0,NULL,3,1,1,1,'LK235757153CN ','eastar4'),(23841,953831421012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','jacko1962*123','jacko.1962@live.co.uk','paul jackson','23 hawthorne avenue','brigg','Lincolnshire','UNITED KINGDOM','dn208pg','07885363279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 17:32:24',0,NULL,3,1,3,1,'RA184500774CN\r ','eastar4uk\rHSJA002\r英标'),(23842,861926573011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','gadley564','victoriagadley@sbcglobal.net','Victoria Gadley','PO Box 7643','Saint Louis','MO','UNITED STATES','63106-0643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 17:39:23',0,NULL,3,1,1,1,'LK235736480CN ','eastar4'),(23843,953836247012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',263.99,'eastar4','google1805','vietha1805@gmail.com','Tuan Dinh - Quang Tran','2002 Dowling St','Houston','TX','UNITED STATES','77003-6006','(713) 922-8198','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 17:40:29',0,NULL,3,1,1,1,'LK235764517CN ','eastar4\rPSGL001*4\r物品编号写在包装上\r220950194178'),(23844,638475738004,140699470972,'Mini Spy Vehicle Realtime Tracker For GSM/GPRS/GPS System Tracking Device TK102',1,'GPS0006',58.99,'cnfaner','tdell-us','tdell@tampabay.rr.com','Teresa Dell','7106 32nd ave e','Bradenton','FL','UNITED STATES','34208-6756','(941) 896-6519','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-17 17:57:36',0,NULL,3,1,1,1,'LK235637411CN ','cnfaner\r美标'),(23845,0,320866848649,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',21.77,'eastar4uk','trackerzone2','cdx14ever@gmail.com','Sharnas Sherwood','32 Rawling Street','Keighley','West Yorkshire','UNITED KINGDOM','bd211au','01535210936','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 18:18:54',0,NULL,3,1,3,1,'RA184500403CN\r ','eastar4uk\rGLOT005\r黑色的'),(23846,694061381013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','kantankeroos','chris.houseman@gmail.com','C Houseman','227<br>Wellington Road','Liverpool','Merseyside','UNITED KINGDOM','L84TX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 18:19:58',0,NULL,3,1,11,1,NULL,'eastar4\rOTHP003'),(23847,953866134012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','beveddy','bev_edd_85@yahoo.co.uk','lee martin','Combellack Vehicle Recyclers LTD<br>Trendale Industrial Park,Higher Trezaise','Roche','Cornwall','UNITED KINGDOM','pl26 8hs','07828474912','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 18:31:11',0,NULL,3,1,3,1,'RA184500757CN\r ','eastar4uk\rOTCN004*10'),(23848,814095008001,110834780577,'a pair of ThinkPad X200 3G GPS+WWAN Antenna',1,'ANCN002',17.5,'buysia','gecuba','gecuba@yandex.ru','Vitaliy Chernyshev','Vyshgorods\'ka st., 46-A, app.13','Kyiv','','UKRAINE','04114','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-17 18:41:29',0,NULL,3,1,11,1,NULL,'buysia\rANCN002'),(23849,953930141012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','drric71','drric71@aol.com','Richard M. Morales','846 S Almond Ave','Kerman','CA','UNITED STATES','93630-9397','(559) 275-5073','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 20:08:04',0,NULL,3,1,1,1,'LK235737785CN ','eastar4\rMOAP001'),(23850,694113192013,230685089223,'4 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*4',147.99,'eastar4','nelsondecastro','nelsondecastro2@yahoo.com.br','José Raimundo Sobral Cruz','RUA MACHADO NETO, 281, EDF. TATTI MORENO, AP. 403-B, PITUBA','Salvador','Bahia','BRAZIL','41830-510','+55 71 99134464','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 20:33:57',0,NULL,3,1,3,1,'RA184500624CN\r ','eastar4\rGLOT001*4'),(23851,953960810012,220498717899,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',3.98,'eastar4','whitetoe304','wcparry2@gmail.com','Cybil Parry','468 Lexington Ave','Newark','OH','UNITED STATES','43055-6424','(740) 403-1530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 20:57:30',0,NULL,3,1,1,1,'LK235740365CN ','eastar4'),(23852,638557710004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',2,'MOMI004',27.2,'cnfaner','lolokopterko','lolokopterka@azet.sk','Andrej Gasper','P.O. Box  86<br>P.O. Box  86','Banská Bystrica','Slovakia','SLOVAK REPUBLIC','97411','00421908683508','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 21:24:51',0,NULL,3,1,3,1,'RA184500655CN\r ','cnfaner\rMOMI004'),(23853,954019920012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','mike-owl0','mandjpriest@mandjpriest.karoo.co.uk','mike priest','2 poplars way,','beverley','East Riding of Yorkshire','UNITED KINGDOM','HU17 8PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 22:54:29',0,NULL,3,1,3,1,'RA184500522CN\r ','eastar4uk\rHSJA010\r英标'),(23854,638591819004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65.99,'cnfaner','jbs9025','jbs9025@aol.com','Joy Emery','7834 W Peck Dr','Glendale','AZ','UNITED STATES','85303-4205','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-17 23:21:33',0,NULL,3,1,1,1,'LK235593256CN ','cnfaner'),(23855,806097485007,170734557693,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',51.99,'au-buy','a11120443','beanyblock@live.com.au','Paul McBean','20 Perrin st.','Seymour','Victoria','AUSTRALIA','3660','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 23:26:53',0,NULL,3,1,3,1,'RA184500394CN\r ','au-buy\rLGFI001'),(23856,0,170802049931,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',1,'CC00002',22.5,'au-buy','bumkrak','bumkrak@hotmail.com','Aaron Bradshaw','PO Box 1246','Woodford','Queensland','AUSTRALIA','4514','0407888766','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 23:59:11',0,NULL,3,1,11,1,NULL,'au-buy\rCC00002'),(23857,694179256013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',2,'GPS0004',219.98,'eastar4','johnfod','foderickj@aol.com','john foderick','28340 128th St NW','zimmerman','MN','UNITED STATES','55398-9438','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 23:46:00',0,NULL,3,1,1,1,'LK235769430CN ','eastar4'),(23858,954050544012,220784875514,'2 pairs of NIB 2011 SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',135.99,'eastar4','brad05121982','bcornel82@hotmail.com','Brad Cornelissen','2476 Malcolm Crescent','Burlington','ON','CANADA','L7P 4A4','(905) 635-8568','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 00:11:16',0,NULL,3,1,3,1,'RA184500505CN\r ','eastar4\rOTSO004*2'),(23859,638607596004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','rivertiger901','rivertiger@gmail.com','Dena Duong','9401 Luders Ave','Garden Grove','CA','UNITED STATES','92844-2321','(650) 995-4941','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 00:29:50',0,NULL,3,1,1,1,'LK235621270CN ','cnfaner'),(23860,954069466012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','bj991551','olivierp@hybride.com','Olivier Painchaud','650 Alfred-Desrochers','Boisbriand','QC','CANADA','J7G 3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 01:06:05',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT009'),(23861,0,220977563794,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',13.5,'eastar4','eols4806','vgabndbiz@me.com','Eric Olsen','305 NE 6th St<br># 622','Grants Pass','OR','UNITED STATES','97526-2059','(541) 287-0851','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 01:21:04',0,NULL,3,1,1,1,'LK235663062CN ','eastar4'),(23862,954078900012,220880680075,'NEW Sunflower Bloom Sun/Rain Stick Umbrella',1,'UM00005',22.99,'eastar4','lecdolorec','lecdolorec@hotmail.com','Lourdes Rodriguez','1035 Sutton Cir<br>Apt 177','Daytona Beach','FL','UNITED STATES','32114-7807','(386) 947-8708','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 01:34:59',0,NULL,3,1,1,1,'LK235749523CN\r ','eastar4\rUM00005'),(23863,694207741013,230576484613,'New ULTIMATE EARS METRO.FI 170VI EARPHONE UE170 VI',1,'HSUE001',20.99,'eastar4','felman2004','vladimir2@optonline.net','Vladimir Litvinenko','10 Harbor Ct','Mount Sinai','NY','UNITED STATES','11766-1203','(631) 473-2526','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 01:44:47',0,NULL,3,1,1,1,'LK235766053CN ','eastar4'),(23864,694211065013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',67.99,'eastar4','msel9693','ccostello163@gmail.com','Michael Selvadurai','167 Trail Side Circle','Ottawa','ON','CANADA','K4A 5B4','(416) 770-4697','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 01:58:41',0,NULL,3,1,3,1,'RA184500615CN\r ','eastar4\rMOSA004'),(23865,862175035011,320402057334,'HP NX7300 NX7400 Bluetooth Module 2.0 EDR + cable',1,'BTHP2001',9.88,'eastar4','gmendozaf','gabrielemf@hotmail.com','Gabriel Mendoza Flores','Village D 257A<br>Oklahoma State University','Stillwater','OK','UNITED STATES','74077-0001','(509) 339-3146','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 02:50:08',0,NULL,3,1,1,1,'\\ ','eastar4\rHP 8pin 1.0 3cm  '),(23866,806168580007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',254.59,'au-buy','troon1084','ninaandjim@bigpond.com','James Blunt','42 Fred Campbell Drive','Albany Creek','Queensland','AUSTRALIA','4035','0732642738','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 03:45:34',0,NULL,3,1,4,1,'YW870147430CN\r ','au-buy\rPSGL001*4'),(23867,954124198012,220915147042,'New Innovated Heart shape Fashion Rose Sun/Rain Umbrella',1,'UM00047',24.99,'eastar4','candiheart','cjheart@msn.com','Candice Johnston','2622 S San Diego Ave','Ontario','CA','UNITED STATES','91761-6351','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 04:08:17',0,NULL,3,1,1,1,'LK235748253CN\r ','eastar4'),(23868,862201187011,320791294923,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103',1,'GPS0007',88.99,'eastar4','iceman14036','stevebarraco@ymail.com','steve barraco','10 Edgewood Dr','batavia','NY','UNITED STATES','14020-3907','(716) 880-5419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 04:45:36',0,NULL,3,1,1,1,'LK235645245CN ','eastar4'),(23869,862203474011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','jasmine7767','kotomifune@gmail.com','Akemi Mifune','9-30-7-704 Seijo Setagaya','Tokyo','Tokyo','JAPAN','1570066','03-3483-3301','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 04:53:12',0,NULL,3,1,11,1,NULL,'eastar4\rUM00040'),(23870,694254311013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'eastar4','colabs7334','5000k@mail.ru','Yuri Druzhinin','Profsouznaja St., 96-3-70','Moscow','RU','RUSSIAN FEDERATION','117485','+79032101447','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 06:21:42',0,NULL,3,1,11,1,NULL,'eastar4\rOT00004'),(23871,806196855007,170785414219,'New Original Apple AirPort Extreme WiFi Card 54M',1,'WLAP003',25.99,'au-buy','it-bitsnpieces','stephen.parry@virginblue.com.au','Stephen Parry','4/161 Allen Street<br>Hamilton','Brisbane','Queensland','AUSTRALIA','4007','0731609346','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 06:27:34',0,NULL,3,1,11,1,NULL,'au-buy\rWLAP003'),(23872,954166171012,220880035382,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',45.99,'eastar4','kgeoffrion','ken@geoffrions.com','Ken Geoffrion','9678 Biltmore Way','Highlands Ranch','CO','UNITED STATES','80126-3059','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 07:34:04',0,NULL,3,1,1,1,'LK235636464CN ','eastar4'),(23873,694267115013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','ehondik76','ehondik@yandex.ru','Evgeniy Handakov','ulitca Savushkina dom 124 korp 1 kv 262','St-Petersburg','','RUSSIAN FEDERATION','197374','+79633245264','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 07:49:25',0,NULL,3,1,11,1,NULL,'eastar4\rWLAP008'),(23874,954169370012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',263.99,'eastar4','virgomercury70','tasmaniandevv@hotmail.com','Anthony Palmer','Bank of America Merrill Lynch Canada<br>181 Bay Street, Suite 400','Toronto','ON','CANADA','M5J 2V8','(416) 369-8479','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 07:51:49',0,NULL,3,1,3,1,'RA184500567CN\r ','eastar4\rPSGL001*4'),(23875,0,230761517901,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',37,'eastar4','igal.avishai1','igal.avishai@gmail.com','Igal Avishai','Shikmim 11','Ness-Zyionna','','ISRAEL','74064','972-54-7438199','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 07:55:10',0,NULL,3,1,11,1,NULL,'eastar4\rLGRM001'),(23876,0,320865555616,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',27.2,'eastar4uk','igorlisenko','solo-car@yandex.ru','Игорь Лысенко','Танковая 45/3 -10','Новосибирск','Новосибирская область','RUSSIAN FEDERATION','630075','+79139334333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 08:22:50',0,NULL,3,1,11,1,NULL,'eastar4uk\rLGAD001'),(23877,806239083007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',137.99,'au-buy','jean-fla','jfla46@gmail.com','jean-flavien rochat','3/95 homer street','dianella','Western Australia','AUSTRALIA','6059','00610416399731','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 09:09:21',0,NULL,3,1,3,1,'RA184500482CN\r ','au-buy\rPSGL001*2'),(23878,954202346012,220886923190,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',17.95,'eastar4uk','adminlinknet','a.telicin@rambler.ru','alexey telitsyn','kashtanovaya house 20','stanica Kushchevskaya','Krasnodar region','RUSSIAN FEDERATION','352030','9034554212','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 09:20:43',0,NULL,3,1,11,1,NULL,'eastar4uk\rUM00008'),(23879,797635583008,180781265333,'New Grohe Twist Free 59\" Shower Hose chrome non-metallic Made in Germany',1,'OTGR002',21.9,'au-buy','2007gien','gslau75@hotmail.com','Brandon Lau','81 Hordern St.,<br>Newtown','Sydney','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 09:47:23',0,NULL,3,1,11,1,NULL,'au-buy\rOTGR002'),(23880,862282032011,320826634815,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',12.99,'eastar4uk','kuroko911','kuroko@gmail.com','Helena Bozic','Bicevje 1','Ljubljana','','SLOVENIA','1000','00386595097','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 09:53:29',0,NULL,3,1,11,1,NULL,'eastar4uk\rHBPH009'),(23881,638716551004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65.99,'cnfaner','websterm999','websterm74@verizon.net','michael webster','804 Waverly Dr','Salisbury','MD','UNITED STATES','21801-6228','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 10:19:13',0,NULL,3,1,1,1,'LK235600235CN ','cnfaner'),(23882,0,170804745914,'New Ultimate Ears MetroFi 220vi Noise-Isolating Earphones with Voice Capability',1,'HSUE003',10.99,'au-buy','raytheguy12','raymond1w@hotmail.com','Raymond Wang','4 Elizabeth St','Granville','New South Wales','AUSTRALIA','2142','0424360270','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 10:24:02',0,NULL,3,1,11,1,NULL,'au-buy\rHSUE003\r澳标'),(23883,814408672001,110832702660,'4 pairs of New in box Samsung SSG-3700CR 3D Active Ultra Rechargeable Glasses',1,'GLSG008*4',787.99,'buysia','southstorm74','southstorm@mail.ru','Vladimir Kozhevnikov','Universitetskaya<br>Naberezhnaya 38-71','Chelyabinsk','','RUSSIAN FEDERATION','454016','982-302-8505','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-18 10:39:10',0,NULL,5,0,18,0,NULL,'buysia\r缺货，已退款'),(23884,797673834008,180757093122,'Genuine Logitech G7 Rechargeable Battery for MX Revolution 600mAh',2,'BALO009',15.98,'au-buy','cpaml','cpamel@gmail.com','Melchior Lee','53A Pagoda Crescent','Quakers Hill','New South Wales','AUSTRALIA','2763','0296267182','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 11:13:28',0,NULL,3,1,11,1,NULL,'au-buy\rBALO009'),(23885,954259934012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','valdisryaba76','valdisryaba@ya.ru','Владислав Рябинин','ул. адмирала Васюнина, д.12, корп.1, кв.119','Нижний Новгород','','RUSSIAN FEDERATION','603106','8-904-065-7222','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 11:20:45',0,NULL,3,1,11,1,NULL,'eastar4\rWLAT009'),(23886,862319666011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','hamnaali','majidraza@talktalk.net','majid raza','18 bullroyd avenue','bradford','West Yorkshire','UNITED KINGDOM','bd8 0ax','07525729903','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 11:25:22',0,NULL,3,1,3,1,'RA184500465CN\r ','eastar4uk\rOTSO004'),(23887,797691254008,180836866138,'New in box SONY 3D Active Glasses TDG-BR250 rechargeable BR 250',1,'OTSO004',68.99,'au-buy','megaman.073','whiteinthezone@hotmail.com','William White','24/17 Marlow  Street<br>Woodridge','Logan City','Queensland','AUSTRALIA','4114','0731333512','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 11:53:43',0,NULL,3,1,3,1,'RA184500479CN\r ','au-buy\rOTSO004'),(23888,954281199012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','richwilko2k','donotcontactme@hotmail.co.uk','Richard Wilkinson','15 Kilton Court<br>Howdale Road','Hull','Humberside','UNITED KINGDOM','HU8 9FE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 12:05:05',0,NULL,3,1,3,1,'RA184500765CN\r ','eastar4uk\rMOMI002'),(23889,862356258011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','cassied_31','cassied31@yahoo.com','Casandra Rentas','161 W Hollis St<br>Apt C','Nashua','NH','UNITED STATES','03060-3147','(603) 233-1357','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 12:34:21',0,NULL,3,0,1,1,'LK235660018CN ','eastar4'),(23890,862382896011,320787483278,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',38.99,'eastar4','cabrelon','ronaldo@virabc.com.br','RONALDO','AV. QUEIROS FILHO, 137','SANTO ANDRÉ','SÃO PAULO','BRAZIL','09110260','(011) 4458-4235','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 13:26:39',0,NULL,3,1,11,1,' ','eastar4\rLGRM001'),(23891,797730579008,180821320427,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card+Tyco 2.4/5.0GHz Antenna',1,'WLAT001+ANTY002',15.95,'au-buy','l_blue_l','blueboy88@gmail.com','Chris Green','18  Fern  St<br>209','Surfers Paradise','Queensland','AUSTRALIA','4217','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 13:29:12',0,NULL,3,1,11,1,NULL,'au-buy\rWLAT001+ANTY002'),(23892,0,230761518190,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones Compatible w/iP',1,'HSAL002',6.75,'eastar4','heavenlybell','lou_flores03@yahoo.com','Lou Norman Flores','463 Machado Compound<br>Fr. E. Salvador Street, Sta Maria','Zamboanga City','','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 14:05:30',0,NULL,3,1,11,1,NULL,'eastar4\rHSAL002'),(23893,0,220976861154,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',24.99,'eastar4','jclark2143','jamesclark2@comcast.net','James Clark','2608 Moore Ave.','Baltimore','MD','UNITED STATES','21234','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 15:01:53',0,NULL,3,1,1,1,'LK235694025CN ','eastar4'),(23894,954362628012,220457504119,'Acer Aspire 7720 7720G 7720Z Bluetooth Module 2.0+cable',1,'BTAC2022',9.88,'eastar4','vroman0476','vroman1976@mail.ru','Volodymyr Roman','rua Almirante gago Coutinho<br>Nº6-2dt','Guarda','Guarda','PORTUGAL','6300-507','00351-271-109086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 15:04:46',0,NULL,3,1,11,1,'BJ01714165 ','eastar4\rBTAC2022\racer 8pin1.00 15cm '),(23895,0,220976889381,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',6.99,'eastar4uk','stubbsmlc','stubbsmlc@aol.com','Malcolm Stubbs','37 Crown Bank Crescent<br>Talke Pits','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST7 1SS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 15:22:28',0,NULL,3,1,3,1,'RA184500788CN\r ','eastar4uk\rHSJA002\r英标'),(23896,814549040001,110827288137,'New Logitech Cradle L-LG7 for Harmony remote 880 890 + US AC adapter',1,'CRLO001+POLO001',16.99,'buysia','sandrarama','sandrarama11@gmail.com','Sandra Meron','1862 red tail cres.','Kamloops','BC','CANADA','v2b8s9','(250) 376-7064','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-18 15:32:42',0,NULL,3,1,11,1,NULL,'buysia\rCRLO001+POLO001'),(23897,694424802013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','wyattchesley','daranderson@xplornet.ca','Daren J Anderson','5 Boardwalk Rd.<br>P.O. Box 122','Harrington Harbour','QC','CANADA','G0G 1N0','(418) 795-3301','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 15:41:43',0,NULL,3,1,3,1,'RA184590823CN\r\r\r ','eastar4\rGPS0004'),(23898,862476634011,320566963477,'Unlocked NEW Sierra Wireless WWAN MC8790 3G+antenna',1,'WWSI006+ANCN001',60.45,'eastar4','bambur_vmf','bambur.vmf@gmail.com','Anton Budarev','Dergaevskaya, 28, flat 209','RAMENSKOE','MOSKOVSKAYA OBLAST','RUSSIAN FEDERATION','140103','7-926-2369904','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 15:59:53',0,NULL,3,1,3,1,'RA184500425CN\r ','eastar4\rWWSI006+ANCN001'),(23899,862492308011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','alex_hs','alexhs@estvideo.fr','Alexandre Hessemann','8, rue du 8 mai 1945<br>Code porte 32A54','Bourg-la-reine','Ile-de-France','FRANCE','92340','06.72.68.33.46','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 16:21:21',0,NULL,3,1,11,1,NULL,'eastar4\rOTCN002'),(23900,862520123011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',2,'OTSO004',85.98,'eastar4uk','ebi5757','ebi57@hotmail.co.uk','Ebrahim Jahaniyan','111 Squires Lane','London','London','UNITED KINGDOM','N3 2AJ','07747093218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 16:56:36',0,NULL,3,1,3,1,'RA184500607CN\r ','eastar4uk\rOTSO004'),(23901,633267747003,130490219201,'New Logitech Cradle L-LG7 Harmony 880 890 w/US adapter',1,'CRLO001+POLO001',16.9,'cnfaner','wmcgarity','wmcgarity@gmail.com','Wade McGarity','3659 Rogers Dr','Douglasville','GA','UNITED STATES','30134-4353','(404) 625-1242','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 17:18:49',0,NULL,3,1,1,1,'LK235597451CN ','cnfaner'),(23902,633270971003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',46.99,'cnfaner','eddieshalom','dr.eddieshalom@gmail.com','Eddie  Shalom','Yaacov Cohen 7/9','Beer-Sheva','Israel','ISRAEL','84374','0508804979','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 17:23:58',0,NULL,3,1,3,1,'RA184500859CN\r ','cnfaner\rMOOE002\rOEM'),(23903,694500113013,230719960644,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',24,'OT00004',187.2,'eastar4','a12r1','a.baf@live.com','Ahmed A. Bafageeh-NEW2K','6147 Ar Ruwais District / AL-Andalus RD.<br>Saudi Electricity Company(head office) - Information Technology','Jeddah',':21413-POBox:','SAUDI ARABIA','9299','966500007650','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 17:48:40',0,NULL,3,1,3,1,'RA386088699CN\r ','eastar4\rOT00004\r一共买了25个'),(23904,859238729002,120868118837,'Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',45.99,'buysia','grisu-der-1','rosekoll@amassno.de','Rosemarie Kollmützer','Robert-Koch-Str. 7','Ottobrunn','','GERMANY','85521','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-18 17:33:04',0,NULL,3,1,3,1,'RA184500638CN\r ','buysia\rHBPH007'),(23905,0,140723816405,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',29.99,'cnfaner','hippoarthur','artrudan@mail.ru','Arthur Rudanov','Bondarnaya street 1 flat 8','Murmansk','Murmanskaya','RUSSIAN FEDERATION','183052','7-902-130-37-70','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 18:02:46',0,NULL,3,1,3,1,'RA184500933CN\r ','cnfaner\rLGAD001'),(23906,862573766011,320708628062,'New in box SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004',42.99,'eastar4uk','2011.era','angel26alex@hotmail.com','Dan Alexa','FLAT 1, 72 DEVONSHIRE  ROAD<br>PRINCES PARK','LIVERPOOL','Merseyside','UNITED KINGDOM','L8 3TZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 17:55:12',0,NULL,3,1,3,1,'RA184500584CN\r ','eastar4uk\rOTSO004'),(23907,862574008011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',18.99,'eastar4','osagekim','wland58@yahoo.com','young kim','2545 Osage Dr','glenview','IL','UNITED STATES','60026-1066','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 17:56:41',0,NULL,3,1,1,1,'LK235664187CN ','eastar4'),(23908,954555249012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',1,'BTSA2004',9.88,'eastar4','poqarfe','poq@gmx.de','Arne Felber','Parkring 21 (App. 47)','Mannheim','','GERMANY','68159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 18:18:09',0,NULL,3,1,11,1,'BJ01714172 ','eastar4\rBTSA2004\r4pin 1.25'),(23909,859484735002,120856120275,'New in box DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',44.89,'buysia','rodolfopoeys','rodpf@bol.com.br','rodolfo poeys ferreira','rua alcyr fernandes de oliveira 81 apt 301<br>bairro jardim bervely','miracema','rio de janeiro','BRAZIL','28460-000','00552238523433','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-18 18:54:12',0,NULL,3,1,3,1,'RA184500519CN\r ','buysia\rGLOT005'),(23910,862648267011,320665755395,'New in box ZAGG DUAL USB CAR CHARGER',1,'CCZG001',7.98,'eastar4','curanga24','carlosuranga@msn.com','Carlos J. Uranga','2912 SE 15th Rd','Homestead','FL','UNITED STATES','33035-2440','(305) 338-5045','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 19:00:03',0,NULL,3,1,1,1,'LK235619483CN ','eastar4\r新地址\rCarlos J. Uranga\r5795 NW 109 ave \runit 5, \rDoral Fl 33178\rUNITED STATES\r(305) 338-5045'),(23911,954532347012,220771653301,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005*10',14.2,'eastar4','armanchiksatenik','badkarmaa@bigmir.net','Satenik Aivazyan','62a Mayakovskovo  Str., Apt. 118','Kiev','Kiev district','UKRAINE','02222','0936574819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 19:41:11',0,NULL,3,1,11,1,NULL,'eastar4\rOTCN005*10'),(23912,638993115004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',1,'MOLO001',65.99,'cnfaner','yingning112','liuchenglin11@gmail.com','Joshua Hutchinson','3783 HWY 13','Wolf Point','MT','UNITED STATES','59201','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 19:51:54',0,NULL,3,1,1,1,'LK235625033CN ','cnfaner'),(23913,862704878011,320781476411,'New SONY ERICSSON MW600 BLUETOOTH STEREO HEADSET',1,'HSSE011',54.99,'eastar4','dimzel10','damir.kopajtic@gmail.com','Damir Kopajtic','Kukuljanovo<br>212b','Bakar','','CROATIA','51227','091/592-1366','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 19:54:18',0,NULL,3,1,3,1,'RA184500417CN\r ','eastar4\rHSSE011\r欧标'),(23914,693876054013,230653158623,'New Grohe handheld Shower Head big water output Massage',1,'OTGR005',22.9,'eastar4','ushanka*com','moscowusa1@gmail.com','Alex Poberezkin','13972 Mango Dr','Del Mar','CA','UNITED STATES','92014-3104','(858) 449-8401','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 20:56:27',0,NULL,3,1,1,1,'LK235743874CN ','eastar4\r'),(23915,633433287003,130598387084,'2 pairs of New in box SONY 3D Active Glasses TDG-BR250',1,'OTSO004*2',134.99,'cnfaner','aquamarine00','soilacetone@hotmail.com','Lyndsey Hart','28 Chimo Drive','Ottawa','ON','CANADA','K2L1A5','(613) 592-5043','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 21:16:41',0,NULL,3,1,3,1,'RA184500669CN\r ','cnfaner\rOTSO004*2'),(23916,0,320868695871,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.35,'eastar4uk','chippywendy','alanhamer1959@yahoo.co.uk','Alan Stephen Hamer','9 Roberts Street<br>Wombwell','Barnsley','South Yorkshire','UNITED KINGDOM','s730ln','01226340510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 21:33:03',0,NULL,3,1,3,1,'RA184500955CN\r ','eastar4uk\rSCLO002'),(23917,859629619002,120865585479,'New 44 Pin Female to Female Mini IDE Cable for PC 30 cm',1,'OTCN002',5.98,'buysia','antonionegreira','antonio.negreira@br.abb.com','Antonio Lopez','Rua Orissanga 280 apto 43','São Paulo','São Paulo','BRAZIL','04052-030','55 11 5585-2244','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-18 21:44:54',0,NULL,3,1,11,1,NULL,'buysia\rOTCN002'),(23918,0,220977820400,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',5.99,'eastar4uk','dunkley200','chazzy200@gmail.com','Charles Dunkley','20 Corran Close','Northampton','Northamptonshire','UNITED KINGDOM','NN57AL','01604755006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 22:06:54',0,NULL,3,1,3,1,'RA184500553CN\r ','eastar4uk\rHBPH003'),(23919,954797524012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','750bfkb','tigrgatr@gmail.com','ken benson','26886 Duffy Rd','sedro woolley','WA','UNITED STATES','98284-9090','(360) 856-6902','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 22:19:00',0,NULL,3,1,1,1,'LK235641570CN ','eastar4\r'),(23920,806778061007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','mmcf6419','megan@stonekithomes.com.au','Megan McFadden','151 Smeaton Grange Road','Smeaton Grange','New South Wales','AUSTRALIA','2567','0438312045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 22:30:16',0,NULL,3,1,4,1,'YW870147415CN\r ','au-buy\rUM00001\r3x purple and 2x blue ，1xblack\r一共6个\r'),(23921,862830862011,320826634741,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',32.99,'eastar4uk','cosmetics1','lynnrichardson729@btinternet.com','Lynn Richardson','9 Towcester Rd','Whittlebury','Northamptonshire','UNITED KINGDOM','NN12 8XU','07515916546','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 22:35:16',0,NULL,3,1,3,1,'RA184500726CN\r ','eastar4uk\rHBPH007'),(23922,636487542004,140516496368,'10 pcs CentreCom AT-210TS Ethernet Transceiver AUI/RJ45',1,'TRTS001*10',84,'cnfaner','fz2l6r','alabit2003@yahoo.com','timothy alabi','7124 Stone Throw way','Elkridge','MD','UNITED STATES','21075-7902','(410) 799-6650','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 23:13:39',0,NULL,3,1,1,1,'\\ ','cnfaner'),(23923,633486452003,130620865308,'Lowrance iFinder H2O C GPS+WAAS Compact handheld GPS Receiver',1,'GPS0004',108.99,'cnfaner','crankbait321','shoutdoors@hotmail.com','Sean Hoernke','31 Bark Bend Pl','Conroe','TX','UNITED STATES','77385-3755','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-18 23:54:20',0,NULL,3,1,1,1,'LK235601068CN ','cnfaner'),(23924,954851603012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','hughes457','hughes457@googlemail.com','chris hughes','6 maxholm road<br>streetly sutton coldfield','birmingham','West Midlands','UNITED KINGDOM','b74 3su','07887754328','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 00:04:08',0,NULL,3,1,3,1,'RA184500902CN\r ','eastar4uk\rHSJA002\r英标'),(23925,798206913008,180757094477,'Original New Replaceable Shell for logitech Performance MX Mouse M950',1,'SHLO002',17.99,'au-buy','sonic_it','joseph@sonicit.com','Sonic I.T','45 Henderson Ave<br>Pooraka','Adelaide','South Australia','AUSTRALIA','5095','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 01:14:50',0,NULL,3,1,11,1,NULL,'au-buy\rSHLO002'),(23926,8881332120119034,111,'Free Shipping & Tracking # !!! NEW Genuine USB Wired Optical Mighty Mouse A1152 for Apple - ',1,'MOAP001',27.99,'aliexpress','1007468701','1@1.com','Bruno Vince','Rua Cavalheiro Ernesto Giuliano, 771 Apto 14','Sao Caetano do Sul','SP/Brazil','BRAZIL','09570400','85205101/+55 11 42320716',NULL,NULL,NULL,'2012-03-19 01:21:59',0,NULL,3,1,3,1,'RA184501721CN ','MOAP001 '),(23927,0,220977820376,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.06,'eastar4uk','luckyhappy12','mawindeehongphan@gmail.com','mawindee hongphan','99/432 ,Phaholyothin Rd. Soi Klongluang10<br>Klongnueng','Klongluang','Patumthanee','THAILAND','12120','8865836392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 01:38:47',0,NULL,3,1,11,1,NULL,'eastar4uk\rPOLO001'),(23928,0,110843211590,'New Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',0.99,'buysia','atf_mountaindew','stoshua@gmail.com','Stosh Przychowicz','108 S Main St Apt 3','North Wales','PA','UNITED STATES','19454','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-19 01:56:40',0,NULL,3,1,1,1,'LK235679765CN ','buysia'),(23929,954905637012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',49.99,'eastar4','lancelotbrasil','feliperdr@uol.com.br','FELIPE RODRIGUES','RUA ALIANCA N.40<br>-BAIRRO PENHA','SAO PAULO','SP','BRAZIL','03715-000','+551126423436','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 02:04:11',0,NULL,3,1,3,1,'RA184500451CN\r ','eastar4\rKBFF001'),(23930,954908568012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',49.99,'eastar4','lancelotbrasil','feliperdr@uol.com.br','FELIPE RODRIGUES','RUA ALIANCA N.40<br>-BAIRRO PENHA','SAO PAULO','SP','BRAZIL','03715-000','+551126423436','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 02:10:25',0,NULL,5,0,18,0,NULL,'eastar4\r客户买重了\r这票 退款 并删单'),(23931,0,220977564128,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',15.5,'eastar4','faunlee','wmlaucis@aol.com','James Wylie','421 Wedgewood Dr','Gulf Shores','AL','UNITED STATES','36542-3047','(256) 391-6833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 02:23:35',0,NULL,3,1,1,1,'LK235757255CN ','eastar4'),(23932,862941583011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','bnucci24','brian_nucci@hotmail.com','Brian  Antonucci','42 Danbury Rd','TINTON FALLS','NJ','UNITED STATES','07753-7918','(732) 918-8658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 03:02:44',0,NULL,3,1,1,1,'LK235816979CN ','eastar4'),(23933,806881191007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',99.95,'au-buy','mmcf6419','megan@stonekithomes.com.au','Megan McFadden','151 Smeaton Grange Road','Smeaton Grange','New South Wales','AUSTRALIA','2567','0438312045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 03:03:53',0,NULL,3,0,17,0,'YW870147415CN ','au-buy'),(23934,954933530012,220850740440,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',68.9,'eastar4','watitsthis','cakepiesim@gmail.com','Josue Eduarte','13155 SW 134th St<br>Ste 125','Miami','FL','UNITED STATES','33186-4488','(305) 975-2110','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 03:17:21',0,NULL,3,1,1,1,'\\ ','eastar4\rHBPH001'),(23935,862955588011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','ajprop','jb@sdcpm.com','James Burrell','1133 Thistlewood Ave','CHULA VISTA','CA','UNITED STATES','91913-1571','(619) 742-8543','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 03:54:24',0,NULL,3,1,1,1,'\\ ','eastar4'),(23936,862961324011,320812367649,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102  Tk 102',2,'GPS0010',39.98,'eastar4uk','marxiecorporation','marxiecorp@gmail.com','Ozspy Brunswick - Martin Gomulya','Shop 1, 259 Sydney Road','Brunswick','Victoria','AUSTRALIA','3056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 04:19:13',0,NULL,3,1,3,1,'RA184500377CN ','eastar4uk\rGPS0010'),(23937,0,320865575720,'NIB 2200mAh Rechargeable Universal Mobile Charger 4 iphone ipad ipod nokia HTC',1,'OT00008',5.99,'eastar4uk','finnishdeal','pirx@live.fi','Pirkko Palm','Lupajantie 4-6 A 6','Helsinki','Uusimaa','FINLAND','00970','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 05:07:53',0,NULL,3,1,11,1,'BJ01714159 ','eastar4uk\rOT00008\r银色的'),(23938,806915939007,170761450095,'New Original FireFly Borealis Illuminated USB long-lasting lighting  Keyboard',1,'KBFF001',55.99,'au-buy','phillipp6149','phillipp49@gmail.com','Phillip Plaisted','95 Farr St','Rockdale','New South Wales','AUSTRALIA','2216','61295677853','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 05:54:59',0,NULL,3,1,3,1,'RA386089632CN\r ','au-buy\rKBFF001'),(23939,8881332137540709,111,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',0,'eastar4','kym39','mykeydee1957@yahoo.com.au','Kym Wallace','Unit 2<br>576 Norman Road','North Rockhampton','Queensland','AUSTRALIA','4701','0749140741',NULL,NULL,NULL,'2012-03-19 06:12:20',0,NULL,3,1,11,1,'BJ01713506 ','UM00033\r补发的\rEASTAR4\r发一把带点点的 '),(23940,806923602007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.29,'au-buy','witold_nz','giejwito@xnet.co.nz','Witold Giejsztowt','38 Wingate','Christchurch','Canterbury','NEW ZEALAND','8051','0064 3 3529130','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-19 06:45:32',0,NULL,3,1,11,1,'BJ01714160 ','au-buy\rRELO002'),(23942,954985272012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','jpenno','lpennington@hotmail.co.uk','john pennington','47 bagot grove sneyd green','stoke-on-trent','Staffordshire','UNITED KINGDOM','st16jf','01782262077','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 07:16:00',0,NULL,3,1,3,1,'RA184500213CN ','eastar4uk\rHSJA002\r英标'),(23943,860817280011,320691247750,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',47.89,'eastar4uk','kofrukt','michalik.radek@seznam.cz','Radek Michalík','Javorová  1521','Veselí nad Moravou','','CZECH REPUBLIC','698 01','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 07:47:03',0,NULL,3,1,3,1,'RA184500227CN ','eastar4uk\rOTSO002\r\r\r'),(23944,8881332143861508,111,'Replaceable Shell for logitech Anywhere MX Mouse M905',1,'SHLO005',9.99,'eastar4uk','ascospora','alexbred@tiscali.it','Alessandro BREDA','via Carso nr.22',' ARCORE (MB)','','ITALY','20862','',NULL,NULL,NULL,'2012-03-19 07:57:41',0,NULL,3,1,11,1,'BJ01714157 ','SHLO005\rEASTAR4UK\r直接打的款 '),(23945,0,140723777868,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',4.25,'cnfaner','don_luigi_72','ludvikk@gmail.com','Ludvik Krulik','Cesta Gradenj 1','Vrhnika','','SLOVENIA','1360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 08:05:27',0,NULL,3,1,3,1,'RA184500292CN ','cnfaner\rRCHP001'),(23946,639207570004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',44.5,'cnfaner','julya9532','9949948@gmail.com','Zhukov Alexandr','Nagornaya 22-2-40','Moscow','MOSCOW','RUSSIAN FEDERATION','117186','+7 (916) 9949948','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 08:56:00',0,NULL,3,1,3,1,'RA184500289CN ','cnfaner\rGLOT005'),(23947,955019700012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','cjerome','jerome.capton@gmail.com','Jerome Capton','34 rue du Clos Saint-Georges','Le Breuil en Auge','Basse-Normandie','FRANCE','14130','0951641959','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 09:31:43',0,NULL,3,1,3,1,'RA184500235CN ','eastar4\rPSGL001*2'),(23948,806968025007,170762819519,'Brand new HP MCE Media Center Remote Control bigger + IR RECEIVER+IR Emitter',1,'OTHP004',20.8,'au-buy','sxtacy','rahul@rahul.com.au','Rahul Dudeja','Level 24, 242 Exhibition St<br>Telstra Building','Melbourne','Victoria','AUSTRALIA','3000','0448339541','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 09:57:02',0,NULL,3,1,11,1,'BJ01713508\r ','au-buy\rOTHP004'),(23949,0,140723777904,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',11.49,'cnfaner','ahj101211','angel_p13@yahoo.com','Angel Patterson','117 Kammerer Dr','Statesville','NC','UNITED STATES','28625-1651','(704) 682-0552','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-19 10:11:19',0,NULL,3,1,1,1,'LK236497698CN\r ','cnfaner'),(23950,806261303007,170735464388,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons',1,'UM00008',27.99,'au-buy','popeye040178','joeydale@tpg.com.au','Dale Donovan','338 The Parkway','Bradbury','New South Wales','AUSTRALIA','2560','0409283860','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 10:53:47',0,NULL,3,1,11,1,'BJ01714140\r ','au-buy\rUM00008'),(23951,863053419011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','khmercub','jlumkl@gmail.com','Jeffrey Lum','PO Box 570','Phnom Penh, Cambodia','','CAMBODIA','0000','+855 12 222301','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 11:02:47',0,NULL,3,1,11,1,'BJ01714141\r ','eastar4\rWLAT003'),(23952,806989670007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',18.99,'au-buy','yimo123','yimod@yahoo.com','Hannah Liu','22 La Trobe Close','Douglas','Queensland','AUSTRALIA','4814','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 11:11:12',0,NULL,3,1,11,1,'BJ01714151\r ','au-buy\rUM00001\r黑色'),(23953,639235402004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','123-mogane','kurtroar@broadpark.no','Kurt Roar Johansen','Martin Stokkens vei 45','Trondheim','Sør-Trøndelag','NORWAY','7027','(+47)92802359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 11:17:26',0,NULL,3,1,3,1,'RA184500099CN\r ','cnfaner\rHSJA002\r欧标'),(23954,863066550011,320816532466,'New Philips Bluetooth Stereo Over-the-Ear Headset SHB9100',1,'HSPH008',109.99,'eastar4','fa-skam','salvagedump@yandex.ru','Denis Sitkevich','ul. Popovicha, d. 25, kv. 31','Yuzhno-Sakhalinsk','Sakhalin Region','RUSSIAN FEDERATION','693010',' 89241817311','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 11:47:14',0,NULL,3,1,3,1,'RA184500125CN\r ','eastar4\rHSPH008'),(23955,0,140723807766,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',25.11,'cnfaner','voto11','playsbestwhenwet@yahoo.com','Vaughn Ownbey','194 Birkhall Cir','Greenville','SC','UNITED STATES','29605','(864) 248-0877','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-19 12:12:33',0,NULL,3,1,1,1,'LK236510978CN\r ','cnfaner'),(23956,863078471011,320820766166,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',14.99,'eastar4uk','cwood71dc','chriswood72@hotmail.com','Chris Wood','Science and Education Dept, BMA<br>BMA House, Tavistock square','London','London','UNITED KINGDOM','WC1H 9JP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 12:19:17',0,NULL,3,1,3,1,'RA184500187CN\r ','eastar4uk\rHSAL001'),(23957,0,220977818813,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',21.01,'eastar4uk','leaffield','lyn@leaffield.co.uk','lyn farrell','23 Queensway','Rotherham','South Yorkshire','UNITED KINGDOM','S60 3EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 12:36:59',0,NULL,3,1,3,1,'RA184500200CN\r ','eastar4uk\rHBPH007'),(23958,955081118012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','asturyan','lemarchand.marc@wanadoo.fr','Marc Lemarchand','44 résidence du Mascaret','Precey','Basse-Normandie','FRANCE','50220','02.33.48.13.75','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 12:37:40',0,NULL,3,1,3,1,'RA184500071CN\r ','eastar4\rPSGL001*2'),(23959,955082815012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','martywhet','martywet@twcny.rr.com','Martha L. Whetzel','2889 Slaterville Rd','Brooktondale','NY','UNITED STATES','14817-9504','(607) 539-7868','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 12:40:26',0,NULL,3,1,1,1,'LK236641545CN\r ','eastar4'),(23960,0,180843434610,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',1,'CC00002',24.83,'au-buy','hsv_addict','hsv_addict@hotmail.com','linton bauer','15 james st','castlemaine','Victoria','AUSTRALIA','3450','0432024854','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 12:47:43',0,NULL,3,1,11,1,'BJ01714169\r ','au-buy\rCC00002\r'),(23961,0,180843434584,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',32.5,'au-buy','toipaibr','astorlinden@hotmail.com','ASTOR LINDEN','RUA ODORICO MOSMANN, 246 - CENTRO','PAROBÉ','RS','BRAZIL','95630-000','+555192619321','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-19 12:54:11',0,NULL,3,1,11,1,'BJ01714168\r ','au-buy\rLGAD001'),(23962,0,220976859754,'New Portable HD 720P Car Dashboard Camera Accident DVR',1,'CC00002',25.52,'eastar4','grigorich-802012','grigorich-80@mail.ru','Oleg Bezditko','Uborevycha 8A , kv. 55','Kharkov','','UKRAINE','61144','380961900341','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 13:18:19',0,NULL,3,1,11,1,'BJ01714139\r ','eastar4\rCC00002'),(23963,807038351007,170752343589,'New Grohe Multi Function hand Shower Head has Seven pattens no water pipe',1,'OTGR001',19.86,'au-buy','jeruk3','atan.s@optusnet.com.au','Atan Subakti','22 Hornet Rise','Willetton','Western Australia','AUSTRALIA','6155','0416036711','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 13:43:48',0,NULL,3,1,11,1,'BJ01714170\r ','au-buy\rOTGR001'),(23964,955115358012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',263.99,'eastar4','willisroses10523','willisroses10523@aol.com','SANDRA WILLIS','2905 W Spruce St','TAMPA','FL','UNITED STATES','33607-3231','(813) 349-4843','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 14:00:28',0,NULL,3,1,1,1,'LK236664339CN\r ','eastar4'),(23965,955115105012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',165.99,'eastar4uk','frosty1300','matkin66@yahoo.co.uk','Mark Atkin','10 Ridding Court','Esh Winning','Durham','UNITED KINGDOM','DH79HY','01913736896','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 14:00:38',0,NULL,3,1,4,1,'YW867611490CN  ','eastar4uk'),(23966,639286485004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',44.5,'cnfaner','cromugnon','cromugnon@hotmail.com','Nestor Cons Perez','Pazos 68, Marcon','Pontevedra','Galicia','SPAIN','36158','622322382','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 14:47:35',0,NULL,3,1,3,1,'RA184500054CN\r ','cnfaner\rGLOT005\r黑色的'),(23967,955137853012,220451379732,'Acer Travelmate 7730 7730A Bluetooth Module 2.0+cable',1,'BTAC2011',9.88,'eastar4','dam62200','mouskito62@hotmail.fr','Damien Hocq','27, rue du Camp de Droite','Boulogne sur Mer','Nord-Pas-de-Calais','FRANCE','62200','06.23.39.00.25','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 14:55:17',0,NULL,3,1,11,1,'BJ01714144\r ','eastar4\rBTAC2011\racer 5pin1.25 4cm'),(23968,857861671002,120868118049,'New Microsoft Wired Optical Wheel Mouse Black',5,'MOMI002',68.95,'buysia','gustav_1953','w.supper@pcc.at','Walter Supper','Raiffeisenstr. 154','Graz','','AUSTRIA','8041','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-19 15:00:50',0,NULL,3,1,3,1,'RA184500037CN\r ','buysia\rMOMI002'),(23969,694919132013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','amardeepi','sabhisira@gmail.com','Amarbir Sira','WiFi Computers<br>105 Father Tobin Rd Unit 3','Brampton','ON','CANADA','L6R 0W9','(905) 789-9434','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 15:05:19',0,NULL,3,1,11,1,'BJ01714150\r ','eastar4\rOTHP003'),(23970,955153535012,220775635216,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',13.66,'eastar4','vshukayev2012','vshukayev@gmail.com','Vadym Shukayev','7/7 VASYLKIVSKA STR','Kyiv','','UKRAINE','03040',' 0631616083','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 15:37:51',0,NULL,3,1,11,1,'BJ01714148\r ','eastar4\rMOMI002'),(23971,863139984011,320730087234,'New IBM/ThinkPad Mini PCI Atheros 5213A AR5BMB CARD',1,'WLAT006',7.49,'eastar4uk','thisisconcept','contact@thisisconcept.co.uk','Concept Computers','13 Southtown Road','Great Yarmouth','Norfolk','UNITED KINGDOM','NR310HU','01493444111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 15:43:18',0,NULL,3,1,3,1,'RA184500244CN\r ','eastar4uk\rWLAT006'),(23972,632388899003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',1,'GLOT001',39.5,'cnfaner','andreysa','sapelnikov@mail.com','Andrey Sapel\'nikov','Ural\'skay, house 5, flat 1','Novoural\'sk','RU','RUSSIAN FEDERATION','624130','89533819431','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 15:54:46',0,NULL,3,1,3,1,'RA184500045CN\r ','cnfaner\rGLOT001'),(23973,863161081011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',2,'GLOT001',51.98,'eastar4uk','brennan1612','elliottdjbrennan@gmail.com','Elliott Brennan','19 Howes Drive<br>Marston Moretaine','Bedford','Bedfordshire','UNITED KINGDOM','MK43 0FD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 16:02:58',0,NULL,3,1,3,1,'RA184500160CN\r ','eastar4uk\rGLOT001'),(23974,633701310003,130553148360,'New Jabra JX10 Series II 2 Wireless Bluetooth headset',1,'HSJA012',18.98,'cnfaner','6el4atina','travmat777@gmail.com','Sergey Konach','Leningradska, 3-D/102','Nikolaev','','UKRAINE','54052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 16:46:33',0,NULL,3,1,3,1,'RA184500108CN\r ','cnfaner\rHSJA012\r欧标\rsilver'),(23975,863193878011,320814060678,'New Double-Reinforced India Flower Transparent Dome Birdcage Stick Umbrella',1,'UM00051',24.99,'eastar4','kunosha','kunorus@gmail.com','Ilya Orehov','Micro.1 home 45 app. 44','Moskovskiy','Moskovskaya oblast, Leninskiy rayon','RUSSIAN FEDERATION','142784','+79263601889','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 17:09:50',0,NULL,3,1,11,1,'BJ01714137\r ','eastar4\rUM00051'),(23976,860023155002,120869720668,'Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'buysia','foxstrat89','foxstrat@bk.ru','Kirill Kazakov','1 Rabfakovskiy pereulok, dom 3, kv. 18','Sankt-Peterburg','Sankt-Peterburg','RUSSIAN FEDERATION','192012','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-19 17:06:13',0,NULL,3,1,11,1,'BJ01714147\r ','buysia\rUM00001\r紫色的'),(23977,863210706011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','manolis1984','manolismagos@hotmail.com','MANOLIS MAGOS','FLASKAS','KALYMNOS','DODEKANISA','GREECE','85200','2243028777','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 17:41:27',0,NULL,3,1,11,1,'BJ01714163\r ','eastar4uk\rGLOT001'),(23978,955220616012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','rem989','mspencer@telus.net','Mark Spencer','2965 Roseglen Court','Burnaby','BC','CANADA','V5A3W4','(604) 762-4099','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 17:46:16',0,NULL,3,1,11,1,'BJ01714152\r ','eastar4\rTRMX003'),(23979,0,130665893601,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',0.97,'cnfaner','hiufanwong','hiufan@me.com','Jason wong','5040 W State Road 46<br>Ste 1114','Sanford','FL','UNITED STATES','32771-9249','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-19 17:47:23',0,NULL,3,1,1,1,'LK236490482CN\r ','cnfaner'),(23980,0,220977818787,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',20.02,'eastar4uk','goonia13','goonia_b@hotmail.com','Gosia Brzozowska','14 Buttercup Lane<br>East Ardsley','Wakefield','West Yorkshire','UNITED KINGDOM','WF3 2LU','01924823189','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 17:47:47',0,NULL,3,1,3,1,'RA184500258CN\r ','eastar4uk\rGLOT001'),(23981,863217489011,320727196877,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.5,'eastar4','fredmac08','fredmac_cmob@yahoo.com','Fredrick McHenry','419 Cambridge Dr','Desoto','TX','UNITED STATES','75115-5607','(713) 231-6940','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 17:55:52',0,NULL,3,1,1,1,'LK236681195CN\r ','eastar4'),(23982,694990967013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','eosyslov','eosyslov-mail@uniquitous.net','cheol-woong kim','#503 Anyang Megavalley, 799<br>Kwanyang, Dongan','Anyang','Kyoungki','KOREA,REPUBLIC OF','431-767','(010) 9367-4251','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 18:30:37',0,NULL,3,1,11,1,'BJ01714153\r ','eastar4\rWLAP008'),(23983,694990874013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','roma_pop','roma_pop@apollo.lv','Roman Lisovoy','Roņu iela 8 - 2<br>Ķekavas pag.','Katlakalns','Ķekavas nov','LATVIA','LV-2111','(371)29229441','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 18:31:37',0,NULL,3,1,11,1,'BJ01714149\r ','eastar4\rWLIN014'),(23984,863258583011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tdogtrone','tronehall@yahoo.com','trone hall','1220 W 37th St','lorain','OH','UNITED STATES','44053-2766','(440) 670-3755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 19:09:45',0,NULL,3,1,1,1,'LK237753741CN\r ','eastar4'),(23985,955282843012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',165.99,'eastar4uk','forsyth19gail','gailwhyte12@btinternet.com','Gail Whyte','19 Muirfield Road','Dundee','Dundee (City of)','UNITED KINGDOM','DD3 8NW','01382810028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 19:18:32',0,NULL,3,1,4,1,'YW867611453CN ','eastar4uk'),(23986,695019181013,230729621562,'Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n  BlueToo',1,'ANTY002',4.99,'eastar4','marlo_teeuwen','marloteeuwen@home.nl','Marlo Teeuwen','Meijelseweg 16','Beringe','','NETHERLANDS','5986 NJ','0773076558','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 19:30:38',0,NULL,3,1,11,1,'BJ01714138\r ','eastar4\rANTY002'),(23987,863280618011,320679542166,'Original Allied Telesyn AUI AT-210T Transceiver10Base-T',1,'TRTT002',9.99,'eastar4','honda-pol','polik666@yahoo.de','Mr. Obnorsky Vlodimir','M. Tuhachewskogo 39 kv.95','Sankt -Petersburg','Russia','RUSSIAN FEDERATION','195067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 19:36:00',0,NULL,3,1,11,1,'BJ01714173\r ','eastar4\rTRTT002'),(23988,0,220977818730,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',39,'eastar4uk','blake7-2008','blakeledge@btinternet.com','Chris Blakeledge','9 Albury Way','Wigan','Lancashire','UNITED KINGDOM','WN2 1BN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 19:41:44',0,NULL,3,1,3,1,'RA184500195CN\r ','eastar4uk\rPSGL001'),(23989,955305175012,220763380845,'NewGenuine SonyEricsson HBH-PV710 710 Bluetooth Headset',1,'HSSE008',24.9,'eastar4uk','okan99','serhat_64@hotmail.de','Okan Akuygur','astrid lindgren str 40','münchen','','GERMANY','81829','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 19:51:02',0,NULL,3,1,11,1,'BJ01714167\r ','eastar4uk\rHSSE008\r欧标'),(23990,0,220974194056,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',3.2,'eastar4uk','ghost2oo2008','ghost2oo@live.co.uk','Leon Drew','30 Thirsk Road','South Norwood','London','UNITED KINGDOM','se25 6qg','02084050116','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 19:54:30',0,NULL,3,1,3,1,'RA184500173CN\r ','eastar4uk\rOT00004'),(23991,815313854001,110837938896,'Super Light Bubble Pattern Windproof Rain/Sun Umbrella w/24 Skeleton',2,'UM00049',49.98,'buysia','ldnshop1976','ldn_mail@ukr.net','Dmitry Lepenkov','Dubninskaya St., 40a, korpus 1, kv.155','Moscow','','RUSSIAN FEDERATION','127591','+7-916-625-06-57','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-19 19:57:28',0,NULL,3,1,3,1,'RA184500068CN\r ','buysia\rUM00049\r红色的和桔色的'),(23992,863299673011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','tdogtrone','tronehall@yahoo.com','trone hall','1220 W 37th St','lorain','OH','UNITED STATES','44053-2766','(440) 670-3755','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 20:12:45',0,NULL,5,0,18,0,NULL,'eastar4'),(23993,695051881013,230445487408,'NEW Apple Atheros AR9280 AR5BXB92 Mini Pci-e AGN 300Mbp',1,'WLAP008',19.88,'eastar4','midex1','e.f@mail.bg','Plamen Gerov','Hristo G.Danov str. 12, fl.3','Plovdiv','Plovdiv','BULGARIA','4000','(+359)887684898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 20:37:45',0,NULL,3,1,11,1,'BJ01714164\r ','eastar4\rWLAP008'),(23994,0,170802049837,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',59,'au-buy','sigmarilion','thesigmarilion@hotmail.com','OSCAR GARCIA GOMEZ','C/ ULPIANO 24 PISO 1-B','TORREVIEJA-ALICANTE','Comunidad Valenciana','SPAIN','03182','965705618','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-19 21:26:25',0,NULL,3,1,3,1,'RA184500023CN\r ','au-buy\rPSGL001'),(23995,863353053011,320730083728,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mb',1,'WLAT008',6.89,'eastar4uk','gandalf92_fr','david@derrida.fr','David Derrida','187 rue de Courcelles','Paris','Paris','FRANCE','75017','0952812323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 21:27:38',0,NULL,3,1,11,1,'BJ01714171\r ','eastar4uk\rWLAT008'),(23996,863372763011,320443640787,'Acer Timeline 1810 1410 1410T Bluetooth Module 2.0',1,'BTAC2010',9.88,'eastar4','le_yaniv','leyaniv@gmail.com','Yaniv Levinsky','Sderot HaLamed-Heh 4','Haifa','','ISRAEL','32204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 22:03:59',0,NULL,3,1,11,1,'BJ01713504\r ','eastar4\rBTAC2010\racer 5pin 1.25 3cm\r客户要换成2.1Acer Timeline 1810 1410 1410T Bluetooth Module cable\r\r客户补了差价'),(23997,695109747013,230463761507,'Cisco 3FT Back to Back DCE/DTE DB60 Crossover Cable',1,'CASS003',10.99,'eastar4','melatdel','melwinds@gmail.com','Melwin D\'souza','Suite 2, Ground Floor<br>460 Lower Heidelberg Rd','Melbourne','Victoria','AUSTRALIA','3084','0402385744','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 23:16:13',0,NULL,3,1,11,1,'BJ01714145\r ','eastar4\rCASS003'),(23998,863414546011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','vaporaizer','p.tavoularis@gmail.com','Panagiotis Tavoularis','Psaron 12','Pallini','Attica','GREECE','15351','(030)2106033237','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 23:45:42',0,NULL,3,1,11,1,'BJ01714166\r ','eastar4uk\rMOAP001'),(23999,629048616003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',18.99,'cnfaner','jerseytom600','thomasgmango@aol.com','Thomas Manganiello','600 Whitecomb Ave','Jackson','NJ','UNITED STATES','08527-5230','(732) 408-1444','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-19 23:41:47',0,NULL,3,1,1,1,'LK236480661CN\r ','cnfaner'),(24000,863428930011,320752638721,'Replacement LCD Touch Screen Glass Digitizer iPhone 3GS',1,'',8.99,'eastar4','fperboni','fperboni@gmail.com','Fernando Perboni','Rua Duarte Schutel, 89<br>Centro','Florianopolis','Santa Catarina','BRAZIL','88015-640','48-32252359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 00:25:16',0,NULL,3,0,11,1,'BJ01714136\r ','eastar4'),(24001,0,120878273553,'New US Logitech Harmony AC Power Adapter',1,'POLO001',0.99,'buysia','aldefevere','defevere@sbcglobal.net','Alan DeFevere','127 W. Live Oak St<br>Apt 2','San Gabriel','CA','UNITED STATES','91776-1392','(626) 695-2258','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-20 01:01:54',0,NULL,3,1,1,1,'LK236514008CN\r ','buysia'),(24002,863445250011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','pgoff1952','peggygoff52@yahoo.com','Peggy Goff','1021 Lorraine St','Memphis','TN','UNITED STATES','38122-2160','(901) 734-0014','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 01:15:27',0,NULL,3,1,1,1,'LK236666272CN\r ','eastar4'),(24003,8881332206712862,111,'Free shipping - 2 pairs of DLP-Link 3D Ready Projector Active Shutter Glasses - ',1,'GLOT005*2',88.99,'aliexpress','1007497370','sergey@voino.spb.ru','Voino Sergey','Komendantskiy prospekt house 11 flat 130','Saint-Petersburg','Russia','RUSSIAN FEDERATION','197227','+7 911 2131292',NULL,NULL,NULL,'2012-03-20 01:25:12',0,NULL,3,1,3,1,'RA184501735CN ','GLOT005*2 '),(24004,8881332206908181,111,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102 - ',1,'GPS0006',70.99,'aliexpress','1007514583','maurb@ig.com.br','	MAURICIO RODRIGUES BASTOS','RUA MARTINHO DE ALBOIN 20 JARDIN SANTA TERESINHA','SAO PAULO','','BRAZIL','03572250','+55 11 92107936',NULL,NULL,NULL,'2012-03-20 01:28:28',0,NULL,3,1,3,1,'RA184501749CN ','GPS0006 '),(24005,798731141008,180836304464,'New Apple Atheros Dual-Band AR9280 AR5BXB92 AGN 300Mbps',1,'WLAP008',18.89,'au-buy','cocovanya','ozzymas@gmail.com','Victor Masyuk','107 Turner Road','Berowra Heights','New South Wales','AUSTRALIA','2082','0404414064','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 01:57:53',0,NULL,3,1,11,1,'BJ01713507\r ','au-buy\rWLAP008'),(24006,694917917013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',77.99,'eastar4','lizzie061342010','lizzie06134@yahoo.com','Elizabeth Donnelly','108 Meadowdale Ct<br>Apt 203','Carpentersville','IL','UNITED STATES','60110-2035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 01:59:44',0,NULL,3,1,1,1,'LK236654190CN\r ','eastar4'),(24007,8881332214028719,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Martin Braunschweig ','31 FAIR LN','JERICHO,','NY','UNITED STATES','11753-2309 ','',NULL,NULL,NULL,'2012-03-20 03:27:08',0,NULL,3,1,3,1,'RA184500085CN\r ','MOAP001 \reastar4\r直接打款  '),(24008,8881332214173939,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','MK Woo ','12 Glen Park Road','Purchase,','New York ','UNITED STATES','10577 ','',NULL,NULL,NULL,'2012-03-20 03:29:33',0,NULL,3,1,3,1,'RA184500111CN\r ','MOAP001 \reastar4\r直接打款   '),(24009,8881332214456531,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com',' scott greenberg ','100 RACEWAY PARK DR','DR MOSCOW MILLS','MO','UNITED STATES','63362-1725','',NULL,NULL,NULL,'2012-03-20 03:34:16',0,NULL,3,1,3,1,'RA184500139CN\r ','MOAP001 \reastar4\r直接打款    '),(24010,0,220980410748,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',2.24,'eastar4','dbraun36667','dbraun21@yahoo.com','David Braun','7 Churchill Street','St. Catharines','ON','CANADA','L2S 2P3','(905) 937-6721','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:04:54',0,NULL,3,1,11,1,'BJ01713513\r ','eastar4\rMOFP001'),(24011,0,320871118956,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista small',1,'RCHP002',2.99,'eastar4','damakor','frederictre@hotmail.com','Frédéric Tremblay','1-11½ Rue Notre-Dame','Québec','QC','CANADA','G1K4E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:09:38',0,NULL,3,1,11,1,'BJ01714143\r ','eastar4\rRCHP002'),(24012,0,320871123110,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',15.99,'eastar4','clarin','clarin@themillion.com','Fabian Waintal','13418 Parkview Ter','Chino Hills','CA','UNITED STATES','91709-3504','(818) 784-5761','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 04:13:37',0,NULL,3,1,1,1,' lk237018671cn','eastar4'),(24013,0,220980416933,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',0.55,'eastar4','runtwo','runtwo36484@gmail.com','Kirill Kazanov','Krasnoobsk, Vostochnaya ul. 23-1','Novosibirsk','Novosibirskaya obl','RUSSIAN FEDERATION','630501','79529379760','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:39:08',0,NULL,3,1,11,1,'BJ01714142\r ','eastar4\rANTY001'),(24014,949662785012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',49.98,'eastar4','ashcroft1949','dianneashcroft49@hotmail.com','dianne heenan','41 fahey street<br>shepparton','shepparton','Victoria','AUSTRALIA','3630','0401458149','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:40:14',0,NULL,3,1,3,1,'RA386089014CN\r ','eastar4\rUM00034+UM00024\r再发一把\rNew lady Leopard lines w/lace Bowtie sun stick Umbrella\r'),(24015,639541867004,140630816288,'New Microsoft Wired Optical Wheel Mouse White',2,'MOMI004',27.2,'cnfaner','werock4u','bob@iyndistributions.com','IYN Distributions (Attn: Bob)','2029 Opportunity Dr<br>Ste 5','Roseville','CA','UNITED STATES','95678-3009','(916) 705-6821','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 05:28:53',0,NULL,3,1,1,1,'LK236896823CN\r ','cnfaner'),(24016,0,110843212346,'3G WWan antenna compatibled for MC8780 MC8790 F3507G GTM378 GTM380 M250 DELL5530',1,'ANCN001',0.25,'buysia','charithaws','charitha.ws@gmail.com','Charitha Goonetilleke','631,<br>Bangala Junction','Pitakotte, Kotte','','SRI LANKA','10100','94777513669','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-20 06:15:16',0,NULL,3,1,11,1,'BJ01713505\r ','buysia\rANCN001'),(24017,798788383008,180779483416,'New 3-section Anti-UV Waterproof Blue Sky White Cloud Sun/Rain folding Umbrella',1,'UM00043',20.89,'au-buy','1am7hewalrus','iam7hewalrus@yahoo.com.au','Patrick Edwards','9 Pine Street','Moss Vale','New South Wales','AUSTRALIA','2577','0061248681509','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 06:18:05',0,NULL,3,1,11,1,'BJ01713510\r ','au-buy\rUM00043'),(24018,798767790008,180755522252,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',38.94,'au-buy','bellafonte2005','bellafonte2001@yahoo.com','richard  butler','3/3 Omeo st','Darwin','Northern Territory','AUSTRALIA','0810','610408893309','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 07:06:40',0,NULL,3,1,3,1,'RA184500142CN\r ','au-buy\rLGAD001'),(24019,633930999003,130626363912,'New Logitech Unifying USB Receiver 4 Anywhere MX mouse',1,'RELO002',12.95,'cnfaner','2112dobu','goran.budimlija@zg.t-com.hr','Goran Budimlija','Brune Busica 28','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 07:20:15',0,NULL,3,1,3,1,'RA184500156CN\r ','cnfaner\rRELO002'),(24020,863531414011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'eastar4','edwardlin12','edward813@gmail.com','Edward Lin','Flat 15C SC TOWE 1 FESTIVAL CITY 1MEI TIN ROAD TAI WEI,SHATIN .','default','','HONG KONG','default','61828618','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 07:27:20',0,NULL,3,1,11,1,'BJ01713511\r ','eastar4\rTRSN001'),(24021,8881332230354636,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',10,'MOAP001',254,'eastar4uk','sinnsinner123','sinnsinner@hotmail.com','M. Moehamad','Blauwdasstraat 29','AMSTERDAM ZUIDOOST','','NETHERLANDS','1102SP','+31(0)624589627',NULL,NULL,NULL,'2012-03-20 07:59:14',0,NULL,3,1,4,1,'YW867611523CN\r ','这个是 漏发了的'),(24022,955578271012,220502334207,'2.1 HP Pavilion DV5 HDX X16 Bluetooth Module EDR+cable',1,'BTHP2113',12.39,'eastar4','hackmars','sebastian_mende@web.de','Sebastian Mende','Riebeckstr. 40','Leipzig','','GERMANY','04317','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 08:08:46',0,NULL,3,1,11,1,'BJ01713514 ','eastar4\rBTHP2113\rHP 6pin 1.0 12cm '),(24023,0,130665893699,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',12.5,'cnfaner','sormat23','volkolak22@gmail.com','Aleksey Denissenko','Zaslonova 33-67','Pavlodar','Pavlodarskaya obl','KAZAKHSTAN','140000','+7 702 1821173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 08:16:27',0,NULL,3,1,3,1,'RA386089028CN ','cnfaner\rRELO002'),(24024,0,170803578520,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',8.24,'au-buy','alf212red','alfredboy@gmail.com','Alfred Chung','25 Branscombe Street<br>Johnsonville','Wellington','','NEW ZEALAND','6037','+64211676234','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-20 08:15:44',0,NULL,3,1,11,1,'BJ01714146 ','au-buy\rRELO002'),(24025,639567041004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',12.59,'cnfaner','meirolami-il','meirolami@gmail.com','meir olami','israel','otnial','DN Har Hebron','ISRAEL','90407',' 0972506584450','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 08:38:04',0,NULL,3,1,3,1,'RA386089782CN\r ','cnfaner\rHSAL002\r欧标'),(24026,0,220980489906,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.06,'eastar4uk','luckyhappy12','mawindeehongphan@gmail.com','mawindee hongphan','99/432 ,Phaholyothin Rd. Soi Klongluang10<br>Klongnueng','Klongluang','Patumthanee','THAILAND','12120','8865836392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 08:45:39',0,NULL,3,1,11,1,'BJ01713501\r ','eastar4uk\rANCN001'),(24027,639571218004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',46.9,'cnfaner','crust848','detectivehomes@hotmail.com','Chris Sherlock','102 Blackbutt St','Wyoming','New South Wales','AUSTRALIA','2250','0243234984','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 09:05:12',0,NULL,3,1,3,1,'RA386089915CN\r ','cnfaner\rLGFI001'),(24028,798824802008,180730163247,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',39.89,'au-buy','beehel','brihel44@bigpond.com','brian hardman','42  hewitt drive','grovedale','Victoria','AUSTRALIA','3216','0352430679','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 09:12:58',0,NULL,3,1,3,1,'RA386089941CN\r ','au-buy\rGLOT001'),(24029,695222889013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','brendan.leo94','brendan.leo@gmail.com','Brendan Leo','32 Edward st<br>Carlton','Sydney','New South Wales','AUSTRALIA','2218','61432901325','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 09:21:09',0,NULL,3,1,11,1,'BJ01713518\r ','eastar4\rCACN004'),(24030,955604195012,220901458046,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',9,'eastar4uk','snizniks','raux@inbox.lv','Sergejs Nizniks','Olgas 2-17','Riga','','LATVIA','LV1007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 09:45:16',0,NULL,3,1,11,1,'BJ01713509\r ','eastar4uk\rSHLO009'),(24031,0,230763678149,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',3.25,'eastar4','rachid69563','rachid.abjij@gmail.com','Abjij Rachid','rue Jean-Jacques Rousseau, 21','Colfontaine','','BELGIUM','7340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 09:45:56',0,NULL,3,1,11,1,'BJ01713512\r ','eastar4\rRCHP001'),(24032,955606392012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','qzapp','adrian.j.eide@gmail.com','Adrian Eide','Fosnagata 3','Kristiansund','Møre og Romsdal','NORWAY','6509','004795726203','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 09:53:01',0,NULL,3,1,11,1,'BJ01713520\r ','eastar4\rMOAP001'),(24033,8881332237588984,111,'Free shipping & Tracking # - New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella - ',1,'UM00053',19.99,'aliexpress','1007518220','budlight@rambler.ru','Yuri Kosolapov','Marshala Zhukova 70-47 ','Abakan','Khakasia','RUSSIAN FEDERATION','655003','89628438386/+7 3902 279224',NULL,NULL,NULL,'2012-03-20 09:59:48',0,NULL,3,1,3,1,'RA386089031CN\r ','UM00053 '),(24034,0,180842630671,'New Philips Sonicare Flexcare Toothbrush Handle HX6950',1,'HBPH001',36.99,'au-buy','e-marter','jccis@msn.com','JAMES CHOUCAIR','281a MILLER RD. BASS HILL','SYDNEY','New South Wales','AUSTRALIA','2197','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 10:10:15',0,NULL,3,1,11,1,'BJ01713521\r ','au-buy\rHBPH001'),(24035,695232821013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','hakkefrido88','hakkefrido@live.de','Daniel Friedrichs','Am Lindenbusch 5','Hürth','','GERMANY','50354','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 10:11:04',0,NULL,3,1,3,1,'RA386089805CN\r ','eastar4\rLGAD001'),(24036,639585709004,140584763255,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',11.95,'cnfaner','sergeybugorsky','sbugorskij@yandex.ru','Sergey Bugorskiy','Shevlyakova, dom 27/1, kv 214.','Lyubertsy','Moscowskaya oblast','RUSSIAN FEDERATION','140007','+7-916-395-20-22','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 10:20:32',0,NULL,3,1,3,1,'RA386089765CN\r ','cnfaner\rRELO003'),(24037,0,220976892653,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',37.1,'eastar4uk','jg190','grin190@mail.ru','juris grindulis','384a<br>Kettering road','Northampton','Northamptonshire','UNITED KINGDOM','NN3 6QH','447816950826','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 10:26:59',0,NULL,3,1,3,1,'RA386089898CN\r ','eastar4uk\rPSGL001'),(24038,955616520012,220759905128,'New Sony VAIO P Series Display/LAN Adapter VGP-DA10',1,'OTSO002',74.95,'eastar4','sts_pro','stanislav.prokhorov@gmail.com','VALERI NASHOKIN','84 Pacific Road','Palm Beach, Sydney','New South Wales','AUSTRALIA','2108','0449054104','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 10:33:25',0,NULL,3,1,3,1,'RA386089663CN\r ','eastar4\rOTSO002'),(24039,863580967011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','juarez42','juvenaljuarez42@yahoo.com','Juvenal Juarez','8 Davidfield Cv<br>Apt L','Jackson','TN','UNITED STATES','38305-4142','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 10:37:51',0,NULL,3,1,1,1,'LK237361056CN\r ','eastar4'),(24040,807502427007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.38,'au-buy','trevorjayem','valmarin@bigpond.com','Trevor Marinovich','Unit 24<br>6 Waverton Avenue','Waverton','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 11:19:53',0,NULL,3,1,11,1,'BJ01713499\r ','au-buy\rRELO003\r'),(24041,639603035004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','marcusveras','marcusveras@hotmail.com','Marcus Veras','Rua Armando Lombardi, 303 - Apto 302<br>Bairro Santa Maria','Uberlândia','Minas Gerais','BRAZIL','38408-046','553496767677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 11:49:35',0,NULL,3,1,3,1,'RA386089779CN\r ','cnfaner\rLGAD001'),(24042,807519389007,170779618329,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',241.86,'au-buy','08bella16','dazndeb@live.com.au','Darren Nicks','16 Lillimur Ave','Morphett Vale','South Australia','AUSTRALIA','5162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 12:16:02',0,NULL,3,1,4,1,'YW867611501CN\r ','au-buy\rPSGL001*4'),(24043,955658862012,220901458141,'New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',31.99,'eastar4uk','paulgreenleaf','paul.greenleaf@talk21.com','Paul Greenleaf','Carr Hill Cottage, Carr Hill Road<br>Upper Cumberworth','Huddersfield','West Yorkshire','UNITED KINGDOM','HD8 8XN','01484606213','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 12:37:11',0,NULL,3,1,3,1,'RA386089907CN\r ','eastar4uk\rSAFI001'),(24044,633989511003,130553147178,'New Jabra BT250V FreeSpeak Bluetooth Headset BT 250V',1,'HSJA001',24.89,'cnfaner','popinboy77','lyalain@hotmail.com','Alain Ly','unit 2, 11 Colchester Drive','east doncaster','Victoria','AUSTRALIA','3109','0430474587','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 12:47:53',0,NULL,3,1,3,1,'RA386089990CN\r ','cnfaner\rHSJA001\r澳标'),(24045,955655045012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','sergusm','mokeev@pisem.net','Irina Mokeeva','3 mkr, 3, 115','Kurgan','','RUSSIAN FEDERATION','640023','+79638630202','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 12:28:16',0,NULL,3,1,3,1,'RA386090009CN\r ','eastar4\rPSGL001*2'),(24046,863628570011,320441564467,'2.1 Acer Aspire 5540 5542 Bluetooth Module EDR + cable',1,'BTAC2102',12.4,'eastar4','felipekunert','felipe.kunert@gmail.com','Felipe Kunert','Rua Ernesto da Fontoura nº 864<br>Bairro São Geraldo','Porto Alegre','Rio Grande do Sul','BRAZIL','90230090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 13:28:04',0,NULL,3,1,11,1,'BJ01713523\r ','eastar4\rBTAC2102\racer 4pin1.25 4cm'),(24047,863635976011,320812367704,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',53.99,'eastar4uk','gcooke12012','g.cooke1@hotmail.co.uk','Grant cooke','14 kirfield drive','hinckley','Leicestershire','UNITED KINGDOM','le101sx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 13:33:15',0,NULL,3,1,3,1,'RA386089972CN\r ','eastar4uk\rGPS0011'),(24048,634007319003,130645332963,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',263.5,'cnfaner','gps1944','gps_ebay@hotmail.com','gene p. smith','5426 S Dayton Ave','springfield','MO','UNITED STATES','65810-2697','(417) 889-1918','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 14:09:05',0,NULL,3,1,1,1,'LK237302645CN\r ','cnfaner'),(24049,695287545013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','marekcw','mcwener@hotmail.co.uk','Marek Cwener','225A tinshill Lane','Leeds','West Yorkshire','UNITED KINGDOM','LS16 6EE','07725807400','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 14:13:25',0,NULL,3,1,11,1,'BJ01713503\r ','eastar4\rWLIN014'),(24050,0,320866867935,'NEW Logitech Unifying Receiver 4 K340 K350 N305 MK710',1,'RELO002',6.7,'eastar4uk','kinia16322','kinia163@interia.eu','Kinga Dombrowska','Cairnfield Avenue 96','London','London','UNITED KINGDOM','NW2 7pe','07428478000','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 14:20:58',0,NULL,3,1,3,1,'RA386089734CN\r ','eastar4uk\rRELO002'),(24051,637731150004,140626375035,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',3,'OTCN005*10',42.3,'cnfaner','789pendulum','luca.lehner@gmail.com','Media Services Center GmbH, Luca Lehner','Bahnhofstrasse 40','Romanshorn','','SWITZERLAND','8590','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 14:28:23',0,NULL,3,1,3,1,'RA386089986CN\r ','cnfaner\rOTCN005*10'),(24052,0,220976861785,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',53.11,'eastar4','klykodesh69','klykodesh@gmail.com','roger jones','83 Deerfield Rd','boiceville','NY','UNITED STATES','12412-5113','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 14:45:30',0,NULL,3,1,1,1,'LK237343865CN\r ','eastar4'),(24053,955715780012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',38,'eastar4uk','mike-springob','mike-springob@t-online.de','Mike Springob','Auf den Peulen 36','Attendorn','','GERMANY','57439','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 15:06:04',0,NULL,3,1,3,1,'RA386089969CN\r ','eastar4uk\rMOLO001'),(24054,0,220977577341,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',6.01,'eastar4','alikkach','pro22000@mail.ru','Aleksey Kachmar','Dobrovolskogo 128a, apt 40','Odessa','Odessa','UKRAINE','65111','+380674890616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:18:50',0,NULL,3,1,11,1,'BJ01713522\r ','eastar4\rANTY001+WLAT008\r再发一个\rNEW Atheros AR5B93 Half Height Wireless WiFi card 300M\r'),(24055,955741187012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','bizzyboi918','bizzybeingsweet@yahoo.com','le nguyen','6526 E 27th Pl','tulsa','OK','UNITED STATES','74129-6114','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(24056,863704156011,320774354992,'New IBM Atheros AR5BXB72 AR5008 Wireless PCI-E card',1,'WLAT003',14.9,'eastar4','joerg70k','joerg70@nexgo.de','Jörg Krüger','Republikstr. 3','Schönebeck','','GERMANY','39218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 16:37:40',0,NULL,3,1,11,1,'BJ01713525\r ','eastar4\rWLAT003'),(24057,634045190003,130490259190,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26.9,'cnfaner','easilyautomated','cottinison@optonline.net','Marc Cottini','25 Pine St','west harrison','NY','UNITED STATES','10604-2522','(914) 837-1342','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 16:40:06',0,NULL,3,1,1,1,'LK237312948CN\r ','cnfaner'),(24058,0,320867816074,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',29,'eastar4uk','leanne2008','leanne.sheppard1@ntlworld.com','leanne sheppard','18 gainsborough avenue, eaton ford','st neots','Cambridgeshire','UNITED KINGDOM','PE197RJ','01480475558','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 17:15:22',0,NULL,3,1,3,1,'RA386089796CN\r ','eastar4uk\rLGAD001'),(24059,955778208012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','caswell2369','caswell23@hotmail.com','Chad Caswell','217 Fullerton Drive','Fort McMurray','AB','CANADA','T9K1M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 17:25:09',0,NULL,3,1,3,1,'RA386089938CN\r ','eastar4\rPSGL001*2'),(24060,0,110844980559,'New Original Logitech Harmony Remote USB Cable',1,'CALO001',0.11,'buysia','tdv1953','terrydvannals@hotmail.com','Terry Vann','5035 Rocky Falls Rd','Hazlehurst','MS','UNITED STATES','39083-8950','(601) 894-0302','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-20 18:24:29',0,NULL,3,1,1,1,'LK237283932CN\r ','buysia'),(24061,634082303003,130603400274,'NIB genuine Philips SHS4843 Flexible Earhook Headphones Blue durable Bass Pipe',1,'HSPH005',16.9,'cnfaner','koko20122012','roicohen111@gmail.com','michel cohen','hadolev 347','givon hachadasha','israel','ISRAEL','90901',' 0527561419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 18:34:43',0,NULL,3,1,3,1,'RA386089819CN\r ','cnfaner\rHSPH005\r欧标'),(24062,863765469011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','seaview2525','bbduk@aol.com','Robert Bateman','21 Ashdown Road','Bexhill-on-Sea','East Sussex','UNITED KINGDOM','TN401SE','07976731856','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 18:43:35',0,NULL,3,1,3,1,'RA386089045CN\r ','eastar4uk\rMOAP001'),(24063,955829716012,220915185196,'New 3-section Anti-UV Waterproof Blue Sky  White Cloud Sun/Rain folding Umbrella',1,'UM00043',13.95,'eastar4uk','ne_monro','an1974na@bk.ru','Anna Berseneva (Берсенева Анна)','Starobitcevskaya street, 21-1-367<br>Старобитцевская ул, 21-1-367','Moscow','Moscow','RUSSIAN FEDERATION','117628','(926) 399-2552','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 18:56:22',0,NULL,3,1,11,1,'BJ01713502\r ','eastar4uk\rUM00043'),(24064,695395826013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','josecaixa','josecaixa@gmail.com','Jose Ignacio Alvarez','c/cerrada, 9 -Oficina-LA CAIXA','Valladolid','Castilla y León','SPAIN','47010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 19:39:19',0,NULL,3,1,3,1,'RA386089685CN\r ','eastar4\rLGAD001'),(24065,0,320871203696,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',1,'GLOT001',19,'eastar4uk','zappro1','par-olof@odromen.se','Pär-Olof Lif','Stationsbacken 9','Dalby','','SWEDEN','SE-247 50','+46 705 12 34 45','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 20:35:11',0,NULL,3,1,11,1,'BJ01713519\r ','eastar4uk\rGLOT001'),(24066,863837099011,320441575399,'2.1 Acer Aspire 7110 7000 9300 Bluetooth Module +cable',1,'BTAC2108',12.39,'eastar4','shmrv','shmrv@mail.ru','Dmitry Shamarov','Russian Federation, Bryansk, Chernyshevsky str., 72A, 57','Bryansk','Russia','RUSSIAN FEDERATION','241047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 20:43:10',0,NULL,3,1,11,1,'BJ01713524\r ','eastar4\rBTAC2108\racer 4pin1.25 18cm '),(24067,634133991003,130596581671,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',21.9,'cnfaner','kathymedved13s5v','kathymedved@gmail.com','KATHY MEDVED','81946 Camino Cantos','Indio','CA','UNITED STATES','92203-7814','(253) 208-6794','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 20:43:50',0,NULL,3,1,1,1,'LK237305292CN\r ','cnfaner'),(24068,863843373011,320704213252,'NEW LOGITECH NANO USB RECEIVER4 Anywhere M505 mouse',1,'RELO003',7.5,'eastar4uk','siemohwbmf','siemohwbmf@eranet.pl','Przemyslaw Soszynski','56 Gordon Road','London','London','UNITED KINGDOM','N3 1EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 20:53:20',0,NULL,3,1,3,1,'RA386089717CN\r ','eastar4uk\rRELO003'),(24069,955917834012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','larkstongueinaspic','robert.boudart@sgsintl.com','Robert Boudart','4145 N Yale Ave','Arlington Heights','IL','UNITED STATES','60004-7924','(847) 590-8426','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 21:10:58',0,NULL,3,1,1,1,'LK237329308CN\r ','eastar4'),(24070,955923630012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',2,'MOAP001',55.98,'eastar4','velezan1','velez@riverschoolk8.org','Andres Velez','4439 River Rd','Sodus','MI','UNITED STATES','49126-9779','(269) 925-6757','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 21:20:57',0,NULL,3,1,1,1,'LK237364976CN\r ','eastar4\rMOAP001'),(24071,639786518004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',3,'HSNO005',41.37,'cnfaner','rcime','ralphcime@yahoo.com','Ralph Cime','1920 N 61st St','Philadelphia','PA','UNITED STATES','19151-3519','(267) 752-0173','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-20 21:45:29',0,NULL,3,1,1,1,'LK237263765CN\r\r ','cnfaner'),(24072,955936820012,220815928448,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card',2,'WLHP002',17.98,'eastar4uk','toxicated101','matthew.wheatley1@ntlworld.com','Matthew Wheatley','27a<br>Sansome Place','Worcester','Worcestershire','UNITED KINGDOM','WR1 1UA','0190522316','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 21:46:02',0,NULL,3,1,3,1,'RA386089725CN\r ','eastar4uk\rWLHP002'),(24073,953401665012,220815928912,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N',1,'WLIN013',10.99,'eastar4uk','gbrueno','bruno.goellner@gmail.com','Bruno Goellner','Dorothea-Schlözer-Str.4','Ingolstadt','','GERMANY','85049','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 21:50:37',0,NULL,3,1,11,1,'BJ01713498\r ','eastar4uk\rWLIN013'),(24074,0,320871203716,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',26.99,'eastar4uk','nrwaite','neil.waite@gmail.com','Neil Waite','Dovecote House<br>Northcote Fold','Linton','West Yorkshire','UNITED KINGDOM','LS22 4UZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 22:00:14',0,NULL,3,1,3,1,'RA386089884CN\r ','eastar4uk\rHBPH001'),(24075,955948337012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 22:10:45',0,NULL,3,1,3,1,'RA386089924CN\r ','eastar4\rPSGL001*2'),(24076,955960706012,220871868866,'Genuine Jabra BT250 Bluetooth Headset BT 250',1,'HSJA002',13.6,'eastar4uk','raymondad1963','raymondad@fsmail.net','RAYMOND DOWNER','Building 2 Dandy Bank Road<br>Pensnett Trading Estate','Pensnett','West Midlands','UNITED KINGDOM','DY6 7PP','01384455269','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 22:34:43',0,NULL,3,1,3,1,'RA386089822CN\r ','eastar4uk\rHSJA002\r英标'),(24077,955969995012,220688992851,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',21.9,'eastar4','moonvalleytoppers','toppers@centurylink.net','Leola Young','8411 Moon Valley Rd SE','North Bend','WA','UNITED STATES','98045','(425) 888-1625','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 22:56:02',0,NULL,3,1,1,1,'LK237333452CN\r ','eastar4'),(24078,955976864012,220872377067,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',72.99,'eastar4uk','snowys82','snowy77@matilda.net.au','Jayne Snowdon','21 Webley Way<br>DYSART','DYSART','Queensland','AUSTRALIA','4745','0409419446','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 23:12:38',0,NULL,3,1,3,1,'RA386089059CN\r ','eastar4uk\rGPS0004'),(24079,863920229011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','nunotecno','nunode12@hotmail.com','Nuno Oliveira','Rua do Alto de São João, n54 - 1º Andar<br>Alto de São João','Coimbra','Coimbra','PORTUGAL','3030-001','351918558579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 23:56:13',0,NULL,3,1,11,1,'BJ01713516\r ','eastar4uk\rGLOT001'),(24080,863925869011,320730085376,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',8.27,'eastar4uk','fastt501','petri.t.j.mattila@gmail.com','Petri Mattila','39 Tarn Close','Farnborough','Hampshire','UNITED KINGDOM','GU14 0RP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 00:06:00',0,NULL,3,1,3,1,'RA386089867CN\r ','eastar4uk\rCACN004'),(24081,815918991001,110773418749,'NIB 9\"x6\" 2048 level Pen Tablet USB Drawing Board replace WACOM Intuos4',1,'GRUG001',199.99,'buysia','spikeeeboy','sakemp@shaw.ca','Sheila Kemp','214 Whiteshore Cres.','Saskatoon','SK','CANADA','S7J3W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 00:36:50',0,NULL,3,1,3,1,'RA386088362CN ','buysia\rGRUG001\r黑色的\r'),(24082,0,140726043688,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',33.15,'cnfaner','elyriagirl','diane.melody@mesanetworks.net','Diane R. Melody','127 S Pinon Cir','Florissant','CO','UNITED STATES','80816-8974','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 00:38:54',0,NULL,3,1,1,1,'LK237315140CN\r ','cnfaner'),(24083,0,170802050316,'New Altec Lansing Backbeat Plus UHP206  Earphones for iPod  iPhone music player',1,'HSAL002',4.99,'au-buy','mikerobe943','miker99@tpg.com.au','Mike Robert','MTS<br>8 Sarton Road','Clayton','Victoria','AUSTRALIA','3168','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 01:22:41',0,NULL,3,1,11,1,'BJ01713526\r ','au-buy\rHSAL002\r澳标'),(24084,695507867013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','ariky65ariky','ariky65@gmail.com','Arik Yakobi','derech ako<br>93a','Kiriat Motzkin','','ISRAEL','26373','+972503001464','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 01:32:22',0,NULL,3,1,3,1,'RA386089840CN\r ','eastar4\rLGAD001'),(24085,8881332293663331,111,'New Japan Rainbow Color Sun/Rain stick Umbrella w/24 skeletons - ',1,'UM00008',24.99,'aliexpress','1007533836','oksanka-2002@mail.ru','Pavel Khokhlov','2-oy ambulatorniy proezd, 6 DO VOSTREBOVANIYA','Moscow','Moscow','RUSSIAN FEDERATION','125315','+7 903 6732092',NULL,NULL,NULL,'2012-03-21 01:34:23',0,NULL,3,1,3,1,'RRA386089561CN ','UM00008 \r包好了 '),(24086,639844877004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',23.9,'cnfaner','wiizt','darwis059@gmail.com','Darwis ,','PT PLN (Persero) UPK RING SULMAPA II<br>JL NURI NO 9','PALU','SULAWESI TENGAH','INDONESIA','94114','+6285656393075','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 01:38:40',0,NULL,3,1,3,1,'RA386089955CN\r ','cnfaner\rMOAS001\r'),(24087,955999455012,220915101992,'New in box genuine Philips SHQ4000 Sports Sweat Proof Headphones',1,'HSPH002',31.99,'eastar4','rvedovi','rodrigovedovi@gmail.com','Rodrigo Barreto','Rua Salomão FIlho 155 bl2 apt204<br>Bento Ribeiro','Rio de Janeiro','Rio de Janeiro','BRAZIL','21331660','512193169582','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 01:51:08',0,NULL,3,1,11,1,'BJ01713496\r ','eastar4\rHSPH002'),(24088,955738850012,220313149050,'AUI Ethernet 10Base-T RJ45 Transceiver BEST CONDITION!!',1,'TRMX003',9.99,'eastar4','nelly874','nelly874@hotmail.com','David Nelson','3201 W Roosevelt St','Phoenix','AZ','UNITED STATES','85009','(602) 400-6138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 02:12:04',0,NULL,3,1,1,1,'LK237351005CN\r ','eastar4'),(24089,0,220981213701,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',36,'eastar4','bmetbatya','biomedvahan@yahoo.com','VAHAN ADAMOV','1410 E Glenoaks Blvd','GLENDALE','CA','UNITED STATES','91206-2613','(818) 242-4128','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4'),(24090,0,320871854776,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',10.75,'eastar4','jepp1760','eppy8123@yahoo.com','Joseph Epperson','217 Stonegate Dr','Dothan','AL','UNITED STATES','36305-1099','(334) 655-8877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 02:37:52',0,NULL,3,1,1,1,'LK237749177CN\r ','eastar4'),(24091,956050715012,220915101992,'New in box genuine Philips SHQ4000 Sports Sweat Proof Headphones',1,'HSPH002',31.99,'eastar4','spxande79','spxande@yahoo.com','Alexandre Cesar Gomes Fonseca','Rua Germano Ulbrich,155 ap 111<br>Vila Andrade','São Paulo','São Paulo','BRAZIL','05717-240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 02:39:13',0,NULL,3,1,11,1,'BJ01713494\r ','eastar4\rHSPH002'),(24092,799223283008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.1,'au-buy','enhaich','enhaich@hotmail.com','neale hansen','14 hinkler street<br>mayfield','newcastle','New South Wales','AUSTRALIA','2304','0249671073','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 02:43:52',0,NULL,3,1,11,1,'BJ01713515\r ','au-buy\rMOMI002'),(24093,639860022004,140667904050,'new DLP-Link 3D Ready Projector Active Shutter Glasses',1,'GLOT005',44.5,'cnfaner','orchid.gallery','orchid.gallery@hotmail.com','CALBI Davide','\"Les cottages de l\'Esterel\" B101<br>462, rue Jean Monnet','Mandelieu','Franche-Comté','FRANCE','06210','0609805666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 02:46:41',0,NULL,3,1,3,1,'RA386089875CN\r ','cnfaner\rGLOT005'),(24094,639861077004,140626375805,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',6.3,'cnfaner','105susjejesus','poncejesus53@gmail.com','Jesus Ponce','3135 solano ave','Napa','CA','UNITED STATES','94558-4553','(707) 602-0796','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 02:52:51',0,NULL,3,1,1,1,'LK237394482CN\r ','cnfaner'),(24095,0,140726735515,'New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n &BlueTooth',1,'ANTY002',1.25,'cnfaner','redbaron01','blackdragonmo@charter.net','Gary Erhardt','4705 Warrior Dr','Saint Louis','MO','UNITED STATES','63123-5719','(314) 601-3606','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 02:56:14',0,NULL,3,1,1,1,'LK237409350CN\r ','cnfaner'),(24096,695526740013,230679574853,'Lowrance iFinder H2OC H2O C GPS+WAAS Compact handheld GPS color Receiver',1,'GPS0004',109.99,'eastar4','scottie_y','scottie_y@hotmail.com','Scott Stanke','5961 Janes Rd','Saginaw','MI','UNITED STATES','48601','(989) 780-0962','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 02:59:39',0,NULL,3,1,1,1,'LK237721770CN\r ','eastar4'),(24097,956056770012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*4',263.99,'eastar4','arealfox','arealfoxx@aol.com','Aurelia Higginbotham','131 Eagle Head Dr','Fort Washington','MD','UNITED STATES','20744-5736','(301) 567-3890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 03:04:35',0,NULL,3,1,1,1,'LK237729040CN\r ','eastar4'),(24098,799229945008,180810765145,'4 pairs of New 3D Active Shutter TV Glasses for 3D TV  Panasonic TY-EW3D10',1,'GLOT001*4',148.19,'au-buy','chimpachimpi','ashutoshreached@gmail.com','Ashutosh Misra','11 longford crescent ','acacia ridge','Queensland','AUSTRALIA','4110','6141370925','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 03:14:57',0,NULL,3,1,4,1,'YW867611556CN\r ','au-buy\rGLOT001*4'),(24099,695531179013,230641257901,'New lady lace trim sun/rain stick Umbrella blue',1,'UM00011',24.99,'eastar4','prettyfeather1119','pretty_feather@hotmail.com','ZEYU PENG','1601 Hillcrest Dr<br>Apt Y8','Manhattan','KS','UNITED STATES','66502-2419','(785) 320-3909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 03:21:58',0,NULL,3,1,1,1,'LK237750904CN\r ','eastar4'),(24100,695533274013,230699435088,'Mini Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK102',1,'GPS0006',59.99,'eastar4','260richardd','r_julamor@att.net','Richard Downing','231 Curry ave','Vallejo','CA','UNITED STATES','94590-6453','(707) 655-9015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 03:43:51',0,NULL,3,1,1,1,'LK237734963CN\r ','eastar4'),(24101,634234686003,130458358302,'New GENUINE  NOKIA BH-203 BLUETOOTH HEADSET track#',1,'HSNO007',13.88,'cnfaner','nikosglikis','nikosglikis@gmail.com','Nikos Glikis','P.O. Box 62546','Paphos','','CYPRUS','8065','0035799804938','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 03:44:49',0,NULL,3,1,3,1,'RRA386089575CN ','cnfaner\rHSNO007\r欧标'),(24102,0,220981253140,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.3,'eastar4uk','grafbotan','mypostgraf@mail.ru','Viacheslav Rumyanzew','ul. Marshala Golovanova, d. 19, kv. 68','Moskva','RU','RUSSIAN FEDERATION','109144','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 03:48:03',0,NULL,3,1,11,1,'BJ01713486\r ','eastar4uk\rPOLO001'),(24103,639869398004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.29,'cnfaner','mxexports2010','robertgiraldez4@hotmail.com','roberto giraldez','8400 NW 30th Ter','Doral','FL','UNITED STATES','33122-1911','(305) 436-0300','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 03:48:20',0,NULL,3,1,1,1,'LK237734036CN\r ','cnfaner'),(24104,8881332302746114,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Isaac Gutierrez ','7438 3rd Street','Downey,','CA','UNITED STATES','90241-3212 ','',NULL,NULL,NULL,'2012-03-21 04:05:46',0,NULL,3,1,3,1,'RA386089615CN\r ','MOAP001 \reastar4\r直接打款     '),(24105,863995073011,320721398573,'New Jabra BT500v BT 500v wireless Bluetooth Headset',2,'HSJA011',55.98,'eastar4','10momin','mominsadik@ymail.com','momin sadik','4318 mobile hwy','montgomery','AL','UNITED STATES','36108','(251) 744-1350','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 04:07:05',0,NULL,3,1,1,1,'LK237710967CN\r ','eastar4\rHSJA011'),(24106,8881332304144332,111,'Acer Aspire 6930 6530 6930G Bluetooth Module 2.0+cable',1,'BTAC2012',0,'eastar4','jem6ndy','ebay.eric@laposte.net','DOISNE Cindy','10 allée de houx','Souesmes','Centre','FRANCE','41300','0624680792',NULL,NULL,NULL,'2012-03-21 04:29:04',0,NULL,3,1,11,1,'BJ01713500','eastar4\rBTAC2012\racer 5pin1.25 6cm   \r只补发一条线'),(24107,0,320871890487,'New triple Tyco 2.4/5.0 GHz Mini Pci Antenna',1,'ANTY002',0.01,'eastar4uk','kenney0_0','johnkenney2@yahoo.co.uk','John Kenney','196 Gleadless Common','Sheffield','South Yorkshire','UNITED KINGDOM','S12 2US','01142653917','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 04:30:44',0,NULL,3,1,3,1,'RA386089629CN\r ','eastar4uk\rANTY002'),(24108,695542707013,230526919227,'Brand new HP MCE Media Center Remote Control+ IR RECEVE',1,'OTHP003',20.9,'eastar4','bmxsk8ergirl','xaltoidsx1@aol.com','Perryhan  Elhakeem','10112 Forrestal Dr','Huntington Beach','CA','UNITED STATES','92646-3720','(310) 484-9056','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 04:32:20',0,NULL,3,1,1,1,'LK237700085CN\r ','eastar4'),(24109,807899181007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',18.99,'au-buy','mmcf6419','megan@stonekithomes.com.au','Megan McFadden','151 Smeaton Grange Road','Smeaton Grange','New South Wales','AUSTRALIA','2567','0438312045','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 04:53:22',0,NULL,3,1,11,1,'BJ01713487\r ','au-buy  \rUM00001\r蓝色的'),(24110,0,220981252214,'NIB 3D Active Shutter TV Glasses for SONY TDG-BR250',1,'GLOT001',16,'eastar4uk','eneidaregis','eneida_regis@yahoo.com','Eneida Regis','Top Flat<br>7 The Grange','Wimbledon','London','UNITED KINGDOM','SW19 4PT','07939942529','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 05:02:15',0,NULL,3,1,3,1,'RA386089703CN\r ','eastar4uk\rGLOT001'),(24111,0,320868504198,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',6,'eastar4','a12r1','a.baf@live.com','Ahmed A. Bafageeh-NEW2K','6147 Ar Ruwais District / AL-Andalus RD.<br>Saudi Electricity Company(head office) - Information Technology','Jeddah',':21413-POBox:','SAUDI ARABIA','9299','966500007650','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 05:24:24',0,NULL,3,1,17,1,'RA386088699CN\r ','eastar4\rOT00004'),(24112,807906486007,170778548102,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',131.09,'au-buy','the_smegger','ajpcc@internode.on.net','Arpad J Szasz','35 Stanley St','Morphett Vale','South Australia','AUSTRALIA','5162','0883823963','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 05:40:25',0,NULL,3,1,3,1,'RA386089650CN ','au-buy  PSGL001*2'),(24113,864018910011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','ajoh4790','ajjohnson1984@att.net','Audrey Johnson','9271 Crimnson Court','Dallas','TX','UNITED STATES','75217','(972) 286-1531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 06:21:16',0,NULL,3,1,1,1,'LK237711477CN\r ','eastar4'),(24114,807921884007,170740412441,'2 pair New 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001*2',77.89,'au-buy','dave1957.075','ringdave@bigpond.com','David Ring','36 Coolibah Street','Mudjimba','Queensland','AUSTRALIA','4564','0459777099','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 07:12:22',0,NULL,3,1,3,1,'RA386089646CN ','au-buy  GLOT001*2'),(24115,8881332314331594,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Edward J Field ','1121 N. Bethlehem Pike Suite 60-138 ','Spring House','PA ','UNITED STATES','19477 ','',NULL,NULL,NULL,'2012-03-21 07:18:51',0,NULL,3,1,3,1,'RA386089694CN\r ','MOAP001 \reastar4\r直接打款      '),(24116,8881332315473884,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Sharon Wang','22708 Chicora Dr. ',' Diamond Bar',' CA ','UNITED STATES','91765','',NULL,NULL,NULL,'2012-03-21 07:37:53',0,NULL,3,1,3,1,'RA386089589CN ','MOAP001 \reastar4\r直接打款       '),(24117,864033749011,320730088682,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',49.99,'eastar4uk','bob8bi','bobbi79@mail.ru','Denis Yaparov','Bummashevskaya<br>82-31','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426060','(341)244-5999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 07:38:13',0,NULL,3,1,3,1,'RA386089592CN ','eastar4uk\rOTES001'),(24118,799282271008,180758270621,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',11.51,'au-buy','r_cantafio','r_cantafio@hotmail.com','Raimondo Cantafio','Unit 209<br>11 Railway Street','Chatswood','New South Wales','AUSTRALIA','2067','0428037563','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 07:53:09',0,NULL,3,1,11,1,'BJ01714573 ','au-buy  SHLO009'),(24119,8881332316958753,111,'CAB-6060',1,'',20.98,'eastar4','tmarkota','tmarkota','Tomislav Markota','Petrova 77','Zagreb','','CROATIA','10000','',NULL,NULL,NULL,'2012-03-21 08:02:38',0,NULL,3,0,11,1,'BJ01714100\r ','EASTAR4\rCASS002+CASS003\r再发一条cable CAB-2660\r已入库\r'),(24120,8881332320522883,111,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',0,'eastar4','bynmst','byn1970@list.ru','Yuriy Barmin','str.Valihanova 155 - 1','Temirtau','Karaganda','KAZAKHSTAN','101407','87003248347',NULL,NULL,NULL,'2012-03-21 09:02:02',0,NULL,3,1,11,1,'BJ01713495\r ','UM00033\r补发的\rEASTAR4 '),(24121,695338409013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',15.94,'eastar4','helderjrse','helderjrse@gmail.com','Helder Junior','Av Adelia Franco 2288<br>Edf Maragogi Apto 1802','Aracaju','SERGIPE','BRAZIL','49048-010','+55(79)3217-0846','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 09:04:23',0,NULL,3,1,3,1,'BJ01713497\r ','eastar4\rCACN004\r客户打了三美金'),(24122,956142359012,220816785967,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',12.9,'eastar4uk','rochelledel','rochelle.gunter@gmail.com','Rochelle Gunter','34 the Edge<br>Clowes Street','Salford','Greater Manchester','UNITED KINGDOM','M3 5NB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 09:21:04',0,NULL,3,1,3,1,'RA386088226CN\r ','eastar4uk\rHBPH003'),(24123,639921103004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',1,'GPS0010',32,'cnfaner','russ_63','avtostop@mail.ru','Evgeni Basenkov','Tuhachevskogo 58 - 36','Samara','Samarskaya oblast`','RUSSIAN FEDERATION','443082','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 09:44:52',0,NULL,3,1,3,1,'RA386088098CN\r ','cnfaner\rGPS0010'),(24124,0,220980489888,'Brand New Tyco 2.4/5.0 GHz Dual Mini Pci Antenna',1,'ANTY001',0.11,'eastar4uk','m.standish2212.2','standish.mark1@gmail.com','Mark Standish','Fujitsu, Wakefield House<br>Borough Road','Wakefield','West Yorkshire','UNITED KINGDOM','wf1 1xu','07427699739','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 09:46:34',0,NULL,3,1,3,1,'RA386088288CN\r ','eastar4uk\rANTY001'),(24125,864066579011,320730089078,'Original Allied Telesyn CentreCOM AT-210TS Transceiver',4,'TRTS001',27.96,'eastar4uk','iliverover','w_srirach@hotmail.com','wiroj srirach,MWAS Mechatronics Service Co.,ltd.','23 Chalermprakeat th.9 soi 48 yeak2<br>Dokmai','Pravet','Bangkok','THAILAND','10250','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 09:51:28',0,NULL,3,1,3,1,'RA386088067CN\r ','eastar4uk\rTRTS001'),(24126,816045296001,110819588687,'New Original Logitech Harmony Remote USB Cable',1,'CALO001',3.87,'buysia','bec_55','rebecca.iemma@gmail.com','Rebecca Iemma','43 Marianne Way','Alexander Heights','Western Australia','AUSTRALIA','6064','0893430260','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-21 10:03:47',0,NULL,3,1,11,1,'BJ01714129\r ','buysia\rCALO001'),(24127,799318787008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',2,'BALO001',22.78,'au-buy','**hawa**','pht@live.com.au','Michael Stryler','PO BOX 788','Pacific Fair','Queensland','AUSTRALIA','4218','0405141575','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 10:18:02',0,NULL,3,1,11,1,'BJ01714134\r ','au-buy\rBALO001'),(24128,0,140726735487,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',3.25,'cnfaner','fswh3959','frederick@avpl.biz','Frederick Sia','No. 10 Ubi Crescent,<br>#07-61 Ubi Techpark,','Singapore','Singapore','SINGAPORE','408564','+65 6743 6177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 10:22:26',0,NULL,3,1,3,1,'RA386088040CN\r ','cnfaner\rMOFP001'),(24129,807970270007,170759125993,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen+Holder',1,'CC00002',34.19,'au-buy','midget95','colin_adsl@dodo.com.au','Colin Robertson','63 Iona Avenue','Belmont','Victoria','AUSTRALIA','3216','61352434506','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 10:27:41',0,NULL,3,1,11,1,'BJ01714133\r ','au-buy\rCC00002'),(24130,956165400012,220815929531,'New brand ASUS N554 bluetooth mouse +battery',1,'MOAS001',15.5,'eastar4uk','denny_jk','kusche@web.de','Jan Kusche','Wellweg 78','Sarstedt','','GERMANY','31157','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 10:40:12',0,NULL,3,1,11,1,'BJ01714119\r ','eastar4uk\rMOAS001'),(24131,695604547013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','sylvandale7','the_daniells_family@yahoo.com.au','Alex Daniells','15 High Brook Place','Castle Hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 11:08:07',0,NULL,3,1,11,1,'BJ01714122\r ','eastar4\rWLIN014'),(24132,695604915013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','gp201081','greatpasha@gmail.com','Pavel Mikhed','Kigevatov str. 62-209','Minsk','','BELARUS','220024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 11:08:59',0,NULL,3,1,11,1,'BJ01714123\r ','eastar4\rCACN004'),(24133,864097400011,320701011328,'NIB 3D Active Shutter TV Glasses for Sony Panasonic TV',1,'GLOT001',39.99,'eastar4','fcbtqcc','cbfan99@yahoo.com','Fan Chin Boon','Kelkay Bulking Installation<br>Jalan Pertabalan','Pelabuhan Selatan','Pelabuhan Klang, Selangor','MALAYSIA','42008','0192525747','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 11:35:44',0,NULL,3,1,11,1,'BJ01714128\r ','eastar4\rGLOT001'),(24134,0,220981252255,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.01,'eastar4uk','zamookie','zamookie@mail.com','Tony Daglish','75 southway<br>south west denton','newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','NE15 7RB','1912649815','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 11:48:01',0,NULL,3,1,3,1,'RA386088291CN\r ','eastar4uk\rSCLO002'),(24135,956189662012,220816388534,'New Logitech MX Revolution Mouse Mat 3M material',1,'SCLO003',2.99,'eastar4uk','bozo3k','waj3k@live.com','Wajahat Hussain','153 Handsworth New Road<br>Winson Green','Birmingham','West Midlands','UNITED KINGDOM','B18 4PU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 11:52:20',0,NULL,3,1,3,1,'RA386088124CN\r ','eastar4uk\rSCLO003'),(24136,0,140723777978,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.01,'cnfaner','burt153','burt153@aol.com','Judith  A Burt','18153 Lincoln Rd','Purcellville','VA','UNITED STATES','20132-4031','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 12:05:09',0,NULL,3,1,1,1,'LK237973915CN\r ','cnfaner'),(24137,864113972011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',99.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 12:29:21',0,NULL,3,1,4,1,'YW867611593CN\r ','eastar4uk\rGLOT001*4\r一共买了八副'),(24138,695624752013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','antonlomik','lomik@me.com','Антон Ломаченков','Вернова С. Н.<br>дом 3А квартира 380','Дубна','Московская область','RUSSIAN FEDERATION','141980','+79261965855','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 12:39:35',0,NULL,3,1,11,1,'BJ01714126\r ','eastar4\rCACN004'),(24139,639957911004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',2,'MOLO001',131.98,'cnfaner','justa1133','justinupi@gmail.com','Justin Warner','1133 19th St NW<br>Ste 800','Washington','DC','UNITED STATES','20036-3655','(202) 898-8122','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 12:51:16',0,NULL,1,1,1,1,NULL,'cnfaner'),(24140,953181502012,220834709456,'New blue sky Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00034',24.99,'eastar4','irishaafina1','irishaafina@gmail.com','Irina Stepanova','12/75 Mezhevaya str. app.52','Vsevolozhsk','Leningrad region','RUSSIAN FEDERATION','188640','(007) 9618034321','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 12:59:10',0,NULL,3,1,11,1,'BJ01713493\r ','eastar4\rUM00034'),(24141,808025860007,170740412441,'2 pair New 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001*2',81.99,'au-buy','sammy.the.snake','samanthajwingrove@gmail.com','Samantha Wingrove','27 Beltana Road','Craigie','Western Australia','AUSTRALIA','6025','0894011179','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 13:28:08',0,NULL,3,1,3,1,'RA386088019CN\r ','au-buy\rGLOT001*2'),(24142,864136633011,320826634908,'New Grohe Copper Plating Multi function washer Germany',1,'OTGR006',18.99,'eastar4uk','worldtechltd','info@worldtechuk.com','World tech ltd','169 the drive','Ilford','Essex','UNITED KINGDOM','Ig13pj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 13:40:24',0,NULL,3,1,3,1,'RA386088328CN\r ','eastar4uk\rOTGR006'),(24143,0,130665893665,'New Logitech Unifying USB Receiver For Performance MX',1,'RELO002',9.01,'cnfaner','renec183','ingrenec@hotmail.com','DO94518 Rene Cruz','8550 NW 66th St','Miami','FL','UNITED STATES','33166-2635','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 13:59:46',0,NULL,3,1,1,1,'LK237942918CN\r ','cnfaner'),(24144,864150081011,320679575677,'Unlocked NEW Sierra Wireless WWAN MC8780 PCI-E HSUPA 3G',1,'WWSI004',24.9,'eastar4uk','matthew825050408','capelaberfan@yahoo.co.uk','Capel Aberfan','12 Bridge Street<br>Aberfan','Merthyr Tydfil','Merthyr Tydfil','UNITED KINGDOM','CF484RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 14:12:06',0,NULL,3,1,3,1,'RA386088115CN\r ','eastar4uk\rWWSI004'),(24145,639977271004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','m0bifrik','matic.masat@gmail.com','Matic Mašat','Škapinova 9','Celje','','SLOVENIA','3000','+38651417688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 14:13:28',0,NULL,3,1,3,1,'RA386088053CN\r ','cnfaner\rCACN004'),(24146,864160168011,320773581953,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',99.99,'eastar4uk','latiendadelsotano','gusmlg86@gmail.com','ALMAGRO AGUSTIN','C/ ARAGONITO 7A','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 14:40:48',0,NULL,3,1,17,1,'YW867611593CN\r ','eastar4uk'),(24147,799420436008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','mopnup','drdanbon@aol.com','Daniel Bonfiglio','6676 Exchequer Dr','Baton Rouge','LA','UNITED STATES','70809-5147','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-21 15:35:27',0,NULL,3,1,1,1,'LK238402667CN\r ','au-buy'),(24148,0,220976891795,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses TMR BR 100',1,'TRSN001',9.99,'eastar4uk','jashdahi','ebay@jashdahi.nildram.co.uk','Jason Hilton','60 St Albans Road','Blackpool','Lancashire','UNITED KINGDOM','FY1 4EQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 15:56:48',0,NULL,3,1,3,1,'RA386088155CN\r ','eastar4uk\rTRSN001'),(24149,864192121011,320786223079,'New Visenta Wireless keyboard Muti-point Touch pad',1,'KBVI001',85.99,'eastar4','mabrasil','tomybrasil@hotmail.com','Manuel Antonio Barreira','R. Cristovão Lins,531','São Paulo','São Paulo','BRAZIL','02083-000','11 29895382','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 16:03:02',0,NULL,3,1,3,1,'RA386088274CN\r ','eastar4\rKBVI001'),(24150,799425227008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','jdubnz','emailjoelrussell@gmail.com','Joel Russell','4A Eastglen Road, Glen Eden','Auckland','Waitakere','NEW ZEALAND','0602',' 642102375392','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-21 15:49:22',0,NULL,3,1,11,1,'BJ01714135\r ','au-buy\rMOMI002'),(24151,0,230764140470,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',2.99,'eastar4','damakor','frederictre@hotmail.com','Frédéric Tremblay','1-11½ Rue Notre-Dame','Québec','QC','CANADA','G1K4E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 16:22:06',0,NULL,3,1,11,1,'BJ01714120\r ','eastar4\rRCHP001'),(24152,860982837002,120841235310,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',99.99,'buysia','wildtrapper','psliger@serbernet.com','Pierre Sliger','Box 660','Falher','AB','CANADA','T0H 1M0','(780) 837-8253','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-21 16:29:07',0,NULL,3,1,3,1,'RA386088169CN\r ','buysia\rGPS0011'),(24153,640015864004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.29,'cnfaner','ledyanoy-44','ledyanoy44@gmail.com','Alexander Korenev','ul. Molodezhnaya, dom 54, kv. 38','Izhevsk','Udmurt Republic','RUSSIAN FEDERATION','426072','(950)810-5848','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 16:38:25',0,NULL,3,1,3,1,'RA386088107CN\r ','cnfaner\rHBPH003'),(24154,640006079004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',10,'CACN004',129,'cnfaner','torment66','ichernyakov@mail.ru','Igor Chernyakov','Elektricheskiy pereulok, 3/10 str.3, \"Notebookinn\"','Moscow','','RUSSIAN FEDERATION','123557','+79250026661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 16:44:25',0,NULL,1,1,3,1,'RA386088376CN ','cnfaner\rCACN004\r缺货 先录的号'),(24155,956307034012,220919281428,'Lowrance Airmap600C Upgraded Color Display GPS+WAAS Receiver',1,'GPS0012',199.99,'eastar4','wildtrapper','psliger@serbernet.com','Pierre Sliger','Box 660','Falher','AB','CANADA','T0H 1M0','(780) 837-8253','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 16:48:09',0,NULL,3,1,3,1,'RA386088075CN\r ','eastar4\rGPS0012'),(24156,956181107012,220950194178,'4 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',2,'PSGL001*4',527.98,'eastar4','dr.freedom','free-dom@mail.ru','Aleksandr Polotsky','Bogdanova 8.  2','Moskva','Moskva','RUSSIAN FEDERATION','119618','(916)206-1571','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 18:34:11',0,NULL,3,1,6,1,'EE667839169CN\r ','eastar4\rPSGL001*4'),(24157,640061475004,140516506881,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.9,'cnfaner','vitorjmm','vitorm@gmail.com','Vitor Melo','Av. Barão de Studart, 2095, apt 1002<br>Joaquim Távora','Fortaleza','Ceará','BRAZIL','60120-002','+558588917995','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 18:53:07',0,NULL,3,1,3,1,'RA386088084CN\r ','cnfaner\rWLDE002'),(24158,640062493004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','hgtstorebuy','hgtstore@gmail.com','DANIEL DEHLING','SIEDLECKIEGO 2','Władysławowo','pomorskie','POLAND','84-120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 19:00:41',0,NULL,3,1,3,1,'RA386088036CN\r ','cnfaner\rLGAD001'),(24159,956384248012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','sofitim555','tdnew1@verizon.net','TIm Newman','PO Box 218','Southfield','MA','UNITED STATES','01259-0218','(413) 229-2212','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 19:08:11',0,NULL,3,1,1,1,'LK238043023CN\r ','eastar4'),(24160,956396748012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','lw_wanderer','larry.finger@lwfinger.net','Larry Finger','411 Marina Ct','Smithville','MO','UNITED STATES','64089-8382','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 19:26:38',0,NULL,3,1,1,1,'LK238035716CN\r ','eastar4'),(24161,808179913007,170762819519,'Brand new HP MCE Media Center Remote Control bigger + IR RECEIVER+IR Emitter',1,'OTHP004',21.9,'au-buy','simcom0','psimonis@simcomcity.com','SIMCOM','21 Manikato Cl','Jimboomba','Queensland','AUSTRALIA','4280','0731033677','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 19:40:21',0,NULL,3,1,11,1,'BJ01714131\r ','au-buy\rOTHP004'),(24162,639585338004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','lebedew1','andrew.lebedew@gmail.com','Andrey Lebedev','Tovarisheskiy pr. 14-112','Saint-Petersburg','SPB','RUSSIAN FEDERATION','193312','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 20:11:19',0,NULL,3,1,3,1,'RA386088190CN\r ','cnfaner\rCACN004'),(24163,695779726013,230696519783,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',42.99,'eastar4','5668antonio','genio67a@yahoo.de','antonio galione','heppstr.137','reutlingen','','GERMANY','72770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 20:26:43',0,NULL,3,1,3,1,'RA386088172CN\r ','eastar4\rLGAD001'),(24164,634464505003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.59,'cnfaner','hgtstorebuy','hgtstore@gmail.com','Piotr Salwa','Sandomierska 28 m.40','Radom','mazowieckie','POLAND','26-611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 20:35:22',0,NULL,3,1,3,1,'RA386088209CN\r ','cnfaner\rTRSN001'),(24165,864343895011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','bonya13','friy@bk.ru','Artem Papcenko','Aharon Tsizling  11/8','Beer Sheva','','ISRAEL','84486','+972527726741','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 20:48:33',0,NULL,3,1,11,1,'BJ01714130\r ','eastar4\rHSJA002\r欧标'),(24166,640106512004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.29,'cnfaner','mfj7268hzm','mfj726@aol.com','Mark Jent','129 Falcon Crst','Warner Robins','GA','UNITED STATES','31088-7516','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-21 20:40:00',0,NULL,3,1,1,1,'LK237983679CN\r ','cnfaner'),(24167,0,120880723254,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',0.55,'buysia','remenyhal','lakhazi.tamas@freemail.hu','Tamás LAKHÁZI','Réti u. 158. II/4','TATABÁNYA','','HUNGARY','2800','+36205254294','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-21 21:17:03',0,NULL,3,1,11,1,'BJ01714125\r ','buysia\rANTY002'),(24168,0,320871853165,'Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n  BlueToo',1,'ANTY002',0.35,'eastar4','remenyhal','lakhazi.tamas@freemail.hu','Tamás LAKHÁZI','Réti u. 158. II/4','TATABÁNYA','','HUNGARY','2800','+36205254294','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:18:54',0,NULL,3,1,11,1,'BJ01714121\r ','eastar4\rANTY002'),(24169,816323021001,110830211070,'4 pairs of New 3D Active Shutter TV Glasses for Sony TDG-BR250 BR100',1,'GLOT001*4',147.99,'buysia','priscilla280','saenzroman7@gmail.com','priscilla velasquez','6525 lazy willow ct','corpus christi','TX','UNITED STATES','78412-4857','(361) 510-1433','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-21 21:35:42',0,NULL,3,1,1,1,'LK237936696CN\r ','buysia'),(24170,956486340012,220778955222,'New Original FireFly Borealis Illuminated USB Keyboard',1,'KBFF001',49.99,'eastar4','canadaorca','canadaorca@hotmail.com','Dr Jason Cressey','1404 Beddis Road','Salt Spring Island','BC','CANADA','V8K 2C9','(250) 538-0914','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:51:32',0,NULL,3,1,3,1,'RA386088230CN\r ','eastar4\rKBFF001'),(24171,956484403012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','the*driver','s7evemiller@aol.com','Steve Miller','43 Hawks Park','Saltash','Cornwall','UNITED KINGDOM','PL124SP','07710204480','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 21:52:52',0,NULL,3,1,3,1,'RA386088141CN\r ','eastar4uk\rHSJA010\r英标'),(24172,695816007013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','andersnavara','anderssletta@gmail.com','Anders Sletta','Soggemoen','Åndalsnes','NE','NORWAY','6300','99381661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:56:23',0,NULL,3,1,11,1,'BJ01714127\r ','eastar4\rCACN004'),(24173,956508294012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',171.99,'eastar4uk','vorave','gugive@infonegocio.com','GUSTAVO GIL VERA','C/ MARIA AMADOR 1-3ºI','LAS PALMAS DE GRAN CANARIA','LAS PALMAS','SPAIN','35016','660313047','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 22:38:31',0,NULL,3,1,4,1,'YW867611604CN\r ','eastar4uk\rOTSO004*4'),(24174,956508144012,220815929709,'New BroadCom Wireless + Bluetooth Card BCM94313 BCM9207',1,'WLIN015',6.99,'eastar4uk','darkloganmaster','rapsodya@gmail.com','Vitaliy Mostovyak','Olomouckaya 84 -172','Volzhsky','Volgogradskaya obl','RUSSIAN FEDERATION','404109','7-927-516-99-66','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 22:39:49',0,NULL,3,1,11,1,'BJ01714118\r ','eastar4uk\rWLIN015\r 无线蓝牙二合一'),(24175,864405347011,320394908463,'Acer Aspire 4230 4530 Bluetooth Module 2.0 EDR+cable',1,'BTAC2011',9.88,'eastar4','ee4219','securebid@sbcglobal.net','Jack Obst','1080 Pamela Dr','Florissant','MO','UNITED STATES','63031-2909','(314) 954-2234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 22:50:37',0,NULL,3,1,1,1,'LK238057711CN\r ','eastar4\rBTAC2011\racer 5pin1.25 4cm'),(24176,956525374012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','violinmusic2','bobandjudy@eaglecom.net','Robert L. Priest','Marion County Lake, 26 Lakeshore Drive','Marion','KS','UNITED STATES','66861','(620) 382-8904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 23:18:53',0,NULL,3,1,1,1,'LK238052498CN\r ','eastar4'),(24177,956535678012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','dpj4703','djursic@sympatico.ca','Dave Jursic','1079 Crosscreek Cresent','London','ON','CANADA','n5y 6k9','(519) 451-8661','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 23:48:00',0,NULL,3,1,3,1,'RA386088243CN\r ','eastar4\rPSGL001*2'),(24178,956532582012,220815928097,'Genuine Jabra BT500 Bluetooth Headset BT 500',1,'HSJA010',15.95,'eastar4uk','newington4u','bob.100scs@talktalk.net','Robert Sutherland','100 South Clerk Street','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH8 9PT','01316672991','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 23:53:25',0,NULL,3,1,3,1,'RA386088138CN\r ','eastar4uk\rHSJA010\r英标'),(24179,808314966007,170735485499,'New Auto folding 3-section Sun umbrella w/Paris Eiffel Tower pattern',1,'UM00015',24.99,'au-buy','kmcpink8q7w','kym_crawford@hotmail.com','Kym Crawford','6/21 Lisson Grove','Wooloowin','Queensland','AUSTRALIA','4030','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 00:19:43',0,NULL,3,1,11,1,'BJ01713490\r ','au-buy\rUM00015'),(24180,808317658007,170805377477,'Original Allied Telesyn CentreCOM AUI Ethernet 10Base-T RJ45 Transceiver',2,'TRTT002',19.98,'au-buy','silvan_kaz','silvan_kaz@hotmail.com','Kieran Sadlier','Unit 1A, 37 Delawney St','Balcatta','Western Australia','AUSTRALIA','6021','0402651373','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 00:30:33',0,NULL,3,1,11,1,'BJ01714132\r ','au-buy\rTRTT002'),(24181,695861557013,230641250398,'New Rainbow Trim  parasol Sun/Rian stick umbrella',1,'UM00009',24.99,'eastar4','rumba_babe18','nicksfastaparcels@bigpond.com','Jennifer Compston','PO Box 289','Garbutt East','Queensland','AUSTRALIA','4814','0410001970','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 00:42:12',0,NULL,3,1,11,1,'BJ01713489\r ','eastar4\rUM00009'),(24182,956557033012,220930548494,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M) adult',1,'PSGL001',68.99,'eastar4','denniswho','dennisgray@shaw.ca','Dennis Gray','133 Williams Street','Sault Ste. Marie','ON','CANADA','P6A 5V3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 00:45:14',0,NULL,3,1,3,1,'RA386088257CN\r ','eastar4\rPSGL001'),(24183,640183485004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','ibadru2','wmersfel@twcny.rr.com','Bill Mersfelder','103 Hazard St','Solvay','NY','UNITED STATES','13209-2326','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 01:09:13',0,NULL,3,1,1,1,'LK237949363CN\r ','cnfaner'),(24184,640191714004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','samuraidentista','valmirdentista@globo.com','valmir costa','rua engneheiro mario de gusmao, nº400<br>apto. 418-b , ponta verde','Maceió','alagoas','BRAZIL','57035000','8293310093','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 01:45:50',0,NULL,3,1,3,1,'RA386088022CN\r ','cnfaner\rLGAD001'),(24185,808344174007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','seppiroth','regent.fang@hotmail.com','Joseph Cucinotta','295-321 Perry Road, Keysborough','Melbourne','Victoria','AUSTRALIA','3173','0397981952','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 02:00:55',0,NULL,3,1,11,1,'BJ01713488\r ','au-buy\rRELO002\r'),(24186,956590543012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',24.99,'eastar4','markida07','bery_sur@qwest.net','Mark A Levings','25803 Tidball Ln.','Veneta','OR','UNITED STATES','97487','(541) 935-0940','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 02:24:14',0,NULL,3,1,1,1,'LK238170472CN\r ','eastar4'),(24187,8881332383709150,111,'New 2nd HDD hard drive caddy SATA for MacBook pro - ',1,'CACN004',12.99,'aliexpress','1007565752','carlosnino@hotmail.com','	Carlos Pinto Ferreira Martins','Ave. Eduard Maristany 13, Escalera: A Planta: 7 , Puerta: 3','Barcelona','Sant Adria de Besos','SPAIN','08930','654189178/+00 34 933563094',NULL,NULL,NULL,'2012-03-22 02:35:09',0,NULL,3,1,3,1,'RA386088186CN\r ','CACN004 '),(24188,864481285011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'eastar4','lansingbrandon','brandonellen21@gmail.com','Craig Moos','11534 E Madero Ave','Mesa','AZ','UNITED STATES','85209-1439','(989) 245-9308','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 02:46:00',0,NULL,3,1,1,1,'LK238205097CN\r\r ','eastar4'),(24189,695892429013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',147.99,'eastar4','franks_finds','franks_finds.ebay@comcast.net','Lou Erwin','1910 Tundra Loop','Mount Vernon','WA','UNITED STATES','98273-8638','(360) 873-8550','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 02:56:56',0,NULL,3,1,1,1,'LK238169797CN\r ','eastar4'),(24190,808361190007,170762819519,'Brand new HP MCE Media Center Remote Control bigger + IR RECEIVER+IR Emitter',2,'OTHP004',43.8,'au-buy','neven0101','neven@live.com.au','Neven Stewart','Unit 13 / 14 -18 Little Norman St','Southport','Queensland','AUSTRALIA','4215','0755388664','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 02:59:17',0,NULL,3,1,3,1,'RA386088331CN\r ','au-buy\rOTHP004'),(24191,0,140727455143,'New Fire-Pad Professional FPS Gaming Game Surface Mouse Pad',1,'MOFP001',2,'cnfaner','stonefilosoh','stonefilosoph@gmail.com','Alexey Kozlov','Malahova 116, kvartira 346','Barnaul','Altayskii kray','RUSSIAN FEDERATION','656000',' 79635022083','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 03:28:26',0,NULL,3,1,3,1,'RA386088345CN\r ','cnfaner\rMOFP001'),(24192,640213602004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','coreyasa','brown_21@live.ca','Corey Brown','169 Garden Avenue','Richmond Hill','ON','CANADA','l4c 6l7','(647) 208-9568','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 03:34:49',0,NULL,3,1,3,1,'RA386088359CN\r ','cnfaner\rHSJA002\r美标'),(24193,8881332387325985,111,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',0,'eastar4','themurrman','mgrudz@mac.com','Murray Grudzinski','LCBO<br>34 Barrack Street','Kingston','ON','CANADA','K7K 7A9','',NULL,NULL,NULL,'2012-03-22 03:35:25',0,NULL,3,1,3,1,'RA386088305CN\r ','UDAP001\r补发的\reastar4 '),(24194,634572987003,130596105709,'New Jabra JX10 Series II 2 Bluetooth headset red',1,'HSJA013',18.98,'cnfaner','sommervalley62','kaxmajan@yahoo.se','anette jovanovic','mäster henriks alle 9D','sollentuna','stockholm','SWEDEN','19274','+46735897755','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 04:01:14',0,NULL,3,1,3,1,'RA386088265CN\r ','cnfaner\rHSJA013\r欧标'),(24195,0,120881422553,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',0.06,'buysia','manymorepoppula','sapoldanai.d@gmail.com','Chaiyarerk Aksornpreechanon','4 Park Dr<br>Dr.lavale','Lavale','MD','UNITED STATES','21502-7522','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-22 04:16:53',0,NULL,3,1,1,1,'LK238400428CN\r ','buysia'),(24196,0,220982052481,'3G WWAN antenna MC8775 MC8781 F3507G GTM382 dell 5530',1,'ANCN001',0.01,'eastar4uk','kenney0_0','johnkenney2@yahoo.co.uk','John Kenney','196 Gleadless Common','Sheffield','South Yorkshire','UNITED KINGDOM','S12 2US','01142653917','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 04:35:42',0,NULL,3,1,3,1,'RA386088212CN\r ','eastar4uk\rANCN001'),(24197,808381182007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','debvantir','debbiet78@optusnet.com.au','Debbie Tiratel','PO Box 792','SUMNER PARK','Queensland','AUSTRALIA','4074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 04:38:03',0,NULL,3,1,11,1,'BJ01713492\r ','au-buy\rUM00040'),(24198,808381449007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',19.99,'au-buy','delasias2010','delasias73@hotmail.com','Joe Nebe','4 / 40 Tenth Avenue<br>Windsor','Brisbane','Queensland','AUSTRALIA','4030','0418763037','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 04:47:31',0,NULL,3,1,11,1,'BJ01713491\r ','au-buy\rUM00001\r黑色'),(24199,0,220982016419,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',36,'eastar4','bcristy','cbcristy@msn.com','Carl Cristy','81 Lakeside Dr','Shrewsbury','MA','UNITED STATES','01545-4546','(508) 769-3408','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 05:09:16',0,NULL,3,1,1,1,'LK238437175CN\r ','eastar4'),(24200,640228935004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',1,'HSNO022',14.88,'cnfaner','adelan2011','adelan.errachide@gmail.com','ADNANE ERRACHIDE','100 Bergen Ave','kearny','NJ','UNITED STATES','07032-2006','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 05:26:27',0,NULL,3,1,1,1,'LK238417508CN\r ','cnfaner'),(24201,0,130668559715,'Unlocked NEW Sierra Wireless WWAN MC8780 +3G antenna',1,'WWSI004+ANCN001',0.01,'cnfaner','raz.van','contact.cnm@gmail.com','Imbrea Catalin','Bld. Socola, 2, Bl.F ,Sc.F, Et.8, Ap.29','IASI','IASI','ROMANIA','700289','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 06:58:02',0,NULL,5,1,3,1,'、','cnfaner\rWWSI004+ANCN001 价格错了 实际没发'),(24202,0,220980385821,'NEW Atheros AR5B93 Half Height Wireless WiFi card 300M',1,'WLAT008',2.99,'eastar4','stanislav_777','astanislav@russia.ru','Станислав Алехин','Akademika Koroleva 8-2-210','Moscow','RU','RUSSIAN FEDERATION','129515','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 07:12:21',0,NULL,3,1,11,1,'BJ01714111\r ','eastar4\rWLAT008');
INSERT INTO `hmsh_ebay_eastar_transaction` VALUES (24203,808415336007,170746910673,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Patten',1,'UM00040',19.99,'au-buy','carolineatau','389026654@qq.com','zi ye','42 stirling street','footscray','Victoria','AUSTRALIA','3011','0452214515','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 07:54:47',0,NULL,3,1,11,1,'BJ01714115\r ','au-buy\rUM00040'),(24204,950219260012,220785820173,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',44.89,'eastar4','rassomaha2012','niskovskiy1956@mail.ru','Николай Нисковский','г.курган','Ипподромная  д.13 кв.72','Курганская','RUSSIAN FEDERATION','640002','89128333714','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 08:36:45',0,NULL,3,1,3,1,'RA386088380CN\r ','eastar4\rGLOT001'),(24205,808425594007,170789531080,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista',1,'RCHP002',7.99,'au-buy','puck_ii','sexualdyslexia@aim.com','Patrick Foley','32 Patricia St','Marsfield','New South Wales','AUSTRALIA','2122','61419736539','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 08:41:32',0,NULL,3,1,11,1,'BJ01714116\r ','au-buy\rRCHP002'),(24206,862792357011,320826634655,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',44.99,'eastar4uk','*scientia*','weyl33@yahoo.com','Kalina Rose','8345 NW 66th St<br># 6294','MIAMI','FL','UNITED STATES','33166-2626','3054061696','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 08:44:19',0,NULL,3,1,3,1,'RA386088393CN\r ','eastar4uk\rHBPH001\r新地址\rKalina Rose\r23/8 High Timber Street\rLondon London EC4V 3PA\rUnited Kingdom\r\r'),(24207,0,220980489954,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',23,'eastar4uk','oldkamoon2012','oldkamoon@gmail.com','enrico acoca','moshe veber 8/7','ashkelon','','ISRAEL','78697',' 0505454592','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 08:47:36',0,NULL,3,1,11,1,'BJ01714117\r ','eastar4uk\rLGRM001'),(24208,634610890003,130490601966,'HP Broadcom BCM4322 4322 half mini PCI-E card wifi AGN',1,'WLHP002',11.9,'cnfaner','0248991','paypal@jvthert.dds.nl','Jeroen van \'t Hert','Groenewoudsedijk 41','Utrecht','','NETHERLANDS','3528BG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 08:56:01',0,NULL,3,1,3,1,'RA386088402CN\r ','cnfaner\rWLHP002'),(24209,864563436011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','harijs','harijs@parks.lv','Harijs Ausmanis','Rododendru 5 - 13','Riga','','LATVIA','LV-1083','+371 67844984','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 09:23:24',0,NULL,3,1,11,1,'BJ01714114\r ','eastar4\rANCN001'),(24210,864570760011,320861244985,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card+antenna*2',1,'WLHP002+ANTY001',12.99,'eastar4','tlarum927','tiffanyl927@yahoo.com','tiffany larum','10955 N 79th Ave<br>Lot 61','peoria','AZ','UNITED STATES','85345-5971','(480) 310-2008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 09:50:29',0,NULL,3,1,1,1,'LK238823143CN\r ','eastar4\rWLHP002+ANTY001'),(24211,799787985008,180781265436,'New Grohe handheld Shower Head big water output w/Massage function + Grohe hose',2,'OTGR005+OTGR002',79.8,'au-buy','sonik_74','szymras@hotmail.com','Dave Sonia Barras','12 Lambert crt','Rosebud','Victoria','AUSTRALIA','3939','0359748857','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 09:56:55',0,NULL,3,1,3,1,'RA386088464CN\r ','au-buy\rOTGR005+OTGR002'),(24212,0,180845712489,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',25.5,'au-buy','leni730','larryld4@bigpond.com','Laurence De Longville','3 View Court','DANDENONG.','Victoria','AUSTRALIA','3175','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 10:13:13',0,NULL,3,1,11,1,'BJ01714099\r ','au-buy\rGLOT001'),(24213,864605964011,320741901009,'Original Yamaha AV Remote control RAV255 WE45880 EU',1,'RCYA001',22.99,'eastar4uk','casper27534','thomas.wilpernig@gmail.com','Thomas Wilpernig','Gurk Au 25','Althofen','','AUSTRIA','9330','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 11:57:31',0,NULL,3,1,11,1,'BJ01712824\r ','eastar4uk\rRCYA001'),(24214,0,230763683178,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',18.5,'eastar4','marioemd226','marioemd203@gmail.com','Mario Martinez','5597 Seminary Rd<br>Apt 2009S','Falls Church','VA','UNITED STATES','22041-2915','(703) 459-6410','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 12:00:20',0,NULL,3,1,1,1,'LK238831462CN\r ','eastar4'),(24215,956743450012,220748695606,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 cable',1,'OTCN004*10',10.39,'eastar4uk','windsorbrokersltd','offers@windsorbrokersltd.com','IT Support','Windsor Business Center<br>53, Spyrou Kyprianou Av.','Limassol','Mesa Yitonia','CYPRUS','4004','00357 25500970','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 12:36:37',0,NULL,3,1,11,1,'BJ01714097\r ','eastar4uk\rOTCN004*10'),(24216,0,220980489927,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',17.99,'eastar4uk','peejay0_10','pjreader24@msn.com','Peter Reader','Ashmead House, Halwill Junction','Beaworthy','Devon','UNITED KINGDOM','EX215UA','01409221601','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 13:02:33',0,NULL,3,1,3,1,'RA386088521CN\r ','eastar4uk\rHBPH007'),(24217,956472456012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','suk_cho20032012','suk_cho2003@yahoo.com','Suk Cho','7761 Water St','Fulton','MD','UNITED STATES','20759-2557','(646) 279-9400','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 13:14:27',0,NULL,3,1,1,1,'LK238855305CN\r ','eastar4'),(24218,864630640011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','danhoule41','danielhoule488@msn.com','Daniel Houle','1359,Cartier','Saint-Laurent','QC','CANADA','H4L2N7','(514) 748-2891','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 13:17:06',0,NULL,3,1,11,1,'BJ01714113\r ','eastar4\rOTCN002'),(24219,956763596012,220815930479,'New GENUINE NOKIA BH-700 BLUETOOTH HEADSET',1,'HSNO028',13.39,'eastar4uk','cavallo316','djcaval@yahoo.com','Roderick Cavallo','15<br>Edward Str','Cospicua','Europe','MALTA','BML2140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 13:18:46',0,NULL,3,1,11,1,'BJ01714098\r ','eastar4uk\rHSNO028\r英标'),(24220,864634636011,320821464650,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV ANWF100',1,'LGAD001',30.99,'eastar4uk','gazzaoc81','gaz_oconnor@hotmail.co.uk','Gary O Connor','milson road<br>4 rayburne court','london','London','UNITED KINGDOM','w140lf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 13:29:17',0,NULL,3,1,3,1,'RA386088566CN\r ','eastar4uk\rLGAD001'),(24221,0,320871203774,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M',1,'SCLO002',0.06,'eastar4uk','joanne.1736','freak614@yahoo.com','paul matson','3 penmayne villas<br>rock','wadebridge','Cornwall','UNITED KINGDOM','pl276nh','01208869498','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 14:28:38',0,NULL,3,1,3,1,'RA386088433CN\r ','eastar4uk\rSCLO002'),(24222,0,180845712457,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',5.99,'au-buy','bluenose380','leslielloyd@blueyonder.co.uk','Leslie Lloyd c/o hardyman','Hardyman Ltd<br>Oakfield House 478 Station Rd','Dorridge Solihull','West Midlands','UNITED KINGDOM','b93 8he','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-22 14:47:50',0,NULL,3,1,11,1,'BJ01714096\r ','au-buy\rRELO002'),(24223,640330171004,140583359827,'New Jabra BT500V FreeSpeak Bluetooth Headset BT 500V',1,'HSJA011',27.5,'cnfaner','eric.robitaille','snowduckbibi@hotmail.com','Eric Robitaille','977 St-Clement','Mercier','QC','CANADA','J6R 1T5','(450) 698-1922','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 14:52:57',0,NULL,3,1,3,1,'RA386088420CN\r ','cnfaner\rHSJA011'),(24224,956803156012,220815927687,'Allied Telesyn CentreCOM AUI Ethernet 10Base-T 210T',10,'TRTT002',69.9,'eastar4uk','ercanyildiz','ekol@ekolteknoloji.com.tr','ERCAN YILDIZ','EKOL Teknoloji, 2. Organize San. Bol.<br>Muammer Guler Bul. No:14','Baspinar / Gaziantep','27','TURKEY','27120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 15:02:41',0,NULL,4,0,3,0,NULL,'eastar4uk\r客户要退他钱部分钱'),(24225,0,230764668650,'A Pair of New Tyco 2.4/5.0GHz Dual Mini Pci Antenna',1,'ANTY001',0.46,'eastar4','vestel.technologies','djeddydj@yahoo.com','MOROZOV EDUARD','Sector 6 ,STR. CARA ANGHEL , NR 11, BL C55 ,SC A, ET 3, Ap. 20','BUCURESTI','ROMANIA','ROMANIA','061642','+40722869715','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 15:23:58',0,NULL,3,1,11,1,'BJ01714101\r ','eastar4\rANTY001+ANTY002\r再发一个Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n BlueToo\r'),(24226,864673630011,320816532232,'New BELKIN F5D7050 wireless WiFi network adapter+USB base 54M 802.11g',1,'OT00002',12.99,'eastar4','rits4u','ritesh.mangal2@gmail.com','Ritesh Mangal','605, 82 Ontario Street','Kingston','ON','CANADA','K7L5M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 15:24:49',0,NULL,3,1,11,1,'BJ01714108\r ','eastar4\rOT00002'),(24227,864680848011,320441575818,'2.1 Acer Travelmate 5520 5530 Bluetooth Module+cable',1,'BTAC2109',12.39,'eastar4','lzw200_0','williams1949@rogers.com','Lloyd Williams 416-433-8559','1711 Cudaback Ave','Niagara Falls','NY','UNITED STATES','14303-1709','(416) 433-8559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 15:42:38',0,NULL,3,1,1,1,'LK238839639CN\r ','eastar4\rBTAC2109\racer 4pin1.25 20cm'),(24228,696040664013,230641567572,'2 pairs 3D Active shutter Glasses 4 SONY TDG-BR250',1,'GLOT001*2',77.99,'eastar4','helgem3','helge_monsen@hotmail.com','helge monsen','saltfjellveien 689','storforshei','','NORWAY','8630','94247310','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 16:07:20',0,NULL,3,1,3,1,'RA386088416CN\r ','eastar4\rGLOT001*2'),(24229,696048380013,230641235669,'New lady Piano Anti-UV Rain Sun Parasol Stick Umbrella',1,'UM00010',24.99,'eastar4','vtahmaz','vtahmaz@hotmail.com','Viktor Tahmaz','Matije Gupca 115<br>Pojatno','Donja Pusca','','CROATIA','10294','+385992346998','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 16:33:39',0,NULL,3,1,11,1,'BJ01714089\r ','eastar4\rUM00010\r粉红色的'),(24230,634715578003,130617205363,'Lowrance Waterproof iFINDER Hunt Handheld GPS+WAAS Receiver',1,'GPS0011',98.9,'cnfaner','biigtiitan','crashsmash@msn.com','Brent Cronkwright','1083 6th Con.<br>RR1','Waterford','ON','CANADA','n0e 1y0','(519) 443-4595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 17:02:43',0,NULL,3,1,3,1,'RA386088481CN\r ','cnfaner\rGPS0011'),(24231,956888724012,220793700984,'2 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*2',87.99,'eastar4uk','20and11','andy.heeggie@ntlworld.com','andrew heggie','69 woodside crescent<br>staincliffe','batley','West Yorkshire','UNITED KINGDOM','wf17 7dy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 18:25:24',0,NULL,3,1,3,1,'RA386088583CN\r ','eastar4uk\rOTSO004*2'),(24232,864748838011,320408111964,'3G WWAN antenna MC8775 MC8781  F3507G GTM378 dell 5530',1,'ANCN001',4.89,'eastar4','major-naiman','ilya.nurzhanov@mail.ru','Илья Нуржанов','ул.Восточная, 29','г.Астрахань','Астраханская обл','RUSSIAN FEDERATION','414041','79033212308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 18:25:40',0,NULL,3,1,11,1,'BJ01714112\r ','eastar4\rANCN001'),(24233,696092256013,230412690731,'2.0 New ASUS Bluetooth Module+cable A8/Z99/F8/N80/U5/U6',1,'BTHU2001',9.88,'eastar4','vsaxis','vsaxis@gmail.com','Sergey A Vasyuk','Kahovka d.16 k.1 kv.6','Moscow','','RUSSIAN FEDERATION','117461','+79261700999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 18:43:25',0,NULL,3,1,11,1,'BJ01712819\r ','eastar4\rBTHU2001\r华硕10pin 0.8 6cm '),(24234,956921547012,220825062401,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo E27',1,'BTLE3001',19.98,'eastar4','oppauli','uliwessel@gmx.de','Ulrich  Wessel','c/o Schoenhofer GmbH Lindenstr. 92-98','Siegburg','','GERMANY','53721','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 19:10:00',0,NULL,3,1,11,1,'BJ01712820\r ','eastar4\rBTLE3001'),(24235,956784174012,220852716608,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',27.99,'eastar4','kostas2917','kospi@otenet.gr','costas spiliopoulos','lampi 120','kos','','GREECE','166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 19:22:00',0,NULL,3,1,11,1,'BJ01714107\r ','eastar4\rMOAP001'),(24236,864783440011,320557739481,'2.0 Acer Aspire 5740 8730 7738 7740 Bluetooth Module',1,'BTAC2004',9.88,'eastar4','jasond1188','ja121@hotmail.co.uk','mr j b dees','63 grantham avenue<br>kingswood','hull','Humberside','UNITED KINGDOM','hu7 3dt','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 19:26:33',0,NULL,3,1,11,1,'BJ01712822\r ','eastar4\rBTAC2004\racer 4pin1.25 6cm\r'),(24237,864790181011,320786773728,'New iTech Clip II mini Multipoint Bluetooth Headset blue',2,'HSIT004',39.98,'eastar4uk','simela1980','semi9055@yahoo.gr','SIMELA EYSTATHIADOY','ITHOMIS, 67<br>67','AIGALEO','ATHENS','GREECE','12244','2105443787','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 19:35:34',0,NULL,3,1,3,1,'RA386088552CN\r ','eastar4uk\rHSIT004'),(24238,0,220982052318,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',1,'POLO001',0.06,'eastar4uk','mladen-ab','ablau@posluh.hr','Anton Blau','Grobnicka cesta 10','Rijeka','','CROATIA','51000','091 537 2204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 19:38:44',0,NULL,3,1,11,1,'BJ01714109\r ','eastar4uk\rPOLO001'),(24239,0,120881422912,'New US Logitech Harmony AC Power Adapter',1,'POLO001',0.99,'buysia','mladen-ab','ablau@posluh.hr','Anton Blau','Grobnicka cesta 10','Rijeka','','CROATIA','51000','091 537 2204','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-22 19:41:01',0,NULL,3,1,11,1,'BJ01714102\r ','buysia\rPOLO001'),(24240,864793402011,320500774916,'New GENUINE NOKIA BH-900 BLUETOOTH HEADSET BH 900',1,'HSNO019',37.98,'eastar4','pringles05','sylvia.knoepfler@web.de','Sylvia Knöpfler','Maria-Anna-Braig-Weg 3','Ravensburg','','GERMANY','88212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 19:41:10',0,NULL,3,1,11,1,'BJ01714105\r ','eastar4\rHSNO019\r欧标'),(24241,0,230761952786,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',12.5,'eastar4','oscbay','ebay408@tampabay.rr.com','Dennis Misorek','1424 North Hampton Drive','Davenport','FL','UNITED STATES','33897','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 19:44:44',0,NULL,3,1,1,1,'LK238839188CN\r ','eastar4\r带麦的'),(24242,696117162013,230685089110,'4 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*4',147.99,'eastar4','ciarik','jjarik@mail.ru','Jaroslavas Brasel','Kelmijos 70','Vilnius','Vilnius','LITHUANIA','LT- 02212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 20:01:02',0,NULL,3,1,3,1,'RA386088606CN\r ','eastar4\rGLOT001*4'),(24243,0,320872641121,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',16.2,'eastar4uk','bongybill','markoneill@blueyonder.co.uk','Mark O\'Neill','4 Tilney Street<br>Orrell Park','Liverpool','Merseyside','UNITED KINGDOM','L9 8DT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 20:16:45',0,NULL,3,1,3,1,'RA386088478CN\r ','eastar4uk\rGLOT001'),(24244,0,130667531650,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',2.25,'cnfaner','b_robert8777','b_robert87@yahoo.com','bratescu robert','rotunda nr 8<br>bloc Y2C sc2 ap 49','bucuresti','bucuresti','ROMANIA','032701','(0040)0745932704','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 20:18:47',0,NULL,3,1,3,1,'RA386088504CN\r ','cnfaner\rPOLO001'),(24245,864825887011,320730549137,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR250',1,'GLOT001',25.99,'eastar4uk','ron6391','ronwhite62@talktalk.net','Ronald White','Foxgloves<br>2 Holt View','Great Easton','Leicestershire','UNITED KINGDOM','LE16 8TN','01536771423','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 20:35:16',0,NULL,3,1,3,1,'RA386088597CN\r ','eastar4uk\rGLOT001'),(24246,640442011004,140584763385,'New original ASUS N554 bluetooth mouse+manual',1,'MOAS001',23.9,'cnfaner','derek_smalls7','dereksmalls7@gmail.com','Ryan Williams','620 Pamela Rd','Waco','TX','UNITED STATES','76708-7095','(254) 733-8830','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 20:42:17',0,NULL,3,1,1,1,'LK238756293CN\r ','cnfaner'),(24247,634796696003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.59,'cnfaner','hgtstorebuy','hgtstore@gmail.com','Sławomir Miiller','Kolska Szosa 11','Turek','wielkopolskie','POLAND','62-700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 20:55:45',0,NULL,3,1,3,1,'RA386088455CN\r ','cnfaner\rTRSN001'),(24248,640449455004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','hgtstorebuy','hgtstore@gmail.com','ELZBIETA KOMOROWSKA','MICKIEWICZA 35','JELENIA GORA','dolnośląskie','POLAND','58-500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 21:01:55',0,NULL,3,1,3,1,'RA386088447CN\r ','cnfaner\rLGAD001'),(24249,696150489013,230655991587,'Clear Transparent Dome Birdcage Rain Umbrella w/patten',1,'UM00033',19.99,'eastar4','ptavaresvieira00','ptavaresvieira@gmail.com','Paula Tavares Vieira','Rua Carolina Santos','Rio de Janeiro','Rio de Janeiro','BRAZIL','20720310',' 2182420844','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 21:02:39',0,NULL,3,1,11,1,'BJ01714090\r ','eastar4\rUM00033'),(24250,864843525011,320737995787,'2 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*2',50.99,'eastar4uk','326miner','reggyperrin@hotmail.co.uk','alfred','perrin<br>21 monkwood rd','outwood wakefield','West Yorkshire','UNITED KINGDOM','wf12jx','01924823487','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 21:04:48',0,NULL,3,1,3,1,'RA386088570CN\r ','eastar4uk\rGLOT001*2'),(24251,634800977003,130623334267,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.59,'cnfaner','hgtstorebuy','hgtstore@gmail.com','Maciej Grzesikiewicz','Grunwaldzka 47/8','Gdansk','pomorskie','POLAND','80-241','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 21:07:12',0,NULL,3,1,3,1,'RA386088549CN\r ','cnfaner\rTRSN001'),(24252,864856590011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',19.99,'eastar4','cb942','chuck@quad-b.com','Charles Barrett','2148 Niagara Falls Blvd','Tonawanda','NY','UNITED STATES','14150-4734','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 21:30:25',0,NULL,3,1,1,1,'LK238826122CN\r ','eastar4\rHSJA002'),(24253,640462832004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','hgtstorebuy','hgtstore@gmail.com','Edyta Siller','Gospodarcza 4d/63','Sosnowiec','śląskie','POLAND','41-200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 21:41:12',0,NULL,3,1,3,1,'RA386088495CN\r ','cnfaner\rLGAD001'),(24254,816782075001,110807072704,'New USB Battery Cell Eco-friendly Rechargeable AA Battery 1.2V-1450mAh',1,'OT00004',7.8,'buysia','rojatrmara','mcbrrb96@sbcglobal.net','Raymie Burns','309 high st','waupaca','wi','UNITED STATES','54981-1747','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-22 21:53:22',0,NULL,3,1,1,1,'LK238754978CN\r ','buysia'),(24255,957029728012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','412412nikki','rlyons3@live.com','Roger Lyons','89 Springmeadow Ct','Pittsburgh','PA','UNITED STATES','15236','(412) 885-2332','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 22:02:14',0,NULL,3,1,1,1,'LK238801616CN\r ','eastar4\rPSGL001*2'),(24256,864882967011,320577184889,'New ULTIMATE EARS METRO.FI 220 EARPHONE UE220 UE',1,'HSUE002',18.99,'eastar4','dzinch','milbergs@inbox.lv','Dzintars  Milbergs','Inzenieru 99-29','Ventspils','Ventspils','LATVIA','LV-3601','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 22:28:13',0,NULL,3,1,11,1,'BJ01714104\r ','eastar4\rHSUE002'),(24257,0,220980488451,'New Fire-Pad Professional FPS Gaming Game Surface Mouse',1,'MOFP001',0.52,'eastar4uk','alexjumping00','maosin00@hotmail.com','Alejandro  Lobato Gimenez','Calle Valle de Zuriza <br>nº18  6ºD','Zaragoza','Aragón','SPAIN','50015','655581582','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 22:28:18',0,NULL,3,1,11,1,'BJ01714106\r ','eastar4uk\rMOFP001'),(24258,696180098013,230633020151,'New Samsung WMN2000A Ultra Slim Wall Mount 32\"-40\"  TV',1,'MOSA004',67.99,'eastar4','fcandel','fcandel76@gmail.com','Francesc Candel Soley','Calle Aragón num 390 5 piso','Barcelona','Cataluña','SPAIN','08013','630940277','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 22:31:00',0,NULL,3,1,3,1,'RA386088518CN\r ','eastar4\rMOSA004'),(24259,0,120880148339,'New Fire-Pad Professional FPS Gaming Game Surface Mouse Pad',1,'MOFP001',2.05,'buysia','tehskyzone','skyzone@live.ca','Kevin Rodrigue','741 Abbé-Théoret, Apartment #5','Sainte-Julie','QC','CANADA','J3E 1R9','(450) 986-1689','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-23 00:29:37',0,NULL,3,1,11,1,'BJ01714110\r ','buysia\rMOFP001'),(24260,640507031004,140584764214,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',18.29,'cnfaner','cndylane','cndymos@aol.com','Cindy Moscatelli','9311 204th Ave E','Bonney Lake','WA','UNITED STATES','98391-6332','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 00:35:20',0,NULL,3,1,1,1,'LK238746693CN\r ','cnfaner'),(24261,8881332465224245,111,'Free shipping & Tracking # - New 3-section Anti-UV Waterproof Blue Sky & White Cloud Sun/Rain folding Umbrella - ',1,'UM00043',19.99,'aliexpress','1007580236','1@1.com','Sofiya Uryvayeva','500 Three Islands Blvd., Apt. 209 ','Hallandale Beach','Florida','UNITED STATES','33009','+305 600 6977',NULL,NULL,NULL,'2012-03-23 01:13:44',0,NULL,3,1,1,1,'LK100834356CN ',NULL),(24262,8881332465380634,111,'New HP MCE Media Center Remote Control big+ IR RECEVE - ',1,'OTHP004',22.99,'aliexpress','1007570807','robert.edwards1987@gmail.com','robert edwards','10 macadam pl gunn ','Palmerston','Northern Territory','AUSTRALIA','0832','+61 08 89327768',NULL,NULL,NULL,'2012-03-23 01:16:20',0,NULL,3,1,3,1,'RA386088708CN\r ','OTHP004 '),(24263,864943840011,320553054241,'NEW GENUINE NOKIA BH-103 BLUETOOTH HEADSET BH 103',1,'HSNO003',21.99,'eastar4','nishonda','cindaysales@aol.com','Gordon Blake','8216 Princeton Glendale Rd','West Chester','OH','UNITED STATES','45069-1675','(513) 608-0538','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 01:30:15',0,NULL,3,1,1,1,'LK238821448CN\r ','eastar4\rHSNO003'),(24264,800147343008,180792779402,'New Microsoft Wired Optical Wheel USB Compatible  Mouse Black',1,'MOMI002',13.79,'au-buy','jhovez','jhovey.a.breva@gmail.com','Jhovey Breva','26 Bordeaux Cres','Castle Hill','New South Wales','AUSTRALIA','2154','0298948551','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 02:00:27',0,NULL,3,1,11,1,'BJ01714103\r ','au-buy\rMOMI002'),(24265,864960299011,320873430981,'New Tracker For GSM GPRS GPS System Tracking bundle TK102 + 8pin USB car charger',1,'GPS0006+ADPT002',65.99,'eastar4','buythai77','supatraputthaklang@gmail.com','supatra putthaklang','317 changphuak rd.','muang nakhonratchasima','','THAILAND','30000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 02:33:54',0,NULL,3,1,3,1,'RA386088535CN\r ','eastar4\rGPS0006+ADPT002'),(24266,864967551011,320616837853,'New 44 Pin Female to Female Mini IDE Cable for PC 30cm',1,'OTCN002',5.98,'eastar4','kuko-900','kuko900@hotmail.com','Felix Carrasquillo','19C Cook Lane','Marlborough','MA','UNITED STATES','01752','(508) 251-1341','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 02:54:15',0,NULL,3,1,1,1,'LK238911174CN\r ','eastar4\rOTCN002'),(24267,0,230765175493,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',2.07,'eastar4','killafreak','drago_d@abv.bg','Drago Draganov','949 E Piney Branch Dr<br>Apt 201','Virginia Beach','VA','UNITED STATES','23451-6763','(757) 462-6450','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 03:20:07',0,NULL,3,1,1,1,'LK238920304CN\r ','eastar4\rMOFP001'),(24268,0,140728104842,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',33,'cnfaner','linds1982','lcarl1982@yahoo.com','lindsay carlisle','254 Divisadero St<br>Apt 10','san francisco','CA','UNITED STATES','94117-3257','(908) 507-1419','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 03:30:08',0,NULL,3,1,1,1,'LK239255846CN\r ','cnfaner'),(24269,957147424012,220885789282,'4 pairs 3D Active shutter Glasses 4 SHARP LC-40LE835U',1,'GLOT001*4',147.99,'eastar4','jalvwfans','vwfans@hotmail.com','Jerry Larkin','4720 73rd Dr NE','Marysville','WA','UNITED STATES','98270-8849','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 03:32:38',0,NULL,3,1,1,1,'LK238928373CN\r ','eastar4'),(24270,957154480012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','katajkar','a.johnson1@comcast.net','Antoine Johnson','42 W 55th Pl','Westmont','IL','UNITED STATES','60559-2335','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 04:03:07',0,NULL,3,1,1,1,'LK239200414CN\r ','eastar4'),(24271,696259617013,230611970211,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',18.99,'eastar4','souji72','scbyoon@hotmail.com','Chang Bae Yoon','10 Country Village Villas NE','Calgary','AB','CANADA','T3K0L7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 04:30:51',0,NULL,3,1,11,1,'BJ01712823\r ','eastar4\rWLIN014'),(24272,0,320871854719,'New Fire-Pad FPS Gaming Game Surface Mouse',1,'MOFP001',6.01,'eastar4','shirleen_i','iskandar.shirleen@gmail.com','Shirleen Iskandar','Pangeran Jayakarta 66 Blok B No.2','Jakarta','Jakarta','INDONESIA','10730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 04:38:06',0,NULL,3,1,11,1,'BJ01714088\r ','eastar4\rMOFP001\r'),(24273,957169663012,220812874680,'New Atheros AR5B195 Wireless Bluetooth Half PCI-E  card',1,'WLIN016',21.09,'eastar4','sergey_svivalnev','parents.b@gmail.com','Sergey Svivalnev','Dzerjinskogo st., 17','Izobilny','STAVROPOL REGION','RUSSIAN FEDERATION','356140','+79188707400','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 05:21:08',0,NULL,3,1,11,1,'BJ01714093\r ','eastar4\rWLIN016'),(24274,865005833011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','ghaffari23','ghaffari10@yahoo.com','Alex Ghaffari','211 S Poinsettia Pl<br>Apt 4','Los Angeles','CA','UNITED STATES','90036-2866','(310) 801-9110','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 06:10:41',0,NULL,3,1,1,1,'LK239248641CN\r ','eastar4'),(24275,8881332484464388,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',104,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Dave Tarr ','1408 N SAINT MARYS ST','SAN ANTONIO','TX','UNITED STATES','78215-1739 ','',NULL,NULL,NULL,'2012-03-23 06:34:24',0,NULL,3,1,3,1,'RA386088645CN\r ','MOAP001 \reastar4\r直接打款    '),(24276,8881332484750758,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Eric Topolsky','43 Bushwick Ave #2F ','Brooklyn','NY','UNITED STATES','11211','',NULL,NULL,NULL,'2012-03-23 06:39:10',0,NULL,3,1,3,1,'RA386088654CN\r ','MOAP001 \reastar4\r直接打款     '),(24277,8881332484873657,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Enjoli Rountree','43 BETTY ST ','UKIAH','CALIFORNIA','UNITED STATES','95482-5947','',NULL,NULL,NULL,'2012-03-23 06:41:13',0,NULL,3,1,3,1,'RA386088637CN\r ','MOAP001 \reastar4\r直接打款      '),(24278,8881332484998576,111,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',26,'eastar4','youtube123456','retardedmonkeycrap@gmail.com','Tyler Carson','6400 CORNHUSKER ','HWY LINCOLN','NEBRASKA','UNITED STATES','68507-3188 ','',NULL,NULL,NULL,'2012-03-23 06:43:18',0,NULL,3,1,3,1,'RA386088623CN\r ','MOAP001 \reastar4\r直接打款       '),(24279,634913574003,130465769239,'New SAMSUNG WMN1000B ULTRA SLIM WALL MOUNT TV 40\"-55\"',1,'MOOE002',46.99,'cnfaner','l4zypapa','v.lotchak@gmail.com','Victor Lotchak','Petrogradskaya Nab., 18A, of.501<br>OOO \"EKVANT\"','Saint-Petersburg','','RUSSIAN FEDERATION','197046','(911) 020-9798','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 06:52:56',0,NULL,3,1,3,1,'RA386088610CN\r ','cnfaner\rMOOE002\rOEM'),(24280,0,120880723331,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',13.99,'buysia','globalworlds','nguyennancy2010@hotmail.com','Dung Tran','902 Cooper Ct SE','Vienna','VA','UNITED STATES','22180-5966','(703) 400-3531','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-23 07:00:10',0,NULL,3,1,1,1,'LK239228602CN\r ','buysia'),(24281,0,220977645240,'New Intel Centrino Advanced N WiMAX 6250 622ANXHMW',1,'WLIN014',12.5,'eastar4','sharil_m','sharilmohd@gmail.com','Sharil Mohamad','Conditioning Center, National Sports Institute Of Malaysia<br>National Sports Complex Bukit Jalil','Sri Petaling','Kuala Lumpur','MALAYSIA','57000','0389929634','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 07:30:21',0,NULL,3,1,11,1,'BJ01714092\r ','eastar4\rWLIN014'),(24282,865022959011,320611022750,'Unlocked NEW Sierra WWAN MC8781 PCI-E HSUPA 3G+ antenna',1,'WWSI005+ANCN001',40.99,'eastar4','angel_minsk','usangel@inbox.ru','Klochka Aliaksandr','prospekt gazety \"Zvyazda\" , 37-24','Minsk','Minsk','BELARUS','220116','37529-1141721','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 07:41:07',0,NULL,3,1,3,1,'RA386088685CN\r ','eastar4\rWWSI005+ANCN001'),(24283,0,220982773310,'Dell 1510 mini PCI-E half size card +2 tyco antenna',1,'WLDE002+ANTY001',4.04,'eastar4','alikkach','pro22000@mail.ru','Aleksey Kachmar','Dobrovolskogo 128a, apt 40','Odessa','Odessa','UKRAINE','65111','+380674890616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 07:56:10',0,NULL,3,1,11,1,'BJ01714095\r ','eastar4\rWLDE002+ANTY001+RCHP002+ANTY002\r再发一个Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista small\r一个Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n BlueToo\r'),(24284,0,120882141339,'3PCS Brand New Tyco 2.4/5.0 GHz Mini Pci Antenna for Wireless 802.11 a/b/g/n',1,'ANTY002',0.06,'buysia','alikkach','pro22000@mail.ru','Aleksey Kachmar','Dobrovolskogo 128a, apt 40','Odessa','Odessa','UKRAINE','65111','+380674890616','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-23 07:58:01',0,NULL,3,1,11,1,'BJ01714094\r ','buysia\rANTY002'),(24285,634935411003,130620867997,'NIB Spy Vehicle Realtime Tracker For GSM GPRS GPS System Tracking Device TK103-2',1,'GPS0008',110.99,'cnfaner','and_lit','pp@lgeo.pl','Andrzej Litwin','Sikorskiego 30/3','Bytów','pomorskie','POLAND','77100','609 650231','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 09:20:26',0,NULL,0,1,3,0,NULL,'cnfaner\rGPS0008'),(24286,816953484001,110830210266,'New 3D Active Shutter TV Glasses compatible for  Sony TDG-BR250 TDG-BR100',1,'GLOT001',39.99,'buysia','serenkiy303','alfa303@mail.ru','Sergey Golovchenko','Komsomolskaya st. 115','Armavir','RU','RUSSIAN FEDERATION','352900','+79184923066','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-23 09:29:41',0,NULL,0,1,3,0,NULL,'buysia\rGLOT001'),(24287,696306140013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','ertanden','ertanden@gmail.com','Ertan Deniz','Siemens EC Galyum Blok Kat: 3 No: 2 Teknokent ODTÜ','ANKARA','Cankaya','TURKEY','06531','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 09:33:38',0,NULL,0,1,11,0,NULL,'eastar4\rCACN004'),(24289,0,180846444176,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',1,'UM00001',11.99,'au-buy','donnazt','donnatatnell@hotmail.com','Donna  Tatnell','22 Henry St','Sorell','Tasmania','AUSTRALIA','7172','0362651368','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 10:42:59',0,NULL,0,1,11,0,NULL,'au-buy\rUM00001\r粉色'),(24288,957233657012,220901458046,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip black ver1',1,'SHLO009',9,'eastar4uk','igorked','igorked@gmail.com','Igor Kedrinski','19Towerhill<br>Borrisokane','Nenagh','Tipperary','IRELAND','default','06727612','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 09:56:19',0,NULL,0,1,3,0,NULL,'eastar4uk\rSHLO009'),(24290,957250051012,220820893940,'New Logitech Performance MX Mouse M950 Mat 3M material',1,'SCLO004',3.4,'eastar4uk','markhamkevin302011','markhamkevin30@gmail.com','kevin markham','37 Kilkenny Court','Taunton','Somerset','UNITED KINGDOM','TA2 7QL','01823330185','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 10:51:21',0,NULL,0,1,3,0,NULL,'eastar4uk\rSCLO004'),(24291,0,140726735350,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',37.99,'cnfaner','kamalsadiyan2011','kamalsadiyan@yahoo.com','Sadiyan Halaldeen Kamal','8B-73L, National Scheme Raddolugama. Sri Lanka','Raddoluwa','Sri Lanka','SRI LANKA','+94','+94719651965','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 10:52:10',0,NULL,0,1,3,0,NULL,'cnfaner\rLGAD001'),(24292,0,140726735399,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',36,'cnfaner','razvan8','razuban8@yahoo.com','Otava Razvan','Str. Paduroiu Nr. 3 Bl.B25 Ap.2','Bucharest','Bucharest','ROMANIA','041471','+40724238785','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 11:13:16',0,NULL,0,1,3,0,NULL,'cnfaner\rLGRM001'),(24293,800274585008,180821242191,'100% NEW Genuine Intel 5300 AGN MIMO Wireless Network Mini PCI-E Card',1,'WLIN010',19.49,'au-buy','philipynt','ruanyt@gmail.com','Philip Yuen','2/6-8 May Street Eastwood','Sydney','New South Wales','AUSTRALIA','2122','0423704851','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 11:38:22',0,NULL,0,1,11,0,NULL,'au-buy\rWLIN010'),(24294,957268088012,220463388016,'Acer Aspire 5735 5735Z 5738Z Bluetooth Module 2.0+cable',1,'BTAC2005',9.88,'eastar4','outlawgull','aleksandrs.tarakanovs@gmail.com','Aleksandrs Tarakanovs','Ieriku 36-78','Riga','Riga','LATVIA','LV-1084','(371) 29 620 - 909','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 11:48:27',0,NULL,0,1,11,0,NULL,'eastar4\rBTAC2005\racer 4pin1.25 8cm'),(24295,0,220981252273,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',26.22,'eastar4uk','tcmdj1203','t.arsenault1@verizon.net','anthony arsenault','633 N Valley Pkwy','Lewisville','TX','UNITED STATES','75077','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 11:50:48',0,NULL,0,1,1,0,NULL,'eastar4uk'),(24296,800281267008,180827876552,'New CREATIVE SOUND BLASTER HD SB1140 STEREO USB SOUND CARD',1,'OTSB001',22.99,'au-buy','phillip636356','phillipmacrae@optusnet.com.au','Philip Macrae','PO Box 725<br>80 Bumboras Rd','Norfolk Island','New South Wales','AUSTRALIA','2899','0011672353990','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 12:03:29',0,NULL,0,1,11,0,NULL,'au-buy\rOTSB001'),(24297,0,110845541986,'Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',35.01,'buysia','abad55','karkingdom@verizon.net','KARAOKE KINGDOM','700 S Philadelphia Blvd<br>Ste D','ABERDEEN','MD','UNITED STATES','21001-3640','(410) 272-8322','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-23 12:08:34',0,NULL,0,1,1,0,NULL,'buysia'),(24298,634967255003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','p3pyt0','alejandro_fernandez_diaz@hotmail.com','Alejandro Fernandez','CMaria Moliner','Albacete','Castilla-La Mancha','SPAIN','02001','661871445','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 12:23:42',0,NULL,0,1,3,0,NULL,'cnfaner\rSHLO009'),(24299,640628752004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','rhymeshaker','wlltstsw@yahoo.com','william Tsitsiwu','156 colony rd<br>Apt A','silver spring','MD','UNITED STATES','20903-2507','(301) 412-5927','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 12:42:44',0,NULL,0,0,0,0,NULL,'cnfaner'),(24300,640629117004,140584761987,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.9,'cnfaner','emarikos','marikosich@gmail.com','Mark Ganzin','st. Kuznechnaya<br>13/1','Leningradskaya','Krasnodar region','RUSSIAN FEDERATION','353740','+79282402092','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 12:44:27',0,NULL,1,1,3,0,NULL,'cnfaner\rCACN004'),(24301,0,320867813708,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',48,'eastar4uk','eskimokarl','eskimosound@hotmail.co.uk','Karl Thorpe Morgan','The Loft Mellor Hall<br>Mellor','STOCKPORT','Cheshire','UNITED KINGDOM','SK6 5LU','01614275950','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'eastar4uk'),(24302,634978014003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','sachagloba2012','sachagloba@gmail.com','Oleksandr Globa','street Dobrovolskogo, home 87, apartment 76','Odessa','Odessa','UKRAINE','65069',' 380677921329','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 13:06:20',0,NULL,0,1,3,0,NULL,'cnfaner\rSHLO009'),(24303,634979419003,130554590327,'NIB ESI 4-in/4-out PCI Audio Interface MAYA44 24BIT/96K',1,'OTES001',77.9,'cnfaner','xenofonvasiliadis','xenofonking2t@hotmail.com','xenofon vasileiadis','A. papadiamanti 6','thessaloniki','thessaloniki','GREECE','54645','00306998888832','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 13:09:27',0,NULL,0,1,3,0,NULL,'cnfaner\rOTES001'),(24304,800308911008,180810778773,'New in box 3D Active Shutter TV Glasses for Sony TDG-BR250',1,'GLOT001',41.99,'au-buy','gti-095','www.joshis@hotmail.com','Joshua Salisnew','56 Arthur Street<br>Plympton Park','Adelaide','South Australia','AUSTRALIA','5038','0438004161','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 13:35:39',0,NULL,0,1,3,0,NULL,'au-buy\rGLOT001'),(24305,957312651012,220806841884,'Transparent Dome Birdcage Rain Sun Umbrella with trim',1,'UM00001',19.99,'eastar4','cred42','cmllbsk@aol.com','Camille Redmon','10 Ross Ade Dr<br>Apt 1','West Lafayette','IN','UNITED STATES','47906-2524','(214) 316-5786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 13:55:22',0,NULL,0,1,1,0,NULL,'eastar4'),(24306,634989654003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',77.5,'cnfaner','steemer130','steemer@hughes.net','Richard R Neel','258 Oakdale Rd','Townville','SC','UNITED STATES','29689-3425','(864) 287-0879','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 13:58:46',0,NULL,0,1,1,0,NULL,'cnfaner'),(24307,634993420003,130626402405,'4 pairs of New 3D Active Shutter TV Glasses Compatible for  Samsung SSG -2200AR',1,'GLOT001*4',147.5,'cnfaner','660damien','parpaillous@orange.fr','DAMIEN FRIOUX','3 CHEMIN DES PARPAILLOUS','ILE D\' YEU','Pays de la Loire','FRANCE','85350','0251260260','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 14:12:49',0,NULL,0,1,3,0,NULL,'cnfaner\rGLOT001*4'),(24308,955741187012,220582257529,'New Atheros AR5B95 AR9285 Half WiFi Mini PCI-E card',1,'WLAT009',9.98,'eastar4','bizzyboi918','bizzybeingsweet@yahoo.com','le nguyen','6526 E 27th Pl','tulsa','OK','UNITED STATES','74129-6114','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 14:22:50',0,NULL,0,1,1,0,NULL,'eastar4'),(24309,865140648011,320814017783,'2 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*2',59.99,'eastar4uk','hen205','jonnyf205@aol.com','Jonathan Frost','205 Wootton Road','Kings Lynn','Norfolk','UNITED KINGDOM','PE303AB','01553673072','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 14:29:30',0,NULL,0,1,3,0,NULL,'eastar4uk\rSAFI001*2'),(24310,957339011012,220901458596,'New Logitech Harmony Rechargeable battery 890 880 950mA',1,'BALO001',7.99,'eastar4uk','sonigoods','maryam@mtahir1.wanadoo.co.uk','m tahir','88 Uplands Avenue<br>Finchfield','Wolverhampton','West Midlands','UNITED KINGDOM','WV3 8AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 15:03:49',0,NULL,0,1,3,0,NULL,'eastar4uk\rBALO001'),(24311,861892716002,120853616250,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones',2,'HSAL002',25.98,'buysia','ste4281','aquastig@hotmail.com','Stig Thomas Eliassen','Mistelteinen 69 A','Tønsberg','','NORWAY','3154','+4748245962','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-23 15:35:19',0,NULL,0,1,11,0,NULL,'buysia\rHSAL002\r欧标'),(24312,865157861011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',4,'MOAP001',67.96,'eastar4uk','neo_riga','ebay@neo.lv','Gundars Bedre','Daugavgrivas iela 45 (NEO)','Riga','','LATVIA','LV-1007','371-675-00360','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 15:25:28',0,NULL,0,1,3,0,NULL,'eastar4uk\rMOAP001'),(24313,865169406011,320677497947,'New Apple 8GB USB PEN KEY FLASH DRIVE U disk',1,'UDAP001',34.49,'eastar4','evgeny_ts','evgeny.tsikanovski@gmail.com','Evgeny Tsikanovski','P.O. Box 8152','Tel Aviv','Israel','ISRAEL','61081','(972) 54 3494185','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 15:43:38',0,NULL,0,1,11,0,NULL,'eastar4\rUDAP001'),(24314,640678573004,140675757111,'4 pairs of New 3D Active Shutter TV Glasses Compatible for LG AG-S110 AGS110',1,'GLOT001*4',147.5,'cnfaner','jlam8287','joanne_lamotte@yahoo.com','JOANNE LAMOTTE','5636  W 85TH STREET','BURBANK','IL','UNITED STATES','60459','(773) 715-8575','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 16:09:37',0,NULL,0,1,1,0,NULL,'cnfaner'),(24315,640680549004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','rascauri','nda.b@uol.com.br','Raphael Trindade Scauri','rua hildebrando siqueira, 218','são paulo','são paulo','BRAZIL','04334-150','5511-55881054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 16:17:57',0,NULL,0,1,3,0,NULL,'cnfaner\rLGAD001'),(24316,0,220981213701,'Philips Sonicare Elite Series 7500/7750/E7500/HX7500/HX7754 Toothbrush Handle',1,'HBPH007',36,'eastar4','bmetbatya','biomedvahan@yahoo.com','VAHAN ADAMOV','1410 E Glenoaks Blvd','GLENDALE','CA','UNITED STATES','91206-2613','(818) 242-4128','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 16:31:03',0,NULL,0,1,1,0,NULL,'eastar4'),(24317,640703126004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',2,'MOLO001',131.98,'cnfaner','ron1701f','rp_sparks@yahoo.com','Ronnie Sparks','2707 Moonmist Cv','Round Rock','TX','UNITED STATES','78665-2589','(512) 310-2345','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 17:34:06',0,NULL,1,1,1,0,NULL,'cnfaner'),(24318,859913795011,320730002309,'New Jabra BT250 BT 250 wireless Bluetooth Headset',2,'HSJA002',39.98,'eastar4','drmollemolle','drmolle@gmail.com','Fernando Hernandez Perez','2701 N 10th St','Hidalgo','TX','UNITED STATES','78557-4358','956 843 6674','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 17:43:06',0,NULL,0,1,1,0,NULL,'eastar4\rHSJA002'),(24319,865235310011,320861156547,'Brand New Sony Infrared Receiver + Sony Remote Control RM-MCV10T',1,'RMSN001',14.99,'eastar4uk','7783888383','peter.mo@openroadautogroup.com','Peter Mo','13251 Smallwood Place','Richmond','BC','CANADA','V6V1W8','(778) 388-8383','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 18:15:26',0,NULL,0,1,11,0,NULL,'eastar4uk\rRMSN001'),(24320,640730639004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','rafa_js_br','rafa_js@hotmail.com','Rafael Jose Schneider','Av. Porto Alegre<br>333','Dois Irmaos','Rio Grande do Sul','BRAZIL','93950000','+555191777754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 18:58:58',0,NULL,0,1,3,0,NULL,'cnfaner\rLGAD001'),(24321,635077163003,130592182433,'Logitech Unifying receiver for mouse M505 M705 M905 keyboard K340 K350',1,'RELO002',12.95,'cnfaner','dermot1742','dermotsquash1@eircom.net','Tom Fortune','Griffins Way<br>Clonattin','Gorey','Wexford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 19:14:47',0,NULL,0,1,3,0,NULL,'cnfaner\rRELO002'),(24322,640742254004,140583359451,'New Jabra BT250 FreeSpeak Bluetooth Headset BT 250',1,'HSJA002',19.89,'cnfaner','waldin1000','waldin_saenz@yahoo.com','waldin saenz','3771 Shirebrook Dr<br>Apt 163','las vegas','NV','UNITED STATES','89115-3265','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-23 19:35:15',0,NULL,0,1,1,0,NULL,'cnfaner'),(24323,640752973004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','maxa479','maxa4@live.ru','Makhach Gusarov','smp-700<br>house 20-2','Novyy  Urengoy','Tumenskay obl YNAO','RUSSIAN FEDERATION','629300','89044577665','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 20:03:24',0,NULL,0,1,3,0,NULL,'cnfaner\rLGAD001'),(24324,865292342011,320730083633,'3G WWAN antenna MC8775 MC8781 F3507G GTM378 dell 5530',1,'ANCN001',3.55,'eastar4uk','ruben2rl','2rlsecundari@gmail.com','Ruben Rodrigo','Canongate<br>103/2','Edinburgh','Edinburgh City','UNITED KINGDOM','EH8 8BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 20:03:38',0,NULL,0,1,3,0,NULL,'eastar4uk\rANCN001'),(24325,0,180846444159,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',28.51,'au-buy','breviarium','memling@freemail.hu','GERGELY GYULAI','Medve u. 42','BUDAPEST','','HUNGARY','1027','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-23 21:02:27',0,NULL,0,1,11,0,NULL,'au-buy\rLGAD001'),(24326,865328979011,320861244985,'HP BCM94322MC BCM4322 BCM94322 ABGN Wlan Half Mini-Card+antenna*2',1,'WLHP002+ANTY001',12.99,'eastar4','brzy','jngothia@alumni.princeton.edu','Jacob Gothia','1710 2nd Ave Apt 3N','New York','NY','UNITED STATES','10128-3263','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 21:14:14',0,NULL,0,1,1,0,NULL,'eastar4'),(24327,0,320873333445,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista small',1,'RCHP002',1.01,'eastar4uk','white115','2dwhite@googlemail.com','Melissa White','115 Canterbury Road','Newton Hall','Durham','UNITED KINGDOM','DH15XT','01913867195','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 21:48:21',0,NULL,0,1,3,0,NULL,'eastar4uk\rRCHP002'),(24328,635145506003,130645332978,'Brand new HP MCE Media Center Receiver+ IR emitte',1,'OTHP005',18.5,'cnfaner','chandrabhanja','chandrakanta.bhanja@gmail.com','Chandrakanta Bhanja','APT# 204, Buzzer# 014<br>2797 Battleford Road','Mississauga','ON','CANADA','L5N2W2','(647) 781-2897','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 22:46:33',0,NULL,0,1,3,0,NULL,'cnfaner\rOTHP005'),(24329,957539453012,220823006414,'2 pairs 3D Ready Shutter Glasses 4 DLP-Link Projector',1,'GLOT005*2',87.99,'eastar4','bohemiaaidualk','cjuarez@vossteck.com','Muhammad Abbas Arif','House # 493 Street 14<br>Phase IV Bahria Town','Islamabad','Pakistan','PAKISTAN','44000','(300) 946-3119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 22:54:51',0,NULL,0,1,3,0,NULL,'eastar4\rGLOT005*2\r黑色的'),(24330,0,320873333430,'Logitech Harmony Remote USB Cable 880 890 720 1000 one',1,'CALO001',0.06,'eastar4uk','simon2012-cy','simon_st2012@hotmail.com','Symeon Tzoubanni','19 Poseidonos','ayia thekla','sotera','CYPRUS','5390',' 35795710600','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 23:14:51',0,NULL,0,1,11,0,NULL,'eastar4uk\rCALO001'),(24331,957587900012,220871198896,'New Jabra BT250V BT 250V wireless Bluetooth Headset',1,'HSJA001',24.99,'eastar4','paulpudssizer','paulfeb1966@yahoo.co.uk','paul murray','45 commercial street','pontymister','Newport','UNITED KINGDOM','np11 6aw','01633619848','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 23:54:41',0,NULL,0,1,11,0,NULL,'eastar4\rHSJA001\r英标'),(24332,809214803007,170737835792,'New Logitech Unifying receiver for mouse and keyboard MX M505/705/905 K340/350',1,'RELO002',13.99,'au-buy','eli4991','e.mrkusich@gmail.com','Eli  Mrkusich','7 Grange St<br>Preston','Melbourne','Victoria','AUSTRALIA','3072','0380600706','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 00:29:27',0,NULL,0,1,11,0,NULL,'au-buy\rRELO002'),(24333,800575159008,180821269266,'100% New Genuine Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',1,'WLAT008',8.99,'au-buy','cragv01','craig@dataretriever.com.au','Craig Veness','46 Torbay St','Macleod','Victoria','AUSTRALIA','3085','0414554724','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 00:50:49',0,NULL,0,1,11,0,NULL,'au-buy\rWLAT008'),(24334,865423144011,320820750003,'New In Box genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',24.99,'eastar4','oferprtz','ofer.peretz@gmail.com','Ofer Peretz','Ha-Carmel 5','Raanana','','ISRAEL','43731','972542279524','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 01:48:47',0,NULL,0,1,11,0,NULL,'eastar4\rTRSN001'),(24335,957632301012,220930022498,'New 4 Parking Sensor Car Reverse backup Radar kit w/ buzzer 10 colors available',1,'PS00002',24.99,'eastar4','intelwindows','gomezalberto1987@yahoo.com','Alberto Gomez','503 E Main ST','Arcadia','WI','UNITED STATES','54612-1325','(608) 323-0255','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 02:02:47',0,NULL,0,1,1,0,NULL,'eastar4\r深蓝色'),(24336,800593735008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','timmyb4sale','timbessant@hotmail.com','Tim Bessant','37 Nicholli St<br>Duncraig','Perth','Western Australia','AUSTRALIA','6023','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 02:08:40',0,NULL,0,1,11,0,NULL,'au-buy\rBALO001'),(24337,640848982004,140490636162,'New Grohe Twist Free 59\" Shower Hose chrome',1,'OTGR002',20.9,'cnfaner','verajoyi','verajoy@gmail.com','vera stevens','po box 16','everson','PA','UNITED STATES','15631-0016','(724) 972-7166','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 02:32:11',0,NULL,0,1,1,0,NULL,'cnfaner'),(24338,696577757013,230495140165,'100% Original NOKIA BH-900 Bluetooth Wireless Headset',1,'HSNO019',37.98,'eastar4','sidhuraj.sidhu2012','sidhuraj.sidhu@gmail.com','Kanwarjit Sidhu','4632 Morningstar Ln','Salida','CA','UNITED STATES','95368-9704','(209) 605-3706','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 02:15:50',0,NULL,0,1,1,0,NULL,'eastar4'),(24339,865437199011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','lukado2011','lukopti@yahoo.com','lukasz slusarczyk','8308 e prairie rd','skokie','IL','UNITED STATES','60076-2807','(219) 851-0080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 02:52:47',0,NULL,0,1,1,0,NULL,'eastar4'),(24340,0,220982016278,'100% New genuine Microsoft Wired Optical Wheel Mouse',1,'MOMI002',6.5,'eastar4','regstaxidermy','ccfielding@hotmail.com','Craig Fielding','25 Jervois street','Peterborough','South Australia','AUSTRALIA','5422','0886512857','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:10:12',0,NULL,0,1,11,0,NULL,'eastar4\rMOMI002'),(24341,957653028012,220475280848,'2.0 Bluetooth cable Module screw 4 Lenovo Ideapad S10',1,'BTLE2001',9.88,'eastar4','hypnosw','thanatos.w@gmail.com','Minsheng Wang','3767 Mentone Ave<br>Apt 205','Los Angeles','CA','UNITED STATES','90034-6463','(310) 633-1686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 03:20:48',0,NULL,0,1,1,0,NULL,'eastar4'),(24342,0,140729034741,'NEW Philips Sonicare Elite Series HX7500 Toothbrush Handle',1,'HBPH007',30.5,'cnfaner','appinrabbit','hobb01_@hotmail.com','Ian Hobson','14 Macquariedale Road','APPIN','New South Wales','AUSTRALIA','2560','0246311367','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:42:26',0,NULL,0,1,3,0,NULL,'cnfaner\rHBPH007'),(24343,865452400011,320814060131,'Clear Transparent Dome Birdcage Rain Sun Umbrella with I Love Rain Pattern',1,'UM00040',19.99,'eastar4','le-to','oion@mail.ru','Olga Ionina','250-let Chelyabinska st.,13-5','Chelyabinsk','Chelyabinsk region','RUSSIAN FEDERATION','454128','9823047894','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:55:53',0,NULL,0,1,11,0,NULL,'eastar4\rUM00040'),(24344,635203674003,130617205330,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.9,'cnfaner','jabarlocker','jaren.barlocker@gmail.com','Jaren Barlocker','11756 HISTORY DR','SOUTH JORDAN','UT','UNITED STATES','84095-8034','(801) 520-0816','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 04:13:24',0,NULL,0,1,1,0,NULL,'cnfaner'),(24345,865457472011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','davewatson1969','ddwatson1969@ymail.com','Dave Watson','5225 White Willow Dr<br>Apt I230','fort collins','CO','UNITED STATES','80528-5023','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 04:29:13',0,NULL,0,1,1,0,NULL,'eastar4'),(24346,0,220982052512,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',2.4,'eastar4uk','white115','2dwhite@googlemail.com','David White','Calle Ronda del Golf Este<br>Royal Residencial Golf 1 B,Torrequebrada','Benalmádena, Málaga','Andalucía Ceuta y Melilla','SPAIN','29630','671023500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 04:47:06',0,NULL,0,1,11,0,NULL,'eastar4uk\rRCHP001'),(24347,0,130667532213,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',24.51,'cnfaner','hyebear','yerevan1986@cs.com','STEVE SAROYAN','6900 Fulton Ave<br>Apt 5','NORTH HOLLYWOOD','CA','UNITED STATES','91605-6613','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 05:23:46',0,NULL,0,1,1,0,NULL,'cnfaner'),(24348,809317520007,170730544669,'BRAND NEW LOGITECH NANO USB RECEIVER for MX M905/950 M215/235/305/310/505/510',1,'RELO003',11.98,'au-buy','eskiee','eskieedownunder@gmail.com','Rocky Dunn','10 Tait Street','Armadale','Western Australia','AUSTRALIA','6112','080435314748','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 05:59:31',0,NULL,0,1,11,0,NULL,'au-buy\rRELO003'),(24349,696617962013,230695960165,'New Philips Sonicare Flexcare Toothbrush Handle HX6950+ travel charger',1,'HBPH001+HBPH003',85.9,'eastar4','woofmeowtweet','isyzhu@gmail.com','Ivy Zhu','808-8080 Cambie Road','Richmond','BC','CANADA','V6X 0C1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 06:59:07',0,NULL,0,0,3,0,NULL,'eastar4\rHBPH001+HBPH003'),(24350,0,130668559612,'New Logitech mx1000 MX5000 MX3100 AC Power Adapter',1,'POLO001',1.25,'cnfaner','grafbotan','mypostgraf@mail.ru','Viacheslav Rumyanzew','ul. Marshala Golovanova, d. 19, kv. 68','Moskva','RU','RUSSIAN FEDERATION','109144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 07:15:12',0,NULL,0,1,3,0,NULL,'cnfaner\rPOLO001'),(24351,0,220982052601,'New Altec Lansing UHP326 noise-isolating Earphones 4 iPod  iPhone  Music player',1,'HSAL001',7.99,'eastar4uk','gdw0776','graham.dwest@tiscali.co.uk','graham west','20 aston grove','cheltenham','Gloucestershire','UNITED KINGDOM','gl510ps','07761070759','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 07:32:46',0,NULL,0,1,3,0,NULL,'eastar4uk\rHSAL001'),(24352,0,320871203808,'New Genuine Intel Centrino Advanced N + WiMAX 6250 622ANXHMW',1,'WLIN014',6.99,'eastar4uk','dobrin2000','d_dimitrov1980@abv.bg','Dobrin Dimitrov','Nikola Petkov 9','Plovdiv','Plovdiv','BULGARIA','4000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 08:40:58',0,NULL,0,1,11,0,NULL,'eastar4uk\rWLIN014'),(24353,0,320872607445,'Brand New HP MCE Media Center Edition Remote Control Win7 XP Vista Big',1,'RCHP001',4.25,'eastar4','don_luigi_72','ludvikk@gmail.com','Ludvik Krulik','Cesta Gradenj 1','Vrhnika','','SLOVENIA','1360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 08:47:19',0,NULL,0,1,11,0,NULL,'eastar4\rRCHP001'),(24354,809359176007,170775726989,'New HP MCE Media Center + Sony Remote Control RM-MCE20E White+IR Emitter Wire',1,'RMSN002',19.99,'au-buy','vit320','phillip.vella@vellait.com.au','Phillip  Vella','2/500 Princes Highway<br>CPP Wind Building','St Peters','New South Wales','AUSTRALIA','2044','0280149098','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 09:11:02',0,NULL,0,1,11,0,NULL,'au-buy\rRMSN002'),(24355,865522842011,320730083567,'10 pcs of New VGA Extender over CAT5/CAT6/RJ45 white',1,'OTCN005',9.99,'eastar4uk','dj-dan-e-b','botterelldanny@googlemail.com','Danny Botterell','Clacton Angling<br>100 Pier Avenue','Clacton-on-sea','Essex','UNITED KINGDOM','CO15 1NJ','07812154813','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 09:36:44',0,NULL,0,1,3,0,NULL,'eastar4uk\rOTCN005'),(24356,0,180845712561,'Original Logitech MX600 MX1000 MX610 MX620 Mouse Mat 3M material',1,'SCLO002',1.25,'au-buy','jorgew2001','joca33@gmail.com','Jorge Cabana Perez','Plaza Camilo Jose Cela, 3, 7-H<br>--Edificio Mastil escalera 2--','Murcia','Murcia','SPAIN','30008','667637157','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-24 10:11:31',0,NULL,0,1,11,0,NULL,'au-buy\rSCLO002'),(24357,640917562004,140671479195,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',12.59,'cnfaner','alongold','agold80@gmail.com','Alon Goldman','Kibbutz Urim','D.N. Negev','','ISRAEL','85530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 10:12:11',0,NULL,0,1,3,0,NULL,'cnfaner\rHSAL002\r欧标'),(24358,0,220982052573,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',22,'eastar4uk','shishob1','mamidipallyshiva@gmail.com','Shiva Krishna . Mamidipally','Flat 9, Victoria Gardens<br>195 London Road','Leicester','Leicestershire','UNITED KINGDOM','LE2 1ZH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 10:28:30',0,NULL,0,1,3,0,NULL,'eastar4uk\rLGRM001'),(24359,0,180845712513,'NIB LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',26.99,'au-buy','fredkoop','freddy-leemans@base.be','Freddy Leemans','Petrus Van Der Jeugdlaan 9','HAMME','','BELGIUM','9220','052-477325','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-24 10:44:09',0,NULL,0,1,11,0,NULL,'au-buy\rLGRM001'),(24360,957758430012,220785828978,'2 pairs 3D Active shutter Glasses 4 Panasonic TY-EW3D10',1,'GLOT001*2',77.99,'eastar4','annoplert','noplert@hotmail.com','Annop Lerttanaphiboon','58/4 M.6 Ekachai 89, Ekachai Rd.','Bangbon','Bangkok','THAILAND','10150','081-944-1909','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 10:49:37',0,NULL,0,1,3,0,NULL,'eastar4\rGLOT001*2'),(24361,957793984012,220815931226,'New Microsoft Wired Optical Wheel Mouse Black',1,'MOMI002',8.99,'eastar4uk','mx5634','an15hg@hotmail.com','Anish Gami','14 Bovingdon Avenue','wembley','Middlesex','UNITED KINGDOM','HA9 6DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 12:28:41',0,NULL,0,1,3,0,NULL,'eastar4uk\rMOMI002'),(24362,640948164004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','gthley','arlyfast@mail.ru','Andrey Lukiyanov','prospect geroev Stalingrada, house № 40, apartment 55.','Volgograd','','RUSSIAN FEDERATION','400026','+79023149213','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 12:38:33',0,NULL,0,1,3,0,NULL,'cnfaner\rLGAD001'),(24363,957798546012,220885112892,'New Logitech MX1000 Wireless Laser Cordless Mouse PcMac',1,'MOLO001',38,'eastar4uk','cpt-neemo','martinsamuel@hotmail.com','Martin Samuel','6 Watermint Drive<br>Tuffley','Gloucester','Gloucestershire','UNITED KINGDOM','GL4 0SY','07970863047','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 12:41:18',0,NULL,1,1,3,0,NULL,'eastar4uk\rMOLO001'),(24364,635287400003,130629477182,'New 4 Parking Sensor Car Reverse backup Radar kit w/ buzzer 9 colors available',2,'PS00002',49.18,'cnfaner','cdogrj24','cdogrj16@yahoo.com','Christopher Stracener','806 knoxville rd.','knoxville','MD','UNITED STATES','21758','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 12:45:01',0,NULL,4,1,3,0,NULL,'cnfaner\rPS00002'),(24365,0,110844982906,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',11.5,'buysia','admiraal79','admiraak@gmail.com','Ryan Admiraal','129 Prestwick Heights SE','Calgary','AB','CANADA','T2Z 4H9','(403) 454-6447','NoPaymentFailure','CheckoutComplete','CA_EconomyShippingfromoutsideCanada','2012-03-24 13:10:03',0,NULL,0,1,11,0,NULL,'buysia\rHBPH003'),(24366,957674927012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','wrigleyfield81','wrigleyfan81@hotmail.com','matthew curran','3685 school dr','morris','IL','UNITED STATES','60450-8418','(815) 416-0929','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 13:21:35',0,NULL,0,1,1,0,NULL,'eastar4'),(24367,696705860013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',44.99,'eastar4','maan1v','maaniv@gmail.com','Андрей Мачулин','проспект Ленина, дом 74, квартира 3','Брянск','Брянская область','RUSSIAN FEDERATION','241050','89206053109','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 14:01:00',0,NULL,0,1,3,0,NULL,'eastar4\rGLOT005\r黑色的'),(24368,0,110846179983,'New Portable HD 720P Car Dashboard Camera DVR w/2.5\" TFT LCD screen',1,'CC00002',24.51,'buysia','fieak','info.beauty.and.lifestyle@gmail.com','Anastassia Knjazeva FIE','Anne 88-54','Tartu','Tartumaa','ESTONIA','50705','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-24 14:22:36',0,NULL,0,1,11,0,NULL,'buysia\rCC00002'),(24369,865620485011,320696765757,'NEW Genuine APPLE USB Wired Optical Mighty Mouse A1152',1,'MOAP001',16.99,'eastar4uk','haken8_67','magnus@cadfix.se','Magnus Holmström','Skelleftehamnsvägen 236','Ursviken','','SWEDEN','93235','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 14:30:55',0,NULL,0,1,11,0,NULL,'eastar4uk\rMOAP001'),(24370,640982178004,140662512555,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',54.89,'cnfaner','rdanilov-ru','daniloffr@gmail.com','Roman Danilov','ul. Baryshiha, dom 34, kv. 178','Moscow','','RUSSIAN FEDERATION','125368',' 79032387807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 14:52:11',0,NULL,0,1,3,0,NULL,'cnfaner\rMOHP002\r1个\rBrand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV\rLGAD001\r1个\r'),(24371,957866768012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','merwis1','themerwins@comcast.net','Frances Merwin','6694 Empire Ct','Maple Grove','MN','UNITED STATES','55311-3433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 15:27:45',0,NULL,0,1,1,0,NULL,'eastar4'),(24372,696740637013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','fiphoto','shishkaby@mail.ru','dzmitry shyshkouski','shamyakina 9-60','minsk','minsk','BELARUS','220019','80296019547','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 16:02:10',0,NULL,1,1,11,0,NULL,'eastar4\rCACN004'),(24373,635392987003,130626402686,'New 3D Active Shutter TV Glasses Compatible for Panasonic TY-EW3D10',2,'GLOT001',79,'cnfaner','dokus31','emielv@chello.nl','Veldhoedt','snoekenveen 905','spijkenisse','','NETHERLANDS','3205CK','0620659213','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 18:38:48',0,NULL,0,1,3,0,NULL,'cnfaner\rGLOT001'),(24374,865740128011,320786808161,'New iTech Clip II mini Multipoint Bluetooth Headset white',1,'HSIT003',39.9,'eastar4','pwong168','12pwong@gmail.com','Paul Wong','12839<br>161 avenue','edmonton','AB','CANADA','t6v1p3','(780) 885-3660','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 18:45:05',0,NULL,0,1,11,0,NULL,'eastar4\rHSIT003'),(24375,957986430012,220449144503,'Samsung NC10 ND10 NC20 Bluetooth Module 2.0 EDR+cable',5,'BTSA2004',49.4,'eastar4','henry2965','hans-georg-dick@t-online.de','Hans-Georg Dick','Hauptstraße 243','Hemer','','GERMANY','58675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 19:05:34',0,NULL,0,1,3,0,NULL,'eastar4\rBTSA2004\r4pin 1.25'),(24376,696821781013,230724607810,'New Fashion Full Transparent dome J-handle Manual Opening Sun Umbrella',1,'UM00053',19.59,'eastar4','shimritassaf','shimrit.assaf@gmail.com','shimrit assaf','Kakal 24 a2 / 5','givataim','israel','ISRAEL','53224','=972542024252','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 19:32:46',0,NULL,0,1,11,0,NULL,'eastar4\rUM00053'),(24377,641095217004,140482242995,'New GENUINE NOKIA BH-200 BLUETOOTH HEADSET track#',2,'HSNO005',27.58,'cnfaner','lindsay*cowvins','meryheins1@comcast.net','mary  heins','4836 NW 94th Ave','sunrise','FL','UNITED STATES','33351-5226','(954) 616-5071','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 20:18:38',0,NULL,0,1,1,0,NULL,'cnfaner'),(24378,635432936003,130626402226,'2 pairs of New 3D Active Shutter TV Glasses Compatible for Sony TDG-BR100 BR250',1,'GLOT001*2',77.5,'cnfaner','petrycioby','a.stoian@yahoo.com','Petru Ciobanu','Brennbakkvegen 3<br>Leil. 201','Hamar','Hedmark','NORWAY','2318','90236194','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 20:27:54',0,NULL,0,1,3,0,NULL,'cnfaner\rGLOT001*2'),(24379,958041241012,220633187369,'Dell 1510 PCI-E WIRELESS WLAN Half-Height Mini Card',1,'WLDE002',11.99,'eastar4','neally01','emile_blake@hotmail.com','Emile Blake','8829 Woodgrove Ridge Ct','Boynton Beach','FL','UNITED STATES','33473-4872','(954) 661-2173','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 20:36:10',0,NULL,0,1,1,0,NULL,'eastar4'),(24380,958044163012,220785361518,'2pairs New genuine Samsung 3D Active Glasses SSG-2100AB',1,'GLSG001*2',85.99,'eastar4uk','harryd365','hgpdrabbe@casabacardi.net','Henry Drabbe','Maiboxes etc.365  H.Drabbe<br>Ctra.cabo la nao (pla) 71-6','Javea','Alicante','SPAIN','03730','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 20:40:18',0,NULL,0,1,3,0,NULL,'eastar4uk\rGLSG001*2'),(24381,696863637013,230654780294,'3D Ready Active Shutter Glasses For DLP-Link Projector',2,'GLOT005',89.98,'eastar4','saeedss120','saeedre55@yahoo.com','saeed ahmed alghamdi / JED 11800','14729 182nd St<br>GARDENS, NEW YORK 11413-4028','Springfield Gardens','NY','UNITED STATES','11413-4028','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 21:23:31',0,NULL,0,1,1,0,NULL,'eastar4'),(24382,641120672004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',2,'GPS0010',64,'cnfaner','epayment.ro','vendorgsm@gmail.com','Cristian Cocos','4283 Express Lane<br>Ste K4208','Sarasota','FL','UNITED STATES','34238','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,0,0,0,0,NULL,'cnfaner'),(24383,641141587004,140651314212,'NIB LG Premium Water Filter Gen11042FR-08 for Kenmore and LG refrigerators',1,'LGFI001',46.9,'cnfaner','andreutriches','andretriches@yahoo.com.br','Andre Triches','Av. Rui Barbosa 500, apt. 202','Rio de Janeiro','Rio de Janeiro','BRAZIL','22250-020','55 21 33252239','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 22:43:49',0,NULL,0,1,3,0,NULL,'cnfaner\rLGFI001'),(24384,0,140727455228,'NEW Logitech Nano Receiver 4 M505 M705 M905 mouse',1,'RELO003',9.38,'cnfaner','falerina','falerina@gmail.com','Terese Housker','16775 455th Ave','Mabel','MN','UNITED STATES','55954-1484','(507) 493-5734','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-24 22:49:58',0,NULL,0,1,1,0,NULL,'cnfaner'),(24385,0,320868512456,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',37.12,'eastar4','makinistidris','idrisdurmaz@yahoo.com','idris durmaz','evren Mah oba sok no:2/10<br>güneşli / bağcılar','istanbul','marmara','TURKEY','34212','+905357464800','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 23:07:02',0,NULL,0,1,11,0,NULL,'eastar4\rLGAD001'),(24386,865879909011,320820765669,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',25.99,'eastar4','btcoonhound0','johnnybad77@hotmail.com','jon cromwell','69 broadway<br>apt 1','chelsea','MA','UNITED STATES','02150-2605','(617) 501-3824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 23:23:48',0,NULL,0,1,1,0,NULL,'eastar4'),(24387,0,230765814588,'New Fire-Pad FPS Gaming Game Surface Mouse pad',1,'MOFP001',2,'eastar4','devdas_q8ii','m_monther@hotmail.com','Monther Al-Sharekh','207 , 302 Nelson Road<br>Buzzer #37','Saskatoon','SK','CANADA','S7S 1N9','(130) 634-1135 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 23:33:23',0,NULL,0,1,11,0,NULL,'eastar4\rMOFP001'),(24388,809733112007,170762819519,'Brand new HP MCE Media Center Remote Control bigger + IR RECEIVER+IR Emitter',1,'OTHP004',21.9,'au-buy','jdf0878','jae78@live.com.au','Jamie Foulstone','Unit 3<br>15 Wambool Street','Bulimba','Queensland','AUSTRALIA','4171','0414822884','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 00:36:01',0,NULL,0,1,11,0,NULL,'au-buy\rOTHP004'),(24389,957185593012,220806882288,'New lady Piano  Rain Sun Parasol Stick Umbrella Ivory',1,'UM00010',49.98,'eastar4','milkybunny','milkybunny.kate@gmail.com','Kristine Tarog','609 E 19th St','National City','CA','UNITED STATES','91950-5812','(619) 829-1040','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 00:40:58',0,NULL,0,1,1,0,NULL,'eastar4\r一共买了两把   一把黑色的 一把白色的'),(24390,809746953007,170735464182,'New Clear Transparent Dome Birdcage Rain Sun Umbrella with color Trim',3,'UM00001',59.97,'au-buy','greyjoy1976','greyjoy76@adam.com.au','Anthony Tindale','20 Frick Street<br>Lobethal','Adelaide','South Australia','AUSTRALIA','5241','0884435667','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 01:27:25',0,NULL,0,1,3,0,NULL,'au-buy\rUM00001\r黄色，蓝色和粉色'),(24391,696938148013,230656397856,'New 3.0 Bluetooth BCM92070 Module+cable Lenovo S10-3S',1,'BTLE3001',19.98,'eastar4','wkobashi2553','wkobashi@pr.email.ne.jp','WATARU KOBASHI','Hamasuka 18-50','Chigasaki','Kanagawa','JAPAN','253-0035',' 09046135467','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 02:12:16',0,NULL,0,1,11,0,NULL,'eastar4\rBTLE3001'),(24392,865932571011,320762434110,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950 HX6911',1,'HBPH003',18.5,'eastar4','queen0_5','jstewart2@ec.rr.com','Jeff Stewart','712 Christine Ave','Jacksonville','NC','UNITED STATES','28540-6805','(910) 346-1068','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 02:16:56',0,NULL,0,1,1,0,NULL,'eastar4'),(24393,641193209004,140482633242,'New GENUINE NOKIA HS-4W BLUETOOTH HEADSET track#',2,'HSNO022',29.76,'cnfaner','ashathopkinton1','verasminimart@aol.com','ashraf youssef','1 Plummers Cor<br>Vera\'s Mini Mart','whitinsville','MA','UNITED STATES','01588-2135','(508) 234-9326','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 02:47:01',0,NULL,0,1,1,0,NULL,'cnfaner'),(24394,0,220981213612,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',27.51,'eastar4','ggusta','ggusta@gmail.com','gregg gusta','361 Collinsworth Dr','Clayton','NC','UNITED STATES','27527-3936','(919) 337-5317','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 03:00:09',0,NULL,0,1,1,0,NULL,'eastar4'),(24395,0,130668013530,'New Altec Lansing Backbeat Plus UHP206 Noise Isolation Earphones for iPod&iphone',1,'HSAL002',11.52,'cnfaner','sayed.majid','smdurazi@gmail.com','S Majed Fadhel','4003<br>H:43 Road 4003, Block: 540, Duraz','Diraz','','BAHRAIN','00973','0097339449654','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 03:05:22',0,NULL,0,1,3,0,NULL,'cnfaner\rHSAL002\r英标'),(24396,0,220982773551,'NIB 3D Active Shutter TV Glasses 4 Panasonic TY-EW3D10',1,'GLOT001',37.5,'eastar4','shellycourn','brentshelly@shaw.ca','shelly cournoyer','16 jewell st.','thunder bay','ON','CANADA','P7A6H6','(807) 767-1208','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 03:24:13',0,NULL,0,1,11,0,NULL,'eastar4\rGLOT001'),(24397,801082601008,180757093930,'New Logitech harmony remote Li-ion Rechargeable Battery 950mAh',1,'BALO001',11.99,'au-buy','vesna070362','vesna.hatzi@hotkey.net.au','Vesna Hatzi','9 Jack street','Newport','Victoria','AUSTRALIA','3015','0393994453','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 03:31:13',0,NULL,0,1,11,0,NULL,'au-buy\rBALO001'),(24398,0,320873275267,'New Altec Lansing UHP326 noise-isolating Earphones for iPod&iPhone&Music players',1,'HSAL001',13.5,'eastar4','5150hugo','bobhugo@live.com','BOB HUGO','4727 E Silverbell Rd','San Tan Valley','AZ','UNITED STATES','85143','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 03:39:02',0,NULL,0,1,1,0,NULL,'eastar4'),(24399,0,120882141388,'LG AN-MR200 Magic Motion Remote for LG HDTVs with Smart TV',1,'LGRM001',24.49,'buysia','ruasjr','ruasjunior@uol.com.br','Carlos Ruas Jr.','Monte Simplon, 970, apto. 02','Belo Horizonte','MG','BRAZIL','30550162','+553191415885','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-25 04:07:05',0,NULL,0,1,11,0,NULL,'buysia\rLGRM001'),(24400,958216265012,220816372256,'4 pair NIB SONY 3D Active Glasses TDG-BR250 rechargeabl',1,'OTSO004*4',171.99,'eastar4uk','calinium','calinium@hotmail.com','Luc-Alexandre Parenteau','70 Anne-Hébert','Ste-Catherine-de-la-Jacques-Cartier','QC','CANADA','G3N 2K7','(418) 875-5007','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 04:42:42',0,NULL,0,1,3,0,NULL,'eastar4uk\rOTSO004*4'),(24401,0,140727455253,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',10.5,'cnfaner','2010jaci_0721','jaci_0721@hotmail.com','Jessica Chyba','418 Mine St','Lead','SD','UNITED STATES','57754-1265','(605) 717-1789','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 04:45:35',0,NULL,0,1,1,0,NULL,'cnfaner'),(24402,0,220981252295,'New ULTIMATE EARS METRO.FI 220VI EARPHONE UE220 VI',1,'HSUE003',7.99,'eastar4uk','gardini88','tutor88@yahoo.co.uk','Gardiner, Paul','5F, Fortune Industrial Building<br>35 Tai Yip Street, Kowloon Bay','default','','HONG KONG','default','90380871','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 04:52:27',0,NULL,0,1,11,0,NULL,'eastar4uk\rHSUE003'),(24403,801108491008,180793383706,'New BELKIN F5D7050 wireless WiFi network adapter +USB base 54M 802.11g',1,'OT00002',12.99,'au-buy','blenky1156','andpro29@bigpond.com','SUSAN BLENKINSOP','ANDREW BLENKINSOP<br>5 Tea Tree Place','GELORUP','Western Australia','AUSTRALIA','6230','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 05:50:05',0,NULL,0,1,11,0,NULL,'au-buy\rOT00002'),(24404,696975823013,230498933879,'2.1 Acer Aspire AS 4740  Bluetooth Module EDR + cable',1,'BTAC2123',12.39,'eastar4','spreysvladimir','vladimir.and.natalia@gmail.com','Vladimir Spreys','4/24 Hawera road','Auckland','Kohimarama','NEW ZEALAND','1071','021713860','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 06:04:54',0,NULL,0,1,11,0,NULL,'eastar4\rBTAC2123\racer 8pin1.00 10cm '),(24405,0,230765175520,'New Jabra BT250 BT 250 wireless Bluetooth Headset',1,'HSJA002',15.5,'eastar4','curtisv777','wh@cvancura.com','Curtis Vancura','10902 Grand Ave<br>Ste K','Temple City','CA','UNITED STATES','91780-3567','(626) 840-9004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 06:05:06',0,NULL,0,1,1,0,NULL,'eastar4'),(24406,865985521011,320721793687,'NIB 3D Active Shutter TV Glasses 4 SONY TDG-BR100',2,'GLOT001',79.98,'eastar4','domenicosaritanastya','dommae@yahoo.com','campos esther','shimo ogino 820-1 soreyu 93-105','atsugi','Kanagawa','JAPAN','243-0203','046-242-7160','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 06:26:58',0,NULL,0,1,3,0,NULL,'eastar4\rGLOT001'),(24407,0,110845542005,'New 3D Active Shutter TV Glasses compatible for Samsung SSG-2100AB SSG-2200AR',1,'GLOT001',29.5,'buysia','breu5940','b.reusink@tele2.nl','Bert Reusink','sint Barbarastraat 40','Heerlen','','NETHERLANDS','6415 RW','0622911907','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-25 06:21:03',0,NULL,0,1,11,0,NULL,'buysia\rGLOT001'),(24408,0,220981213390,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',41,'eastar4','proxytelecom','rxsantos@gmail.com','Roberto Xavier dos Santos','Rua Plutao 133','Curitiba','Parana','BRAZIL','81910410','554133786224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 06:42:08',0,NULL,0,1,3,0,NULL,'eastar4\rGLOT005'),(24409,958245912012,220806892088,'NEW Sunflower Bloom 3-section Folding umbrella',1,'UM00004',21.99,'eastar4','mrnoseygirl','rirvine14@comcast.net','Rebecca A. Irvine','50 Parramatta Road','Glebe','New South Wales','AUSTRALIA','2037','(029) 518-9032','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 07:06:55',0,NULL,1,1,11,0,NULL,'eastar4\rUM00004'),(24410,809812499007,170730544862,'Logitech Limit MX518 MX 518 Gaming Optical USB Mouse 90% like new',1,'MOLO003',37.99,'au-buy','ciaranguitars','ciaran.odowd57@gmail.com','Ciaran O\'Dowd','66C Ponsonby<br>Seaforth','Sydney','New South Wales','AUSTRALIA','2092','0299079528','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 07:10:02',0,NULL,1,1,3,0,NULL,'au-buy\rMOLO003'),(24411,0,320873333488,'New Philips Sonicare flexcare toothbrush Handle HX6950',1,'HBPH001',32,'eastar4uk','dcact','bdwebster@btinternet.com','Brian  Webster','2 Gwithian Road,<br>Connor Downs,','Hayle','Cornwall','UNITED KINGDOM','TR27 5EA','01209610061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 07:49:20',0,NULL,0,1,3,0,NULL,'eastar4uk\rHBPH001'),(24412,866005408011,320701018592,'2 pairs 3D Active Shutter TV Glasses for Sony Panasonic',1,'GLOT001*2',77.99,'eastar4','baller2279','zbball79@yahoo.com','Zac Hanford','309 E 23rd Ave','Post Falls','ID','UNITED STATES','83854-9103','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 07:51:19',0,NULL,0,1,1,0,NULL,'eastar4'),(24413,697010876013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','anvalku2008','anvalku@gmail.com','Andrey Kucherenko','Shipilovskaya 48-2-138','Moscow','Moscow','RUSSIAN FEDERATION','115573','+79262357590','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 09:12:15',0,NULL,1,1,11,0,NULL,'eastar4\rCACN004'),(24414,635594580003,130603400128,'New Replaceable Shell for Logitech G9X G9 Gaming Mouse Precision Grip balck ver1',1,'SHLO009',12.95,'cnfaner','frankgr1969','frankgranato@hotmail.com','Frank Granato','8 Latina Circuit','Prestons','New South Wales','AUSTRALIA','2170','0298266162','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 09:38:57',0,NULL,0,1,3,0,NULL,'cnfaner\rSHLO009'),(24415,0,120880723509,'New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear (M)',1,'PSGL001',56,'buysia','jan_devenson','jan_devenson@hotmail.fr','Jan Devenson','Fabijoniskiu 37-24','Vilnius','','LITHUANIA','07120','','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-25 11:02:57',0,NULL,0,0,0,0,NULL,'buysia'),(24416,866094381011,320861157547,'Brand new HP MCE Media Center + Sony Remote Control RM-MCE20E',1,'RMSN002',13.99,'eastar4uk','johno_6','johnosullivan87@gmail.com','John   O\'Sullivan','3 Dale street','Bacup','Lancashire','UNITED KINGDOM','OL138AP','01706872907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 11:48:23',0,NULL,0,0,0,0,NULL,'eastar4uk'),(24417,817925664001,110836856963,'NEW Romantic Cute 3-section Sun Rain umbrella w/Starfish pattern',1,'UM00017',19.99,'buysia','nbychenko','nivlad@gmail.com','Nikolai Bychenko','42 home, village  Andreevskoe','Moscow','Odintsovo district/Moscow Region','RUSSIAN FEDERATION','143057','+79091686147','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-25 11:59:01',0,NULL,0,0,0,0,NULL,'buysia'),(24418,958396157012,220823018514,'3D Ready Active Shutter Glasses For DLP-Link Projector',1,'GLOT005',29.99,'eastar4uk','hhop7082','huughop@gmail.com','Hugo Hopstaken','Bilderdijkstraat 12','Gemert','','NETHERLANDS','5421 PJ','0492367383','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 13:22:57',0,NULL,0,0,0,0,NULL,'eastar4uk'),(24419,0,140728106713,'New Philips Toothbrush Sonicare Travel Charger base',1,'HBPH003',10.24,'cnfaner','assuredgroup','lcmeadows42@gmail.com','Linda C Meadows','400 Saddleworth Pl','Lake Mary','FL','UNITED STATES','32746-4348','(407) 333-2236','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 13:43:43',0,NULL,0,0,0,0,NULL,'cnfaner'),(24420,641345935004,140700689902,'Brand New LG AN-WF100 Wireless Wi-Fi USB Adaptor Dongle for LG TV',1,'LGAD001',41.99,'cnfaner','estronciobr','helio.arakawa@gmail.com','Hélio Arakawa','621 Estado de Israel Apt 161','São Paulo','São Paulo','BRAZIL','04022-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 14:27:01',0,NULL,0,0,0,0,NULL,'cnfaner'),(24421,958446810012,220824004393,'NIB 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001',39.99,'eastar4','alexxxandrkosarev','alexxxandr_k@mail.ru','Alexandr Kosarev','Bolshaya Marfinskaya 4 k.1 kv.30','Moscow','','RUSSIAN FEDERATION','127276','(903)7580666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 14:56:19',0,NULL,0,0,0,0,NULL,'eastar4'),(24422,641379421004,140583359703,'New Jabra BT500 FreeSpeak Bluetooth Headset BT 500',1,'HSJA010',24.5,'cnfaner','rajeshekara','damoder@gmail.com','Rajeshekara D Gurappagari','720 Avonwick Avenue<br>Unit# 134','Mississauga','ON','CANADA','L5R 4C7','(647) 996-5879','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 15:52:32',0,NULL,0,0,0,0,NULL,'cnfaner'),(24423,866219424011,320773581847,'4 pair 3D Active Shutter TV Glasses 4 LG AGS110 AG-S110',1,'GLOT001*4',99.99,'eastar4uk','karusha16','karusha@seznam.cz','Karla Beránková','Komořanská 823','Most','výchozí','CZECH REPUBLIC','43401','+420721521993','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 16:06:29',0,NULL,0,0,0,0,NULL,'eastar4uk'),(24424,958495758012,220950183994,'2 pairs of New Genuine Panasonic Rechargeable HDTV TY-EW3D3MC 3D Glasses Eyewear',1,'PSGL001*2',135.99,'eastar4','hazydavy2','davlaurich@hotmail.com','Dave Laurich','2977 W Briarwood Dr','Franklin','WI','UNITED STATES','53132-9145','(414) 856-0831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 16:10:55',0,NULL,0,0,0,0,NULL,'eastar4'),(24425,697128231013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','peterzsilak','peter.zsilak@gmail.com','Peter Zsilak','Szechenyi str. 26.','Tiszanagyfalu','Szabolcs-Szatmar-Bereg','HUNGARY','4463','+36304466974','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 16:20:02',0,NULL,0,0,0,0,NULL,'eastar4'),(24426,641399021004,140667905212,'NEW Logitech MX1000 Wireless Laser Cordless Mouse',2,'MOLO001',131.98,'cnfaner','woodman1534','woodman1953@comcast.net','Louis McHugh','1136 Florence Dr<br>Apt E','Westmont','IL','UNITED STATES','60559-2712','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 16:36:26',0,NULL,0,0,0,0,NULL,'cnfaner'),(24427,697143032013,230602670945,'New 2nd HDD hard drive caddy SATA for Apple MacBook pro',1,'CACN004',12.94,'eastar4','gunroc2012','gunroc@yandex.ru','Farit Sindikaev','Tupoleva 9-87','Zhukovsky','Moscow Region','RUSSIAN FEDERATION','140185',' 89104544008','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 16:44:08',0,NULL,0,0,0,0,NULL,'eastar4'),(24428,958527002012,220763418811,'New Logitech MX5000 MX3100 mx1000 AC Power Adapter 8V',2,'POLO001',9.18,'eastar4uk','hastamala','darius@zendeh.de','Darius Zendeh','Carl-Von-Ossietzky-Weg 3','Margetshöchheim','','GERMANY','97276','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 16:49:55',0,NULL,0,0,0,0,NULL,'eastar4uk'),(24429,0,230765251426,'New Philips Toothbrush Sonicare Travel Charger base for HX6930 HX6950',1,'HBPH003',10.5,'eastar4','dr_niclam','carol.kalo.ng@gmail.com','Carol Ng','3451 E51st ave','Vancouver','BC','CANADA','V5S 1S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 17:04:08',0,NULL,0,0,0,0,NULL,'eastar4'),(24430,958545206012,220448684525,'Acer Aspire 3680 5570 5050 Bluetooth Module 2.0+cable',1,'BTAC2015',9.88,'eastar4','derrick-9','danpittsc@charter.net','Daniel Pitts','1431 Gum Creek Rd','Oxford','GA','UNITED STATES','30054-3010','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 17:11:03',0,NULL,0,0,0,0,NULL,'eastar4'),(24431,0,230765175562,'Transparent Dome Rain Sun Umbrella with Yellow trim',1,'UM00001',8.99,'eastar4','halo891','halo891@gmail.com','carla pursley','4 Woodscape Dr','Mills River','NC','UNITED STATES','28759-9761','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-25 17:41:48',0,NULL,0,0,0,0,NULL,'eastar4'),(24432,0,130669094446,'New genuine Sony TMR-BR100 3D Sync Transmitter for Sony\'s 3D Glasses',1,'TRSN001',15.99,'cnfaner','globalworlds','nguyennancy2010@hotmail.com','Dung Tran','902 Cooper Ct SE','Vienna','VA','UNITED STATES','22180-5966','(703) 400-3531','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 18:00:42',0,NULL,0,0,0,0,NULL,'cnfaner'),(24433,818227904001,110834781206,'New WIFLY-CITY IDU-2850UG-U20 plus 2 Wireless USB Adapter +7 plus dBi Antenna',1,'ANWI001',55.9,'buysia','isaiasguerra2012','isaiasguerra@live.com','oscar jacobo','84 Lexington Ave','passaic','NJ','UNITED STATES','07055-5206','(646) 359-8967','NoPaymentFailure','CheckoutComplete','CA_StandardInternational','2012-03-25 19:51:08',0,NULL,0,0,0,0,NULL,'buysia'),(24434,641567381004,140662512555,'New HP Wireless Comfort Optical Mobile Mouse + Receiver 2.4 GHz',1,'MOHP002',12.9,'cnfaner','carmosantos','carmocovas@hotmail.com','Carmo Santos','Hermann Neeser, 111<br>Itaigara','Salvador','Bahia','BRAZIL','41815330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 20:41:05',0,NULL,0,0,0,0,NULL,'cnfaner'),(24435,810309859007,170759159918,'2 pcs New LG Premium Water Filter Gen11042FR-08 4 Kenmore and LG refrigertors',1,'LGFI001*2',99.99,'au-buy','danh2701','dan@nuway.com.au','Dan Haddon','37 Meera Street','Cornubia','Queensland','AUSTRALIA','4130','0417796664','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 20:59:28',0,NULL,0,0,0,0,NULL,'au-buy'),(24436,866512407011,320826634815,'New Philips Sonicare Essence 5300 Toothbrush Handle HX5300',1,'HBPH009',12.99,'eastar4uk','dimpleuk','dimple@compuserve.com','Gurdeep S Ranautta','4 The Drive, Earley','Reading','Berkshire','UNITED KINGDOM','RG6 1EG','01189668845','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 21:01:58',0,NULL,0,0,0,0,NULL,'eastar4uk'),(24437,697360512013,230717820578,'New In Box SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001',43.99,'eastar4','tlcshuki0543','tlcshuki@gmail.com','labe shuki','rimon 1 post office box 1611<br>85025','mitar','israel','ISRAEL','1611','0543017317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 21:23:27',0,NULL,0,0,0,0,NULL,'eastar4'),(24438,641120672004,140662512528,'New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102',2,'GPS0010',64,'cnfaner','epayment.ro','vendorgsm@gmail.com','Cristian Cocos','4283 Express Lane<br>Ste K4208','Sarasota','FL','UNITED STATES','34238','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-25 21:40:41',0,NULL,0,0,0,0,NULL,'cnfaner'),(24439,866539876011,320820753359,'3 pcs of New SAMSUNG Aqua-Pure Plus Replacement Refrigerator Water Filter',1,'SAFI001*3',87.99,'eastar4uk','p4dul','p4dul@yahoo.co.uk','A Piempreecha','83 moss lane','Pinner','Middlesex','UNITED KINGDOM','HA5 3AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 21:43:30',0,NULL,0,0,0,0,NULL,'eastar4uk');
/*!40000 ALTER TABLE `hmsh_ebay_eastar_transaction` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_itemstatus`
--

DROP TABLE IF EXISTS `hmsh_ebay_itemstatus`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_itemstatus` (
  `id` int(10) unsigned NOT NULL,
  `description` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_itemstatus`
--

LOCK TABLES `hmsh_ebay_itemstatus` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_itemstatus` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_itemstatus` VALUES (0,'NA'),(1,'Ready for Packaging');
/*!40000 ALTER TABLE `hmsh_ebay_itemstatus` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_product_supplier`
--

DROP TABLE IF EXISTS `hmsh_ebay_product_supplier`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_product_supplier` (
  `item_id` bigint(20) NOT NULL,
  `supplier_id` int(8) NOT NULL,
  `description` varchar(1024) DEFAULT NULL,
  UNIQUE KEY `pairunique` (`item_id`,`supplier_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_product_supplier`
--

LOCK TABLES `hmsh_ebay_product_supplier` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_product_supplier` DISABLE KEYS */;
/*!40000 ALTER TABLE `hmsh_ebay_product_supplier` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_shippingmethod`
--

DROP TABLE IF EXISTS `hmsh_ebay_shippingmethod`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_shippingmethod` (
  `id` int(10) unsigned NOT NULL,
  `index` int(11) NOT NULL,
  `Shipper` varchar(255) DEFAULT NULL,
  `carrier` varchar(256) NOT NULL,
  `description` varchar(255) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_shippingmethod`
--

LOCK TABLES `hmsh_ebay_shippingmethod` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_shippingmethod` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_shippingmethod` VALUES (0,0,'NA','','NA'),(1,1,' e邮宝 ','',' e邮宝 '),(2,2,'新加坡小包平邮 ','',' 递四方平邮'),(3,3,' 国内小包挂号 ','China Post registered airmail',' 国内小包挂号'),(4,4,'燕文','YanWen express','燕文'),(5,5,' SAL','China Post registered airmail',' SAL'),(6,6,' EMS 外地','EMS',' EMS 外地'),(7,7,' EMS 北京','EMS',' EMS 北京'),(8,8,'航空大包','China Post registered airmail','航空大包'),(9,9,' 递四方专线','others',' 递四方专线'),(10,10,' 递四方挂号','others',' 递四方挂号'),(11,11,' 国内小包','',' 国内小包'),(12,12,' DHL','DHL',' DHL'),(13,13,' UPS','',' UPS'),(14,14,' 顺丰','',' 顺丰'),(15,15,' 国内普通快递','',' 国内普通快递'),(16,21,' 其他','',''),(17,22,'合并订单','same as other transactions',''),(18,23,'订单取消','',''),(19,24,'待定-重量?','',''),(20,25,'代发','',''),(21,16,'国际SAL小包挂号','China post registered airmail','国际SAL小包挂号'),(22,17,'国际SAL小包','','国际SAL小包'),(23,18,'燕文专线欧洲小包','Yanwen registered package','燕文专线欧洲小包'),(24,19,'香港小包平邮','','香港小包平邮'),(25,20,'香港小包挂号','HK post','香港小包挂号');
/*!40000 ALTER TABLE `hmsh_ebay_shippingmethod` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_sku_item`
--

DROP TABLE IF EXISTS `hmsh_ebay_sku_item`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_sku_item` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `sku` varchar(255) NOT NULL,
  `item_id` bigint(20) NOT NULL,
  `quantity` int(8) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM AUTO_INCREMENT=5191 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_sku_item`
--

LOCK TABLES `hmsh_ebay_sku_item` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_sku_item` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_sku_item` VALUES (1,'AB2208',100001,1),(2,'AB2209',100002,1),(3,'AB2210',100003,1),(4,'AB2211',100004,1),(5,'AB2212',100005,1),(6,'AB2214',100006,1),(7,'AA3201',100007,1),(8,'AA3202',100008,1),(9,'AA3203',100009,1),(10,'AA3204',100010,1),(11,'AA3205',100011,1),(12,'AA3206',100012,1),(13,'AA3207',100013,1),(14,'AA3208',100014,1),(15,'AA3209',100015,1),(16,'AA3210',100016,1),(17,'AA3211',100017,1),(18,'AA3212',100018,1),(19,'AA3229',100019,1),(20,'AA3213',100020,1),(21,'AA3214',100021,1),(22,'AA2219',100022,1),(23,'AA2220',100023,1),(24,'AA2221',100024,1),(25,'AA3218',100025,1),(26,'AA3219',100026,1),(27,'AA3220',100027,1),(28,'AA3221',100028,1),(29,'AA3222',100029,1),(30,'AA3223',100030,1),(31,'AA3224',100031,1),(32,'AA3225',100032,1),(33,'AA3226',100033,1),(34,'AA3227',100034,1),(35,'AA3228',100035,1),(36,'AA2201',100036,1),(37,'AA2202',100037,1),(38,'AA2203',100038,1),(39,'AA2204',100039,1),(40,'AA2205',100040,1),(41,'AA2206',100041,1),(42,'AB3301',100042,1),(43,'AB3303',100043,1),(44,'AB3305',100044,1),(45,'AB3317',100045,1),(46,'AB3307',100046,1),(47,'AB3309',100047,1),(48,'AB3311',100048,1),(49,'AB3313',100049,1),(50,'AB3315',100050,1),(51,'AB3318',100051,1),(52,'AB3319',100052,1),(53,'AB3320',100053,1),(54,'AB3321',100054,1),(55,'AB3325',100055,1),(56,'AB3326',100056,1),(57,'AB3322',100057,1),(58,'AB3323',100058,1),(59,'AB3324',100059,1),(60,'AB3302',100060,1),(61,'AB3304',100061,1),(62,'AB3306',100062,1),(63,'AB3308',100063,1),(64,'AB3310',100064,1),(65,'AB3312',100065,1),(66,'AB3314',100066,1),(67,'AB3327',100067,1),(68,'AB3328',100068,1),(69,'AB3329',100069,1),(70,'AB3330',100070,1),(71,'AB3331',100071,1),(72,'AB3332',100072,1),(73,'AA3301',100073,1),(74,'AA3302',100074,1),(75,'AA3303',100075,1),(76,'AA3304',100076,1),(77,'AA3305',100077,1),(78,'AA3306',100078,1),(79,'AA3307',100079,1),(80,'AA3308',100080,1),(81,'AA3309',100081,1),(82,'AA3310',100082,1),(83,'AA3311',100083,1),(84,'AA3312',100084,1),(85,'AA3313',100085,1),(86,'AA3314',100086,1),(87,'AE2301',100087,1),(88,'AE2302',100088,1),(89,'AE2303',100089,1),(90,'AE2304',100090,1),(91,'AE2305',100091,1),(92,'AE2306',100092,1),(93,'AE2307',100093,1),(94,'AE2308',100094,1),(95,'AE2309',100095,1),(96,'AE2310',100096,1),(97,'AE2311',100097,1),(98,'AE2312',100098,1),(99,'AE2313',100099,1),(100,'AE2314',100100,1),(101,'AA3315',100101,1),(102,'AA3316',100102,1),(103,'AA3317',100103,1),(104,'AA3318',100104,1),(105,'AA3319',100105,1),(106,'AA3320',100106,1),(107,'AA3321',100107,1),(108,'AE3201',100108,1),(109,'AE3202',100109,1),(110,'AE3203',100110,1),(111,'AE3204',100111,1),(112,'AE3205',100112,1),(113,'AE3206',100113,1),(114,'AE3207',100114,1),(115,'AE3208',100115,1),(116,'AE3209',100116,1),(117,'AE3210',100117,1),(118,'AE3211',100118,1),(119,'AE3212',100119,1),(120,'AE3213',100120,1),(121,'AE3214',100121,1),(122,'AE3215',100122,1),(123,'AE3216',100123,1),(124,'AE3217',100124,1),(125,'AE3218',100125,1),(126,'AE3219',100126,1),(127,'AE3220',100127,1),(128,'AE3221',100128,1),(129,'AE3222',100129,1),(130,'AE3223',100130,1),(131,'AE3224',100131,1),(132,'AE3225',100132,1),(133,'AE3226',100133,1),(134,'AE3227',100134,1),(135,'AE3228',100135,1),(136,'AA2301',100136,1),(137,'AA2302',100137,1),(138,'AA2303',100138,1),(139,'AA2304',100139,1),(140,'AA2305',100140,1),(141,'AA2306',100141,1),(142,'AA2307',100142,1),(143,'AA2308',100143,1),(144,'AA2309',100144,1),(145,'AA2310',100145,1),(146,'AA2311',100146,1),(147,'AA2312',100147,1),(148,'AA2313',100148,1),(149,'AA2314',100149,1),(150,'AA2315',100150,1),(151,'AA2207',100151,1),(152,'AA2208',100152,1),(153,'AA2209',100153,1),(154,'AA2210',100154,1),(155,'AA2211',100155,1),(156,'AA2212',100156,1),(157,'AA2213',100157,1),(158,'AA2214',100158,1),(159,'AA2222',100159,1),(160,'AA2215',100160,1),(161,'AA2216',100161,1),(162,'AA2316',100162,1),(163,'AA2317',100163,1),(164,'AA2318',100164,1),(165,'AA2319',100165,1),(166,'AA2320',100166,1),(167,'AA2322',100167,1),(168,'AA2321',100168,1),(169,'AA2323',100169,1),(170,'AA2324',100170,1),(171,'AA2325',100171,1),(172,'AE2315',100172,1),(173,'AE2316',100173,1),(174,'AE2317',100174,1),(175,'AA2326',100175,1),(176,'AE2318',100176,1),(177,'AE1201',100177,1),(178,'AE1202',100178,1),(179,'AE1203',100179,1),(180,'AB1301',100180,1),(181,'AB1302',100181,1),(182,'AB1303',100182,1),(183,'AB1304',100183,1),(184,'AB1305',100184,1),(185,'AB1306',100185,1),(186,'AB1307',100186,1),(187,'AA3401',100187,1),(188,'AA3402',100188,1),(189,'AA3403',100189,1),(190,'AA3404',100190,1),(191,'AA3405',100191,1),(192,'AA3406',100192,1),(193,'AA3407',100193,1),(194,'AA3408',100194,1),(195,'AA1301',100195,1),(196,'AA1302',100196,1),(197,'AA1303',100197,1),(198,'AA1304',100198,1),(199,'AA1305',100199,1),(200,'AA1306',100200,1),(201,'AA1307',100201,1),(202,'AA1308',100202,1),(203,'AA1309',100203,1),(204,'AA1314',100204,1),(205,'AA1315',100205,1),(206,'AA1310',100206,1),(207,'AA1311',100207,1),(208,'AA1312',100208,1),(209,'AA1313',100209,1),(210,'AA3101',100210,1),(211,'AA3102',100211,1),(212,'AA1201',100212,1),(213,'AA1202',100213,1),(214,'AA1203',100214,1),(215,'AA1204',100215,1),(216,'AA1205',100216,1),(217,'AA1206',100217,1),(218,'AA2217',100218,1),(219,'AA2218',100219,1),(220,'AA1207',100220,1),(221,'AA1208',100221,1),(222,'AA1209',100222,1),(223,'AA1210',100223,1),(224,'AA1211',100224,1),(225,'AA1212',100225,1),(226,'AA1213',100226,1),(227,'AA1214',100227,1),(228,'AC2301',100228,1),(229,'AC2302',100229,1),(230,'AC2303',100230,1),(231,'AC1301',100231,1),(232,'AC2304',100232,1),(233,'AC2305',100233,1),(234,'AC1302',100234,1),(235,'AC1303',100235,1),(236,'AC1304',100236,1),(237,'AC1305',100237,1),(238,'AC1201',100238,1),(239,'AC1202',100239,1),(240,'AC1203',100240,1),(241,'AC1204',100241,1),(242,'AC2202',100242,1),(243,'AC2203',100243,1),(244,'AC2204',100244,1),(245,'AC3201',100245,1),(246,'AC3301',100246,1),(247,'AC3401',100247,1),(248,'AC3302',100248,1),(249,'AC3303',100249,1),(250,'AC3304',100250,1),(251,'AE2501',100251,1),(252,'AC2401',100252,1),(253,'AC2402',100253,1),(254,'AC2403',100254,1),(255,'AB1201',100255,1),(256,'AE1401',100256,1),(257,'AE1601',100257,1),(258,'AB1202',100258,1),(259,'AE1502',100259,1),(260,'AB1203',100260,1),(261,'AE1503',100261,1),(262,'AE1101',100262,1),(263,'AE1102',100263,1),(264,'AO0001',100264,1),(265,'AO0022',100265,1),(266,'AO0023',100266,1),(267,'AE2101',100267,1),(268,'AB1204',100268,1),(269,'AE2102',100269,1),(270,'AE1602',100270,1),(271,'AE1603',100271,1),(272,'AE1604',100272,1),(273,'AO0027',100273,1),(274,'AO0020',100274,1),(275,'AO0017',100275,1),(276,'AE3101',100276,1),(277,'AE3102',100277,1),(278,'AE3103',100278,1),(279,'AE3104',100279,1),(280,'AE3401',100280,1),(281,'AE3501',100281,1),(282,'AE3402',100282,1),(283,'AE3403',100283,1),(284,'AE3404',100284,1),(285,'AD1401',100285,1),(286,'AD1402',100286,1),(287,'AB2301',100287,1),(288,'AB2302',100288,1),(289,'AB1401',100289,1),(290,'AE1301',100290,1),(291,'AE1302',100291,1),(292,'AE3301',100292,1),(293,'AE2401',100293,1),(294,'AE2201',100295,1),(295,'AE2202',100295,1),(296,'AE2203',100296,1),(297,'AE2204',100297,1),(5187,'AD1183',100523,2),(299,'AO0009',100299,1),(300,'AO0010',100299,1),(301,'AO0011',100280,2),(302,'AO0012',100302,1),(303,'AO0005',100303,1),(304,'AO0018',100304,1),(305,'AO0019',100305,1),(306,'AO0050',100306,1),(307,'AO0003',100307,1),(308,'AE3601',100308,1),(309,'AO0004',100309,1),(310,'AO0013',100310,1),(311,'AO0014',100311,1),(312,'AO0015',100312,1),(313,'AO0028',100313,1),(314,'AO0029',100314,1),(315,'AO0030',100315,1),(316,'AO0031',100316,1),(317,'AO0032',100317,1),(318,'AO0033',100318,1),(319,'AO0034',100319,1),(320,'AO0035',100320,1),(321,'AA1102',100321,1),(322,'AA1103',100322,1),(323,'AA1104',100323,1),(324,'AA2101',100324,1),(325,'AA2102',100325,1),(326,'AA2103',100326,1),(327,'AA2104',100327,1),(328,'AA2105',100328,1),(329,'AA2106',100329,1),(330,'AA2107',100330,1),(331,'AA2108',100331,1),(332,'AA2109',100332,1),(333,'AA2110',100333,1),(334,'AA2111',100334,1),(335,'AA2112',100335,1),(336,'AB1402',100336,1),(337,'AB2401',100337,1),(338,'AB1403',100338,1),(339,'AB1404',100339,1),(340,'AB1405',100340,1),(341,'AB1406',100341,1),(342,'AB1407',100342,1),(343,'AB1408',100343,1),(344,'AB1409',100344,1),(345,'AB1410',100345,1),(346,'AB1411',100346,1),(347,'AKT001',100058,1),(348,'AKT001',100059,2),(349,'AKT002',100058,1),(350,'AKT002',100059,3),(351,'AKT013',100058,1),(352,'AKT013',100059,1),(353,'AKT003',100280,1),(354,'AKT003',100293,1),(355,'AKT003',100276,1),(356,'AKT004',100280,1),(357,'AKT004',100293,1),(358,'AKT004',100276,1),(359,'AKT004',100308,1),(360,'AKT005',100298,1),(361,'AKT005',100303,1),(362,'AKT005',100280,2),(363,'AKT005',100293,2),(364,'AKT005',100308,2),(365,'AKT005',100347,1),(366,'AKT006',100162,1),(367,'AKT006',100163,1),(368,'AKT006',100164,1),(369,'AKT006',100165,1),(370,'AKT006',100166,1),(371,'AKT006',100167,1),(372,'AKT006',100168,1),(373,'AKT006',100169,1),(374,'AKT006',100170,1),(375,'AKT006',100171,1),(376,'AKT006',100154,1),(377,'AKT006',100160,1),(378,'AKT006',100176,1),(379,'AKT007',100307,2),(380,'AKT008',100163,1),(381,'AKT008',100166,1),(382,'AKT008',100167,1),(383,'AKT008',100169,1),(384,'AKT008',100170,1),(385,'AKT008',100171,1),(386,'AKT008',100179,1),(387,'AKT009',100280,2),(388,'AKT009',100290,2),(389,'AKT009',100285,2),(390,'AKT009',100347,1),(391,'AKT010',100282,1),(392,'AKT010',100289,1),(393,'AKT014',100280,1),(394,'AKT014',100287,1),(395,'AKT014',100286,1),(396,'AKT052',100280,1),(397,'AKT052',100288,1),(398,'AKT052',100286,1),(399,'AKT015',100299,1),(400,'AKT015',100303,2),(401,'AKT016',100280,2),(402,'AKT016',100293,2),(403,'AKT016',100347,1),(404,'AKT017',100280,2),(405,'AKT017',100293,2),(406,'AKT017',100308,2),(407,'AKT017',100347,1),(408,'AKT018',100152,1),(409,'AKT018',100160,1),(410,'AKT019',100153,1),(411,'AKT019',100160,1),(412,'AKT020',100154,1),(413,'AKT020',100160,1),(414,'AKT021',100155,1),(415,'AKT021',100160,1),(416,'AKT022',100156,1),(417,'AKT022',100160,1),(418,'AKT023',100157,1),(419,'AKT023',100160,1),(420,'AKT024',100158,1),(421,'AKT024',100160,1),(422,'AKT053',100151,1),(423,'AKT053',100160,1),(424,'AKT054',100159,1),(425,'AKT054',100160,1),(426,'AKT025',100152,1),(427,'AKT025',100153,1),(428,'AKT025',100154,1),(429,'AKT025',100155,1),(430,'AKT025',100156,1),(431,'AKT025',100157,1),(432,'AKT025',100158,1),(433,'AKT025',100160,1),(434,'AKT026',100169,1),(435,'AKT026',100170,1),(436,'AKT026',100171,1),(437,'AKT026',100154,1),(438,'AKT026',100160,1),(439,'AKT028',100167,1),(440,'AKT028',100154,1),(441,'AKT028',100160,1),(442,'AKT029',100195,10),(443,'AKT030',100280,1),(444,'AKT030',100276,1),(445,'AKT031',100280,2),(446,'AKT032',100073,10),(447,'AKT033',100082,10),(448,'AKT034',100013,10),(449,'AKT035',100182,10),(450,'AKT036',100220,10),(451,'AKT037',100479,1),(452,'AKT037',100305,1),(453,'AKT037',100280,4),(454,'AKT037',100290,2),(455,'AKT037',100285,2),(456,'AKT037',100307,4),(457,'AKT037',100347,1),(458,'AKT038',100479,1),(459,'AKT038',100304,1),(460,'AKT038',100280,4),(461,'AKT038',100290,2),(462,'AKT038',100285,2),(463,'AKT038',100307,4),(464,'AKT038',100347,1),(465,'AKT039',100280,2),(5188,'AD1183',100479,1),(467,'AKT039',100307,8),(468,'AKT039',100347,1),(469,'AKT040',100295,2),(470,'AKT041',100298,1),(471,'AKT041',100303,1),(472,'AKT041',100280,2),(473,'AKT041',100285,2),(474,'AKT041',100290,2),(475,'AKT041',100308,4),(476,'AKT041',100347,1),(477,'AKT042',100080,1),(478,'AKT042',100094,1),(479,'AKT042',100129,1),(480,'AKT042',100101,1),(481,'AKT042',100178,1),(482,'AKT043',100081,1),(483,'AKT043',100095,1),(484,'AKT043',100130,1),(485,'AKT043',100102,1),(486,'AKT043',100178,1),(487,'AKT044',100082,1),(488,'AKT044',100096,1),(489,'AKT044',100131,1),(490,'AKT044',100103,1),(491,'AKT044',100178,1),(492,'AKT045',100083,1),(493,'AKT045',100097,1),(494,'AKT045',100132,1),(495,'AKT045',100104,1),(496,'AKT045',100178,1),(497,'AKT046',100084,1),(498,'AKT046',100098,1),(499,'AKT046',100133,1),(500,'AKT046',100105,1),(501,'AKT046',100178,1),(502,'AKT047',100085,1),(503,'AKT047',100099,1),(504,'AKT047',100134,1),(505,'AKT047',100106,1),(506,'AKT047',100178,1),(507,'AKT048',100086,1),(508,'AKT048',100100,1),(509,'AKT048',100135,1),(510,'AKT048',100107,1),(511,'AKT048',100178,1),(512,'AKT049',100308,2),(513,'AKT050',100479,1),(514,'AKT050',100304,1),(515,'AKT050',100280,4),(516,'AKT050',100293,2),(517,'AKT050',100308,2),(518,'AKT050',100347,1),(519,'AKT051',100206,2),(520,'AKT055',100310,1),(521,'AKT055',100312,1),(522,'AKT056',100251,1),(523,'AKT056',100280,1),(524,'AKT057',100310,1),(525,'AKT057',100312,1),(526,'AKT057',100284,1),(527,'AKT058',100311,5),(528,'AKT059',100312,5),(529,'AKT060',100280,1),(530,'AKT060',100312,1),(531,'AKT060',100310,1),(532,'AKT061',100280,1),(533,'AKT061',100291,1),(534,'AKT061',100285,1),(535,'AKT062',100169,1),(536,'AKT062',100170,1),(537,'AKT062',100171,1),(538,'AO0036',100347,1),(539,'AD1101',100348,1),(540,'AA2401',100349,1),(541,'AA2113',100350,1),(542,'AA2114',100351,1),(543,'AA2115',100352,1),(544,'AA2116',100353,1),(545,'AA2117',100354,1),(546,'AA2118',100355,1),(547,'AA2119',100356,1),(548,'AA2120',100357,1),(549,'AA2121',100358,1),(550,'AA2122',100359,1),(551,'AA2123',100360,1),(552,'AD1102',100361,1),(553,'AD1103',100362,1),(554,'AD1104',100363,1),(555,'AD1105',100364,1),(556,'AD1106',100365,1),(557,'AD1107',100366,1),(558,'AD1108',100367,1),(559,'AD1109',100368,1),(560,'AKT063',100479,1),(561,'AKT063',100305,1),(562,'AKT063',100280,4),(563,'AKT063',100293,2),(564,'AKT063',100308,2),(565,'AKT063',100347,1),(566,'AKT064 ',100280,1),(567,'AKT064 ',100276,1),(568,'AKT064 ',100293,1),(569,'AKT064 ',100308,1),(570,'AKT065 ',100479,1),(571,'AKT065 ',100305,1),(572,'AKT065 ',100280,4),(573,'AKT065 ',100291,2),(574,'AKT065 ',100286,2),(575,'AKT065 ',100308,2),(576,'AKT065 ',100347,1),(577,'AKT066 ',100280,3),(578,'AKT066 ',100276,1),(579,'AKT066 ',100293,3),(580,'AKT066 ',100308,3),(581,'AKT066 ',100347,1),(4863,'AA1215 ',100389,1),(4864,'AA1216 ',100390,1),(4865,'AA1217 ',100391,1),(4866,'AA1218 ',100392,1),(4867,'AKT067 ',100206,1),(4868,'AKT067 ',100207,1),(4869,'AD1110 ',100393,1),(4870,'AD1111 ',100394,1),(4871,'AD1112 ',100395,1),(4872,'AD1113 ',100396,1),(4873,'AD1114 ',100397,1),(4874,'AD1115',100398,1),(4875,'AD1116 ',100399,1),(4876,'AD1117 ',100400,1),(4877,'AD1118',100401,1),(4878,'AD1119 ',100402,1),(4879,'AD1120 ',100403,1),(4880,'AD1121',100404,1),(4881,'AD1122 ',100405,1),(4882,'AD1123 ',100406,1),(4883,'AD1124',100407,1),(4884,'AKT087  ',100299,1),(4885,'AKT087 ',100303,1),(4886,'AKT087 ',100280,2),(4887,'AKT087 ',100285,2),(4888,'AKT087 ',100290,2),(4889,'AKT087 ',100307,4),(4890,'AKT087 ',100347,1),(4891,'AD1125 ',100408,1),(4892,'AD1126',100409,1),(4893,'AD1127',100410,1),(4894,'AD1128',100411,1),(4895,'AD1129',100412,1),(4896,'AD1130 ',100413,1),(4897,'AD1131',100414,1),(4898,'AD1132',100415,1),(4899,'AD1133 ',100416,1),(4900,'AKT003 ',100347,1),(4901,'AKT004',100347,1),(4914,'AKT068 ',100347,1),(4913,'AKT068 ',100307,4),(4912,'AKT068 ',100290,2),(4911,'AKT068 ',100285,2),(4910,'AKT068 ',100280,2),(4907,'AKT069 ',100308,4),(4908,'AD1140 ',100423,1),(4909,'AD1141',100424,1),(4915,'AD1142 ',100425,1),(4916,'AD1143',100426,1),(4917,'AD1134 ',100417,1),(4918,'AD1137',100420,1),(4919,'AD1144 ',100427,1),(4920,'AD1145',100428,1),(4921,'AKT070  ',100163,1),(4922,'AKT070 ',100166,1),(4923,'AKT070 ',100167,1),(4924,'AKT070 ',100169,1),(4925,'AKT070 ',100170,1),(4926,'AKT070 ',100171,1),(4927,'AKT070 ',100179,1),(4928,'AKT070 ',100154,1),(4929,'AKT070 ',100160,1),(4930,'AD1146 ',100429,1),(4931,'AD1147 ',100430,1),(4932,'AKT072  ',100280,3),(4933,'AKT072 ',100310,3),(4934,'AKT072 ',100312,6),(4935,'AD1148 ',100431,1),(4936,'AD1149 ',100432,1),(4937,'AD1150',100433,1),(4938,'AD1151',100434,1),(4939,'AD1152',100435,1),(4940,'AD1153',100436,1),(4941,'AD1154',100437,1),(4942,'AD1155',100438,1),(4943,'AD1158 ',100441,1),(4944,'AD1159',100442,1),(4945,'AD1160',100443,1),(4946,'AD1161',100444,1),(4947,'AD1162 ',100445,1),(4948,'AD1163 ',100446,1),(4949,'AD1164 ',100447,1),(4950,'AKT073 ',100280,3),(4951,'AKT073 ',100438,3),(4952,'AKT073 ',100296,3),(4953,'AKT073 ',100447,1),(4954,'AKT072 ',100447,1),(4955,'AKT074 ',100479,1),(4956,'AKT074 ',100305,1),(4957,'AKT074 ',100280,5),(4958,'AKT074 ',100276,1),(4959,'AKT074 ',100293,3),(4960,'AKT074 ',100308,3),(4961,'AKT074 ',100347,1),(4962,'AKT075 ',100479,1),(4963,'AKT075 ',100304,1),(4964,'AKT075 ',100280,5),(4965,'AKT075 ',100276,1),(4966,'AKT075 ',100293,3),(4967,'AKT075 ',100308,3),(4968,'AKT075 ',100347,1),(4969,'AD1165 ',100448,1),(4970,'AD1166',100449,1),(4971,'AD1156 ',100439,1),(4972,'AD1157',100440,1),(4973,'AD1167 ',100450,1),(4975,'AD1168 ',100451,1),(4976,'AD1169',100452,1),(4977,'AKT076 ',100453,1),(4978,'AKT076 ',100454,1),(4979,'AKT076 ',100455,1),(4980,'AKT076 ',100456,1),(4981,'AKT076 ',100457,1),(4982,'AKT076 ',100458,1),(4983,'AKT076 ',100459,1),(4984,'AKT076 ',100460,1),(4985,'AKT076 ',100461,1),(4986,'AKT076 ',100462,1),(4987,'AKT076 ',100463,1),(4988,'AKT076 ',100154,1),(4989,'AKT076 ',100160,1),(4990,'AD1170 ',100463,1),(4991,'AKT077 ',100453,1),(4992,'AKT077 ',100454,1),(4993,'AKT077 ',100455,1),(4994,'AKT077 ',100456,1),(4995,'AKT077 ',100457,1),(4996,'AKT077 ',100458,1),(4997,'AKT077 ',100459,1),(4998,'AKT077 ',100460,1),(4999,'AKT077 ',100461,1),(5000,'AKT077 ',100462,1),(5001,'AKT072 ',100464,3),(5002,'AD1171 ',100466,1),(5003,'AKT071 ',100160,1),(5004,'AKT071 ',100163,1),(5005,'AKT071 ',100166,1),(5006,'AKT071 ',100167,1),(5007,'AKT071 ',100154,1),(5008,'AKT078 ',100280,1),(5009,'AKT078 ',100295,1),(5010,'AKT078 ',100409,1),(5011,'AKT078 ',100307,4),(5012,'AKT025 ',100151,1),(5013,'AKT025 ',100159,1),(5014,'AKT025 ',100161,1),(5015,'AD1175 ',100470,1),(5016,'AKT085 ',100280,1),(5017,'AKT085 ',100437,1),(5018,'AKT085 ',100286,1),(5019,'AKT079 ',100280,2),(5020,'AKT079 ',100437,2),(5021,'AKT079 ',100286,2),(5022,'AKT079 ',100347,1),(5023,'AKT080 ',100280,2),(5024,'AKT080 ',100437,2),(5025,'AKT080 ',100296,2),(5026,'AKT080 ',100347,1),(5027,'AD1176 ',100295,1),(5028,'AD1177 ',100465,1),(5029,'AD1172 ',100467,1),(5030,'AD1173 ',100468,1),(5031,'AD1174 ',100469,1),(5032,'AD1178 ',100472,1),(5033,'AD1181 ',100475,1),(5034,'AKT081 ',100453,1),(5035,'AKT081 ',100454,1),(5036,'AKT081 ',100455,1),(5037,'AKT081 ',100460,1),(5038,'AKT081 ',100461,1),(5039,'AKT081 ',100462,1),(5040,'AKT081 ',100179,1),(5041,'AD1179 ',100473,1),(5042,'AD1180',100474,1),(5043,'AKT083 ',100280,2),(5044,'AKT083 ',100437,2),(5045,'AKT083 ',100476,1),(5046,'AKT083 ',100296,2),(5047,'AKT083 ',100475,1),(5048,'AD1182 ',100477,1),(5049,'AKT084 ',100283,1),(5050,'AKT084 ',100276,1),(5051,'AKT084 ',100069,1),(5053,'AD1184',100479,1),(5054,'AD1185 ',100480,1),(5055,'AD1186 ',100481,1),(5056,'AD1187',100482,1),(5057,'AD1188',100483,1),(5058,'AD1189',100484,1),(5059,'AD1190',100485,1),(5060,'AKT086 ',100238,1),(5061,'AKT086 ',100239,1),(5062,'AKT086 ',100240,1),(5063,'AKT086 ',100241,1),(5064,'AD1191 ',100486,1),(5065,'AD1192 ',100487,1),(5066,'AD1193 ',100488,1),(5067,'AD1194 ',100489,1),(5068,'AD1195 ',100490,1),(5069,'',0,0),(5070,'AKT088 ',100489,1),(5071,'AKT088 ',100431,1),(5072,'AKT089',100490,1),(5073,'AKT089',100431,1),(5077,'AO0011 ',100412,1),(5076,'AO0011 ',100479,1),(5078,'AKT037 ',100412,1),(5079,'AKT050 ',100412,1),(5080,'AKT063 ',100412,1),(5081,'AKT065 ',100412,1),(5082,'AKT074 ',100479,1),(5083,'AKT075 ',100412,1),(5084,'AKT038 ',100412,1),(5085,'AD1196 ',100491,1),(5086,'AD1197 ',100492,1),(5087,'AKT090 ',100280,2),(5088,'AKT090 ',100486,2),(5089,'AKT090 ',100307,10),(5090,'AKT090 ',100347,1),(5091,'AKT091 ',100289,2),(5092,'AKT091 ',100282,2),(5093,'AKT091 ',100307,2),(5094,'AKT091 ',100252,1),(5095,'AD1176 ',100493,1),(5096,'AE2201 ',100494,1),(5097,'AKT040 ',100494,2),(5098,'AD1198 ',100496,1),(5099,'AD1199 ',100497,1),(5100,'AKT092 ',100280,1),(5101,'AKT092 ',100288,1),(5102,'AKT092 ',100496,1),(5103,'AKT093 ',100280,1),(5104,'AKT093 ',100288,1),(5105,'AKT093 ',100497,1),(5106,'AD1200 ',100498,1),(5107,'AD1201',100499,1),(5108,'AKT094 ',100280,5),(5109,'AKT094 ',100479,1),(5110,'AKT094 ',100412,1),(5111,'AKT094 ',100305,1),(5112,'AKT094 ',100486,2),(5113,'AKT094 ',100293,1),(5114,'AKT094 ',100276,1),(5115,'AKT094 ',100307,10),(5116,'AKT094 ',100308,1),(5117,'AKT094 ',100475,1),(5118,'AD1202 ',100502,1),(5119,'AD1203 ',100503,1),(5120,'AD1205 ',100504,1),(5121,'AD1206 ',100500,1),(5122,'AD1207 ',100501,1),(5123,'AD1208 ',100515,1),(5124,'AD1209 ',100516,1),(5125,'AD1210 ',100517,1),(5126,'AD1211 ',100518,1),(5127,'AD1212 ',100519,1),(5128,'AD1213 ',100520,1),(5129,'AD1214 ',100521,1),(5130,'AD1216 ',100522,1),(5131,'AD1217',100523,1),(5132,'AKT095',100280,5),(5133,'AKT095',100479,1),(5134,'AKT095',100305,1),(5135,'AKT095',100486,2),(5136,'AKT095',100276,1),(5137,'AKT095',100293,1),(5138,'AKT095',100307,10),(5139,'AKT095',100308,1),(5140,'AKT095',100475,1),(5141,'AD1218',100524,1),(5142,'AD1219',100453,1),(5143,'AD1220',100454,1),(5144,'AD1221',100460,1),(5145,'AD1222',100461,1),(5146,'AD1223',100462,1),(5147,'AD1224',100455,1),(5148,'AD1225',100456,1),(5149,'AD1226',100457,1),(5150,'AD1227',100458,1),(5151,'AD1228',100459,1),(5152,'AKT096',100460,1),(5153,'AKT096',100461,1),(5154,'AKT096',100462,1),(5155,'AKT096',100177,1),(5156,'AKT097',100524,1),(5157,'AKT097',100453,1),(5158,'AKT097',100454,1),(5159,'AKT097',100177,1),(5160,'AKT098',100455,1),(5161,'AKT098',100456,1),(5162,'AKT098',100453,1),(5163,'AKT098',100177,1),(5164,'AKT099',100524,1),(5165,'AKT099',100453,1),(5166,'AKT099',100454,1),(5167,'AKT099',100461,1),(5168,'AKT099',100178,1),(5169,'AKT100',100280,1),(5170,'AKT100',100287,1),(5171,'AKT100',100286,1),(5172,'AKT100',100285,1),(5173,'AKT100',100412,1),(5174,'AD1229',100525,1),(5175,'AD1230',100526,1),(5176,'AD1231',100527,1),(5177,'AD1232',100528,1),(5178,'AD1233',100529,1),(5179,'AD1234',100530,1),(5180,'AD1235',100531,1),(5181,'AD1236',100532,1),(5182,'AD1237',100533,1),(5183,'AD1238',100534,1),(5184,'AD1239',100535,1),(5185,'AKT039',100295,2),(5186,'AKT039',100494,2),(5189,'AD1183',100303,1),(5190,'AD1183',100412,1);
/*!40000 ALTER TABLE `hmsh_ebay_sku_item` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_stock`
--

DROP TABLE IF EXISTS `hmsh_ebay_stock`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_stock` (
  `item_id` bigint(20) NOT NULL,
  `item_name` varchar(2048) NOT NULL,
  `item_condition` varchar(255) DEFAULT NULL,
  `item_type` varchar(255) DEFAULT NULL,
  `item_stock` int(8) NOT NULL,
  `item_price` double DEFAULT NULL,
  `update_time` datetime DEFAULT NULL,
  PRIMARY KEY (`item_id`)
) ENGINE=MyISAM AUTO_INCREMENT=4862 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_stock`
--

LOCK TABLES `hmsh_ebay_stock` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_stock` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_stock` VALUES (100001,'GGS 3.0\'','New','Photo',0,15,'2011-03-13 19:37:28'),(100002,'GGS 450D/500D','New','Photo',0,27,'2011-03-17 19:51:37'),(100003,'GGS 550D','New','Photo',0,27,'2011-12-17 17:35:15'),(100004,'GGS 50D/5DII','New','Photo',2,27,'2011-09-25 04:43:57'),(100005,'GGS D90','New','Photo',1,30,'2011-12-11 01:07:09'),(100006,'品胜3.0‘','New','Photo',-3,1.2,'2011-09-11 08:32:19'),(100007,'爵影无线N1','宇儿','Photo',-1,70,'2011-08-18 19:59:51'),(100008,'爵影无线N3','宇儿','Photo',0,70,'2011-08-13 02:53:50'),(100009,'爵影无线C1','宇儿','Photo',3,70,'2012-02-01 19:10:22'),(100010,'爵影无线C3','宇儿','Photo',-1,70,'2011-04-29 18:57:55'),(100011,'爵影无线S1','宇儿','Photo',1,70,'2011-08-20 04:48:55'),(100012,'爵影无线E2','宇儿','Photo',-1,70,'2011-12-01 18:51:54'),(100013,'普通有线快门线N1','宇儿 党部','Photo',18,12,'2012-03-21 19:44:33'),(100014,'爵影快门线N2','宇儿 党部','Photo',5,12,'2011-12-04 01:23:13'),(100015,'普通有线快门线N3','宇儿 党部','Photo',9,12,'2011-07-03 20:02:04'),(100016,'普通有线快门线C1','宇儿 党部','Photo',3,12,'2012-02-29 19:07:06'),(100017,'普通有线快门线C3','宇儿 党部','Photo',10,12,'2012-03-22 02:47:53'),(100018,'普通有线快门线S1','宇儿 党部','Photo',10,12,'2012-02-15 08:42:22'),(100019,'普通有线快门线E2','宇儿 党部','Photo',7,12,'2011-10-03 22:24:34'),(100020,'永诺 RS-802 N2','New','Photo',6,22,'0000-00-00 00:00:00'),(100021,'永诺 YN128-S1','New','Photo',0,80,'2012-01-13 02:01:48'),(100022,'优永佳快门线 A C3','New','Photo',0,13,'2011-08-21 19:41:53'),(100023,'优永佳快门线 B N1','New','Photo',5,13,'2012-01-06 04:37:32'),(100024,'优永佳快门线 G N2','New','Photo',4,13,'2012-02-27 04:43:40'),(100025,'永诺 MC-N1','boss少  宇儿 zddpl','Photo',3,140,'2011-07-11 21:51:09'),(100026,'永诺 MC-N2','boss少  宇儿 zddpl','Photo',0,140,'2011-03-05 21:25:42'),(100027,'永诺 MC-N3','boss少  宇儿 zddpl','Photo',-1,140,'2012-03-11 22:03:20'),(100028,'永诺 MC-C1','boss少  宇儿 zddpl','Photo',2,140,'2011-11-13 19:01:49'),(100029,'永诺 MC-C3','boss少  宇儿 zddpl','Photo',2,140,'2011-09-08 19:54:21'),(100030,'永诺 MC-S1','boss少  宇儿 zddpl','Photo',0,140,'2011-06-14 17:18:40'),(100031,'爵影mc-c3 ','New','Photo',1,100,'0000-00-00 00:00:00'),(100032,'永诺 YN126- N1','New','Photo',0,115,'0000-00-00 00:00:00'),(100033,'永诺 YN126- N3','New','Photo',0,115,'0000-00-00 00:00:00'),(100034,'永诺 YN126- C1','New','Photo',0,115,'0000-00-00 00:00:00'),(100035,'永诺 YN126- C3','New','Photo',0,115,'2011-07-31 08:28:23'),(100036,'爵影红外 nikon','宇儿','Photo',17,9,'2012-03-14 19:31:50'),(100037,'爵影红外 canon ','宇儿','Photo',7,9,'2012-03-14 02:31:06'),(100038,'爵影红外 sony','宇儿','Photo',18,9,'2012-02-02 18:38:53'),(100039,'爵影红外 olympus','宇儿','Photo',13,9,'2012-03-19 19:33:10'),(100040,'爵影红外 5 in 1','宇儿','Photo',2,9,'2012-02-01 21:03:41'),(100041,'永诺仿原装 canon RC-5','New','Photo',0,9,'2011-05-13 08:48:04'),(100042,'永诺闪光灯  YN465 for NIKON ','New','Photo',0,330,'0000-00-00 00:00:00'),(100043,'永诺闪光灯  YN465 for CANON ','New','Photo',0,330,'0000-00-00 00:00:00'),(100044,'永诺闪光灯  YN462','New','Photo',0,145,'2011-12-09 02:21:12'),(100045,'永诺 64LED 灯','New','Photo',0,115,'2012-03-03 01:24:21'),(100046,'永诺 SF18- CANON','宇儿','Photo',3,190,'2012-02-28 00:21:39'),(100047,'永诺 SF18- NIKON SB800','宇儿','Photo',1,190,'2012-02-19 19:41:43'),(100048,'永诺 SF18- NIKON SB900','宇儿','Photo',3,190,'2011-12-24 21:45:17'),(100049,'永诺 SF17- CANON','宇儿','Photo',1,160,'2011-11-03 00:26:23'),(100050,'永诺 SF17- NIKON SB800','宇儿','Photo',1,160,'2012-01-31 18:42:57'),(100051,'永诺 sony热靴转换器','New','Photo',0,25,'0000-00-00 00:00:00'),(100052,'爵影1m 多功能ttl线 ','New','Photo',0,75,'2011-09-26 19:54:08'),(100053,'永诺 nikon ttl 线  3m','宇儿','Photo',1,90,'2012-03-22 00:00:41'),(100054,'永诺 canon ttl 线  1m','宇儿','Photo',3,70,'2012-03-13 19:51:51'),(100055,'永诺 Canon ttl线  3m','宇儿','Photo',1,90,'2012-03-04 09:01:04'),(100056,'永诺 Canon ttl线  10m','宇儿','Photo',0,140,'2011-09-29 19:50:11'),(100057,'永诺 YN-04 引闪器一套','New','Photo',-1,70,'2011-05-09 22:21:36'),(100058,'永诺 CTR-301P 触发器','宇儿','Photo',5,30,'2012-03-12 19:25:22'),(100059,'永诺 CTR-301P 接受器','宇儿','Photo',6,70,'2012-03-12 19:25:22'),(100060,'NG200 柔光罩 ','宇儿','Photo',16,25,'2012-02-14 20:30:18'),(100061,'NG128 柔光罩','宇儿','Photo',15,18,'2012-03-25 06:20:45'),(100062,'爵影碗罩P1','宇儿  帝诚','Photo',6,18,'2012-02-12 03:47:36'),(100063,'爵影碗罩P2','宇儿  帝诚','Photo',7,18,'2012-03-01 19:54:27'),(100064,'爵影碗罩P3','宇儿  帝诚','Photo',5,18,'2011-12-12 04:09:22'),(100065,'爵影碗罩P4','宇儿  帝诚','Photo',6,18,'2012-03-22 19:41:36'),(100066,'万用遮光罩','宇儿','Photo',10,10,'2012-03-11 19:44:12'),(100067,'闪光的柔光箱   40cm','艺影','Photo',10,110,'2012-03-20 03:14:17'),(100068,'闪光的柔光箱   50cm','艺影','Photo',0,135,'2011-12-12 19:57:51'),(100069,'闪光的柔光箱   60cm','艺影','Photo',21,120,'2012-03-24 01:32:13'),(100070,'肥皂盒 柔光罩   sb800 sb600','宇儿','Photo',45,4,'2012-03-22 19:19:51'),(100071,'肥皂盒 柔光罩  430EX','宇儿','Photo',12,4,'2012-02-29 19:25:37'),(100072,'肥皂盒 柔光罩   580EX','宇儿','Photo',15,4,'2012-03-14 20:12:39'),(100073,'绿叶 UV  52mm','绿叶家族','Photo',8,6,'2012-03-21 19:25:02'),(100074,'绿叶 UV  55mm','绿叶家族','Photo',6,5.5,'2012-02-16 19:02:14'),(100075,'绿叶 UV  58mm','绿叶家族','Photo',0,6.5,'2012-01-15 18:35:53'),(100076,'绿叶 UV  62mm','绿叶家族','Photo',16,8,'2012-03-24 01:54:50'),(100077,'绿叶 UV  67mm','绿叶家族','Photo',9,9,'2012-03-24 02:09:06'),(100078,'绿叶 UV  72mm','绿叶家族','Photo',8,9.5,'2012-03-04 09:22:09'),(100079,'绿叶 UV  77mm','绿叶家族','Photo',13,11.5,'2012-01-12 18:49:50'),(100080,'绿叶 CPL  52mm','绿叶家族','Photo',15,18,'2012-03-22 21:35:32'),(100081,'绿叶 CPL  55mm','绿叶家族','Photo',11,18,'2012-02-28 19:50:40'),(100082,'绿叶 CPL  58mm','绿叶家族','Photo',12,19,'2012-01-01 22:33:44'),(100083,'绿叶 CPL  62mm','绿叶家族','Photo',10,19,'2011-10-28 18:43:31'),(100084,'绿叶 CPL  67mm','绿叶家族','Photo',9,20,'2012-03-17 07:13:11'),(100085,'绿叶 CPL 72mm','绿叶家族','Photo',11,20,'2012-03-19 19:26:23'),(100086,'绿叶 CPL  77mm','绿叶家族','Photo',8,22,'2012-03-05 18:54:40'),(100087,'绿叶 ND4  52mm','绿叶家族','Photo',12,15,'2011-04-23 07:58:42'),(100088,'绿叶 ND4  55mm','绿叶家族','Photo',7,15,'2011-08-13 02:40:55'),(100089,'绿叶 ND4  58mm','绿叶家族','Photo',6,17,'2012-02-04 02:37:12'),(100090,'绿叶 ND4  62mm','绿叶家族','Photo',15,17,'2011-08-13 02:42:33'),(100091,'绿叶 ND4  67mm','绿叶家族','Photo',13,19,'2011-05-01 21:33:01'),(100092,'绿叶 ND4  72mm','绿叶家族','Photo',5,19,'2011-12-10 03:30:09'),(100093,'绿叶 ND4  77mm','绿叶家族','Photo',5,21,'2011-12-04 18:27:43'),(100094,'绿叶 ND8  52mm','绿叶家族','Photo',10,15,'2011-07-11 20:21:07'),(100095,'绿叶 ND8  55mm','绿叶家族','Photo',7,15,'2011-07-13 03:54:11'),(100096,'绿叶 ND8  58mm','绿叶家族','Photo',6,17,'2012-02-04 02:37:18'),(100097,'绿叶 ND8  62mm','绿叶家族','Photo',2,17,'2011-04-24 07:12:49'),(100098,'绿叶 ND8  67mm','绿叶家族','Photo',6,19,'2011-11-23 20:42:41'),(100099,'绿叶 ND8 72mm','绿叶家族','Photo',14,19,'2011-07-25 02:03:17'),(100100,'绿叶 ND8  77mm','绿叶家族','Photo',4,21,'2012-03-24 01:17:28'),(100101,'绿叶 渐变镜 52mm','绿叶家族','Photo',11,15,'2012-03-15 03:25:28'),(100102,'绿叶 渐变镜 55mm','绿叶家族','Photo',6,15,'2012-01-06 19:46:02'),(100103,'绿叶 渐变镜 58mm','绿叶家族','Photo',12,15,'2012-03-21 19:39:12'),(100104,'绿叶 渐变镜 62mm','绿叶家族','Photo',13,18,'2012-02-24 01:24:35'),(100105,'绿叶 渐变镜 67mm','绿叶家族','Photo',20,18,'2012-02-07 19:23:19'),(100106,'绿叶 渐变镜 72mm','绿叶家族','Photo',3,22,'2012-03-19 22:07:47'),(100107,'绿叶 渐变镜 77mm','绿叶家族','Photo',12,22,'2012-03-22 03:28:29'),(100108,'绿叶近摄镜 +2  52mm','绿叶家族','Photo',1,12,'0000-00-00 00:00:00'),(100109,'绿叶近摄镜 +2  55mm','绿叶家族','Photo',2,12,'0000-00-00 00:00:00'),(100110,'绿叶近摄镜 +2  58mm','绿叶家族','Photo',0,12,'0000-00-00 00:00:00'),(100111,'绿叶近摄镜 +2  62mm','绿叶家族','Photo',6,14,'0000-00-00 00:00:00'),(100112,'绿叶近摄镜 +2  67mm','绿叶家族','Photo',0,17,'0000-00-00 00:00:00'),(100113,'绿叶近摄镜 +2  72mm','绿叶家族','Photo',8,17,'0000-00-00 00:00:00'),(100114,'绿叶近摄镜 +2  77mm','绿叶家族','Photo',6,20,'0000-00-00 00:00:00'),(100115,'绿叶近摄镜 +3  52mm','绿叶家族','Photo',0,12,'0000-00-00 00:00:00'),(100116,'绿叶近摄镜 +3  55mm','绿叶家族','Photo',3,12,'0000-00-00 00:00:00'),(100117,'绿叶近摄镜 +3  58mm','绿叶家族','Photo',0,12,'0000-00-00 00:00:00'),(100118,'绿叶近摄镜 +3  62mm','绿叶家族','Photo',8,14,'0000-00-00 00:00:00'),(100119,'绿叶近摄镜 +3  67mm','绿叶家族','Photo',0,17,'0000-00-00 00:00:00'),(100120,'绿叶近摄镜 +3  72mm','绿叶家族','Photo',10,17,'0000-00-00 00:00:00'),(100121,'绿叶近摄镜 +3  77mm','绿叶家族','Photo',9,20,'0000-00-00 00:00:00'),(100122,'绿叶近摄镜 +4  52mm','绿叶家族','Photo',0,12,'2011-03-08 19:05:44'),(100123,'绿叶近摄镜 +4  55mm','绿叶家族','Photo',1,12,'2011-06-09 20:25:06'),(100124,'绿叶近摄镜 +4  58mm','绿叶家族','Photo',5,12,'2011-04-14 01:39:43'),(100125,'绿叶近摄镜 +4  62mm','绿叶家族','Photo',3,14,'2011-07-10 22:48:00'),(100126,'绿叶近摄镜 +4  67mm','绿叶家族','Photo',5,17,'2011-08-21 02:21:49'),(100127,'绿叶近摄镜 +4  72mm','绿叶家族','Photo',6,17,'2011-07-10 20:06:11'),(100128,'绿叶近摄镜 +4  77mm','绿叶家族','Photo',0,20,'2011-11-18 02:41:32'),(100129,'绿叶近摄镜 +8  52mm','绿叶家族','Photo',3,12,'2011-09-10 01:19:22'),(100130,'绿叶近摄镜 +8  55mm','绿叶家族','Photo',0,12,'2011-05-30 02:20:54'),(100131,'绿叶近摄镜 +8  58mm','绿叶家族','Photo',0,14,'2011-09-04 05:08:12'),(100132,'绿叶近摄镜 +8  62mm','绿叶家族','Photo',1,14,'2011-09-24 09:02:32'),(100133,'绿叶近摄镜 +8  67mm','绿叶家族','Photo',0,17,'2011-07-28 19:54:23'),(100134,'绿叶近摄镜 +8  72mm','绿叶家族','Photo',0,17,'2011-07-25 02:03:17'),(100135,'绿叶近摄镜 +8  77mm','绿叶家族','Photo',0,20,'2011-08-19 01:17:06'),(100136,'天涯 cpl 52mm','小土豆','Photo',0,18,'2011-05-31 18:35:04'),(100137,'天涯 cpl 55mm','小土豆','Photo',2,20,'2011-07-03 19:30:57'),(100138,'天涯 cpl 58mm','小土豆','Photo',0,21,'2011-12-07 18:54:49'),(100139,'天涯 cpl 62mm','小土豆','Photo',0,25,'2011-06-22 06:51:33'),(100140,'天涯 cpl 67mm','小土豆','Photo',0,23,'0000-00-00 00:00:00'),(100141,'天涯 cpl 72mm','小土豆','Photo',1,25,'2011-08-22 19:40:39'),(100142,'天涯 cpl 77mm','小土豆','Photo',0,26,'0000-00-00 00:00:00'),(100143,'天涯 ND8 52mm','小土豆','Photo',1,20,'2012-03-16 21:18:32'),(100144,'天涯 ND8 55mm','小土豆','Photo',6,20,'0000-00-00 00:00:00'),(100145,'天涯 ND8 58mm','小土豆','Photo',7,24,'0000-00-00 00:00:00'),(100146,'天涯 ND8 62mm','小土豆','Photo',6,28,'2011-05-09 19:28:11'),(100147,'天涯 ND8 67mm','小土豆','Photo',0,28,'2011-10-19 20:20:40'),(100148,'天涯 ND8 72mm','小土豆','Photo',7,30,'2011-12-29 18:41:09'),(100149,'天涯 ND8 77mm','小土豆','Photo',-2,30,'2012-03-25 05:26:12'),(100150,'天涯uv 82mm','小土豆','Photo',6,28,'2011-06-06 19:03:50'),(100151,'方形滤镜接口环 49mm','严文君','Photo',37,3,'2012-03-18 09:26:55'),(100152,'方形滤镜接口环 52mm','严文君','Photo',28,3,'2012-03-18 09:26:55'),(100153,'方形滤镜接口环 55mm','严文君','Photo',25,3,'2012-03-18 09:26:55'),(100154,'方形滤镜接口环 58mm','严文君','Photo',28,3,'2012-03-24 01:54:28'),(100155,'方形滤镜接口环 62mm','严文君','Photo',45,3,'2012-03-24 01:55:27'),(100156,'方形滤镜接口环 67mm','严文君','Photo',36,3,'2012-03-19 21:30:21'),(100157,'方形滤镜接口环 72mm','严文君','Photo',41,3,'2012-03-18 09:26:55'),(100158,'方形滤镜接口环 77mm','严文君','Photo',47,3,'2012-03-25 04:58:38'),(100159,'方形滤镜接口环 82mm','严文君','Photo',14,3,'2012-03-22 01:47:58'),(100160,'方镜普通托架（三槽）','绿叶家族 严文君','Photo',71,3.5,'2012-03-25 04:58:38'),(100161,'方镜广角托架（ 一槽）','绿叶家族','Photo',66,6,'2012-03-22 21:38:30'),(100162,'天涯方形滤镜  渐变红','boss少','Photo',6,21,'2012-03-23 00:04:56'),(100163,'天涯方形滤镜  渐变橙','boss少','Photo',2,21,'2012-03-23 00:04:56'),(100164,'天涯方形滤镜  渐变黄','boss少','Photo',6,21,'2012-03-23 00:04:56'),(100165,'天涯方形滤镜  渐变绿','boss少','Photo',6,21,'2012-03-23 00:04:56'),(100166,'天涯方形滤镜  渐变蓝','boss少','Photo',3,21,'2012-03-23 00:04:56'),(100167,'天涯方形滤镜  渐变灰','boss少','Photo',8,21,'2012-03-23 00:04:56'),(100168,'天涯方形滤镜  渐变棕','boss少','Photo',5,21,'2012-03-23 00:04:56'),(100169,'天涯方形滤镜  ND2','boss少','Photo',10,21,'2012-03-23 00:04:56'),(100170,'天涯方形滤镜  ND4','boss少','Photo',11,21,'2012-03-23 00:04:56'),(100171,'天涯方形滤镜  ND8','boss少','Photo',12,21,'2012-03-23 00:04:56'),(100172,'天涯方形滤镜系列  星光镜  star4','boss少','Photo',0,28,'2011-05-02 07:50:57'),(100173,'天涯方形滤镜系列  星光镜  star6','boss少','Photo',9,28,'2012-03-16 21:13:58'),(100174,'天涯方形滤镜系列  星光镜  star8','boss少','Photo',5,28,'2012-03-20 19:29:35'),(100175,'天涯方形滤镜系列  CPL','boss少','Photo',5,58,'2012-03-24 01:12:05'),(100176,'天涯方形滤镜系列 10片装 盒子','boss少','Photo',10,10,'2012-03-23 00:04:56'),(100177,'3片装的滤镜袋','绿叶家族','Photo',9,6,'2012-03-24 01:56:09'),(100178,'4片装的滤镜袋','绿叶家族','Photo',22,6,'2012-03-20 19:41:16'),(100179,'6片装的滤镜袋','绿叶家族','Photo',27,9,'2012-03-24 01:26:10'),(100180,'橡胶遮光罩 52mm','严文君','Photo',45,4.8,'2012-03-21 19:28:53'),(100181,'橡胶遮光罩 55mm','严文君','Photo',42,5.6,'2012-03-22 19:17:22'),(100182,'橡胶遮光罩 58mm','严文君','Photo',26,5.8,'2012-03-25 06:21:17'),(100183,'橡胶遮光罩 62mm','严文君','Photo',34,6.6,'2012-03-25 06:21:40'),(100184,'橡胶遮光罩 67mm','严文君','Photo',27,6.8,'2012-03-25 06:26:48'),(100185,'橡胶遮光罩 72mm','严文君','Photo',27,7.6,'2012-03-18 19:19:01'),(100186,'橡胶遮光罩 77mm','严文君','Photo',46,7.8,'2012-03-21 03:58:07'),(100187,'ET-60','New','Photo',7,17,'0000-00-00 00:00:00'),(100188,'ET-65B','New','Photo',4,17,'2012-03-06 02:21:56'),(100189,'HB-7','New','Photo',2,17,'2011-06-13 01:14:54'),(100190,'EW-73II','New','Photo',0,17,'0000-00-00 00:00:00'),(100191,'EW-78D','New','Photo',50,17,'2012-03-24 01:16:56'),(100192,'EW-83E','New','Photo',0,17,'0000-00-00 00:00:00'),(100193,'绿叶EW-73B','New','Photo',4,17,'0000-00-00 00:00:00'),(100194,'EW-73B','小土豆','Photo',2,17,'2012-03-20 19:33:03'),(100195,'CANON 镜头盖  58mm','fengbinji2','Photo',42,5,'2012-03-22 19:39:17'),(100196,'CANON 镜头盖  67mm','fengbinji2','Photo',53,5,'2012-03-24 01:19:29'),(100197,'CANON 镜头盖  72mm','fengbinji2','Photo',28,5,'2012-03-24 01:19:04'),(100198,'CANON 镜头盖  77mm','fengbinji2','Photo',35,5,'2012-02-25 21:03:53'),(100199,'NIKON 镜头盖 52mm','fengbinji2','Photo',24,5,'2012-03-21 19:21:03'),(100200,'NIKON 镜头盖 62mm','fengbinji2','Photo',38,5,'2012-03-25 06:26:26'),(100201,'NIKON 镜头盖 67mm','fengbinji2','Photo',37,5,'2012-03-17 08:42:18'),(100202,'NIKON 镜头盖 72mm','fengbinji2','Photo',35,5,'2012-02-23 20:26:06'),(100203,'NIKON 镜头盖 77mm','fengbinji2','Photo',75,5,'2012-03-11 21:19:31'),(100204,'机身盖/镜头后盖  Nikon','fengbinji2','Photo',13,4,'2012-03-20 03:59:13'),(100205,'机身盖/镜头后盖  Canon','fengbinji2','Photo',14,4,'2012-01-30 21:23:50'),(100206,'lenspen','小土豆 肯高老汉','Photo',176,15.5,'2012-03-25 06:42:15'),(100207,'气吹 + 布','福盛','Photo',58,4,'2012-03-25 05:18:24'),(100208,'麂皮','河北','Photo',249,1,'2012-03-24 08:29:40'),(100209,'镜头布','一佳','Photo',0,1,'0000-00-00 00:00:00'),(100210,'防雨罩','陈云','Photo',0,23,'2012-03-03 01:19:38'),(100211,'防寒罩','陈云','Photo',6,42,'2012-03-21 19:28:15'),(100212,'眼罩 450D/500D','宇儿','Photo',30,10,'2012-03-24 01:15:55'),(100213,'眼罩 40D/50D','宇儿','Photo',18,10,'2012-02-27 19:03:52'),(100214,'眼罩 D300','宇儿','Photo',29,10,'2012-01-06 19:27:51'),(100215,'热靴保护盖  普通','宇儿','Photo',10,2,'2012-03-14 19:13:24'),(100216,'热靴保护盖  sony','宇儿','Photo',20,6,'2012-03-06 18:37:46'),(100217,'带水平仪 热靴保护盖','宇儿 绿叶家族','Photo',24,12,'2012-03-24 01:14:30'),(100218,'小号灰卡','zddpl','Photo',2,21,'2012-03-14 19:22:25'),(100219,'大号灰卡','zddpl','Photo',3,26,'2012-03-18 09:15:40'),(100220,'canon 反接环  52mm','严文君','Photo',13,6,'2012-03-22 19:07:57'),(100221,'canon 反接环  58mm ','严文君','Photo',29,6,'2012-03-24 01:16:13'),(100222,'pentax 反接环  52mm','严文君','Photo',5,6,'2012-03-24 01:21:22'),(100223,'nikon 反接环  52mm','严文君','Photo',25,6,'2012-03-07 00:38:19'),(100224,'52-52mm 双阳环','严文君','Photo',7,2.5,'2012-03-25 05:47:46'),(100225,'52-58mm 双阳环','严文君','Photo',12,2.5,'2012-03-19 19:19:49'),(100226,'58-58mm 双阳环','严文君','Photo',6,2.5,'2012-03-21 19:16:38'),(100227,'canon 电子触点','toobig1001','Photo',0,21,'2012-02-12 21:43:26'),(100228,'小号内胆包 无字','陈云','Photo',18,11,'2012-03-20 19:28:23'),(100229,'小号内胆包 Nikon','陈云','Photo',1,11,'2012-03-13 00:44:13'),(100230,'小号内胆包 canon ','陈云','Photo',6,11,'2012-03-24 01:45:01'),(100231,'中号内胆包 无字','陈云','Photo',21,11,'2012-03-22 21:37:04'),(100232,'中号内胆包 nikon','陈云','Photo',12,11,'2012-02-18 23:47:02'),(100233,'中号内胆包 canon ','陈云','Photo',28,11,'2012-03-04 18:54:47'),(100234,'大号内胆包 无字','陈云','Photo',19,11,'2012-03-24 01:13:53'),(100235,'大号内胆包 nikon','陈云','Photo',17,11,'2012-02-19 19:27:18'),(100236,'大号内胆包canon','陈云','Photo',10,11,'2012-03-18 23:55:51'),(100237,'新式内胆包小号','陈云','Photo',-2,22,'2012-03-18 22:08:59'),(100238,'镜头筒 小号','陈云 党部','Photo',23,6,'2012-03-19 04:19:52'),(100239,'镜头筒 中号','陈云 党部','Photo',7,6,'2012-03-25 06:20:18'),(100240,'镜头筒 大号','陈云 党部','Photo',33,6,'2012-03-04 19:17:49'),(100241,'镜头筒 xl 大号','陈云 党部','Photo',34,9,'2012-03-11 21:16:04'),(100242,'JJC 镜头筒 JN22','New','Photo',0,20.3,'2011-11-07 19:09:44'),(100243,'JJC 镜头筒 JN23','New','Photo',7,20.7,'0000-00-00 00:00:00'),(100244,'JJC 镜头筒 JN24','New','Photo',6,24.3,'2011-04-14 19:37:57'),(100245,'反光板 100*150 40*60 5合1','严文君','Photo',18,65,'2012-03-25 05:29:33'),(100246,'反光板  80cm 5合1','严文君','Photo',22,30,'2012-03-19 01:19:21'),(100247,'反光板 110cm 5合1','严文君','Photo',14,40,'2012-03-13 19:16:11'),(100248,'反光板 80cm 2合1','严文君','Photo',4,21,'2012-02-26 19:22:54'),(100249,'反光板 60cm 2合1','严文君','Photo',3,14,'2012-03-18 19:24:47'),(100250,'2mx1.5m 背景板（蓝，绿）','严文君 王晓','Photo',28,85,'2012-03-17 08:21:59'),(100251,'反光板支架','艺影','Photo',18,38,'2012-03-25 06:41:25'),(100252,'圆形柔光棚 40cm','dgs197012dgs 艺影','Photo',34,38,'2012-03-23 00:28:57'),(100253,'圆形柔光棚 50cm','dgs197012dgs 艺影','Photo',11,45,'2012-03-24 01:58:47'),(100254,'圆形柔光棚 60cm','dgs197012dgs 艺影','Photo',27,60,'2012-03-21 20:02:38'),(100255,'倒影板（白黑）','lruisen88','Photo',32,15,'2012-03-23 02:12:46'),(100256,'肩架','宇儿','Photo',34,46,'2012-03-08 19:30:19'),(100257,'三脚架  伟峰 WF-6662A','李东 李大君','Photo',4,120,'2012-03-22 22:36:56'),(100258,'伟峰 6662A 快装板','李东 李大君','Photo',15,15,'2012-03-14 22:34:21'),(100259,'三脚架 伟峰 WF-6663A ','李东 李大君','Photo',4,155,'2012-03-24 01:59:13'),(100260,'伟峰 6663A 快装板','李东 李大君','Photo',7,20,'2012-01-10 19:08:46'),(100261,'三脚架 伟峰 wf-6662A+ 6160H 球台','李东 李大君','Photo',11,140,'2012-03-08 23:46:29'),(100262,'三脚架 伟峰 WF-531','李东 李大君','Photo',0,140,'0000-00-00 00:00:00'),(100263,'三脚架 伟峰 WF-531B','李东 李大君','Photo',2,135,'2012-02-08 01:40:38'),(100264,'三脚架 伟峰 EI-717','李东 李大君','Photo',-1,580,'2012-03-25 05:17:34'),(100265,'三脚架 伟峰 EI-717  155','李东 李大君','Photo',5,590,'2012-02-08 19:01:44'),(100266,'三脚架 伟峰 EI-717  180','李东 李大君','Photo',5,640,'2012-01-29 06:20:53'),(100267,'球台 伟峰 WF-717AH','李东 李大君','Photo',-1,310,'2012-03-22 01:09:25'),(100268,'伟峰 717 快装板','李东 李大君','Photo',3,46,'2012-03-14 19:33:39'),(100269,'伟峰717 手柄','李东 李大君','Photo',5,50,'2012-03-24 08:30:12'),(100270,'独脚架  伟峰 WT-1003','李东 李大君','Photo',8,35,'2012-03-19 01:40:02'),(100271,'独脚架  伟峰 WT-1005','李东 李大君','Photo',9,50,'2012-03-04 18:55:05'),(100272,'独脚架  伟峰 WT-1007','李东 李大君','Photo',5,65,'2012-02-27 19:03:41'),(100273,'WT600','李东 李大君','Photo',0,130,'2012-03-17 08:20:33'),(100274,'WFC-592T + WF-570H','李东 李大君 zddpl','Photo',1,530,'2011-12-31 06:20:59'),(100275,'NIB EI7060AA','李东 李大君','Photo',0,1350,'0000-00-00 00:00:00'),(100276,'斜臂 ','艺影','Photo',-4,38,'2012-03-25 06:38:35'),(100277,'大力夹','名雅阁_精品 ','Photo',44,8.5,'2012-03-21 19:58:25'),(100278,'大力夹云台','名雅阁_精品 ','Photo',9,16,'2012-03-12 19:46:08'),(100279,'c型大力夹','名雅阁_精品 ','Photo',27,11,'2012-03-24 02:11:55'),(100280,'灯架  2m','凯琳','Photo',10,26,'2012-03-25 06:40:18'),(100281,'灯架 84cm','凯琳','Photo',0,20,'2012-03-18 23:00:06'),(100282,'灯架 38cm','凯琳','Photo',16,16,'2012-03-18 09:12:07'),(100283,'2m 弹簧灯架 ','王晓','Photo',5,28,'2012-03-24 01:32:13'),(100284,'2.8m 弹簧灯架 ','王晓','Photo',5,45,'2012-01-16 18:34:15'),(100285,'反光伞','王晓','Photo',67,10,'2012-03-25 06:27:14'),(100286,'柔光伞','王晓','Photo',52,7,'2012-03-25 06:40:18'),(100287,'闪光灯B座 ','艺影','Photo',28,15,'2012-03-25 06:40:18'),(100288,'闪光灯云台(配合灯架）','宇儿','Photo',45,20,'2012-03-19 19:37:24'),(100289,'桌面灯灯头','艺影','Photo',16,20,'2012-03-18 09:12:07'),(100290,'双灯头 ','艺影 凯琳','Photo',68,18,'2012-03-19 02:18:46'),(100291,'单灯头','艺影 凯琳','Photo',197,9,'2012-03-21 19:42:53'),(100292,'一转四 灯头','凯琳','Photo',46,18,'2012-03-24 01:21:56'),(100293,'柔光箱 50-70cm 单灯头','凯琳','Photo',58,38,'2012-03-25 06:38:35'),(100295,'4灯头 灯头 孔 ','艺影','Photo',86,30,'2012-03-25 05:35:53'),(100296,'50-70柔光棚 通用塑料卡口','王晓','Photo',34,40,'2012-03-19 02:30:34'),(100297,'50-70柔光棚 通用金属卡口','王晓','Photo',13,45,'2011-09-06 19:48:15'),(100299,'背景架2mx2m  + 3个夹子','凯琳','Photo',16,100,'2012-03-25 06:44:32'),(100302,'3m 伸缩横杆 ','王晓','Photo',3,80,'2012-02-13 21:49:14'),(100303,'背景布 1.6','大红门','Photo',-673,10,'2012-03-24 08:15:42'),(100304,'背景布 3x6 白色','王晓','Photo',-60,72,'2012-03-21 19:32:36'),(100305,'背景布 3x6 绿色','王晓','Photo',-36,72,'2012-03-24 01:20:13'),(100306,'背景布 3x6 黑色','王晓','Photo',0,72,'2012-01-23 20:53:01'),(100307,'45w 5500k 灯泡 220v','sarah021009','Photo',100,13,'2012-03-25 06:42:23'),(100308,'115w 5500k 灯泡  220v','凯琳','Photo',135,21,'2012-03-25 06:38:35'),(100309,'115w 5500k 灯泡  110v','凯琳','Photo',53,28,'2011-09-06 04:18:13'),(100310,'800w红头灯   ','王晓','Photo',6,85,'2012-03-22 19:25:04'),(100311,'800w 110v 灯泡 ','王晓','Photo',89,15,'2012-03-08 19:17:05'),(100312,'800w  220v 灯泡','王晓','Photo',74,12,'2012-03-22 19:25:04'),(100313,'sony 单肩包  A1   ','e格阁','Photo',-3,28,'2012-01-31 18:38:58'),(100314,'canon 单肩包 A1 ','e格阁','Photo',2,28,'2012-03-21 19:48:34'),(100315,'Nikon 单肩包  A1','e格阁','Photo',14,28,'2012-02-02 19:01:18'),(100316,'Canon 单肩包  D1','e格阁','Photo',11,27,'2012-02-21 03:01:03'),(100317,'Nikon 单肩包 D1','e格阁','Photo',5,27,'2012-01-01 22:36:57'),(100318,'Canon 单肩包 小包 D2','e格阁','Photo',-1,8,'2012-03-13 21:17:11'),(100319,'canon 三角包  D3','e格阁','Photo',2,13,'2012-03-02 05:51:03'),(100320,'Nikon 三角包  D3','e格阁','Photo',23,13,'2011-11-09 19:17:33'),(100321,'摄影背心 夏  XL','福盛','Photo',13,48,'2012-03-05 20:12:41'),(100322,'摄影背心 冬夏  L','福盛','Photo',7,58,'2011-11-27 01:29:54'),(100323,'摄影背心 冬夏 XL','福盛','Photo',3,58,'2012-02-04 02:41:19'),(100324,'摄影背心 Nikon 老款 大小无特别标注为 M','贝尔金club','Photo',15,80,'2012-03-11 20:15:56'),(100325,'摄影背心 Nikon  L','贝尔金club','Photo',11,80,'0000-00-00 00:00:00'),(100326,'摄影背心 Nikon  XL','贝尔金club','Photo',8,80,'0000-00-00 00:00:00'),(100327,'摄影背心 Nikon  XXL','贝尔金club','Photo',19,80,'0000-00-00 00:00:00'),(100328,'摄影背心 Nikon  XXXL','贝尔金club','Photo',9,80,'0000-00-00 00:00:00'),(100329,'摄影背心 Canon  老款 大小无特别标注为 M','贝尔金club','Photo',12,80,'2012-03-04 09:07:53'),(100330,'摄影背心 Canon  L','贝尔金club','Photo',16,80,'0000-00-00 00:00:00'),(100331,'摄影背心 Canon  XL','贝尔金club','Photo',11,80,'0000-00-00 00:00:00'),(100332,'摄影背心 Canon  XXL','贝尔金club','Photo',16,80,'0000-00-00 00:00:00'),(100333,'摄影背心 Canon  XXXL','贝尔金club','Photo',12,80,'0000-00-00 00:00:00'),(100334,'摄影背心 nikon 原厂（75th） 大小无特别标注为 L','福盛','Photo',6,90,'2012-03-05 18:17:21'),(100335,'摄影背心 Nikon 原厂 （75th） XL','福盛','Photo',18,90,'2011-06-26 06:19:57'),(100336,'尼康 90th 周年肩带  ','New','Photo',0,30,'2011-03-03 21:55:52'),(100337,'尼康 90th 周年镜头筒','New','Photo',-1,15,'2011-07-19 22:58:26'),(100338,'肩带 nikon ','陈云 党部','Photo',12,8,'2012-01-11 04:42:21'),(100339,'肩带 canon ','陈云 党部','Photo',3,8,'2012-03-21 19:41:50'),(100340,'肩带 pentax','陈云 党部','Photo',10,8,'2012-02-25 21:41:42'),(100341,'肩带 sony','陈云 党部','Photo',20,8,'2012-03-17 08:36:17'),(100342,'肩带 无字','陈云 党部','Photo',16,8,'2012-03-19 19:18:54'),(100343,'JJC 腕带  JJC-1','New','Photo',-1,18.8,'2011-04-05 08:00:15'),(100344,'JJC 腕带  JJC-2','New','Photo',1,30.5,'2012-02-09 01:36:12'),(100345,'JJC 腕带  JJC-3A','New','Photo',7,26,'2012-03-02 00:46:01'),(100346,'JJC 腕带  JJC-N ( 4)','New','Photo',0,36,'2011-06-23 07:53:50'),(100347,'灯架包  ','zl810910','Photo',-275,5,'2012-03-25 06:38:35'),(100348,'Canon D8 单肩包','福盛','Photo',-2,45,'2012-03-24 08:05:24'),(100349,'4螺丝井字扳手','荒凉西部','Photo',11,65,'2012-03-21 19:22:39'),(100350,'摄影背心 黑色厚 sony 大小无特别标注为 XL','哈喽豆豆','Photo',9,60,'2012-03-25 05:31:23'),(100351,'摄影背心 黑色厚 无字 大小无特别标注为XL','哈喽豆豆','Photo',0,60,'2012-03-25 06:25:31'),(100352,'摄影背心 黑色薄 canon 大小无特别标注为XL','哈喽豆豆','Photo',10,60,'2012-03-23 00:44:20'),(100353,'摄影背心 蓝色薄 canon 大小无特别标注为 XL','哈喽豆豆','Photo',1,60,'2011-05-26 17:01:31'),(100354,'摄影背心 蓝色薄 nikon 大小无特别标注为XL','哈喽豆豆','Photo',0,60,'2011-04-11 19:53:51'),(100355,'摄影背心 蓝色薄 无字大小无特别标注为 XL','哈喽豆豆','Photo',1,60,'2011-09-21 20:09:17'),(100356,'摄影背心 绿色薄 nikon 大小无特别标注为XL','哈喽豆豆','Photo',0,60,'2011-03-17 21:34:20'),(100357,'摄影背心 绿色薄 canon  大小无特别标注为XL','哈喽豆豆','Photo',0,60,'2011-11-01 00:15:59'),(100358,'摄影背心 红色薄 sony  大小无特别标注为XL','哈喽豆豆','Photo',3,60,'2011-07-24 04:20:02'),(100359,'摄影背心 红色薄 无字 大小无特别标注为 XL','哈喽豆豆','Photo',3,60,'0000-00-00 00:00:00'),(100360,'摄影背心 驼色厚 无字 大小无特别标注为 XL','哈喽豆豆','Photo',7,52,'2012-03-18 19:20:34'),(100361,'Sony 三角包  D3','e格阁','Photo',32,13,'2011-10-12 21:08:15'),(100362,'摄影包 单肩  nikon  N2','福盛','Photo',3,55,'0000-00-00 00:00:00'),(100363,'摄影包 单肩  canon  N2','福盛','Photo',2,55,'2011-07-24 03:49:23'),(100364,'摄影包 单肩  nikon  N4','福盛','Photo',0,75,'2011-09-25 20:01:47'),(100365,'摄影包 单肩  canon  N4','福盛','Photo',-1,75,'2011-09-04 20:38:04'),(100366,'摄影包 单肩  canon  D4','福盛','Photo',1,35,'0000-00-00 00:00:00'),(100367,'摄影包 单肩  nikon  M2','福盛','Photo',6,55,'0000-00-00 00:00:00'),(100368,'摄影包 单肩  canon  M2','福盛','Photo',0,55,'0000-00-00 00:00:00'),(100369,'摄影背心 黑色厚 sony XXL','哈喽豆豆','Photo',16,60,NULL),(100370,'摄影背心 黑色厚 sony XXXL','哈喽豆豆','Photo',11,60,NULL),(100371,'摄影背心 黑色厚 无字 XXL','哈喽豆豆','Photo',3,60,NULL),(100372,'摄影背心 黑色厚 无字 XXXL','哈喽豆豆','Photo',-1,60,NULL),(100373,'摄影背心 黑色薄 canon XXL','哈喽豆豆','Photo',0,60,NULL),(100374,'摄影背心 黑色薄 canon XXXL','哈喽豆豆','Photo',11,60,NULL),(100375,'摄影背心 蓝色薄 nikon XXL','哈喽豆豆','Photo',0,60,NULL),(100376,'摄影背心 蓝色薄 nikon XXXL','哈喽豆豆','Photo',0,60,NULL),(100377,'摄影背心 蓝色薄 无字 XXL','哈喽豆豆','Photo',0,55,NULL),(100378,'摄影背心 蓝色薄 无字 XXXL','哈喽豆豆','Photo',5,55,NULL),(100379,'摄影背心 绿色薄 nikon XXL','哈喽豆豆','Photo',0,60,NULL),(100380,'摄影背心 绿色薄 nikon XXXL','哈喽豆豆','Photo',1,60,NULL),(100381,'摄影背心 绿色薄 canon  XXL','哈喽豆豆','Photo',7,60,NULL),(100382,'摄影背心 绿色薄 canon  XXXL','哈喽豆豆','Photo',0,60,NULL),(100383,'摄影背心 红色薄 sony  XXL','哈喽豆豆','Photo',2,60,NULL),(100384,'摄影背心 红色薄 sony  XXXL','哈喽豆豆','Photo',4,60,NULL),(100385,'摄影背心 红色薄 无字 XXL','哈喽豆豆','Photo',3,60,NULL),(100386,'摄影背心 红色薄 无字 XXXL','哈喽豆豆','Photo',0,60,NULL),(100387,'摄影背心 驼色厚 无字 XXL','哈喽豆豆','Photo',8,52,NULL),(100388,'摄影背心 驼色厚 无字 XXXL','哈喽豆豆','Photo',13,52,NULL),(100389,'麦克风','topview2008','Photo',3,110,'2012-03-22 19:16:36'),(100390,'HB-7 花瓣','贝尔金club','Photo',10,31,'2012-03-24 01:50:13'),(100391,'摄影背心 夏  L ','福盛','Photo',3,48,'2012-03-05 18:32:10'),(100392,'2mx1.5m 背景板（黑，白） ','严文君 王晓','Photo',17,85,'2012-03-25 06:20:50'),(100393,'肩带 Q-strap 单','宇儿','Photo',0,48,'2011-07-14 04:18:52'),(100394,'肩带 Double-Q-strap 双','宇儿','Photo',12,88,'2012-03-22 00:25:24'),(100395,'内胆包无字加大 ','陈云 党部','Photo',0,11,'2011-08-20 05:25:06'),(100396,'永诺 nikon ttl 线  1m ','宇儿','Photo',5,60,'2012-02-08 19:05:13'),(100397,'新款内胆包 中号 无logo','陈云','Photo',22,30,'2011-07-10 02:05:42'),(100398,'新款内胆包 大号 canon logo','陈云 党部','Photo',23,33,'2012-03-18 09:09:56'),(100399,'Mini 红外  nikon ','宇儿 党部','Photo',-1,7,'2012-03-04 19:49:12'),(100400,'Mini 红外  canon ','宇儿 党部','Photo',0,7,'2012-02-08 02:36:55'),(100401,'Mini 红外  pentax ','宇儿 党部','Photo',5,7,'2012-02-18 23:53:35'),(100402,'Mini 红外  olympus ','宇儿 党部','Photo',7,7,'2012-03-14 22:14:27'),(100403,'yongnuo无线 YN159-C3 ','宇儿','Photo',1,60,'2012-03-04 09:46:31'),(100404,'yongnuo无线 YN159-E2 ','宇儿','Photo',10,60,NULL),(100405,'闪光灯D座 ','艺影','Photo',8,10,'2012-03-07 18:58:30'),(100406,'2螺丝井字扳手 ','荒凉西部','Photo',21,93,'2012-02-12 03:49:34'),(100407,'力飞单灯头棚 ','王晓','Photo',0,60,'2011-08-24 19:48:40'),(100408,'柔光伞110cm ','王晓','Photo',27,16,'2012-03-19 03:21:06'),(100409,'反光伞110cm ','王晓','Photo',14,16,'2012-03-24 02:07:17'),(100410,'反光伞棚90cm ','王晓','Photo',0,50,'2011-10-03 22:20:22'),(100411,'灯架包厚 ','天通苑',NULL,27,31,'2012-03-24 08:16:29'),(100412,'灯架包薄 ','凯琳','Photo',22,5,'2012-03-25 06:27:14'),(100413,'快摄手II 单 ','宇儿','Photo',1,45,NULL),(100414,'百诺三脚架A1691TB0 ','李东','Photo',2,730,'2011-11-20 01:31:26'),(100415,'曼比利 MBL-306 ','李东 宇儿','Photo',0,140,'2012-03-13 19:54:59'),(100416,'45w 5500k 灯泡 110v ','sarah021009','Photo',104,17,'2012-02-22 19:39:14'),(100423,'60x90cm 通用卡口柔光箱 ','王晓','Photo',5,65,'2012-03-18 08:40:34'),(100424,'70x100cm通用卡口柔光箱 ','王晓','Photo',5,70,'2012-03-15 19:16:18'),(100425,'可调ND镜 67mm ','绿叶家族','Photo',5,80,NULL),(100426,'可调ND镜 77mm ','绿叶家族','Photo',1,95,'2012-03-14 19:50:15'),(100417,'摄影背心（河北，厚）canon xl ','哈喽豆豆','Photo',19,55,'2012-03-12 19:59:38'),(100418,'摄影背心（河北，厚）canon xxl ','哈喽豆豆','Photo',19,55,NULL),(100419,'摄影背心（河北，厚）canon xxxl ','哈喽豆豆','Photo',18,55,NULL),(100420,'摄影背心（河北，厚）nikon xl ','哈喽豆豆','Photo',13,55,'2012-03-21 19:44:02'),(100421,'摄影背心（河北，厚）nikon xxl ','哈喽豆豆','Photo',16,55,NULL),(100422,'摄影背心（河北，厚）nikon xxxl ','哈喽豆豆','Photo',28,55,NULL),(100427,'Nikon 原厂背心（非75th）（黑色）M ','哈喽豆豆','Photo',34,60,NULL),(100428,'Nikon 原厂背心（非75th）（黑色）L','哈喽豆豆','Photo',22,60,NULL),(100431,'新款15kg大力夹 ','王晓','Photo',3,40,'2012-03-24 08:22:01'),(100429,'永诺无线 YN159-N1 ','宇儿','Photo',5,60,'2012-02-12 06:48:56'),(100430,'手动升降背景架 ','王晓','Photo',8,125,'2012-03-22 19:40:24'),(100432,'利帅LED系列 312AS ','New','Photo',1,750,'2012-03-15 19:35:31'),(100433,'利帅LED系列 312A ','王晓','Photo',3,700,'2011-10-12 20:50:46'),(100434,'利帅LED系列 144AS ','王晓','Photo',0,450,NULL),(100435,'利帅LED系列144A ','王晓','Photo',0,400,NULL),(100436,'力飞 影视闪光灯 lf160w ','王晓','Photo',2,170,NULL),(100437,'力飞 影视闪光灯 lf200w ','王晓','Photo',10,190,'2012-03-11 19:47:43'),(100438,'利帅 影视闪光灯 D200w ','王晓','Photo',3,280,NULL),(100441,'canon 原厂背心 ','New','Photo',-14,NULL,'2012-01-31 20:12:23'),(100442,'nikon 原厂摄影背心 网眼 M ','New','Photo',0,78,'2012-03-20 19:25:10'),(100443,'nikon 原厂摄影背心 网眼 L','New','Photo',5,70,'2012-03-06 18:40:43'),(100444,'nikon 原厂摄影背心 网眼 XL','New','Photo',-1,70,'2012-03-06 18:41:06'),(100445,'新款内胆包 中号 canon logo ','陈云 党部','Photo',-14,30,'2012-03-25 06:26:43'),(100446,'Nikon D8 单肩包 ','福盛','Photo',3,45,'2012-03-07 18:50:08'),(100447,'红边套装包  ','王晓','Photo',31,60,'2012-03-25 05:23:52'),(100448,'拉杆箱 ','王晓','Photo',0,170,'2011-10-02 20:16:47'),(100449,'蜂窝 ','王晓','Photo',3,45,'2012-03-14 19:18:07'),(100439,'85cm 两用伞 ','王晓','王晓',10,35,'2012-03-19 19:32:47'),(100440,'110cm 两用伞 ','New','王晓',17,45,'2012-03-04 09:38:17'),(100450,'铝合金灯座（N） ','艺影','Photo',7,30,'2012-03-18 19:14:03'),(100451,'沙袋（大） ','王晓','Photo',-6,16,'2012-03-24 01:18:05'),(100452,'沙袋（普通） ','艺影','Photo',2,3,'2012-03-24 02:06:29'),(100453,'无牌方镜 渐变灰 （nd4） ','严文君','Photo',11,8,'2012-03-24 01:26:10'),(100454,'无牌方镜 渐变灰 （nd8） ','严文君','Photo',-5,8,'2012-03-25 05:27:16'),(100455,'无牌方镜 渐变蓝 ','严文君','p',7,8,'2012-03-24 01:26:10'),(100456,'无牌方镜 渐变橙 ','严文君','Photo',27,8,'2012-03-24 01:26:02'),(100457,'无牌方镜 渐变日落 ','严文君','Photo',21,8,'2012-03-22 20:41:32'),(100458,'无牌方镜 渐变棕 ','严文君','Photo',32,8,'2012-03-11 21:24:16'),(100459,'无牌方镜 渐变红 ','严文君','Photo',36,8,'2012-01-30 04:21:41'),(100460,'无牌方镜 ND2 ','严文君','Photo',31,8,'2012-03-24 01:56:09'),(100461,'无牌方镜 ND4 ','严文君','Photo',24,8,'2012-03-24 01:56:09'),(100462,'无牌方镜 ND8 ','严文君','Photo',15,8,'2012-03-24 01:56:09'),(100463,'透明10片装盒 ','严文君','Photo',2,8,'2012-02-18 22:43:29'),(100465,'新款大力夹（手柄） ','王晓','Photo',2,55,'2012-03-19 19:22:31'),(100470,'vasqueVE400背包 ','摄影包专柜','Photo',3,320,NULL),(100466,'新款内胆包 S  Nikon  ','党部','Photo',22,15,'2012-03-25 06:24:20'),(100467,'新款内胆包 M  Nikon  ','党部','Photo',29,17,'2012-03-20 19:49:44'),(100468,'新款内胆包 L  Nikon  ','党部','Photo',24,24,'2012-03-24 08:06:23'),(100469,'新款内胆包 XL  Nikon  ','党部','Photo',13,27,'2012-02-29 19:14:21'),(100472,'永诺无线 YN159-N3 ','宇儿','Photo',3,58,'2012-03-07 02:47:45'),(100475,'牛津布大包 ','艺影','Photo',3,24,'2012-03-24 08:07:24'),(100473,'反光板支架的夹子（双轮） ','艺影','Photo',28,10,'2012-03-21 19:36:41'),(100474,'斜臂的夹子（单轮） ','艺影','Photo',11,10,'2012-03-17 07:15:56'),(100476,'影室灯AC引闪器 ','王晓 宇儿 ','Photo',11,58,'2011-12-09 02:23:50'),(100464,'红头灯5m电源延长线 ','王晓','Photo',14,20,'2012-03-15 22:06:16'),(100477,'150-200cm 5in1 反光板 ','严文君','Photo',5,95,'2012-03-24 08:22:06'),(100479,'3m 横杆（通用4节） ','艺影 ','photo',72,45,'2012-03-25 05:28:17'),(100480,'观鸟云台 ','数码小情迷 ','photo',4,265,'2012-03-19 19:21:22'),(100481,'ks-0 II （绿盒）','数码小情迷 ','photo',39,75,'2012-03-25 05:48:17'),(100482,'ks-0 III (白盒）','数码小情迷 ','photo',-6,98,'2012-03-25 06:47:44'),(100483,'DSLR-Rig ','zddpl','photo',6,190,'2012-03-25 06:40:09'),(100484,'帽子 canon ','jinyuanlau ','photo',37,25,'2012-03-15 19:43:44'),(100485,'帽子 nikon ','jinyuanlau ','photo',23,18,'2012-03-23 00:44:46'),(100486,'5灯头+60-90棚 ','凯琳 ','photo',46,93,'2012-03-21 20:51:26'),(100487,'O型闪光灯支架 ','艺影 ','photo ',20,36,'2012-02-23 03:00:02'),(100488,'C型闪光灯支架 ','艺影 ','photo ',11,22,'2011-12-14 17:56:11'),(100489,'魔术手臂7寸 ','数码小情迷 lijing10231223 ','photo',11,90,'2012-01-10 01:13:19'),(100490,'魔术手臂11寸 ','数码小情迷 lijing10231223 ','photo',16,100,'2012-03-01 18:42:37'),(100491,'伟峰6714 ','李大君 ','photo',-3,140,'2012-03-13 21:49:36'),(100492,'伟峰6614A ','李大君','photo',0,320,'2011-12-24 21:24:19'),(100493,'50cmx70cm 的柔光箱 (配4灯头）','艺影','photo',24,25,'2012-03-25 05:35:53'),(100494,'60cmx60cm 的柔光箱（配4灯头） ','艺影 ','photo',85,25,'2012-03-21 23:59:43'),(100498,'PU单肩包  黑色  nikon ','陈云','Photo',3,75,'2012-02-26 18:49:34'),(100496,'伞式柔光箱 80cm 8角  ','王晓','photo',32,95,'2012-03-24 08:07:51'),(100497,'伞式柔光箱 60×90cm ','王晓','photo',90,95,'2012-03-25 05:27:57'),(100499,'PU单肩包  棕色  canon ','陈云','photo',1,75,'2011-12-17 17:18:44'),(100500,'2mx1.5m 白色背景板 ','严文君 ','photo',28,65,'2012-03-15 19:11:09'),(100501,'井字扳手 可换头 ','荒凉西部 ','photo',14,72,'2012-03-25 06:27:32'),(100502,'伟峰三脚架WTC6624 ','李大君','photo',1,660,NULL),(100503,'伟峰三脚架WF676 ','李大君','photo',1,300,NULL),(100504,'伟峰三脚架WF673 ','李大君','photo',1,310,NULL),(100505,'GOTO肩带HB2F ','绿叶家族','Photo',1,12,NULL),(100506,'GOTO肩带HB4F ','绿叶家族','Photo',1,12,NULL),(100507,'GOTO肩带HB6F ','绿叶家族','Photo',1,12,NULL),(100508,'GOTO肩带HB7F ','绿叶家族','Photo',1,12,NULL),(100509,'GOTO肩带HB10F ','绿叶家族','Photo',1,12,NULL),(100510,'GOTO肩带HB11F ','绿叶家族','Photo',1,12,NULL),(100511,'GOTO肩带HB12F ','绿叶家族','Photo',1,12,NULL),(100512,'GOTO肩带LZ001 ','绿叶家族','Photo',1,12,NULL),(100513,'GOTO肩带LZ002 ','绿叶家族','Photo',1,12,NULL),(100514,'GOTO肩带LZ004 ','绿叶家族','Photo',1,12,NULL),(100515,'吸盘 ','李东','Photo',1,180,NULL),(100516,'lif通用柔光罩L ','王晓','Photo',0,NULL,'2012-02-12 04:13:29'),(100517,'lif通用柔光罩XL ','王晓','Photo',8,NULL,'2012-03-07 19:47:35'),(100518,'lif闪光灯套装 ','王晓','Photo',1,NULL,NULL),(100519,'新款50cm闪光灯柔光箱 ','王晓','Photo',0,100,'2011-12-10 07:11:20'),(100520,'新款内胆包 S  Canon  ','陈云','Photo',16,13,'2012-03-08 19:48:00'),(100521,'新款内胆包 XL  Canon   ','陈云','Photo',6,22,'2012-03-04 20:36:50'),(100522,'PU单肩包  黑色  canon ','陈云 ','Photo',1,75,'2012-02-23 19:17:48'),(100523,'2.5m高灯架','凯琳','photo',60,35,'2012-03-23 00:04:25'),(100524,'无牌方镜 渐变灰 （nd2）','严文君','Photo',21,8,'2012-03-17 07:24:12'),(100525,'mini lenspen','new','小土豆',19,14,'2012-03-24 01:46:56'),(100526,'夹车窗云台','new','mymr',5,75,NULL),(100527,'迷彩版内胆包小号','new','党部',20,15,NULL),(100528,'迷彩版内胆包中号','new','党部',20,16,NULL),(100529,'大力夹（铁头）','new','petercxl2009',20,7,NULL),(100530,'折叠反光伞','new','王晓',1,45,NULL),(100531,'折叠柔光伞','new','王晓',1,35,NULL),(100532,'加大内胆包 nikon','new','党部',10,13,NULL),(100533,'加大内胆包 canon','new','党部',9,13,'2012-03-24 01:48:15'),(100534,'新款内胆包 XXL  Nikon ','new','党部',10,32,NULL),(100535,'新款内胆包 XXL  Canon','new','党部',10,32,NULL);
/*!40000 ALTER TABLE `hmsh_ebay_stock` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_stock_in`
--

DROP TABLE IF EXISTS `hmsh_ebay_stock_in`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_stock_in` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `item_id` bigint(20) NOT NULL,
  `item_price` double DEFAULT NULL,
  `order_date` datetime DEFAULT NULL,
  `order_quantity` int(8) DEFAULT NULL,
  `order_arrive_date` datetime DEFAULT NULL,
  `order_arrive_quantity` int(8) DEFAULT NULL,
  `order_type` tinyint(4) NOT NULL,
  `relation_id` int(8) DEFAULT NULL,
  `description` varchar(2048) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_stock_in`
--

LOCK TABLES `hmsh_ebay_stock_in` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_stock_in` DISABLE KEYS */;
/*!40000 ALTER TABLE `hmsh_ebay_stock_in` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_supplier`
--

DROP TABLE IF EXISTS `hmsh_ebay_supplier`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_supplier` (
  `id` int(8) NOT NULL,
  `name` varchar(256) NOT NULL,
  `address` varchar(1024) DEFAULT NULL,
  `email` varchar(256) DEFAULT NULL,
  `phone` varchar(256) DEFAULT NULL,
  `type` tinyint(4) DEFAULT NULL,
  `description` varchar(1024) DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_supplier`
--

LOCK TABLES `hmsh_ebay_supplier` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_supplier` DISABLE KEYS */;
/*!40000 ALTER TABLE `hmsh_ebay_supplier` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `hmsh_ebay_transaction`
--

DROP TABLE IF EXISTS `hmsh_ebay_transaction`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `hmsh_ebay_transaction` (
  `id` int(8) NOT NULL AUTO_INCREMENT,
  `transaction_ID` bigint(20) NOT NULL,
  `ebay_itemID` bigint(20) NOT NULL,
  `ebay_itemTitle` varchar(2048) DEFAULT NULL,
  `quantity` tinyint(4) DEFAULT NULL,
  `hmsh_sku` varchar(255) DEFAULT NULL,
  `amountPaid` double DEFAULT NULL,
  `ebay_sellerID` varchar(255) DEFAULT NULL,
  `ebay_buyerID` varchar(255) DEFAULT NULL,
  `ebay_buyerEmail` varchar(255) DEFAULT NULL,
  `shipping_name` varchar(255) DEFAULT NULL,
  `shipping_street` varchar(1024) DEFAULT NULL,
  `shipping_city` varchar(255) DEFAULT NULL,
  `shipping_state` varchar(255) DEFAULT NULL,
  `shipping_country` varchar(255) DEFAULT NULL,
  `shipping_zip` varchar(255) DEFAULT NULL,
  `shipping_phone` varchar(255) DEFAULT NULL,
  `ebaypaymentstatus` varchar(255) DEFAULT NULL,
  `checkoutstatus` varchar(255) DEFAULT NULL,
  `shippingservice` varchar(255) DEFAULT NULL,
  `paid_time` datetime DEFAULT NULL,
  `shippingstatus` tinyint(4) DEFAULT '0',
  `shipping_time` datetime DEFAULT NULL,
  `item_status` tinyint(4) NOT NULL DEFAULT '0',
  `stock_status` tinyint(4) NOT NULL DEFAULT '0',
  `shipping_method` tinyint(4) NOT NULL DEFAULT '0',
  `if_printed` tinyint(2) NOT NULL DEFAULT '0',
  `tracking_id` varchar(256) DEFAULT NULL,
  `notes` varchar(2048) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `ebayDuplicate` (`transaction_ID`,`ebay_itemID`,`ebaypaymentstatus`)
) ENGINE=MyISAM AUTO_INCREMENT=26669 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `hmsh_ebay_transaction`
--

LOCK TABLES `hmsh_ebay_transaction` WRITE;
/*!40000 ALTER TABLE `hmsh_ebay_transaction` DISABLE KEYS */;
INSERT INTO `hmsh_ebay_transaction` VALUES (1926,637157497002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','vinnieherrera','vinicius_ferreira@hotmail.com','Vinicius Ferreira','Rua Marlo da Costa e Souza, 135 - apt. 707 Apple - Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22790735','55 21 99287253','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 09:14:57',0,NULL,3,1,3,1,NULL,'RR723016250CN '),(1924,598439047001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',12.99,'hermeshine','f_madika','liga.lysa@gmail.com','Fransisko Madika','Mulia Group, Wisma Mulia 53rd Floor<br>Jl. Jend. Gatot Subroto No. 42','Jakarta Selatan','DKI Jakarta','INDONESIA','12710','(62) 817-0876037','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:44:32',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1 \r234gï¼Ÿ'),(1923,598435381001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jub13071','jub130@mail.ru','Vadim Pastukhov','Botanicheskaya 22-18','Krasnoyarsk','Russia','RUSSIAN FEDERATION','660030','+7 913 8359749','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:24:03',0,NULL,3,1,2,1,NULL,''),(1922,598434643001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','riendi','chochon@gmail.com','Marylise Devoyault','1066 Rang 1 Ouest','Sainte-Christine','QC','CANADA','J0H 1H0','(819) 858-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 07:15:37',0,NULL,3,1,2,1,NULL,NULL),(1921,598413681001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','ezra.bay','ezra_nj@hotmail.com','Ezra Ganesh','2747 Hooper Ave<br>Apt 13-16','Brick','NJ','UNITED STATES','08723','(732) 556-7329','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 04:51:19',0,NULL,3,1,1,1,NULL,' '),(1920,598409228001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','bobduhrke','bobduhrke@hotmail.com','Robert Duhrke','1240 W 139th St','Gardena','CA','UNITED STATES','90247-2210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 04:23:51',0,NULL,3,1,1,1,NULL,' '),(1581,595151970001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','antonioruizg','antrg2@yahoo.es','Antonio Ruiz Galayo','Plaza 8 de Septiembre nÂº 15, 3Âº F','CÃ¡ceres','Extremadura','SPAIN','10003','649110209','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 09:00:49',0,NULL,3,1,4,1,NULL,'è¿™æ˜¯æµ‹è¯•æ•°æ®æœ€åŽä¸€ç¥¨ï¼Œä¹‹åŽæ­£å¼è¯•ç”¨'),(1582,633710294002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','enriched92','libra-oha@hotmail.com','Hong An Ong','Boon Lay Drive Blk 268a #13-584','default','Boon Lay Drive','SINGAPORE','641268','+65- 96753274','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 09:42:59',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–ä¸€ RR658661499CN'),(1584,633729440002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','snep1968','frankjoansierra@gmail.com','NÃºria Llorca Altirriba','Calle Mayor, 67 3Âº 2Âª','Castelldefels','Barcelona','SPAIN','08860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 11:04:41',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶  1 \rYW863686686CN'),(1585,633759619002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kripstian','dominguez752@hotmail.com','Cristian Dominguez rein-loring','Alameda Urquijo 102 1Âº puerta 6','Bilbao','PaÃ­s Vasco','SPAIN','48013','663532984','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 13:02:01',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶ 1\rbåº§   1\ræŸ”å…‰ä¼ž  1\rRR658661511CN'),(1586,595212958001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','renef180','renefraioli@ntlworld.com','Rene Fraioli','5 Oakhill ave<br>Mount Vernon','Glasgow','Glasgow (City of)','UNITED KINGDOM','G69 7ES','01415737779','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-18 13:19:42',0,NULL,5,1,2,1,NULL,' '),(1587,595236708001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','lassekamppari','lasse.kamppari@gmail.com','Lasse Kamppari','Raisiontie 11 A 1','Helsinki','','FINLAND','00280','358405231721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 14:32:03',0,NULL,3,1,2,1,NULL,'é˜²å¯’ç½©  1 '),(1588,595238195001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','mystifire1960','kurtmitstifer@yahoo.com','Kurt Mitstifer','1020 Raintree Dr','Palm Beach Gardens','FL','UNITED STATES','33410-5247','(561) 236-1402','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 14:37:17',0,NULL,3,1,1,1,NULL,' '),(1589,595246330001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','erjotola','erik@erikogtove.dk','Erik Johansen','Store Kongensgade 27, 4. tv','Copenhagen K','','DENMARK','1264','(45)33935610','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 15:03:25',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1 \rYW863686664CN'),(1590,595263608001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','nsch8980','noahschu@msn.com','noah schumacher','114 Old Homestead Hwy','North Swanzey','NH','UNITED STATES','03431-4436','(860) 912-3729','NoPaymentFailure','CheckoutComplete','Other','2010-11-18 15:55:31',0,NULL,3,1,4,1,NULL,' YW863686675CN'),(1591,595275286001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','steven40','steven40@aol.com','Steven Sweringen','1220 E Greg St<br>Ste 15','Sparks','NV','UNITED STATES','89431','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 16:28:02',0,NULL,3,1,1,1,NULL,'2 x 52mm Nikon caps\r4 x  58mm Canon caps\r2 x  72mm Canon caps\r2 x 72mm Nikon caps\r161g\r\rSteve Sweringen\rCamera Clinic\r1220 E Greg Street #15\rSparks, NV 89431\r877-511-4811 \r'),(1592,595281792001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','tystange','info@ty-stange.dk','Ty Stange','16tyve, Vesterbrogade 80b, 4. sal','Kbh, V','','DENMARK','1620','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 16:54:42',0,NULL,3,1,3,1,NULL,' RR658661471CN'),(1593,595319666001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','jevgsvet','jevg88@msn.com','Jevgenia Tsikulenko','Tamme pst. 82a-3','Tartu','Tartumaa','ESTONIA','50416','58176426','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 18:15:44',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1\rNG128   1   \r\r335g\rRR658662389CN'),(1594,633880871002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','commandosexy','commandosexies@yahoo.com','Rattanachote Leeyanumas','12/18 Soonvijai 6, New Petchburi Road<br>Bangkapi, Huay Khwang','Bangkok','Bangkok','THAILAND','10310','66819250239','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 18:27:35',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 RR658661485CN'),(1595,633886461002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','samantha_jeff86','samantha_jeff86@yahoo.com','Samantha Jackson','PO Box 2014','Caseville','MI','UNITED STATES','48725-2014','(989) 551-8913','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 18:38:00',0,NULL,3,1,1,1,NULL,' '),(1596,594946171001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',384,'hermeshine','diepstra123','cdiepstra@tersteege.eu','Chris Diepstra','Brugakker 35-01','Zeist','','NETHERLANDS','3704LJ','030-6971545','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 19:29:41',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ ï¼‰ 1\r2m ç¯æž¶   2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\råŒ…    1\rç”³æŠ¥ lighting kit $25\rYW863686701CN\r'),(1597,633954701002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','var8_metal','var.photographer@gmail.com','Photoworld di Bonato Simone','verga 1<br>CC Ipercity','albignasego','PD','ITALY','35020','+393497072977','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 20:45:07',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(1598,595393975001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-18 20:58:08',0,NULL,3,1,11,1,NULL,' '),(1599,595176222001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','chrholoul','christopheroulie@gmail.com','Chris Oulie','Stubberudveien 3','GrÃ¥lum','','NORWAY','1712','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 21:09:29',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658661468CN'),(1600,595411752001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','laiiane2010','mineirinha_portuga@hotmail.com','laiane pereira','1263 north ave','bridgeport','CT','UNITED STATES','06604-2717','(203) 209-4906','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-18 21:22:41',0,NULL,3,1,3,1,NULL,' RR658661556CN'),(1601,633989948002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','guerrillero_spa','karekanopam7@gmail.com','PABLO MARTÃN AGUILAR','C/ LAS BOTIJAS , BLOQUE 5, 2Âº IZQUIERDA.<br>DOS HERMANAS','SEVILLA','AndalucÃ­a Ceuta y Melilla','SPAIN','41700','636372318','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-18 22:00:39',0,NULL,3,1,4,1,NULL,'6662a   1 \r\rç”³æŠ¥ tripod  $15\rYW863686712CN\r'),(1602,595282528001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',14.59,'hermeshine','kamalsanghera','kamal.sanghera@gmail.com','Kamal Sanghera','# 8925<br>135A St.','Surrey','BC','CANADA','V3V 5V2','(778) 994-1094','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 00:15:48',0,NULL,3,1,2,1,NULL,' å°å·ç°å¡  1\rLenspen  1'),(1603,595489134001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','isidoro654','doroelviss@hotmail.com','isidoro gonzalez rodriguez','plaza fuente del cantaro NÂº1-2 ATICO A','salamanca','Castilla y LeÃ³n','SPAIN','37008','630778739','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 01:26:42',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl  1 \rRR658661542CN'),(1604,634061039002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','admir.b','champ071@hotmail.com','admir begovic','Grbavicka 40','Sarajevo','ba','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 01:45:10',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR658661525CN'),(1605,631601984002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','repiolariel','ariel_in@hotmail.com','Ariel Butron Blanco','Correos de Bolivia. La Paz. Casilla 1583','La Paz','La Paz','BOLIVIA','591','(591)70560522','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:22:15',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rb åº§   1\ræŸ”å…‰ä¼ž   1RR658661600CN '),(1606,634070911002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','toppukuma','top_the_white@yahoo.com','Chatiwat Lerdvongveerachai','23 Soi Sunthornpimol  Jarumuang Road<br>Rongmuang','Patumwan','Bangkok','THAILAND','10330','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:23:54',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rb åº§   1\ræŸ”å…‰ä¼ž   1 RR658661595CN'),(1607,595503637001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','damoja','danmjacobs@pol.net','daniel jacobs','319 S Riverside Dr','pompano beach','FL','UNITED STATES','33062','(954) 633-4079','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 02:25:34',0,NULL,3,1,1,1,NULL,' '),(1608,595503807001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','andrew_liem','dj_drex@hotmail.com','Andrew Liem','9 Yolanda Place','Brampton','ON','CANADA','l7a3n5','(647) 294-6050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 02:26:09',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR658661539CN'),(1610,634073228002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','nancyhumphrey','cndiamk@hotmail.com','Nancy Humphrey','102 Centre Street<br>P.O. Box 117','Vulcan','AB','CANADA','T0L 2B0','(403) 485-3116','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 02:28:47',0,NULL,3,1,2,1,NULL,' '),(1611,634103906002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','awemedia','olaf@vigilante-studios.com','Olaf Skjenna','127 Wexford Road<br>Miramar','Wellington','Wellington','NEW ZEALAND','6022','04 974-7055','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 04:40:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \rRR658661627CN'),(1612,595540217001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',80,'hermeshine','polognus','wencepili@yahoo.fr','Wenceslas PILIPCZUK','14 rue de vandelicourt','MARQUEGLISE','Picardie','FRANCE','60490','0344428807','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 05:33:05',0,NULL,3,1,4,1,NULL,'tripod $20\rYW863686690CN'),(1613,595549792001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','bigjamg','pjensen79@sbcglobal.net','Edson Hong','17305 Esperanza','Irvine','CA','UNITED STATES','92618','(949) 378-8015','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 06:38:26',0,NULL,3,1,1,1,NULL,'52mm-58mm åŒé˜³çŽ¯  1 '),(1614,595564947001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','racerjin22','racerjin22@hotmail.com','HYOJIN LEE','5699 Fullerton Ave<br>Apt 21','BUENA PARK','CA','UNITED STATES','90621-1968','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 08:13:09',0,NULL,3,1,1,1,NULL,'å“èƒœ  3.0 è†œ  1 '),(1615,633272317002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',57.7,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 09:10:00',0,NULL,3,1,3,1,NULL,'RR658661613CN'),(1616,595594538001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','nielsremigius','niels.remigius@upcmail.nl','Paul Remigius','Krijn van den Helmstraat 33','Leeuwarden','','NETHERLANDS','8923 CL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 10:32:53',0,NULL,3,1,2,1,NULL,''),(1617,595569373001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',24.2,'hermeshine','jumping_bean77','kimmy@internode.on.net','Rob Wilder','82 Sierra Drive<br>North Tamborine','Gold Coast','Queensland','AUSTRALIA','4272','0755452605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-19 11:15:01',0,NULL,3,1,3,1,NULL,'WF-1007 ç‹¬è„šæž¶   1 \r\r842g\rRR658662185CN'),(1618,634186527002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','jerwinpuzon','jerwinpuzon@yahoo.com','Jeoffrey Erwin Puzon','44 Laurel St.','Baguio City','none','PHILIPPINES','2600','9156000086','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 11:45:31',0,NULL,3,1,2,1,NULL,' '),(1620,634190456002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','faro_marin','marin@bulat.ro','marin bulat','G. Alexandrescu 11<br>ap 43','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2008','037379480728','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 11:59:08',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2\råŽé¢æœ‰ä¹°äº†ä¸€ä¸ªï¼Œåˆåœ¨ä¸€èµ·å‘'),(1621,634216231002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','brookerafaly','bvr6u@uvawise.edu','Brooke Rafaly','356 Union Mills Rd','Troy','VA','UNITED STATES','22974-3804','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 13:28:52',0,NULL,3,1,1,1,NULL,'canon æ‘„å½±èƒŒå¿ƒ  M  1 '),(1622,634217000002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','faro_marin','marin@bulat.ro','marin bulat','G. Alexandrescu 11<br>ap 43','Chisinau','Chisinau','MOLDOVA, REPUBLIC OF','2008','037379480728','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 13:30:25',0,NULL,5,1,18,0,NULL,' '),(1623,595649165001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','ocoeemom77','livsmom1@bellsouth.net','Integrity Web Development','935 Cloudview Place NE','Cleveland','TN','UNITED STATES','37312','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 13:56:01',0,NULL,3,1,1,1,NULL,' '),(1624,595677552001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','alberto1817','vengadorjust@hotmail.com','alberto sells moreno','POLÃGON INDUSTRIAL VILABLAREIX. C/ GÃœELL, 48. 17180 VILABLAREIX','girona','CataluÃ±a','SPAIN','17005','635696959','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 15:26:59',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143016CN\r '),(1625,595694146001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','colorsdclown','ctwells7@embarqmail.com','Tim Wells','1981 County Road 4','Ashley','IN','UNITED STATES','46705-9734','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 16:14:57',0,NULL,3,1,1,1,NULL,'å°¼åº·æ‘„å½±èƒŒå¿ƒ  M   1 \r656g\r'),(1626,634289011002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','dreamwalker90','crazy_edvin@hotmail.com','Edvin Kalic','Zeljeznicka b.b.','Sanski Most','','BOSNIA AND HERZEGOVINA','79260','+38761754086','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 16:54:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 '),(1627,595728689001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','mentepoluida','rodrigosantiago2005@gmail.com','Luis Bernardo','83 country way','Dartmouth','MA','UNITED STATES','02748-1229','','NoPaymentFailure','CheckoutComplete','Other','2010-11-19 17:38:15',0,NULL,3,1,3,1,NULL,' æ–°åœ°å€ï¼š\rRua Helena \rVaz da Silva, nÂº13-6ÂºA \r1750-405 Lisboa \rPortugal \r\r52mm -77mm æŽ¥å£çŽ¯ + holder  1 RR658662295CN'),(1628,634308178002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','bobharker','rjharker@gmail.com','Robert Harker','8 St John Woods Terrace','London','London','UNITED KINGDOM','NW8 6JJ','02077225267','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 17:40:14',0,NULL,3,1,4,1,NULL,'717AH çƒå°  1 \rballhead  $15\rYW864143020CN\r'),(1629,595757270001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','deepportage','mbock@d.umn.edu','Martin Bock','4084 Hicken Rd','Duluth','Mn','UNITED STATES','55803-9271','(218) 721-4492','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 18:42:40',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  1 '),(1630,595777620001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','flozzyflozz','fcnaber@yahoo.com','F.C. Naber','H.Pootstraat 15','Heemskerk','','NETHERLANDS','1962HA','+31 622869325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 19:38:13',0,NULL,3,1,3,1,NULL,'RR658662596CN'),(1631,634358621002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','flozzyflozz','fcnaber@yahoo.com','F.C. Naber','H.Pootstraat 15','Heemskerk','','NETHERLANDS','1962HA','+31 622869325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 19:38:14',0,NULL,5,1,18,0,NULL,'å‘ä¸‹åˆå¹¶\r '),(1632,634367745002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mastah_lew','louiscomeau@hotmail.com','Louis Comeau','71 ch Pin Rouge','Grand-Remous','QC','CANADA','j0w1e0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 19:44:27',0,NULL,3,1,2,1,NULL,''),(1633,634376729002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT007',126,'hermeshine','niji745','guarneri.luca@gmail.com','Luca Guarneri','Via Verdi 66','Catania','CT','ITALY','95129','3332879601','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 20:25:53',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  2  \r800w 220v ç¯æ³¡  2 \rYW864142891CN\rlight $22'),(1634,595843597001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'',7.9,'hermeshine','php0010','info@philharrisphoto.com','Phil Harris','PO Box 833','Nowra','New South Wales','AUSTRALIA','2541','0408412143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 21:49:51',0,NULL,3,1,2,1,NULL,''),(1635,595844132001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','abahler1990','abahler@gmail.com','Aaron Bahler','6428 Iron Bridge Rd','Athens','WI','UNITED STATES','54411-8407','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 21:51:35',0,NULL,3,1,1,1,NULL,NULL),(1636,595847513001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','bears*10','t-me@live.com','Tania  emes','7 Gold Crt','Salisbury Heights','South Australia','AUSTRALIA','5109','0882587365','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 22:01:07',0,NULL,3,1,3,1,NULL,'40cm æ£š   1 RR658662335CN'),(1637,595844661001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 21:53:02',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1638,595843458001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 21:53:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1639,634435528002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pbazsy86','pfeiffer.balazs@endi.hu','BalÃ¡zs Pfeiffer','DÃ³zsa GyÃ¶rgy 32/A','LÃ¡batlan','KomÃ¡rom-Esztergom','HUNGARY','2541','36305633536','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-19 22:13:40',0,NULL,3,1,2,1,NULL,' '),(1640,634437399002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','steph4712','stephp@charter.net','Stephenie Pippin','453 Hermitage Ave','Cookeville','TN','UNITED STATES','38501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:18:51',0,NULL,3,1,1,1,NULL,NULL),(1641,634438285002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bencrystalr7227','bencrystalr@gmail.com','Ben Rempel','1609 Highway 32 N','Walhalla','ND','UNITED STATES','58282-4306','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:25:13',0,NULL,3,1,1,1,NULL,' '),(1642,634426313002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','vedran_v','vedran.vrhovac@gmail.com','Vedran Vrhovac','Trg Antuna Cvetkovica 6','Novo Cice','','CROATIA','10415','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 21:53:03',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\råŒç¯å¤´ æ¬§æ ‡  1\r115w 220v   2 \ré‡3075\rCP212150759CN'),(1643,595859891001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',3,'AB1303',10.02,'hermeshine','kdphoto851','kdcaviness@hotmail.com','Keith Caviness','PO Box 851<br>203 E Main St','Ottumwa','IA','UNITED STATES','52501-0851','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-19 22:34:11',0,NULL,3,1,1,1,NULL,' '),(1644,634451169002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','harly01','hn@onsmail.nl','Nouwens Hans','Torenvalk 12','Veldhoven','','NETHERLANDS','5508KS','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-19 23:05:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   1\råå…‰ä¼ž  1 \rRR658662239CN'),(1645,595896202001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','akaspudnik','swerdnase@mac.com','Chris Kenner','5690 Deer Creek Falls Ct','Las Vegas','NV','UNITED STATES','89118','(702) 301-3376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 00:50:43',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1646,634481769002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','akaspudnik','swerdnase@mac.com','Chris Kenner','5690 Deer Creek Falls Ct','Las Vegas','NV','UNITED STATES','89118','(702) 301-3376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 00:50:43',0,NULL,3,1,1,1,NULL,'58mm lenscap for Canon 1\r77mm lenscap for Canon 1\r '),(1647,595911629001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','limmerm','limmer.michael@gmail.com','Michael Limmer','25 Butler Blvd.','Winnipeg','MB','CANADA','R2R0Y7','(204) 296-1459','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 01:58:06',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658662225CN'),(1648,595914295001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','s.sibley','sibleys@hotmail.com','Photo International','1186 Trestle Glen Rd.','Oakland','CA','UNITED STATES','94610','','NoPaymentFailure','CheckoutComplete','NotSelected','2010-11-20 02:26:39',0,NULL,3,1,1,1,NULL,NULL),(1649,595926776001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','kknott50','knott.kristopher@hotmail.com','Kristopher Knott','1049 Read Road','Shannonville','ON','CANADA','K0K3A0','(613) 396-5692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 03:12:01',0,NULL,3,1,2,1,NULL,' '),(1650,595931797001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 03:39:04',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rRR658662171CN'),(1651,595931585001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 03:39:05',0,NULL,3,1,2,1,NULL,'\rå€’å½±æ¿  1 \r351g'),(1652,634530587002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','troikaventures','om_troika@yahoo.com.au','Teik Oh','1/1 Simms Road','Hamilton Hill','Western Australia','AUSTRALIA','6163','0893315288','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(1653,595939541001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',12.99,'hermeshine','troikaventures','om_troika@yahoo.com.au','Teik Oh','1/1 Simms Road','Hamilton Hill','Western Australia','AUSTRALIA','6163','0893315288','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1\rNG128   1   \r\r335g\rRR658662389CN'),(1654,634542457002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:40:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rRR723016263CN'),(1655,634542651002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:42:29',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1  \rå®¢æˆ·è¦æ±‚3ç¥¨è´§åˆ†ä¸‰å¤©å‘\rRR723016317CN'),(1656,634543408002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nnightangell','nnightangel@yandex.ru','Evgeniy Zelenin','Studencheskiy proezd, 10/1, 20','Kirov','Kirov region','RUSSIAN FEDERATION','610033','+79195154445','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:47:30',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rRR658662551CN '),(1657,595953023001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','prolific_hasbeen','scheuerv@nucleus.com','Vic Scheuerman','103 Beaconsfield Rd NW','Calgary','AB','CANADA','T3K 1X8','(403) 275-2622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 05:54:40',0,NULL,3,1,3,1,NULL,'nikonæ‘„å½±èƒŒå¿ƒ M  1RR723016918CN '),(1659,634551180002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','germanautorecycler','germansolutionz85@yahoo.com','Tomas Ballesteros','2442 Iowa Ave<br>Apt A12','Riverside','CA','UNITED STATES','92507','(951) 522-4032','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 06:44:13',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿   1'),(1660,634572420002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mattvegas808','mattvegas808@hotmail.com','Fat Tuesday - Matt Mochida','3500 Las Vegas Blvd S<br>Ste L23','LAS VEGAS','NV','UNITED STATES','89109-8905','','NoPaymentFailure','CheckoutComplete','Other','2010-11-20 08:49:52',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR658662865CN'),(1661,595988276001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:22',0,NULL,3,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(1664,634576198002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:23',0,NULL,3,1,3,1,NULL,' 2mç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rRR723016325CN'),(1665,634572679002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',9.6,'hermeshine','drora1','ilanz1@zahav.net.il','Ilan Zeir Harim','12 Hativat Golani','Ra\'anana','','ISRAEL','43333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 09:29:24',0,NULL,3,1,3,1,NULL,'3pcsæ»¤é•œè¢‹  2\rä¸­å·å†…èƒ†åŒ… nikon  1\rxl é•œå¤´ç­’  1\rå°å·é•œå¤´ç­’  1\rçƒ­é´æ°´å¹³ç›–   1\ré‡é‡?0.354 RR658662287CN\r'),(1670,595950316001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 10:28:16',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ ( ç™½ é»‘ ç° )  1\rEE520583689CN\r3480g\r '),(1671,596016487001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','j-joe','johann.hoff@gmail.com','Johannes Hoff','Top Floor<br>8 John Street','London','London','UNITED KINGDOM','WC1N2ES','07910586619','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 11:15:48',0,NULL,3,1,2,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1  '),(1672,596019899001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','futiyke','fernandout@yahoo.com.br','Fernando Utiyke','Rua Bruna,351','SÃ£o Paulo','SÃ£o Paulo','BRAZIL','03370-000','55 11 2671-7973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 11:22:35',0,NULL,3,1,2,1,NULL,' '),(1673,596024585001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','philambre','philcare@wanadoo.fr','cayrouse philippe','2 PLACE DE L\'EGLISE','CHOISEL','Ile-de-France','FRANCE','78460','06.60.66.56.44','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 11:44:41',0,NULL,3,1,4,1,NULL,'6663a  1\rYW864142924CN\rTripod  $22 '),(1674,634623408002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gustavobispo1981','gusvahe@hotmail.com','Gustavo Valiente Herrero','Carretera Puente Nuevo, 4, Bj C','Coria (CÃ¡ceres)','Extremadura','SPAIN','10800','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 12:05:23',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rRR658662945CN'),(1675,596041323001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0024',6.99,'hermeshine','eshalom45b','nat8gal7@gmail.com','Alexander Moshkovich','52B Hanasi Harishon','Rehovot','','ISRAEL','76302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 12:35:50',0,NULL,3,1,2,1,NULL,'canon å°åŒ…   1 '),(1676,596073755001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','alexdms72','alexdms@mail.ru','Alexander Pustobaev','Kropotkina 269/1 apt. 293','Novosibirsk','Novosibirskay','RUSSIAN FEDERATION','630111','+7383 214-20-70','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 14:13:37',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR658662211CN'),(1677,596077944001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','friedlimabean','freefallfroggie@yahoo.com','Alexandra Sola','12-14 Sulak Lane Apt#3','Park Ridge','NJ','UNITED STATES','07656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 14:26:56',0,NULL,3,1,1,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ  é»‘è‰²  1 \r\r358g\r'),(1678,596079643001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','terrylreimer','tlrphoto@yahoo.com','Terry Reimer','1150 Settlers Landing Dr','Tappahannock','VA','UNITED STATES','22560-5071','(704) 996-2156','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 14:29:27',0,NULL,3,1,1,1,NULL,'72mm æ©¡èƒ¶ç½©  1 '),(1679,634672453002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','sandramlund','some-say@hotmail.com','Sandra Mari Lund','Jarlsborgveien 18 c','Trondheim','','NORWAY','7041','+4794436998','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 14:31:06',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(1680,634678251002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','calfab63','ebay@calzeroni.it','Fabio Calzeroni','Via Borgomanero 26','PARUZZARO','NO','ITALY','28040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 14:51:13',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ( ç™½) 1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡  2\råå…‰ä¼ž  2\r115w 220v   4\råŒ…  1\rYW864142961CN\rlighting kit  $30\r'),(1681,596089547001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','koolinggames','fmichaux@gmail.com','Fabrice Michaux','Route de Bambois, 13','Fosses-la-Ville','','BELGIUM','5070','0473503503','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 15:04:22',0,NULL,3,1,4,1,NULL,'6663a  1\rYW864142950CN\rtripod $22\r '),(1683,634692739002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','oratrend01','oratrend@gmail.com','SZABÃ“ Ã‰VA','SzenthÃ¡romsÃ¡g utca 13.','Szeged','','HUNGARY','6725','003630-9982769','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:22:38',0,NULL,3,1,2,1,NULL,'115w 220v   1 \r\r362g'),(1684,596100035001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jufede','jufedex@hotmail.com','Maria Eugenia Taboada','Avenida Del Libertador 6550 Piso 4 Dto B','NuÃ±ez','Ciudad Autonoma de Buenos Aires','ARGENTINA','C1428ARV','1564071665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:28:42',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1685,596099594001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','jufede','jufedex@hotmail.com','Maria Eugenia Taboada','Avenida Del Libertador 6550 Piso 4 Dto B','NuÃ±ez','Ciudad Autonoma de Buenos Aires','ARGENTINA','C1428ARV','1564071665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 15:28:42',0,NULL,3,1,2,1,NULL,'lenspen  1\ræ°”å¹+å¸ƒ   1\r\ré‡é‡?0.118\r '),(1686,634726968002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','roman_d_e','reremkin@gmail.com','Roman Eremkin','Belinskovo, 222, room 177','Ekaterinburg','Sverdlovskaia','RUSSIAN FEDERATION','620130','+7 908-906-3515','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 16:39:05',0,NULL,3,1,3,1,NULL,'MC-C1   1\rRR658662358CN '),(1687,596134747001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tonymik2498','tonymik65@hotmail.com','Anatoliy Mikhaylyuk','309 Wild Azalea dr.','Inman','SC','UNITED STATES','29349','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 16:43:11',0,NULL,3,1,1,1,NULL,'éº‚çš®  1 '),(1688,634748360002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nmiw6488','vaganova.pointe@gmail.com','Nami Miwa','12 Highland Street','Natick','MA','UNITED STATES','01760','(617) 999-6394','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 17:20:14',0,NULL,3,1,1,1,NULL,NULL),(1689,634765420002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','lcas3662','luis_carlos_castillo@yahoo.es','LUIS CARLOS CASTILLO RODRIGUEZ','CRISTOBAL COLON 13 1Âº C','GETXO','PaÃ­s Vasco','SPAIN','48992','629969832','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 17:55:44',0,NULL,3,1,4,1,NULL,'tripod  $30\rYW864142880CN\r '),(1690,634884590002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 22:07:02',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1691,596286730001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-20 22:07:02',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r100-150 5in1 åå…‰æ¿  1\rYW864142913CN\rç‡•æ–‡ ä¸€ç¥¨ä¸¤ä»¶  2196g\rreflector $22 '),(1692,634912122002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jcjjt','jimncat@embarqmail.com','James L. Taylor','385 NE 59th St','Ocala','FL','UNITED STATES','34479-7609','(352) 840-0043','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-20 23:00:48',0,NULL,3,1,1,1,NULL,NULL),(1693,596325768001,110566018900,'EW-73II Lens Hood lenshood for Canon EF 24-85 /f3.5-4.5',1,'AA3404',8.99,'hermeshine','fraser7588','libozhang88@hotmail.com','Libo Zhang','#203 - 5835 Hampton Place','Vancouver','BC','CANADA','V6T 2G2','(778) 866-8695','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-20 23:40:35',0,NULL,3,1,2,1,NULL,'EW-73II   1 '),(1694,596333308001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','albert02','lqc@sbcglobal.net','Y Choi','5410 Isabella Ct','Agoura Hills','CA','UNITED STATES','91301','(818) 879-8716','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 00:06:50',0,NULL,3,1,1,1,NULL,NULL),(1695,634950070002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','cookingdigs','cookingdigs@hotmail.com','Debbie Depriest','18118 E Mansfield Ave','Spokane valley','WA','UNITED STATES','99016-5091','(509) 921-1178','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 01:14:23',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1696,596348260001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','cookingdigs','cookingdigs@hotmail.com','Debbie Depriest','18118 E Mansfield Ave','Spokane valley','WA','UNITED STATES','99016-5091','(509) 921-1178','NoPaymentFailure','CheckoutComplete','Other','2010-11-21 01:14:23',0,NULL,3,1,1,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl  1 \r72mm æ©¡èƒ¶ç½©   1'),(1697,596379990001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mikeythetiregod','t_ateah@yahoo.ca','mike alexander','B 45658 lewis ave','CHILLIWACK','BC','CANADA','V2P3C6','(604) 418-1502','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 03:24:06',0,NULL,5,1,18,0,NULL,' '),(1698,596387453001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','yigit_urk','yigit007@gmail.com','yigit urkmezturk','bilkent university dorm (yurt) 75<br>room(oda) 207','bilkent','Ankara','TURKEY','06800','(312) 290 - 4846','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 04:03:48',0,NULL,3,1,2,1,NULL,NULL),(1699,635000464002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kknarf','frank@kingkiner.com','Frank Kingkiner','21 Van Zandt Rd','Skillman','NJ','UNITED STATES','08558','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 04:38:30',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1700,596394504001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','kknarf','frank@kingkiner.com','Frank Kingkiner','21 Van Zandt Rd','Skillman','NJ','UNITED STATES','08558','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 04:39:55',0,NULL,3,1,1,1,NULL,'58mm lenscap  canon  1 \r77mm lenscap  canon  1\ræ˜¨å¤©åŒ…å¥½äº†ï¼Œä½†æ˜¯éœ€è¦æ£€æŸ¥ä¸€ä¸‹ä¼¼ä¹Žåˆ†å¼€åŒ…çš„è¿˜æ˜¯åŒ…åœ¨ä¸€èµ·äº†'),(1701,596394133001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','prasada_g','prasada_g2001@yahoo.com','Prasada Goonaratne','335/1 Kotte Road','Nugegoda','Western Province','SRI LANKA','02','94777749480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 04:42:14',0,NULL,3,1,2,1,NULL,NULL),(1702,635016087002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','aa657','aanger2@sympatico.ca','Amanda Anger','207-6530 Wyandotte St E','Windsor','ON','CANADA','N8S 1P2','(519) 945-8918','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 06:10:14',0,NULL,3,1,3,1,NULL,' RR658662199CN'),(1703,596408397001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','homesik','homesik@yahoo.com','Jon Thiessen','16316 Prairie Farm Cir','Parker','CO','UNITED STATES','80134-3050','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 06:11:52',0,NULL,3,1,1,1,NULL,' '),(1705,690047805015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-21 07:34:30',0,NULL,3,1,2,1,NULL,NULL),(1706,635038799002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','frub9407','frubio@geutebruckspain.com','Francisco Jose Rubio Sanchez','C/ Carmen Martin Gaite 3 Portal E 2B','San Sebastian de los Reyes','Madrid','SPAIN','28702','639081738','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 08:21:33',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864142935CN'),(1707,689128962015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','pic1711','rdw1711@googlemail.com','Robin Walker','2 North Park Villas','Saltash','Cornwall','UNITED KINGDOM','PL126LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 09:03:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(1708,596446467001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','us4yayhoos','erinscellphone@gmail.com','George Swanson','5410 Whittlington Dr','Charlotte','NC','UNITED STATES','28215-9607','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 09:17:33',0,NULL,3,1,1,1,NULL,' '),(1709,635064055002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','gadget_geek2000','rjzandvoort@gmail.com','Robert-Jan Zandvoort','Klooslaan 53','Groningen','','NETHERLANDS','9721XM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 09:43:31',0,NULL,3,1,2,1,NULL,NULL),(1710,635078610002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','aschecky','andrew@waygen.com','Andrew Scheck','14 Carrie Dr','Marlboro','NJ','UNITED STATES','07746','(732) 490-8414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-21 10:20:53',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(1711,635131811002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','gregtlawson','lawsongr@hotmail.com','Greg T Lawson','22 Limestone Dr','Moncton','NB','CANADA','E1G 5P4','(506) 854-0076','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 12:23:18',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon  1 '),(1712,596555451001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','astashkinpa','pastashkin@gmail.com','Pavel Astashkin','19 Schmitovskiy proezd, App. 38','Moscow','Moscow','RUSSIAN FEDERATION','123100','+79032041572','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 13:36:45',0,NULL,3,1,2,1,NULL,NULL),(1713,596556853001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','juane1012','juanesdan@hotmail.com','juan espluga de antonio','c/san miguel,2,2Âº','barbastro','AragÃ³n','SPAIN','22300','616931522','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 13:43:27',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\rYW864142876CN\rlight stand $18 '),(1714,596563756001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','traktooorn','traktoorn@hotmail.com','Erik Ã–stberg','VÃ¤stra Ã–savÃ¤gen 18','Alfta','','SWEDEN','82240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 13:51:30',0,NULL,3,1,2,1,NULL,'45w  2 '),(1715,635180240002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','manu-dienekes','dienekes73@hotmail.com','MANUEL REGADERA EGUIZABAL','C/ ANASTASIO MATEO NÂº 2 BAJO','VILLAMEDIANA DE IREGUA','La Rioja','SPAIN','26142','629486140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 14:09:11',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž  2\r2643g\rtripod $25      \rYW864143031CN'),(1716,635208271002,120581555566,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','mike1arooau','mikefreeman@iinet.net.au','Mike Freeman','8 Olivedale Road','Madeley','Western Australia','AUSTRALIA','6065','0893024770','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 14:54:13',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(1717,635223471002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','phobic0_0','ramonprince@theprincespalace.com','Ramon Prince','4021 Sand Dollar Ct','Seabrook','TX','UNITED STATES','77586-7500','(281) 827-9158','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 15:19:41',0,NULL,3,1,1,1,NULL,' '),(1718,596637515001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','albertouy','alberto_moroy14@hotmail.com','Matias Fernandez','Alferez CÃ¡mpora y SimÃ³n Bolivar<br>Chalet: (name of the house) \"Marina Piccola\"','Punta del Este','Maldonado','URUGUAY','20000','42225530','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 16:01:01',0,NULL,3,1,2,1,NULL,' '),(1719,596706776001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','omer.erkol','omer-erkol@hotmail.com','Ã–mer ERKOL','223 Sokak No:59 D:3 Buca','Izmir','','TURKEY','35390','905077244797','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-21 17:28:54',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \r2870G\rCP212235091CN'),(1720,635411509002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','sound.matter','forest.dude@gmail.com','Steve Cox','553 Parkview Rd','Nashville','IN','UNITED STATES','47448-8066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 18:56:14',0,NULL,3,1,1,1,NULL,'1m ttl çº¿   canon   1 \ré‡é‡ï¼Ÿ171g'),(1721,635416278002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','tvykulil','tvykulil@msn.com','Tom Vykulil','1191 E Jupiter Pl','Chandler','AZ','UNITED STATES','85225-8912','(480) 633-0524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 19:01:11',0,NULL,3,1,1,1,NULL,' '),(1722,635425894002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','tenero30','sistampi@gmail.com','Rosati Luca','Via tore 16','Scauri','LT','ITALY','04028','328-3131500','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-21 19:08:47',0,NULL,3,1,3,1,NULL,'cåž‹å¤§åŠ›å¤¹  3 \ré‡é‡ï¼Ÿ\r737g\rRR658662517CN'),(1723,690645562015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','peterszeged74','juhaszpeterszeged@vipmail.hu','Peter Juhasz','2 Major Road','Stratford','London','UNITED KINGDOM','E15 1EE','0044755383409','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 20:52:26',0,NULL,3,1,2,1,NULL,'sony çº¢å¤–   1 '),(1724,635576010002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:35',0,NULL,5,1,18,0,NULL,''),(1725,635575879002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:36',0,NULL,5,1,18,0,NULL,''),(1726,635574866002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:36',0,NULL,5,1,18,0,NULL,' åˆå¹¶ä¸Šç¥¨ '),(1727,635575764002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rosehyps','cherol@comcast.net','Cheryl Olson','13016 126th Ave E','puyallup','WA','UNITED STATES','98374-3658','(253) 845-4830','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-21 22:08:37',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›– canon  4'),(1728,690722641015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','mosspalmeronline','mosspalmer@inbox.com','Mossiah Palmer','6 Southside Apartments St John\'s Walk','Birmingham','West Midlands','UNITED KINGDOM','B5 4TF','01216225263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-21 22:36:32',0,NULL,3,1,2,1,NULL,' '),(1729,596994867001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','qq**96','2zola@att.net','Helen Yesui, EZ Smog','2900 Mitchell Rd<br>Ste B','ceres','CA','UNITED STATES','95307-5035','','NoPaymentFailure','CheckoutComplete','Other','2010-11-21 23:27:01',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\r50-70 æ£š  1\ræ–œè‡‚    1\r115w 110v   1\rlight stand   $25\rYW864142946CN\r'),(1730,677368814016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','albertkc2007','albertkc2008@yahoo.com','Albert Cabreira','6801 W Ocotillo Rd APT#2047 Apt 2047','Glendale','AZ','UNITED STATES','85303','(602) 653-4972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 00:30:25',0,NULL,3,1,1,1,NULL,'xl é•œå¤´ç­’  1 '),(1731,635639653002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','kw56','kenwelte@hotmail.com','Ken Welte','1854 extension Rd','Nanaimo','BC','CANADA','v9x 1b1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:33:28',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰ç½© \ræˆ‘æ¥åŒ… \ré‡é‡ï¼Ÿ\r1312g\rRR658662242CN\r '),(1732,596967193001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',21.99,'hermeshine','jopafavoritus','sojo@sapo.pt','Joao Pires','Farmacia Teixeira Bessa Lda<br>Avenida Foz Sousa 1715','Foz Sousa','Foz Sousa','PORTUGAL','4515-084','+351 960075265','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:34:20',0,NULL,3,1,3,1,NULL,' RR658662208CN'),(1733,597026202001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1303',10.02,'hermeshine','647gloria','johnknippel@live.com','JOHN KNIPPEL','4060 LAWRENCE AVE EAST<br>UNIT 411','SCARBOROUGH','ON','CANADA','M1E4V4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 00:56:08',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©  3 '),(1734,690787836015,250600501508,'Continuous Lighting System soft box photography studio ',1,'',68,'hutongstore','leaaudreyhardy80','leaaaa.xx@hotmail.com','Lea Hardy','p.o box 306','mudgeeraba','Queensland','AUSTRALIA','4213','61448117993','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-22 01:01:15',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\råŒ…  1\rEE520583715CN'),(1735,597032581001,110600486184,'TianYa 67mm CPL filter New 67 Circular Polarizing C-PL',1,'AA2305',6.5,'hermeshine','theandreagail','kcyeow61@hotmail.com','Yeow Kong Chong','Blk 161 #10-623 Woodlands Street 13, Singapore 730161','default','','SINGAPORE','730161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 01:12:27',0,NULL,3,1,11,1,NULL,' '),(1736,635658544002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','aravena562','jaravenaa@mi.cl','juan carlos aravena acuna','Pasaje Santiago de Compostela #1834<br>Villa Mirador de la Bahia','Puerto Montt','Decima Region','CHILE','5480000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 01:22:17',0,NULL,3,1,2,1,NULL,NULL),(1737,690823714015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','mooseheadorangenet','jhyndman@brookes.ac.uk','Jim Hyndman','Westminster Institute of Education Oxford Brookes University','Oxford','Oxon','UNITED KINGDOM','OX2 9AT','07815734857','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 02:23:57',0,NULL,3,1,2,1,NULL,' '),(1738,635684893002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'',17.8,'hermeshine','andresabadg','andresabad@gmail.com','ANDRES ABAD','1140 SORRENTO DR','WESTON','FL','UNITED STATES','33326-4553','(786) 556-4869','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-22 02:44:59',0,NULL,3,1,1,1,NULL,' 74g'),(1739,597068245001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','saa153','saa153@gmail.com','Scott Ayres','1053 Cayer Dr','Glen Burnie','MD','UNITED STATES','21061','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 02:52:22',0,NULL,3,1,1,1,NULL,NULL),(1740,635685888002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 02:59:43',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1741,597060553001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT007',130,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 02:59:43',0,NULL,3,1,8,1,NULL,'å¼¹ç°§ç¯æž¶  1\rçº¢ç¯å¤´  1\r800w 110v  6 \råˆ†ä¸¤ç¥¨å‘\rCP212150731CN\rCP212150745CN\r'),(1742,635697070002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pet_lab','troykim1@cox.net','Kim Malpass','176 Pond St','Vanceboro','NC','UNITED STATES','28586-7618','(252) 244-3566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 03:02:41',0,NULL,3,1,1,1,NULL,NULL),(1743,635697489002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',5,'AKT049',175,'hermeshine','emelymares','mares95b@yahoo.es','Maria E. Fernandez','2800 S Lamb Blvd<br>Spc 32','Las Vegas','NV','UNITED STATES','89121-1810','','NoPaymentFailure','CheckoutComplete','Other','2010-11-22 03:14:18',0,NULL,3,1,4,1,NULL,'115w110v  10 \rlight $25\r3.4kg\r\rYW864143182CN'),(1747,635722150002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera MartÃ­nez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 04:29:16',0,NULL,5,1,18,0,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \r\r'),(1744,597077331001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','thrashtractor','dominicgangx@gmail.com','Dominic Gan','Blk 211, Pasir Ris Street 21<br>#12-248','default','','SINGAPORE','510211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 03:21:09',0,NULL,3,1,11,1,NULL,' '),(1745,597089326001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','discountjunkseller','discountjunk@yahoo.com','James McDonald','PO Box 1962','Rockingham','NC','UNITED STATES','28380-1962','(910) 273-8819','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 04:07:45',0,NULL,3,1,1,1,NULL,' '),(1746,635717545002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','cristinaandkids','ooocristinaooo@sbcglobal.net','Cristina Medeiros','764 Santos Ave','Ripon','CA','UNITED STATES','95366-9354','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 04:07:48',0,NULL,3,1,1,1,NULL,'test-Jiangang '),(1748,597107245001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','drapolla2010','drapolla@gmail.com','Adriana de la Rocha Aguirre','Rio Amarillo #280 Col. Residencial Fluvial Vallarta','Puerto Vallarta','Jalisco','MEXICO','48312','3222246588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 05:53:33',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1\r '),(1749,635739034002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jrsola3566','jsola1032@gmail.com','Jose Sola','45 Blvd Media Luna D-1008<br>Villas de Parque Escorial','Carolina','PR','PUERTO RICO','00987','(787) 668-7332','NoPaymentFailure','CheckoutComplete','Other','2010-11-22 05:56:26',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \r\rRR658662579CN'),(1750,597111008001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','75cnx','zeeazaaa@gmail.com','Thunyathorn Traisirichok','40/8 Moo.5 T.Suthep','Chiang Mai','','THAILAND','50200','66869212039','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 06:13:30',0,NULL,3,1,3,1,' ','\rRR658662605CN'),(1751,597113124001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','flybear8','han67391@optusnet.com.au','Heather Anderson','10 Etherington Ave<br>Spearwood','Perth','Western Australia','AUSTRALIA','6163','0894186718','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 06:29:13',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©  1 \r\rRR658662582CN'),(1752,597119555001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','archdeluxe696','sedemihcra34@yahoo.com','archie mandap','3250 Port Pacific Ln','Elk Grove','CA','UNITED STATES','95758-3606','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 07:09:00',0,NULL,3,1,1,1,NULL,NULL),(1753,597138854001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','maakkonen','makko2000_@hotmail.com','Mikko Suomalainen','Ketunkatu 9','HyvinkÃ¤Ã¤','','FINLAND','05460','0405233925','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 08:56:17',0,NULL,3,1,4,1,NULL,'717 155cm   1 \rTripod $25\rYW864143005CN'),(1754,635774256002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','inverse_of_zero','from_zero_to_infinity@live.com.au','George Papadopoulos','Fastfit Automotive Specialist<br>601 Paramatta Road','Leichhardt','New South Wales','AUSTRALIA','2040','0414442332','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 09:20:00',0,NULL,3,1,2,1,NULL,' '),(1755,597150807001,110600486184,'TianYa 67mm CPL filter New 67 Circular Polarizing C-PL',1,'AA2305',6.5,'hermeshine','jeanmarie2726','jean.marie.trautmann@gmail.com','Jean-Marie TRAUTMANN','84 route d\'Aspach','Vieux-Thann','Alsace','FRANCE','68800','03 89 37 05 89','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 09:48:54',0,NULL,5,1,2,1,NULL,' åˆå¹¶ä¸Šç¥¨'),(1756,635808342002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','jeanmarie2726','jean.marie.trautmann@gmail.com','Jean-Marie TRAUTMANN','84 route d\'Aspach','Vieux-Thann','Alsace','FRANCE','68800','03 89 37 05 89','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 11:21:08',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  1 '),(1757,690987597015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','denegg','denniswalker@ntlworld.com','Dennis Walker','335 Poulton Road','Wallasey','Merseyside','UNITED KINGDOM','CH44 4DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 12:12:21',0,NULL,3,1,2,1,NULL,NULL),(1758,690991124015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','kamilasv','kamila.varadova@seznam.cz','Kamila VaraÄovÃ¡','RilskÃ¡ 3181/2','Praha','','CZECH REPUBLIC','14300','731-528-798','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-22 12:22:18',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   2\råŒ…  1 \rCP212150688CN'),(1759,635831467002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','zjflowers','zjflowers@aol.com','Maelene dianne Zuniga','15650 Ludlow St','Granada Hills','CA','UNITED STATES','91344','(818) 363-1055','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 12:42:59',0,NULL,3,1,1,1,NULL,' '),(1760,691014054015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','horsehead1980','tony.janoska@gmail.com','MSC Ireland (Anton Janoska)','3rd FLOOR, NORTH POINT HOUSE, NORTH POINT BUSINESS PARK, NEW MALLOW ROAD','CORK','Cork','IRELAND','default','085 7126466','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 13:28:20',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR658662888CN'),(1764,597216503001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','pinkrsvp','renupandya@yahoo.com','Renu Pandya','70 Beebe St<br>Staten Island','Staten Island','NY','UNITED STATES','10301-4545','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 13:49:52',0,NULL,3,1,1,1,NULL,'æ¸å˜æ©™   1 '),(1766,635858321002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','jukkav','jukka.vuokko@iki.fi','Jukka Vuokko','TÃ¤hkÃ¤polku 4 B 62','Turku','Finland','FINLAND','20720','+358504352787','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:03:46',0,NULL,3,1,2,1,NULL,NULL),(1767,635856182002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','hyeminsz','hyemin-sz@hotmail.com','Hyemin Park','Unit 2207 108 Albert Street','Brisbane','Queensland','AUSTRALIA','4000','0423624191','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:11:34',0,NULL,3,1,2,1,NULL,NULL),(1768,635863150002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','dtracing614','dreamteamracing614@yahoo.com','franklin bohanan','785 barberry spur ave','delaware','OH','UNITED STATES','43015-3415','(614) 949-2633','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 14:18:02',0,NULL,3,1,1,1,NULL,NULL),(1769,635868313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','boothjad','drboothjones@cinci.rr.com','Angela Jones','2891 Bentbrook Dr','Cincinnati','OH','UNITED STATES','45251-1107','(513) 825-4708','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 14:33:05',0,NULL,3,1,1,1,NULL,NULL),(1770,635867730002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adrian.quintano','adrianquintano@gmail.com','adrian quintano','jl. bogor no. 349/m cinere','jakarta selatan','jakarta','INDONESIA','16514','628557894455','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 14:34:57',0,NULL,3,1,2,1,NULL,NULL),(1771,597232000001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','summerlad','kdc@ducann.com','kenneth  ducann','27 miller  street','summerseat','manchester','UNITED KINGDOM','bl9 5px','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-22 14:37:22',0,NULL,3,1,2,1,NULL,NULL),(1772,635891075002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','maunal1905','maunal1987@gmail.com','mehmet ali Ã¼nal','gÃ¼neÅŸtepe mahallesi.sergi sokak.no:7 daire: 5<br>gÃ¼ngÃ¶ren / istanbul','istanbul','TN','TURKEY','34164','+905352680228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 15:38:17',0,NULL,3,1,2,1,NULL,NULL),(1773,691075217015,250623448641,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','larguetas','manijero73@gmail.com','jorge arroyo ovalle','cruz de granada BL 2 piso 7 puerta 4','granada','AndalucÃ­a Ceuta y Melilla','SPAIN','18015','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 15:53:27',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(1774,635895704002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:09',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1775,635903501002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:07',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1776,635891103002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1777,635895400002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:09',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶  '),(1778,597255990001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','phunter_majia','phunter.lau@gmail.com','Anne-Claire Decorvet to Hongliang Liu','56 route du SalÃ¨ve Entrance E','PrÃ©vessin-MoÃ«ns','RhÃ´ne-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:11:10',0,NULL,3,1,3,1,NULL,'77mm çŽ¯æž¶  2\r58mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯  1\rå¹¿è§’æ‰˜æž¶   2 \rRR658662959CN'),(1779,635908247002,120531377860,'JueYing Lambency Flash Diffuser for 430EX F36AM',1,'AB3308',22,'hermeshine','demitryvolovich','demion1403@gmail.com','Demitry volovich','zolotorov 1b','hadera','beit eliaezer','ISRAEL','38496','0544691631','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 16:18:40',0,NULL,3,1,3,1,NULL,'ç¢—ç½© P2   1 \rRR658662931CN'),(1780,635911002002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','roger2008br','rogerioishikawa@uol.com.br','Rogerio Ishikawa','Rua Manoel Barbosa Filho, 345<br>Granja Olga III','Sorocaba','SÃ£o Paulo','BRAZIL','18017-228','55-15-3228-1414','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 16:25:51',0,NULL,3,1,3,1,NULL,'Canon A1 æ–°æ¬¾åŒ…ï¼Œ æˆ‘æ¥å§ï¼Œ\r563g\rRR658662928CN'),(1781,597271109001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','dis7784935','munadis@hotmail.com','mohamed munadis','H.oikolhuge<br>roashaneemagu','male\'','henvayru','MALDIVES','20033','009607784935','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 16:26:31',0,NULL,3,1,3,1,NULL,'800w 220v ç¯æ³¡  5\r132gï¼Ÿ\r RR658662914CN'),(1782,635931640002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dainius_67','dainius67@gmail.com','Dainius Aleliunas','Projektuotoju 12-71','Panevezys','','LITHUANIA','37131','(370) 68042471','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 17:10:27',0,NULL,3,1,2,1,NULL,' '),(1783,691126682015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','lebaneer1981','lebanneer@gmail.com','Darius Jonyla','Main Street, Collon \'Collon Furniture\'','Collon','Louth','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 17:31:27',0,NULL,3,1,2,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ  é»‘è‰²  1 '),(1784,635960554002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','brookebattery','brooke@pacific.net','Brooke Clarke','3425 Deerwood Dr.','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-22 18:08:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1785,597318345001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8.5,'hermeshine','chappersanddave','davidmichaels.odt@hotmail.com','Dave Rudkin','41 silken court','Nuneaton','Warwickshire','UNITED KINGDOM','cv11 5nn','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-22 18:10:46',0,NULL,3,1,2,1,NULL,NULL),(1786,691152189015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','shmulis','stalbergs@tvnet.lv','janis stalbergs','lielais pr.68-30','ventspils','','LATVIA','lv-3601','37126529567','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-22 18:11:15',0,NULL,3,1,2,1,NULL,''),(1787,597319597001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','brookebattery','brooke@pacific.net','Brooke Clarke','3425 Deerwood Dr.','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 18:11:44',0,NULL,3,1,1,1,NULL,'40cm æ£š  1\rå¤§åŠ›å¤¹   2 '),(1788,689606675015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','lukecciara','ciaraluke@hotmail.co.uk','ciara luke','7 hillside view','newtonabbey','Antrim','UNITED KINGDOM','bt36 6de','07935095562','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 18:47:47',0,NULL,3,1,2,1,NULL,NULL),(1789,677759149016,260660053665,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','mjc771','collins.castledrive@ntlworld.com','Martin Collins','35 Castle Drive','Dover','Kent','UNITED KINGDOM','CT163EN','01304820786','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 19:02:07',0,NULL,3,1,2,1,NULL,'æ˜Ÿå…‰é•œ  star  4  1 '),(1790,636006018002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','chnkyeyes','ryu022@yahoo.com','Rex Yu','72 tangerine','irvine','CA','UNITED STATES','92618-4574','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 19:26:00',0,NULL,3,1,1,1,NULL,NULL),(1791,595037884001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','kristiem25','kristiemantle@hotmail.com','Kristie Mantle','8410 Centre street NE','calgary','AB','CANADA','T3K1Y1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 19:27:45',0,NULL,3,1,2,1,NULL,NULL),(1792,597399009001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','gr778899','gr778899@gmail.com','GREGORY ATHANASIADIS','15, Diou str, Ionia','Thessaloniki','','GREECE','GR-57008','6999778899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 20:30:58',0,NULL,3,1,3,1,NULL,' RR658662826CN'),(1793,597402793001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 20:40:10',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR658662905CN'),(1794,636067608002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',20,'AKT051',230,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 21:10:49',0,NULL,3,1,3,1,NULL,'lenspen  40\r1808g\r RR658662891CN'),(1795,691302937015,250692238279,'New 72mm 72 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','addo-d','addo-d@excite.com','Samuel Addo-Debrah','11 Garfield Street','Watford','Hertfordshire','UNITED KINGDOM','WD24 5HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 21:51:44',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(1796,597440727001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','stiopatatata','dr.stef4o@abv.bg','Stefan Mladenov','7 High Street Buckingham House Dental Practice','Buckingham','Buckinghamshire','UNITED KINGDOM','MK18 1NT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-22 21:53:27',0,NULL,3,1,2,1,NULL,NULL),(1797,597456489001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','rosanolu','nrogic@exchange.ubc.ca','Novak Rogic','#1170-2329 West Mall','Vancouver','BC','CANADA','V6T 1Z4','(604) 221-6010','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 22:32:20',0,NULL,3,1,5,1,NULL,' \rCP212235247CN\r'),(1798,636108141002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','moni-maga-sym','moniimages@yahoo.com','Monica Larson','7226 W Sheila Ln','phoenix','AZ','UNITED STATES','85033-4337','(623) 266-2683','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 22:35:02',0,NULL,3,1,1,1,NULL,' '),(1799,691348917015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'',1.88,'hutongstore','js_almada','js.almada87@gmail.com','Santiago Almada','Lupton Flats, Alma Road, Block D Room 2.12','LEEDS','West Yorkshire','UNITED KINGDOM','LS6 2PG','7505657609','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-22 23:21:00',0,NULL,3,1,2,1,NULL,'77mm lenscap nikon  1 '),(1800,636129610002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','john4160','jbjcdj@yahoo.com','John Jeffers','25399 Broadway Road','Morton','IL','UNITED STATES','61550','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-22 23:34:34',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿    1'),(1801,636133140002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','hp_777','evergreen_frn@yahoo.com.au','Helen Paulus','10 Pambula Ave','Prestons','New South Wales','AUSTRALIA','2170','0287839277','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-22 23:46:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR658662874CN'),(1802,597486488001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','pauleljoda','eljoda@hotmail.com','paul zambrano','r. euclides da cunha, 1387<br>apto 101','Curitiba','ParanÃ¡','BRAZIL','80730-360','(041) 9137-7475','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:16:08',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1803,636139057002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pauleljoda','eljoda@hotmail.com','paul zambrano','r. euclides da cunha, 1387<br>apto 101','Curitiba','ParanÃ¡','BRAZIL','80730-360','(041) 9137-7475','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:16:09',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r77mm é•œå¤´ç›–  canon  1 '),(1804,597493669001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','sell2ski','sell2ski@hotmail.com','Tim Grant','3035 Uplands Dr SE','Grand Rapids','MI','UNITED STATES','49506-1932','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 00:35:56',0,NULL,3,1,1,1,NULL,NULL),(1805,636148404002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.77,'hermeshine','domduf78','dominicdufault@hotmail.com','Dominic Dufault','3895 Lavoie','St-Hubert','QC','CANADA','J3Y 5E3','(450) 445-4101','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 00:47:21',0,NULL,3,1,2,1,NULL,' '),(1806,597511576001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','aravena562','jaravenaa@mi.cl','juan carlos aravena acuna','Pasaje Santiago de Compostela #1834<br>Villa Mirador de la Bahia','Puerto Montt','Decima Region','CHILE','5480000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 01:48:03',0,NULL,3,1,2,1,NULL,' '),(1809,636193504002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','henryyxyu','henryyxyu@gmail.com','Henry Yu','5173 Maison Ave','Los Angeles','CA','UNITED STATES','90041-1623','(323) 257-7609','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 03:23:34',0,NULL,3,1,1,1,NULL,' '),(1807,592070727001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kweenofcanada','retromodern2@gmail.com','Rick Fritschy','111 Cunnington AVE.','Winnipeg','MB','CANADA','R2M 0W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 02:28:23',0,NULL,3,1,2,1,NULL,NULL),(1808,636181753002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','r_trelles','rtrelles@bellsouth.net','Rick Trelles','PO Box 650264','Miami','FL','UNITED STATES','33265-0264','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 02:41:59',0,NULL,3,1,1,1,NULL,NULL),(1810,597543795001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','burs','bursey3@cogeco.ca','paul e. bursey','2153 sunnyvale Dr','Oakville','ON','CANADA','l6l1w6','(905) 847-9573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 03:59:12',0,NULL,3,1,2,1,NULL,' '),(1811,597554362001,110502916835,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',3.55,'hermeshine','ta_tum','thossapon@infomec-it.com','thossapon kammoon','32/7 moo2 klong9<br>rangsit-nakornnayok road. brungsanan','tanyaburi','Patumtani','THAILAND','12110','6629089249','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 04:56:53',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1812,636213903002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','ta_tum','thossapon@infomec-it.com','thossapon kammoon','32/7 moo2 klong9<br>rangsit-nakornnayok road. brungsanan','tanyaburi','Patumtani','THAILAND','12110','6629089249','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 04:58:01',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  1\r62mm æŽ¥å£çŽ¯  1 '),(1813,597564945001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','plainamericanguy','grandbob@gmail.com','Robert Otey','3824 Virginia Avenue SE','Charleston','WV','UNITED STATES','25304-1508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 06:05:54',0,NULL,3,1,1,1,NULL,NULL),(1814,636224815002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','willax1','willirotorua@aol.com','wilhelm werner','65 utuhina road','Rotorua','BOP','NEW ZEALAND','3015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 06:07:27',0,NULL,3,1,3,1,NULL,NULL),(1815,636231707002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pepster-returns','arcoona.estate@bigpond.com','Peter Burke','12 Arcoona Avenue','Rostrevor','South Australia','AUSTRALIA','5073','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 06:54:04',0,NULL,3,1,6,1,NULL,'EE520583661CN\r'),(1816,636248083002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','spiritrx-7','dragntek@hotmail.com','henry   lam','2624 darwin ave','los angeles','CA','UNITED STATES','90031','(323) 788-5896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 08:28:30',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(1817,597593243001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 09:01:10',0,NULL,3,1,3,1,NULL,'çº¢å¤´ç¯ 1\r800w 220v  1\ræŽ§åˆ¶2kg  \rRA022499146CN\r'),(1818,636257780002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ttuffghost','c.gian@yahoo.com','Christopher Gian','2826 Telegraph Ave<br>Apt 1','Berkeley','CA','UNITED STATES','94705-1125','(714) 305-4003','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 09:17:24',0,NULL,3,1,1,1,NULL,' '),(1819,636258900002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adorroimpressions13','adorroimpressions@gmail.com','Jessica Wolfe','Katrina Christ Photographer<br>58 Burwood Rd','Hawthorn','Victoria','AUSTRALIA','3122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 09:20:12',0,NULL,3,1,2,1,NULL,NULL),(1820,597610105001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','brandokhoo','bckkhoo@hotmail.com','Brando Khoo','2418 Talavera Dr','San Ramon','CA','UNITED STATES','94583-2226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 10:16:09',0,NULL,3,1,1,1,NULL,'  67MM adapter ring and ND2 + ND4 + ND8 filters, and the holder '),(1821,678105153016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'',120,'hutongstore','oldxavier','pinechip25@yahoo.it','Saverio Giaquinta','via Nervi, 7','Ravenna','RA','ITALY','48100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-23 10:47:29',0,NULL,3,1,4,1,NULL,'2mç¯æž¶ 2\r4ç¯å¤´æ£š  æ¬§æ ‡  2\r45w 220v  8\råŒ…  1 \rlighting kit  $30\rYW864143123CN\r'),(1822,636279146002,120601700875,'TianYa New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','mariagonzalez80','mariagonzalezmarro@hotmail.com','Maria Gonzalez Marro','C/ Bilbao 237, 6Âº 3Âª Esc. 7','Barcelona','CataluÃ±a','SPAIN','08018','630088027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 10:50:08',0,NULL,3,1,2,1,NULL,''),(1823,636279585002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','cooper74ura','urpl999@gmail.com','Ura Plusnin','Vostrecova d. 3 kv. 106','Cheliabinsk','ru','RUSSIAN FEDERATION','454106','81079043069971','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 10:51:42',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 \rRR723016303CN\r'),(1824,636283437002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','mantonnet','netmarn@gmail.com','Navin Thongdee','THAI CHAINS<br>2/99 Moo 14  Seri Thai 58 Rd,Minburi','Minburi','Bangkok','THAILAND','10510','+66850564399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:05:36',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(1825,636285352002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','pedrosanc','pedrosan@ono.com','Pedro Vicente Sanconstantino Ossorio','Pedro Vicente Sanconstantino Ossorio<br>Carrera Fuente San LuÃ­s, 62 -7','Valencia','Valencia','SPAIN','46013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:11:02',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(1826,597629152001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Å ubrt','PÅ™Ã­ÄnÃ¡ 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 11:32:20',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1827,636290176002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Å ubrt','PÅ™Ã­ÄnÃ¡ 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 11:32:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rå•ç¯å¤´  1 æ¬§æ ‡ \råå…‰ä¼ž  1\r115w 220v  1 \ré‡é‡ï¼ŸRR723016351CN\r'),(1828,597633560001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','captaindanieo','josedanielps@gmail.com','Jose Daniel PÃ©rez Serralvo','Escritor Angel Palomino nÂº3 bq1 2ÂºC','Torremolinos (MÃ¡laga)','AndalucÃ­a Ceuta y Melilla','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 11:50:08',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143101CN'),(1829,636020910002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','kenaram55','dafzal@yahoo.com','Dawood Afzal','1403 Queens Ct<br>Apt C','Kirksville','MO','UNITED STATES','63501-2798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 12:53:58',0,NULL,3,1,1,1,NULL,' '),(1830,597657077001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','digital-nala','dzt2000@hotmail.com','Gang-hun Lee','314-55, 2F<br>Inchang-dong','Guri-si','Gyeonggi-do','KOREA,REPUBLIC OF','471-833','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 13:17:47',0,NULL,3,1,2,1,NULL,''),(1831,635529093002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ejar5071','teddy2084428@yahoo.com','Elzbieta Jaracz','6009 69th ave<br>1Fl','Ridgewood','NY','UNITED STATES','11385-5139','(718) 366-3958','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 13:19:13',0,NULL,3,1,1,1,NULL,' '),(1832,597681340001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','delicioussakura','shadow404@gmx.net','Katharina Barkley','3-10-19 kitahama<br>Noda bldg. 205','Beppu','Oita','JAPAN','8740920','08067875678','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 14:38:28',0,NULL,3,1,6,1,NULL,'2mx3m èƒŒæ™¯æž¶ 1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\råŒç¯å¤´  2\råå…‰ä¼ž 2\råŒ…  1\r æ–°åŠ å¡ EMS\rEX000080445SG\r'),(1833,636362685002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','brogers121','rogerscreativenh@yahoo.com','Bill Rogers','323 Powder Mill Rd','Alton','NH','UNITED STATES','03809-4937','(603) 875-8315','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 15:25:27',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRA022499075CN\r'),(1834,597721930001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','omerunlu','omerunlu@yahoo.com','Dr. DT. Omer Unlu','TepebaÅŸÄ± AÄŸÄ±z ve DiÅŸ SaÄŸlÄ±ÄŸÄ± Merkezi<br>GÃ¼Ã§lÃ¼ Kaya Mah. Fatih Cad. Ã‡aÄŸla Sok. No:2 KeÃ§iÃ¶ren','Ankara','','TURKEY','06310','4954847','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:37:07',0,NULL,3,1,2,1,NULL,''),(1836,597723574001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jeanjb2007','raptormatrix137@hotmail.com','jeanj breau','48 rue de l\'eglise','neguac','NB','CANADA','e9g 1b8','(506) 776-8795','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:41:17',0,NULL,3,1,2,1,NULL,NULL),(1837,597702193001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.2,'hermeshine','dziknsk','dkhodarenok@gmail.com','Dmitry Khodarenok','Pechatnikov str. 1-24','Novosibirsk','','RUSSIAN FEDERATION','630057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:46:10',0,NULL,3,1,2,1,NULL,' '),(1838,597728520001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',4,'AB1301',13.36,'hermeshine','malldova1st','z55001987@rambler.ru','Eugeniu Grosul','str.Podul Inalt 14/2 ap.12','Chisinau','','MOLDOVA, REPUBLIC OF','2023','37368221313','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 16:52:47',0,NULL,3,1,2,1,NULL,''),(1839,597738434001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',2,'AB3313',82.98,'hermeshine','stanshih2007','stanshihcomputers@gmail.com','Paul Khoury','530 S Lake Ave<br>Ste 350','Pasadena','CA','UNITED STATES','91101-3515','(818) 209-7168','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 17:23:29',0,NULL,3,1,1,1,NULL,''),(1840,636431803002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','diogof88','diogof1988@hotmail.com','Diogo Ferreira','Rua D.LourenÃ§o de Almeida nÂº13','Lisbon','Lisboa','PORTUGAL','1400-125','+ 351 96 86 86 080','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 18:18:37',0,NULL,3,1,2,1,NULL,NULL),(1841,678314262016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'',16.99,'hutongstore','aaronlava','letsburndownsomethingbeautiful@hotmail.co.uk','aaron leaman','25 arnison avenue','high wycombe','Buckinghamshire','UNITED KINGDOM','hp13 6dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 19:00:45',0,NULL,3,1,2,1,NULL,''),(1842,636464235002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','mannel2411','t092728s@terra.es','Manuel Hernandez Garcia','Avda. Ventisquero de la Condesa, 7, ptal. B, 4Âº D','MADRID','Madrid','SPAIN','28035','913 76 51 90','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 19:11:10',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(1843,597804968001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','sekstiseks','syttisyv@gmail.com','Fredrik Aasland','GrÃ¥steinveien 20','OSLO','OSLO','NORWAY','1157','004790162108','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 19:31:35',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016285CN\r'),(1844,636475794002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','nurzur','kristijan.vuckovic@gmail.com','Kristijan Vuckovic','Ruziceva 31','Rijeka','Croatia','CROATIA','51000','+385917361999','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 19:32:21',0,NULL,3,1,2,1,NULL,''),(1845,691795151015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'',2.75,'hutongstore','jasonpm007','jpmarsh007@gmail.com','jason marsh','104 tamar house james street devonport','plymouth','Devon','UNITED KINGDOM','pl1 4hj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 20:12:52',0,NULL,3,1,2,1,NULL,'5åˆ1 çº¢å¤–é¥æŽ§   1 '),(1846,597821403001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','radubogdan87','radu.bogdan@yahoo.com','Bogdan Radu','133 Stefan cel Mare Street','Sibiu','Sibiu','ROMANIA','550321','0040727821388','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 20:17:20',0,NULL,3,1,2,1,NULL,''),(1847,597830979001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','spacylittlecowgirl','fyrelyzard@yahoo.com','Florence Chan','16 Dallimore Circle<br>Unit #201','North York','ON','CANADA','M3C 4C4','(416) 919-1761','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 20:18:48',0,NULL,3,1,3,1,NULL,'52mm-77mm æŽ¥å£çŽ¯  ä¸€å¥—\ræ‰˜æž¶  1 \rRA022499225CN\r'),(1848,633100236002,120562082179,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'AO0002',96.8,'hermeshine','strelez57','nnproton612@gmail.com','ARKADY RABINOVICH','YEHUDA HAMACCABI 31room2','ASHDOD','','ISRAEL','77544','','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2010-11-23 20:24:47',0,NULL,3,1,8,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  1 \rCP212235065CN\r'),(1849,691817373015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','hastingsseagulls','kurtvinz@hotmail.com','vincent geli','2-4 holmesdale garden flat 12 furness mount','hastings','East Sussex','UNITED KINGDOM','tn34 1ly','01424425076','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 20:46:52',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ S1  1 '),(1850,636526157002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','alejasena16041983','alejasena@hotmail.com','Vanessa HernÃ¡ndez MuÃ±oz','C/La Chercha. NÂº77<br>La Gallega','Santa Cruz de Tenerife','Canarias','SPAIN','38107','686920799','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 20:59:12',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  1\r2m ç¯æž¶  2\råŒç¯å¤´ 2 æ¬§æ ‡\råå…‰ä¼ž  2\r115w 220v   4\råŒ…   1\rlighting kit $30\r YW864143112CN\r'),(1851,636533253002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','spos86','spos86@gmail.com','Paolo Esposito','606 Greenville Ave','Staunton','VA','UNITED STATES','24401','(301) 237-3689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-23 21:12:49',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(1852,595641522001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','minoltiano_es','hgb@wanadoo.es','HIGINIO GOMEZ BARRERAS','C/ Manzanares, 15 - 1Âº A','La Penilla de CayÃ³n','Cantabria','SPAIN','39650','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-23 22:19:36',0,NULL,3,1,3,1,NULL,'Nikon æ‘„å½±èƒŒå¿ƒ XXXL   1 \rRA022499234CN\r'),(1853,691877230015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','elsinore001','dickie.gallagher@gmail.com','Richard Gallagher','1st Floor Flat 53 Bovill Road','London','London','UNITED KINGDOM','SE23 1EX','07748430022','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-23 22:27:39',0,NULL,3,1,2,1,NULL,NULL),(1854,636573012002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','marcomention','occasionsandbeyond@yahoo.com','MARCO MENTION','4801 Baker Grove Rd NW<br>Apt 503','ACWORTH','GA','UNITED STATES','30101-6331','(404) 399-3452','NoPaymentFailure','CheckoutComplete','Other','2010-11-23 22:43:06',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRA022499248CN\r'),(1855,636593418002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tlee02','tlee83@gmail.com','Taehune Lee','3101 N Hampton Dr<br>Apt 314','Alexandria','VA','UNITED STATES','22302-1520','(806) 681-1614','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-23 23:42:01',0,NULL,3,1,1,1,NULL,NULL),(1856,597916466001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',29.4,'hermeshine','f.lopes10','almirflmoura@yahoo.com.br','almir fontes lopes de moura','av.oliveira bello n 1179 /301<br>vila da penha','rio de janeiro','RI','BRAZIL','21221-300','212481-1985','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:47:49',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(1857,597916273001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','susnosversus','susnosversus@gmail.com','diego galvan','gran via 12  6Âºdcha','San Sebastian','PaÃ­s Vasco','SPAIN','20002','675592652','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:48:46',0,NULL,3,1,2,1,NULL,'115w 220v   1 '),(1858,597917681001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','jayaraujo','jay@lacedinteractive.com','JOAO LUIZ MARQUES ARAUJO JR','Rua Fidalma Martins de Carvalho 4355<br>Bloco 2 - Apartamento 202 Bairro Ininga','Teresina','Piaui','BRAZIL','64048-190','+55 86 3237 1915','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-23 23:49:55',0,NULL,3,1,3,1,NULL,'çº¢å¤´ç¯  1\r800w 220v  1\ræŽ§åˆ¶é‡é‡2kgä»¥ä¸‹ \rRA022499251CN\r'),(1859,636605442002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','f.lopes10','almirflmoura@yahoo.com.br','almir fontes lopes de moura','av.oliveira bello n 1179 /301<br>vila da penha','rio de janeiro','RI','BRAZIL','21221-300','212481-1985','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 00:24:42',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶ 1\ræ–œè‡‚  1\r50-70 æ£š  1 \rå•ç¯å¤´ 3 \ræ£€æŸ¥ä¸€ä¸‹è¦æ˜¯ç¾Žæ ‡çš„\r3300ï¼Ÿ\rCP212150572CN\r'),(1860,636617212002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mariepiert90','marie_pier_t90@msn.com','marie-pier Tremblay','495 J.R.ThÃ©berge','chicoutimi','QC','CANADA','g7j 3s3','(418) 545-3473','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 01:08:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723016215CN\r'),(1861,596205163001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','jkobcso','jko@zoomtown.com','Jennifer Kotzbauer','4655 Catalpa Ct','Burlington','KY','UNITED STATES','41005','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 01:16:09',0,NULL,3,1,1,1,NULL,'ä¸­å·é•œå¤´ç­’  1 '),(1862,597118309001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',52.99,'hermeshine','sonjarothwell888','sonja_888@hotmail.com','Sonja Rothwell','P.O. Box 1178','Wangaratta','Victoria','AUSTRALIA','3677','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-11-24 01:42:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\räº‘å° 1\ræŸ”å…‰ä¼ž  1 \rRA022499163CN\r'),(1863,597946063001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','kufrik','stano1@optonline.net','Stanislav Repko','251 PORT READING AVE','PORT READING','NJ','UNITED STATES','07064-1925','(908) 787-5249','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-24 01:46:50',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(1864,597528493001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','93nx2k','93nx2k+ebay@gmail.com','Vinnie Nguyen','PO Box 21802','San Jose','CA','UNITED STATES','95151-1802','(408) 828-4237','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 02:16:15',0,NULL,3,1,1,1,NULL,NULL),(1865,597476536001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 03:25:52',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRA022499177CN\r'),(1866,636666197002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',3,'AA1309',7.4,'hermeshine','danit8569','danit6985@yahoo.com','Daniel Dyar','8020 Sunny Ln','Fort Wayne','IN','UNITED STATES','46835','(812) 278-6172','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 04:26:05',0,NULL,3,1,1,1,NULL,NULL),(1867,636670557002,120601698793,'Canon 58mm Reverse Adapter 50mm 1.4 40D 7D 5DII Macro',1,'AA1208',4.4,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:58',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1868,636670448002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:58',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1869,636670497002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3401',2.6,'hermeshine','james007th','viman_w@yahoo.com','wiman worasiriwat','kp house 9 sukhumvit 62 road<br>yak3 soi rim-tang-daun 4 bangchak','prakhanong','bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 04:50:59',0,NULL,3,1,2,1,NULL,'580ex è‚¥çš‚ç›’ 1\r58mm - canon åæŽ¥çŽ¯  1\r72mm é•œå¤´ç›–  canon  1'),(1870,597989110001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',75,'hermeshine','tecworks10','citizengav-1@yahoo.com.au','Wallace Gavin Lardner','13/5 Clancy Crt','Tugun','Queensland','AUSTRALIA','4224','0756070458','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2010-11-24 05:07:41',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rç¯æž¶  1\rRR723016229CN\r'),(1871,636682472002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','proforica','profor@vanea.net','IVAN PROFOR','Sciusev 4/8','Balti','Balti','MOLDOVA, REPUBLIC OF','3100','37369833368','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 06:01:34',0,NULL,3,1,3,1,NULL,' 2mç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1\r\rRR723016232CN\r'),(1872,636687268002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','anko3452','busi4avk@gmail.com','Andrey Kozhevnikov','proezd Solnechny 5 - 109','Tyumen','','RUSSIAN FEDERATION','625022','+79058201992','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:34:02',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(1873,597899410001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',6.6,'hermeshine','pekesurf','kaslokapacha@hotmail.com','Esther GarcÃ­a','Petrarca 6,  3Âº  2Âª','Sabadell','Barcelona','SPAIN','08206','937171609','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:46:38',0,NULL,3,1,2,1,NULL,'52mm uv   2 '),(1874,598005408001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','photos6288','ttocsm@gmail.com','Matt Scott','14 Cantonments Rd<br>Lyttelton Manor','Centurion','Gauteng','SOUTH AFRICA','0157','0732128584','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 06:55:06',0,NULL,3,1,2,1,NULL,NULL),(1875,598008554001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','miroslavkatrak','miroslav.katrak@gmail.com','Miroslav Katrak','VyÅ¡nÃ¡<br>5','KoÅ¡ice Slovakia','','SLOVAK REPUBLIC','00421','00421907481988','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 07:46:01',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1 æ¬§æ ‡\r '),(1876,636703217002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','balintkiss','valentine969@gmail.com','Strasser Katalin','Kassai utca 166/b','Budapest','Pest','HUNGARY','1142','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 08:07:45',0,NULL,3,1,3,1,NULL,'RR723016294CN\r'),(1877,636246783002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 08:41:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723016246CN\r'),(1878,636477825002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','acesnakas','a.cesnakas@gmail.com','Audrius Cesnakas','Ukmerges g. 224-42','VILNIUS','','LITHUANIA','07162','+37060166236','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 08:54:38',0,NULL,3,1,2,1,NULL,NULL),(1879,598037037001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','vaidas.m','turistas30@hotmail.com','Vaidas Morkevicius','R.Jukneviciaus 48-41','Marijampole','','LITHUANIA','68201','+37065994399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 09:40:36',0,NULL,3,1,2,1,NULL,NULL),(1880,598040658001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','tarmarlai','tarja.laitinen@gmail.com','Tarja Laitinen','Niittykallio 2 F 48','ESPOO','','FINLAND','02200','+358 40 709 5731','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 09:56:15',0,NULL,3,1,2,1,NULL,'115w 220v  1 '),(1881,689503733015,250692239871,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'',46.9,'hutongstore','2009yazza','blondy_x_1990@hotmail.com','yasmin graham','32 cromwell close walcote','lutterworth','Leicestershire','UNITED KINGDOM','LE17 4JJ','01455698987','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-24 10:00:07',0,NULL,3,1,4,1,NULL,'background support  $20 \rYW864143263CN'),(1883,692100073015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','voldinsh','valdis.andersons@apollo.lv','Valdis Andersons','21, Ventas Str.','Liepaja','','LATVIA','LV-3407','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 11:45:34',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(1884,598077476001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',2,'AB3307',99.98,'hermeshine','luizacfbr','luizacf@gmail.com','Luiz Ferreira','R Pedroso , 486 cj 44','Sao Paulo','sp','BRAZIL','01322010','55 11 32894599','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 12:23:13',0,NULL,3,1,10,1,NULL,'sf18-canon   2 RF052234730SG8\r'),(1885,598083473001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','shemeshmor','mor@shafit.com','mor shemesh','kfar warburg','kfar warburg','','ISRAEL','70998','972544726838','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 12:45:38',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1 '),(1886,636772519002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','stelevan','stelevan@yahoo.it','Stefano Cristiani','Corso Cavour 118 c/o chiosco edicola','Barletta','BA','ITALY','70051','3477947366','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 12:57:16',0,NULL,3,1,2,1,NULL,''),(1887,678692705016,260660054309,'Shutter Release Remote Cord For Canon 550D 450D RS-60E3',1,'',2.98,'hutongstore','larslidgren','larlid@gmail.com','Lars Lidgren','Thulegatan 7','HÃ¤ssleholm','Sweden','SWEDEN','28139','4645141201','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 13:25:37',0,NULL,3,1,2,1,NULL,'RS-C1   1 '),(1888,692156743015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','khaledroshdy','khaledroshdy@hotmail.com','Khaled Roshdy','19 The Quadrangle','Manchester','Greater Manchester','UNITED KINGDOM','M1 5QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 14:25:24',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(1889,692163847015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','utchyba','bd4vy@aol.com','craig davy','42 montague road, north end','portsmouth','hampshire','UNITED KINGDOM','po2 0nf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 14:41:50',0,NULL,3,1,2,1,NULL,'45w   2 '),(1890,636824473002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','rockelis','rokas.rokelis@gmail.com','Rokas Bubelis','Taikos pr. 58-24','Kaunas','','LITHUANIA','51303','+37062769295','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 15:40:24',0,NULL,3,1,3,1,NULL,'ç”³æŠ¥ gift $10 \rRA022499305CN\r'),(1891,598141389001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','vader2501','jim_jaroo@yahoo.co.uk','john morris','31 Alwen<br>Plas Madoc','Wrexham','Wrexham','UNITED KINGDOM','LL14 3ET','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 15:54:55',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ é»‘ï¼‰  1 \rbackground support  $25\rYW864143171CN\r'),(1892,598145011001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',3,'AB1303',10.02,'hermeshine','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 15:59:41',0,NULL,3,1,2,1,NULL,''),(1893,598168747001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','roodyroody','ojilly@gmail.com','Jill Petersen','36 Settler\'s Landing Drive','Belleville','ON','CANADA','K8N 4Z2','(613) 969-9860','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 17:01:47',0,NULL,3,1,2,1,NULL,NULL),(1894,598182213001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','kobiavr69','kobiavraham69@yahoo.com','kobi avraham','Ben Hur 4/12<br>Em Hamoshavot','Petach Tikva','','ISRAEL','49063','+972578124269','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 17:33:19',0,NULL,3,1,2,1,NULL,'æŸ¥ï¼Œåº”è¯¥æ˜¯æ¼å‘äº† '),(1895,598192306001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jfreyesjr','rjj2jljr2@yahoo.com','JOSE REYES','10527 W Chautauga MTN','LITTLETON','CO','UNITED STATES','80127-3858','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 17:53:05',0,NULL,3,1,1,1,NULL,' '),(1896,598214173001,110566018900,'EW-73II Lens Hood lenshood for Canon EF 24-85 /f3.5-4.5',1,'AA3404',8.99,'hermeshine','rick42d','rick42@waterw.com','Richard DeCristofaro','18 Fir Lane','Voorhees','NJ','UNITED STATES','08043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 18:38:30',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1897,636903830002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','rick42d','rick42@waterw.com','Richard DeCristofaro','18 Fir Lane','Voorhees','NJ','UNITED STATES','08043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 18:39:45',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›– canon  1\rEW-73II   1 '),(1898,636924115002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','n8ciz','combs6136@yahoo.com','carl a. combs','2288 Oxford Middletown Rd','hamilton','OH','UNITED STATES','45013-9751','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 19:18:46',0,NULL,3,1,1,1,NULL,NULL),(1899,692313607015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','gab00pok','gabriel.vigo@gmail.com','Gabriel Vigo','207 Odessa Road','London','London','UNITED KINGDOM','E79DX','07957308234','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 19:22:12',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRA022499217CN\r'),(1900,692341153015,250666866568,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'',62,'hutongstore','2bstylish','mamaliebox-ebay@yahoo.co.uk','Mr M Parkook','31 Grahame Park Way','Mill Hill','London','UNITED KINGDOM','NW7 2LA','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-24 20:03:03',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1\r50-70 æ£š  1\r115w 220v  1\rYW864143252CN\rlighting kit  $22'),(1901,598253897001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','viva_villa_productions','247help@vivipro.org','Guillermo Villa','810 E 14th St<br>Ste 193','Brownsville','TX','UNITED STATES','78520-5714','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 20:13:07',0,NULL,3,1,1,1,NULL,NULL),(1902,636964035002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','radkolesay','rlesay@gmail.com','Radoslav Lesay','530 Riverdale Ave<br>Apt 6K','Yonkers','NY','UNITED STATES','10705-3558','(646) 620-1190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-24 20:26:19',0,NULL,3,1,1,1,NULL,''),(1904,597863917001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',4,'AB1302',26.72,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-24 20:38:14',0,NULL,3,1,3,1,NULL,'55mm æ©¡èƒ¶ç½©  4\r58mm æ©¡èƒ¶ç½©   4\rRA022499279CN\r'),(1905,598291783001,110471802137,'New Rotate Flash Bracket for Canon Nikon VH 2000',1,'AB3316',25.99,'hermeshine','jpyem','wgwxnuso@panamanetbuy.com','Panama Netbuy','8424 NW 56th St<br>Ste PTY-1779','Doral','FL','UNITED STATES','33166-3327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 21:00:50',0,NULL,3,1,1,1,NULL,'Låž‹æ”¯æž¶  1 \ré‡é‡'),(1906,692394782015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','debian.user','peter@millarduk.com','peter millard','10 Antrim Close','basingstoke','Hampshire','UNITED KINGDOM','RG22 5BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-24 21:22:00',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1 '),(1907,598304832001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ivarsk9598','ivars.kukainis@apollo.lv','Ivars Kukainis','Valdeku 50/1-33','Riga','Latvia','LATVIA','LV-1058','+37126549201','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-24 21:29:57',0,NULL,3,1,3,1,NULL,'æ–°çš„é‚£ä¸ªç¯æž¶  1\ré‡é‡ï¼Ÿ 1595\rRA022499282CN\r'),(1908,636998523002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','tingzhao1688','vincent82123@hotmail.com','Min Wong','10352 Stone Ave N<br>Apt 6','seattle','WA','UNITED STATES','98133-9494','(206) 605-3138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 21:31:03',0,NULL,3,1,1,1,NULL,' '),(1909,692409652015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','meretemusen','jon@enovo.dk','Merete Jensen','Pebermyntevej 69 2.sal.th','Viborg','Jylland','DENMARK','8800','(0045)23270418','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-24 21:51:39',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(1911,637048629002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5,'hermeshine','kimbenstore','kimbenstore@gmail.com','Phillip Nguyen','2006 W 3rd Ave','Kennewick','WA','UNITED STATES','99336','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-24 23:52:12',0,NULL,3,1,1,1,NULL,NULL),(1912,637070164002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','jdavis9184','jeffdavis82778@gmail.com','jeffrey Davis','12689 stallion CT','Jacksonville','FL','UNITED STATES','32223-2094','(904) 260-9793','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-25 01:23:34',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\råå…‰æ¿æ”¯æž¶  1 \rYW864143230CN\rlight stand  1 '),(1915,598384943001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','dll003','dll_cisfca@yahoo.com','David Leo','730 17th Avenue','San Francisco','CA','UNITED STATES','94121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 02:18:19',0,NULL,3,1,1,1,NULL,'ä¸­å·é•œå¤´ç­’  1 '),(1916,598385323001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sonographer56','delizzio209@comcast.net','david delizzio','209 swedes run dr','delran','NJ','UNITED STATES','08075-2117','(856) 764-7825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 02:20:36',0,NULL,3,1,1,1,NULL,NULL),(1917,598393909001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cjyards588','jbpanka@juno.com','Roger Knepp','58216 Olde Towne Dr','Goshen','IN','UNITED STATES','46528-8916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 03:01:50',0,NULL,3,1,1,1,NULL,NULL),(1918,598397625001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','wyatt2502008','wyatt250@gmail.com','Mark Wyatt','409-3868<br>Shelbourne Street','Victoria','BC','CANADA','V8P5J1','(250) 590-1039','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 03:20:12',0,NULL,3,1,2,1,NULL,NULL),(1919,637101276002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','plumcrazy65','mike@plumcrazy.ca','Michael McLaughlin','6715 Cools Rd','Vernon','BC','CANADA','V1B3T2','(250) 542-7022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 03:47:42',0,NULL,3,1,2,1,NULL,NULL),(1927,598467975001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','semircok','gurnik@gmail.com','Marianna Janeczkova','Galakticka 34','Kosice','Slovakia','SLOVAK REPUBLIC','04012','+421911100700','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 10:07:52',0,NULL,3,1,2,1,NULL,NULL),(1928,597577712001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mrgattermaier','gattermaier@ig.com.br','Oscar Gattermaier Junior','Gorge Road<br>47/159','Queenstown','Otago','NEW ZEALAND','9300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 10:55:52',0,NULL,3,1,2,1,NULL,' '),(1929,679186158016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','monkjunior','dave@davewhite.com.au','David J White','PO Box 599','Waverley','New South Wales','AUSTRALIA','2024','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-25 12:08:32',0,NULL,3,1,6,1,NULL,' 2mx3mèƒŒæ™¯æž¶ 1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶ 2\r50-70æ£š æ¾³æ ‡  2\r115w 220v   2\råŒ…   1\rçœ‹çœ‹ä½“ç§¯æ˜¯å¦å¯ä»¥å‘æ–°åŠ å¡ems\rEX000041637SG'),(1930,637203512002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','salaba_tadeas','salaba.tadeas@yahoo.com','Tadeas Salaba','Dolni Libchavy 261<br>Libchavy','Usti nad Orlici','CZECH','CZECH REPUBLIC','56116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 12:27:17',0,NULL,3,1,2,1,NULL,'éº‚çš®  1'),(1931,598511081001,110502563166,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA1310',4.5,'hermeshine','jayachands18','mjaya18@gmail.com','MURUGESAN JAYA CHANDRAN','NANBATASINDEN 96-8<br>TAKUMI ENGG. CO. LTD., ROOM NO : 101','FUJIMI SHI','Saitama','JAPAN','354-0003','+81-90-6642-0363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 13:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1932,598511655001,110502563166,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA1310',4.5,'hermeshine','jayachands18','mjaya18@gmail.com','MURUGESAN JAYA CHANDRAN','NANBATASINDEN 96-8<br>TAKUMI ENGG. CO. LTD., ROOM NO : 101','FUJIMI SHI','Saitama','JAPAN','354-0003','+81-90-6642-0363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 13:05:00',0,NULL,3,1,2,1,NULL,'77mm uv  2 '),(1933,598532534001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','ddsnyc','artdds@gmail.com','Arthur Yam','19 Skytop Rd','Edison','NJ','UNITED STATES','08820','','NoPaymentFailure','CheckoutComplete','Other','2010-11-25 14:16:35',0,NULL,3,1,1,1,NULL,NULL),(1934,598536041001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mindofdead','akrutofalov@gmail.com','Aleksey Krutofalov','Russia, Moscow, ul. Svobody,  dom 91, kv. 164','Moscow','','RUSSIAN FEDERATION','125481','+79167850747','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 14:36:20',0,NULL,3,1,2,1,NULL,NULL),(1935,679246999016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','kebippi','roahpe@gmail.com','Antti Soini','Portaankorvankatu 5','Tampere','','FINLAND','33820','+358407614849','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-25 15:04:27',0,NULL,3,1,2,1,NULL,' é•œå¤´ç­’ xl å¤§å·  1'),(1936,637254984002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','cedricma','cedric.marchand@laposte.net','Cedric Marchand','10  Avenue Nelson Mandela','Tremblay en France','Ile-de-France','FRANCE','93290','09 50 31 84 55','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 15:21:17',0,NULL,3,1,2,1,NULL,NULL),(1937,598554103001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rkharbuck','gharbuck@gmail.com','Regina Harbuck','823 Creek Trl','Anniston','AL','UNITED STATES','36206-1043','(256) 820-9120','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 15:25:43',0,NULL,5,1,18,0,NULL,NULL),(1938,637273202002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','dingc9','charlie@charlieding.com','Charlie Ding','Flat K, Wolfson House<br>49 Weston Street','London','London','UNITED KINGDOM','SE1 3RB','07812218123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-11-25 16:13:31',0,NULL,3,1,2,1,NULL,'NG200   1 '),(1939,598569809001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','sxgreenee','sxgreenee@gmail.com','Pedro Martins','Rua do Cantinho, 13<br>Ceflar','CANTANHEDE','PORTUGAL','PORTUGAL','3060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 16:22:10',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143215CN\ré‚®ç¼–æ˜¯3060225\r'),(1940,598579528001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',22,'hermeshine','linxaut','linxautomacao@terra.com.br','Sandro G. Mabilia','RUA BORTOLO ZANI, 97, SALA 1<br>B. CRUZEIRO','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','+55 054 32285664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 16:37:01',0,NULL,3,1,2,1,NULL,' '),(1941,598579908001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','ydna52','andywinfield@sbcglobal.net','Jack winfield','115 Jasmine Way','East Palo Alto','CA','UNITED STATES','94303','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 16:38:50',0,NULL,3,1,1,1,NULL,NULL),(1942,637287947002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 16:58:22',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š  2\r45w 220v  8\råŒ…  1 \råå…‰æ¿æ”¯æž¶  1\r2mç¯æž¶  1\ré‡é‡\rCP212150586CN\r'),(1943,636120147002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 16:58:23',0,NULL,5,1,18,0,NULL,'å‘ä¸‹åˆå¹¶ '),(1944,637303992002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','jonathangrandmont','jonathangrandmont@hotmail.com','Jonathan Grandmont','1180 rang 4','Saint-Cyrille-de-Wendover','QC','CANADA','j1z 1t7','(819) 397-4686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 17:29:23',0,NULL,3,1,2,1,NULL,' '),(1945,637306176002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','sagebrushnomad','tanja_henderson@yahoo.com','roderik henderson','palmar de ocoa 743<br>palmas de chimba','copiapo','atacama','CHILE','1535037','(568) 493-4565','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 17:37:01',0,NULL,3,1,2,1,NULL,NULL),(1946,598623713001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','motero34juan','joninza@hotmail.com','Juan Antonio Inza','Plaza Harrobieta NÂº15 1Âº C','San Sebastian','Guipuzcoa','SPAIN','20017','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 18:21:18',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143075CN'),(1947,637344748002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','sharkwobbegong','greenworksus@yahoo.com','R. Brian Green','837 Hcr 1313','Hillsboro','TX','UNITED STATES','76645-5052','(254) 744-5760','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 19:00:36',0,NULL,3,1,1,1,NULL,' '),(1948,637351251002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','th_rjs','th_rjs@yahoo.com','Rajesh Thapa','5616 EL DORADO AVE<br>Apt 2','El Cerrito','CA','UNITED STATES','94530-3434','(415) 425-3068','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 19:11:33',0,NULL,3,1,1,1,NULL,NULL),(1949,637400811002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mmcgheejr','saugerman@comcast.net','Rick and Tiffany Mayberry','150 Old Coalfield Rd','Harriman','TN','UNITED STATES','37748-4316','(865) 882-2610','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 20:45:12',0,NULL,3,1,1,1,NULL,NULL),(1950,598697736001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','tal_blit1','tal_blit@yahoo.com','Tal Blitstein','Shlomo 8','Petach Tikva','Israel','ISRAEL','49581','972508631347','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:49:21',0,NULL,3,1,11,1,NULL,NULL),(1951,637403542002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','ivarsk9598','ivars.kukainis@apollo.lv','Ivars Kukainis','Valdeku 50/1-33','Riga','Latvia','LATVIA','LV-1058','+37126549201','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:50:53',0,NULL,3,1,3,1,NULL,' 50-70é€šç”¨å¡å£ æ£š  1\ræˆ‘æ¥\ré‡é‡639\rRA022499910CN\r'),(1952,637181237002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','melinabeads','ermushina@mail.ru','Yuriy Ermushin','Krasnyi pereulok d. 2  kv. 271','Aleksandrov','Vladimirskaya oblast','RUSSIAN FEDERATION','601650','+79066155124','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 20:55:29',0,NULL,3,1,2,1,NULL,' '),(1953,679443921016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','damrua','dam.rua@googlemail.com','Davide Rua','109 Wentworth Road','CROYDON','Surrey','UNITED KINGDOM','CR0 3HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-25 21:11:15',0,NULL,3,1,2,1,NULL,NULL),(1954,637423452002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','olivierludsko','odulieu@yahoo.fr','Olivier Dulieu / PMU EQUIDIA','165 boulevard de Valmy<br>Batiment D porte 401','Colombes','Ile-de-France','FRANCE','92700','0682932662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 21:38:29',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1955,637422650002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','olivierludsko','odulieu@yahoo.fr','Olivier Dulieu / PMU EQUIDIA','165 boulevard de Valmy<br>Batiment D porte 401','Colombes','Ile-de-France','FRANCE','92700','0682932662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 21:38:30',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 \r58mm çŽ¯æž¶  1'),(1956,637414619002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','rgbman40','rgbman40@hotmail.com','Rogier Bruggeman','Hamerstraat 3','Heerlen','','NETHERLANDS','6411 cS','045-5717167','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 21:13:58',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  1  æ¬§æ ‡\råå…‰ä¼ž   1 \rRA022499866CN\r'),(1957,692907878015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','jacek.jakubas','karolina.opiola@yahoo.co.uk','JACEK JAKUBAS','42e Chalkhill Road','LONDON','Middlesex','UNITED KINGDOM','HA9 9FN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-25 21:18:30',0,NULL,3,1,2,1,NULL,NULL),(1958,637441478002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','flagator10','flagator10@hotmail.com','Charles Perry','2280 S Highway 97','Cantonment','FL','UNITED STATES','32533-9794','(859) 937-8373','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-25 22:20:48',0,NULL,3,1,1,1,NULL,NULL),(1959,637448641002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','hofferpeter','hofferpter@gmail.com','PÃ©ter Hoffer','MÃ³ricz Zs u. 10.','Tapolca','VeszprÃ©m','HUNGARY','8300','36309363971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 22:41:25',0,NULL,3,1,3,1,NULL,'wf1005  1 \rRA022499954CN\r'),(1960,637452877002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','andreamaas0','andreamaasr@hotmail.com','eduardo lopez bermejo','c. simancas 60 1b','las palmas de gran canaria','Canarias','SPAIN','35010','633501622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-25 22:55:24',0,NULL,3,1,4,1,NULL,'ballhead $16 \rYW864143042CN'),(1961,598759525001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','super_best_ebuyer','nikolas99@mail.ru','ALEXANDER ISCHIMJI','8 Valea Crucii Str. Ap. 143','Chisinau','','MOLDOVA, REPUBLIC OF','2072','+373 69014721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-25 23:40:35',0,NULL,3,1,2,1,NULL,''),(1962,637469063002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','callcybercop','callcybercop@gmail.com','Naveen Gagadam','107 May Dr<br>Apt 2','Camp Hill','PA','UNITED STATES','17011-5020','(407) 579-1415','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-25 23:56:28',0,NULL,3,1,1,1,NULL,'canonä¸‰è§’åŒ…  1 '),(1963,692981474015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','neil242vnv','n.white242@yahoo.com','Neil white','232 bramford lane','Ipswich','Suffolk','UNITED KINGDOM','ip1 4ep','01473744030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 00:29:39',0,NULL,3,1,2,1,NULL,' çˆµå½±æ— çº¿ S1  1 '),(1964,692998840015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'',1.88,'hutongstore','thejamstrangler','box.andy1@googlemail.com','andy box','106 randwick drive','worcester','Worcestershire','UNITED KINGDOM','WR4 9LR','01905452858','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 01:40:24',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›– Nikon   1 '),(1965,637513914002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pnd-nsw','pnd@zip.com.au','Paul Douriaguine','55 Montview Pde','Hornsby Heights','New South Wales','AUSTRALIA','2077','0413009303','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 03:19:17',0,NULL,3,1,3,1,NULL,' RA022499945CN\r'),(1966,637515510002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','shawnd0520','shawnd0520@comcast.net','Shawn Douglas','601 Amy Cir','Bryant','AR','UNITED STATES','72022-4116','(501) 626-2800','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 03:27:37',0,NULL,3,1,1,1,NULL,NULL),(1967,598805724001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jlmsid09','jlmsid@gmail.com','Jose Luis Sidero','Bermejo 2386','San Justo','Buenos Aires','ARGENTINA','1754','4484-5968','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 03:36:50',0,NULL,3,1,3,1,NULL,' RA022499937CN\r'),(1968,637521077002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','philhogansr','philhogansr@msn.com','Phil  Hogan','27269 Terrytown Rd','Sun City','CA','UNITED STATES','92586-3210','(951) 837-3224','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 03:57:30',0,NULL,3,1,1,1,NULL,NULL),(1969,637538016002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','mattisal','mattisal@hotmail.com','Matti Salminen','Vanhakartanontie 38','Pori','','FINLAND','28660','+358443552886','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 05:44:43',0,NULL,3,1,3,1,NULL,' RA022499923CN\r'),(1970,598832351001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','just.one.more.deck','imdillinger@yahoo.com','Justin MArtens','39355 Calistoga Dr','Murrieta','CA','UNITED STATES','92563-6805','(951) 323-1135','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 06:32:23',0,NULL,3,1,1,1,NULL,' '),(1971,637556132002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','sudeepmandal','sudeepmandal@gmail.com','Sudeep Mandal','880 East St<br>Apt 1A','Lee','MA','UNITED STATES','01238-9120','(607) 342-4772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 07:39:51',0,NULL,3,1,1,1,NULL,'æ²¡å‘ \råº”è¯¥æ²¡å‘'),(1972,598849360001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','valkeajoki1','valkeajoki@gmail.com','Jussi Valkeajoki','Makikuja 3','Orivesi','','FINLAND','35300','358452308491','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 08:09:16',0,NULL,3,1,2,1,NULL,NULL),(1973,637565123002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','valkeajoki1','valkeajoki@gmail.com','Jussi Valkeajoki','Makikuja 3','Orivesi','','FINLAND','35300','358452308491','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 08:27:29',0,NULL,5,1,3,1,NULL,NULL),(1974,637574911002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alex-yuger','brn_karamel@mail.ru','Aleksey Germanov','Entuziastov 42/64','Barnaul','Altayskiy','RUSSIAN FEDERATION','656065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 09:14:42',0,NULL,3,1,2,1,NULL,'é€’å››æ–¹ '),(1975,598866328001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','heilyninette','jailynin@hotmail.com','Claudio Gabriel Ceino Gordillo','Via Gastaldi 9A-9<br>16043','Chiavari (GE)','GE','ITALY','16043','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 09:33:39',0,NULL,3,1,4,1,NULL,'tripod dolly  $20\rYW864143241CN'),(1976,598868452001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ramab80','rama_bungaroo@yahoo.com','Rama Bungaroo','Morcellement Diocese','Rose Belle','','MAURITIUS','230','2306274473','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 09:39:34',0,NULL,3,1,3,1,NULL,'æ–°çš„é‚£ä¸ªç¯æž¶ \rRA022500003CN\r'),(1977,598868463001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','taladrin.simon','taladrin@andaluciajunta.es','Jose Luis SimÃ³nLÃ³pez','C/ CÃ¡novas del Castillo nÂº14 2ÂºB','AlcalÃ¡ de Henares','Madrid','SPAIN','28807','619661971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 09:42:57',0,NULL,3,1,2,1,NULL,'é€’å››æ–¹ '),(1978,637592277002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pa.85','patriciag1985@hotmail.com','Patricia Garcia Canut','C/ JoaquÃ­n Rodrigo nÂº9; 5Âº B','Zaragoza (Zaragoza)','AragÃ³n','SPAIN','50012','679778843','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 10:30:08',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1RR723016776CN\r'),(1979,679665574016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',4,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1980,693126065015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',3,'',5.64,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:03:03',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1981,693129436015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:07:42',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1982,679666492016,260660056106,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',4.8,'hutongstore','robperfectmo','rob@vision-thing.com','Rob Alexander','Perfect Motion Media The Media Centre, 15 - 17 Middle Street','Brighton','East Sussex','UNITED KINGDOM','BN1 1AL','01273806099','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:09:35',0,NULL,3,1,2,1,NULL,NULL),(1983,693129934015,250692242614,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',1,'',2.4,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:20:16',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(1984,693128824015,250692242108,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',2,'',4.8,'hutongstore','homemadeah47','alfred@hoole.myzen.co.uk','Alfred Hoole','14 Queen Elizabeth Crescent','Accrington','Lancashire','UNITED KINGDOM','BB52AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 11:05:45',0,NULL,3,1,3,1,NULL,'52mm é•œå¤´ç›–  Nikon  2\r62mm é•œå¤´ç›– Nikon  2\r67mm é•œå¤´ç›– Nikon  1 \r72mm é•œå¤´ç›– Nikon  1\r77mm é•œå¤´ç›– Nikon  3RR723016966CN\r'),(1985,598901136001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','flowfr','florian.casse.mail@gmail.com','Florian CASSE','9 rue des Marronniers','Paris','ÃŽle-de-France','FRANCE','75016','06.65.21.99.18','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 11:48:55',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1986,598900873001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','flowfr','florian.casse.mail@gmail.com','Florian CASSE','9 rue des Marronniers','Paris','ÃŽle-de-France','FRANCE','75016','06.65.21.99.18','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 11:48:55',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… æ— å­— 1\r67mm uv   1 '),(1987,598908966001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 12:20:31',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(1988,598908035001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 12:20:32',0,NULL,3,1,3,1,NULL,'Nikon æ‘„å½±èƒŒå¿ƒ xxxl  1\råŽŸåŽ‚nikon èƒŒå¿ƒ xl  1 RR723016816CN\r'),(1989,637621908002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ivofotev','ivofotev@yahoo.com','Ivo Fotev','42 Traiko Kitanchev str','Bourgas','Bourgas','BULGARIA','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:30:28',0,NULL,3,1,2,1,NULL,NULL),(1990,598912660001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','salihovic.almir','salihovic.almir@gmail.com','Almir Salihovic','Hasana Brkica 9','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','+38761190745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:32:41',0,NULL,3,1,2,1,NULL,NULL),(1991,598915577001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','compilog','iromeo77@ya.ru','Roman Ivlev','Kronverskiy pr., d.59, kv.30','Saint-Petersburg','','RUSSIAN FEDERATION','197198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 12:43:09',0,NULL,3,1,2,1,NULL,' '),(1992,597037499001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 13:50:47',0,NULL,3,1,3,1,NULL,'ç¢—ç½© P1   1 RR723016997CN\r'),(1993,637649332002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 13:59:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 RR723016855CN\r'),(1994,598939727001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','num_r','numchai_g@yahoo.com','Numchai Rungratpatana','22/58 M.6  Phahonyothin road<br>Saimai      Saimai','Bangkok','THAILAND','THAILAND','10220','0813432318','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 14:06:42',0,NULL,3,1,2,1,NULL,''),(1995,637652269002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sistersobeautiful','director@ilcaffediroma.com.sg','Gina Tan/Preston Chang','300 Tanjong Katong Road<br>02-08 Chelsea Lodge','default','','SINGAPORE','437083','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 14:08:39',0,NULL,3,1,11,1,NULL,NULL),(1996,637632417002,120565901367,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','dsbarlow','diretoria@culturainglesapb.com.br','Davidrlow Ba','Av Epitacio Pessoa 2953','Joao Pessoa ','Paraiba','BRAZIL','58030002','83 88025330','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-26 15:29:46',0,NULL,3,1,5,1,NULL,'717 135cm  1 \rCP212150569CN\r'),(1997,679773660016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','mollyrice007','rbeip@hotmail.co.uk','M Kitchen','16 Newfield Road','Liss','Hampshire','UNITED KINGDOM','GU33 7BW','01730890006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 16:00:26',0,NULL,3,1,2,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ  1 '),(1998,598982260001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','sekstiseks','syttisyv@gmail.com','Fredrik Aasland','GrÃ¥steinveien 20','OSLO','OSLO','NORWAY','1157','004790162108','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 16:11:00',0,NULL,3,1,2,1,NULL,NULL),(1999,598982446001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 16:11:55',0,NULL,5,1,2,1,NULL,'å‘ä¸Šåˆå¹¶ '),(2000,637704407002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',3,'AA1305',7.4,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:04',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2001,637703605002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',3,'AA1303',7.4,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:04',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2002,598989307001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','briankauf','briankauf@gmail.com','Main','5705 Merlin St.','Fitchburg','WI','UNITED STATES','53711','(608) 469-4359','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 16:31:05',0,NULL,3,1,1,1,NULL,'77mm é•œå¤´ç›–  canon 2\r72mm é•œå¤´ç›– canon 3\r52mm é•œå¤´ç›– nikon  3 '),(2003,599013992001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','brenzef','ebay@brenzef.com','R. van der Knaap','Poelruit 25','Reeuwijk','','NETHERLANDS','2811SW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:28:14',0,NULL,3,1,2,1,NULL,NULL),(2004,599015982001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','melissamustard2010','melissarjmark@hotmail.com','Melissa Mark','box 20743','Whitehorse','YT','CANADA','Y1A 7A2','(867) 633-3024 ext.: 1','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:32:53',0,NULL,3,1,11,1,NULL,NULL),(2005,599016599001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','entropia2387','amag87@hotmail.com','Ana MarÃ­a Alvarez Gonzalez','el castro nÂº38','Piedras Blancas','Asturias','SPAIN','33450','649553760','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 17:34:05',0,NULL,3,1,2,1,NULL,NULL),(2006,637761340002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','atlas125','tpapa23@hotmail.com','Thomas Papanikolaou','4270 Vilamoura Dr','Avon','OH','UNITED STATES','44011-3753','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 18:36:20',0,NULL,3,1,1,1,NULL,NULL),(2007,679874622016,260661403826,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'',5.78,'hutongstore','tp472007','terho.paavilainen@elisanet.fi','Terho Paavilainen','Virolahdentie 385','Viljakkala','','FINLAND','39310','358414450082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-26 19:09:33',0,NULL,3,1,2,1,NULL,' '),(2008,637789772002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','guita000','big004@hotmail.com','Mr. Chaiwat Lertwongchaikul','99/178 moo3 Soikamnanmaen28, Eakchai Road,<br>Bangkuntian,Jomthong, Bangkok 10150 Thailand','default','BA','THAILAND','10150','+66865498234','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 19:31:00',0,NULL,3,1,2,1,NULL,''),(2009,637454473002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',5,'AA1303',12.2,'hermeshine','ilya-narizniy','narizniy@ukr.net','illia naryzhnyi','Gritsevca st., 11-a, 22','Kharkiv','','UKRAINE','61172','(050) 403-6544','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 20:10:23',0,NULL,3,1,3,1,NULL,' RR723017003CN\r'),(2010,693388083015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','roland660','paulhughes6@blueyonder.co.uk','Paul Hughes','1 Ilfracombe Avenue','Southend on Sea','Essex','UNITED KINGDOM','SS12QX','01702319682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 20:27:27',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  1 '),(2011,599102691001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','anselmoas','anselmoas@yahoo.com.br','Valesca dos Santos Lima','Rua Saldanha Marinho, 558 - Neves','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24425-227','+55(21) 2628-3775','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-26 20:31:56',0,NULL,3,1,2,1,NULL,NULL),(2012,637848313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','71dodgefan','dmdhmc@yahoo.com','Brian DeLong','56 Academy St','Presque Isle','ME','UNITED STATES','04769-2948','(207) 764-1928','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-26 21:30:37',0,NULL,3,1,1,1,NULL,NULL),(2013,693485564015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','lz_boutique','lilmisslb_xxx@hotmail.com','Lauren Brown','16 Hermiston Avenue','London','London','UNITED KINGDOM','N8 8NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-26 23:46:25',0,NULL,3,1,2,1,NULL,NULL),(2014,637907036002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 00:19:05',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(2015,598541059001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nomarelis','venture20042@yahoo.com','sr mendez','611 Calle Jacinto','Juncos','PR','UNITED STATES','00777-3932','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 00:36:54',0,NULL,3,1,1,1,NULL,NULL),(2016,599195693001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3401',10,'hermeshine','harioe','harioe2002@yahoo.com.au','Hari Oetomo','5 Bordeaux Crescent, Castle Hill','Sydney','New South Wales','AUSTRALIA','2154','0288501729','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-11-27 00:49:54',0,NULL,3,1,2,1,NULL,''),(2017,637954909002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cdreemz2','cdreemz2@aol.com','Cindy Nina','3216 112th Pl<br>Fl 3','East Elmhurst','NY','UNITED STATES','11369-2532','(347) 624-1444','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 03:31:46',0,NULL,3,1,1,1,NULL,NULL),(2018,599244074001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AKT002',7.9,'hermeshine','mayromlo','mayromlo@ryerson.ca','Many Ayromlou','1 Bentwood Crescent','Thornhill','ON','CANADA','L4J8R3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 04:34:16',0,NULL,3,1,2,1,NULL,'æ°¸è¯ºçƒ­é´è½¬æ¢  1 '),(2019,599260263001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','makanani9919m','makanani9@juno.com','irene gombac','15 Kulanihakoi St<br>Apt 7E','kihei','HI','UNITED STATES','96753-7341','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 06:18:39',0,NULL,3,1,1,1,NULL,'æ°”å¹+å¸ƒ  1 '),(2020,637989757002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','kimerydw','dave.kimery@gmail.com','David Kimery','Suite 201, 620 - 12 Avenue SW','Calgary','AB','CANADA','T2R 0H5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 06:57:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016847CN\r'),(2021,637993679002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','seri7516','seri7516@hotmail.com','SERI BOUN','46 RUNCORN Street<br>ST. JOHNS PARK','Fairfield ','New South Wales','AUSTRALIA','2176','0298233469','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 07:23:08',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡ EMS \r717ah  1\rEX000113360SG'),(2022,638012609002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','zortteil','olivierchaume@yahoo.fr','olivier chaume','56 rue Pierre CAZENEUVE','TOULOUSE','Midi-PyrÃ©nÃ©es','FRANCE','31200','0660973802','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 09:01:56',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143311CN\r'),(2024,693631673015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','giorgos_v','vlageorg@otenet.gr','GEORGIOS VLACHOS','1 TSELIOU STREET','THESSALONIKI','THESSALONIKI','GREECE','54352','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 09:22:14',0,NULL,3,1,2,1,NULL,NULL),(2025,598492795001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','bonda-andrew','bonda.andrew@gmail.com','Bonda Andrew','Sovetskaya str<br>9, ComputerMarket','Novozybkov','Bryanskaya obl','RUSSIAN FEDERATION','243020','+79051767474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 11:10:17',0,NULL,3,1,2,1,NULL,NULL),(2026,693668944015,250600489459,'New Hairlight photostudio boom arm ',1,'',23.9,'hutongstore','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 11:15:00',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016780CN\r'),(2027,638063200002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 12:09:01',0,NULL,3,1,3,1,NULL,'50cm æ£š   1\rå€’å½±æ¿   1\r846g\rRR723017533CN\r'),(2028,692626565015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','brettarcher','kba68@hotmail.com','kevin archer','19 ferrymoore ham','surrey','Surrey','UNITED KINGDOM','tw10 7sd','020899401108','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 12:53:53',0,NULL,3,1,2,1,NULL,''),(2029,680240128016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','eazy-trade','tds10@uk2.net','Paul Bridgeman','124 Claymoor Flora Street','Oldham','Lancashire','UNITED KINGDOM','OL12XG','08445670302','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 13:07:37',0,NULL,3,1,2,1,NULL,''),(2030,638083999002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','maggi1970','magnus@amphilion.com','Magnus Palmarsson','Glosolum 5','Kopavogur','IS','ICELAND','201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:12:54',0,NULL,3,1,2,1,NULL,' 58mm æ©¡èƒ¶ç½©   1\rï¼ˆå®¢æˆ·æ”¹è®¢å•äº†æ³¨æ„ï¼‰'),(2031,599363871001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',3,'AB1301',10.02,'hermeshine','alexander_magnum','alexandr.churakov@gmail.com','Alexander Churakov','Gorky str. 27 Apt 16','Kirov','Kirovskaya obl','RUSSIAN FEDERATION','610017','79127347358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:23:14',0,NULL,3,1,2,1,NULL,'æ˜¯3ä¸ª '),(2032,599372205001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','kojisama','satirx@hotmail.com','Ruben Sousa Perez','Zuazaurre NÂº 23 4Âº A','Galdakao','Vizcaya','SPAIN','48960','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 13:47:22',0,NULL,3,1,2,1,NULL,NULL),(2033,693757789015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','gibbare10','gibbare@hotmail.com','Jonas Karlsson','Innervik 627','SkellefteÃ¥','VÃ¤sterbotten','SWEDEN','93191','+46 70 33 63 170','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 14:53:40',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C1   1 '),(2034,693764898015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','stargr1l','matnsara@gmail.com','Mathew Street','DÃ¶rfl 48','Reichenau an der Rax','','AUSTRIA','2651','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 15:05:15',0,NULL,3,1,2,1,NULL,''),(2035,599403947001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','jargoncia','mailalex@mixmail.com','alejandro gonzalez garcia','lleida 9, 3-1','sant adria de besos. Barcelona','CataluÃ±a','SPAIN','08930','607076698','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 15:11:29',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ ç™½ç›’  1 RR723016762CN\r'),(2036,599446276001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','susana1000','susande23@hotmail.com','Susana Sande Cadenas','C/ Romero Robledo,20 2ÂºB','Madrid','Madrid','SPAIN','28008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 16:46:44',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2037,599446147001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','susana1000','susande23@hotmail.com','Susana Sande Cadenas','C/ Romero Robledo,20 2ÂºB','Madrid','Madrid','SPAIN','28008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 16:46:45',0,NULL,3,1,3,1,NULL,'80cm 5in1 åå…‰æ¿  1\r40cm æ£š   1\ré‡é‡ï¼Ÿ 832g\rRR723017547CN\r'),(2038,599233542001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','riis1883norge','lincoln_10tpr@email.com','Timothy Reese','PO Box 1641','Monterey','CA','UNITED STATES','93942-1641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 17:20:54',0,NULL,3,1,1,1,NULL,NULL),(2039,680426055016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:27',0,NULL,5,1,18,0,NULL,NULL),(2040,680429128016,260660055664,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.7,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:27',0,NULL,5,1,18,0,NULL,NULL),(2041,693901120015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.6,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:28',0,NULL,5,1,18,0,NULL,NULL),(2042,693902286015,250599395859,'55mm 55 Close Up  Macro Close-Up +8 Filter New',1,'',3.6,'hutongstore','markhalset3','halseym9@aol.com','MARK HALSEY','28 MILLSHOTT CLOSE','FULHAM','London','UNITED KINGDOM','SW6 6PG','02073859140','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-27 19:00:28',0,NULL,3,1,3,1,NULL,'55mm +8  1\r72mm uv   1\r55mm uv   1\rlenspen   1 RR723016970CN\r'),(2043,638266726002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','dmerchan920','davidmerchan920@hotmail.com','David Merchan Munoz','C/ Lira  47','Getafe- Madrid','madrid','SPAIN','28905','615097868','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 19:45:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž  2 \rlight stand $22\rYW864143300CN\r\r'),(2044,599554940001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','lameton','thalassi@euskalnet.net','ANGEL MARIA ZAMANILLO MARTINEZ','LOIOLA ANDER DEUNA, 28-2ÂºD','SOPELANA','PaÃ­s Vasco','SPAIN','48600','656781982','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 20:12:12',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864143296CN\r'),(2045,638288125002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','mcgeester','mariannem7@bellsouth.net','Marianne McGee','8175 Landing S','Atlanta','GA','UNITED STATES','30350','(770) 650-7907','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 20:23:13',0,NULL,3,1,1,1,NULL,NULL),(2046,599563645001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','dannyandtrish','dannyandtrish@msn.com','Patricia Dunham','4450 N Loma Vista Rd','Willcox','AZ','UNITED STATES','85643-3221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 20:27:19',0,NULL,3,1,1,1,NULL,NULL),(2047,599597141001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jnr_t','jnr_t@hotmail.com','roy Thomas','85 Mansfield Drive','Hayes','Middlesex','UNITED KINGDOM','ub4 8eb','07931761779','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 21:54:06',0,NULL,3,1,3,1,NULL,'RR723016833CN\r'),(2048,599606852001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','tsur2701','suresht@upmc.edu','tunga suresh','750 washington road apt 1607','pittsburgh','PA','UNITED STATES','15228','(412) 200-5368','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 21:57:46',0,NULL,3,1,1,1,NULL,NULL),(2049,638338462002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','co-manche','fabrice.burguet@free.fr','Fabrice Burguet','14 rue du pavillon','VALOGNES','Basse-Normandie','FRANCE','50700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 22:08:42',0,NULL,3,1,2,1,NULL,NULL),(2050,599596075001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','trigomots88','trigomots@yahoo.com','Setlhare Lucas Motsamai','50 Palmoral Avenue','Kingston 6','St Andrew','JAMAICA','00000','(876) 455-5988','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-27 22:10:49',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 RR723016895CN\r'),(2051,694054376015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','voiceofsoul','voiceofsoul143@gmail.com','gul hassan','21 moy glass way Lucan','Dublin','Dublin','IRELAND','00','0860659288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-27 23:16:22',0,NULL,3,1,2,1,NULL,NULL),(2052,599636948001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','borfo','ebay@k-town.on.ca','rob kittredge','APT 902 - 736 SPADINA AVE','Toronto','ON','CANADA','M5S 2J6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-27 23:17:28',0,NULL,3,1,2,1,NULL,NULL),(2053,637761077002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jerryx2004','yvet_sanxag@yahoo.com','JERRY XAGORARIS','31201 FM 3069','LOS FRESNOS','TX','UNITED STATES','78566-4692','(956) 561-3405','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-27 23:31:14',0,NULL,3,1,1,1,NULL,NULL),(2054,637500716002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','knittinpearl','car0lyn@charter.net','Carolyn Keiser','208 Cedar Grove Dr','Saint Charles','MO','UNITED STATES','63304','(636) 448-9442','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 02:58:21',0,NULL,3,1,1,1,NULL,NULL),(2055,638432435002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','brasilcarvalhaes','cristinacarvalhaes@yahoo.com.br','Cristina Carvalhaes','Rua Ilacir Pereira Lima, 419 apt 503','Belo Horizonte','Minas Gerais - Belo Horizonte','BRAZIL','31140540','55-31-25152211','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 03:06:45',0,NULL,3,1,2,1,NULL,NULL),(2056,638433422002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','lpaulw1','lpaulw@charter.net','L. PAUL WASSERMAN','2433 S Nadine St<br>Apt 2','WEST COVINA','CA','UNITED STATES','91792-3559','(818) 625-0947','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 03:08:13',0,NULL,3,1,1,1,NULL,'58mm æŽ¥å£çŽ¯  1 '),(2057,599719353001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','julie_jeff_138','jljk@nb.sympatico.ca','Julie Leger','138 Mckay Ave','Moncton','NB','CANADA','E1A3N4','(506) 878-3174','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 04:45:53',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 RR723016820CN\r'),(2058,599730236001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','open2shop','deb@finelineintl.com','Bill Lavallie','c/o Fine Line International<br>19474 State Hwy 88, Suite A','Pine Grove','CA','UNITED STATES','95665','(209) 296-4450','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 05:45:34',0,NULL,3,1,1,1,NULL,NULL),(2059,638485237002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','sdavidi','sdavidi@pendari.com','Steven Davidi','1800 Century Park E<br>Ste 600','Los Angeles','CA','UNITED STATES','90067-1508','(310) 229-5722','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 07:36:02',0,NULL,3,1,1,1,NULL,NULL),(2060,599752733001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','martynas_siauciunas','martynas.siauciunas@gmail.com','Martynas Siauciunas','Nedre Valdersneset 80','Sletta','Radoy','NORWAY','5939','37067533975','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 08:16:20',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\ræ–œè‡‚  1\r50-70 æ£š  1  æ¬§æ ‡ \r115w 220v   1\rlighting kit $26 \rYW864143285CN\r'),(2061,638497851002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','racer_hollic','christian_aninzo@yahoo.com','CHRISTIAN ANINZO','P.O.BOX 4218','YIGO','GU','UNITED STATES','96929','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 08:34:30',0,NULL,3,1,1,1,NULL,'éº‚çš®  1 '),(2062,691351777015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','kconway84','kateconway84@hotmail.co.uk','Kate Conway','Flat 1015, 1 Courthouse Lane Metropolis Building','Auckland Central','Auckland','NEW ZEALAND','1010','00640212618206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 09:29:51',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon  1 '),(2063,680788014016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','avonloco','graham.white@bentley.com','Graham White','1a Albion Road','Sandhurst','Berkshire','UNITED KINGDOM','GU47 9BP','01252861831','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 10:38:46',0,NULL,3,1,2,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–   1 '),(2064,599812928001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','saviocc','saviocc@ig.com.br','Savio Cavalcante','Rua Rodrigues Ferreira, 45 - 1602B<br>Varzea','Recife','PE','BRAZIL','50810-020','+55 81 9961-0767','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 10:55:02',0,NULL,3,1,2,1,NULL,NULL),(2065,599858134001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','celter','to@kjellevand.no','Tor Ole Kjellevand','Inkognito terrasse 7B','Oslo','','NORWAY','0256','4722558085','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 12:36:39',0,NULL,3,1,2,1,NULL,NULL),(2066,599887307001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:40:33',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶'),(2067,599887295001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:40:34',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©  2\r58mm æ©¡èƒ¶ç½©   2 '),(2068,638624889002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','ville12345','villelappi@hotmail.com','Ville Lappi','Nokia Siemens Networks<br>PL 785','Tampere','','FINLAND','33101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 13:42:39',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2069,694371152015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','lynnmaccabe','lynn_maccabe@hotmail.com','BCC','7 Borthwick Place','Balmullo','Fife','UNITED KINGDOM','KY160EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 13:50:16',0,NULL,3,1,2,1,NULL,''),(2070,680977883016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','1962iskander','afan1962@gmail.com','ALEXANDR AFANASYEV','s-t BALAKIREVA 37D-42','VLADIMIR','','RUSSIAN FEDERATION','600028','9206275301','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 15:56:20',0,NULL,3,1,2,1,NULL,'lenspen  1 '),(2071,694459104015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','conaty8809','stevec85@aol.com','stephen conaty','43 Biddlestone Creasant','North Shields','Tyne and Wear','UNITED KINGDOM','NE29 7JW','01912895154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 15:56:51',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(2072,638698985002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','53240169','everfree5273@gmail.com','Yi Zou','4417 2nd Ave<br>Apt 401','Detroit','MI','UNITED STATES','48201-1257','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 15:57:35',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2073,599991947001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','njoh6323','nealalbrechtjohnson@gmail.com','Neal Johnson','11105 Scotland Well Dr.','Cedar Park','TX','UNITED STATES','78750','(512) 496-1920','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-11-28 16:32:48',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(2074,681047644016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sorigonvadim','sorigon@gmail.com','Vadim Ljubimov','Riga, Stirnu 37a-67','Riga','Vidzeme','LATVIA','lv-1084','+37127877502','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 17:12:29',0,NULL,3,1,2,1,NULL,'lenspen  1 '),(2075,600060894001,110532007108,'72mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1303',2.6,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 17:55:00',0,NULL,3,1,1,1,NULL,''),(2076,600072796001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','elhelado','specialist1982@mail.ru','Yulia Tveritinova','Zhivopisnaya ulitsa, dom 8, kvartira 41','Balashiha','Moscow region','RUSSIAN FEDERATION','143905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 18:07:03',0,NULL,3,1,2,1,NULL,' '),(2077,638807946002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','adriano_bitencourt','adrianosaj@gmail.com','Adriano Bitencourt','Av. EsperanÃ§a, 279/267 ou 194<br>Maria Preta','Santo AntÃ´nio de Jesus','Bahia','BRAZIL','44570-670','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 18:07:13',0,NULL,3,1,3,1,NULL,' canon æ‘„å½±èƒŒå¿ƒ M   1 RR723016878CN\r'),(2078,694600891015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'',1.88,'hutongstore','allenbesley','informmark@gmail.com','Mark Allen','Garfield 1 Boldrewood','Burghfield Common','Berkshire','UNITED KINGDOM','RG7 3LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 18:16:04',0,NULL,3,1,2,1,NULL,NULL),(2079,638835880002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','melissacramer062908','melissacramer@hotmail.com','Melissa Cramer','2570 Coyote Rd','Willits','CA','UNITED STATES','95490-9034','(707) 841-0803','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-28 18:32:48',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(2080,694618124015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','kew30','graham-webber@sky.com','Karen Webber','123 London Road','Colchester','Essex','UNITED KINGDOM','CO3 9AW','01206545610','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 18:35:37',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³   1 '),(2081,694715035015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'',16,'hutongstore','redwoodsnemesis','henrik@thierry.nu','Henrik Thierry','Digital Lifestyle Torvet 15','Koege','','DENMARK','4600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-11-28 19:41:09',0,NULL,3,1,3,1,NULL,'wf1003   1 RR723016949CN\r'),(2082,694720122015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','hooya892000','alifnur@gmail.com','Alif Nurhaziq Abd Rahman','373 Claremont Road','Manchester','Greater Manchester','UNITED KINGDOM','M14 7PA','07895356003','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 19:41:02',0,NULL,3,1,2,1,NULL,NULL),(2083,600174310001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','m.ognedal','mognedal@gmail.com','Magnus Ognedal','Feisteinveien 4B','STAVANGER','ND','NORWAY','4026','+47 90949197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 19:38:46',0,NULL,3,1,2,1,NULL,'40cm æ£š   1 '),(2084,681318010016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','dentistsmiling311','sneetverma@hotmail.com','sunita verma','Sparkle Dental Boutique 311 Boston road','Hanwell','London','UNITED KINGDOM','W13 8PT','02085674344','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-28 20:54:42',0,NULL,3,1,4,1,NULL,'2m x3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡  2\r115w 220v   2\råŒ…    1 \rYW864143274CN\r\rlighting kit  $32'),(2085,600272678001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','alflamer','alvarofl@gmail.com','Ãlvaro FernÃ¡ndez','C/ Cardenal Solis nÂº10---1ÂºG','Madrid','Madrid','SPAIN','28012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:31:15',0,NULL,3,1,2,1,NULL,'40cm æ£š  1 '),(2086,600273762001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','ham1248','graham@scotlandscapes.com','graham macfarlane','bellsmyre pharmacy<br>7c merkins avenue','bellsmyre dumbarton','West Dunbartonshire','UNITED KINGDOM','g82 3eb','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:33:14',0,NULL,3,1,2,1,NULL,NULL),(2087,694847071015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','pixel_vision','gary@haveyourcakeandeatit.org','Gary Brown','356-358 Spendmore Lane, Coppull','Chorley','Lancashire','UNITED KINGDOM','PR7 5DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 21:44:44',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(2088,599771709001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',21.6,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-28 21:58:12',0,NULL,3,1,2,1,NULL,'æ¸å˜è“  1\ræ¸å˜æ©™   1\ræ¸å˜æ£•  1 '),(2089,694883303015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'',23.9,'hutongstore','madmogga','a.morhall@btinternet.com','mrs a morhall','30 the drive','mayland','essex','UNITED KINGDOM','cm3 6aa','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 22:38:14',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723016921CN\r'),(2090,694893732015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'',3.59,'hutongstore','jayceephotography10','jayceephotography@hotmail.co.uk','jay cee','40 wheatash road','addlestone','Surrey','UNITED KINGDOM','kt15 2es','07951729684','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-28 22:57:12',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2091,600323115001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','peroni_es','por@retemail.es','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-28 23:13:17',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 RR723016904CN\r'),(2092,600360887001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','cbairbrush','clburrell34@att.net','Casandra Burrell','9809 Rosehill Ave<br>Apt 1','Cleveland','OH','UNITED STATES','44104-3659','(216) 253-0921','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 00:59:35',0,NULL,3,1,1,1,NULL,'1.6mx2.1m èƒŒæ™¯å¸ƒ  2 ï¼ˆéƒ½æ˜¯ç™½è‰²çš„ï¼‰  '),(2093,600365204001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','br4nk1nho','marco_g@netmadeira.com','Marco AntÃ³nio F. GonÃ§alves','C. St. AntÃ³nio, 80, Edificio Gemini, bloco B; X','Funchal','Madeira','PORTUGAL','9020-001','+351919731777','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-11-29 01:12:17',0,NULL,3,1,2,1,NULL,' '),(2094,638920114002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 01:19:41',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2095,638916760002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','rhianspaypal','rhianpaypal@yahoo.com','R Cope','C/O ERMA<br>20 customhouse quay','Wellington','New Zealand','NEW ZEALAND','6140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 01:19:40',0,NULL,3,1,6,1,NULL,'3m æ¨ªæ†  3\r2900g\ræ–°åŠ å¡ ems  EX000113356SG\r'),(2096,639121535002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','emoskau','office@ericmoskau.com','Eric Moskau','32 Falcon Dr','Mandeville','LA','UNITED STATES','70471-2952','(985) 626-3417','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 01:44:48',0,NULL,3,1,1,1,NULL,' '),(2097,639125504002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','eliassaint9','cefritz@yahoo.com','Carmelot Eliassaint','9 Sandy Ln','Norwich','CT','UNITED STATES','06360-3156','(860) 887-4603','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 01:58:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rå•ç¯å¤´  1\råå…‰ä¼ž   1 RR723016881CN\r'),(2098,630960812002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',57.9,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-12 19:26:07',0,NULL,5,1,18,0,NULL,''),(2099,639141959002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','jaylindsay','jaylindsaydds@gmail.com','Jay Lindsay','57 Fox Ln','Fredericksburg','TX','UNITED STATES','78624-7346','(830) 997-6457','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 02:41:50',0,NULL,3,1,3,1,NULL,' RR723016952CN\r'),(2100,639174202002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ruanoooo','ruano11@hotmail.com','Ruano Oliveira','Rua Aguiar, nÂº 55/apto 204<br>Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','20261120','55 21 25675616','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 04:17:34',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 RR723016864CN\r'),(2101,600431714001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','m4bz','mark@markforbes.com','Mark Forbes','873 W Y St','Washougal','WA','UNITED STATES','98671-7434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 04:46:37',0,NULL,3,1,1,1,NULL,NULL),(2102,639193053002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 05:47:02',0,NULL,3,1,2,1,NULL,NULL),(2103,600445844001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'',7.9,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 06:10:37',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶'),(2104,600446152001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115, appartment 3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 06:12:01',0,NULL,3,1,5,1,NULL,'çº¢ç¯å¤´  1\r800w 220v   2\rCP212235180CN\r '),(2105,639199203002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','mgpharmd','vfmartinelli@yahoo.com','Vincent Martinelli','5941 Ruthwood Dr','Calabasas','CA','UNITED STATES','91302-1076','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 06:23:10',0,NULL,3,1,1,1,NULL,NULL),(2106,639195179002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','nandofjs','nandofjs@ig.com.br','FERNANDO STELSER','4 OAK GROVE AVE<br>DOMINOS PIZZA','BATH','ME','UNITED STATES','04530','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-29 06:34:25',0,NULL,3,1,3,1,NULL,' RR723016935CN\r'),(2107,600452738001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','osmanay2010','osmanay63@mynet.com','OSMAN AYDIN','Basaksehir 4.Etap I.Kisim L3 Blok Da.18 Basaksehir','ISTANBUL','','TURKEY','34000','0212 4537939','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 07:00:34',0,NULL,3,1,2,1,NULL,NULL),(2108,600456512001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','picok2','picok2@net.hr','Goran Svaco','Kralja Tomislava 87','Djurdjevac','','CROATIA','48350','0038598452426','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 07:17:51',0,NULL,3,1,3,1,NULL,' RR723016983CN\r'),(2109,600460636001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','cscrrg2010','csc.rrg@hotmail.com','Rachel Gentry','PO Box 6084','Silverdale','WA','UNITED STATES','98315-6084','(360) 447-0806','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 07:41:41',0,NULL,5,1,18,0,NULL,NULL),(2110,600268832001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.2,'hermeshine','kreved','coolez@ya.ru','Konstantin Krysanov','Ul. Izumskaya street dom 30 kv 14','Moscow','Moscow','RUSSIAN FEDERATION','117624','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 08:50:47',0,NULL,3,1,2,1,NULL,NULL),(2111,600481755001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','felabgu','fela93@gmail.com','Felix Krikun','Shalom ash 26/2','Rishon Le-Zion','','ISRAEL','75607','972528716353','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 09:22:29',0,NULL,3,1,2,1,NULL,NULL),(2112,639234567002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 09:22:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723017119CN\r'),(2113,639236736002,120448751271,'Remote Shutter Release for SONY A100 A200 A900 =RM-S1AM',1,'AA3212',6.98,'hermeshine','linas565','linas@paintbaleris.lt','Linas Navardauskas','Taikos 84-54','Kaunas','lithuania','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 09:30:08',0,NULL,3,1,2,1,NULL,'RS-S1  1 '),(2114,695140088015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','02izzie02','pat-stone@tiscali.co.uk','Patricia Stone','73, The Glebe','West Calder','West Lothian','UNITED KINGDOM','EH55 8BL','01506871651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 11:19:34',0,NULL,3,1,2,1,NULL,NULL),(2115,695142520015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','02izzie02','pat-stone@tiscali.co.uk','Patricia Stone','73, The Glebe','West Calder','West Lothian','UNITED KINGDOM','EH55 8BL','01506871651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 11:26:11',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§  sony  1 '),(2116,600527995001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','ohcejohkanharri','hilehtonen@gmail.com','Harri Lehtonen','RievanrÃ¡dnu 7 D 10','Utsjoki','','FINLAND','99980','358-40-5211043','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:12:05',0,NULL,3,1,2,1,NULL,NULL),(2117,639294816002,120653773659,'for wenndysebli',1,'',49,'hermeshine','wenndysebli','wenndy_sebli@yahoo.com','Wenndy Sebli','Lot 3652, No. 19, Taman Selasih, Jalan Cenderawasih,<br>Off Jalan Depo, Petra Jaya','Kuching','Sarawak','MALAYSIA','93100','6082230032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:53:47',0,NULL,3,1,3,1,NULL,' 1- ND8 for 67mm( brand tianya)\r2- CPL for 67mm ( brand tianya\r3- Black color non woven  ( 1.6m x 3m)\r4- Chocolate color non woven ( 1.6m x 3m)\rRR723017476CN\r\r'),(2118,638582167002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',14.19,'hermeshine','gaw530','markdayoc@yahoo.com','Ghuinn Mark Dayoc','6 Desmond Place Rivervale','Perth','Western Australia','AUSTRALIA','6103','61451308848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 12:58:40',0,NULL,3,1,2,1,NULL,' ew-73b   1\r67mm  Lens Cap for Canon 2\r'),(2119,600561521001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','projet2001','projetizmir@superonline.com','Gokhan Ergun','273 / 7 Sok.No:4<br>Projet A.S. Bornova','Izmir','','TURKEY','35047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 13:59:50',0,NULL,3,1,2,1,NULL,NULL),(2120,639143586002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','skokie1996','mansur1954@hotmail.com','Anvar Khodzhaev','821 W 17th St<br>Unit A','Houston','TX','UNITED STATES','77008-3576','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 14:01:20',0,NULL,3,1,1,1,NULL,'çˆµå½±æ— çº¿  N1   1 '),(2121,600567335001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',2,'AE3401',74.9,'hermeshine','meaow2007','larfta2@aol.com','Tiyana Mardesich','10 Etherington Ave<br>Spearwood','Perth','Western Australia','AUSTRALIA','6163','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 14:14:32',0,NULL,3,1,6,1,NULL,'æ–°çš„ç¯æž¶     2\ræ–°åŠ å¡ems \rEX000165322SG'),(2122,681740220016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','viliushunter','viliuscece@gmail.com','Vilius Cesevicius','Diana 8','Scunthorpe','Lincolnshire','UNITED KINGDOM','DN15 6AX','07564070334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 14:51:29',0,NULL,3,1,2,1,NULL,NULL),(2123,695233241015,250600501508,'Continuous Lighting System soft box photography studio ',1,'',68,'hutongstore','watcook','louise.cookson@hotmail.co.uk','Louise Cookson','Chy-An-Kernow Botley Road, Horton Heath','Eastleigh','Hampshire','UNITED KINGDOM','SO50 7DW','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-29 15:10:58',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡   2\råŒ…   1 \rlighting kit $26\rYW864143440CN\r'),(2124,639346768002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','tove123martin','mart-k@online.no','Martin KrokÃ¥','Furuvegen 8','Tornes i Romsdal','MÃ¸re og Romsdal','NORWAY','6443','(047)41325840','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 15:17:23',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 \rRR723017493CN\r'),(2125,600599866001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','lauminsh21','rfjodorovs@gmail.com','Reinis Fjodorovs','13 florys Court<br>Augustus Rd.','London','London','UNITED KINGDOM','Sw19 6ra','02087805743','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 15:41:06',0,NULL,3,1,2,1,NULL,'40cm æ£š    1 '),(2126,639369058002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','megafashion-2009','megafashion2009@gmail.com','Keishla Davila','11606 NW 29th St<br>Apt. A-4','Coral Springs','FL','UNITED STATES','33065-3471','','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 16:12:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž    1 \rRR723017480CN\r'),(2127,695264165015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','johnenty','johnenty@btopenworld.com','John Entwistle','38 Clarence St','Bolton','Lancashire','UNITED KINGDOM','BL47RF','01204795985','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 16:12:50',0,NULL,3,1,2,1,NULL,' '),(2128,639383911002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','minishre','mindashreve@yahoo.com','Minda Shreve','699 N Vulcan Ave<br>Spc 88','Encinitas','CA','UNITED STATES','92024','(760) 809-7484','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 16:45:21',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…   nikon   1 '),(2129,600459359001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','ronyeden','ronybarbi@gmail.com','Elad Zalman','Ovadya 24 apartment 6','Haifa','Israel','ISRAEL','34563','972-52-8526626','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 16:57:16',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723017462CN\r'),(2130,639411697002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:44',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2131,639409623002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:45',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2132,639409112002,120489236687,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:46',0,NULL,5,1,18,0,NULL,' å‘ä¸Šåˆå¹¶ '),(2133,600653638001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','cuquico','victorsoriano@terra.es','victor soriano','marquÃ©s de la ensenada 10-6A','murcia','Murcia','SPAIN','30007','669792300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:42:45',0,NULL,3,1,3,1,NULL,' æŸ”å…‰ä¼ž  1\råå…‰ä¼ž   1\rbåº§   1\r80cm 5in1 åå…‰æ¿   1\rRR723017555CN\r'),(2134,600659311001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','redivivaii','gokyori@shaw.ca','Roger Simpson','20850  72nd Ave,','Langley','BC','CANADA','V2Y 1T3','(604) 510-3150','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 17:50:27',0,NULL,3,1,2,1,NULL,NULL),(2135,639426427002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','mamuphoto','d.malorzo@teletu.it','damiano malorzo','strada per minnuta ,1B','brindisi','BR','ITALY','72100','0831/451993','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 18:07:41',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž   2 \rlight stand   $22\rYW864143425CN\r'),(2136,600674224001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','tomas9141','tom.coufal@gmail.com','Tomas Coufal','Olomoucka 87','Prostejov','','CZECH REPUBLIC','79601','+420603919590','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 18:19:49',0,NULL,3,1,2,1,NULL,NULL),(2137,639449941002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','hottabich','aleks2003@inbox.lv','Aleksandrs Lukicovs','Marupe,Liela 39-43','Riga','','LATVIA','2167','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 18:48:13',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 \rRR723017428CN\r'),(2138,639451585002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','eagle4801','tsblaw@netamumail.com','Teri Boland','303 2nd St S','Swea City','IA','UNITED STATES','50590','','NoPaymentFailure','CheckoutComplete','Other','2010-11-29 18:49:46',0,NULL,3,1,3,1,NULL,'canon R2 å•è‚©åŒ…   1 \rRR723017502CN\r'),(2139,695370110015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'',134,'hutongstore','janice7077','jailpalmer@hotmail.com','janice palmer','unit cleaners ltd 286 brixton road','london','London','UNITED KINGDOM','sw96ag','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-11-29 19:01:39',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2mç¯æž¶   2\råŒç¯å¤´  2 è‹±æ ‡\råå…‰ä¼ž   2\r45w ç¯æ³¡   4\råŒ…   1 \rYW864143436CN\r\rLighintg kit  $30'),(2140,639477718002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','pipo-9820','peterkiryakov@mail.bg','Peter Kiryakov','Rozen blvd 25<br>ATY BALKAN','sofia','sofia','BULGARIA','1220','0035929369820','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:29:41',0,NULL,3,1,2,1,NULL,NULL),(2141,639352402002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:37:19',0,NULL,5,1,18,0,NULL,NULL),(2142,639312814002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 19:37:19',0,NULL,5,1,18,0,NULL,' '),(2143,600558373001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','8mmaster','siggaarne@hotmail.com','Stig Satherskar','Midteggen 16','7078 Saupstad NO','Trondheim','NORWAY','7000','+47 92609238','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 19:37:20',0,NULL,3,1,3,1,NULL,'nikon 90th é•œå¤´ç­’   1\rä¸­å·å†…èƒ†åŒ… nikon   1\r3pcs æ»¤é•œè¢‹      1 \rRR723017312CN\r'),(2144,600735716001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bigdlls','bigdlls@sbcglobal.net','David Moore','416 S Waverly Dr','Dallas','TX','UNITED STATES','75208-5728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 19:56:23',0,NULL,3,1,1,1,NULL,NULL),(2145,639510166002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','eskimoyety','radko.vavrik@gmail.com','Radko Vavrik','Dlhy rad 165','Velke Zaluzie','','SLOVAK REPUBLIC','95135','+421948048821','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 20:19:55',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2146,600747079001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','eskimoyety','radko.vavrik@gmail.com','Radko Vavrik','Dlhy rad 165','Velke Zaluzie','','SLOVAK REPUBLIC','95135','+421948048821','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 20:19:55',0,NULL,3,1,2,1,NULL,'52mm rubber æ©¡èƒ¶ç½©  1\rå°å·ç°å¡   1 '),(2147,639516277002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cubarican1985','foxyfire6000@yahoo.com','Angela Solis','1151 Evening Trail Drive','Wesley Chapel','FL','UNITED STATES','33543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 20:28:40',0,NULL,3,1,1,1,NULL,NULL),(2148,695451731015,250615143615,'YongNuo Flash Battery Pack SF-17 for Canon Flash 580EXI',1,'',28.99,'hutongstore','dawiddrozdz','dawid.drozdz@gmail.com','Dawid Drozdz','46 Grovelands Close','london','London','UNITED KINGDOM','se5 8jn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 20:41:37',0,NULL,3,1,3,1,NULL,'RR723017391CN\r'),(2149,695461326015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','lannos79','lanceguyatt@gmail.com','Lance Guyatt','Wilson Fletcher 1 Old Nichol Street','London','London','UNITED KINGDOM','E2 7HR','07723198662','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 20:54:47',0,NULL,3,1,2,1,NULL,NULL),(2150,600790178001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 21:26:09',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2151,600733651001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','bhlevin','blevin@imagerygroup.com','Barry Levin','3245 Whipple Rd','Union City','CA','UNITED STATES','94587','(510) 324-4020','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 21:45:58',0,NULL,3,1,1,1,NULL,NULL),(2152,639563927002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 21:52:19',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR723017388CN\r'),(2153,639573116002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-29 22:10:54',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  2  æ¬§æ ‡\råŒ…  1\r2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1 \rlighting kit  $28\rYW864143414CN\r'),(2154,639579050002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','bphoto57','bphotousa@live.com','steve brudzinski','5 S Longyard Rd<br>Apt C4','southwick','MA','UNITED STATES','01077-9379','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 22:24:04',0,NULL,3,1,1,1,NULL,NULL),(2155,695532679015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'',2.98,'hutongstore','andyg840','andrewguest@live.co.uk','Andrew Guest','16 Oak Stret','Northwich','Cheshire','UNITED KINGDOM','CW9 5LJ','0160647310','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 23:06:50',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2156,695535595015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'',2.98,'hutongstore','andyg840','andrewguest@live.co.uk','Andrew Guest','16 Oak Stret','Northwich','Cheshire','UNITED KINGDOM','CW9 5LJ','0160647310','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-29 23:06:50',0,NULL,3,1,2,1,NULL,'RS-C1   1\rRS-C3   1 '),(2157,639599626002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','duhgoober','tomoleary1@juno.com','THOMAS R. OLEARY','13443 Fm 346 E','WHITEHOUSE','TX','UNITED STATES','75791','(903) 752-2703','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-29 23:15:15',0,NULL,3,1,1,1,NULL,NULL),(2158,600846470001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',28.99,'hermeshine','gmzsur','gmzsur@hotmail.com','Jose Antonio  Gamez Mangas','MUEBLES CASANDRES Ctra. Badajoz-Montijo km.22 (EX209)','Pueblonuevo del Guadiana','Extremadura','SPAIN','06184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-29 23:41:46',0,NULL,3,1,3,1,NULL,'3m ttlçº¿   for  Canon   1 \rRR723017374CN\r'),(2159,600853714001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','bafalda','lolov16@hotmail.fr','laurent gibouin','10 rue des Jonquilles','la BruffiÃ¨re','Pays de la Loire','FRANCE','85530','0637654197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 00:14:43',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   æ¬§æ ‡   1 '),(2160,638723265002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',10,'hermeshine','msgdlsmith','msgdlsmithret@aol.com','Darrell L. Smith','519 Logan St','Frankfort','KY','UNITED STATES','40601-3517','(502) 682-0028','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 00:53:09',0,NULL,3,1,1,1,NULL,'72mm canon é•œå¤´ç›–  2\r58mm canon é•œå¤´ç›–  2 '),(2161,639645725002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','margaux100680','utkidmm@comcast.net','Margaux Morgan','7165 Alice Springs Ln','Corryton','TN','UNITED STATES','37721-3956','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 01:38:28',0,NULL,3,1,1,1,NULL,NULL),(2162,600885405001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','underashes2008','agkurylo@gmail.com','Adam Kurylo','1112 S Zenith Ave','Davenport','IA','UNITED STATES','52802-2541','(563) 726-2747','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 01:51:14',0,NULL,3,1,1,1,NULL,' 1112 S. Zenith Ave \rDavenport Iowa\r52802\r'),(2163,639654032002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','surabky_123','stockphotothailand@hotmail.com','Sura Nualpradid','BKY Co.,Ltd. 93/9 Moo 1 Praram 2 Road<br>Bangnamjaed, Maung','Samutsakorn','','THAILAND','74000','6624528564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 02:10:26',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶'),(2164,639657117002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','surabky_123','stockphotothailand@hotmail.com','Sura Nualpradid','BKY Co.,Ltd. 93/9 Moo 1 Praram 2 Road<br>Bangnamjaed, Maung','Samutsakorn','','THAILAND','74000','6624528564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 02:14:00',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(2165,639668289002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','traveltime88','tarahss77@gmail.com','Tara  Neuheisel','223 N 193rd Dr','Buckeye','AZ','UNITED STATES','85326-5899','(623) 853-0954','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 03:00:27',0,NULL,3,1,1,1,NULL,NULL),(2166,639361616002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','originalstadium','originalstadium@palermoplanet.it','William Anselmo','Via Lancia di Brolo, 82','Palermo','Palermo','ITALY','90100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 03:16:27',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 \rRR723017459CN\r'),(2167,599583903001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','adelbot2','bavlyab@yahoo.com','ADEL BOTROUS','451 E Rowland St<br>Apt 11','COVINA','CA','UNITED STATES','91723','(626) 339-7488','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 03:41:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723017445CN\r'),(2168,695647387015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'',4.99,'hutongstore','nevilleclarke','nobby7921@hotmail.com','N T Clarke','19 Ryland Close Sydenham','Leamington Spa','Warks','UNITED KINGDOM','CV31 1HU','01926335539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 03:56:49',0,NULL,3,1,2,1,NULL,NULL),(2169,590564606001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3305',3.6,'hermeshine','mello021','rafael.calero@hotmail.com','Rafael Calero','Rua GirÃ£o Barroso 100<br>Bloco 3B apartamento 202 Alcantara','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24711-160','55 21 87050724','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,NULL),(2170,639690358002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','brian730407','brian0407@gmail.com','BYUNG KYU LEE','1353 2ND AVE<br>SEDGBURY CLEANERS','NEW YORK','NY','UNITED STATES','10021-4560','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-11-30 04:04:39',0,NULL,3,1,3,1,NULL,' RR723017431CN\r'),(2171,595160345001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','dionne782','crazy_climber6@hotmail.com','Dionne Dionne','5214-49st','Lacombe','AB','CANADA','T4L1J3','(403) 782-7224','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 04:26:15',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3m x6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2\r115w110v  2\råŒ…   1 \rCP212150609CN\r'),(2172,639700926002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','$dealz','git.ur.dun@hotmail.com','Darcy Neigel','1139 Henleaze Ave','Moose Jaw','SK','CANADA','S6H 3V8','(306) 693-8795','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 04:50:33',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1 '),(2173,639707518002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','tfarms3150','tfarms@wildblue.net','Thomas Barfield','17401 Katydid Ln','Immokalee','FL','UNITED STATES','34142-9689','(239) 657-4181','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 05:29:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 \rRR723017414CN\r'),(2174,695675910015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','delvars','steverowse@gmail.com','Steven Rowse','22 Huxley Close','Godalming','Surrey','UNITED KINGDOM','GU72AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 05:53:02',0,NULL,3,1,2,1,NULL,NULL),(2175,600928227001,110502916835,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',3.55,'hermeshine','meetmyoffer','sgbox@live.com','steven goldstein','1815 215th St<br>apt 4P','bayside','NY','UNITED STATES','11360-2132','(516) 287-8821','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 06:21:03',0,NULL,3,1,1,1,NULL,NULL),(2176,639657992002,120560203167,'77mm Lens lenscap for Canon Combined shipping discounts',1,'AA1304',2.6,'hermeshine','nwmaple206','nwmaple@gmail.com','Wei Lu','5829 133rd PL SW','Edmonds','WA','UNITED STATES','98026','(425) 329-7689','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 06:24:02',0,NULL,3,1,1,1,NULL,NULL),(2177,600643605001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','wizardonbay','sergio.o@tugamail.com','SÃ©rgio Oliveira','Rua Nuno Amorim, nÂº6 - 4Âº Esquerdo Frente','Braga','Braga','PORTUGAL','4710-505','962548954','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 08:56:00',0,NULL,3,1,2,1,NULL,NULL),(2178,639762574002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','tomasi_030','tomers.ts@gmail.com','tomer shalom','beery 8 ( Entry b  - Apartment 3)','givat-shmuel','','ISRAEL','54035','972-722-322-864','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 10:04:40',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2179,600483661001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','bador.lifestrike','matthew.carlson92@gmail.com','Matthew Carlson','5041 Alabama St<br>Apt 54','El Paso','TX','UNITED STATES','79930-2643','(661) 904-0145','NoPaymentFailure','CheckoutComplete','Other','2010-11-30 11:03:09',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\ræ–œè‡‚  2 \rlight stand $22\rYW864143462CN'),(2180,601022764001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','benington','ben.secs@dsl.pipex.com','Martin Halley','16 The Beeches<br>Fetcham','LEATHERHEAD','Surrey','UNITED KINGDOM','KT22 9DT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 12:08:31',0,NULL,3,1,2,1,NULL,''),(2181,639803672002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','alpha-sphere','yilkee@gmail.com','Yilkee Lam','Groenewegje 67','Den Haag','Zuid-Holland','NETHERLANDS','2515LM','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 12:36:59',0,NULL,3,1,2,1,NULL,''),(2182,639811622002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','bam666','bamitche@execpc.com','Brian Mitchell','452 Sunset Dr','De Forest','WI','UNITED STATES','53532-1128','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 13:03:07',0,NULL,3,1,1,1,NULL,NULL),(2183,639813527002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sasanka87sasanka','sricotechnologies@gmail.com','Sasanka Rajapaksa','5, Udyana Mawatha,<br>Pepiliyana Road,','Nugegoda.','Colombo','SRI LANKA','10250','0774193065','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 13:11:28',0,NULL,3,1,2,1,NULL,''),(2185,695807957015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','j.smity','julian@julsplace.co.uk','Julian Smith','4 Iron Way tondu','bridgend','Bridgend','UNITED KINGDOM','cf329bf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 13:27:01',0,NULL,3,1,2,1,NULL,NULL),(2186,601053409001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','jubeai','big@euskalnet.net','Juan Arrrondo Ecenarro','Asteasuain kalea NÂº3-5ÂºD','Lasarte-Oria','Guipuzcoa','SPAIN','20160','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 13:41:05',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143506CN'),(2187,695813065015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'',6.95,'hutongstore','jskorupa80','jakub.skorupa@yahoo.pl','Jakub Skorupa','Flat A, Chiswick Court, 1A, Silver Crescent','LONDON','LONDON','UNITED KINGDOM','W4 5SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 13:41:29',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2188,639830819002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','proforica','profor@vanea.net','IVAN PROFOR','Sciusev 4/8','Balti','Balti','MOLDOVA, REPUBLIC OF','3100','37369833368','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:09:46',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723017839CN\r'),(2189,639845258002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:43:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\räº‘å° 1\ræŸ”å…‰ä¼ž   1 \rRR723017842CN\r'),(2190,639848602002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','malldova2nd','z55001987@yahoo.com','Larisa Grosul','str.Podul Inalt 14/2 ap.12','ChiÅŸinau','','MOLDOVA, REPUBLIC OF','MD2023','37368418989','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 14:52:04',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR723017856CN\r'),(2191,639860674002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','exdeo84','exdeo84@gmail.com','Synergy Computers','901Quartz Ct<br>Unit B','Cedar Park','TX','UNITED STATES','78613','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 15:25:24',0,NULL,3,1,1,1,NULL,NULL),(2192,639862210002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','recycle3','mlc1usa@msn.com','Michael Cullom','204 E Sunny Sands Rd','Cathlamet','WA','UNITED STATES','98612-9728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 15:30:30',0,NULL,3,1,1,1,NULL,' '),(2193,601094849001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','fzetec','fcerrato@gmail.com','fernando marques','gabriel de lara 293','sao paulo','sao paulo','BRAZIL','04582050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 15:43:03',0,NULL,3,1,2,1,NULL,NULL),(2194,639871653002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','regety','avplus@list.ru','Alexandr Plusnin','ulica Kuznecova, 6, kv.54','Kotlas','Arhangelskaya obl','RUSSIAN FEDERATION','165300','8-911-565-04-69','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 15:55:35',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(2195,601131064001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÃ‰LIX ARRANZ MARTÃN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÃA DE EDUCACIÃ“N','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 17:10:19',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’  1 '),(2196,636267630002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',11.54,'hermeshine','andris_ogre','ogreasd@inbox.lv','Andris Gelzinis','Tinuzu 18-11','Ogre','Ogre','LATVIA','LV-5001','+37129343432','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 17:13:54',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(2197,601147949001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alvins1204','alvins1987@gmail.com','Alvin Scherbahn','Feldbergstrasse 58','Mannheim','','GERMANY','68163','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 17:45:50',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\r2m ç¯æž¶   1 \rlight stand  $16\rYW864143510CN'),(2199,682500854016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','formby650','charlie@smudge.uk.com','Hannah Flannery','2 Ryder Way','Ickleford','Hertfordshire','UNITED KINGDOM','SG5 3XL','07722052721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 19:17:20',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶  1 \rYW864143473CN\rreflector  holder  $15\r'),(2200,639978716002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','protrekmao','protrek@centrum.cz','Martin Vylasek','Husova 100','Bedihost','','CZECH REPUBLIC','79821','+420776747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 19:34:07',0,NULL,5,1,2,1,NULL,''),(2201,601206075001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','protrekmao','protrek@centrum.cz','Martin Vylasek','Husova 100','Bedihost','','CZECH REPUBLIC','79821','+420776747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-11-30 19:34:06',0,NULL,3,1,2,1,NULL,' å°å·ç°å¡   1 \r77mm æ©¡èƒ¶ç½©   1'),(2202,696006691015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','johnenty','johnenty@btopenworld.com','John Entwistle','38 Clarence St','Bolton','Lancashire','UNITED KINGDOM','BL47RF','01204795985','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 19:34:29',0,NULL,3,1,2,1,NULL,NULL),(2203,639988636002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','dbigby1','dylan@macaframa.com','Dylan Bigby','533 Frederick St','San Francisco','CA','UNITED STATES','94117-2753','(415) 990-6769','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 19:46:20',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2204,695855991015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',6,'',11.28,'hutongstore','annie592','andrea-solomon@ntlworld.com','Andrea Solomon','15 Bentley Way','Essex','Essex','UNITED KINGDOM','IG80SE','02085029996','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 22:19:33',0,NULL,3,1,3,1,NULL,'RR723017811CN '),(2205,640070872002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','the_fishtank_2007','bigfatfish@hotmail.co.uk','James Penrose','2500 Asp Ave<br>Traditions Square East Bldg H Rm 303','Norman','OK','UNITED STATES','73072-6409','02084625929','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 22:19:38',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(2206,696126822015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','flaffy*123','go_wild_6@hotmail.com','Jenny Johns','23 Benson Drive Northam','Bideford','Devon','UNITED KINGDOM','EX39 1UY','01237423950','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 22:33:56',0,NULL,3,1,2,1,NULL,NULL),(2207,601309326001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','msxodesigns','msxodesigns2@yahoo.com','Alonna Leverett','23111 Laurel Valley Ct<br># 10','southfield','MI','UNITED STATES','48034-2085','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 22:47:31',0,NULL,3,1,1,1,NULL,'1.6x2.1 é»‘è‰²èƒŒæ™¯å¸ƒ  1 '),(2208,696153386015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','7812dg','davidgiddins7812@hotmail.com','David Giddins','5, Sussex Drive, Belle Vue','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 7NQ','01743368590','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-11-30 23:36:56',0,NULL,3,1,2,1,NULL,NULL),(2209,601326370001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','4037edward','eppiv@juno.com','edward pawley','10600 Griffin Rd<br># A105','Davie','FL','UNITED STATES','33328-3208','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:37:36',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(2210,640106936002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','mipro83','prilepokm@gmail.com','Miroslav Prilepok','Prievozska 1','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','+421905616600','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-11-30 23:51:05',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723017825CN\r'),(2211,640108566002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:28',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2212,640108154002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:28',0,NULL,5,1,18,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2213,640108405002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','efm6660','e.mcnamara6@verizon.net','Elizabeth McNamara','18 Prospect St','East Greenwich','RI','UNITED STATES','02818-3217','(401) 885-6497','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-11-30 23:56:29',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon 3 '),(2214,640114247002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','jorgerr2007','joryaanso15@yahoo.com','Jorge Rivera','PO Box 154','Juncos','PR','UNITED STATES','00777','(787) 361-8398','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 00:14:37',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(2215,640073975002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','oaks','rj_6@hotmail.com','RAVI JOSHI','955 desmet way','san jose','CA','UNITED STATES','95125-6362','(408) 746-6018','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:25:25',0,NULL,3,1,1,1,NULL,NULL),(2216,601356664001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','heet9885','jheetland@ou.edu','Jesse Heetland','1003 King St','Lancaster','OH','UNITED STATES','43130-3243','(740) 215-8223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:33:45',0,NULL,3,1,1,1,NULL,'æ¸å˜ç°  1\r58mm çŽ¯æž¶   1 '),(2217,640143439002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','tydus1957','tydusleon@yahoo.com','Tydus Huddleston','4133 Mountain Oak Cv','Stone Mountain','GA','UNITED STATES','30083-1229','(678) 522-7266','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 01:55:55',0,NULL,3,1,1,1,NULL,NULL),(2218,601366315001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','kasenter','sas33@psu.edu','S. Alex Studniarz','205 Mercer Ave','Hermitage','PA','UNITED STATES','16148','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 02:01:32',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  2 '),(2219,601367104001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','nunocosmos','franfvc@gmail.com','FRANCISCO VIDAL CUESTA','LANZAROTE, 42 (ESQ. VALENTIN IGLESIAS) PISO 2, PTA. 43','BARCELONA','CataluÃ±a','SPAIN','08030','639137962','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 02:04:54',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR723017768CN\r'),(2220,601374033001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fredleescot','fredleepoirier@hotmail.com','frederic poirier','la moriniere (GPS=grimordiere)','avoise','Pays de la Loire','FRANCE','72430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 02:29:58',0,NULL,3,1,2,1,NULL,NULL),(2221,640158725002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','agatha354','sekhmet_syo@hotmail.com','Carla Carcamo Vidal','Libertad 595','Coyhaique','XI','CHILE','5950102','56974891217','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 02:47:03',0,NULL,5,1,17,0,NULL,'å‘ä¸Šåˆå¹¶   '),(2222,640158654002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','agatha354','sekhmet_syo@hotmail.com','Carla Carcamo Vidal','Libertad 595','Coyhaique','XI','CHILE','5950102','56974891217','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 02:47:03',0,NULL,3,1,3,1,NULL,'6662a  1\rä¸­å·å†…èƒ†åŒ… nikon   1 \rRR723017895CN'),(2223,601383408001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','macmanrules','macmanfan@hotmail.com','Scott   McEwan','221 Elmwood St','Dearborn','MI','UNITED STATES','48124-1467','(248) 797-3846','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 03:03:47',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2224,640167386002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','boby98','rob.worthington@bigpond.com','Robert Worthington','52 Winifred St','Condell Park','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 03:16:18',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶   1 \rRR723017771CN\r'),(2225,640168760002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','gazali2010','m_gazali2001@yahoo.com','Mohammed Gazali Rashad','503 W 138th St<br>Apt 2D','new york','NY','UNITED STATES','10031-7768','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 03:20:07',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…nikon   1 '),(2226,601400446001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',4,'AA1309',9.8,'hermeshine','itriedtofixit','thetech@gmail.com','Dave Ullman','7525 Aurora Ave N','seattle','WA','UNITED STATES','98103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:10:43',0,NULL,5,1,18,0,NULL,NULL),(2227,640181767002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5,'hermeshine','itriedtofixit','thetech@gmail.com','Dave Ullman','7525 Aurora Ave N','seattle','WA','UNITED STATES','98103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:11:41',0,NULL,3,1,1,1,NULL,'72mm é•œå¤´ç­’ canon 2\r77mm é•œå¤´ç­’  canon 4 '),(2228,601404466001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','jenja5','jen.snyder@verizon.net','Jennifer Jacoby Snyder','46 Image DR','Scotrun','PA','UNITED STATES','18355-9656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 04:30:32',0,NULL,3,1,1,1,NULL,''),(2229,601406157001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.9,'hermeshine','georgeting','georgetingfz@gmail.com','George Ting','1st Floor, Lot 8795 Pending Court<br>Jalan Kwong Lee Bank','Kuching','Sarawak','MALAYSIA','93450','0128861512','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 04:39:01',0,NULL,3,1,2,1,NULL,''),(2230,601413901001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','lbk46','hbseagull@verizon.net','LEON KOGAN','4297 Via Cerritos','Thousand Oaks','CA','UNITED STATES','91320-6821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:23:42',0,NULL,8,1,17,1,NULL,'å‘ä¸Šåˆå¹¶ '),(2231,601413543001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','lbk46','hbseagull@verizon.net','LEON KOGAN','4297 Via Cerritos','Thousand Oaks','CA','UNITED STATES','91320-6821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:23:42',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’  1\rå°å·å†…èƒ†åŒ… æ— å­—   1 '),(2232,640197153002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','flatfenders','dennyscjs@aeroinc.net','Dennis L. Goethe','11408 N Pecatonica Rd','Durand','IL','UNITED STATES','61024-9609','(815) 248-2553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 05:27:37',0,NULL,3,1,1,1,NULL,NULL),(2233,640197480002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','jarrod.basl','jarrodsumpter@gmail.com','Jarrod Sumpter','3215 NE 143rd St<br># A170','Seattle','WA','UNITED STATES','98125-3753','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 05:27:44',0,NULL,3,1,1,1,NULL,'Jarrod Sumpter\r14021 15th Ave NE \rApt 304N \rSeattle, WA 98125\rUNITED STATES\r\r'),(2234,601424347001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','ralphie805','ralphie@gmail.com','Zach Ingram','289 Brentwood way','Goleta','CA','UNITED STATES','93117-1032','(805) 570-7313','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 06:25:35',0,NULL,3,1,1,1,NULL,NULL),(2235,640208726002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 06:34:59',0,NULL,3,1,2,1,NULL,NULL),(2236,640221235002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','thargjunior','algood@iinet.net.au','A L Goodland','P O Box 117<br>North Perth','Perth','Western Australia','AUSTRALIA','6906','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 07:48:01',0,NULL,3,1,6,1,NULL,' EE520583595CN'),(2237,601445584001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','yairamoyal','yair_amoyal@walla.com','yair amoyal','eli cohen<br>41/8','ashkelon','israel','ISRAEL','78718','972 917086842715','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 08:26:31',0,NULL,3,1,3,1,NULL,'æ–°ç¯æž¶ æ½˜'),(2238,640229285002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xdesign_george','xdesigngroup@gmail.com','George Georgiev','Mladost, bl. 156, ap. 24','Varna','Varna','BULGARIA','9000','+359889382582','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 08:27:55',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ 1\rbåº§  1\ræŸ”å…‰ä¼ž  1 æ½˜'),(2239,696319836015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'',45.99,'hutongstore','rik67','bob.clark25@btinternet.com','Mrs Michelle Riley','Ras Al Khaimah English Speaking School P.O. Box 975','Ras Al Khaimah','United Arab Emirates','UNITED ARAB EMIRATES','','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-01 09:16:25',0,NULL,3,1,3,1,NULL,'\rRR723018009CN\r'),(2240,696320133015,250693634824,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'',4.78,'hutongstore','markfr1','markfr1uk@yahoo.co.uk','Mark Fisher','62 St Leonards Road','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU177HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 09:17:59',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯çš„58mm nd8   1 '),(2241,640241186002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jorfermo','jferrando@cc.upv.es','Jorge Ferrando Monterde','C/Chiva 20, 7Âª','Valencia','Comunidad Valenciana','SPAIN','46018','659576903','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 09:22:50',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143484CN'),(2242,639302994002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','stef0653','sp_style@live.nl','stef swinkels','vullingsstraat 11','leunen','','NETHERLANDS','5809at','0478586947','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 09:25:56',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR723017927CN\r'),(2243,601461196001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','robinm5407','robinm5407@aol.com','Robin M OBrien','5513 Brookmere St','Edwards','IL','UNITED STATES','61528-9407','(309) 692-1733','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-01 09:36:00',0,NULL,3,1,3,1,NULL,'çº¢ç›’ç¯æž¶   1 \rRR723017913CN\r'),(2244,640251731002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mrgeo1024','jiri.lapka@seznam.cz','Jiri Lapka','Slavikova 1758','Ostrava-Poruba','Czech Republic','CZECH REPUBLIC','70800','00420603756500','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:01:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723017989CN\r'),(2245,640072289002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','pupss0','djkob3on@yahoo.com','octavian malai','cuza-voda 24 apt 85<br>MD-2060','chisinau','','MOLDOVA, REPUBLIC OF','md2060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:14:42',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\råŒ…   1 \rCP212235159CN'),(2246,640256429002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',131.7,'hermeshine','doublem6','matustikm@yahoo.com','Marek Matustik','Ctyrkoly 115','Cercany','','CZECH REPUBLIC','25722','00420724110409','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:22:14',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  3\räº‘å°  3\ræŸ”å…‰ä¼ž  3 \rCP212235145CN'),(2247,640222413002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','lan-mas-ter','vacaciones@rambler.ru','Gennadiy Zuev','st. Kolcevay 159/1 - 57','Ufa','Bashkortostan','RUSSIAN FEDERATION','450038','917-345-2848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 10:23:48',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿  3 '),(2248,639225955002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',89.78,'hermeshine','icevace1982','icevace@mail.ru','Marsel Valiullin','Zarechnaya ulitsa<br>dom 7, kvartira 132','Moscow','Moscow','RUSSIAN FEDERATION','121087','79031599999','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 10:47:52',0,NULL,3,1,5,1,NULL,'50-70 é€šç”¨å¡å£æŸ”å…‰æ£š  2\r100-150 5in1 åå…‰æ¿   1 \rCP212235131CN\ré‡é‡ï¼Ÿ'),(2249,696359176015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','missmeggles2005','test_tube_daisies@hotmail.com','Megan Craggs','31/7 gillespie crescent','Edinburgh','Midlothian','UNITED KINGDOM','EH104HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 11:18:08',0,NULL,3,1,2,1,NULL,NULL),(2250,601488619001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','washo68','kwa83620@bigpond.net.au','Peter Washington','40 Hillcrest Rd, Nerrina','Ballarat','Victoria','AUSTRALIA','3350','0353388804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 11:23:55',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723017992CN\r'),(2251,640277286002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','aschecky','andrew@waygen.com','Andrew Scheck','14 Carrie Dr','Marlboro','NJ','UNITED STATES','07746','(732) 490-8414','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 11:35:24',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(2252,640280213002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','lassekamppari','lasse.kamppari@gmail.com','Lasse Kamppari','Raisiontie 11 A 1','Helsinki','','FINLAND','00280','358405231721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 11:47:53',0,NULL,3,1,2,1,NULL,'1.6mx3m ç°è‰²èƒŒæ™¯å¸ƒ  1 '),(2253,601498140001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','catlos.ales','ales.catlos@gmail.com','Ales Catlos','Iljusinova 4','Bratislava','SC','SLOVAK REPUBLIC','85101','+421903555899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 11:54:20',0,NULL,3,1,2,1,NULL,'éº‚çš®  2 '),(2254,601512965001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','drtsos124','drtsos@gmail.com','Dimitris Karabetsos','32, Xiromerou Str<br>Ampelokipoi','Athens','Ampelokipoi, Athens','GREECE','11526','00306934505633','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 12:45:23',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 \rRR723014245CN\r'),(2255,696406774015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','tobysdruso','tobysdruso@yahoo.it','Tomas Sheridan','7/1 Montpelier Park','Edinburgh','lothian','UNITED KINGDOM','eh104lu','07708795648','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 13:34:28',0,NULL,3,1,2,1,NULL,NULL),(2256,640317977002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'',39,'hermeshine','cheaphuntgear','ytail@roadrunner.com','Blaine Anthony','123 Unity Rd','Benton','ME','UNITED STATES','04901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-01 13:46:14',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(2257,640319795002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','bmwracer41','ross@atlasaerospace.com','ross bleustein','7820 NW 56th St','Doral','FL','UNITED STATES','33166-3524','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 13:52:21',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2258,640318150002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','mustafakarli','mkarli1@yahoo.com','Mustafa KARLI','BIL LOJMANLARI A. BLOK D.4<br>GOLOVASI MEVKII CEYHAN','ADANA','','TURKEY','01985','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 13:55:22',0,NULL,3,1,2,1,NULL,'531t çš„å¿«è£…æ¿ï¼Œ ä¸‹åˆåˆ° '),(2259,601537636001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','joao2k1','info@portugalgay.pt','joao paulo','Rua St. Ant. Contumil, 152-6Dto','Porto','','PORTUGAL','4350-285','919030229','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 14:07:53',0,NULL,3,1,2,1,NULL,' '),(2260,640328881002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','matteosaderis80','matteosaderis@gmail.com','Matteo Saderis','Via Toscana 15','Segrate','MI','ITALY','20090','3402300727','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 14:18:05',0,NULL,3,1,3,1,NULL,'canon æ‘„å½±èƒŒå¿ƒ  L   1\rè€æ¬¾ \rRR723014316CN'),(2261,640338738002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','fornan100','johan.fornstedt@gmail.com','Johan Fornstedt','Kuppbolsvagen 70A','GAVLE','GAVLE','SWEDEN','80430','+46736494260','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-01 14:44:16',0,NULL,3,1,3,1,NULL,'RR723014280CN\r '),(2262,601575653001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:18',0,NULL,8,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2263,640361856002,120454219152,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',5.8,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:19',0,NULL,8,1,17,0,NULL,'å‘ä¸Šåˆå¹¶ '),(2264,640362036002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','twiggy_mtl','patrice33@videotron.ca','Patrice Cuerrier','1, Alexandre-Graham-Bell<br>Wing E4','Verdun','QC','CANADA','H3E3B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 15:48:19',0,NULL,3,1,2,1,NULL,NULL),(2265,601594378001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','mbagah1','kamenyi1@yahoo.com','Robert Kamenyi','714 N Washington Ave','Warrensburg','MO','UNITED STATES','64093-1153','(816) 679-1970','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 16:32:45',0,NULL,3,1,1,1,NULL,NULL),(2267,640408623002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','ilovelamp15','jonnylong15@gmail.com','Jonathan Long','3604 NE 80th St','Vancouver','WA','UNITED STATES','98665-1147','(503) 522-1961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 17:29:34',0,NULL,3,1,1,1,NULL,NULL),(2268,601659232001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','bandaler0','alexanderkhan@rogers.com','Alexander T Khan','175 Goldenwood Crescent','Markham','ON','CANADA','L6E 1L8','(905) 554-3344','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 18:46:27',0,NULL,3,1,2,1,NULL,NULL),(2269,640464552002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','myabellasdesigns','myabellas@gmail.com','Mayra Rigual','739 Kenilworth Cir','Lake Mary','FL','UNITED STATES','32746-5556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 19:15:09',0,NULL,3,1,1,1,NULL,'æ–°åœ°å€ï¼š\rMayra Rigual\r739 Kenilwoth cir. \rApt 205 Lake Mary \rFlorida 32746\rUNITED STATES'),(2270,640475547002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','123penniek','penniek@bresnan.net','Pennie Kittilson','2665 Valley Dr','East Helena','MT','UNITED STATES','59635-3132','(406) 227-7949','NoPaymentFailure','CheckoutComplete','Other','2010-12-01 19:29:55',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ è€æ¬¾  L   1 '),(2271,683112967016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','linnelinn55','soa.svensson@hotmail.com','Sven Svensson','StÃ¶rÃ¥sen 139','FÃ¶llinge','','SWEDEN','83060','0645-61024','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-01 19:45:45',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡   2\r115w 220v   2\råŒ…    1 \rlighting kit  $32\rYW864143532CN'),(2272,601713712001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',3,'AC2401',65.82,'hermeshine','froggy2i','ebay@photoalex.ca','Alex Leblanc','C.C. Franco-Ouest<br>411 Seyton dr','Nepean','ON','CANADA','K2H 8X1','(613) 820-2920 ext.: 1306','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 20:15:10',0,NULL,3,1,3,1,NULL,'40cm æ£š   3 \rRR723017975CN\r'),(2273,640513368002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','1515kate','caitlin_sara_hogan@yahoo.com','Kate Hogan','2312 3rd Avenue<br>Apt 313','Seattle','WA','UNITED STATES','98121','(214) 632-4882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-01 20:29:52',0,NULL,3,1,1,1,NULL,NULL),(2274,696720881015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','ukgadgetguy','graysteve@btinternet.com','Stephen Gray','32 Meadowgate Eston','Middlesbrough','Cleveland','UNITED KINGDOM','TS6 9JB','01642456019','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-01 22:12:42',0,NULL,3,1,2,1,NULL,NULL),(2275,640572079002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','rogercaldeira','rogeriocaldeira@gmail.com','Rogerio Caldeira','Rua Curruiras, 400','Florianopolis','Santa Catarina','BRAZIL','88063091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 22:23:41',0,NULL,3,1,2,1,NULL,NULL),(2276,640589122002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','mafldemamafldema','fabridale@gmail.com','fabricio dalessandro','cachimayo 1324','buenos aires','capital federal','ARGENTINA','1424','49328403','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-01 23:07:52',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2277,601812223001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','lestebr','ivanleste@metacomsoft.com.br','Ivan Leste Ribeiro','Rua Sagitario, 81 - Apt. 501','Belo Horizonte','MG','BRAZIL','30360-230','55 31 3293-8926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 00:03:56',0,NULL,3,1,2,1,NULL,NULL),(2278,601815694001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jfreyesjr','rjj2jljr2@yahoo.com','JOSE REYES','10527 W Chautauga MTN','LITTLETON','CO','UNITED STATES','80127-3858','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 00:12:32',0,NULL,3,1,1,1,NULL,NULL),(2280,640632991002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',9.25,'hermeshine','teenyharris','teeny.harris@gmail.com','Teeny Harris','6211 Wrightsville Ave<br>Apt 157','Wilmington','NC','UNITED STATES','28403-3853','(704) 572-1042','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 01:36:07',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(2281,696800455015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','completecqc','jason.litchfield@gmail.com','lauren pieri','42 ambrose rise wheatley','oxford','Oxfordshire','UNITED KINGDOM','ox33 1ye','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 01:42:40',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  C1   1 '),(2282,640645620002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lieslkarbo','lkardatzke@comcast.net','Liesl Bohan','5580 MacDonald St','Lansing','MI','UNITED STATES','48911-7218','(517) 699-0884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 02:20:53',0,NULL,3,1,1,1,NULL,NULL),(2283,640654471002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mello021','rafael.calero@hotmail.com','Rafael Calero','Rua GirÃ£o Barroso 100<br>Bloco 3B apartamento 202 Alcantara','SÃ£o GonÃ§alo','Rio de Janeiro','BRAZIL','24711-160','55 21 87050724','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 02:51:32',0,NULL,3,1,2,1,NULL,NULL),(2284,601866226001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','tadichter','dichtert@charter.net','Terry Dichter','3525 Eddingham Ave','Calabasas','CA','UNITED STATES','91302-5828','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 03:24:44',0,NULL,3,1,1,1,NULL,NULL),(2285,601868264001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','discountjunkseller','discountjunk@yahoo.com','James McDonald','PO Box 1962','Rockingham','NC','UNITED STATES','28380-1962','(910) 273-8819','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-02 03:32:06',0,NULL,3,1,1,1,NULL,NULL),(2286,601868667001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','jackymf6','lhmarketing178@hotmail.com','Vu Kah Tshun@Jacky Leong','LH Marketing/Jacky\'s Fitness Club, Block D7, Lot 20,<br>Yee Shing Commercial Centre, Jalan Masak','Keningau','Sabah','MALAYSIA','89008','0168307935','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 03:44:39',0,NULL,3,1,2,1,NULL,NULL),(2287,696850500015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','peterrabbit1980','pompeysrabbit@yahoo.co.uk','Peter Lambeth','Flat 44, Copperfield House Wingfield Street','Portsmouth','Hampshire','UNITED KINGDOM','PO1 4NY','07784361945','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 04:26:04',0,NULL,3,1,2,1,NULL,NULL),(2288,640693499002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','rod5434','redge48034@aol.com','rodney edge','OPM-SANG NGS<br>Unit 61304','APO','AE','AA','09803-1304','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 05:42:48',0,NULL,3,1,1,1,NULL,' '),(2289,696885735015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','coussell','tom@botservice.net','Tom Coussell','20 Gainsborough Road','Bournemouth','Dorset','UNITED KINGDOM','BH7 7BD','01202394688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 07:06:25',0,NULL,3,1,2,1,NULL,NULL),(2290,601921743001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2106',32,'hermeshine','777soln','mgg@777solution.net','M. Gastrock','2427 Nina St<br>Apt 2','West Covina','CA','UNITED STATES','91792','(626) 667-7346','NoPaymentFailure','CheckoutComplete','Other','2010-12-02 08:46:33',0,NULL,3,1,1,1,NULL,'è“è‰²èƒŒå¿ƒ æ— å­—  xxxl  1 '),(2291,696921410015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'',7.8,'hutongstore','tangosierraone','tn.watson@btinternet.com','Thomas Watson','\'Camusfearna\' 19 Sycamore Gardens','BLACKWOOD','Lanarkshire,Scotland','UNITED KINGDOM','ML11 9SX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 09:29:13',0,NULL,3,1,2,1,NULL,'star6 æ˜Ÿå…‰é•œ   1 '),(2292,640745119002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','timchen8653','timchen415@hotmail.com','Xie Tian Chen','5532 Geary Blvd<br>Apt B','San Francisco','CA','UNITED STATES','94121-2209','(415) 832-0521','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 10:08:59',0,NULL,3,1,1,1,NULL,NULL),(2293,600998261001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',153.68,'hermeshine','scar074','energosb@yandex.ru','Alexander Tihonov/Ð¢Ð¸Ñ…Ð¾Ð½Ð¾Ð²','Salutnay 10 - 22<br>Ð¡Ð°Ð»ÑŽÑ‚Ð½Ð°Ñ 10 - 22','Chelybinsk/Ð§ÐµÐ»ÑÐ±Ð¸Ð½ÑÐº','Ð§ÐµÐ»ÑÐ±Ð¸Ð½ÑÐºÐ°Ñ Ð¾Ð±Ð»Ð°ÑÑ‚ÑŒ','RUSSIAN FEDERATION','454071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 10:12:10',0,NULL,3,1,5,1,NULL,' 2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\råŒ…   1\r60cm æ£š  1\rä¸­å·å†…èƒ†åŒ…  æ— å­—   1\rCP212235114CN\r\rå€’å½±æ¿   1\r'),(2295,640753641002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','kbro7815','broumand@hotmail.com','Kamyar Broumand','Schavei 69','Overijse','','BELGIUM','3090','+3226876031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 10:42:53',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  4 \rRR723014599CN'),(2296,601973048001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','iunux','desmondyee@iunuxstudio.com','Desmond Yee','Blk. 897A, Tampines St.81, #09-714','default','','SINGAPORE','521897','96465453','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 11:58:08',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿  1 \rRR723014585CN'),(2297,601978738001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','szaborobert3','szaborobert8@gmail.com','Robert Szabo','PattantyÃºs Ã. u. 1. 1/4.','Miskolc','','HUNGARY','3529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 12:17:12',0,NULL,3,1,2,1,NULL,NULL),(2298,602002958001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','zellyzell','dzelikovitz@hotmail.com','David Zelikovitz','94 regal road','Toronto','ON','CANADA','M6h2k2','(416) 347-8688','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 13:37:04',0,NULL,3,1,2,1,NULL,NULL),(2299,602022687001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','chris_here','chrkuhn@gmail.com','Kuhn Christoph','Im Lee 15','Winterthur','','SWITZERLAND','8400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 14:32:38',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1 \rYW864143521CN\r\rlight stand  $15'),(2300,602042275001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','rnd.ru','rnd@getek.ru','Ruslan Dvornikov','Solov\'inyj proezd, d.14, kv. 442','Moscow','Moscow','RUSSIAN FEDERATION','117593','+7 906 7140185','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 15:38:09',0,NULL,3,1,3,1,NULL,'çº¢ç›’ç¯æž¶  1 \rRR723014381CN'),(2301,602050555001,110583278393,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'AA2303',6.7,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 15:50:04',0,NULL,8,1,17,0,NULL,NULL),(2302,602048171001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.8,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 15:51:30',0,NULL,8,1,17,0,NULL,NULL),(2303,602047696001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','jorgeamoros','jorgeamorosd@gmail.com','Jorge AmorÃ³s PayÃ¡','Rio Segura 52','Torrellano - Elche','Comunidad Valenciana','SPAIN','03320','660660077','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 15:51:30',0,NULL,3,1,4,1,NULL,'6662a   1\rå¤©æ¶¯ 58mm nd8  1\r58mm uv    2 \rYW864143554CN\r\rtripod   $15'),(2304,602053950001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fipinha22','filipa.a.f.agostinho@gmail.com','Filipa Agostinho','PraÃ§a Gil Vicente nÂº 3 4ÂºEsq','Lisbon','Prior Velho','PORTUGAL','2685-404','00351913508319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 16:01:15',0,NULL,3,1,2,1,NULL,NULL),(2305,640856242002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','slemmigahelge','slemhelge@gmail.com','Kenny Berglund','Karlfeldtsgatan 36 A','VÃ¤sterÃ¥s','VÃ¤stmanland','SWEDEN','72222','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 16:13:05',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143565CN\r'),(2306,640867735002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','*yoyo*69','cd.denis@gmail.com','Denis Cemazar','Breg ob Savi 22a','Mavcice','Kranj','SLOVENIA','4211','+38642332975','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 16:34:13',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2307,602068751001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 16:41:29',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014364CN'),(2308,640880868002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','ladysalsa514','marysetanguay@hotmail.fr','Maryse Tanguay','5230, 7e Avenue','Montreal','QC','CANADA','H1Y 2N3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:03:56',0,NULL,3,1,2,1,NULL,NULL),(2309,640539063002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','67jonasttt','tom.jira@o2active.cz','Tomas Jira','Machateho 682/8','Praha5','vÃ½chozÃ­','CZECH REPUBLIC','15200','00420725586863','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 17:19:32',0,NULL,8,1,17,0,NULL,NULL),(2310,602093745001,110583278219,'TianYa 62mm CPL filter New 62 Circular Polarizing C-PL',1,'AA2304',6.5,'hermeshine','67jonasttt','tom.jira@o2active.cz','Tomas Jira','Machateho 682/8','Praha5','vÃ½chozÃ­','CZECH REPUBLIC','15200','00420725586863','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:32:52',0,NULL,3,1,5,1,NULL,'å¤©æ¶¯ 62mm CPL   1 \r6662a   1\rCP212235105CN\r'),(2311,640901173002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÃšMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 17:49:36',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   2 '),(2312,697133004015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','angelmiguel.a','dispar@dispar.es','Angel Miguel Albertos GÃ³mez','C/ PÃ­o Baroja nÂº 1, Bloque 1, 3Âº C','Boadilla del Monte','Madrid','SPAIN','28660','625098732','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 18:00:35',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å›› ç¯å¤´   1 '),(2313,640924077002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','lamzak','lamgagnon@yahoo.com','Lambert Gagnon','3033 Ziron Ave','Simi Valley','CA','UNITED STATES','93065-0507','(805) 452-9683','NoPaymentFailure','CheckoutComplete','Other','2010-12-02 18:34:13',0,NULL,3,1,1,1,NULL,'canonèƒŒå¿ƒ  L   1 æ—§æ¬¾ '),(2314,600881692001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',22.2,'hermeshine','3824alain','brod_alain@hotmail.com','Alain Brodeur','11762 26e avenue','St-Georges','QC','CANADA','G6A 1E8','(418) 221-7093','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 18:36:33',0,NULL,3,1,3,1,NULL,'77mm é•œå¤´ç›–  canon  9 \rRR723014404CN'),(2315,601588165001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',94.9,'hermeshine','shark_raph','shark.raph@gmail.com','Maksim Sarychau','Peterdy utca 5, 1/11','Budapest','Budapest','HUNGARY','1071','36207761177','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 18:45:52',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ç»¿ çº¢ï¼‰   1 \rCP212150630CN\r'),(2316,696938695015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','1947gp','georgepender@btinternet.com','GEORGE PENDER','2 KILN FIELD STAXTON','SCARBOROUGH','NORTH YORKSHIRE','UNITED KINGDOM','YO12 4RX','01944710510','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-02 19:09:09',0,NULL,3,1,2,1,NULL,'1.6x2.1 ç»¿è‰²èƒŒæ™¯å¸ƒ   1 '),(2318,683665537016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','ibisabelle','isa.vgl@gmail.com','bertrand maquin','5 rue trieu maquette','sirault','','BELGIUM','7332','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-02 19:12:14',0,NULL,3,1,3,1,NULL,'115w 220v   2 \rRR723014395CN'),(2319,683692370016,260660056106,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',2.4,'hutongstore','lkh4717','lkh@stoneloose.dk','Lars Hansen','RÃ¸dkÃ¦lkevej 14','StenlÃ¸se','','DENMARK','DK-3660','004529808500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 19:50:42',0,NULL,3,1,2,1,NULL,NULL),(2320,640965012002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','photos6288','ttocsm@gmail.com','Matt Scott','14 Cantonments Rd<br>Lyttelton Manor','Centurion','Gauteng','SOUTH AFRICA','0157','0732128584','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 19:59:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š  2\r115w 220v   2\råŒ…   1 \rLighting kit  $58\rYW864143576CN\r'),(2321,640977031002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','imalooser','brucek@outhouseinc.com','Cassie Keesee','4711 Regency Dr','Durham','NC','UNITED STATES','27713','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 20:06:08',0,NULL,3,1,1,1,NULL,NULL),(2322,683734997016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','7544bmw','alanmc@hotmail.fr','ALAN  BRYANT','101 RUE DU FOUR A CHAUX','LA CERLANGUE','HAUTE NORMANDIE','FRANCE','76430','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 20:51:18',0,NULL,3,1,2,1,NULL,NULL),(2323,602211661001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tayfun78','t_yildiz@msn.com','Tayfun Yildiz','Ortabayir Mahallesi Sarigol Caddesi<br>No.9 D.7','Istanbul','Kagithane','TURKEY','34413','+90 543 957 26 51','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 21:10:22',0,NULL,3,1,2,1,NULL,' '),(2324,602214345001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','jckaphotography','jaybass5@gmail.com','Jon Adjjahoe','6210 Belcrest Rd<br>Apt 1032','Hyattsville','MD','UNITED STATES','20782-2972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-02 21:17:08',0,NULL,3,1,1,1,NULL,NULL),(2325,641029814002,120565901367,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','lutreolus','lutreolus@yahoo.com.au','ben griggs','6/1-3 McGrath Court<br>Richmond','Melbourne','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 21:46:54',0,NULL,3,1,6,1,NULL,'717  135    1 \ræ–°åŠ å¡EMS\rEX000065338SG\r'),(2326,683772580016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','tullesfar','jens.nielsen45@gmail.com','Jens Peter Nielsen','Emdrupvej 137 st. th.','2400 KÃ¸benhavn NV','Denmark','DENMARK','0045','(0045) 50805538','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-02 21:50:05',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(2327,602233870001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','bacoretajoseluis','jlyep@hotmail.com','JOSÃ‰ LUIS YEPES ALARCÃ“N','C/ OESTE, 4 URB. LOS VIENTOS','MOLINA DE SEGURA','Murcia','SPAIN','30500','968641656','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 22:09:27',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014452CN'),(2328,641053840002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pedro.soria','pedrojsoria@gmail.com','Pedro Soria','c/ Goleta 8','Velilla de San Antonio','Madrid','SPAIN','E-28891','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-02 22:36:11',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014378CN'),(2329,641060764002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','playtaf','playvision@ono.com','CRISTOBAL BELLES VIDAL','c/ SAN FEDERICO NÂº1 2Âºd','ALMASSORA','Comunidad Valenciana','SPAIN','12550','964563106','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-02 22:55:07',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   2 '),(2330,641082388002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tusik123456','tusik12345@walla.com','Yishay Lamzin','P.O.BOX 44220<br>pisgat zehev','jerusalem','','ISRAEL','91441','972-52-3288889','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 00:04:48',0,NULL,3,1,2,1,NULL,NULL),(2331,641111220002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','stastlv','stas.peters@gmail.com','Stanislav Peters','Yesod Hamala<br>10/6','Tel Aviv','n/a','ISRAEL','66055','0544534881','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 01:54:07',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š  æ¬§æ ‡   2\råˆ†ä¸¤ç¥¨å‘\rRR723014262CN\rRR723014347CN'),(2332,602307293001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',1,'AB3313',41.99,'hermeshine','mcap1972','mario@avangardphoto.com','Mariusz Caputa','17 Gracefield Crt','Maple','ON','CANADA','L6A 1G5','(905) 417-9535','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 02:04:54',0,NULL,3,1,3,1,NULL,'sf17 canon   1 \rRR723010610CN'),(2333,602169326001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','thebiestsc','the_biest_sc@hotmail.com','Logan Biesterfeldt','2221, 19th ave south','Lethbridge','AB','CANADA','t1k1e7','(403) 795-3929','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 02:26:56',0,NULL,3,1,2,1,NULL,NULL),(2334,683912936016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','aquila_alba','stil@stilphoto.com','Martin Marcinkiewicz','73 Bryn Parc Morriston','Swansea','Swansea','UNITED KINGDOM','SA6 8ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 04:35:23',0,NULL,3,1,2,1,NULL,NULL),(2335,602364594001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','igorbb2010','biven-2001@mail.ru','Igor Baranov','Shirotnaya dom157 kv 109','Tyumen','','RUSSIAN FEDERATION','625028','+79044900222','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 06:35:40',0,NULL,3,1,5,1,NULL,' CP212150294CN\r'),(2336,602365607001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','coreylunsford','coreylunsfordphotography@yahoo.com','corey lunsford','10 Alta vista','Sylacauga','AL','UNITED STATES','35150','','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 06:40:19',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143580CN\r'),(2337,601427340001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',54.05,'hermeshine','studio94ua','studio94spd@gmail.com','Punov-Drozdovsky Stanislav','Pavlenko 16/31, ap 21','Simferopol','Crimea','UKRAINE','95006','+380505680222','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 07:56:40',0,NULL,3,1,3,1,NULL,'æ¸å˜ç°  1\rND4  1\r72mm çŽ¯æž¶  1\rä¸€è½¬å››ç¯å¤´   1\rçƒ­é´ç›–   1\r40cm æ£š  1\rRR723014333CN\r\r '),(2338,602384024001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','speckledfrog','specklesphotography@hotmail.com','Rebecca Thompson','97 Burke Rd','Ferntree Gully','Victoria','AUSTRALIA','3156','0397586989','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-03 08:26:53',0,NULL,3,1,6,1,NULL,' èƒŒæ™¯æž¶( ç™½ é»‘ ç»¿)   1\rEX000046078SG\r'),(2339,683964215016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','mevijaynair','mailmevj@ymail.com','Vijay Nair','H.No.4, 54 RGL Bungalows, phase 1, Mugalivakam Porur.PO','Chennai','TN','INDIA','600116','00919952079708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 08:37:10',0,NULL,3,1,2,1,NULL,NULL),(2340,602400958001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:40',0,NULL,8,1,17,0,NULL,NULL),(2341,602399966001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:41',0,NULL,8,1,17,0,NULL,NULL),(2342,641210464002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:42',0,NULL,8,1,17,0,NULL,NULL),(2343,641211517002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.77,'hermeshine','hhp4595','penghh@yahoo.com','Honghong Peng','3845 Evangelho Cir','San Jose','CA','UNITED STATES','95148-4374','(585) 214-9157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 09:43:42',0,NULL,3,1,1,1,NULL,'Lenspen   1\r58mm é•œå¤´ç­’  canon  1\r58mm uv   1\r58mm æ©¡èƒ¶ç½©    1 '),(2344,692692656015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','ergheiz','carlos_dlux@hotmail.com','JosÃ© Piteira','Rua de Entrecampos NÂº 28 7Âº andar  Bloco C  Sala  7.10','Lisboa','Lisboa','PORTUGAL','1749-076','00351962639038','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 11:17:26',0,NULL,3,1,2,1,NULL,'49mm æŽ¥å£çŽ¯   1 '),(2346,602430655001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','bheka134','barrykusuma@gmail.com','To : Barry Kusuma','Pondok Kelapa Indah<br>Jl kelapa kuning Raya blok C1 no 7, Jakarta Timur.','DKI','Jakarta','INDONESIA','13450','62811928357622193672032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 11:30:52',0,NULL,3,1,2,1,NULL,'Barry Kusuma\rPondok Kelapa Indah\rJl kelapa kuning Raya blok C1 no 7, Jakarta Timur.\rDKI Jakarta 13450\rIndonesia\r+62811928357 /+622193672032\rå°å·å†…èƒ†åŒ…  Nikon  1 \r'),(2347,641267421002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',87.8,'hermeshine','syl20n','syl20n@yahoo.fr','sylvain negro','15 rue gerbier','paris','ÃŽle-de-France','FRANCE','75011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 12:58:04',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\räº‘å°  2\ræŸ”å…‰ä¼ž   2 \rlight kit  $22\rYW864143672CN\r'),(2348,641274659002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','paorefon45','paorefon@yahoo.com.br','Fonseca Andre','Rua Domiciano Santana, 1239, Centro','Avare','Sao Paulo','BRAZIL','18700-080','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 13:28:29',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶  1 RR723014735CN'),(2349,684079032016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','berni9361','berni.gore7@fsmail.net','Bernadette McArthur','7 Gore Avenue','Salford','Greater Manchester','UNITED KINGDOM','M5 5LF','01617361324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:04:08',0,NULL,8,1,17,0,NULL,NULL),(2350,684078728016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','berni9361','berni.gore7@fsmail.net','Bernadette McArthur','7 Gore Avenue','Salford','Greater Manchester','UNITED KINGDOM','M5 5LF','01617361324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:04:09',0,NULL,3,1,2,1,NULL,'lenspen   1\ræ°”å¹+å¸ƒ   1 '),(2351,641294284002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','sunrayplaytime','rcrobson@cytanet.com.cy','Richard Campbell-Robson','PO Box 61185','Paphos','','CYPRUS','8131','26960665','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 14:15:56',0,NULL,3,1,2,1,NULL,' '),(2352,684092906016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','damianhose','damian@thefotografer.net','Damian Mizzi','The Foto Grafer. St.Thomas Street,','Fgura.','','MALTA','FGR 1605','+356 99253690','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 14:35:27',0,NULL,3,1,2,1,NULL,NULL),(2353,602488868001,110534332881,'CTR-301P Wireless Flash Trigger 2 Receiver SB800 580EX',1,'AKT001',41.9,'hermeshine','spfldcustomer33','bilyrocker33@gmail.com','Billy Jenkins','7880 N Prairie View Rd','Strafford','MO','UNITED STATES','65757-8879','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-03 14:40:43',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(2354,684096431016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','cankanbol','banner@firma.home.pl','Bartosz Wscisel','13 Glazebrook Close Dulwich','London','London','UNITED KINGDOM','SE218RP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 14:42:53',0,NULL,3,1,2,1,NULL,NULL),(2355,602495076001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cgrytten','cgrytten@online.no','Cato Grytten','Motlandsmarka 118','NÃ¦rbÃ¸','','NORWAY','4365','(+47)40249502','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 15:01:17',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ nikon xxxl   1\rè€æ¬¾ RR723014727CN'),(2356,641321977002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','sforzinda','galip.kurkcu@gmail.com','galip kurkcu','75. sokak (eski 15. sokak) no: 1/2<br>Bahcelievler','Ankara','Ankara','TURKEY','06500','903122210182','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 15:39:02',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£æ£š   1 RR723014744CN'),(2357,641340955002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','kostis123','karakiolis@gmail.com','Kostis Karakiolis','Mitropolitou Amvrosiou 17A','Larissa','GREECE','GREECE','41221','+306936479140','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 16:16:07',0,NULL,3,1,2,1,NULL,'ä½³èƒ½ä¸‰è§’åŒ…  1 '),(2358,697664235015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','rider76','goran76@abv.bg','Goran Manolov','jk.2A bl.76 vh.G et.2 ap.4','Kozlodui','Kozlodui   Vraca   Kozlodui','BULGARIA','3320','00359885555877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 16:36:25',0,NULL,3,1,2,1,NULL,''),(2359,641351266002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','alexandrnikitin','alexandrnikitin11@yandex.ru','ALEKSANDR NIKITIN','Grazhdanskiy pr. Dom-36 Kv-289','Sankt-Peterburg','','RUSSIAN FEDERATION','195220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 16:38:53',0,NULL,3,1,2,1,NULL,'ä½³èƒ½ä¸‰è§’åŒ…  1   '),(2360,640234084002,120654560408,'for waelilas',1,'',135,'hermeshine','waelilas','cubafm2@yahoo.com','wael fouad','dubai media city<br>CNN building first floor 103 arabian radio network','dubai','','UNITED ARAB EMIRATES','502012','+971507969122','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 17:01:53',0,NULL,8,1,17,0,NULL,NULL),(2361,602547982001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','waelilas','cubafm2@yahoo.com','wael fouad','dubai media city<br>CNN building first floor 103 arabian radio network','dubai','','UNITED ARAB EMIRATES','502012','+971507969122','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 17:05:40',0,NULL,3,1,8,1,NULL,' 6662a   1\rWT600   1\rlenspen   1\r110cm 5in1 åå…‰æ¿   1\rä¸èƒ½åˆåœ¨ä¸€èµ·ï¼Œå°±æŠŠåå…‰æ¿å‘å›½å†…å°åŒ…æŒ‚å·\rCP212330971CN\rRR723010654CN\r'),(2362,602552376001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','10marvinc','mcascante.63@gmail.com','MARVIN CASCANTE','2976 SW 23rd St','MIAMI','FL','UNITED STATES','33145-3312','506 244 5717 1','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-03 17:15:33',0,NULL,3,1,1,1,NULL,NULL),(2363,641375443002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','shelmilkitmu','giro_cyborg@yahoo.com','mohd nazirul asyraf','nakaku nunohashi 2-4<br>karejjitaun wingu 402','hamamatsu','Shizuoka','JAPAN','4328012','(080)-3662-2242','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 17:30:42',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡EMS\r\r717AH  1 \rEX000290784SG\r'),(2364,602346524001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','blue-frog-boutique','volkswagenmom@yahoo.com','Tarrah Kjolby','816 Peace Portal Drive','Blaine','WA','UNITED STATES','98230','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 17:41:47',0,NULL,3,1,1,1,NULL,NULL),(2365,697734914015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'',6.95,'hutongstore','susanns1','susanns1@yahoo.co.uk','Susann Schmidt','Interactive Data - BDG 13-17 Epworth Street','London','London','UNITED KINGDOM','EC2A 4DL','07786135252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-03 18:34:16',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2366,602604522001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 19:01:54',0,NULL,8,1,17,0,NULL,NULL),(2367,602599589001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 19:01:55',0,NULL,3,1,4,1,NULL,'tripod  $15 \rç‡•æ–‡ ä¸€ç¥¨äºŒä»¶\r\rYW864143786CN\r'),(2368,602603718001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2106',32,'hermeshine','obaidah13','alzayeas@aramco.com','Abdullah Salman Al Zayer','14729 182nd St<br>DHA 7539','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 19:01:55',0,NULL,3,1,4,1,NULL,'æ‘„å½±èƒŒå¿ƒè–„æ¬¾é»‘è‰² canon XL 1\r80CM 5in1 åå…‰æ¿   1\rYW864143716CN\r\rç‡•æ–‡ ä¸€ç¥¨äºŒä»¶\r '),(2369,697757225015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','weshtie','jennrussell@ireland.com','Jennifer Russell Fulgosi','Ehrlichovea 9/5 Sopot','Zagreb','','CROATIA','10,020','0996801907','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-03 19:11:48',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR723014758CN'),(2370,641441068002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','jcarrio','julio.carrio@gmail.com','Julio Carrio','Av.Oswaldo Cruz, 90/711<br>Flamengo','Rio de Janeiro','RJ','BRAZIL','22250060','+55+21-25532270','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 19:38:03',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†   1 RR723014660CN'),(2371,601962938001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','petrs4321','svoboda@lmail.cz','Petr Svoboda','Budovcova 1149, -','Podebrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-03 20:46:11',0,NULL,3,1,2,1,NULL,'nikon 90th é•œå¤´ç­’   1 '),(2372,602679478001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','narsuitus','narsuitus@hotmail.com','Dr. Harvey Cobb','9214 S King Dr','Chicago','IL','UNITED STATES','60619-7314','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-03 21:28:59',0,NULL,3,1,1,1,NULL,'åŒç¯å¤´   1 '),(2373,641516122002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','liardp66a','jikchan@shaw.ca','Jik C Chan','44 Varsity Estates Court N.W.','Calgary','AB','CANADA','T3B5B1','(403) 286-3759','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:02:19',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   1 '),(2374,602708555001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','dacamcam','davidcambero@yahoo.es','David Cambero Cambero','Avda. Burjasot 29 Esc. A Puerta 4','Valencia','Comunidad Valenciana','SPAIN','46009','659213721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:39:02',0,NULL,3,1,2,1,NULL,NULL),(2375,602712496001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','anafantastika','ka-indb@online.no','Karianne IndbjÃ¸r','Etterstadsletta 7a','Oslo','Oslo','NORWAY','0660','4799470518','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-03 22:49:23',0,NULL,3,1,2,1,NULL,NULL),(2376,684388568016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'',43,'hutongstore','damonjamesdriver','damonjamesdriver@yahoo.co.uk','Damon Driver','32 Blakeland Hill','Duxford','Cambridgeshire','UNITED KINGDOM','CB22 4RX','07515917469','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  2 \rYW864143705CN\r'),(2377,602728728001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','yelenam27','yelenam27@yahoo.com','Yelena Melnikov','1706 Sheepshead Bay rd<br>Fl 2','Brooklyn','NY','UNITED STATES','11235-3605','(917) 628-6823','NoPaymentFailure','CheckoutComplete','Other','2010-12-03 23:37:05',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ ï¼‰ 1\r2mç¯æž¶  2\r50-70 æ£š   1\r115w 110v   2\råŒ…   1 \rlighting kit  $30\rYW864143742CN\r'),(2378,641567544002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','oahudogger','oahuray@earthlink.net','Ray Gress','581 Lancaster Dr SE<br># 259','Salem','OR','UNITED STATES','97317','(503) 689-7696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 00:34:48',0,NULL,3,1,1,1,NULL,NULL),(2380,602772827001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3301',16.5,'hermeshine','msmim10','mimidorazio@bigpond.com','Emilia D\'Orazio','11 Irwin Road','Embleton','Western Australia','AUSTRALIA','6062','0892751143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 02:29:07',0,NULL,3,1,3,1,NULL,'52mm uv   5 RR723014687CN'),(2381,602779950001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','tmaxwell_design','max-o-s@hotmail.com','T.Maxwell  Smith','9 Palmgrove Ct','Palmwoods','Queensland','AUSTRALIA','4555','0754763915','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 02:59:41',0,NULL,3,1,6,1,NULL,'çº¢å¤´ç¯   æ¾³æ ‡  1 \ræ–°åŠ å¡EMS\rEX000239952SG\r'),(2382,641607783002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','snowdog0416','www.jeremysingleton.com@gmail.com','Jeremy Singleton','937 Blanche Dr','Miamisburg','OH','UNITED STATES','45342-2027','(937) 866-5550','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-04 03:02:31',0,NULL,3,1,1,1,NULL,'canon å•è‚©åŒ…  a1   1 '),(2383,602804482001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','waynej5227','wayne@epatant.com.au','wayne jaye (Ã©patant model management)','unit 1/12 ensign avenue','annerley','Queensland','AUSTRALIA','4103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 05:01:36',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1RR723014673CN '),(2384,697654529015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'',125,'hutongstore','2010villemuurinen','ville.muurinen@gmail.com','Ville Muurinen','Sahalahdentie 8','PiikkiÃ¶','','FINLAND','21500','+35840 5256749','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-04 07:18:05',0,NULL,3,1,4,1,NULL,'tripod $30 \rYW864143683CN\r'),(2385,602832885001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','drerkan20','mderkan@hotmail.com','ERKAN KAYGIN','Ã‡AMLARALTI MAH. DOÄžAN DEMÄ°RCÄ°OÄžLU CAD NO:2<br>FORUM Ã‡AMLIK AVM. DOUGLAS PARFÃœMERÄ°','DENÄ°ZLÄ°','MERKEZ','TURKEY','20070','+90 (555) 305 9607','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 07:56:06',0,NULL,3,1,5,1,NULL,'CP212330897CN\r '),(2386,641666474002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','plainamericanguy','grandbob@gmail.com','Robert Otey','3824 Virginia Avenue SE','Charleston','WV','UNITED STATES','25304-1508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 08:11:13',0,NULL,3,1,1,1,NULL,NULL),(2387,641671958002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','chrys9429','ccygay@yahoo.com','Chrysostom Ygay','3151 S ST<br>Apt 350','SACRAMENTO','CA','UNITED STATES','95816-7076','(714) 757-8460','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 08:34:46',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(2388,641680523002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','goldopt','gold@goldopt.ru','Vladimir Birukov','Kirova 96-313','Volgograd','','RUSSIAN FEDERATION','400059','89275104547','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 09:12:07',0,NULL,3,1,2,1,NULL,' '),(2389,641691097002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','yoaninka','yoanina.borisova@gmail.com','Yoanina Borisova','Mladost Bl.119 et9 ap47','Varna','Varna','BULGARIA','9020','+359886768542','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 09:51:39',0,NULL,3,1,3,1,NULL,'wf1005  1 RR723014695CN'),(2390,602865346001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','peroni_es','por@retemail.es','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 10:05:29',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°   1\ré‡é‡ï¼Ÿ 232g'),(2391,684586236016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','chrisgosling23','chris@gosling.com','Chris Gosling','Carl Plougs Vej 6, st.th','Frederiksberg','','DENMARK','1913','+45 3379 0185','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 11:11:54',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR723014700CN'),(2392,698107222015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','up-north-ian','hello@ianmcmanus.com','Ian McManus','16 Langdale Road','Blackburn','England','UNITED KINGDOM','BB2 5DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 11:18:01',0,NULL,3,1,2,1,NULL,NULL),(2393,602930070001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','caracolits','caro.contreras@gmail.com','Carolina Andrea Contreras Tapia','Maquehue 9250','Hualpen - VIII regiÃ³n','Region del Bio Bio','CHILE','4601980','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 13:21:47',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1 '),(2394,641770034002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','hector_python','teufeur_1987@hotmail.com','Meckes','79, rue principale','Leutenheim','Alsace','FRANCE','67480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 13:48:11',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…canon   1 '),(2395,641774249002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','narsil06','dewiric@ebuyclub.com','David RICHARD','54 allÃ©e des Consuls','GUERANDE','Pays de la Loire','FRANCE','44350','0647886622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 13:58:38',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014611CN'),(2396,641776404002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','davidammar','duduammar@gmail.com','david amar','coresh 1915','Afula','Israel','ISRAEL','18310','9720524687337','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:04:27',0,NULL,3,1,2,1,NULL,NULL),(2397,641782008002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','1103peterd','photojack5@gmail.com','Peter Damo','69 Wigram Rd<br>Glebe','Sydney','New South Wales','AUSTRALIA','2037','0296604194','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:36:39',0,NULL,8,1,17,0,NULL,NULL),(2398,602872723001,110532007244,'77mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1304',35.22,'hermeshine','1103peterd','photojack5@gmail.com','Peter Damo','69 Wigram Rd<br>Glebe','Sydney','New South Wales','AUSTRALIA','2037','0296604194','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:36:39',0,NULL,3,1,3,1,NULL,'RS-C3   1\r77mm é•œå¤´ç›–  canon   1\rå¤§å·ç°å¡    1\r40cm æ£š    1\rRR723014894CN\r '),(2399,602930477001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 14:41:59',0,NULL,3,1,2,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2400,698204712015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 14:55:18',0,NULL,3,1,2,1,NULL,'45w   2 '),(2401,602834117001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',14.98,'hermeshine','scroc_fr','scroc@hotmail.com','Guillaume ALEXANDRE','68, les Casses Vivert','La Batie Neuve','Provence-Alpes-CÃ´te d\'Azur','FRANCE','05230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:09:50',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\r77mm çŽ¯æž¶  1\rå¹¿è§’æ‰˜æž¶    1 '),(2402,641808768002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','hosa87','hosacrew@seznam.cz','AXA CNC stroje, s.r.o.','Jan Hosek<br>Cintlovka 535','Horovice','','CZECH REPUBLIC','26801','00420604913394','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:18:15',0,NULL,3,1,2,1,NULL,NULL),(2403,698221827015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',2,'',6.76,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','KÃ¤rberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 15:27:26',0,NULL,3,1,2,1,NULL,NULL),(2405,641819609002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','reyabe','mycadipo.ventas@gmail.com','Carlos DÃ­az Polo','C/ Justina NÂº62','Yecla','Murcia','SPAIN','30510','617850603','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 15:40:54',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2407,641824161002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',70,'hermeshine','conan80','tom@tomsig.de','Thomas Starke','Magnusweg 13 a','Gaimersheim','','GERMANY','85080','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 15:51:38',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ  canon L   2 è€æ¬¾ 1.292\rRR723010274CN\r'),(2408,641854005002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','magnet32','magnet32@hotmail.com','Jesus Neira Martel','Avenida Extremedura, 73C','Santiponce','Sevilla','SPAIN','41970','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 16:48:30',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž  1 \rRR723014625CN'),(2409,603047623001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','will2fire','williec@pacific.net.sg','Willie Chan','Pearl Bank #14-10','default','','SINGAPORE','169016','96195688','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 17:50:59',0,NULL,3,1,11,1,NULL,NULL),(2410,684794239016,260660054946,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB800',1,'',32.99,'hutongstore','mau180161','ik3ord1@inwind.it','Maurizio Busato','Sant\'Antonio n.73','Teolo','PD','ITALY','35037','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 17:59:52',0,NULL,3,1,3,1,NULL,'sf18 nikon  sb800   1 RR723014639CN'),(2411,641900608002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','melktabares','msegbar@gmail.com','Miguel Angel Segura Barandalla','C/SebastiÃ¡n Machado, 40','TACORONTE','Canarias','SPAIN','38350','922560864','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 18:10:44',0,NULL,3,1,4,1,NULL,'tripod $15\rYW864143694CN\r '),(2412,641926601002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','omriamos','omriamos@gmail.com','Omri Amos','Levi Eshkol 3<br>Apartment 4','Kiryat Motzkin','Israel','ISRAEL','26397','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 19:07:28',0,NULL,3,1,3,1,NULL,' RR723014642CN'),(2413,641939339002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','arqhfernandes','arq.h.fernandes@gmail.com','Hugo Fernandes','RRCRS Arquitectos<br>Av. D. Joao II, lote 1.03.2.1B, 4ÂºA1','Lisboa','Lisboa','PORTUGAL','1990-092','(+351) 918151509','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 19:23:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723014656CN'),(2414,603107661001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','mihocidavid','mihoci@gmail.com','David Mihoci','Preloska 66','Cakovec','Hrvatska','CROATIA','40000','098220252','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 19:26:54',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–äºŒ   1 \rRR723014568CN'),(2415,698391954015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','tullichcroft','kevin.mcglynn@virgin.net','kevin mcglynn','tullich croft soroba','oban','Argyll and Bute','UNITED KINGDOM','pa34 4sb','01631563717','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 19:40:56',0,NULL,3,1,2,1,NULL,NULL),(2416,603121605001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','duametef2010','duametef@seznam.cz','Jiri Padour','Na Luzci 735/3','Lazne Bohdanec','Czech Republic','CZECH REPUBLIC','533 41','+420 606 619 602','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-04 19:42:15',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  Nikon   1 '),(2417,684906515016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','philbot24','psoliven_24@yahoo.com','MR PAUL SOLIVEN','#2 Laureston Terrace,','Douglas,Isle of Man','Isle of Man','UNITED KINGDOM','IM2 5DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 20:39:13',0,NULL,3,1,2,1,NULL,NULL),(2418,641989048002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','adeje_dario','dario_adeje@hotmail.com','Dario Bascones Carrodeguas','Residencial Los Abalos nÂº1 El Galeon','Adeje','Canarias','SPAIN','38670','617441150','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 20:46:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž   1 \rRR723014903CN'),(2419,641992097002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','katzmeny77','katzmeny@gmail.com','meny  katz','moshe sharet 79/19 kyriat haim','haifa','israel','ISRAEL','26308','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-04 20:47:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž   1  \rRR723014850CN'),(2420,603164935001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','lsloomie','lsloomie@hotmail.com','Leo Loomie','9 Hall Pl','Albany','NY','UNITED STATES','12210-2550','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 21:00:35',0,NULL,3,1,1,1,NULL,NULL),(2421,642016440002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','tingzhao1688','vincent82123@hotmail.com','Min Wong','10352 Stone Ave N<br>Apt 6','seattle','WA','UNITED STATES','98133-9494','(206) 605-3138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 21:35:12',0,NULL,3,1,1,1,NULL,NULL),(2422,642019067002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','adamnguyen','shushilov3r@yahoo.com','Adam T. Nguyen','811 Seabrook ct','San Jose','CA','UNITED STATES','95111-1410','(408) 896-7794','NoPaymentFailure','CheckoutComplete','Other','2010-12-04 21:39:38',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR723014761CN'),(2423,698508621015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','imflister','borut.komac@mangrt.com','Borut Komac','Reska ulica  25','Ljubljana','Slovenia','SLOVENIA','1000','051674764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-04 22:48:57',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(2424,684981805016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','encl4ve','gummibear@rambler.ru','Vjaceslavs Sanins','Flat 11 190 Quarry Street','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 6QR','07791774216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-04 22:52:18',0,NULL,3,1,2,1,NULL,'lenspen   1 '),(2425,642057662002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','eaglewomyn','eaglewomyn@aol.com','Stephanie Shore','242 Rutland Blvd','West Palm Beach','FL','UNITED STATES','33405-5034','(561) 585-3662','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-04 23:04:20',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… Nikon   1 '),(2426,603240348001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fredwidall','fwwidall@uwaterloo.ca','Fred Widall','544 Red River Drive','Waterloo','ON','CANADA','N2T 2B7','(519) 744-1478','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 00:01:12',0,NULL,3,1,2,1,NULL,NULL),(2427,642095550002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','rsg123','rsghuman@hotmail.com','RUPAUL GHUMAN','595 Gidda Loop','YUBA CITY','CA','UNITED STATES','95993-5000','(530) 218-1257','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-05 00:55:16',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(2428,642110968002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','schwarzschild1924','philipcops@gmail.com','Winkin M.G.','Rue sur les Roches, 18','Namur','','BELGIUM','5004','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 01:45:04',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR723014775CN'),(2429,642119656002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','ko_paints','ko_paints@hotmail.com','Eric McPherson','13439 County Road 339','Sidney','MT','UNITED STATES','59270-3554','(406) 798-3122','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 02:18:40',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡  1 '),(2430,642125194002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0024',27.9,'hermeshine','cozine','ari.ahlbom@gmail.com','Ari Ahlbom','Koskitie 12 a3','Huittinen','Satakunta','FINLAND','32700','0449449011','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 02:34:55',0,NULL,3,1,3,1,NULL,'canon å•è‚©åŒ… A1   1\rRR723014801CN '),(2431,642133632002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','lpaulw1','lpaulw@charter.net','L. PAUL WASSERMAN','2433 S Nadine St<br>Apt 2','WEST COVINA','CA','UNITED STATES','91792-3559','(818) 625-0947','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 03:03:28',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2432,642133328002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jimstack1942','jimsta1942@roadrunner.com','James Stack','2158 Langdon Rd','Ransomville','NY','UNITED STATES','14131-9704','(716) 791-3990','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 03:03:35',0,NULL,3,1,1,1,NULL,NULL),(2433,603309136001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','overkillweldingco','lokistink1@comcast.net','georgia eckert','2205 Three Mile Run Rd','perkasie','PA','UNITED STATES','18944-2037','(267) 354-1783','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 04:17:36',0,NULL,3,1,1,1,NULL,NULL),(2434,603314419001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','morenah1000','videoz@terra.com.br','Azevedo Zilah','Rua Cesar Zama, 74 Bl 2/303<br>Lins de Vasconcelos','Rio de Janeiro','Rio de Janeiro','BRAZIL','20725-090','02178132984','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 04:39:40',0,NULL,3,1,2,1,NULL,NULL),(2435,642173734002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','karakozov2010','rogers@yandex.ru','Vladimir Karakozov','Grajdanskiy prospect<br>122-4-287','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195267','904-516-3517','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 05:54:57',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon L   1 è€æ¬¾ RR723014789CN'),(2436,642181036002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','sattastrin','sattas@inbox.com','Brad Semeniuk','Box 1244','Vernon','BC','CANADA','V1T6N6','(250) 558-8120','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 06:36:13',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž   2 CP212330883CN\r'),(2437,642184302002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','vintageboy69','nandgbsjeremy@hotmail.com','Jeremy Chuang','3251 Cardiff Ave<br>Apt 7','Los Angeles','CA','UNITED STATES','90034-2840','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 06:54:54',0,NULL,3,1,1,1,NULL,NULL),(2438,642220570002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','ostrenok','lostrenok@gmail.com','Leonid Ostrenok','Yunnatov street 3-28','Khimki','Moscow region','RUSSIAN FEDERATION','141400','7-985-773-9420','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 09:21:02',0,NULL,3,1,3,1,NULL,'115w 220v    2 RR723014792CN'),(2439,603378098001,110532006869,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','8anos','8annos@gmail.com','Nikopoulos Thanasis','OGA Panepistimiou 168','Patra','','GREECE','26443','00306945718123','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 09:33:35',0,NULL,3,1,2,1,NULL,NULL),(2440,642235669002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','wayne.ck','wayne_underoath@hotmail.com','Wayne Devine','Unit 2/262 Lenah Valley Rd, Lenah Valley','Hobart','Tasmania','AUSTRALIA','7008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 09:58:51',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(2441,603398645001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','jesabltd64','jeanette.edstrom@hotmail.com','jeanette edstrÃ¶m','illervÃ¤gen 7','Sundsvall','','SWEDEN','86232','0046702604435','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 10:23:01',0,NULL,3,1,2,1,NULL,''),(2442,642287562002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','ezavgorodniy','zavgorodniy@ymail.com','Eugene Zavgorodniy','Novoslobodskaya str. 73, gzt Kultura','Moscow','Moscow','RUSSIAN FEDERATION','127055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 11:49:49',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2443,642287437002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','nickybear0001','nickybear@internode.on.net','Michael Denholm','4 Meadowview Rise','Aberfoyle Park','South Australia','AUSTRALIA','5159','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 11:54:33',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon XL  1\rè€æ¬¾   RR723014713CN'),(2444,698810553015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'',29,'hutongstore','mickyblueeyes.ie','mickpcunningham@gmail.com','MicheÃ¡l Cunningham','N0 3 Riverchapel Place','Riverchapel / Courtown, Gorey, County Wexford','','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 12:26:32',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š   1   è‹±æ ‡RR723014571CN'),(2445,603462183001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','feelx100','brianleung1103@hotmail.com','Brian Leung','7451 Nevis Dr','Richmond','BC','CANADA','V7A 1J5','(778) 323-0032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 12:32:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(2446,698869398015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'',2.75,'hutongstore','anoi71','nevrotika@tiscali.it','IGNAZIO DE MAIO','VIA ACCADEMIA 36','SORRENTO','NA','ITALY','80067','0818073904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 13:56:04',0,NULL,3,1,2,1,NULL,'çº¢å¤–5in1   1 '),(2447,698886429015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','shildon2','ericwhite@talktalk.net','Eric White','21 Dale Rd','Shildon','Durham','UNITED KINGDOM','DL4 2LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 14:18:56',0,NULL,3,1,2,1,NULL,NULL),(2448,603532043001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chadrundle','crundle@cargologistics.com','Chad Rundle','8761 Dorchester rd<br>Suite 205','North Charleston','SC','UNITED STATES','29420','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 14:38:52',0,NULL,3,1,1,1,NULL,NULL),(2449,603580807001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','mikhaelsinenko','cper34@gmail.com','Mikhael Sinenko','bakhchivandzhi 2a flat138','Shelkovo-3','Moscow','RUSSIAN FEDERATION','141103','+79265594371','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 15:56:18',0,NULL,3,1,5,1,NULL,'wt600   1 CP212330923CN\r'),(2450,699031881015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','dushkoivanko','dusanivanko@yahoo.co.uk','Mr Dusan Ivanko','Startide Limited, Unit 72, Mill Mead Business Centre Mill Mead Road','London','London','UNITED KINGDOM','N17 9QU','07958769188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 17:08:42',0,NULL,3,1,2,1,NULL,NULL),(2451,699051150015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',3.76,'hutongstore','dkephalas','d_kephalas@kephalas.gr','Dimitris Kephalas','Tellou Agra 4','Volos','','GREECE','38333','6945802354','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 17:25:25',0,NULL,3,1,2,1,NULL,NULL),(2452,603678865001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','allenchester4xo8','allenchester@comcast.net','Charles Allen Chester','3011 Lopez Rd','Jacksonville','FL','UNITED STATES','32216-3509','(904) 641-4672','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-05 17:46:53',0,NULL,3,1,1,1,NULL,NULL),(2453,603699805001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','alex.shishkin','shishkin.82@gmail.com','Alexey Shishkin','Pr. Mira 64-197','Nizhnekamsk','Tatarstan','RUSSIAN FEDERATION','423571','+7-904-675-3650','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 18:30:46',0,NULL,3,1,2,1,NULL,NULL),(2454,685602399016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','paulmeakings','paul@pmeakings.orangehome.co.uk','paul meakings','121 South Eastern Road','ramsgate','Kent','UNITED KINGDOM','CT11 9QD','01843851053','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-05 18:31:41',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  2 è‹±æ ‡\r115w 220v   2\råŒ…  1\rlight kit  $32 \rYW864143764CN\r'),(2455,603745591001,110519774429,'Pro FANCIER WF-531T Tripod with 593H 6662a Upgraded NEW',1,'AE1101',79,'hermeshine','maormuki','mukipe@gmail.com','maor peretz','× ×•×¨×“××• 52 ×§.××ª×','×§×¨×™×ª ××ª×','','ISRAEL','28000','0774010258','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 18:50:05',0,NULL,5,1,18,0,NULL,NULL),(2456,642628299002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','chrispar76','chrisparsons76@sky.com','chris parsons','99 percival road','Eastbourne','East Sussex','UNITED KINGDOM','BN22 9JW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 19:08:50',0,NULL,3,1,2,1,NULL,NULL),(2457,603814386001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','wrongeway5','bjbrush@hotmail.com','Brian Brush','4282<br>WALTON WOODS ROAD','WALTON','NS','CANADA','B0N2R0','(902) 528-2716','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 19:38:16',0,NULL,3,1,2,1,NULL,NULL),(2458,699319025015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','canik1','sleeponit@dysonuk.com','Adrian Dyson','176 Meadfoot Road','Coventry','West Midlands','UNITED KINGDOM','CV3 3DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 20:38:26',0,NULL,3,1,2,1,NULL,NULL),(2459,642731184002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ftir','fotis_tirokomos@yahoo.gr','Fotis Tirokomos','6-8, Agisilaou str.<br>OTEGLOBE, BlueLand building 3rd floor','Marousi','Athens - Attica','GREECE','15123','+306975869317','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 20:38:56',0,NULL,3,1,2,1,NULL,NULL),(2460,685821335016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','tntmah','tntmahar1@optusnet.com.au','Terrence Mahar','19 O\'Neill street','Coffs Harbour','New South Wales','AUSTRALIA','2450','0266519703','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-05 21:10:53',0,NULL,3,1,6,1,NULL,' 2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¾³æ ‡\r115w 220v   2\råŒ…  1\ræ–°åŠ å¡EMS\rlight kit  $32 \rEX000290775SG\r'),(2461,642767835002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ozjohnbayid','texon@rogers.com','Oz John Tekson','2706 - 27 Sudbury Street','Toronto','ON','CANADA','M6J 3W6','(416) 837-3451','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 21:19:10',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723014829CN'),(2462,685857759016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','sanglierolivier','ptitgomme@yahoo.fr','Olivier  Sanglier','Rue Bois Madame , 37','Mont-sur-Marchienne','','BELGIUM','6032','0472476951','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-05 21:52:26',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723014815CN'),(2463,603941179001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','eryka91','eryka91@hotmail.com','Eryka Garbutt','4 Rechner Place, Flynn','Canberra','Australian Capital Territory','AUSTRALIA','2615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:03:44',0,NULL,3,1,2,1,NULL,'40cm æ£š   1 '),(2464,642805707002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','angelitofr','julietafraga@hotmail.com','Angel Fraga Rivera','C/ RÃ­a de Arousa NÂº 12 4ÂºB<br>Arteixo','A CoruÃ±a','Galicia','SPAIN','15142','607935537','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:12:13',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864143775CN\r'),(2465,603950128001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jlpe4837','jmloplin@yahoo.es','JosÃ© Manuel LÃ³pez Linares','Plaza JosÃ© RamÃ³n Aketxe, 8 - 5ÂºA','Leioa','PaÃ­s Vasco','SPAIN','48940','606 384 777','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:18:32',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864143731CN\r'),(2466,642802233002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','co$mik','cosmik@mail.ru','Maxim Shepelev','Schelkovskoe Shosse<br>26-1-93','Moscow','','RUSSIAN FEDERATION','105425','+79265403810','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:20:33',0,NULL,3,1,2,1,NULL,NULL),(2467,685879844016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'',28.99,'hutongstore','insidecover','alec.kirkham@red5audio.com','Alec Kirkham','21 Dalmore Drive','Airdrie','North Lanarkshire','UNITED KINGDOM','ML6 9AH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 22:22:36',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†  1 RR723014832CN'),(2468,699416465015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','wobbegong1977','wesg77@hotmail.com','Wesley Gottliebsen','55 barfleur lane','london','London','UNITED KINGDOM','se8 3dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-05 22:33:30',0,NULL,3,1,2,1,NULL,NULL),(2469,603964949001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','pierre50mm','hiboudejour@hotmail.com','Pierre Boucher','200, Fleury ouest','Montreal','QC','CANADA','H3L 1T7','(514) 858-7661','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-05 22:50:56',0,NULL,5,1,18,0,NULL,NULL),(2470,642825945002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','pierre50mm','hiboudejour@hotmail.com','Pierre Boucher','200, Fleury ouest','Montreal','QC','CANADA','H3L 1T7','(514) 858-7661','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-05 22:50:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   1\råå…‰ä¼ž   1 \rRR723010433CN\r'),(2471,641441578002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','sick_cycles','paypal@sickcycles.com','Brian A Bailey','9 EDGEWOOD ST','CHELMSFORD','MA','UNITED STATES','01824-2509','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-05 22:59:41',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  2 '),(2472,642864122002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','carlos.pizarro','carlos.pizarro.bravo@gmail.com','Carlos Pizarro Bravo','Avda Maria Moliner 48','Leganes','Madrid','SPAIN','28919','675123042','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 00:14:44',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 RR723014846CN'),(2474,603561555001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nallurjeyam1971','nallurjeyam@yahoo.com','thirukulasingam jeyapalan','78,nayanmar road,nallur,jaffna,srilanka.','jaffna','noth','SRI LANKA','40000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 01:11:40',0,NULL,3,1,2,1,NULL,'45w   2 '),(2475,642886392002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','robyn9315','princezo7@aol.com','Robyn Parker','9845 Deepwoods Dr','Shreveport','LA','UNITED STATES','71118','(318) 687-2279','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 01:07:01',0,NULL,3,1,1,1,NULL,NULL),(2476,642894013002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','fsumsn98','penpie64@bellsouth.net','PENNYE AREHART','PO Box 600368','ST JOHNS','FL','UNITED STATES','32260-0368','(904) 287-4186','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 01:32:55',0,NULL,3,1,1,1,NULL,NULL),(2477,638583636002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','9965glee','greg@liservices.com.au','Greg Lee','10 McNae Street','Moonee Ponds','Victoria','AUSTRALIA','3039','0398197084','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 02:27:47',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2478,604058169001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','duane2210','duey2210@msn.com','Duane Gullard','5610 80th St E','Puyallup','WA','UNITED STATES','98371-5457','(253) 881-1448','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 02:49:07',0,NULL,3,1,1,1,NULL,'å°å·é•œå¤´ç­’   1 '),(2479,604076889001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','acm8ker','uchillin14@embarqmail.com','dave green','30 Apple Hill Holw','casselberry','FL','UNITED STATES','32707-4945','(407) 767-0755','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 03:42:02',0,NULL,3,1,1,1,NULL,NULL),(2480,604068726001,110531022936,'3ft Universal TTL Off camera Cord  Canon/Nikon/Pentax',1,'AB3319',18.5,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:06',0,NULL,8,1,17,0,NULL,NULL),(2481,642953603002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:06',0,NULL,8,1,17,0,NULL,NULL),(2482,604067896001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 05:42:05',0,NULL,8,1,17,0,NULL,NULL),(2483,604083612001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 05:42:07',0,NULL,8,1,17,0,NULL,NULL),(2484,642955806002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','udarling1','udarling1@verizon.net','Ural Darling','202 40th St S','Saint Petersburg','FL','UNITED STATES','33711','(727) 327-6915','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-06 05:42:08',0,NULL,3,1,4,1,NULL,' 2m ç¯æž¶  2\ræ–œè‡‚   1\råå…‰æ¿æ”¯æž¶   1\r80cm 2in1 åå…‰æ¿   1\rçˆµå½±ttlçº¿ 1m   1\rçˆµå½±æ— çº¿ c3   1\rä¸€ç¥¨å¤šä»¶\rYW864143650CN\r\r\r'),(2485,642982906002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2106',32,'hermeshine','countryboycreations','maurice@countryboycreations.com','Country Boy Creations LLC','300 Berkshire Dr<br>Ste E','Columbia','SC','UNITED STATES','29223-1859','(803) 600-6563','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 05:46:45',0,NULL,3,1,1,1,NULL,'è–„æ¬¾ æ‘„å½±èƒŒå¿ƒ  NIkon  xxl   1 è“è‰²'),(2486,642991326002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','a_brooke2006','afordham06@yahoo.com','Amber Baldino','351 Clover Brook Dr','Locust Grove','GA','UNITED STATES','30248-3692','(678) 294-5675','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 06:32:29',0,NULL,3,1,1,1,NULL,'NG200   1 '),(2489,643009087002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','anbidian','azine@mm.st','Matthew Capowski','9 Fair Oaks Drive','St. Albert','AB','CANADA','t8n 1p7','(780) 964-1200','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 08:12:40',0,NULL,3,1,2,1,NULL,'NG200   1 '),(2490,604150265001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','agreis81','agreis@agreis.hu','Bela Forgo','FÃ³ti Ãºt 122','Budapest','Budapest','HUNGARY','H-1046','36704584638','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 09:34:26',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1  \rRR723010362CN\r'),(2491,643036564002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 10:02:34',0,NULL,3,1,3,1,NULL,'\rRR723010455CN\r'),(2492,604173161001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','uszkomatonta','don@tricon.hu','Szilard Pasztor','KaposvÃ¡r u. 14-18.','Budapest','Budapest','HUNGARY','1117','+3613727154','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 10:59:54',0,NULL,3,1,2,1,NULL,NULL),(2493,686154370016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','nimrod1937a','etootell@btinternet.com','Eric Tootell','14, Tennyson Avenue','Chorley','Lancashire','UNITED KINGDOM','PR7 3HX','01257231741','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 11:02:29',0,NULL,3,1,2,1,NULL,NULL),(2494,643053525002,120601698743,'Canon 52mm Reverse Adapter 450D 50mm 1.8 500D Macro',1,'AA1207',4.4,'hermeshine','lesterlem','lesterlem@hotmail.com','Justin Lem','1st Floor, 155 Wong Nai Chung Road, Happy Valley','default','','HONG KONG','default','(852) 983-4133 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 11:02:44',0,NULL,3,1,2,1,NULL,'canon 52mm åæŽ¥çŽ¯  1 '),(2495,641812696002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',62.79,'hermeshine','greeneagle65','mike.bolcskey@gmail.com','Martin Domeny (Eltec)','Daimler str.13-15','Wernau','','GERMANY','73249','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 11:13:30',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  2 \r Mike Bolcskey\r Katona Jozsef u. 24. Budapest, 1194\r Hungary RR723010685CN'),(2496,604190456001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ap.lv','andris.pilmanis@inbox.lv','Andris Pilmanis','M.Nometnu street 28 - 24A','Riga','','LATVIA','LV-1002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 11:59:52',0,NULL,3,1,2,1,NULL,NULL),(2497,643076515002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','litlestar','msracheljavila@aol.com','RACHEL AVILA','824 Pepperidge Road','Westbury','NY','UNITED STATES','11590','(917) 439-1408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 12:22:55',0,NULL,3,1,1,1,NULL,NULL),(2498,643078141002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','c.diaz.c','cskyline@gmail.com','Carlos Diaz Canovas','Utrillas 8 5A','Madrid','Madrid','SPAIN','28043','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 12:26:11',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143834CN\r'),(2499,643086246002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','veerawol','veerawol@innovate.co.th','Veerawong Lohayuenyongsook','1115/2 Itsaraparp Road<br>Wataroon','Bangkokyai','Bangkok','THAILAND','10600','66814979070','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 12:52:23',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2500,699735559015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'',7.75,'hutongstore','carnlough16','krzysztofosa@wp.pl','krzysztof ossowski','19 croft road','carnlough','Antrim','UNITED KINGDOM','bt44 0ex','02828885925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 13:04:07',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡   1 '),(2501,643092020002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:09:59',0,NULL,8,1,17,0,NULL,''),(2502,604214727001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:18:17',0,NULL,8,1,17,0,NULL,''),(2503,604218875001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',4,'AA1314',11.96,'hermeshine','ujangubed','ujangbidik@gmail.com','Ujang Hidayat / bidik photo','Jl Terusan Pasir Koja no .96B dan 96C','Bandung','Jawa Barat','INDONESIA','40232','081321 875152','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 13:31:21',0,NULL,3,1,2,1,NULL,'NIKON æœºèº«ç›–/é•œå¤´åŽç›–     4 '),(2505,604217901001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','tony_c77','tony_c@mail.ru','Cheremukhin Anton','Moravsky side str.  3-1-395','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192289','+79216446366','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 13:36:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRR723010963CN'),(2506,604226690001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','astralstar','astralstar2009@yandex.ru','Aleksander Udalov','Zavodskoe shosse, dom 56, kv. 29','Samara','Samarskaya oblast','RUSSIAN FEDERATION','443052','89171107322','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 13:54:27',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rCP212330945CN\r'),(2507,699786480015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','filmugamyba','info@filmugamyba.lt','Mindaugas Ciciunas','J.Basanaviciaus 17','Kretinga','','LITHUANIA','97125','+370 676 39744','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-06 15:01:49',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \r 52mm çŽ¯æž¶   1 \rND8    1\rRR723010932CN'),(2508,604251852001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','mickekss','micke_kss@hotmail.com','Mikael Andersson','Sadelmakaregatan 9','Klippan','','SWEDEN','264 70','+46735615009','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 15:05:46',0,NULL,3,1,2,1,NULL,NULL),(2509,601952525001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','georgeting','georgetingfz@gmail.com','George Ting','1st Floor, Lot 8795 Pending Court<br>Jalan Kwong Lee Bank','Kuching','Sarawak','MALAYSIA','93450','0128861512','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 15:31:16',0,NULL,3,1,3,1,NULL,'ç”³æŠ¥ï¼š camera accessories \råå…‰æ¿æ”¯æž¶    1\rRR723010416CN\r'),(2510,604265421001,110591560700,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','finsilop1','finsilop@gmail.com','Sergey Chupina','24, Polevaya Str.<br>Infopulse Ukraine LLC','Kiev','UA','UKRAINE','03056','380951891123','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 15:41:37',0,NULL,3,1,2,1,NULL,'82mm çŽ¯æž¶    1 '),(2512,642956936002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:05:48',0,NULL,8,1,17,0,NULL,NULL),(2514,642956662002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0024',18,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 16:08:02',0,NULL,8,1,17,0,NULL,NULL),(2516,604082334001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2106',32,'hermeshine','vespagott','viva.zapata@arcor.de','Helmut Zapatka','Klapheckenhof 27a','Gelsenkirchen','','GERMANY','45883','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:10:01',0,NULL,3,1,4,1,NULL,'è–„æ¬¾æ‘„å½±èƒŒå¿ƒ  canon é»‘è‰² xxxl   1 \rè€æ¬¾æ‘„å½±èƒŒå¿ƒ canon  xxxl   1\rcanon ä¸‰è§’åŒ…   2\rYW863884296CN\r'),(2517,604277480001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','zinmen','lavazza1@freemail.hu','Gabriel Melaga','Stefanikova 40','Sturovo','','SLOVAK REPUBLIC','94301','+421907738943','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 16:11:19',0,NULL,3,1,2,1,NULL,NULL),(2518,604272765001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','toprcm','jevgenijs.kuh@toprcm.lv','Jevgenijs Kuhalskis','Skanstes 29a-10','Riga','Latvia','LATVIA','LV-1013','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:15:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 RR723010668CN'),(2519,604295309001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','jobermesik','joberm01@yahoo.com','Jeffery Obermesik','10756 Larissa St','Orlando','FL','UNITED STATES','32821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 16:51:01',0,NULL,3,1,1,1,NULL,NULL),(2520,604297740001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','kirgon','matthieu.fynes@lesplansj.com','Matthieu FYNES','12 rue des couvre-toits','FRELINGHIEN','Nord-Pas-de-Calais','FRANCE','59236','0699039033','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 16:59:22',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864143823CN\r'),(2521,643189233002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','virgmayjune','ififig@gmail.com','Phill Yendt','114 Dalgleish Ave','Kingston','ON','CANADA','K7K 7E3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 17:08:05',0,NULL,3,1,2,1,NULL,NULL),(2522,643188765002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mmlowe2005','misty.dlowe@gmail.com','Misty Lowe','14030 Merseyside Dr','Pflugerville','TX','UNITED STATES','78660-8808','(512) 820-3624','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 17:15:48',0,NULL,3,1,1,1,NULL,NULL),(2523,604310451001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0024',20.99,'hermeshine','blinkyblinkyusa','blinky1@blinkyblinky.com','C Wilson','4405 Candlewood Pl<br>Wilson-Devoronoff Apt 103','Rapid City','SD','UNITED STATES','57702-0183','(605) 718-7494','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-06 17:22:12',0,NULL,3,1,3,1,NULL,'Nikon å•è‚©åŒ…  æ–°æ¬¾  1 \rRR723010420CN\r'),(2524,699866498015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','dale_ee','megake@gmail.com','Mihhail Maslakov','Vilde 6-5','Kohtla-JÃ¤rve','Estonia','ESTONIA','30321','+372 5123739','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-06 17:31:02',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½  é»‘ï¼‰   1 \rCP212330937CN\r'),(2526,604320180001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','darkwater308','dougy308@verizon.net','DOUG YOUNG','308 Quarry St<br>Apt 501','QUINCY','MA','UNITED STATES','02169-4135','(617) 471-2740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-06 17:45:15',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   1 '),(2527,643246532002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','dstaton','2co@bloomingtononline.net','BloomingtonOnline.NET','101 W Kirkwood Ave<br>Ste 008A','Bloomington','IN','UNITED STATES','47404-6130','(812) 961-0630','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 18:55:02',0,NULL,3,1,1,1,NULL,NULL),(2528,604378118001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 19:21:52',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1\rND2/4/8    1 '),(2529,643270595002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','lom41','me@albertzak.com','Theresa Zak','GerasdorferstraÃŸe 153/167','Wien','','AUSTRIA','A-1210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 19:28:54',0,NULL,3,1,4,1,NULL,'BALLHEAD  $18 \rYW864143790CN\r'),(2530,641852965002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','rocknroller2009','ginji.amano@voila.fr','Romuald Bavarin','79 rue de Patay','PARIS','Ile-de-France','FRANCE','75013','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'CANan å•è‚©åŒ…  R2   1 \rRR723010393CN\r'),(2531,604414950001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','onyxander','tom.dekock@gmail.com','Tom','Leurschans 44','Steenbergen','','NETHERLANDS','4651 WJ','0167500853','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 20:17:36',0,NULL,3,1,2,1,NULL,NULL),(2532,604424144001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moti_malul','mm18@zahav.net.il','MORDEHAI MALUL','Hativat Givati 10/9','yavne','ISRAEL','ISRAEL','81205','97289493116','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 20:32:12',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723010380CN\r'),(2533,699994611015,250599408294,'Green.L 77mm 77 Neutral Density ND4 Filter ND 4 New',1,'',4.8,'hutongstore','1esadmf','paul10downingstreet@hotmail.com','paul white','10 burn road','scunthorpe','Lincolnshire','UNITED KINGDOM','dn15 8ax','01724344651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-06 21:18:06',0,NULL,3,1,2,1,NULL,NULL),(2534,604462975001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',1,'AB3313',41.99,'hermeshine','jighairy','frucgiu@comcast.net','Giuseppe Fruci','840 Michigan Ave<br>Apt 3','Evanston','IL','UNITED STATES','60202-2588','','NoPaymentFailure','CheckoutComplete','Other','2010-12-06 21:40:21',0,NULL,5,1,18,0,NULL,'sf17  canon   1 '),(2535,643347698002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','rzanini','zureta@gmail.com','Romulo Zanini de Gouveia Pinto','Rua Quintino Bocaiuva 131 ap. 61','Curitiba','PR','BRAZIL','80035090','55 41 33523731','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 21:53:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rRR723010376CN\r'),(2536,643375768002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','dragon011','dragon011@worldnet.att.net','Hipolito R Gonzales','6606 Sherman St','Houston','TX','UNITED STATES','77011-3524','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 22:23:04',0,NULL,3,1,1,1,NULL,'90th é•œå¤´ç­’   1 '),(2537,643380230002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','lasseskive','ln@netip.dk','Lars Nielsen','Skolevej 24','HÃ¸jslev','DK','DENMARK','7840','+4551386610','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 22:36:04',0,NULL,3,1,2,1,NULL,NULL),(2538,643386549002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','biasa84','salonnebiancamaria@yahoo.it','BIANCAMARIA SALONNE','VIA BALDARI, 12','LATIANO','BR','ITALY','72022','3403706565','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 22:48:11',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2539,604501261001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','the-intercessor','heytoddman@msn.com','Todd  Almquist','1093-143rd Ave NW','Andover','MN','UNITED STATES','55304','(763) 434-1423','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-06 23:06:55',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…   1 '),(2540,604512344001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 23:38:41',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ  è€æ¬¾   xxl  1\rRR723010402CN\r'),(2541,604514007001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:44:08',0,NULL,8,1,17,0,NULL,NULL),(2542,643409118002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:46:13',0,NULL,8,1,17,0,NULL,NULL),(2543,642961056002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','zinabra','mls_so@hotmail.com','Milles GonÃ§alves','Rua AmbirÃ© Cavalcanti 496<br>Rio Comprido','Rio De Janeiro','Rio de janeiro','BRAZIL','20250-490','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-06 23:49:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž    1\rç”³æŠ¥ï¼š gift  $37.9\rRR723010328CN\r'),(2544,604515974001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:53',0,NULL,8,1,17,0,NULL,NULL),(2545,643410162002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:54',0,NULL,8,1,17,0,NULL,NULL),(2546,604515432001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-06 23:53:54',0,NULL,3,1,3,1,NULL,' 77mm çŽ¯æž¶   2\r67mm çŽ¯æž¶  1\r52mm çŽ¯æž¶  1\rCPL    1\rND2/4/8    1\ræ¸å˜ç°   1\rRR723010314CN\r'),(2547,604519572001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','juanan.ramirez','juan-antonio.ramirez@vodafone.com','Juan Antonio Ramirez Quintero','San Bartolome 9, 3 B','Malaga','Andalucia Ceuta y Melilla','SPAIN','29013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 00:02:38',0,NULL,3,1,2,1,NULL,NULL),(2548,604531997001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','mafiacream','lord@eakom.com','Mabanza Ma-luvuezo','Route de Chavannes 123','Lausanne','','SWITZERLAND','1007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 00:42:41',0,NULL,3,1,4,1,NULL,'tripod dolly  $20 \rYW864143801CN\r\r'),(2549,604550712001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','jorge-o','ochavo-57@gmx.es','jorge ochavo muÃ±oz','avda badalona 8 atico 2<br>mollet del valles','barcelona','CataluÃ±a','SPAIN','08100','935935899','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 01:45:50',0,NULL,3,1,2,1,NULL,NULL),(2550,603472463001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',61.68,'hermeshine','marz520','mmarziotto@gmail.com','Michael Marziotto','The Financial Center At Woodbury<br>80 Crossways Park Dr W','Woodbury','NY','UNITED STATES','11797-2000','(516) 677-6270','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 02:14:47',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\råå…‰æ¿æ”¯æž¶   1 \r77mm æ©¡èƒ¶ç½©   1\rYW864143646CN\rboom arm  $18'),(2551,602803449001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','wavesonstn','rdrstnrit1945@yahoo.com','Stanley Ritterbach','20763 Syracuse Ave','Warren','MI','UNITED STATES','48091-2820','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 02:38:05',0,NULL,3,1,1,1,NULL,NULL),(2552,643468385002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','michelle_rk','michelle_rk@hotmail.com','Michelle Keith','2 E Walnut St','Washington','IN','UNITED STATES','47501-2785','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 02:45:56',0,NULL,3,1,1,1,NULL,NULL),(2553,700183741015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','sharonk100','skelly100@live.co.uk','Sharon Kelly','100 Glenrandel','Eglinton','Londonderry','UNITED KINGDOM','BT47 3XW','02871812068','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-07 02:51:57',0,NULL,3,1,2,1,NULL,'60cm 2in1   åå…‰æ¿   1 '),(2554,604599820001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','c-photo','cphoto@gmail.com','Christophe Testi','1048 Petie Way','Mountain View','CA','UNITED STATES','94040-3128','(650) 823-2706','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 04:44:26',0,NULL,3,1,1,1,NULL,NULL),(2555,604602240001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','spacec21','spacec21@hotmail.com','Shanon Hong','Unit B - 4th street nw<br>PO Box 1143','Nakusp','BC','CANADA','V0G 1R0','(250) 265-4354','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 04:53:31',0,NULL,3,1,2,1,NULL,NULL),(2556,643504037002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','spacec21','spacec21@hotmail.com','Shanon Hong','Unit B - 4th street nw<br>PO Box 1143','Nakusp','BC','CANADA','V0G 1R0','(250) 265-4354','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 04:53:31',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1\réº‚çš®   1 '),(2557,604606725001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','gotdane','c_james3@hotmail.com','Christy Saint','2924 Canna St','thousand Oaks','CA','UNITED STATES','91360','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 05:17:56',0,NULL,3,1,1,1,NULL,NULL),(2558,643511446002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','leclick','misscream@live.com','Rebecca Cream','147 St. Mary\'s Street','Fredericton','NB','CANADA','E3A2S1','(506) 260-3414','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 05:31:18',0,NULL,3,1,3,1,NULL,'ç™½è‰²ï¼ŒåŽšçš„èƒŒæ™¯å¸ƒ  3mx2m  1 RR723010699CN'),(2559,604617827001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',70,'hermeshine','fun2vy10','fun2vy@hotmail.com','Vy Mac','9203 39th Ave S','Seattle','WA','UNITED STATES','98118-4826','(206) 992-5886','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 06:24:45',0,NULL,3,1,3,1,NULL,'è€æ¬¾èƒŒå¿ƒ  nikon  L   2 \rRR723010637CN\r'),(2560,643524861002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pau1600','au.pinky@gmail.com','Pinky Au','1118 West 48th Ave','Vancouver','BC','CANADA','V6M 2N5','(604) 760-6889','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 06:46:00',0,NULL,3,1,2,1,NULL,NULL),(2561,643530975002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','phongd','phongacn@gmail.com','Phong Dang','11624 SE 223rd Dr','Kent','WA','UNITED STATES','98031-2398','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 07:22:35',0,NULL,3,1,1,1,NULL,NULL),(2562,604636574001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE1301',29.4,'hermeshine','balbirrichi','balbirsinghrishi@hotmail.com','Balbir Singh Rishi','218  Richvale Dr. South,','Brampton','ON','CANADA','L6Z 4W2','(905) 495-0321','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 08:10:01',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹äº‘å°   3 \rRR723010645CN\r'),(2563,643466703002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:20',0,NULL,8,1,17,0,NULL,' '),(2564,604542197001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:21',0,NULL,8,1,17,0,NULL,NULL),(2565,643438528002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',87.8,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:21',0,NULL,8,1,17,0,NULL,NULL),(2566,604542948001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','ludolilian','labouillette42@hotmail.fr','ludovic pivot','16 rue de l hotel de ville','le donjon','Auvergne','FRANCE','03130','0470995357','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 08:34:22',0,NULL,3,1,4,1,NULL,'301p ä¸€æ‹–ä¸‰   1\r 2m ç¯æž¶  3\räº‘å°   3\ræŸ”å…‰ä¼ž   3\r\r2mx3m èƒŒæ™¯æž¶    1\rlight kit  $25\rYW864143613CN\r'),(2567,643546250002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','arvin2k','arvin@nissan.com.sa','Arvin Biscarra','Alhamrani Trading & Import Co. - Nissan<br>Al Ahsa St., PO Box 2745','Riyadh','Malaz','SAUDI ARABIA','11461','0532124561','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 08:42:44',0,NULL,3,1,2,1,NULL,NULL),(2568,604645027001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','adamnguyen','shushilov3r@gmail.com','Adam T. Nguyen','811 Seabrook ct','San Jose','CA','UNITED STATES','95111-1410','(408) 896-7794','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 08:54:58',0,NULL,3,1,1,1,NULL,NULL),(2569,604666527001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','marovilya','ilyamarov@gmail.com','Ilya Marov','Matrosova str, 6, 18','Nekrasovskoe','Yaroslavskaya oblast','RUSSIAN FEDERATION','152260','+79159857562','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 10:19:34',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 58mm cpl   1 '),(2570,604749472001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','mloup','mirek.loup@gmail.com','Miroslav Loup','Reklama Kubicek, spol. s r.o.<br>Francouzska 81','Brno','','CZECH REPUBLIC','602 00','00420739229010','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 15:00:14',0,NULL,3,1,2,1,NULL,NULL),(2571,643660435002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dest6001ad59981','dest6001ad@gmail.com','Mohamed Yusri  Abdul Wahab','Blk 805 yishun ring road<br>#08-4279','Singapore','Singapore','SINGAPORE','760805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 15:13:41',0,NULL,3,1,11,1,NULL,NULL),(2572,604755664001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','jabr9677','real3550@gmail.com','joao abreu','15, ivatt place<br>west kensington','london','London','UNITED KINGDOM','w149nq','07939664372','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 15:19:56',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ  M   1 RR723010671CN'),(2573,700435832015,250619800184,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'',39,'hutongstore','atieayus','yatie_musm02@yahoo.com','Mohd Fairus Ahmad','18th Floor, Menara Boustead 69, Jalan Raja Chulan','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50200','0169274852','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-07 15:50:37',0,NULL,3,1,6,1,NULL,'æ–°åŠ å¡EMS\rEX000344200SG'),(2574,686878334016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','krolis007','svetlank@post.skynet.lt','Rolandas Kubilinskas','Staneviciaus 4-48','Vilnius','','LITHUANIA','LT-07129','(370)60029277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 15:56:17',0,NULL,3,1,2,1,NULL,NULL),(2575,643702793002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.5,'hermeshine','photomanglen','glensphotos@webtv.net','Glen Lipton','7929 Nagle Ave','North Hollywood','CA','UNITED STATES','91605-1708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 16:49:18',0,NULL,3,1,1,1,NULL,NULL),(2576,643704397002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','wlfranz','wlfranz@aol.com','William L. Franz','17 Lonsdale Ave','Dayton','OH','UNITED STATES','45419-3143','(937) 298-9780','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 16:59:57',0,NULL,3,1,1,1,NULL,NULL),(2577,643730746002,120500417599,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',10,'AA3311',56,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 17:47:10',0,NULL,3,1,3,1,NULL,'RR723010708CN '),(2578,643739991002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','clemen2002','find_ir@hotmail.com','Clement Auo','25 Kovan Road #12-21<br>Kovan Melody','Singapore','','SINGAPORE','545024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 18:04:26',0,NULL,3,1,11,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2580,700526157015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','nikiforosgt','nikiforosgt@yahoo.gr','NIKIFOROS MANOLAS','BOMOY 13, KYPSELI, KYPSELI KYPSELI','ATHENS','','GREECE','11364','6972740952','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 18:27:10',0,NULL,3,1,2,1,NULL,'sonyçº¢å¤–   1 '),(2581,686992368016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','benbammens','ben.bammens@telenet.be','Ben Bammens','Bosstraat 51','Hasselt','','BELGIUM','3500','0485730363','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-07 19:14:46',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder  $18\rYW864143635CN\r'),(2582,643780524002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','liongkoen','koen.liem@hccnet.nl','Koen Liem','Engelenburg 277','HAARLEM','','NETHERLANDS','2036RJ','0638515333','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 19:15:38',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(2583,700564409015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'',15.5,'hutongstore','thecuestick','kelsey_colin@yahoo.co.uk','colin kelsey','8 orchard grove','diss','norfolk','UNITED KINGDOM','ip224lx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-07 19:19:05',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  è‹±æ ‡   2 '),(2584,643783791002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','topcat999','tcip@att.net','Thomas D. Cipriano','3527 Oleander Ave','Alameda','CA','UNITED STATES','94502','(510) 865-2133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-07 19:21:32',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2586,604903857001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','anton.kovalev','aykovalev@gmail.com','Anton Kovalev','Yubileynaya str. 12 apartment 206','Serpukhov','Moscow','RUSSIAN FEDERATION','142204','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 20:15:01',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆç™½ï¼‰1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\råŒ…    1 \rCP212330985CN\r'),(2587,643771299002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','osmanoz26','osman.ufukecz@gmail.com','osman oz','sair fuzuli cad.no:27/a ufuk eczanesi','eskisehir','eskisehir','TURKEY','26010','+90 532 2710892','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-07 21:17:41',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ï¼‰   1\rCP212330999CN '),(2588,643904755002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','heliogas17','helio_rogerio@hotmail.com','HÃ©lio Lopes','Rua Padre AntÃ³nio Vieira nÂº12 1Âº andar','Rio Tinto','Rio Tinto/Gondomar/Porto','PORTUGAL','4435-370','+351916699358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:19:09',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2589,643909444002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','nickip911','nperi816@gmail.com','Nick Peri','PO Box 233<br>2749 Chestnut St.','York','NY','UNITED STATES','14592-0233','(585) 991-9880','NoPaymentFailure','CheckoutComplete','Other','2010-12-07 23:25:00',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723010756CN'),(2590,643910344002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','carloslzf','carlosliu913@gmail.com','Zhifeng Liu','54 Compton Street<br>Hillcrest','Auckland','','NEW ZEALAND','0627','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:25:03',0,NULL,8,1,17,0,NULL,NULL),(2591,643910334002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','carloslzf','carlosliu913@gmail.com','Zhifeng Liu','54 Compton Street<br>Hillcrest','Auckland','','NEW ZEALAND','0627','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-07 23:25:04',0,NULL,3,1,2,1,NULL,'72mm æŽ¥å£çŽ¯  1\rå¹¿è§’æ‰˜æž¶    1 '),(2592,605009114001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','mirare202','mariana_harsan@yahoo.com','Mariana Harsan','7717 rowan ct','annandale','VA','UNITED STATES','22003','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 00:11:48',0,NULL,3,1,1,1,NULL,NULL),(2593,643938729002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','ralphsworldtour','worldcup2006@verizon.net','Ralph Rodriguez','12654 Izetta Ave','downey','CA','UNITED STATES','90242-4942','(562) 382-7240','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 00:57:57',0,NULL,3,1,1,1,NULL,NULL),(2594,643956963002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:02',0,NULL,8,1,17,0,NULL,NULL),(2595,605036726001,110486687213,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:02',0,NULL,8,1,17,0,NULL,NULL),(2596,605033511001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:03',0,NULL,8,1,17,0,NULL,' '),(2597,605033753001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:03',0,NULL,8,1,17,0,NULL,NULL),(2598,605036805001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','jakubch88','info@jakubchrudina.eu','Jakub Chrudina','Matuskova<br>8','Havirov','Okres Karvina, Moravskoslezsky kraj','CZECH REPUBLIC','73601','608447543','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 01:51:04',0,NULL,3,1,3,1,NULL,'58mm çŽ¯æž¶   2\ræ¸å˜è“  1\ræ¸å˜æ£•   1\ræ¸å˜ç°   1RR723010739CN\r '),(2599,643961275002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','u8ey','adsl9lyi@tpg.com.au','Dave Tease','9 Boundary rd','Windang','New South Wales','AUSTRALIA','2528','0242954140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 02:02:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723010742CN'),(2600,605047356001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','rchall23','rchall242@hotmail.com','Robert Hall','3421 W Village Grove Pl<br>Apt 4','Memphis','TN','UNITED STATES','38115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:29:25',0,NULL,3,1,1,1,NULL,NULL),(2601,643972991002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','roshan517','patelro@msu.edu','Roshan patel','6532 spring brook road<br>apt302','rockford','IL','UNITED STATES','61114','(517) 388-0895','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:41:50',0,NULL,3,1,1,1,NULL,NULL),(2602,643978284002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','605ranger','stevie605@hotmail.com','steven ontaneda','349 NE 33rd St<br>Apt 1','miami','FL','UNITED STATES','33137-4047','(954) 593-7837','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 02:55:08',0,NULL,3,1,1,1,NULL,NULL),(2603,643978767002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','dooglestar88','laetitia@songololochildren.com','Laetitia H Casta c/o Liam O\'Prey','Plaza Lesseps 11<br>6Âº 1Âª','Barcelona','CataluÃ±a','SPAIN','08023','670357375','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 02:57:15',0,NULL,3,1,4,1,NULL,'ballhead $20 \rYW864143370CN'),(2604,605056745001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','wilsonpazos','wilsonpazos@hotmail.com','Wilson Pazos','Ekkodalen 16 2.tv','Aarhus','Danmark','DENMARK','8210','004528814877','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(2605,643628026002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','kingzazza','sizolee@gmail.com','SisÃ¡k ZoltÃ¡n','KecskemÃ©ti Ã. u. 2. 1/1','MakÃ³','','HUNGARY','6900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 06:50:02',0,NULL,3,1,2,1,NULL,NULL),(2606,644034026002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','amstel00','ndongo@gmail.com','ANA VERONICA NDONGO BINDANG','C/SIERRA DE LOS FILABRES 48<br>1Âº A','MADRID','Madrid','SPAIN','28038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 07:11:33',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   1 '),(2607,604936725001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',709.17,'hermeshine','mr0mer','tuzakk@gmail.com','Ã–MER GÃœNGÃ–R','Zumrutevler Mh. Ugral Sk. Altinsoy Is Merkezi No:14/3 Maltepe','Istanbul','','TURKEY','34852','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 07:27:39',0,NULL,3,1,6,1,NULL,'800w çº¢å¤´ç¯   2\rçº¢ç›’ç¯æž¶  2\r800w 220v ç¯æ³¡   5\r6663a   1\rwt600   1\r2mx3m èƒŒæ™¯æž¶   1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2\r10ç‰‡è£…  + 58mm çŽ¯æž¶   1\ré˜²é›¨ç½©   1\r115w  220v   2\r110cm 5in1 åå…‰æ¿  1\rEX000344213SG'),(2609,605111000001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','topcat999','tcip@att.net','Thomas D. Cipriano','3527 Oleander Ave','Alameda','CA','UNITED STATES','94502','(510) 865-2133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 07:34:35',0,NULL,3,1,1,1,NULL,NULL),(2610,605117600001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',4,'AA1204',6.46,'hermeshine','strafel67','strafel@cox.net','Robert Strafeldas','85 Northern Pine Loop','Aliso Viejo','CA','UNITED STATES','92656','(949) 215-9145','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 08:08:46',0,NULL,3,1,1,1,NULL,NULL),(2611,605131489001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','liveoakbob','bobyount@sbcglobal.net','Robert Yount','3400 Portola Dr<br>Apt 9','Santa Cruz','CA','UNITED STATES','95062-5137','(831) 479-4734','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-08 09:13:52',0,NULL,3,1,1,1,NULL,' '),(2612,605132400001,110469599322,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',24.99,'hermeshine','alien5651','allan5651@hotmail.com','Allan Bailey','18 Pioneer Drive<br>Narangba','Brisbane','Queensland','AUSTRALIA','4504','0733856654','NoPaymentFailure','CheckoutComplete','AU_Regular','2010-12-08 09:18:27',0,NULL,8,1,17,0,NULL,NULL),(2613,605132217001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','alien5651','allan5651@hotmail.com','Allan Bailey','18 Pioneer Drive<br>Narangba','Brisbane','Queensland','AUSTRALIA','4504','0733856654','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 09:27:56',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   æ¾³æ ‡  1\r45w   2 \rRR723010929CN'),(2615,604839908001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',4,'AE1302',43.2,'hermeshine','luizprettif','luizprettif@gmail.com','Luiz Pretti Filho','Estrada do Limoeiro, 500<br>Limoeiro','Aruja','SÃ£o Paulo','BRAZIL','07400-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 10:08:07',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ 4 \rRR723015078CN'),(2616,644085101002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','slartiii','ofer.maor@gmail.com','Ofer Maor','1 Moshe Vilensky St.','Tel Aviv','','ISRAEL','69623','054-6545406','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 10:52:34',0,NULL,3,1,2,1,NULL,NULL),(2617,687357169016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','dfleed74','harlock.arcadia@tin.it','Giuseppe Mirabile','Via Roma 283','Barcellona Pozzo di Gotto','ME','ITALY','98051','3490069162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 10:59:23',0,NULL,8,1,17,0,NULL,NULL),(2618,687358369016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','dfleed74','harlock.arcadia@tin.it','Giuseppe Mirabile','Via Roma 283','Barcellona Pozzo di Gotto','ME','ITALY','98051','3490069162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 11:02:22',0,NULL,3,1,2,1,NULL,'Lenspen  1\ræ°”å¹+å¸ƒ   1 '),(2619,644133919002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','mtbguy','anhvudo@hotmail.com','Anhvu Do','5761 Lake Melrose Dr','Orlando','FL','UNITED STATES','32829-7690','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-08 13:30:59',0,NULL,3,1,1,1,NULL,NULL),(2620,605178631001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',20.99,'hermeshine','jalanen','jani.alanen@pp.inet.fi','Jani Alanen','Possilanrinne 6 B','Tampere','','FINLAND','33400','+358400867241','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 13:37:56',0,NULL,3,1,3,1,NULL,'RR723015081CN '),(2621,605249495001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','veraz7','veraz7@hotmail.com','Juan RamÃ³n Reina Vera','c/ Camino Nuevo, 23','MÃ¡laga','AndalucÃ­a Ceuta y Melilla','SPAIN','29500','669335742','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:36:50',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723015095CN'),(2622,605246053001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','oles771','ovsjak@ukr.net','Oleksandr Ovsjak','Skrypnika 31a/49','Lviv','ua','UKRAINE','79049','380971101090','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:37:57',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR723015104CN'),(2623,605256559001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','veraz7','veraz7@hotmail.com','Juan RamÃ³n Reina Vera','c/ Camino Nuevo, 23','MÃ¡laga','AndalucÃ­a Ceuta y Melilla','SPAIN','29500','669335742','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:55:07',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rlight stand  $18\rYW863884753CN\r'),(2624,644188667002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','rocter1963','razvodovskij@gmail.com','Sergej Razvodovskij','Cialkovska 14-41','Daugavpils','','LATVIA','LV-5410','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 15:55:09',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2 æ¬§æ ‡  \r45w  8\råŒ…   1 \rCP212331005CN\r'),(2625,644209987002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','om-mariam','zbon_draz@yahoo.com','Fatemah Alhusayni','446 Blue Course Dr<br>Apt 1001','State College','PA','UNITED STATES','16803-2872','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 16:43:28',0,NULL,3,1,1,1,NULL,NULL),(2626,644220044002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','zara.warthog','robin.lake@mbnl.co.uk','Robin lake','44 Knox Road','Guildford','Surrey','UNITED KINGDOM','GU2 9AH','01483826827','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 17:01:35',0,NULL,3,1,2,1,NULL,NULL),(2627,605290079001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','mikey-fisher','michael.madio@gmail.com','Michael Madio','40 SPRUCE BLVD','ACTON','ON','CANADA','L7J 2Y2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 17:07:49',0,NULL,3,1,2,1,NULL,NULL),(2628,701110317015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','flpicuser072009','flfonseca.pro@gmail.com','Fernando Fonseca','970 Cumbernauld Road','Riddrie','Glasgow (City of)','UNITED KINGDOM','G33 2QR','01417701651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-08 17:36:55',0,NULL,3,1,2,1,NULL,NULL),(2629,699987787015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','shellysherring','shelly_harrell@msn.com','Shelly Herring','8245 Sawyer Mill Cv','Arlington','TN','UNITED STATES','38002-8361','(901) 734-3676','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-08 17:48:40',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70æ£š   2\r115w 110v   2\råŒ…    1 \rlighting kit  $32\rYW863884764CN\r'),(2630,687547354016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','slhpokey69','pokey69@hotmail.co.uk','Stacey Hughes','18 Ripon Road','Stevenage','Hertfordshire','UNITED KINGDOM','SG1 4LY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-08 18:02:50',0,NULL,3,1,2,1,NULL,NULL),(2631,701133643015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','nedproductions','s_ebay@nedproductions.biz','ned Productions Limited','12 Woodlands','Kerry Pike','Cork','IRELAND','default','0214872739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:21:34',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å›› ç¯å¤´   1 '),(2632,644263869002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','fredy_declercq','fredy_declercq@uol.com.br','Frederic Declercq','Rua Doutor JosÃ© Gustavo Bush 155<br>apart.: 101-A  bairro:Morumbi','SÃ£o Paulo','SP','BRAZIL','05705-190','+55-11-96257763','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 18:25:11',0,NULL,3,1,2,1,NULL,NULL),(2633,605207878001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','thomthomtreasures','cultho@yahoo.com','Thomas Cullum','2348 Hillcrest Rd','York','SC','UNITED STATES','29745-9309','(803) 684-5530','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 18:44:10',0,NULL,3,1,1,1,NULL,NULL),(2634,701108504015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.56,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:57',0,NULL,8,1,17,0,NULL,NULL),(2635,701112799015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:58',0,NULL,8,1,17,0,NULL,NULL),(2636,687537922016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','pea11','fotomalheiros@gmail.com','vitor malheiros','rua do ouro 11 Atouguia da baleia','Atouguia da Baleia','Penicha','PORTUGAL','2525-058','00351938360399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-08 18:54:57',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1\ræ–œè‡‚   1\r100-150 5in1 åå…‰æ¿   1\rä¸€ç¥¨ä¸¤ä»¶ \rlight kit $25\rYW863884775CN\r\r'),(2637,605407103001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','bolty1969','adambolt@hotmail.com','Adam Bolt','7 Georgia St','Coombabah','Queensland','AUSTRALIA','4216','0755015159','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 20:37:18',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR723015016CN'),(2638,605445023001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AO0025',40.99,'hermeshine','jumiroc','jumiroc@gmail.com','Juan M.  Roca Ripoll','Av. Argentina, 8, 1Âº, A','Palma de Mallorca','Baleares','SPAIN','07011','971288891','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 21:39:13',0,NULL,3,1,3,1,NULL,'nikon å•è‚©åŒ…  n4   1 \rRR723015020CN'),(2639,644384211002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 21:40:43',0,NULL,5,1,18,0,NULL,NULL),(2640,602314900001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','buycouture4less','sincityphotography@yahoo.com','Leah Seguin','8734 Haviland Rd','Las Vegas','NV','UNITED STATES','89123-0188','(702) 581-1075','NoPaymentFailure','CheckoutComplete','Other','2010-12-08 21:55:08',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3m x 6m ç™½è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š   2\r115w 110v   2\råŒ…   1\rlighting kit  $40\rYW864143753CN'),(2641,605460279001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','sabbatha190987','sabbathabali@hotmail.com','Julia Danilenko','Raketnyi Bulvar dom 9, korp. 2, kv. 113','Moscow','Moscow','RUSSIAN FEDERATION','129366','+79100020090','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 22:12:45',0,NULL,3,1,2,1,NULL,NULL),(2642,605469500001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','tresudek','todd@tr1design.net','Todd Resudek','7166 W Custer Ave<br>C423','Lakewood','CO','UNITED STATES','80226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-08 22:35:48',0,NULL,3,1,1,1,NULL,NULL),(2643,644404458002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','geeugenia','eugeniaapaula@gmail.com','Eugenia Paula','R aquilino Ribeiro n31  3esq<br>carnaxide','carnaxide','','PORTUGAL','2790-028','00351962054955','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 22:36:58',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ… 1 '),(2644,644412729002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','stgod2010','playwithebay2@gmail.com','Oleg Kirillov','39 Kosmonavtov Street, Apt.90','Korolev','Moskovskaya oblast','RUSSIAN FEDERATION','141080','+79162242040','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-08 22:45:40',0,NULL,3,1,3,1,NULL,'2mç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1\rRR723015033CN'),(2645,605485494001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','reznik.andrei','reznikandrew@gmail.com','Andrei Reznik','Avshalom Haviv 7/15','Ashqelon','Hadarom','ISRAEL','78642','+972545828707','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 23:19:03',0,NULL,3,1,2,1,NULL,NULL),(2646,605489949001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AKT002',7.9,'hermeshine','hugojesussanchez','hugo_jesus2000@yahoo.com.mx','Hugo Jesus','Av. Norte # 100 Edificio 17 Departamento 402 Colonia Pantitlan<br>Delegacion Iztacalco','Mexico','Distrito Federal','MEXICO','08100','01525557006691','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-08 23:39:24',0,NULL,3,1,2,1,NULL,'sonyçƒ­é´è½¬æ¢å™¨  1 '),(2647,701382462015,250599924001,'New Circular Polarizing C-PL CPL Filters for Cokin P ',1,'',10.99,'hutongstore','pike990_1','miles51@btinternet.com','miles ferrari','14 Quebec Close Cringleford','Norwich','Norfolk','UNITED KINGDOM','NR4 6XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 01:59:05',0,NULL,8,1,17,0,NULL,NULL),(2648,701381913015,250692237994,'New 55mm 55 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','pike990_1','miles51@btinternet.com','miles ferrari','14 Quebec Close Cringleford','Norwich','Norfolk','UNITED KINGDOM','NR4 6XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 01:59:06',0,NULL,3,1,2,1,NULL,'55mm çŽ¯æž¶   1\rcpl    1 '),(2649,644499824002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','tribemark','josephamey@gmail.com','Joe Amey','223 Royal Arms Way','Glen Burnie','MD','UNITED STATES','21061-6249','(410) 977-7132','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-09 03:24:14',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  1 \rRR723015047CN'),(2650,605559273001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','myrvan_21','djmyrvan_21@hotmail.com','Ivan Urzua','5334 S Laramie Ave','Chicago','IL','UNITED STATES','60638-3044','(773) 251-6010','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 03:46:11',0,NULL,3,1,1,1,NULL,' '),(2651,687862192016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','jwiebe44','jeffwiebe@yahoo.ca','Jeff Wiebe','44 Limetree Cove','Winnipeg','MB','CANADA','R2J 4B4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 04:36:25',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2652,644522710002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','sipooh68','linda.mongrain@hotmail.com','Linda Mongrain','9150 de Lunenburg','QuÃ©bec','QC','CANADA','G2B 5R8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 04:43:44',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(2653,605572926001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','brendad1977','brendper@gmail.com','Brenda Dahlseide','Rural Route 3','Barrhead','AB','CANADA','T7N 1N4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 05:14:41',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†nikon   1 '),(2654,701495961015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','maris0007','kosnel@wp.pl','MARIUSZ KOS','56 HAZEL GROVE','WREXHAM','Wrexham','UNITED KINGDOM','LL12 7HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 08:25:00',0,NULL,3,1,2,1,NULL,NULL),(2655,687912624016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','nenad5044','nenad@helpers.hu','Nenad Ignjatovic','Helpers Hungary Kft. RÃ¡day u. 8 I/5  (buzzer/csengÅ‘: 20)','Budapest','Hungary','HUNGARY','1092','+36705926994','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 08:32:00',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2656,644583313002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','juanjose5593','pernildeldols@hotmail.com','juan jose escortell ibaÃ±ez','marina alta 186, 2Âº piso puerta 4','gata de gorgos (Alicante)','Comunidad Valenciana','SPAIN','03740','653935203','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 09:55:11',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1 '),(2657,644595928002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','linusmic','ebay@magnic.com','Linus Mickelsson','Bymossavagen 1a5','Helsingfors','FI','FINLAND','00320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 10:45:04',0,NULL,8,1,17,0,NULL,' '),(2658,644569322002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','guderian233vladimir','guderian233@gmail.com','Vladimir MandiÄ‡','Vilima Korajca 2','PoÅ¾ega','','CROATIA','34000','0038534622389','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 10:47:35',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž   1 \rRR723015943CN\r'),(2659,605646292001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','linusmic','ebay@magnic.com','Linus Mickelsson','Bymossavagen 1a5','Helsingfors','FI','FINLAND','00320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 10:58:01',0,NULL,3,1,4,1,NULL,'3m æ¨ªæ†   1\råå…‰æ¿æ”¯æž¶   1 \rYW863884230CN\r\r'),(2660,605602688001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','ellenandedgar','ellerrn@msn.com','Ellen Arkinstall','34 Longboard Circuit','Kingscliff','New South Wales','AUSTRALIA','2487','0266742402','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 11:06:08',0,NULL,3,1,6,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\råŒç¯å¤´  2  æ¾³æ ‡  \råå…‰ä¼ž   2\r45w   4\råŒ…    1\ræ–°åŠ å¡EMS\r EX000334675SG'),(2661,605649755001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','thargjunior','algood@iinet.net.au','A L Goodland','P O Box 117<br>North Perth','Perth','Western Australia','AUSTRALIA','6906','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 11:13:13',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿   2\rRR723015869CN\r'),(2663,644604850002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','evalara','eva.lcc@gmail.com','EVA MILLAN VALLDEPERAS','ETSI INFORMATICA, BOULEVARD LOUIS PASTEUR 35. CAMPUS DE TEATINOS','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29002','625585032','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:20:05',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863884731CN\r'),(2664,687968595016,260661685518,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'',9.2,'hutongstore','kukomakijuha','juhakari@nic.fi','Juha Kari','Vuorikatu 30 b','Uusikaupunki','Oletus','FINLAND','23500','0443332912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 11:43:08',0,NULL,3,1,2,1,NULL,'canon å¯¹ç„¦çŽ¯   1 '),(2665,644611983002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','jdolan16','jamesrdolan_1992@yahoo.co.uk','James Dolan','11 St Annes Terrace','Bradford, Shipley','West Yorkshire','UNITED KINGDOM','BD176PR','01274597358','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:44:55',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2666,644613895002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','t_baunkjaer','t_baunkjaer@hotmail.com','Thomas BaunkjÃ¦r','MatthÃ¦usgade 48c, 4., 418','Copenhagen V','Denmark','DENMARK','1666','51262819','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 11:52:02',0,NULL,3,1,2,1,NULL,NULL),(2667,644613991002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michaelesh8u43','michaelesh@comcast.net','Michael Esh','631 Springville Rd','New Holland','PA','UNITED STATES','17557-9561','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 11:52:42',0,NULL,3,1,1,1,NULL,NULL),(2668,605664441001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',3,'AA1311',12.57,'hermeshine','pinto.35','sales@vault35.com','Pontus Perhamn','Adelgatan 3','Nybro','Sweden','SWEDEN','382 32','0738437559','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 12:04:49',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ    3 '),(2670,701571581015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','ashallen1','ashallen@gmx.com','Ash Allen','746 Fishponds Road Fishponds','Bristol','Avon','UNITED KINGDOM','bs163ua','07545216767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-09 12:28:38',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon    1 '),(2671,644236103002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 13:13:08',0,NULL,8,1,17,0,NULL,NULL),(2672,644669712002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 14:46:27',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§   2\ræŸ”å…‰ä¼ž    2 \rlight stand  $22\rYW863884241CN\r'),(2673,605729066001,110533631413,'CTR-301P Flash Trigger Kit with 2 Receivers ctr301p',1,'AKT001',41.9,'hermeshine','dsch1085','dschank9200@att.net','Donna Schank','653 Silver Fox Ct','Indianapolis','IN','UNITED STATES','46217','(317) 362-9200','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-09 15:27:21',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ   1 '),(2674,701639713015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','xsnicholas','xsnicholas@hotmail.com','Nicholas J K Ang','Blk 107,Tampines St 11, #05-355','Singapore','Singapore','SINGAPORE','521107','+65 93898481','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 15:29:16',0,NULL,8,1,17,0,NULL,NULL),(2675,701638676015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','xsnicholas','xsnicholas@hotmail.com','Nicholas J K Ang','Blk 107,Tampines St 11, #05-355','Singapore','Singapore','SINGAPORE','521107','+65 93898481','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 15:29:17',0,NULL,3,1,11,1,NULL,'77mm é•œå¤´ç›–  canon  1\r67mm é•œå¤´ç›–   canon   1 '),(2677,644693456002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','motonany','pasha70@comcast.net','Shaul Anbinder','317 Timber Hill rd','Buffalo Grove','IL','UNITED STATES','60089','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 15:50:07',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(2678,644484923002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','oncatca','oncatca@hotmail.com','NAMJONG LEE','2911 BAYVIEW AVE. 117E','NORTH YORK','ON','CANADA','M2K 1E8','(416) 886-8860','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 16:38:25',0,NULL,3,1,3,1,NULL,'717æ‰‹æŸ„   1 \rRR723015957CN\r'),(2679,644724501002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','xb0129','xb0129@gmail.com','XU BIN','PTE.150 No.842<br>COL.INDUSTRIAL VALLEJO','AZCAPOTZALCO','Distrito Federal','MEXICO','02300','0052-5557377208','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 17:00:53',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2680,605784665001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','hiflyer2007','ebay2007@prointernet.ca','Jim Whitesell','c/o McBain Camera<br>1982 - 8882 170 ST','Edmonton','AB','CANADA','T8N 5E9','(780) 690-5615','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 17:42:37',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2681,701714407015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',41,'hutongstore','suprat_7m','jcause@live.com','James Cause','Unit  2 / 5  Flinders Street','Taree','New South Wales','AUSTRALIA','2430','0265538332','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 17:47:23',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…   +58mm çŽ¯æž¶   1 \rRR723015529CN'),(2682,644753373002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','compilog','iromeo77@ya.ru','Roman Ivlev','Kronverskiy pr., d.59, kv.30','Saint-Petersburg','','RUSSIAN FEDERATION','197198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 18:11:06',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2683,605807949001,110566020134,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:31:17',0,NULL,8,1,17,0,NULL,NULL),(2684,644770252002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:34:38',0,NULL,3,1,1,1,NULL,'72mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶    1 '),(2685,605813570001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','bmeeler','bmeeler@gmail.com','Brock Meeler','339 Rhine Avenue','Wynne','AR','UNITED STATES','72396','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 18:51:00',0,NULL,3,1,1,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2686,688211051016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'',54.5,'hutongstore','cfb700','cuentadecarlos@yahoo.es','Carlos Fernandez','Fernando el Catolico, 55-4Âº izda','Zaragoza','Zaragoza','SPAIN','50006','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-09 19:56:11',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW863884263CN\r'),(2687,644854649002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','iamtorpe','manuelhigueras@gmail.com','manuel higueras garcia','reina sofia, 10','los villares, jaen','AndalucÃ­a Ceuta y Melilla','SPAIN','23160','953323199','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 21:01:50',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863884274CN\r'),(2688,701865712015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','ibisabelle','isa.vgl@gmail.com','bertrand maquin','5 rue trieu maquette','sirault','','BELGIUM','7332','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-09 21:29:42',0,NULL,3,1,2,1,NULL,NULL),(2689,603083511001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',35.2,'hermeshine','ursadoc','galb1@bellsouth.net','paulette L. Foster-galbraith','4806 Jefferson Ave','Gulfport','MS','UNITED STATES','39507','(228) 831-1988','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 22:06:51',0,NULL,3,1,1,1,NULL,'52mm é•œå¤´ç›–   nikon   10\rlenspen    2 '),(2690,605931125001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','mkkknana','bay_666@hotmail.com','Helena Maria GonÃ§alves','Av Angelo Rivelli 820<br>Jardim da Fonte','Jundiai','SÃ£o Paulo','BRAZIL','13216300','45873121','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 22:23:32',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2691,644907584002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','gromov.a','post.gromov@gmail.com','Alexey Gromov','Kolomenskaya naberezhnaya, dom 6, kv 938','Moscow','','RUSSIAN FEDERATION','115142','(495)9435600','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 22:54:18',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ N1   1 '),(2692,644911191002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','zinabra','mls_so@hotmail.com','Milles GonÃ§alves','Rua AmbirÃ© Cavalcanti 496<br>Rio Comprido','Rio De Janeiro','Rio de janeiro','BRAZIL','20250-490','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-09 23:11:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR723015930CN\r'),(2693,605953490001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','cmilitao','celsomilito@yahoo.com.br','Celso MilitÃ£o dos Santos','Rua PanamÃ¡, 59<br>Vila Brasil','Londrina','ParanÃ¡','BRAZIL','86010300','43 3321-5495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:25:30',0,NULL,3,1,2,1,NULL,NULL),(2694,644920563002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','photofan66','photofan66@hotmail.com','Blane Becker','302 E Oak St','Algona','IA','UNITED STATES','50511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-09 23:29:55',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2695,644922467002,120560203167,'77mm Lens lenscap for Canon Combined shipping discounts',2,'AA1304',5,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:40:25',0,NULL,8,1,17,0,NULL,NULL),(2696,605957420001,110523102217,'67mm Lens lenscap for Canon Combined shipping discounts',1,'AA1302',2.6,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-09 23:40:27',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  canon   2\r67mm é•œå¤´ç›–  canon   1 '),(2697,605415531001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','momx3black','jdtrblack4@aol.com','Jami Black','21032 Al Highway 10','Thomasville','AL','UNITED STATES','36784-3948','(334) 992-5979','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 00:07:36',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(2698,605967783001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','gerty-dreamer','h_ohtsu@ma.net3-tv.net','Kouhei Ohtsu','513, Kami-Umesawa','Namerikawa-shi','Toyama','JAPAN','936-0853','(090)8094-1071','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 00:11:57',0,NULL,3,1,2,1,NULL,NULL),(2699,642889662002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sanlah','sandra.lahna@hotmail.com','Sandra Lahnalampi','Gustaf bergs vÃ¤g 17A','TÃ¤by','SD','SWEDEN','18370','+46738064469','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:07:21',0,NULL,3,1,2,1,NULL,NULL),(2700,605988476001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1303',6.68,'hermeshine','neilljm','neill.mathieson@telus.net','Neill Mathieson','16 Abbercove Rd. S.E.','Calgary','AB','CANADA','T2A6Z2','(403) 248-4328','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:36:16',0,NULL,3,1,2,1,NULL,NULL),(2701,605987763001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','littlemattkid','zoltansship@hotmail.com','matthew clinesmith','PSC 251 Box 337','APO','AP','AA','96542','6716852177','NoPaymentFailure','CheckoutComplete','Other','2010-12-10 01:40:56',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   2\råŒ…    1 \rEX000334689SG\rlighting kit   $25'),(2702,605587613001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','andromedasweetie','basicblack25@gmail.com','Piper Black','970 Milner Avenue','Victoria','BC','CANADA','V8X 3N4','(250) 248-2477','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 01:48:14',0,NULL,3,1,2,1,NULL,NULL),(2703,605603262001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',9.8,'hermeshine','gliderpilot2002','bdandress@aol.com','Brent Andress','26341 Alcott Union Dr.','Murrieta','CA','UNITED STATES','92563','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 01:55:02',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   1 \r67mm é•œå¤´ç›–  canon   1 \r72mm é•œå¤´ç›–  canon   1 \r77mm é•œå¤´ç›–  canon   1 '),(2704,605993121001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','brenda.hammel','bhammel@shaw.ca','Brenda Hammel','96 Sunrise Rd SW','Medicine Hat ','AB','CANADA','T1B 4S2','(403) 526-8830','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 01:56:23',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR723015926CN\r'),(2705,605867155001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','gmen87','mgm6704@hotmail.com','Mike McCormick','114 S Manchester St','West Union','OH','UNITED STATES','45693-1221','(937) 544-9722','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 02:05:26',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…   æ— å­—   1 '),(2706,644980567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bburton88','bburton@berklee.net','brian burton','404 Potts St','Davidson','NC','UNITED STATES','28036','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 02:50:34',0,NULL,3,1,1,1,NULL,NULL),(2707,606029501001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','iaorana7577','note4ken@skyviewmail.com','Ken Summerhays','715 W Mariposa Dr','Washington','UT','UNITED STATES','84780-2198','(435) 652-1950','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 04:08:13',0,NULL,3,1,1,1,NULL,NULL),(2708,645004986002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','chadstoolbox-knipextools','email@chadstoolbox.com','ChadsToolbox.com Inc','PO BOX 876084','Wasilla','AK','UNITED STATES','99687','(877) 456-4739','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 04:25:52',0,NULL,3,1,1,1,NULL,NULL),(2709,606039577001,110533631166,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','irandut','hammer_fll@yahoo.com','nana haroen','1075 E Stuart Dr','galax','VA','UNITED STATES','24333-2638','(336) 244-4449','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 05:00:18',0,NULL,3,1,1,1,NULL,NULL),(2710,645020777002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 05:47:06',0,NULL,3,1,11,1,NULL,NULL),(2711,644604553002,120560203032,'58mm Lens lenscap for Canon Combined shipping discounts',1,'AA1301',23.59,'hermeshine','mohdfaxyl','faxyl@me.com','Mohamed Fazeel','M.Light view<br>Blookiya Magu','Male','','MALDIVES','20340','009607977978','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 05:59:19',0,NULL,3,1,3,1,NULL,'canon å•è‚©åŒ…   1\r58mm é•œå¤´ç›– canon    1 \rRR723015719CN\r'),(2712,645027713002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 06:28:02',0,NULL,8,1,17,1,NULL,NULL),(2713,645027437002,120560203127,'72mm Lens lenscap for Canon Combined shipping discounts',2,'AA1303',5,'hermeshine','chalyk','chaly_k@hotmail.com','chaly khoeun','19903 13th ave s','seatac','WA','UNITED STATES','98148','(206) 422-4701','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 06:28:03',0,NULL,3,1,1,1,NULL,'72mm canon é•œå¤´ç›–  2\r67mm canon é•œå¤´ç›–  2\r '),(2714,645030799002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sdibao10','sdibao@gmail.com','Serge  Dibao','15000 W Airport Blvd<br>Apt 1822','sugar land','TX','UNITED STATES','77498-7278','','NoPaymentFailure','CheckoutComplete','Other','2010-12-10 06:45:28',0,NULL,3,1,3,1,NULL,'RR723015722CN'),(2715,606067747001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','shahlesnoit101','shahlesnoit@hotmail.com','Selamat Shahridzuan','Blk 827 Woodlands Street 81 #02-90','Singapore','','SINGAPORE','730827','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 07:47:10',0,NULL,8,1,17,0,NULL,' '),(2716,606067746001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','shahlesnoit101','shahlesnoit@hotmail.com','Selamat Shahridzuan','Blk 827 Woodlands Street 81 #02-90','Singapore','','SINGAPORE','730827','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 07:47:11',0,NULL,3,1,11,1,NULL,'52mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©    1 '),(2717,688476389016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','artwizdean','dean@artwiz.co.uk','Dean Williams','11 Somerset Drive, Glenfield','Leicester','Leicestershire','UNITED KINGDOM','LE3 8QW','01162912374','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-10 08:06:55',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\r50-70 æ£š  è‹±æ ‡   2\r115w 220v   2\råŒ…   1\r lighting kit  $32 \rYW863884285CN\r'),(2718,605674596001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',108.9,'hermeshine','jeve398','jeve398@hotmail.com','Joris Vermeylen','Leuvensesteenweg 398','Kortenberg','Vlaams-Brabant','BELGIUM','3070','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 08:55:28',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£šé€šç”¨å¡å£   2\rlight stand  $22\rYW863884322CN'),(2719,645061727002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','toma_graphics','marco@archeologiasperimentale.it','Marco Tomaselli','via L. D\'Aragona 266','pistoia','PT','ITALY','51100','0573-545284','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 09:23:37',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2\r45w  8\råŒ…    1 \rlighting kit    $28\rYW863884300CN\r'),(2721,606105063001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','yasamehmet','mehmetyasa@yahoo.com','MEHMET YASA','G. M. K. BULVARI NO: 128/C<br>TANDOGAN','ANKARA','TURKEY','TURKEY','06470','905333548487','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 10:35:37',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   æ¬§æ ‡   1 '),(2722,645088941002,120564178566,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11.54,'hermeshine','612150','oln07@mail.ru','Oleg Nikitenkov','Ð Ñ‹Ð»ÐµÐ½ÐºÐ¾Ð²Ð° 42-15','Ð¡Ð¼Ð¾Ð»ÐµÐ½ÑÐº','Smolensk','RUSSIAN FEDERATION','214036','+79190494900','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 11:09:49',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(2723,702145853015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','blacknegr57','negr.black@gmail.com','Martin Cerny','Daskova 3081','Praha','','CZECH REPUBLIC','143 00','+420604911140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 12:00:16',0,NULL,8,1,17,0,NULL,NULL),(2724,702145851015,250599364553,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.1,'hutongstore','blacknegr57','negr.black@gmail.com','Martin Cerny','Daskova 3081','Praha','','CZECH REPUBLIC','143 00','+420604911140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 12:00:15',0,NULL,3,1,2,1,NULL,'RS-S1   1\r55mm uv   1 '),(2726,645117936002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','bet2100','bet@mainpage.ddo.jp','Kengo Mohri','2192-3<br>Yachikusa','Fukusaki-Cho Kanzaki-Gun','Hyogo','JAPAN','679-2202','081-790-22-6302','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 12:51:14',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1åå…‰ä¼ž   1å•ç¯å¤´RR723015395CN'),(2727,702166701015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','mpen5877','mauricepenn@ntlworld.com','Maurice Penn','70 Moran Road','Newcastle under Lyme','Staffordshire','UNITED KINGDOM','ST5 6EX','01782253051','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-10 12:58:39',0,NULL,3,1,2,1,NULL,NULL),(2728,645129661002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','paulogris','paulo.gris@gmail.com','Harita Chotalal','Rua Nossa Sra da Nazare nÂº16 1Âº Esq','Loures','Lisboa','PORTUGAL','2660-316','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 13:31:17',0,NULL,3,1,3,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ   1 \rRR815345035CN\r'),(2729,606156095001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','hadar123','orhadar@gmail.com','or Hadar','1 Gibstain st','Rishon le Zion','','ISRAEL','75313','0578170438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 13:35:23',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³çŽ¯   1 '),(2731,645157933002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','saaliya2010','saaliya.thilakarathna@gmail.com','Saaliya Thilakarathna','No.34,DeLaSalleStreet,<br>Modara,','Colombo','Western','SRI LANKA','15','+94777413739','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 14:51:50',0,NULL,3,1,3,1,NULL,'åå…‰æ¿ RR723015400CN'),(2732,645160342002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','stl.sportsman','mktrrnc@hotmail.com','mike torrence','14477 Eddington Dr','chesterfield','MO','UNITED STATES','63017-2541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 14:55:14',0,NULL,3,1,1,1,NULL,'nikon 90th è‚©å¸¦   1 '),(2733,606200506001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','iuly_yo','pandy.iuly@yahoo.com','Iulian Pandele','Str. Dragos Mladinovici nr. 2-4 Bloc R11 apartament 46 sector 4<br>Post office nr. 82','Bucharest','RO','ROMANIA','041783','+4 0727899848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 15:40:36',0,NULL,8,1,17,0,NULL,NULL),(2734,606197263001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','iuly_yo','pandy.iuly@yahoo.com','Iulian Pandele','Str. Dragos Mladinovici nr. 2-4 Bloc R11 apartament 46 sector 4<br>Post office nr. 82','Bucharest','RO','ROMANIA','041783','+4 0727899848','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 15:40:37',0,NULL,3,1,2,1,NULL,'52-52 åŒé˜³çŽ¯   1\r52-58 åŒé˜³çŽ¯   1 '),(2735,702264914015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','primozkrze2009','primoz.krze@szdl.si','PrimoÅ¾ KrÅ¾e','horjulska 225','Dobrova','','SLOVENIA','1356','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-10 16:36:08',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½  é»‘ ï¼‰   1 \rCP212331075CN\r'),(2736,606232662001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',2.6,'hermeshine','burs','bursey3@cogeco.ca','paul e. bursey','2153 sunnyvale Dr','Oakville','ON','CANADA','l6l1w6','(905) 847-9573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 16:55:23',0,NULL,3,1,2,1,NULL,'è‚¥çš‚ç›’æŸ”å…‰ç½©   430ex   1 '),(2737,606240260001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','grosfaters','serpovs@mail.ru','Serpov Sergey','Shagabudinova 116/120, 2','Almaty','Almaty','KAZAKHSTAN','050012','+77772494350','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 17:12:33',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³çŽ¯   1 '),(2738,645227533002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','guanavi','jllahumada@hotmail.com','Jose Luis Lopez de Ahumada','Lira,5 G','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41003','618052614','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 17:35:54',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW863884366CN\r'),(2739,606252644001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','alonluft','imwaiting23@gmail.com','alon luft','yanush korchak 31','hertzliya','hertzliya','ISRAEL','46309','+972 546743447','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 17:51:50',0,NULL,3,1,11,1,NULL,NULL),(2740,645240648002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','jontrotta1022','jontrotta1022@yahoo.com','jonathan trotta','140 picturesque dr','rochester','NY','UNITED STATES','14616','(585) 278-4040','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 17:59:47',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2741,645251407002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','dusanvlajic','dusanvlajic@hotmail.com','Dusan Vlajic','250 Christie St. Apt. #2','Toronto','ON','CANADA','M6G 3B8','(647) 827-9767','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 18:20:22',0,NULL,3,1,5,1,NULL,'6662a  1 \rCP212331067CN\r'),(2742,645257702002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','victav33','victav33@verizon.net','Victor Taveras','6 Merrick CT','Middletown','NJ','UNITED STATES','07748-1209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 18:32:02',0,NULL,3,1,1,1,NULL,NULL),(2743,702329862015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','foralgebra','info@rexware.fr','Mickael Nicotera','95 rue Jean Zay','St Jean de Braye','Centre','FRANCE','45800','0238215985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 18:34:21',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(2744,606285886001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','relbix','wildworld@bk.ru','Vladimir Nikulkin','Shcherbakovskaya Str., 57/20, 194','Moscow','','RUSSIAN FEDERATION','105187','(919) 100-4190','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 18:46:22',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR723015342CN'),(2745,702337637015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','kazyy','katja.kaipainen@kotiposti.net','Katja Kaipainen','KÃ¤rrykuja 2-4 as 23','Imatra','Oletus','FINLAND','55100','0505414111','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 18:47:48',0,NULL,3,1,2,1,NULL,NULL),(2746,606301182001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','helenio1','britzka@gmail.com','HELENIO GRECH','\'ACUSHLA\'<br>CAPUCCHINS STREET','KALKARA','','MALTA','KKR 1033','(356) 9946 6363','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 19:14:59',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å›› ç¯å¤´  2 \rRR815345027CN\r474'),(2747,702381937015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'',7.5,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-10 19:53:17',0,NULL,8,1,17,0,NULL,NULL),(2748,702380106015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-10 19:53:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆç™½ï¼‰   1\r2mç¯æž¶  2\råŒç¯å¤´ æ¬§æ ‡   2\råå…‰ä¼ž  2\ræŸ”å…‰ä¼ž  1\r115w 220v   4\r åŒ…   1\rlighting kit  $29 YW863884355CN\r\r'),(2749,645022412002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.89,'hermeshine','chev3936','silverado3936@att.net','Kevin Brock','3936 Griffith Rd','Pace','FL','UNITED STATES','32571-9357','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-10 20:25:28',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   1 '),(2750,606339829001,110531023204,'JJC Leather Hand Strap Grip comfort stable D700 5DII',1,'AB3402',14.99,'hermeshine','sniper_stan','mepsy@yandex.ru','Ð¡Ñ‚Ð°Ð½Ð¸ÑÐ»Ð°Ð² Ð“ÑƒÐ´Ð·Ð¾Ð²ÑÐºÐ¸Ð¹','Ð¿Ñ€. Ðš.ÐœÐ°Ñ€ÐºÑÐ°, 268, 17','Ð¡Ð°Ð¼Ð°Ñ€Ð°','Ð¡Ð°Ð¼Ð°Ñ€ÑÐºÐ°Ñ','RUSSIAN FEDERATION','443081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 20:32:54',0,NULL,3,1,2,1,NULL,'jjc-2  è…•å¸¦   1 '),(2751,688807374016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','ickle_pigeon_1337','russie_the_stokie@hotmail.co.uk','Rebecca Ruscoe','Halfway House Slindon','Eccleshall','Staffordshire','UNITED KINGDOM','ST216QP','01782791350','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-10 20:48:29',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2752,606364064001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tanqueton','ramnoel66@yahoo.com','jose ramon fernandez gonzalez','avenida benidorm 34-4 d','arnedo','La Rioja','SPAIN','26580','600322941','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 21:23:18',0,NULL,3,1,2,1,NULL,NULL),(2753,606373319001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-10 21:44:41',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xxl    1 RR723015325CN'),(2754,606410994001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','hemant_07047','hemant_07047@yahoo.com','Hemant Shah','1225 81st Street','North Bergen','NJ','UNITED STATES','07047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-10 23:27:26',0,NULL,3,1,1,1,NULL,'72mm æ©¡èƒ¶ç½©   1 '),(2755,606413215001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','jh-project','honzikhanak@seznam.cz','Jan HanÃ¡k','Bohunova 10','Brno','','CZECH REPUBLIC','62500','+4207244444157','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-10 23:33:58',0,NULL,3,1,2,1,NULL,'nikon 52mm åæŽ¥çŽ¯   1 '),(2756,606428384001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','wookie_with_a_beer','otoolepiece@yahoo.com','Jason Beck','12300 Apache Ave<br>Apt 1609','Savannah','GA','UNITED STATES','31419-2337','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 00:29:39',0,NULL,3,1,1,1,NULL,NULL),(2757,645441787002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','kccims','sgingras@tbs.toshiba.ca','Serge Gingras','23 du Cantonnier','Levis','QC','CANADA','g6v8m3','(418) 837-9399','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 02:05:19',0,NULL,3,1,2,1,NULL,NULL),(2758,688938338016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','nboey','noelboey@yahoo.com.sg','Noel Boey','Blk 441A Fernvale Road #03-307 S(791441)','default','','SINGAPORE','791441','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 02:10:59',0,NULL,3,1,11,1,NULL,NULL),(2759,606169111001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',104.6,'hermeshine','bandphotographer','vincenzo_pistritto@msn.com','Vincenzo Pistritto Photography','C21 939 Western rd<br>BUZZER CODE 021','London','ON','CANADA','N1G1g3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 03:15:39',0,NULL,3,1,5,1,NULL,'æ–œè‡‚  2\råå…‰æ¿æ”¯æž¶   1\rå¤§åŠ›å¤¹   2 \rCP212331053CN\r'),(2760,606467612001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','ml3330577','boo1.1ood@hotmail.com','zihao Li','425 S Los Angeles St<br>Ste D','Los Angeles','CA','UNITED STATES','90013-1434','(909) 827-5220','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 03:21:40',0,NULL,3,1,1,1,NULL,NULL),(2761,645461652002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','cheetah2005','lanz_cbr@yahoo.com.sg','Nor Zailan Jalaludin','Panglima Power Sdn Bhd<br>Teluk Gong Power Station','Kuala Sungai Baru','Melaka','MALAYSIA','78200','0126160085','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 03:25:13',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©    1 \rRR815345013CN\r'),(2762,606472629001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','bogolisk','dang.linh@gmail.com','Linh Dang','39 Rodeo Drive','Ottawa','ON','CANADA','K2J4Z5','(613) 825-8716','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 03:44:49',0,NULL,3,1,2,1,NULL,' '),(2763,606481263001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','nickf6549','awesomenick@gmail.com','nick fish','6549 Longmeadow Cir','west jordan','UT','UNITED STATES','84084-5801','(801) 635-3982','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-11 04:26:59',0,NULL,3,1,1,1,NULL,'ctr301p  ä¸€æ‹–ä¸‰   1 '),(2764,606495454001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','elenka-elenka','work-adress@mail.ru','Elena Fokina','ul.Svyazistov d.5 kv.233','Novosibirsk','Novosibirskaya oblast','RUSSIAN FEDERATION','630120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 05:54:17',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2765,645494763002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','abdullahjun09','abdullahjun@yahoo.com','Abdullah Jun Palma','Security Forces Hospital, Sitteen Street<br>PO Box 3643','Riyadh','','SAUDI ARABIA','11481','0567568050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 06:18:17',0,NULL,3,1,3,1,NULL,'RR723015311CN '),(2766,606512683001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','perrier79','vformuzal@yahoo.com','Vyacheslav Formuzal','10559 Birch Ranch Dr','Sacramento','CA','UNITED STATES','95830','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 07:44:15',0,NULL,3,1,1,1,NULL,NULL),(2767,645510227002,120581410894,'16chan Wireless Remote Control Cord for Canon RS-80N3',1,'AA3204',18.5,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:46',0,NULL,8,1,17,0,NULL,NULL),(2768,606513584001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:46',0,NULL,8,1,17,0,NULL,NULL),(2769,606514034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:47',0,NULL,8,1,17,0,NULL,NULL),(2770,606513324001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:47',0,NULL,8,1,17,0,NULL,' '),(2771,645509495002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','jeb5','jandmbaumann@bigpond.com','John Baumann','8 Visser Court','Rochedale','Queensland','AUSTRALIA','4123','0733411072','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 07:57:48',0,NULL,3,1,3,1,NULL,'77mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   2\rå“èƒœ 3.0 è†œ   1\rçƒ­é´ç›–   1\rçˆµå½±æ— çº¿  C3   1RR723015373CN\r '),(2772,606520150001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','nosnetto','nosnetto@hotmail.com','Nathan Ottenson','15 Marquis cr.','Regina','SK','CANADA','s4s6j8','(306) 584-3179','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 08:24:09',0,NULL,3,1,3,1,NULL,'800w 110v   5 \rRR815345662CN\r'),(2773,645521028002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','bouvierlab','kdobi@shaw.ca','Kim Dobischok','21379 126th ave','Maple Ridge','BC','CANADA','V4R 2K1','(604) 466-9936','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 08:53:29',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  1 RR723015339CN'),(2774,606540759001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','turquoise-web','turquoise.web@gmail.com','GURSOY HAFIZOGLU','HURRIYET MAH. 276 SOK. NO:7/3<br>GAZIOSMANPASA','ISTANBUL','IST','TURKEY','34240','(212) 537 6390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 09:55:38',0,NULL,3,1,2,1,NULL,' '),(2775,645545988002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','theartharindra','harindranishshanka@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 10:21:53',0,NULL,3,1,2,1,NULL,NULL),(2776,645547323002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','toanvle','toantech@gmail.com','Toan Le','3117 SE 136th Ave','Portland','OR','UNITED STATES','97236-2813','(503) 593-0307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 10:27:33',0,NULL,3,1,1,1,NULL,NULL),(2777,702683825015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'',3.82,'hutongstore','noz_90','traffic_@live.co.uk','Nolan Galea','23, Triq il Gammar','Attard','','MALTA','ATD 2640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 10:40:35',0,NULL,3,1,2,1,NULL,NULL),(2778,645555600002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','trilby990','tony-wright@tpg.com.au','Tony Wright','3 / 306 Victoria Avenue','Redcliffe','Queensland','AUSTRALIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 10:54:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1  RR723015268CN'),(2779,645565030002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','gybp','gybp@yahoo.com','Glennford B Perez','Avda Boulevard Edificio Primavera portal 7 apt 3-A Benalmadena<br>Benalmadena','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29631','617588950','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-11 11:24:51',0,NULL,8,1,17,0,NULL,''),(2780,645582177002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','gybp','gybp@yahoo.com','Glennford B Perez','Avda Boulevard Edificio Primavera portal 7 apt 3-A Benalmadena<br>Benalmadena','Malaga','AndalucÃ­a Ceuta y Melilla','SPAIN','29631','617588950','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 12:18:45',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \r52mm çŽ¯æž¶  1 RR723015356CN'),(2781,606595666001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','miodas07','miodas007@hotmail.com','Mateusz Stawicki','20 Rosemount Drive','Cahir','Tipperary','IRELAND','052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-11 12:49:23',0,NULL,3,1,2,1,NULL,'NG128   1 '),(2782,689156876016,260660056537,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'',2.4,'hutongstore','xyponob75','xyponob@interia.eu','Robert Sroga','8 Pellew Close','Padstow','Cornwall','UNITED KINGDOM','PL28 8EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 14:23:22',0,NULL,3,1,2,1,NULL,NULL),(2783,645632426002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bestrashny','gregorygur@gmail.com','gregory gurevich','nahal tzvi 32/16','migdal haemek','','ISRAEL','23049','972-0544831155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 14:33:19',0,NULL,3,1,2,1,NULL,NULL),(2784,606677049001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','halloo9','auction@macnews.de','Christian Eischer','Ferdinand Fleischmanngasse 4/2','MÃ¶dling','','AUSTRIA','2340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 16:26:55',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—   1 '),(2785,606706275001,110566018983,'Flash Softbox Diffuser for internal flash of D40 D60',1,'AB3304',11.34,'hermeshine','jlastuni','juha.lastuniemi@gmail.com','Juha Lastuniemi','Napaturunkatu 3b12','Turku','','FINLAND','20610','(358) 504835026','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 17:11:04',0,NULL,3,1,2,1,NULL,'NG128   1 '),(2786,606760532001,110566020134,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','mtorraufv','marctorra@hotmail.com','Marc Torra i Ferrer','Ronda Paraires nÂº11 baixos','Olot','CataluÃ±a','SPAIN','17800','699698620','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:51:41',0,NULL,8,1,17,0,NULL,NULL),(2787,645764385002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','mtorraufv','marctorra@hotmail.com','Marc Torra i Ferrer','Ronda Paraires nÂº11 baixos','Olot','CataluÃ±a','SPAIN','17800','699698620','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:53:55',0,NULL,3,1,2,1,NULL,'72mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1 '),(2788,645763806002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','adnankalkan65','adnankalkan@gmail.com','Adnan Kalkan','1. Ana Bakim Merkezi Lojmanlari','Sakarya','','TURKEY','54580','02642765570','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:54:31',0,NULL,8,1,17,0,NULL,NULL),(2789,645763496002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','adnankalkan65','adnankalkan@gmail.com','Adnan Kalkan','1. Ana Bakim Merkezi Lojmanlari','Sakarya','','TURKEY','54580','02642765570','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 18:54:31',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1 '),(2790,645770042002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','cooldudz23aeronpaul','aeronpaulm@yahoo.com','Aeron Paul Mendoza, Estimating Department','P.O.box 991<br>M.S. Al-Suwaidi Industrial Services Co. Ltd.','Jubail Industrial City','Eastern Region','SAUDI ARABIA','31951','033411148','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 19:08:42',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(2791,702993315015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 20:11:08',0,NULL,3,1,2,1,NULL,NULL),(2792,645817419002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','nnik01','niklasnilsen@getmail.no','Niklas Nilsen','Olaf Bulls vei 3a','Oslo','','NORWAY','0765','+4799282427','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 20:26:54',0,NULL,3,1,2,1,NULL,NULL),(2793,645822763002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 20:38:05',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´ æ¬§æ ‡   1 '),(2794,703029603015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','choang2603','choang263@gmail.com','Duc Hoang','47 Casby House','Dickens Estate','London','UNITED KINGDOM','SE16-4SX','02072376252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-11 21:10:22',0,NULL,3,1,2,1,NULL,NULL),(2795,606843200001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3401',2.6,'hermeshine','eladsega','eladsega@gmail.com','elad segal','hirshfeld 12','rishon lezion','','ISRAEL','75244','+972525459977','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 21:26:34',0,NULL,3,1,2,1,NULL,'è‚¥çš‚ç›’æŸ”å…‰ç½©  sb800   1 '),(2796,606859652001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','brandondsp','brandon@dreamsoftproductions.com','Brandon Christensen','2821 Shayla Bay Ave','North Las Vegas','NV','UNITED STATES','89086-1431','(702) 278-9373','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:04:10',0,NULL,3,1,1,1,NULL,'çƒ­é´ç›–   1 \rBrandon Christensen\r1101 E Tropicana Ave # 2202\rLas Vegas, NV 89119\rUSA\r'),(2797,645868375002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','vicenteml25','vicenteml25@hotmail.com','Vicente MuÃ±oz Losada','Doctor Angel Pascual Megias, nÂº4 - 5ÂºA','Alicante','Comunidad Valenciana','SPAIN','03015','607800743','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 22:10:10',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2798,606863123001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 22:14:42',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2799,645728471002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','urtrapbud','jerrym@wellingtonatm.com','Jerry Magnuson','1560 Sandstone Bluffs View St','Mesquite','NV','UNITED STATES','89034','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:14:54',0,NULL,3,1,1,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(2800,645885417002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','frogbro','richfrye@comcast.net','Rich Frye','7637 W Catalpa Ave','Chicago','IL','UNITED STATES','60656','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 22:50:33',0,NULL,3,1,1,1,NULL,NULL),(2801,645890022002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','dlehouillier','davel@vacautomation.com','Dave Lehouillier','21 Gower Rd','Georgetown','ON','CANADA','L7G 1E6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-11 23:04:25',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rCP212331040CN\r'),(2802,645895297002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','blackwidow1128','ecwright_28@yahoo.com','Elaine Wright','3490 Quail Lake Rd<br>Apt 280','Colorado Springs','CO','UNITED STATES','80906','(513) 405-1221','NoPaymentFailure','CheckoutComplete','Other','2010-12-11 23:16:06',0,NULL,8,1,17,0,NULL,''),(2803,645896308002,120571007466,'New Umbrella in Silver 85cm / 33.5\" Photo Studio Light',1,'AD1401',9.9,'hermeshine','blackwidow1128','ecwright_28@yahoo.com','Elaine Wright','3490 Quail Lake Rd<br>Apt 280','Colorado Springs','CO','UNITED STATES','80906','(513) 405-1221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-11 23:18:20',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \råå…‰ä¼ž   1RR723015299CN'),(2804,645927213002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','diamondcutter47','gblasberg@gmail.com','Gary Blasberg','1610 Murphy Pkwy','Eagan','MN','UNITED STATES','55122','(651) 688-9075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 00:54:19',0,NULL,3,1,1,1,NULL,NULL),(2806,646003122002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0024',20.99,'hermeshine','bintang1972','bintang68@hotmail.com','Bin Tang','5842 Aline','Brossard','QC','CANADA','J4Z1R5','(514) 574-0638','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 06:12:19',0,NULL,3,1,3,1,NULL,'æ–°æ¬¾å•è‚©åŒ… D1 canon   1 RR723015387CN'),(2807,606992826001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','epochphoto','bvishneski@msn.com','Robert J Vishneski','107 Glen David Dr','Pittsburgh','PA','UNITED STATES','15238','(412) 656-7001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-12 06:26:43',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹äº‘å°  1 '),(2808,606998896001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 07:06:00',0,NULL,3,1,2,1,NULL,'45w   2 '),(2809,703261166015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'',2.2,'hutongstore','dougacteach','douglas.lunnlunn@btinternet.com','Doug Lunn','34, D\'Eyncourt Lighton Avenue','Kirton','Lincolnshire','UNITED KINGDOM','PE20 1HP','01205725065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 08:42:56',0,NULL,3,1,2,1,NULL,'nikon æœºèº«ç›–/é•œå¤´åŽç›–  1 '),(2810,646064716002,120581161644,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','eqzoo_com','zookeeper@eqzoo.com','Christopher Fowler','2261 Edsel ln','Modesto','CA','UNITED STATES','95358-9524','(209) 622-8214','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'ç¢—ç½© P1   1 eé‚®å®æ”¹ä¸€ä¸ªLK012653203CN'),(2811,606984199001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',2,'AA1311',8.38,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:27:12',0,NULL,8,1,17,0,NULL,NULL),(2812,645994853002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:27:12',0,NULL,3,1,3,1,NULL,'æ°”å¹+ å¸ƒ   2\rå¤§åŠ›å¤¹    2 \rRR723015285CN'),(2813,646082875002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tollarp1-2007','tollar.peter@t-online.hu','Peter Tollar','Berenyi u. 3/b','Budapest','','HUNGARY','H-1016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 10:52:49',0,NULL,3,1,2,1,NULL,' '),(2814,646085828002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','tatiana.nefedova','tatiana.nefyodova@gmail.com','Tatiana Nefedova','Shkolniy bulvar, dom 20, kv 25','Chernogolovka','Moscow district','RUSSIAN FEDERATION','142432','007-9057481744','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 11:00:07',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR723015271CN'),(2815,607072342001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',52.99,'hermeshine','harioe','harioe2002@yahoo.com.au','Hari Oetomo','5 Bordeaux Crescent, Castle Hill','Sydney','New South Wales','AUSTRALIA','2154','0288501729','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2010-12-12 11:06:50',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 RR723015308CN'),(2816,703260440015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','learn-and-master','dan-made@hotmail.co.uk','DANIEL KENNY','2 jamaica street Apartment 51','liverpool','Merseyside','UNITED KINGDOM','L1 0AF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 11:09:52',0,NULL,3,1,2,1,NULL,NULL),(2817,689702379016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','moondustgold','geoffmartin@fsmail.net','Geoffrey Martin','174 Selwyn Street Hillstown,  Bolsover','Chesterfield','Derbyshire','UNITED KINGDOM','S44 6LT','01246824065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 11:17:50',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(2819,606609999001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','ewinwins','ewinwins@hotmail.com','M. Eid','58 Ironbark Drive Templestowe Lower','Melbourne','Victoria','AUSTRALIA','3107','61419001270','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 12:43:44',0,NULL,3,1,6,1,NULL,'\rèƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ ç²‰ï¼‰   1 \r\ræ–°åŠ å¡ems\rEX000237316SG\r'),(2820,646151978002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','tzvili','tsl999@gmail.com','tzvi lin','mevo dotan','mevo dotan ','dn tzfon hashomron','ISRAEL','44890','052-3115948','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 13:18:17',0,NULL,3,1,11,1,NULL,'cåž‹å¤§åŠ›å¤¹  2 '),(2821,646164163002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',5,'AA1302',12.2,'hermeshine','kajanakis','al.petrov@live.se','Alexander Petrov','ValhallavÃ¤gen 57, 2 tr','Stockholm','','SWEDEN','11422','+46762728172','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 13:41:19',0,NULL,8,1,17,0,NULL,' '),(2822,607102146001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',59.83,'hermeshine','ayukov','asv@ayukov.com','Sergey Ayukov','ul. Krzhizhanovskogo, d.5, korp.1, kv.54','Moscow','','RUSSIAN FEDERATION','117292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:06:28',0,NULL,3,1,3,1,' ','2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž  1\rçˆµå½±æ— çº¿  N1   1 \rrs-n1    1\rRR815345747CN\r'),(2823,606935976001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','cjeremynoir','cjeremy1@hotmail.fr','crestey','9 allee leon jouhaux<br>chez breard loic','st sebastien de morsent','Haute-Normandie','FRANCE','27180','0659814559','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:39:22',0,NULL,3,1,2,1,NULL,'55mm çŽ¯æž¶   1 '),(2824,607141373001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','tigerwho6','andreas.sleipnes@gmail.com','Andreas Sleipnes','BjÃ¸rnestien 13 B','Horten','Vestfold','NORWAY','3188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 14:52:04',0,NULL,3,1,2,1,NULL,'canon 52mm åæŽ¥çŽ¯  1 '),(2825,646220812002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 15:19:02',0,NULL,8,1,17,0,NULL,NULL),(2826,607220792001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 15:50:30',0,NULL,8,1,17,0,NULL,NULL),(2827,646247878002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','acuglass','ac.uygongco@gmail.com','Albert Uygongco','Block 2 Lot 8 Ledesco Village, Lapaz','Iloilo City','Iloilo','PHILIPPINES','5000','6333209396','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 16:01:47',0,NULL,3,1,2,1,NULL,'67mm  cpl    1\r67mm uv    1\r67mm é•œå¤´ç›–  canon   1 '),(2828,703561702015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','colinn5393','colinjn@talktalk.net','colin nunn','18 moors way','woodbridge','Suffolk','UNITED KINGDOM','ip124hq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 16:48:19',0,NULL,3,1,2,1,NULL,NULL),(2829,646303555002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spongebobparker','heidi@olypen.com','Heidi Hansen','40 Park Ln','Sequim','WA','UNITED STATES','98382-9505','(360) 683-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 17:07:37',0,NULL,8,1,17,0,NULL,NULL),(2830,646302782002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spongebobparker','heidi@olypen.com','Heidi Hansen','40 Park Ln','Sequim','WA','UNITED STATES','98382-9505','(360) 683-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 17:07:38',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   2 '),(2831,606833342001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','oreskovic1970dino','oreskovic1970@gmail.com','Dino Oreskovic','Pljesivicka 6','Zagreb','Dubrava','CROATIA','10040','00385915183412','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-12 17:14:17',0,NULL,3,1,5,1,NULL,'wt600   1 \rCP212331036CN\r'),(2832,607337437001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','jnoble2k','jnoble2k@yahoo.com','judith noble','3030 N Spaulding Ave','chicago','IL','UNITED STATES','60618-6809','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 18:07:01',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1 '),(2833,646373911002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','hellofrankcom','info@hellofrank.com','Frank Bongers','Maaltebruggestraat 194','Gent','','BELGIUM','9000','0496558558','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 18:19:06',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 RR723015210CN'),(2834,703678508015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','dgs_tomek','td145@vp.pl','Tomasz Dobrzanski','12 castle walk','didcot','Oxfordshire','UNITED KINGDOM','ox117pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 18:30:40',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´   1 '),(2835,606378265001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','totty61','slalves@hotmail.com','Suzanne Alves','61 Tulip Tree Close','Tonbridge','Kent','UNITED KINGDOM','TN9 2SJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 18:48:08',0,NULL,3,1,2,1,NULL,NULL),(2836,607484147001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','patrickvanderhorst','mail@patrickvanderhorst.nl','Patrick van der Horst','Onlandhorst 20','Enschede','','NETHERLANDS','7531 KX','+31-53-4317431','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 20:13:03',0,NULL,3,1,2,1,NULL,NULL),(2837,607504915001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','yetifvr','yetifvr@yahoo.com','Tony Tortolano','1003 E Avenue J3','Lancaster','CA','UNITED STATES','93535-3848','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 20:48:18',0,NULL,3,1,1,1,NULL,NULL),(2838,607525372001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','chrisdanielsnz','chris@chrisdaniels.co.nz','Chris Daniels','76 Clear View Lane<br>RD 5','Rangiora 7475','Canterbury','NEW ZEALAND','7475','+64 22 621 4900','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 20:57:42',0,NULL,3,1,2,1,NULL,'cpl   1 '),(2839,607523001001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','mpjsalazar','mpjsalazar@yahoo.com','Patricia Salazar','10848 Scripps Ranch Blvd<br>Apt 204','San Diego','CA','UNITED STATES','92131-6026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-12 21:00:39',0,NULL,3,1,1,1,NULL,NULL),(2841,703869931015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','yogarosedog','briank8@blueyonder.co.uk','carole keenan','50 northmount rd north park est','liverpool','Merseyside','UNITED KINGDOM','L322AZ','01515480892','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 20:45:34',0,NULL,3,1,2,1,NULL,NULL),(2842,646609996002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','kajanakis','al.petrov@live.se','Alexander Petrov','ValhallavÃ¤gen 57, 2 tr','Stockholm','','SWEDEN','11422','+46762728172','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 22:16:25',0,NULL,3,1,3,1,NULL,' NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap  5RR723015360CN'),(2843,607589340001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','120897','jacobson68@yahoo.com','marti m jacobson','490 Bucheit St','Mount Angel','OR','UNITED STATES','97362','','NoPaymentFailure','CheckoutComplete','Other','2010-12-12 22:36:04',0,NULL,3,1,3,1,NULL,'è‚©æž¶RR723015223CN'),(2844,607608694001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','guiguigd','g.debizet@free.fr','Guillaume DEBIZET','6 avenue de la Gare','BIEVRES','ÃŽle-de-France','FRANCE','91570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-12 23:18:00',0,NULL,3,1,2,1,NULL,'star4 æ˜Ÿå…‰é•œ   1 '),(2845,703953935015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','paranoid73','seventy_three@hotmail.co.uk','Karl Fennell','Mill Cottage Norwich Road','Chedgrave','Norwich','UNITED KINGDOM','NR14 6ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-12 22:20:53',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(2846,607635875001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',10,'AA1309',24.2,'hermeshine','janvaaga','jevaaga@online.no','Jan Erik Vaaga','Strandg. 54','Haugesund','','NORWAY','5528','4795435497','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 00:36:08',0,NULL,3,1,3,1,NULL,' RR723015427CN'),(2847,646711307002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',2,'AB1402',27.8,'hermeshine','netniaga','paklongm@gmail.com','mohd akmal yahaya','No. 11 Jalan 3/18<br>bangi perdana','bandar baru bangi','selangor','MALAYSIA','43650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 02:01:52',0,NULL,3,1,3,1,NULL,'90th è‚©å¸¦  2 RR723015435CN'),(2848,646719649002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ilgas72','tommaz1972@sbcglobal.net','Tomas Mazeika','2389 McBride Ln<br>Apt 40','Santa Rosa','CA','UNITED STATES','95403-2942','(707) 545-8515','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 02:19:15',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR723015444CN'),(2849,646719457002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','hiedz10','hmalig@gmail.com','Hiedie Malig c/o Green Harvest','8 Buntun Highway<br>Luna Extension','Tuguegarao City','Cagayan','PHILIPPINES','3500','0788462804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 02:50:06',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ ï¼‰  1 \rEX000237320SG\r'),(2850,646756994002,120581555566,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','eeow45','eeow007@hotmail.com','ladaphan iamsriurai','970/44  Sukhumvit103 rd.','bangna','BKK','THAILAND','10260','0865563730','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 03:55:22',0,NULL,8,1,17,0,NULL,NULL),(2851,646753202002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','eeow45','eeow007@hotmail.com','ladaphan iamsriurai','970/44  Sukhumvit103 rd.','bangna','BKK','THAILAND','10260','0865563730','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 03:55:22',0,NULL,3,1,2,1,NULL,' '),(2852,646776147002,120601698567,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','primetym22','primetym22@aol.com','Dale Meyer','6668 Drake Dr','Anderson','CA','UNITED STATES','96007','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 05:25:59',0,NULL,3,1,3,1,NULL,'1007wf  1 RR723015458CN'),(2853,607739021001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','highborn_talon','highborntalon@gmail.com','Dave Arsenault','4324 Glencanyon Drive','North Vancouver','BC','CANADA','V7N 4B3','(778) 839-3308','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 05:58:42',0,NULL,3,1,2,1,NULL,NULL),(2854,607738787001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','pa4credit','willpa4credit@gmail.com','Rob Rhodes','203 Harbor Lndg','Braidwood','IL','UNITED STATES','60408-1763','(630) 935-7945','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 05:58:58',0,NULL,3,1,1,1,NULL,NULL),(2855,607742149001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','svmonterrosa','robtslucy@yahoo.com','Sandra Monterrosa','266 W Linden Ave<br>Apt D','Burbank','CA','UNITED STATES','91502','(818) 435-2218','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 06:23:56',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(2857,646805610002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','rawbeansta','robin.ong.87@gmail.com','Robin Ong','Block 533 Woodlands Drive 14<br>#10-581 S(730533)','default','Singapore','SINGAPORE','730533','92255105','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 07:41:54',0,NULL,3,1,11,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2856,704164780015,250692240254,'Remote Control Cord Shutter Nikon D300/D200/D700â€‹ MC-30',1,'',2.98,'hutongstore','lundemann77','mch@datea.dk','Martin Lundemann Christensen','Henrik Nielsens Vej 19','Roskilde','Roskilde','DENMARK','4000','+45 51319182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-13 07:09:37',0,NULL,3,1,2,1,NULL,'RS-N1  1 '),(2858,607763258001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mjigz','minojigz@gmail.com','mino jegalian','1939 N Berendo st','los angeles','CA','UNITED STATES','90027-1801','(323) 717-5513','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 08:20:15',0,NULL,3,1,1,1,NULL,' '),(2859,646842797002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','rk20-2008','javidelope@terra.es','Javier de lope sanchez','C/ Mario Vargas Llosa NÂº34, 4Âº A','AlcalÃ¡ de Henares','Madrid','SPAIN','28806','615053293','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 10:31:06',0,NULL,8,1,17,0,NULL,NULL),(2860,607792028001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','rk20-2008','javidelope@terra.es','Javier de lope sanchez','C/ Mario Vargas Llosa NÂº34, 4Âº A','AlcalÃ¡ de Henares','Madrid','SPAIN','28806','615053293','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 10:31:06',0,NULL,3,1,3,1,NULL,'å°å·ç°å¡   1\r40cm æ£š   1\rRR815345101CN\r '),(2861,601088042001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','leah007leah','007leah@walla.com','LEAH MOSE','ALUFY ZAHAL 2/12<br>HOLON','HOLON','ISRAEL','ISRAEL','58417','0508511678','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 11:55:35',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345225CN\r'),(2862,607821125001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','rmar2238','rosamdej@hotmail.com','Rosa MartÃ­n de Jorge','Rambla de catalunya 6, 5Âª planta','Barcelona','CataluÃ±a','SPAIN','08007','649844788','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 12:12:02',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW863884392CN'),(2864,646886869002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',109.45,'hermeshine','inphernomassacro','giuliano.froio@gmail.com','Giuliano Froio','c/o SKY Italia srl<br>via Salaria 1021','ROMA','Roma','ITALY','00138','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 13:12:08',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   3\rbåº§   3\ræŸ”å…‰ä¼ž   3 \rlight stand $25\rYW863884414CN'),(2865,646122284002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','marcusfilmproducer','marcus.sassi@gmail.com','Marcus Sassi','BlidvÃ¤dersgatan 35A','Gothenburg','','SWEDEN','41830','0722-322-159','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 13:26:53',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder   $20\rYW863884425CN'),(2866,646909361002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','danrhomem','mortenris@hotmail.com','Morten Risberg','GrÃ¸nlandsgutua 1','Elverum','','NORWAY','2408','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 14:11:31',0,NULL,3,1,2,1,NULL,NULL),(2867,607857900001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tonybonekhang1','tonybonekhang@gmail.com','Tony Khang','318 S 8th Ave<br>Apt A','Wausau','WI','UNITED STATES','54401','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 14:20:19',0,NULL,3,1,1,1,NULL,NULL),(2868,646918257002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','aristidetor','aristide.torrelli@telecomitalia.it','Aristide Torrelli','Via Luigi Magrini 19','Roma','RM','ITALY','00146','3357510069','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 14:36:07',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰ç½©   1\rRR815345234CN\r '),(2869,704321592015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',51,'hutongstore','darek.s.241271','darek.s.24@wp.pl','darek sikorski','13sherwood avenue','Boston','Lincolnshire','UNITED KINGDOM','pe21 9lg','01205358136','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-13 15:05:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rbackground support $20\rYW863884436CN'),(2870,607900058001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','2deset','i.gledam@gmail.com','Damir Rister','Rakitje, Novacka cesta 18','Bestovje','','CROATIA','10437','0038598569776','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 16:11:46',0,NULL,3,1,2,1,NULL,NULL),(2871,704370928015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','skilgast','stephaniekilgast@yahoo.fr','Stephanie Kilgast','chez MARION 28 rue des Manouvriers','Savigny-le-Temple','ÃŽle-de-France','FRANCE','77176','0164684893','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-13 16:44:13',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(2872,607914757001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','tomasg1010','tomasg10@yahoo.es','TomÃ¡s Gabriel Carretero Ajo','Las Cruces casa 2<br>AlajerÃ³','Tenerife','Canarias','SPAIN','38812','628782598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 16:47:48',0,NULL,3,1,2,1,NULL,NULL),(2875,646999688002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','trsilva23','trsilva_photo@hotmail.com','TÃ¡ssio Ribeiro Da Silva','Rua Benjamin Constant, 972 - Alecrim','Natal','Rio Grande do Norte','BRAZIL','5904030','8432012330','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 17:47:11',0,NULL,8,1,17,0,NULL,' '),(2876,646999127002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','trsilva23','trsilva_photo@hotmail.com','TÃ¡ssio Ribeiro Da Silva','Rua Benjamin Constant, 972 - Alecrim','Natal','Rio Grande do Norte','BRAZIL','5904030','8432012330','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 17:47:12',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræŸ”å…‰ä¼ž  2\rbåº§     1 \rRR815345251CN\r'),(2877,646219155002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','r-db','rdb@r-db.net','C.PERRIN - R. DEBIAUNE','LE TRELOD<br>15 RUE ARMAND AUBRY','ALBERTVILLE','RhÃ´ne-Alpes','FRANCE','73200','0608092092','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 17:20:32',0,NULL,3,1,3,1,NULL,'canon æ‘„å½±èƒŒå¿ƒxl  1\rRR815345305CN\r'),(2878,600521757001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','v.starshinov','starshinov.vn@gmail.com','Viatcheslav Starshinov','Gidromontazhnikov 9','Kazan','Tatarstan','RUSSIAN FEDERATION','420088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 18:05:13',0,NULL,3,1,2,1,NULL,NULL),(2879,607906156001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','basell3','basell@omnicityusa.com','Beth Sell','9207 W 800 N','Huntington','IN','UNITED STATES','46750','(260) 344-3191','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 18:12:47',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   2\råŒ…   1 \rlighting kit  $25\rYW863884440CN'),(2880,607960459001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',2,'AA2326',21.6,'hermeshine','jtyl6390','capt.john.tyler@gmail.com','John Tyler','465 Rush Green Road','Romford','Essex','UNITED KINGDOM','RM70NH','07719342148','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2010-12-13 18:17:09',0,NULL,3,1,2,1,NULL,'cpl   2 '),(2881,704432440015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','daydreamerswindows123','daydreamerswindows@live.com','Hayley Riordan','14 St michaels ave bishops cleeve','cheltenham','Gloucestershire','UNITED KINGDOM','gl52 8nx','01242671092','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 18:22:49',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… canon   1 '),(2882,646909129002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','icevace1982','icevace@mail.ru','Marsel Valiullin','Zarechnaya ulitsa<br>dom 7, kvartira 132','Moscow','Moscow','RUSSIAN FEDERATION','121087','79031599999','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 18:36:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´ æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR815345248CN\r'),(2883,646974256002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','omi0002','fredjhawkins@yahoo.com','Frederick J Hawkins','347 Overcup Ct','Millersville','MD','UNITED STATES','21108-2410','(410) 987-3063','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 18:31:50',0,NULL,3,1,1,1,NULL,NULL),(2884,647050937002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','terminator9210','ssalie@mweb.co.za','Shaheed Salie','59 Pinehurst Road<br>Kenwyn','Cape Town','','SOUTH AFRICA','7780','+27836776634','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 19:12:38',0,NULL,3,1,2,1,NULL,NULL),(2885,684385254016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'',49.99,'hutongstore','damonjamesdriver','damonjamesdriver@yahoo.co.uk','Damon Driver','32 Blakeland Hill','Duxford','Cambridgeshire','UNITED KINGDOM','CB22 4RX','07515917469','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  è‹±æ ‡   1\r800w 220v   1\rlight  $16 \rYW863884451CN'),(2886,608020672001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','brkstrtrcr757','brkstrtrcr@aol.com','Chris Young','439 Marion Rd','Hampton','VA','UNITED STATES','23663-1311','(757) 602-7844','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 19:55:21',0,NULL,3,1,1,1,NULL,NULL),(2888,704533801015,250599966664,'Aluminium Ultra Lightweight 71\" Camera Monopod 3wayhead',1,'',21.99,'hutongstore','siegmond2009','siegmondmarsden@yahoo.co.uk','siegmond marsden','10 oak tree road','thatcham','Berkshire','UNITED KINGDOM','rg194qp','01635862676','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 20:45:52',0,NULL,3,1,3,1,NULL,'wf1005   1 \rRR815345163CN\r'),(2889,704547305015,250693634352,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'',4.4,'hutongstore','hpeake666','helenpeake666@yahoo.co.uk','H Peake','Flat 4 105 Cliff Road','Crigglestone','West Yorkshire','UNITED KINGDOM','WF4 3EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 20:49:42',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 52mm cpl   1 '),(2890,608053160001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 20:51:44',0,NULL,8,1,17,0,NULL,NULL),(2891,647111371002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-13 20:51:44',0,NULL,8,1,17,0,NULL,NULL),(2892,608053336001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','koen20102010','koenvanderjagt@upcmail.nl','Koen van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031180521022','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 20:51:45',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   1\r45w   2 \rYW863884462CN\r'),(2893,704340829015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','jpersson2','gomikael@hotmail.com','Jan Persson','2 Stuttle House Buxton Street','London','London','UNITED KINGDOM','E1 5EJ','02072477448','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 21:33:39',0,NULL,3,1,2,1,NULL,NULL),(2894,608088245001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','epkpern','per.norlander@telia.com','Per Norlander','Vikingagatan 2','Vikingstad','','SWEDEN','59049','+461381041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 21:53:51',0,NULL,3,1,2,1,NULL,NULL),(2895,704595861015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','asaliamirka','asalia35@wp.pl','Mirka Zakrzewska','2 Mon desir apartm. Grouville','Jersey','Channel Islands','JE','JE39DJ','07700744639','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-13 22:00:26',0,NULL,5,1,18,0,NULL,NULL),(2896,647151329002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zoommr09','zmmr12@goldmail.etsu.edu','Michelle Ramsaran','1123 Cedar Pl','Johnson City','TN','UNITED STATES','37604-6533','(423) 434-0375','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:03:25',0,NULL,3,1,1,1,NULL,NULL),(2897,608092983001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fashionmystiquespa','fashionmystique2@verizon.net','Dawn Lackner','6406 Chelton Ave','Harrisburg','PA','UNITED STATES','17112-2389','(717) 695-4244','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:04:17',0,NULL,3,1,1,1,NULL,NULL),(2898,647117604002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','seashore1444','watpat@comcast.net','John Watson','7 N Rumson Ave','Margate City','NJ','UNITED STATES','08402-1341','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 22:10:03',0,NULL,3,1,1,1,NULL,NULL),(2899,608097688001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','herbeapuce','stef@videotron.ca','Stephane Bigras','744 Graham Blvd.','Dorval','QC','CANADA','H9P2B6','(514) 636-2746','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 22:14:28',0,NULL,3,1,2,1,NULL,NULL),(2900,608099987001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 22:20:52',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  Nikon   2 '),(2902,704628416015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','jumanjitim','tlb8000@aol.com','Tim Bateman','Eagle Print, Unit 5 Manor Way Business Centre Fairview Estate, Marsh Way','Rainham','Essex','UNITED KINGDOM','RM13 8UG','07940038843','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-13 23:04:05',0,NULL,3,1,2,1,NULL,' '),(2903,608126851001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','starslite80','jpearson@videotron.qc.ca','jacques pearson','431-audouart','quÃ©bec','QC','CANADA','g1c6m3','(418) 667-6972','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 23:33:49',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(2904,647192746002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','shushumna555','robertocavarra@gmail.com','roberto cavarra','17 Jarvie st<br>Brunswick East','Melbourne','Victoria','AUSTRALIA','3057','0414904462','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-13 23:43:48',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   2 '),(2905,608133138001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','pjsm787','pjsm01@msn.com','Pedro Strazzara','G10 Calle Leon<br>Villa del Rey 1','Caguas','Puerto Rico','PUERTO RICO','00725-6262','(787) 360-9723','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-13 23:54:44',0,NULL,8,1,17,0,NULL,NULL),(2906,647195097002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','pjsm787','pjsm01@msn.com','Pedro Strazzara','G10 Calle Leon<br>Villa del Rey 1','Caguas','Puerto Rico','PUERTO RICO','00725-6262','(787) 360-9723','NoPaymentFailure','CheckoutComplete','Other','2010-12-13 23:54:44',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\räº‘å°   1\ræŸ”å…‰ä¼ž   1\r450d çœ¼ç½©     1 \rRR815345203CN\r'),(2907,646647459002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','katriena88','concealed_one07@yahoo.com','katriena greco','1862 17th ave','Kenosha','WI','UNITED STATES','53140-1628','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-14 00:46:02',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(2908,647213375002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','gerbenzomp','rommelhok@zonnet.nl','Gerben Schmidt','Acaciastraat 35 bis','UTRECHT','','NETHERLANDS','3551 BE','030-2332533','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 00:51:53',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345194CN\r'),(2909,647224894002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','georgegowan','georgegowan_69@hotmail.com','George Gowan','5/7 Teemangum Street','Tugun','Queensland','AUSTRALIA','4224','0755595142','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(2910,647226208002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','shehzadsadiq','princeshad@gmail.com','Shehzad Sadiq','KDB IT, Orica House, Level 2<br>123 Carlton Gore Road, New Market','Auckland','','NEW ZEALAND','1023','006421570070','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 01:34:21',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–äºŒ   1 \rRR815345217CN\r'),(2911,647234844002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','soccerhong','centurydentalcare@msn.com','james hong','13011 century blvd','garden grove','CA','UNITED STATES','92843','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 02:01:55',0,NULL,3,1,1,1,NULL,NULL),(2912,607881103001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','saigon74vietnam','susantran77@hotmail.com','Susan Tran','118 Jackson Ave','Madison','AL','UNITED STATES','35758-2324','(256) 457-3393','NoPaymentFailure','CheckoutComplete','Other','2010-12-14 02:03:47',0,NULL,3,1,4,1,NULL,'tripod\r$25\rYW863884532CN\r'),(2913,647235850002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','paradebh','paravideo@gmail.com','Thiago Cordeiro','Av Carandai n:362 ap:1402<br>Bairro Funcionarios','Belo Horizonte','MG','BRAZIL','30130-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 02:08:08',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   3 \r725'),(2914,608180356001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','naomisabelle88','naomisabelle@gmail.com','Naomi Lee','16 Leedon Heights<br>#11-05','Singapore','','SINGAPORE','267937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 03:02:49',0,NULL,3,1,11,1,NULL,NULL),(2915,647263642002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','thimn123','mitnak@gmail.com','thim naccache','50 av charles floquet code 159A','paris','ÃŽle-de-France','FRANCE','75007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 03:36:23',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(2916,647274940002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE1301',29.04,'hermeshine','deeptech1','delsey@deeptech.com','Doug Elsey','6382 Coachford Way','Mississauga','ON','CANADA','L5N 3V8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 04:21:46',0,NULL,3,1,3,1,NULL,' RR815345115CN\r'),(2917,647274732002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','apples452010','davidandsuewinnett@bigpond.com.au','Sue Winnett','120 Albury Street','Holbrook','New South Wales','AUSTRALIA','2644','0260632075','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 04:23:08',0,NULL,3,1,3,1,NULL,'RR815345177CN \r'),(2918,608213125001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','raquelkg_jewelry','raquelkg@terra.com.br','Raquel Guimaraes','4246 Village Dr<br>Apt E','Chino Hills','CA','UNITED STATES','91709-3719','(909) 644-0688','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 04:53:54',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ† nikon   1 '),(2919,647296686002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','priitk111','pkralla@gmail.com','priit kralla','Rooli tn 1 (AU Rool 12)<br>(phone. +3725183483)','Luige kyla, Kiili vald','Harju maakond','ESTONIA','75404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 06:18:08',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(2920,704786204015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','bonnydj','emanuele.bonaldo@gmail.com','emanuele bonaldo','via tor tre ponti nÂ°14','latina','latina','ITALY','04013','3283016028','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 07:39:40',0,NULL,3,1,2,1,NULL,' '),(2921,608244779001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','bbrigi80','atti73@freemail.hu','Brigitta Brocsko','FÃ¼lÃ¶ke u. 212/1.','Budapest','','HUNGARY','1112','+36-30-240-8694','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:05:20',0,NULL,3,1,2,1,NULL,NULL),(2922,647319042002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','c411','dbp@clara.net','David Butler','25 Pinewood Ave','Leigh on sea','Essex','UNITED KINGDOM','SS9 5PH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:26:51',0,NULL,3,1,2,1,NULL,NULL),(2923,608250446001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','dieseltommy','diesel_1964@hotmail.com','Tommy Berglund','Fargarevagen 3','Roknas','','SWEDEN','94631','+46911240041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 08:35:19',0,NULL,3,1,2,1,NULL,NULL),(2924,608272323001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cyr_est','jyri@pixel.ee','JÃ¼ri Muhhin','Linnupesa 6','KÃµrvekÃ¼la','Tartu vald','ESTONIA','60512','+372 5112218','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 10:13:43',0,NULL,3,1,2,1,NULL,NULL),(2925,647345616002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','eurocrystal','buzasuk@hotmail.com','Jae-young Suk','Junggyegreen @115-508<br>Jung-Gye Dong,Nown-gu','seoul','','KOREA,REPUBLIC OF','139-785','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 10:26:56',0,NULL,3,1,2,1,NULL,NULL),(2927,608237619001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',46.19,'hermeshine','tarikyavuz','o.tarikyavuz@gmail.com','TarÄ±k Yavuz','HacÄ± KÃ¼Ã§Ã¼k Camii Sokak<br>No : 19 Sultanhamam - EminÃ¶nÃ¼','Ä°stanbul','','TURKEY','34120','05327036573','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 11:06:37',0,NULL,3,1,3,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon  1\rå¤§åŠ›å¤¹ çƒå°   2\råŒç¯å¤´  æ¬§æ ‡   1\r RR815345375CN\r'),(2929,608285256001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','resonance*','gokceelhan@yahoo.com','Mehmet Gokce Elhan','ENKA ENERJI SANTRALLERI<br>Taskisigi Mh. Cayirtarla Mevkii PK:225','ADAPAZARI','SAKARYA','TURKEY','54100','0902642890140','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 11:26:03',0,NULL,3,1,3,1,NULL,' RR815345322CN\r'),(2930,704861919015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','lowflyer3','iancturner@btconnect.com','Ian Turner','11 The Broadway','Swindon','Wiltshire','UNITED KINGDOM','SN25 3BN','01793523661','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 12:04:23',0,NULL,3,1,2,1,NULL,NULL),(2931,608312983001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',4,'AA1208',17.6,'hermeshine','aville1210','saccharine_babie@yahoo.com','dona ville rabago','hirose higashi 4-34-1<br>junes sayama 102','sayamashi','Saitama','JAPAN','3501320','0429467729','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 12:52:19',0,NULL,3,1,3,1,NULL,'canon 58mm åæŽ¥çŽ¯   4 \rRR815345455CN\r'),(2932,691214782016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','dav_es','andrewldavies@gmail.com','Attn: Andrew Davies - Best Buy UK','1 Portal Way Acton','London','London','UNITED KINGDOM','W36RS','07717266957','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 13:05:52',0,NULL,3,1,2,1,NULL,'å°å·æ— å­—å†…èƒ†åŒ…   1 '),(2933,704908034015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','jake496','mailjasonpaul@yahoo.co.uk','Jason Paul','496 Upper Newtownards Road','Belfast','Down','UNITED KINGDOM','BT4 3HB','02890290517','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-14 14:09:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   2 è‹±æ ‡   \r115w 220v   2\råŒ…   1 \rlighting kit  $28\rYW864143366CN\r'),(2934,691242438016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','ze-photographer','6161207@inbox.lv','Valerijs Zemisevs','Anninmuizas bulv. 38/3-74c','Riga','','LATVIA','LV-1067','26161207','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 14:17:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rRR815345319CN\r'),(2935,647418545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','love668','stephen.rao@gmail.com','Stephen Rao','3918 Misty Morn Ln','Sugar Land','TX','UNITED STATES','77479-3205','(713) 854-6372','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 14:49:18',0,NULL,3,1,1,1,NULL,NULL),(2936,608351084001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Gunes Can Capanoglu','566. sok 3/1 erek apt<br>Akincilar Mah. Sirinyer Buca','Ä°zmir','','TURKEY','35380','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 14:53:00',0,NULL,8,1,17,0,NULL,NULL),(2938,608351491001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',6.6,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Gunes Can Capanoglu','566. sok 3/1 erek apt<br>Akincilar Mah. Sirinyer Buca','Ä°zmir','','TURKEY','35380','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 14:53:56',0,NULL,3,1,2,1,NULL,'52mm uv   2\r58mm uv   1 '),(2940,704937063015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','pandorastyle2010','stylepandora@live.com','Adam  Hinchcliffe','23 Pensham Hill pershore','worcester','Worcestershire','UNITED KINGDOM','WR10 3HA','01386554940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 15:21:53',0,NULL,3,1,2,1,NULL,NULL),(2941,608365838001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','mbbdesign','mboarman@gmail.com','Mark Boarman','7755 Freedom Ave NW','North Canton','OH','UNITED STATES','44720-6905','(330) 492-1338','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 15:37:23',0,NULL,3,1,1,1,NULL,NULL),(2942,704946164015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','mattserati','fatal@westnet.com.au','Matthew Tillotson','135 West Parade','Mt Lawley','Western Australia','AUSTRALIA','6050','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 15:42:19',0,NULL,3,1,2,1,NULL,NULL),(2943,647443072002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','fortunato190905','mway1@rambler.ru','Nina Sevastyanova','ispitateley av. 15-1, flat: 310','Saint-Petersburg','','RUSSIAN FEDERATION','197341','+7 (921) 937 - 0681','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 15:49:18',0,NULL,3,1,2,1,NULL,'éº‚çš®  1 '),(2944,647450302002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','bigfun28','lionel-gourdy@wanadoo.fr','lionel gourdy','63 av de saint ouen',' paris','ÃŽle-de-France','FRANCE','75017','0142262498','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 16:09:29',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW864143355CN\r 退件 需要联系客户 从法国仓库取0141845515'),(2945,647455384002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','stor9560','suzietorre@aol.com','Suzie Torre','2381 Whittier Avenue','Scotch Plains','NJ','UNITED STATES','07076','(908) 202-2135','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 16:20:05',0,NULL,3,1,1,1,NULL,NULL),(2946,647478686002,120560203012,'52mm Lens lenscap for Nikon Combined shipping discounts',4,'AA1305',9.8,'hermeshine','varanasi','christopher.m.perez@tek.com','Christopher Perez','3532 SE Franklin St','Portland','OR','UNITED STATES','97202-1829','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-14 17:14:14',0,NULL,3,1,1,1,NULL,NULL),(2947,608405716001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','kilincs99','r.miska@gmail.com','MihÃ ly RadvÃ nyi','NyÃ¹l utca 7','Budapest','','HUNGARY','1024','+36-20-823-46-98','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 17:18:46',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(2948,647486469002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-14 17:37:31',0,NULL,3,1,1,1,NULL,'cåž‹å¤§åŠ›å¤¹   1 '),(2949,705058813015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'',8.99,'hutongstore','itsnew2u2010','davespeedyrecovery@yahoo.co.uk','Dave Barrett','51 Chatham Place Curry Rivel','Langport','Somerset','UNITED KINGDOM','TA10 0HS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 18:59:49',0,NULL,3,1,2,1,NULL,'é˜²é›¨ç½©   1 '),(2950,647465852002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','kilin02','pokupka02@mail.ru','ÐÐ½Ð´Ñ€ÐµÐ¹ ÐšÐ¸Ð»Ð¸Ð½','Ð¢Ð°Ñ‚ÑŒÑÐ½Ñ‹ Ð‘Ð°Ñ€Ð°Ð¼Ð·Ð¸Ð½Ð¾Ð¹, 14, 8','Ð˜Ð¶ÐµÐ²ÑÐº','Ð£Ð´Ð¼ÑƒÑ€Ñ‚cÐºÐ°Ñ Ð ÐµÑÐ¿ÑƒÐ±Ð»Ð¸ÐºÐ°','RUSSIAN FEDERATION','426067','+79043127847','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 19:01:57',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345407CN\r'),(2951,608476316001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','tyncho78','tyncho_78@fibertel.com.ar','Martin Gardeazabal','Bolivia 95 9no F','Capital Federal','Buenos Aires','ARGENTINA','1406','5411-4612-3368','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:32:39',0,NULL,3,1,2,1,NULL,NULL),(2952,691408768016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','noz_90','traffic_@live.co.uk','Nolan Galea','23, Triq il Gammar','Attard','','MALTA','ATD 2640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 19:34:19',0,NULL,3,1,2,1,NULL,'77mm æŽ¥å£çŽ¯   1 '),(2953,647560832002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','00420-608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:47:28',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹    2 '),(2954,647564059002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','ezrage12','ezrage@gmail.com','Ezra Genuth','Tarshish 77','Modiin','Israel','ISRAEL','71725','972-50-8918239','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 19:52:28',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹    2  \rRR815345367CN\r'),(2955,646874440002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT014',71.3,'hermeshine','ruuuka','ruukachan@gmail.com','Ruuka Huang','9165 Rollin','Brossard','QC','CANADA','J4X 2P7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:01:45',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rå•ç¯å¤´   2\råå…‰ä¼ž   2 \rCP219437408CN\r'),(2956,608534235001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','jeloul76','jalalkhaldi@gmail.com','Jalal KHALDI','4 avenue san fernando','Montigny le bretonneux','ÃŽle-de-France','FRANCE','78180','0686568711','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:15:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   3 \råŒ…   1\rlighting kit  $30\rYW864143392CN\r'),(2957,647610352002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','jeloul76','jalalkhaldi@gmail.com','Jalal KHALDI','4 avenue san fernando','Montigny le bretonneux','ÃŽle-de-France','FRANCE','78180','0686568711','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:15:18',0,NULL,8,1,17,0,NULL,''),(2958,647622247002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:26',0,NULL,8,1,17,0,NULL,NULL),(2959,608543529001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:26',0,NULL,8,1,17,0,NULL,NULL),(2960,608544120001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 21:37:27',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©   2\r67mm æ©¡èƒ¶ç½©   1 '),(2961,608552686001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0024',6.99,'hermeshine','romanelcuore2010','sheila86_b@hotmail.it','G.Pischedda c/o B.Sardegna','p.zza cavour 32','livorno','LI','ITALY','57126','0586836117','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 21:56:32',0,NULL,3,1,2,1,NULL,'canon å°åŒ…   1 '),(2962,647641880002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','diablots3','paradiss@telefonica.net','JORDI PARADIS MULERO','Urb.San BartolomÃ©, 23','Umbrete','AndalucÃ­a Ceuta y Melilla','SPAIN','41806','692641007','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 22:18:30',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864143381CN\r'),(2963,705193959015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','olppax','ollitee@wippies.fi','olli teelmÃ¤ki','paaskunnankatu 1 d 41','turku','lÃ¤nsi-suomen lÃ¤Ã¤ni','FINLAND','20540','0442584862','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-14 22:23:11',0,NULL,3,1,2,1,NULL,'ä¸€è½¬å››ç¯å¤´  1 '),(2964,608575734001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','marina_lima','marinadfl@hotmail.com','marina dubourcq fonseca lima','rua leonardo bezerra cavalcanti<br>300/702','recife','pernambuco','BRAZIL','52060030','558132682766','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-14 22:53:17',0,NULL,3,1,2,1,NULL,NULL),(2965,647664198002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 23:18:37',0,NULL,8,1,17,0,NULL,''),(2966,647655235002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','oncarf','castellari.franco@libero.it','Franco Castellari/Laura Leccese','Via Romita NÂ°42','Serravalle Scrivia','AL','ITALY','15069','3474786382','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-14 23:35:37',0,NULL,3,1,3,1,NULL,'sony æ‘„å½±èƒŒå¿ƒ  xl  é»‘è‰² åŽš   1 \rRR815345441CN\r'),(2967,608594939001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','big_dolt','dtlockard@gmail.com','David  Lockard','PO Box 240147','Douglas','AK','UNITED STATES','99824-0147','(907) 364-2965','NoPaymentFailure','CheckoutComplete','Other','2010-12-14 23:57:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1 \rlight stand $18\rYW863884543CN\rRR764990593CN\r'),(2968,705236202015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','edel3597','miskis82@hotmail.com','edel bertram','33 gateacre walk, brooklands','sale','Greater Manchester','UNITED KINGDOM','m23 9ba','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-14 23:57:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(2969,608606027001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','moca2100','prasush@hotmail.com','Pramod Puri','12688 CHAPMAN AVE<br>Unit 3211','GARDEN GROVE','CA','UNITED STATES','92840-4043','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 00:38:49',0,NULL,3,1,1,1,NULL,NULL),(2970,608587914001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:09',0,NULL,8,1,17,0,NULL,NULL),(2971,647666973002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:10',0,NULL,8,1,17,0,NULL,NULL),(2972,608589441001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','tetuve','fabtetard@free.fr','Fabrice TETARD','28 rue du lieutenant Fiancey','St EGREVE','RhÃ´ne-Alpes','FRANCE','38120','+33621490622','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 00:56:11',0,NULL,3,1,4,1,NULL,' 717 180    1 \r52mm çŽ¯æž¶  1\r58mm çŽ¯æž¶  1\rND2/4/8   1\ræ¸å˜ç°   1\rcpl   1\rtripod $30\rYW863884591CN\r\r'),(2973,608609597001,110523102217,'67mm Lens lenscap for Canon Combined shipping discounts',1,'AA1302',2.6,'hermeshine','kaimeischke_2007','kai@meischke.net','Kai Meischke','308/15 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0420769443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 01:02:58',0,NULL,8,1,17,0,NULL,NULL),(2974,608609427001,110531023440,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','kaimeischke_2007','kai@meischke.net','Kai Meischke','308/15 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0420769443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 01:02:58',0,NULL,3,1,2,1,NULL,'450d çœ¼ç½©  1\r67mm é•œå¤´ç›–  canon   1 '),(2975,600759322001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',14.5,'hermeshine','goldorak-----go','myspace@hot-bike.ch','chris mettraux','pontaise 41','lausanne','','SWITZERLAND','1018','0041763482041','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,' 2x lenscase (s),\r 2x lenscase(m)\rRR815345438CN\r'),(2976,608635015001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',2,'AE1502',164,'hermeshine','jumpby','juanmaasecas@hotmail.com','juan manuel herrera marin','c/Palacios ValdÃ©s 6, p1-2','Linares','AndalucÃ­a Ceuta y Melilla','SPAIN','23700','648754551','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 02:32:56',0,NULL,3,1,4,1,NULL,'tripod $30 \rYW863884484CN\r'),(2977,608662172001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 04:14:38',0,NULL,3,1,3,1,NULL,'åˆ†ä¸¤ç¥¨å‘ \rRR815345398CN\rRR815345384CN\r\r'),(2978,608662482001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','kobble','kolbein.svensson@gmail.com','Kolbein Svensson','Geitastrandveien 21','Orkanger','','NORWAY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 04:16:12',0,NULL,3,1,2,1,NULL,NULL),(2979,608686556001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','cz3221','cezeez@yahoo.com','Cesar Brito','2248 W 233rd St','Torrance','CA','UNITED STATES','90501-5726','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 06:38:46',0,NULL,3,1,1,1,NULL,NULL),(2980,647776718002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pixoid','mra@pixar.com','Mark R. Adams','1838 Heather Ln','Petaluma','CA','UNITED STATES','94954-8591','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 06:41:57',0,NULL,3,1,1,1,NULL,NULL),(2981,608692713001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','iamdiva007','angela@angelacalderon.com','Angela Calderon','1029 Chatsworth Ln','Woodstock','GA','UNITED STATES','30189-6683','(770) 653-7116','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 07:16:40',0,NULL,3,1,1,1,NULL,NULL),(2982,647794147002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','chernov_da','cdastudio@mail.ru','Dmitry Chernov','Ulyanovskaya 2-60<br>Ruza','Ruza / Moscow','','RUSSIAN FEDERATION','143103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:21:13',0,NULL,8,1,17,0,NULL,NULL),(2983,647793714002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',70,'hermeshine','chernov_da','cdastudio@mail.ru','Dmitry Chernov','Ulyanovskaya 2-60<br>Ruza','Ruza / Moscow','','RUSSIAN FEDERATION','143103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:21:14',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xxl   2\rcanon èƒŒå¿ƒ xxxl  1 \rRR815345954CN\r'),(2984,705378165015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',27,'hutongstore','ziimbabve','abra-kadabra@bk.ru','Yakov Sakhan','Gromova street, 15-117','Rubtsovsk','Altay region','RUSSIAN FEDERATION','658213','+79132796620','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-15 08:31:17',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815345923CN\r'),(2985,608707691001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 08:41:56',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815345866CN\r'),(2986,608729283001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','kobble','kolbein.svensson@gmail.com','Kolbein Svensson','Geitastrandveien 21','Orkanger','','NORWAY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:18:15',0,NULL,3,1,2,1,NULL,'å€’å½±æ¿  1 '),(2987,647831476002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','yskunto','kunto_ys@peter.petra.ac.id','Yohanes Sondang Kunto','Blimbing Indah Tama C2/50','Malang','East Java','INDONESIA','65126','+62 341 496491','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 11:06:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815345945CN\r'),(2988,647827940002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','bushutte','vautinsh@gmail.com','Valdis Krumins','Skolas iela 3-100','Salaspils','','LATVIA','LV-2121','+371 29239141','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:53:07',0,NULL,8,1,17,0,NULL,NULL),(2989,608737494001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','bushutte','vautinsh@gmail.com','Valdis Krumins','Skolas iela 3-100','Salaspils','','LATVIA','LV-2121','+371 29239141','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 10:53:07',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ æ¬§æ ‡   1\r115w 220v ç¯æ³¡   1 \rRR815346005CN\r'),(2990,647839279002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','ifel79','ifelmail@gmail.com','Igor Kanjuka','N. Uzhvij, building 72<br>flat 236','Kharkov','','UKRAINE','61195','380(66)7805537','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 11:35:07',0,NULL,3,1,2,1,NULL,' '),(2991,647833045002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','simonepuma80','21tiger1@aliceposta.it','Simone Zanni','via al fiume<br>1','Cambiasca','VB','ITALY','28814','3488185038','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 12:29:23',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ ï¼‰ 1\r2m ç¯æž¶  2\råŒç¯å¤´ æ¬§æ ‡  2\r115w 220v   4\råå…‰ä¼ž   2\råŒ…    1\rlighting kit  $30\r\r'),(2992,691778593016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.5,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 13:27:48',0,NULL,8,1,17,0,NULL,NULL),(2993,705467618015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 13:27:47',0,NULL,8,1,17,0,NULL,' '),(2994,691778103016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-15 13:27:48',0,NULL,3,1,4,1,NULL,'2m x 3m èƒŒæ™¯æž¶   1\r3m x6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\råŒ…   1\rä¸€è½¬å››ç¯å¤´  1\r100-150 åå…‰æ¿    1 \rä¸€ç¥¨ä¸¤ä»¶å§ï¼Œåå…‰æ¿ä¸å¥½åŒ…çš„è¯\rlighting kit  $32\rYW863884506CN\r'),(2995,608792114001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','imstaeb','dovy@bezeqint.net','Dov Yassky','13, Sderot Chen','Tel Aviv','--','ISRAEL','64071','97236209031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 14:10:27',0,NULL,3,1,2,1,NULL,'52-52 åŒé˜³çŽ¯   1 '),(2996,647930993002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','arturbaikov','abaikov@yandex.ru','Artur Baikov','Kyivskaya 25-29','Zhytomyr','','UKRAINE','10014','380-412-471753','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 16:19:17',0,NULL,3,1,2,1,NULL,NULL),(2997,608495971001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',5.94,'hermeshine','0440.literatboris','literatboris@gmail.com','Boris Literat','Hayogev -- 15','Ofaqim','','ISRAEL','87613','+97289960440','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 16:27:04',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r58mm æ©¡èƒ¶ç½©    1 '),(2998,705542597015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'',18.3,'hutongstore','dgs_tomek','td145@vp.pl','Tomasz Dobrzanski','12 castle walk','didcot','Oxfordshire','UNITED KINGDOM','ox117pd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-15 17:05:32',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å››ç¯å¤´   2 \rRR815345910CN\r'),(2999,648017670002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','punchihewa','manojpunchihewa@yahoo.com','Manoj Punchihewa','1145 Wintergreen Cv','Cordova','TN','UNITED STATES','38018-8828','(901) 921-1196','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 19:17:08',0,NULL,3,1,1,1,NULL,NULL),(3000,648048663002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',8,'AA1301',19.4,'hermeshine','houndqueen','topalov5@optusnet.com.au','HELEN TOPALOV','6 CURLEW CAMP ROAD','MOSMAN','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 20:11:25',0,NULL,3,1,3,1,NULL,'RR815345659CN\r'),(3001,648057487002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','lelodani','re_nato@yahoo.com','Renato F De Araujo','75 Pierrepont St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11201','(718) 855-4235','NoPaymentFailure','CheckoutComplete','Other','2010-12-15 20:31:32',0,NULL,8,1,17,0,NULL,NULL),(3002,648054929002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','lelodani','re_nato@yahoo.com','Renato F De Araujo','75 Pierrepont St<br>Apt 6E','Brooklyn','NY','UNITED STATES','11201','(718) 855-4235','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 20:31:33',0,NULL,3,1,1,1,NULL,'é˜²å¯’ç½©   1\rç¢—ç½© p1    1 '),(3003,648084065002,120568071807,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','bestrashny','gregorygur@gmail.com','gregory gurevich','nahal tzvi 32/16','migdal haemek','','ISRAEL','23049','972-0544831155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:15:12',0,NULL,3,1,2,1,NULL,'canon-52 åæŽ¥çŽ¯   1 '),(3004,608711449001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:37',0,NULL,8,1,17,0,NULL,NULL),(3005,608709201001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:38',0,NULL,8,1,17,0,NULL,' '),(3006,608710881001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.3,'hermeshine','asterixbcn','benfranklinfu@yahoo.de','Ricard Riel Cabrera','ConcÃ²rdia 14, 2-2','Barcelona','CataluÃ±a','SPAIN','08004','675733555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-15 21:19:38',0,NULL,3,1,2,1,NULL,'\r52mm é•œå¤´ç›– nikon   1\rå°å·å†…èƒ†åŒ… nikon   1 '),(3007,692050293016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.5,'hutongstore','dougoudoum','demoulinfabrice@gmail.com','demoulin fabrice','pta carlos manito torres nÂº1, 4f','setubal','setubal','PORTUGAL','2900','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-15 21:38:02',0,NULL,3,1,3,1,NULL,'100-150 åå…‰æ¿    1\rRR815345999CN\r  '),(3008,648103307002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT014',73.3,'hermeshine','james7007_123','jakub.snabl@seznam.cz','Jakub Å nÃ¡bl','Pod MÃ½tem 60','Å ternberk','Czech Republic','CZECH REPUBLIC','78501','00420777012130','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-15 21:54:53',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rå•ç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2 \rCP219437442CN\r'),(3009,648120701002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','s.himanshu09','s.himanshu9@gmail.com','Himanshu','408 Joseph Ct','Oswego','IL','UNITED STATES','60543-7315','(312) 203-0413','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-15 22:39:21',0,NULL,3,1,1,1,NULL,NULL),(3012,609065003001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','shipsforsail','mkdavies@shaw.ca','Ken Davies','582 Hawthorne Rise','Parksville','BC','CANADA','v9p 2k3','(250) 752-4480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:22:25',0,NULL,8,1,17,0,NULL,NULL),(3013,648170356002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shipsforsail','mkdavies@shaw.ca','Ken Davies','582 Hawthorne Rise','Parksville','BC','CANADA','v9p 2k3','(250) 752-4480','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:22:26',0,NULL,3,1,2,1,NULL,'EW-73B   1\rET-65B    1 '),(3014,609073207001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','moreiralm','lmiguelmoreira@gmail.com','Luis Moreira','Rua Pedras da MarÃ©, nÂº 794 3Âº DT sul<br>S. Felix Marinha','V.N.Gaia','S Felix Marinha','PORTUGAL','4410-129','+351919946667','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 01:53:18',0,NULL,3,1,2,1,NULL,NULL),(3015,609074925001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tazy1115','al-fadh1511@hotmail.com','Fadillah Ali','No.8, spg. 806-13, Kg. Jangsak<br>Jalan Gadong','Bandar Seri Begawan','Brunei Muara','BRUNEI DARUSSALAM','BF 2720','+6738839039','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 02:00:20',0,NULL,3,1,3,1,NULL,' RR815345971CN\r'),(3016,609075602001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mkalogios','deppytefaa@yahoo.gr','KALOGYIOS EMMANOUHL','MOUSSON 98B','ATHENS','NIKAIA,NEAPOLH','GREECE','18452','6976613475','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 02:01:37',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815345937CN\r'),(3017,609075756001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','garym165','smclean31@cogeco.ca','Gary','McLean<br>123 Kingham Road','Acton','ON','CANADA','L7J1S3','(519) 929-9255','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 02:02:36',0,NULL,3,1,2,1,NULL,'éº‚çš®  2 '),(3018,609067269001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','lucasdjone','lucasdjone@hotmail.com','lucas haedo','barrio smata 1 , manzana O lote 12<br>12','cordoba','cordoba','ARGENTINA','5016','4622004','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 02:08:03',0,NULL,3,1,2,1,NULL,''),(3019,609087318001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','jw12ang','jwang@wideopenwest.com','Jimmy Wang','511 Gateshead Dr','Naperville','IL','UNITED STATES','60565-3186','(630) 548-9812','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 02:52:29',0,NULL,3,1,1,1,NULL,' '),(3020,648205985002,120568071854,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','hiwave','ksh5-2@hanmail.net','soohyun kim','Life Apt.3-1406, Hang-dong 7-ga, Jung-gu, Incheon, Korea','Incheon','Incheon','KOREA,REPUBLIC OF','400-751','82-32-889-6439','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 03:30:51',0,NULL,3,1,6,1,NULL,'2m ç¯æž¶   2\råŒç¯å¤´  2\råå…‰ä¼ž   2\r åŒ…    1 \ræ–°åŠ å¡ems\rEX000273287SG\r'),(3021,609129019001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 06:17:03',0,NULL,8,1,17,0,NULL,NULL),(3022,648237740002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:17:03',0,NULL,8,1,17,0,NULL,NULL),(3023,648235923002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','tommeo','tommeo@sympatico.ca','Thomas Brezinski','783A  Apt. 3 Danforth Ave','Toronto','ON','CANADA','m4j1l2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:17:04',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1\rcåž‹å¤¹  1\réº‚çš®    1 \rRR815345778CN\r'),(3024,648240010002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','ymliew2','ymliew@hotmail.com','Liew Yien Mau','182, Taman Genesis,<br>Jln Matang Batu Kawa','Kuching','Sarawak','MALAYSIA','93050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 06:32:06',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(3025,648247287002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','platinumz','platinum_ong@hotmail.com','Platinum Ong Choon Yen','42-G, GROUND FLOOR, JALAN DINAR, F U3/F,<br>TAMAN SUBANG PERDANA, SEK U3,','SHAH ALAM','SELANGOR,MALAYSIA','MALAYSIA','40150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 07:18:12',0,NULL,3,1,2,1,NULL,NULL),(3026,608902466001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',23.45,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7Âº 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 08:05:09',0,NULL,3,1,3,1,NULL,' 6662a å¿«è£…æ¿   2\r77mm çŽ¯æž¶  1\r430è‚¥çš‚ç›’    1\rRR815345680CN\r\r\r'),(3027,609162484001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','tatiana.nefedova','tatiana.nefyodova@gmail.com','Tatiana Nefedova','Shkolniy bulvar, dom 20, kv 25','Chernogolovka','Moscow district','RUSSIAN FEDERATION','142432','007-9057481744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 09:33:23',0,NULL,3,1,2,1,NULL,NULL),(3028,692256524016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','photographer1506','edwarddullard@gmail.com','EDWARD DULLARD','13 DE LA SALLE PLACE','KILKENNY CITY','COUNTY KILKENNY','IRELAND','056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 09:35:39',0,NULL,3,1,3,1,NULL,' RR815345755CN\r'),(3029,609173111001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','zheyu321','zhe1984@hotmail.com','Thor Yu Zhe','2, Jalan Indah 1/28,<br>Taman Universiti Indah,','Seri Kembangan','Selangor Darul Ehsan','MALAYSIA','43300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 10:22:36',0,NULL,3,1,2,1,NULL,NULL),(3030,705984993015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','gerardm5368','f63photos@eircom.net','Gerard Murphy','Lavally Lower, Mallow','Cork','Cork','IRELAND','default','00353851740738','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 12:10:49',0,NULL,3,1,2,1,NULL,NULL),(3031,648309188002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','guscupra','guscupra@hotmail.com','GUSTAVO VALVERDE MUÃ‘OZ','BABOR NÂº40','ALHAURIN DE LA TORRE (MALAGA)','AndalucÃ­a Ceuta y Melilla','SPAIN','29130','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 12:15:45',0,NULL,3,1,3,1,NULL,'sony èƒŒå¿ƒ é»‘è‰²   xxl    1 \rRR815345693CN\r'),(3032,647503439002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','tilberien','herzog.pavel@gmail.com','Pavel Herzog','Fujikoki Czech s.r.o.<br>Prumyslova 386','Louny','CZ','CZECH REPUBLIC','44001','415652918','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 12:27:22',0,NULL,3,1,2,1,NULL,' '),(3033,648317237002,120454246029,'4 way Macro Slider for CANON NIKON SONY Olympus PENTAX',1,'AE3102',51.9,'hermeshine','digiser','prodjs@teleline.es','Jose Luis Solar PeÃ±a','Av/ Carmen Miranda 6','Pravia','Asturias','SPAIN','33120','985000000','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 12:45:09',0,NULL,3,1,3,1,NULL,'å¾®è·æž¶  1 \rRR815345702CN\r'),(3034,609206678001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','gizmofr77','tnshop@tiet.net','Trung Nghi TIET','30 Thurlow Street','Redfern','New South Wales','AUSTRALIA','2016','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 12:45:31',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rlight stand  $20\rYW863884580CN\r\r'),(3035,609213461001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','falcorner','pdelalastra@wanadoo.es','Pablo de la Lastra Marcos','Velarde nÂº 2 - 3Âº C','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41001','652926047','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 13:07:48',0,NULL,8,1,17,0,NULL,NULL),(3036,648322470002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','falcorner','pdelalastra@wanadoo.es','Pablo de la Lastra Marcos','Velarde nÂº 2 - 3Âº C','Sevilla','AndalucÃ­a Ceuta y Melilla','SPAIN','41001','652926047','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 13:07:49',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1\r110cm 5in 1  åå…‰æ¿   1\rYW863884576CN\r\rç‡•æ–‡ä¸€ç¥¨ä¸¤ä»¶'),(3037,692322331016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','iancook458','iancook@ijcphotography.co.uk','Ian Cook','647 Monnow Way Bettws','Newport','Gwent','UNITED KINGDOM','NP20 7DN','01633855280','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 13:16:10',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1\rreflector holder  $18\rYW863884565CN\r\r'),(3038,648332648002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','roma1414','romabeg@hotmail.com','Roman Beglarov','Aviakonstruktorov d.36, kv90','Sankt-Petersburg','','RUSSIAN FEDERATION','197373','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 13:41:18',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1'),(3039,648338944002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','rrobbiefcb','robert@limesmodel.hu','Robert Racz','Sas Militaria - Szinvonal<br>Sas u. 5.','Budapest','Hungary','HUNGARY','1051','+36209228474','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 14:00:57',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶   2\r4ç¯å¤´ æ£š   2  æ¬§æ ‡   \r45w  8\r åŒ…    1\rCP219437411CN\r\r '),(3040,692328179016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'',6.1,'hutongstore','ant-eater','koziel@tlen.pl','Opus-B, Tomasz KozieÅ‚','Pijarska 9','KrakÃ³w','maÅ‚opolskie','POLAND','31-015','507 260707','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 14:22:58',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(3041,692356446016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','fotoboy64','fotoboy@apollo.lv','Maris J IK','Darzu 60-22','Rezekne','','LATVIA','LV-4601','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-16 14:50:28',0,NULL,3,1,2,1,NULL,''),(3042,646345024002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ratinha40','vladyszimba@hotmail.com','vladys cargnin','6073 Boca Colony Dr<br>Apt 1211','Boca Raton','FL','UNITED STATES','33433','(954) 562-0679','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:00:05',0,NULL,3,1,1,1,NULL,NULL),(3043,706059301015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','copelinter','ricoplin@googlemail.com','Richard Copeland','69 Delamere RD Bedworth','Nuneaton','Warwickshire','UNITED KINGDOM','CV12 8SG','02476314961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 15:06:21',0,NULL,3,1,2,1,NULL,'45w   2 '),(3044,706063170015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.28,'hutongstore','vincelotte','autenzio@hotmail.com','antonio autenzio','171 rue saint denis','paris','ÃŽle-de-France','FRANCE','75002','0622706868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 15:16:15',0,NULL,3,1,2,1,NULL,NULL),(3045,609257099001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','kenclimber','ken_noyce@hotmail.com','Kenneth Noyce','2245 Nice Ave<br>Apt A2','Mentone','CA','UNITED STATES','92359-9757','(801) 735-8697','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:30:37',0,NULL,3,1,1,1,NULL,''),(3046,609255474001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','blancaportanet','blancasc@gmail.com','BLANCA SANCHEZ CARRERA','PRINCIPE DE VERGARA 58 4Âº C-I','MADRID','Madrid','SPAIN','28006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 15:32:19',0,NULL,3,1,4,1,NULL,'tripod   $15 \rYW863884554CN\r'),(3047,706074036015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','profclimb','prandy@waitrose.com','Kenneth Prandy','School House Llangattock Lingoed','Abergavenny','Monmouthshire','UNITED KINGDOM','NP7 8RR','01873821758','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 15:42:19',0,NULL,3,1,2,1,NULL,NULL),(3048,648377423002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','akilles4','akilles@pacinfo.com','John C. Rowland','637 7th St','Springfield','OR','UNITED STATES','97477-4631','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 15:56:45',0,NULL,3,1,1,1,NULL,NULL),(3049,609270552001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','davidof4','davidbalick@gmail.com','David Balick','765 Bunker Hill Rd','King of Prussia','PA','UNITED STATES','19406-1553','(610) 354-0115','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 16:09:11',0,NULL,3,1,1,1,NULL,'sf18-canon   1 '),(3050,648386285002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2401',49.9,'hermeshine','eniacservice','o.belishta@eniac-services.com','Olsi Belishta','Klinika Ikeda<br>Rr. Kongresi i Manastirit','Tirane','Tirane','ALBANIA','1015','+355672066378','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:18:16',0,NULL,3,1,3,1,NULL,'50-70 æ£š é€šç”¨å¡å£  2 \rRR815345614CN\r'),(3051,648390726002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','joachimwiig','joachimwiig@hotmail.com','joachim wiig raak','kvamstrÃ¸a 10','steinkjer','','NORWAY','7715','(+47) 97756510','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:31:05',0,NULL,8,1,17,0,NULL,''),(3052,648392161002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','joachimwiig','joachimwiig@hotmail.com','joachim wiig raak','kvamstrÃ¸a 10','steinkjer','','NORWAY','7715','(+47) 97756510','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 16:33:02',0,NULL,3,1,3,1,NULL,' ND4/ 8  æ¸å˜ç°  58mm çŽ¯æž¶   1 \r77mm æŽ¥å£çŽ¯   1\rRR815345628CN\r'),(3054,648409395002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','doubleview','yausser@usa.net','Richard Yaussi','1622 W Longhill Dr','Monterey Park','CA','UNITED STATES','91754-4523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 17:16:12',0,NULL,3,1,1,1,NULL,NULL),(3055,609297236001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','enigma505','enigma505@email.com','Patrick Blake II','DynCorp International<br>Unit 42119','APO','AE','AA','09342','(702) 325-4379','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 17:18:03',0,NULL,3,1,1,1,NULL,NULL),(3056,648418991002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','pwakefield71','wakefieldfx@hotmail.com','Patrick Wakefield','77 Masters Dr','Barrie','ON','CANADA','L4M6W9','(705) 734-0909','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 17:37:29',0,NULL,3,1,2,1,NULL,'cåž‹å¤§åŠ›å¤¹   2 '),(3057,648427883002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','hotcorner4jeff','jeffabctv@yahoo.com','Jeff Caldwell','10061 Riverside Dr<br># 210','Toluca Lake','CA','UNITED STATES','91602','(818) 231-3702','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 18:09:32',0,NULL,3,1,1,1,NULL,'canon å°å·å†…èƒ†åŒ…   1 '),(3058,609331580001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo Street<br>64-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','8-902-7918020','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 18:33:55',0,NULL,3,1,2,1,NULL,'72mm æ©¡èƒ¶ç½©   1 '),(3059,609335184001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','inafih','knaphih@gmail.com','Ibrahim Nafih','46/1<br>Rathnawali Road','Kalubowila','Western Province','SRI LANKA','94','+94779449789','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 18:41:37',0,NULL,3,1,2,1,NULL,'58mm uv   1 '),(3060,648450497002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','hadijoyce','hadij@hotmail.com','Hadi Joyce','1588 Boulder Walk Dr SE','Atlanta','GA','UNITED STATES','30316','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 18:43:09',0,NULL,3,1,1,1,NULL,NULL),(3061,706158929015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'',6.1,'hutongstore','ex-dylan-dog','ex_dylan_dog@yahoo.it','Luca Radatti','Via B. Croce, 16','Paese','TV','ITALY','31038','3286645016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-16 18:57:41',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(3062,692487786016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'',10.99,'hutongstore','agajuce','agnieszka.lewin@yahoo.co.uk','agnieszka lewin','139 anson road','crickelwood','London','UNITED KINGDOM','nw2 4ah','07766640925','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-16 19:18:22',0,NULL,3,1,2,1,NULL,'cpl   1 '),(3063,648510540002,120593060982,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1101',22.9,'hermeshine','ggcan','gg@primus.ca','Glane Gorveatt','171 Hages Lane','Prospect','NS','CANADA','B3T 2A4','(902) 852-4201','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-16 20:39:06',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å¤å­£  L   1 \rRR815345631CN\r'),(3064,648515679002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','bobbyddixon117','bobbyddixon@hotmail.com','Bobby D. Dixon','1617 Country Meadows Dr','Sevierville','TN','UNITED STATES','37862-9335','(865) 441-1859','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 20:46:13',0,NULL,3,1,1,1,NULL,NULL),(3065,648526431002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','pedoviejo59','jellynoel@yahoo.com','joel w kaufmann','1023 N Bishop Ave','dallas','TX','UNITED STATES','75208-4112','(214) 300-5840','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:08:25',0,NULL,8,1,17,0,NULL,NULL),(3066,648527721002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','pedoviejo59','jellynoel@yahoo.com','joel w kaufmann','1023 N Bishop Ave','dallas','TX','UNITED STATES','75208-4112','(214) 300-5840','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:10:13',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›–   canon   1\r67mm æ©¡èƒ¶ç½©    1 '),(3067,609411022001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','wiserhoffwiserhoff','wiserhoff@gmail.com','Dinar Burnashev','Kolomenskaya street, 15-2-612','Moscow','','RUSSIAN FEDERATION','115142','(964)-5373272','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:13:47',0,NULL,8,1,17,0,NULL,NULL),(3068,648530875002,120454221534,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','wiserhoffwiserhoff','wiserhoff@gmail.com','Dinar Burnashev','Kolomenskaya street, 15-2-612','Moscow','','RUSSIAN FEDERATION','115142','(964)-5373272','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:17:16',0,NULL,3,1,2,1,NULL,'110cm 5in1  åå…‰æ¿  1\r77mm ND4   1 '),(3069,648530918002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cktechguy13','saigonohato@gmail.com','Chris  King','2446 Taylor Ave','corona','CA','UNITED STATES','92882','(951) 310-0796','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-16 21:18:51',0,NULL,3,1,1,1,NULL,NULL),(3070,609431191001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','epkpern','per.norlander@telia.com','Per Norlander','Vikingagatan 2','Vikingstad','','SWEDEN','59049','+461381041','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 21:58:39',0,NULL,3,1,2,1,NULL,NULL),(3071,609435264001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',14.5,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','KrisztiÃ¡n Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 22:10:27',0,NULL,8,1,17,0,NULL,''),(3072,648554735002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','KrisztiÃ¡n Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-16 22:13:06',0,NULL,3,1,3,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  2\rå¤§å·å†…èƒ†åŒ… nikon   2\rRR815345645CN\r'),(3073,647269007002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','nickball982009','nickball98@yahoo.com','Nick Ball','2217 Lafayette Ter','Clinton','IA','UNITED STATES','52732-6647','(563) 243-4120','NoPaymentFailure','CheckoutComplete','Other','2010-12-16 22:29:05',0,NULL,3,1,1,1,NULL,'sony èƒŒå¿ƒ é»‘è‰²  xxl  1 '),(3075,609480042001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','luizweb','luizantoniogsimoes@gmail.com','Luiz Simoes','Rua Olavo de Paula Borges, 83<br>ap. 23-B','Santos','SÃ£o Paulo','BRAZIL','11035-130','13-3236-8826','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 00:44:50',0,NULL,3,1,2,1,NULL,NULL),(3077,609530525001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','lliatep','zhitenko77@yandex.ru','Ivan Zhitenko','Kurchatova,23A,40','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454092','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:22:33',0,NULL,3,1,2,1,NULL,NULL),(3078,648656858002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','jrbegalli','raphael.begalli@yahoo.com.br','JoÃ£o Raphael Grazia Begali','Av. Dr. Sylvio de Aguiar Maya, 268<br>Centro','Pedreira','SP','BRAZIL','13920-000','55 19 3893 5319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:23:55',0,NULL,8,1,17,0,NULL,NULL),(3079,609529230001,110532007517,'Male-Male 58mm-58mm Macro Combined shipping discounts',1,'AA1213',3.8,'hermeshine','jrbegalli','raphael.begalli@yahoo.com.br','JoÃ£o Raphael Grazia Begali','Av. Dr. Sylvio de Aguiar Maya, 268<br>Centro','Pedreira','SP','BRAZIL','13920-000','55 19 3893 5319','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 04:23:56',0,NULL,3,1,2,1,NULL,'58-58 åŒé˜³çŽ¯  1\ræœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3080,609537402001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','tom4038525','tom.march.ca@gmail.com','Tom March','710 Earl Grey Cres SW','Calgary','AB','CANADA','T2S0N7','(403) 245-8435','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 05:01:29',0,NULL,3,1,2,1,NULL,NULL),(3081,706412734015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'',18.9,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 05:01:58',0,NULL,3,1,2,1,NULL,'ND2/4/8  72mm çŽ¯æž¶  1 '),(3082,706417842015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'',18.9,'hutongstore','waixmonkey','frank@protrader.com.au','Frank Watkins','13 Klem Ave','Redcliff','Western Australia','AUSTRALIA','6104','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 05:11:44',0,NULL,3,1,2,1,NULL,'ND2/4/8  58mm çŽ¯æž¶  1 '),(3083,609542910001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','salteefish','laijason@msn.com','Jason Lai','30 Gentry','Irvine','CA','UNITED STATES','92620-2836','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-17 05:35:05',0,NULL,3,1,1,1,NULL,' '),(3084,648680655002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','telezini','studio1@telezini.com','Sergio Marranzino','45 Gramercy Ave','Yonkers','NY','UNITED STATES','10701-5123','(914) 424-1066','NoPaymentFailure','CheckoutComplete','Other','2010-12-17 06:36:43',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ L   1 '),(3085,648681637002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','casperus','casperus67@gmail.com','Casper Mickwitz','Vironkatu 5C 39','Helsinki','Uusimaa','FINLAND','00170','358405294422','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 06:42:58',0,NULL,3,1,4,1,NULL,'ballhead  $18 \rYW863884602CN\r'),(3086,609559013001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',2,'AA2217',17.98,'hermeshine','jirin_ol','jnol@seznam.cz','Jiri Novacek','Vosmikovych 36','PRAHA 8 -  Liben','','CZECH REPUBLIC','18000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 07:25:54',0,NULL,3,1,2,1,NULL,NULL),(3087,609566330001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tmichael_br','brnstin@zahav.net.il','Michael Bernstein','12/6 Sivan street','Ashqelon','Israel','ISRAEL','78726','+972 (0) 528669438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 08:08:54',0,NULL,3,1,2,1,NULL,NULL),(3088,648716510002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','yngvillsalvesen90','yngvillsalvesen@hotmail.com','Yngvill JÃ¸lstad Salvesen','Konsul Christiansens vei 3','Kristiansand','','NORWAY','4616','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 09:53:43',0,NULL,3,1,2,1,NULL,NULL),(3089,648318853002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',5,'AE1301',48.4,'hermeshine','hellofrankcom','info@hellofrank.com','Frank Bongers','Maaltebruggestraat 194','Gent','','BELGIUM','9000','0496558558','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 10:30:53',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹  5 RR815347076CN'),(3090,648724797002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','biohazardaj','anyeloj@hotmail.com','Anyelo JimÃ©nez Boguier','Carretera General del Sur Nro. 59 2Âº Apto. 8<br>San Miguel de Abona','Santa Cruz de Tenerife','Canarias','SPAIN','38620','609166224','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 10:31:25',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1RR815347062CN\r'),(3091,648734342002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','vaskada','arhivo@yandex.ru','Vas Panov','19/4 Novoyasenevsky Str. App. 512','Moscow','','RUSSIAN FEDERATION','117593','+79266507819','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 11:14:22',0,NULL,3,1,5,1,NULL,'4ç¯å¤´ æ£š  2  æ¬§æ ‡\rCP219437425CN\r   '),(3093,706513320015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'',3.5,'hutongstore','szentandras','ambrus@szarvasnet.hu','GyÃ¶rgy Ambrus','Kisfaludy.u.17','BÃ©kÃ©sszentandrÃ¡s','BÃ©kÃ©s','HUNGARY','5561','36304594558','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 12:09:19',0,NULL,3,1,2,1,NULL,NULL),(3095,648709966002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kohav_sheifa','sheifa@ukr.net','Zhuravskaya Tatyana','Rokosovsky 10a, kv 6','Kiev','','UKRAINE','04201','0938752729','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 12:39:00',0,NULL,3,1,2,1,NULL,NULL),(3096,648766534002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','shakpitz','zilberlicht@gmail.com','Shai Zilberlicht','Yehuda Hamaccabi 2','Nahariyya','Israel','ISRAEL','22291','972-04-9825662','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 13:20:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815347155CN'),(3097,648773692002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ronggurmh','ronggur.mh@gmail.com','Ronggur Hutasuhut','Jl. Pualam Raya No.80 Rt 006/04 Kec. Kemayoran, Kel. Sumur Batu','Jakarta','Jakarta Pusat','INDONESIA','10640','081314191552','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 13:48:15',0,NULL,3,1,2,1,NULL,NULL),(3098,648774503002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','fredfmart','fredericoferreiramartins@hotmail.com','Frederico Martins','fiais','fiais','campia','PORTUGAL','3670-059','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 13:59:01',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ  L   1 RR815347147CN\r'),(3099,692846064016,260660056022,'64-LED Universal Camera Camcorder Video Light & Bracket',1,'',23.95,'hutongstore','31mirage31','fwangprc@gmail.com','Frank Wang','Van Polanenlaan 11','Capelle aan den IJssel','','NETHERLANDS','2902BX','(010) 7440494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 14:02:33',0,NULL,3,1,3,1,NULL,'64LED   1 \rRR815346455CN\r'),(3100,648783806002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','photoman19632zcg','photoman1963@hotmail.com','ryan walsh','8 chestnut lane<br>kingsnorth','ashford','Kent','UNITED KINGDOM','tn233lr','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 14:18:05',0,NULL,3,1,3,1,NULL,'ç¢—ç½©  P4  1 RR815347133CN\r'),(3103,609663002001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','razshwaizer','shwaizer@yahoo.com','Raz Shwaizer','Azar 18/9','Haifa','ID','ISRAEL','32767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 15:01:36',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³  1 '),(3104,609664535001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','inertialsensors','htatlau@gmail.com','Marcella Sunanto Laut','15 Scotts Road<br>#04-10 Thong Teck Building','default','','SINGAPORE','228218','(+65)96962956','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 15:07:52',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 RR815347120CN'),(3105,648823403002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','memitoe21','guillermoe21@yahoo.com','Guillermo Jimenez','7979 NW 21st St<br># SJO-71781','Doral','FL','UNITED STATES','33122-1630','(305) 592-7754','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-17 16:17:29',0,NULL,3,1,1,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3106,647959317002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alexx_gsm','alexx-gsm@yandex.ru','ÐÐ»ÐµÐºÑÐµÐ¹ Ð›ÑƒÐºÑŒÑÐ½Ñ‡ÐµÐ½ÐºÐ¾','Ð¡Ð²ÐµÑ‚Ð»Ð°Ñ, 9<br>Ñ€.Ð¿. Ð®Ð¶Ð½Ñ‹Ð¹','Ð‘Ð°Ñ€Ð½Ð°ÑƒÐ»','ÐÐ»Ñ‚Ð°Ð¹ÑÐºÐ¸Ð¹ ÐºÑ€Ð°Ð¹','RUSSIAN FEDERATION','656906','(3852)687555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 16:12:17',0,NULL,3,1,2,1,NULL,NULL),(3107,648850716002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 17:31:51',0,NULL,3,1,3,1,NULL,'3m æ¨ªæ†   1 RR815347337CN\r'),(3108,609718371001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3401',2.6,'hermeshine','hanei2010','hanei@walla.co.il','Hanan Pinchevsky','Amitsur Shimshon 23/7','Beer Sheva','Negev','ISRAEL','84717','0525815258','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 17:32:18',0,NULL,3,1,2,1,NULL,'430 è‚¥çš‚ç›’æŸ”å…‰ç½©   1 '),(3109,648862918002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','tropicalstormcc','christianstrevy@gmail.com','Christian Strevy','945 Castlemaine Dr','Birmingham','AL','UNITED STATES','35226-5913','(205) 447-8266','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-17 17:55:57',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹  1 '),(3110,609734591001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','guibeloto','guimaemcasa@gmail.com','Guilherme Beloto','Rua Tutoia 839 ap. 12','Sao Paulo','SP','BRAZIL','04007-004','+55 (11) 8114-8190','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 18:15:02',0,NULL,3,1,2,1,NULL,NULL),(3111,609737845001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','teeasin','cappucup@hotmail.com','Thawatchai Changesom','4/4 Loikroh Rd. Lane 3 T.Changklan','MuangChiangmai','ChiangMai','THAILAND','50100','+66818817931','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 18:18:03',0,NULL,3,1,3,1,NULL,'800w 220v ç¯æ³¡   3RR815347354CN\r '),(3112,706677285015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',26,'hutongstore','matiashalme','orders@halme.info','Matias Halme','Onkimiehenpolku 3','Valkeakoski','','FINLAND','37600','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-17 18:43:24',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815347116CN\r'),(3113,706698796015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'',6.1,'hutongstore','5346roberto','roberto.om@libero.it','Roberto Borsoi','via Don lucchinetti 10','sondrio','SO','ITALY','23100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 19:20:14',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon   1 '),(3114,648903453002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 19:23:13',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(3115,706739523015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','stressferdinand','nannyfilipe@gmail.com','ferdinand Filipe','9 levmoss Park the gallops','sandyford','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 20:34:22',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347204CN'),(3116,609798154001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','falcon_112','peter.sjoback@yahoo.se','Peter Sjoback','Sodralanggatan 21B','Oskarshamn','','SWEDEN','572 55','0491769497','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-17 20:35:18',0,NULL,3,1,3,1,NULL,'wf1003    1 RR815347195CN'),(3117,648941858002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',6,'AE1301',47.34,'hermeshine','emmity','michaelleadbetter@me.com','Michael Leadbetter','271 King Street','Newtown','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 20:50:39',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   6 RR815347181CN'),(3118,648952368002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:21:05',0,NULL,8,1,17,0,NULL,''),(3119,648956255002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:28:41',0,NULL,8,1,17,0,NULL,NULL),(3120,648957415002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alexbro_1','alex.broniewicz@swipnet.se','Alexander Broniewicz','KnektevÃ¤gen 38','SÃ¤vedalen','','SWEDEN','43369','+46-31-268669','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:29:14',0,NULL,3,1,2,1,NULL,NULL),(3121,648958724002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','puncaz','puncaz@yahoo.com','Pankaj Singh Negi','Microsoft India(R&D) Pvt Ltd<br>Microsoft campus Building 2 Gachibowli','hyderabad','Andhra Pradesh','INDIA','500032','09701649997','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 21:34:01',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\ræ¸å˜è“   1\ræ¸å˜æ©™   1 '),(3122,609824853001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','koboley','ioannis.lelakis@gmail.com','Ioannis Lelakis','Prestelandet 25a','1632 Gamle Fredrikstad','','NORWAY','1632','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 21:43:11',0,NULL,3,1,4,1,NULL,'2m x 3m èƒŒæ™¯æž¶   1 \rbackground support  $30\rYW863884661CN\r'),(3123,648952277002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 22:25:58',0,NULL,8,1,17,0,NULL,NULL),(3124,609819277001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 22:25:58',0,NULL,8,1,17,0,NULL,NULL),(3125,648955576002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-17 22:25:59',0,NULL,8,1,17,0,NULL,''),(3126,609817519001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','AU_Express','2010-12-17 22:27:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 4\råŒç¯å¤´  æ¾³æ ‡  2\råå…‰ä¼ž   2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v  2\råŒ…   2\r64LED ç¯    1\r800w 220v  ç¯æ³¡  5 \rlighting kit   $40\rYW863884705CN\r\r'),(3127,609843977001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','superpac1974','fcifuentes@iberdrola.es','IBERDROLA - FRANCISCO CIFUENTES FDEZ.','PARQUE EMPRES. CRISTALIA. EDIF.9<br>VIA DE LOS POBLADOS, 3','MADRID','Madrid','SPAIN','28033','639401224','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 22:43:30',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   2 RR815347178CN'),(3128,609005102001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','juutaa2010','juutaa@yahoo.com','Agne Gudziunaite','Molainiu 66-12','Panevezys','LT','LITHUANIA','37149','37060743307','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-17 23:00:14',0,NULL,3,1,2,1,NULL,' '),(3129,649029889002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rvaleriano','rudolphvaleriano@yahoo.com','rudolph valeriano','20929 Parthenia St<br>Apt 23','canoga park','CA','UNITED STATES','91304-6221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 01:47:39',0,NULL,3,1,1,1,NULL,NULL),(3130,649039033002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','kdou8331','kdoubt@gmail.com','Keith Doubt','626 Omar Cir','Yellow Springs','OH','UNITED STATES','45387-1420','(937) 767-1540','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 02:24:11',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3131,649066555002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','randy1982d','randy82@att.net','Randy Singleton','4351 Heron Pt','Portsmouth','VA','UNITED STATES','23703-5376','(757) 681-0221','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 04:39:56',0,NULL,8,1,17,0,NULL,''),(3132,609925131001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 05:20:37',0,NULL,8,1,17,0,NULL,NULL),(3133,609922610001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,' '),(3134,609924133001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,NULL),(3135,609923496001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 05:20:38',0,NULL,8,1,17,0,NULL,NULL),(3136,649072085002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 05:20:39',0,NULL,3,1,5,1,NULL,'58mm cpl   1\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ï¼‰   1\ré˜²å¯’ç½©    1\rNikon æ‘„å½±èƒŒå¿ƒ è€æ¬¾ L    1\rsal\rCP219437310CN\r\r\r110cm 5in1   1\rng200  \rè¿™ä¸¤ä¸ªæ˜¯æŒ‚å·å°åŒ…\r\r\r '),(3137,609931472001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vassilygr','vassily@gmx.at','Vassily Bekrodimitris','Diakou 26','Athens','','GREECE','11743','00306944362403','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 06:07:41',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347164CN'),(3138,649085471002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sarusalvadoralfredo','mattahitori@hotmail.com','SALVADOR ALFREDO DIAZ MATSUDA','NAKAGAWA-KU<br>SHOMEICHO 4-40-1','NAGOYA-SHI','Aichi','JAPAN','454-0854','08036593770','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 06:49:47',0,NULL,3,1,3,1,NULL,' RR815347252CN'),(3139,649093033002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jvarod','mix1@inter.net.il','Moshe Aron','1 Harechev street','Tel-Aviv','Israel','ISRAEL','67771','(003)537-4111','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 07:43:10',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 RR815347249CN\r'),(3140,609946534001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','icyxwindz','icyxwindz@gmail.com','Wilson Tang','543 E Arrow Hwy<br>Apt 48','Azusa','CA','UNITED STATES','91702-5774','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 07:57:43',0,NULL,3,1,1,1,NULL,NULL),(3141,649100742002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ashley86uf','ashley86@ufl.edu','Ashley Marie Reed','640 Navarre Ave','Coral Gables','FL','UNITED STATES','33134-3761','','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 08:43:24',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rå®¢æˆ·ç€æ€¥ï¼Œç­‰é‚®ä»¶çœ‹å‘ä»€ä¹ˆ\rRR815346022CN\r\r'),(3142,609957711001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mustafamaluka','maluka@gmail.com','Amina Maluka','KASTUNTIE 46','Turku','','FINLAND','20300','+358 404821614','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 09:02:30',0,NULL,8,1,17,0,NULL,NULL),(3143,609958601001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','mustafamaluka','maluka@gmail.com','Amina Maluka','KASTUNTIE 46','Turku','','FINLAND','20300','+358 404821614','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 09:06:43',0,NULL,3,1,2,1,NULL,'72mm æ©¡èƒ¶ç½©    1\r52mm æ©¡èƒ¶ç½©    1 '),(3144,706975454015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'',24.95,'hutongstore','maskare','teemu.p.saarinen@gmail.com','Teemu Saarinen','Lahdensivuntie 31 A 11','HÃ¤meenlinna','Oletus','FINLAND','13100','+358415076144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:10:25',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815347235CN'),(3145,706986325015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',2,'',7,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','KÃ¤rberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:41:42',0,NULL,3,1,2,1,NULL,NULL),(3146,609993225001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:32',0,NULL,8,1,17,0,NULL,NULL),(3147,609996750001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:32',0,NULL,8,1,17,0,NULL,NULL),(3148,609993479001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'',35,'hermeshine','matteaster','measterby@msn.com','Matt Easterby','MS L9, Waterfront Place<br>1 Eagle Street','Brisbane','Queensland','AUSTRALIA','4000','0732187044','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 11:45:33',0,NULL,3,1,3,1,NULL,'40cm æ£š   1\rå€’å½±æ¿   1\r800w 220v  ç¯æ³¡  5 RR815347345CN\r'),(3149,609999557001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','julian-starr','julian@minervafilm.dk','Julian Andersen','Baldersgade 6','Copenhagen N','','DENMARK','2200','35821133','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-18 11:56:09',0,NULL,3,1,2,1,NULL,'NG128   1 '),(3150,649144248002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 12:02:01',0,NULL,8,1,17,0,NULL,''),(3151,649152427002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','phantomphoto1983','phantom-tv@mail.ru','Andrey Kozlov','Boicovaia ulica, dom 6, korpus 1, kv. 9','Moskva','Moskovskaia oblast','RUSSIAN FEDERATION','107370','+79264316069','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:14:16',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹   1 '),(3152,649152075002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 12:18:12',0,NULL,8,1,17,0,NULL,'\r'),(3153,610011586001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','knetebol','knetebol@hotmail.com','M.Gerritsen','Castorweg 298','Hengelo ov','','NETHERLANDS','7557KS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:44:07',0,NULL,8,1,17,0,NULL,NULL),(3154,610011499001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','knetebol','knetebol@hotmail.com','M.Gerritsen','Castorweg 298','Hengelo ov','','NETHERLANDS','7557KS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:44:08',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  canon   2 '),(3155,649161775002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','brda1986','hrvoje.bakovic@gmail.com','hrvoje bakoviÄ‡','dracevac 80b','split','','CROATIA','21000','+385 95 9106383','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 12:49:44',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3156,707020891015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','grahamslist','doorcare.systems@ntlworld.com','graham smith','4.saffron close','barrowford','Lancashire','UNITED KINGDOM','bb9 6dl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-18 13:20:50',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  S1   1 '),(3157,610043823001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','enlisette','lis1_svensson@hotmail.com','Lisette Svensson','EksjÃ¶gatan 31','JÃ¶nkÃ¶ping','JÃ¶nkÃ¶ping','SWEDEN','554 54','0046704489953','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:28:33',0,NULL,3,1,2,1,NULL,' '),(3158,647002932002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','klaudiapolec88','klaudiapolec@interia.pl','Klaudia Stawiarska','Apt.1 Chapel Court,<br>Cathedral Place','Limerick','Limerick','IRELAND','061','873211433','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:41:42',0,NULL,3,1,2,1,NULL,'ä¸‰è§’åŒ…  canon  1 '),(3159,610050494001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','yamila02','irvisp@gmail.com','Irvis Y PagÃ¡n','319 Calle Tampa<br>San Gerardo','San Juan','PR','PUERTO RICO','00926-3433','','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 14:48:23',0,NULL,3,1,3,1,NULL,'RR815347986CN\r'),(3160,649200596002,120339084231,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hermeshine','3080stewart','djstewart01@tiscali.co.uk','derek stewart','50 acredales<br>haddington','east lothain','East Lothian','UNITED KINGDOM','eh41 4nu','01620825416','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2010-12-18 14:49:03',0,NULL,3,1,2,1,NULL,'90th è‚©å¸¦  1 '),(3161,609943438001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',9,'AA1204',13.91,'hermeshine','go6maidee','go6maidee_k@hotmail.com','Supakit  Jirawanidchakorn','949/137  Sathu58  Bangpongpang  yannawa','Bangkok','Bangkok','THAILAND','10120','66855059444','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:55:56',0,NULL,3,1,3,1,NULL,'çƒ­é´ç›–   9 \rRR815346331CN\r'),(3162,610052372001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','emil_akhmadi','akhmadistudio@gmail.com','Emil Akhmadeev','Khimikov, dom 27, kv. 59','Kazan','Tatarstan','RUSSIAN FEDERATION','420085','+79046668659','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 14:57:21',0,NULL,3,1,2,1,NULL,NULL),(3163,609941553001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 15:09:35',0,NULL,8,1,17,0,NULL,NULL),(3164,609940344001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT007',130,'hermeshine','auchorhing','we168168@hotmail.com','Albert Chor Hing Au','21 Drawbridge Drive','Markham','ON','CANADA','L6C 2B3','(416) 618-1588','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 15:09:35',0,NULL,3,1,5,1,NULL,'800w çº¢å¤´ç¯   1\r800w 110v ç¯æ³¡   1\r2.8m å¼¹ç°§ ç¯æž¶   1 \r2m ç¯æž¶  1\ræ–œè‡‚   1\rCP219437354CN\rCP219437345CN\r\r'),(3165,707068437015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'',26.56,'hutongstore','25bell25','ebell@anglianwater.co.uk','Emma Bell','219 Four Chimneys Crescent','Peterborough','Cambridgeshire','UNITED KINGDOM','Pe7 8JQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-18 15:17:45',0,NULL,3,1,3,1,NULL,'RR815347221CN '),(3166,649245180002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','macgarys','macgary@gmail.com','Edgar Pedroza','435 Hackberry Dr','Rockwall','Tx','UNITED STATES','75087-6778','(214) 228-1807','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 16:47:25',0,NULL,8,1,17,0,NULL,NULL),(3167,610095110001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','macgarys','macgary@gmail.com','Edgar Pedroza','435 Hackberry Dr','Rockwall','Tx','UNITED STATES','75087-6778','(214) 228-1807','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 16:47:25',0,NULL,3,1,1,1,NULL,'77mm é•œå¤´ç›–  canon  1\r58mm é•œå¤´ç›– canon   1 '),(3168,649268304002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','sw-cheif','dmack1974@gmail.com','Dennis McDowell','26360 Girard St','Hemet','CA','UNITED STATES','92544','(951) 658-1743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 17:38:16',0,NULL,3,1,1,1,NULL,NULL),(3169,649285183002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bhaskar1020','bhaskar1020@yahoo.com','Bhaskar Pandya','300 hartwell st','Fall RIver','MA','UNITED STATES','02721-2912','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 18:15:41',0,NULL,3,1,1,1,NULL,NULL),(3170,649356409002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jken7958','kennedymary@rogers.com','John Kennedy','219 Tamarac Trail','Aurora','ON','CANADA','L4G 5W2','(905) 727-3027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 20:42:05',0,NULL,3,1,2,1,NULL,NULL),(3171,610244667001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',8.9,'hermeshine','madcom1138','alexdumani@gmail.com','alex dumani','Cdla. Los Almendros Mz. A Villa 18','Guayaquil','Guayas','ECUADOR','EC090114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-18 22:35:28',0,NULL,3,1,2,1,NULL,'canon è‚©å¸¦  çº¢å­— logo   1 '),(3172,649401381002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','reywas92','dlsmorgan@att.net','David Morgan','10846 Hamilton Pass','Fishers','IN','UNITED STATES','46037-9494','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 22:41:54',0,NULL,3,1,1,1,NULL,NULL),(3173,610248035001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',59,'hermeshine','bahrialtay10','altaybahri@hotmail.com','Bahri Altay','Veliefendi mah. Saha Yolu No:22 Celik apt. k:2 d:4<br>zeytinburnu','istanbul','','TURKEY','34025','0212 547 59 01','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 22:52:09',0,NULL,8,1,17,0,NULL,NULL),(3174,649403646002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','bahrialtay10','altaybahri@hotmail.com','Bahri Altay','Veliefendi mah. Saha Yolu No:22 Celik apt. k:2 d:4<br>zeytinburnu','istanbul','','TURKEY','34025','0212 547 59 01','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-18 22:52:09',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶   2\r4ç¯å¤´ æ£š   æ¬§æ ‡   2 \r4338\rCP219437385CN\r'),(3176,649409863002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','randy1982d','randy82@att.net','Randy Singleton','4351 Heron Pt','Portsmouth','VA','UNITED STATES','23703-5376','(757) 681-0221','NoPaymentFailure','CheckoutComplete','Other','2010-12-18 23:08:05',0,NULL,3,1,4,1,NULL,'sony èƒŒå¿ƒ xxxl   1 \rsony èƒŒå¿ƒ xxl   1 \rphoto vest  $22\rYW863884650CN\r'),(3177,649419492002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','lenaokh','lena.okhman@gmail.com','Yelena Okhman','5750 Olohena Rd<br># M','Kapaa','HI','UNITED STATES','96746-8808','(949) 395-1871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-18 23:40:13',0,NULL,8,1,17,0,NULL,NULL),(3178,610262201001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lenaokh','lena.okhman@gmail.com','Yelena Okhman','5750 Olohena Rd<br># M','Kapaa','HI','UNITED STATES','96746-8808','(949) 395-1871','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-18 23:47:04',0,NULL,3,1,1,1,NULL,' 77mm CPL+ND8+Macro+8 +Gradual grey+filter case 1\r52mm æ©¡èƒ¶ç½©   1'),(3179,649427627002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','franconialocal','franconialocal@hotmail.com','Chris Fowler','PO Box 151','Franconia','NH','UNITED STATES','03580-0151','(603) 616-7171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:10:30',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3180,649431044002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeannie16452','stevenson519@comcast.net','JEANNIE STEVENSON','16452 Lakeside Dr','LOCKPORT','IL','UNITED STATES','60441-7024','(815) 325-4750','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:25:12',0,NULL,3,1,1,1,NULL,NULL),(3181,693612210016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','mumby33','graham.mumby-croft@ntlworld.com','Graham Mumby-Croft','15 Thirsk Drive, North Hykeham','Lincoln','Lincolnshire','UNITED KINGDOM','LN68SZ','01522889993','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-19 00:30:58',0,NULL,3,1,2,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–   1 '),(3182,610276898001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','taras2376','taras.ebay@glek.net','Taras Glek','411 NW 231st Ave','Hillsboro','OR','UNITED STATES','97124','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 00:37:25',0,NULL,3,1,1,1,NULL,NULL),(3183,649460860002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dede0301','tardif.saulnier@videotron.ca','Andre Tardif','1345 Place du Titanic','Ville Sainte-Catherine','QC','CANADA','J5C 1T8','(450) 632-8713','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 02:40:53',0,NULL,3,1,2,1,NULL,NULL),(3184,609766693001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','richandranda','rich@rt2inc.com','Richard Taylor','10 Briarwood Ct','Warrenton','MO','UNITED STATES','63383-1056','(702) 239-1656','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 03:06:22',0,NULL,3,1,1,1,NULL,NULL),(3185,610328369001,110566021597,'New YN Flash Battery Pack SF-17 Canon Flash 580EX CP-E4',2,'AB3313',82.98,'hermeshine','dewiedbw','dewiedbw@yahoo.com','Bennie Watson','5010 Interstate 10 E','San Antonio','TX','UNITED STATES','78219','(210) 216-4865','NoPaymentFailure','CheckoutComplete','Other','2010-12-19 04:56:49',0,NULL,3,1,1,1,NULL,'sf17 canon   2 '),(3186,649507498002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','campster456','leecam@internode.on.net','Mrs Lee Camporeale','8 Inverness Avenue','St Georges','South Australia','AUSTRALIA','5064','0883795838','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 07:01:54',0,NULL,3,1,4,1,NULL,'717 180cm    1\rtripod $30 \rYW863884646CN\r'),(3187,649512793002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',3,'AKT049',105,'hermeshine','ostrenok','lostrenok@gmail.com','Leonid Ostrenok','Yunnatov street 3-28','Khimki','Moscow region','RUSSIAN FEDERATION','141400','7-985-773-9420','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 07:38:50',0,NULL,3,1,5,1,NULL,'115w 220v   6 \r2111g\rCP219437399CN\r'),(3188,610378983001,110533632545,'New Timer Remote Control for Sony a100 a200 a300 a350',1,'AA3223',48,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:12',0,NULL,8,1,17,0,NULL,NULL),(3189,649541913002,120454219798,'Green.L 55mm Neutral Density ND4 Filter ND 4 55',1,'AE2302',6.5,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:12',0,NULL,8,1,17,0,NULL,NULL),(3190,649541840002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','dmitryv43','dmitry_v43@mail.ru','Dmitry Vikharev','36 Drelevsky street, app.29','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610020','+7(922)6621400','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 09:55:13',0,NULL,3,1,3,1,NULL,'MC-S1   1\r55mm ND4   1\r58mm ND8   1 \rRR815346464CN\r'),(3191,610385798001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','to_dimitry','dimitry.p@hotmail.com','Dmitry Pishchagin','Boitsovaya str, 18-12, kv. 59','Moscow','','RUSSIAN FEDERATION','107150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 10:06:32',0,NULL,3,1,2,1,NULL,NULL),(3192,610408399001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:56',0,NULL,8,1,17,0,NULL,NULL),(3193,610408171001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:57',0,NULL,8,1,17,0,NULL,NULL),(3194,649571356002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5,'hermeshine','mlc15','kossowsk@math.sc.edu','marek b. kossowski','103 Bruton Dr','chapel hill','NC','UNITED STATES','27516-9222','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:13:56',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1\rä¸­å·å†…èƒ†åŒ…  æ— å­—  1\r52mm é•œå¤´ç›– NIkon   2 '),(3195,649575230002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceb997','felisabros@yahoo.com','Felisa Brothers','7457 Gallant Road','Gallant','AL','UNITED STATES','35972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:22:50',0,NULL,8,1,17,0,NULL,NULL),(3196,649574876002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceb997','felisabros@yahoo.com','Felisa Brothers','7457 Gallant Road','Gallant','AL','UNITED STATES','35972','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 11:22:51',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›– canon   2 '),(3197,649559425002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','00420-608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:26:56',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹  1 '),(3198,649581119002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 11:49:08',0,NULL,8,1,17,0,NULL,''),(3199,649582345002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','misterohlsson','mistero@live.se','Anders Ohlsson','AnanasvÃ¤gen 5','JÃ¤rfÃ¤lla','Stockholm','SWEDEN','175 49','+4687391691','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:49:09',0,NULL,3,1,4,1,NULL,'80cm 2in1  åå…‰æ¿   1 \r2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rä¸€ç¥¨ä¸¤ä»¶   light stand  $22\rYW863884635CN\r'),(3200,649588511002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','ripleycats','m_brewis@sky.com','Michelle Brewis','20 Allchurch Drive','Ashington','Northumberland','UNITED KINGDOM','NE63 9EQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 11:59:08',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1 '),(3201,648573797002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','floy.123','floysele@floysele.jazztel.es','Fernando Loysele Gomez','Laguna Negra  13 Portal G 2ÂºA','Madrid','Madrid','SPAIN','28030','608604749','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-19 12:03:06',0,NULL,3,1,4,1,NULL,'6662a   1 \rtripod  $15\rYW864144103CN\r'),(3202,610433994001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','ramcoror1989','ramcoror89@gmail.com','Î¡Î±Î¼Î±Î´Î¬Î½ ÎŸÎ³Î»Î¿Ï Î¡Î±Î¼Î±Î´Î¬Î½','Î£Î±Ï€Î±Î¯Ï‰Î½ 42, Î . Î§ÏÏÏƒÎ±','ÎžÎ¬Î½Î¸Î·','GU','GREECE','67100','00306979437839','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 12:21:41',0,NULL,3,1,2,1,NULL,'æŸ”å…‰ä¼ž  2 '),(3203,610446342001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','vonkuba','jakub.dabrowski@gmail.com','Jakub Dabrowski','Zeeburgerkade 762','Amsterdam','','NETHERLANDS','1019HT','+31614870495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 12:53:18',0,NULL,3,1,2,1,NULL,NULL),(3205,649617981002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','hemeroskopion','ewi@telefonica.net','Olaf Speier','Avenida 9 de Octubre, 9, 1Âº B<br>Residencial El Tossalet','Polop de la Marina','Comunidad Valenciana','SPAIN','03520','637101199','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 13:15:17',0,NULL,3,1,3,1,NULL,'cåž‹å¤¹   2 RR815347218CN\r'),(3206,610461312001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','siriwatj','siriwatj@gmail.com','Siriwat Jithunsa','116 Soi. Moo Baan Suannakarin 1<br>Srinakarin Road, Nongborn','Pravej','Bangkok','THAILAND','10250','+668 1619 1976','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 13:30:02',0,NULL,3,1,11,1,NULL,'\r'),(3207,649634363002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mr2004','cmohanr@hotmail.com','Mohan Chennareddy','167 Rockview','Irvine','CA','UNITED STATES','92612-3239','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 13:57:58',0,NULL,3,1,1,1,NULL,NULL),(3244,650121869002,120564178883,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:33:15',0,NULL,8,1,17,0,NULL,NULL),(3208,610477766001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','ikupi','ivan@inode.nl','Ivan Kupi','2e octaviolaan 36','Capelle aan den IJssel','','NETHERLANDS','2909 RC','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 14:08:45',0,NULL,3,1,3,1,NULL,'1.6m x 2.1m èƒŒæ™¯å¸ƒ  2\ré»‘è‰²ï¼Œ è“è‰²  RR815347323CN\r'),(3209,649649413002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','boerkejos','bjorn.pira@skynet.be','Pira BjÃ¶rn','Nieuwstraat 33<br>3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815347306CN\r'),(3211,649670925002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ffhend26','bwh02@hotmail.com','Brian Harris','1142 Spottswoode St','Henderson','NV','UNITED STATES','89002-3387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 15:13:06',0,NULL,3,1,1,1,NULL,NULL),(3212,610385380001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',148.2,'hermeshine','trivantan','trivan_tan@hotmail.com','Tan Kian Wee','Blk 484 Admiralty Link #10-65','default','','SINGAPORE','750484','97697369','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 15:13:13',0,NULL,3,1,6,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ é»„ ç™½  ï¼‰   1 \r2m ç¯æž¶  2\rå•ç¯å¤´  è‹±æ ‡   2\råå…‰ä¼ž   2\ræ–°åŠ å¡EMS\rEX000455038SG\r'),(3213,649699994002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','paulonorton','paulonorton@hotmail.com','antonio severino lopes paulo','rua ricardo espirito santo lt 9 3Âº dt<br>2615-677 sobralinho','vila franca de xira','lisboa','PORTUGAL','2615-677','0031934357900','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 16:09:27',0,NULL,3,1,4,1,NULL,'tripod  $15 \ræ–°åœ°å€ï¼š \rAntonio Severino Lopes Paulo\rSaint-Gobain. PAM\restrada nacional 1 km 38\r2580-381-Alenquer\rPortugal\r0031934357900\rYW863600142CN\r\r'),(3214,610555813001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',9.9,'hermeshine','lifishort','cookcarol52@aol.com','Carol Cook','6 S Laflin St<br>Apt 803','chicago','IL','UNITED STATES','60607-2443','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 16:44:23',0,NULL,3,1,1,1,NULL,'nikon è‚©å¸¦   1\ré»„å­—   '),(3215,649746558002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 17:21:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  3\rbåº§   3\ræŸ”å…‰ä¼ž   3 \rlight stand   $30\rYW863884672CN\r'),(3216,649763841002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0024',20.99,'hermeshine','alisss54','gamal4ml@yahoo.com','Ali','Pbox:22162,Sana\'a,Yemen','Sana\'a','sheraton/sana\'a/sana\'a','YEMEN (REPUBLIC OF)','YEM','+967-711553355','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 17:46:25',0,NULL,3,1,3,1,NULL,'canon d1 å•è‚©åŒ…    1 RR815347297CN'),(3217,610618836001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','manateepup','onthelargesideofaverage@hotmail.com','neil tadman','12 Hillmore Court<br>32 Belmont Hill','London','London','UNITED KINGDOM','SE13 5AZ','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 18:12:25',0,NULL,3,1,2,1,NULL,'717å¿«è£…æ¿   1 '),(3218,610667832001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','snakeke','marek.janicko@gmail.com','Marek Janicko','Wurmova 6','Kosice','','SLOVAK REPUBLIC','04023','+421905181816','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:07:45',0,NULL,3,1,2,1,NULL,' '),(3219,610664564001,110486687213,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','joancarm','joamac@gmail.com','JUAN MASSEGUR CASANOVA','C/TILÂ·LER NÂº11','OLOT','CataluÃ±a','SPAIN','17800','972272527','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:11:05',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(3220,610675957001,110454864267,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',7.89,'hermeshine','kobiavr69','kobiavraham69@yahoo.com','kobi avraham','Ben Hur 4/12<br>Em Hamoshavot','Petach Tikva','','ISRAEL','49063','+972578124269','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 19:17:04',0,NULL,3,1,3,1,NULL,'æ— å­—è‚©å¸¦   1 RR815347283CN'),(3221,649870594002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','factorandrey','anpetrov2@gmail.com','Andrey Petrov','Mayskiy bulvar 28, Apt.7','Kursk','','RUSSIAN FEDERATION','305038','7 471 2515545','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-19 19:50:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815347270CN\r'),(3222,707874623015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','psvehv82','teunehv@kunen.nl','Ton Kunen','Boschdijk 275','EINDHOVEN','','NETHERLANDS','5612HD','0647312898','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-19 19:57:27',0,NULL,3,1,3,1,NULL,'1.6x3m èƒŒæ™¯å¸ƒ   ç™½è‰²   1 \r484\rRR815347782CN\r'),(3223,707882781015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','170jazmin','bobnield@aol.com','Robert Nield','5 Belle Vue Road','Exmouth','Devon','UNITED KINGDOM','EX8 3DR','01395279537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-19 20:05:16',0,NULL,3,1,3,1,NULL,'115w 220v    2 RR815347266CN\r'),(3224,610741331001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','jimmilligan1','jimmilligan1@aol.com','Jim Milligan','10 ROWANBANK GARDENS<br>BROUGHTY FERRY','DUNDEE','ANGUS','UNITED KINGDOM','DD5 2JW','07540839018','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 20:46:18',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  1\r58mm çŽ¯æž¶   1 '),(3225,610758035001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','truhlar_enterprise','truhlardc@sbcglobal.net','Jonathan A. Truhlar','1413 Sherborn Court South','Minooka','IL','UNITED STATES','60447-4569','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 21:13:21',0,NULL,3,1,1,1,NULL,'å“èƒœ 3.0   1 '),(3227,610761426001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','gcc_20050','kep_numberg@yahoo.com','Kompusel Bilgisayar','Talatpasa Blv. No: 66 Palandoken Apt. Daire: 1<br>Alsancak','Izmir','','TURKEY','35220','905367739884','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 21:22:21',0,NULL,3,1,2,1,NULL,'55mm uv    1 \r '),(3229,649794127002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','juancodo','jic@codoneralonso.com','Juan Ignacio CodoÃ±er','C/ Colombia, 14','Majadahonda','Madrid','SPAIN','28220','678246037','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 22:33:29',0,NULL,3,1,2,1,NULL,NULL),(3230,610800409001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','domins-tigra','domins_1723@hotmail.com','Domingo Javier LÃ³pez HernÃ¡ndez','C/ Arrieros NÂº5, Albox','AlmerÃ­a','AndalucÃ­a Ceuta y Melilla','SPAIN','04800','669083058','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-19 22:55:55',0,NULL,3,1,2,1,NULL,' '),(3231,610802564001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','darrensbabe','dhollis0510@san.rr.com','Brandi Hollis','13333 Caminito Ciera<br>Unit 100','San Diego','CA','UNITED STATES','92129-4048','(858) 484-8461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-19 23:01:44',0,NULL,3,1,1,1,NULL,' '),(3232,610829860001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',75,'hermeshine','zskyejb','zoe_sjb@hotmail.com','Zoe Barton','8 Wragge Pl','Florey','Australian Capital Territory','AUSTRALIA','2615','0403506520','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2010-12-20 00:38:30',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶  1 \rreflector holder   $20\rYW863884624CN\r'),(3233,650018001002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','mirsec','harvestcreations@hotmail.com','Miranda Mirsec','4301 E 3rd St','Long Beach','CA','UNITED STATES','90814-2920','(562) 706-0032','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 01:16:20',0,NULL,3,1,1,1,NULL,NULL),(3234,650025180002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','klynch315','kalynch315@aol.com','Kristina Lynch','5116 Leon St','Oceanside','CA','UNITED STATES','92057-3647','(760) 721-2580','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 01:40:17',0,NULL,3,1,1,1,NULL,NULL),(3235,649171171002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',74.3,'hermeshine','m_jodie1984','m_jodie@hotmail.com','jodie mills','3 Silvabank Drive<br>varsity lakes','Gold Coast','Queensland','AUSTRALIA','4227','0755753698','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 01:55:24',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \rlight kit  $22\rYW863884613CN\r'),(3236,650034769002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','bolla6772','bollaj85@hotmail.com','Jerry Bolla','1416 Broadway','highland','IL','UNITED STATES','62249','(618) 580-9867','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-20 02:06:34',0,NULL,3,1,1,1,NULL,NULL),(3237,650039671002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','lonelobo13','amoellendorf@gvtc.com','Joe Moellendorf','206 Live Oak Pass','Boerne','TX','UNITED STATES','78006-8533','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:22:06',0,NULL,3,1,1,1,NULL,NULL),(3238,650044964002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:39:17',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—   1 '),(3239,650050223002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','claudiasa17','claudia_saucedo17@yahoo.com','claudia saucedo','406 Laurie Ln','billings','MT','UNITED STATES','59105-3924','(406) 208-4170','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 02:58:32',0,NULL,3,1,1,1,NULL,NULL),(3240,694339835016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','glamboyitalia','info@glamboy.com','BRIGNOLI LUCA','GARIBALDI,22','MORENGO','BG','ITALY','24050','3887437467','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-20 03:07:03',0,NULL,8,1,17,0,NULL,'\r'),(3241,708081020015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','glamboyitalia','info@glamboy.com','BRIGNOLI LUCA','GARIBALDI,22','MORENGO','BG','ITALY','24050','3887437467','NoPaymentFailure','CheckoutIncomplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r1.6m x 3m ç™½è‰²èƒŒæ™¯å¸ƒ\r2mç¯æž¶  2\r50-70æ£š   2 æ¬§æ ‡  \r115w 220v  2\råŒ…   1 \rlighting kit  $32\rYW863884694CN\r'),(3242,650067402002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','wabenet73','wabenet@yahoo.com','Joe Wabe','Buk-gu, Young Bong Dong<br>1350-4 Young Bong Parkville #202','Gwangju','Jeollanamdo','KOREA,REPUBLIC OF','500-845','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 03:59:17',0,NULL,3,1,2,1,NULL,NULL),(3243,610911719001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','holoboss','office@holograms.bc.ca','Derek Galon','887 Walfred Rd.','Victoria','BC','CANADA','v9c2p1','(250) 380-2031','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 06:44:17',0,NULL,3,1,2,1,NULL,' '),(3245,610935172001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:33:16',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©   1\rND8   1 '),(3246,610935943001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',3,'',23.7,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:34:54',0,NULL,8,1,17,0,NULL,NULL),(3247,650122644002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Kazankov Valery','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+375447127692','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:37:18',0,NULL,3,1,3,1,NULL,'wf1005   1\r800w  220v   3 \rRR815347779CN\r'),(3248,650123247002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AE2301',8.55,'hermeshine','corypelican','corypelican@gmail.com','Cory Morris','P.O. Box 437 Annerley','Brisbane','Queensland','AUSTRALIA','4103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 09:45:16',0,NULL,3,1,2,1,NULL,'ç»¿å¶çš„ 72mm æ¸å˜ç°   1 '),(3249,694426320016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','standford26','gberbielae@hotmail.com','Guillermo Berbiela Esteve','Paseo de Lazkano, nÂº 14','Donostia - San Sebastian','Guipuzcoa','SPAIN','20009','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 10:10:58',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3250,650129611002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','holistichealth','drnyvlt@hotmail.com','Pavel Nyvlt','Masarykovo nam.175','Podivin','','CZECH REPUBLIC','69145','(420) 739-4428 ext.: 66','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 10:16:08',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž   1 \rRR815347853CN\r'),(3251,650131157002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3302',55.99,'hermeshine','vess1vis2','chichkow@yahoo.com.au','Vesselin Chichkov','Unit 2  Block 1    50 Belomorski Prohod St<br>Lozenec','SOFIA','','BULGARIA','1407','35929672642','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 10:23:03',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯ æŸ”å…‰æ£š   1\rRR815346053CN\r '),(3253,708181941015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','the_hippo14','ray.sievey@ntlworld.com','Ray Sievey','10 Belcroft Close','Bromley','Kent','UNITED KINGDOM','BR1 3TL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 11:10:20',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³ 1 '),(3256,708196357015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'',11.47,'hutongstore','ferrierknight','bbarnett@fsmail.net','Bill Barnett','47 Oakleigh Drive','Swaffham','Norfolk','UNITED KINGDOM','PE37 7AJ','01760336076','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 12:06:32',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  c1   1 '),(3257,610968034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','greenbongo','rdcw@comcast.net','Robert Wynn','36 Windmill Dr','Clementon','NJ','UNITED STATES','08021-5821','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 12:18:08',0,NULL,3,1,1,1,NULL,NULL),(3258,650164356002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','joseluis9131','afrogm@gmail.com','Jose Luis Ruiz Gonzalez','Villa de Marin, 3 (8-1)','MADRID','Madrid','SPAIN','28029','913140971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 13:03:10',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(3259,610988211001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','central_bay','kolodin@gmail.com','Oleg Kolodin','1200 N Queen St<br>Apt 339','Arlington','VA','UNITED STATES','22209-3312','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 13:51:34',0,NULL,3,1,1,1,NULL,NULL),(3261,650184394002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','bootje1974','corne@agrios.nl','Corne Boogaard','Zandbergsestraat 5','Graauw','','NETHERLANDS','4569TC','(06)55190592','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 14:26:13',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§  1\ræŸ”å…‰ä¼ž    RR815347765CN\r'),(3262,611001284001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','svejnozka','spcomposit@centrum.cz','Patrik Svejnoha','Elektrarenska 9','Prague 10','Czech Republic','CZECH REPUBLIC','101 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 14:43:49',0,NULL,8,1,17,0,NULL,NULL),(3263,611001296001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','svejnozka','spcomposit@centrum.cz','Patrik Svejnoha','Elektrarenska 9','Prague 10','Czech Republic','CZECH REPUBLIC','101 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 14:43:49',0,NULL,3,1,2,1,NULL,'52mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   1 '),(3264,611005614001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','evelintamm','evelintamm@hot.ee','Evelin Tamm','Suurevalja tee 3','Saue','HARJUMAA','ESTONIA','76506','3725064557','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 15:10:26',0,NULL,3,1,2,1,NULL,' 803g'),(3265,694512914016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'',32.99,'hutongstore','lovezri','loryas@yahoo.com','Carlos Rivera','Urb. San Luis 500 Calle Valcarcel Apt. 17-H','San Juan','PR','UNITED STATES','00923','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 15:37:38',0,NULL,3,1,1,1,NULL,'sf18- canon   1 '),(3267,650202973002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','chicago1924','peter@kadisnet.se','Peter BodÃ©n','Kaddisvagen 42','905 92 Umea','Vasterbottens Lan','SWEDEN','....','4690148050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 16:06:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   æ¬§æ ‡   1\råå…‰ä¼ž   1 \rRR815347840CN\r'),(3268,650219833002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64,'hermeshine','pampolo','valerio.vella@email.it','valerio vella','Via S.Andrea Avellino n.15','MESSINA','ME','ITALY','98122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 16:33:04',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  1\r800w  220v ç¯æ³¡   1\rlight  $22 \rYW864143845CN\r'),(3269,611030264001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','alkhwaaa','ali.alkhwaldi@gmail.com','Ali Alkhwaildi','Alkatib Street<br>P.O Box 936','Safwa','Eastern Province','SAUDI ARABIA','31921','00966504815264','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 16:34:41',0,NULL,5,1,18,0,NULL,''),(3271,650217397002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','travellikesound','andreathornton@gmail.com','Andrea Thornton','1750 S 900 W<br>Ste A','Salt Lake City','UT','UNITED STATES','84104-1715','(801) 230-7108','NoPaymentFailure','CheckoutComplete','Other','2010-12-20 16:44:34',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚   1\r50-70 æ£š   1 \rlight kit  $22\rYW863884716CN\r'),(3272,648753666002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bugy051','bugy111@net.hr','Matija Mavrinac','Kostrenskih boraca 19','kostrena','Kostrena','CROATIA','51221','0959059782','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 18:06:06',0,NULL,3,1,2,1,NULL,NULL),(3273,694580723016,260660051651,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D S',1,'',5.5,'hutongstore','jackpot68','marinaqb@hotmail.com','Marina Queralto Bartres','Mejia Lequerica 18, ent-4a','Barcelona','CataluÃ±a','SPAIN','08028','696808928','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 18:36:56',0,NULL,3,1,2,1,NULL,'CANON ä¸­å·å†…èƒ†åŒ…   1 '),(3274,611077212001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','domnicmicallef','micallefdomnic@gmail.com','Domnic Micallef','Villa Sandrigam,Sir Ugo Mifsud Strt.','Ta Xbiex','','MALTA','0000','77438995','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 18:40:49',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3275,650268506002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','marzocchi_man','hurdj@rogers.com','Wendy Hurd','1180 Ewart Street','Lefroy','ON','CANADA','L0L 1W0','(705) 456-4707','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 18:47:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815347822CN\r'),(3276,650275380002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','simon182','simon.roseblade@fallon.com','SIMON ROSEBLADE','1772 Dupont Ave S','MINNEAPOLIS','MN','UNITED STATES','55403-3065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 19:02:45',0,NULL,3,1,1,1,NULL,NULL),(3277,610939507001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','erkangunes39','erkangunes@sabanciuniv.edu','Erkan Gunes','Sabanci University<br>Orhanli Beldesi, Tuzla','Ä°stanbul','','TURKEY','34956','+90 535 599 7639','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 19:55:21',0,NULL,3,1,3,1,NULL,'tripod  $15 \rYW864144092CN\ræ¢æˆå°åŒ…æŒ‚å·\rRA014139322CN\r'),(3278,650299444002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','usafchick14','amber.scaife@yahoo.com','amber scaife','1730a dodson st','kailua','HI','UNITED STATES','96734-5127','(386) 503-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-20 19:56:06',0,NULL,3,1,1,1,NULL,NULL),(3279,611088651001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ucoome','mfsebuktekin@gmail.com','FURKAN SEBUKTEKIN','LIMAN MAH.CAMGUZELI SK.<br>DAMLA AP.1623','SAMSUN','TR','TURKEY','55100','+905333091749','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 20:40:50',0,NULL,3,1,2,1,NULL,' '),(3280,708403133015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','tamaradarko','darknula@gmail.com','Tamara Jurca','Zoology department Trinity college Dublin','Dublin','Dublin','IRELAND','2','0861622773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 20:51:52',0,NULL,8,1,17,0,NULL,''),(3281,708404653015,250599414645,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'',4.8,'hutongstore','tamaradarko','darknula@gmail.com','Tamara Jurca','Zoology department Trinity college Dublin','Dublin','Dublin','IRELAND','2','0861622773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 20:57:13',0,NULL,3,1,2,1,NULL,'77mm nd8   1 \r450D çœ¼ç½©   1 '),(3282,650329648002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','primulaed','primula@i.ua','Marina Senchenko','Bulvar Perova 23, 72','Kiev','','UKRAINE','02218','0969393100','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 21:10:24',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3283,611144367001,110471764884,'i-TTL Flash for Nikon D60 D90 D5000 D3000 D300s D700 D3',1,'AB3301',80,'hermeshine','2010fakkar','trond.v43@gmail.com','TROND VOLDSTAD','Ã…SLYVEIEN 7H','SEM','Vestfold','NORWAY','3170','004793683146','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 21:25:03',0,NULL,3,1,3,1,NULL,'æ°¸è¯º YN465  Nikon   1 \rRR815347972CN\r'),(3284,708424029015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'',5.64,'hutongstore','cookie_yum','ninjabat@hotmail.com','Andrew Steele','7 Bridle Close','St. Albans','herts','UNITED KINGDOM','AL3 5HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-20 21:34:58',0,NULL,3,1,2,1,NULL,NULL),(3285,708163958015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','chucky210503','chucky210503@mailcan.com','Ken Griffin','114 Monvoy Valley Tramore','Co.','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-20 21:41:26',0,NULL,3,1,2,1,NULL,NULL),(3286,650357324002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','enyuco','joanvendrell@gmail.com','Joan Vendrell Marce (Estanco)','Passeig Esglesia, 3-5','Begues','CataluÃ±a','SPAIN','08859','615574197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 22:31:17',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(3287,650366146002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','quarter8','sheerecstasy@gmail.com','Yuinping C','Block 114 #03-696<br>Teck Whye Lane','default','Singapore','SINGAPORE','680114','8222 9318','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-20 23:04:11',0,NULL,3,1,11,1,NULL,NULL),(3288,650376956002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','thrais','valentinkelemen@rogers.com','Valentin Kelemen','50 Cedarhurst Drive','Richmond Hill','ON','CANADA','L4S 1B5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-20 23:45:45',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815347836CN\r'),(3289,650382042002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','gabriel4688','gabrielgalarza007@hotmail.com','gabriel galarza','4 Columbus Pl<br>Fl 2','bound brook','NJ','UNITED STATES','08805-1902','','NoPaymentFailure','CheckoutComplete','Other','2010-12-21 00:09:00',0,NULL,3,1,1,1,NULL,'canon èƒŒå¿ƒ m   1 '),(3290,611193094001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','autumn_mi','autumn_bagley@yahoo.com','Autumn Bagley','3322 W Stanley Rd','Mount Morris','MI','UNITED STATES','48458-9408','(810) 964-7533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 00:29:25',0,NULL,3,1,1,1,NULL,NULL),(3291,611193768001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','pinkabilly','crespyration@yahoo.com','Temi Surya','Jalan Terong No. 9A','Bandung','','INDONESIA','40262','+62811590095','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 00:36:07',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1 '),(3292,650402053002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','rickhuntr','rsims20770@aol.com','Richard Sims','2 Metroplex Dr<br>Ste 200','BIRMINGHAM','AL','UNITED STATES','35209-6843','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 01:36:35',0,NULL,3,1,1,1,NULL,NULL),(3293,650406086002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 01:55:44',0,NULL,8,1,17,0,NULL,NULL),(3294,611210026001,110566019774,'Neoprene Protector Camera Cover  for Nikon Size: Large ',2,'AC1303',18.5,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 01:55:43',0,NULL,3,1,3,1,NULL,'å¤§å·å†…èƒ†åŒ…   2  æ— å­—  \rå¤§å·å†…èƒ†åŒ…   2  nikon\rRR815346040CN\r'),(3295,611231196001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','rexosa','xosa@msn.com','Renold Gennosa','4315 205th St','Bayside','NY','UNITED STATES','11361-2610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:42:22',0,NULL,3,1,1,1,NULL,NULL),(3296,650430237002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','photomarvin10','marvel623@hotmail.com','Marvin Schwartz','15125 88th St<br>Apt 6K','Howard Beach','NY','UNITED STATES','11414-2014','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:47:31',0,NULL,3,1,1,1,NULL,NULL),(3297,611234046001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','juanam2754','juanmarrero2005@yahoo.com','Juan Marrero','PO Box 0982','Miami','FL','UNITED STATES','33101','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 03:58:57',0,NULL,3,1,1,1,NULL,NULL),(3298,611236051001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:10:21',0,NULL,8,1,17,0,NULL,' '),(3299,611236320001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:12:04',0,NULL,8,1,17,0,NULL,NULL),(3300,650435144002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','jtbone68','jtbone68@iwon.com','Joseph Resi','21 Orchard Ln','Cold Spring','NY','UNITED STATES','10516-3727','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 04:14:29',0,NULL,3,1,1,1,NULL,'58mm é•œå¤´ç›–  canon   2\r58mm rubber   æ©¡èƒ¶ç½©   1 \ret-65b    1'),(3301,611243667001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','gregorx2001','gregory@incessant.com','Gregory Pruden','2761 Dale Ave','Bexley','OH','UNITED STATES','43209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 05:50:42',0,NULL,3,1,1,1,NULL,'å•ç¯å¤´  2 \r\r'),(3302,611250446001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',4,'AA3302',13.2,'hermeshine','msmim10','mimidorazio@bigpond.com','Emilia D\'Orazio','11 Irwin Road','Embleton','Western Australia','AUSTRALIA','6062','0892751143','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 05:57:30',0,NULL,3,1,2,1,NULL,'55mm uv   4 '),(3303,650461665002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lohner3','lohner3@hotmail.com','Ashlie Lohner','1803 Lantana Court','Southlake','TX','UNITED STATES','76092','(817) 488-7818','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 07:33:43',0,NULL,3,1,1,1,NULL,' '),(3304,610903989001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','thomajo2','thoma@edge.net','Thoma   Parker','618 Boscobel St','Nashville','TN','UNITED STATES','37206-4141','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 07:52:18',0,NULL,3,1,1,1,NULL,' '),(3305,650464703002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','sky3910michal','sky3910@yahoo.com.sg','Michal Lim','Blk 762 Pasir Ris St 71 #04-228<br>(S)510762','default','','SINGAPORE','510762','6590236398','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 07:56:11',0,NULL,3,1,3,1,NULL,'RR815346504CN\r '),(3306,650474676002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','nahumzax','zook89@gmail.com','nahum zax','90teena st\'','moshav hemed','ISRAEL','ISRAEL','50295','972-50-8267563','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:07:55',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3307,611276148001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:15:43',0,NULL,8,1,17,0,NULL,NULL),(3308,611276010001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 09:15:43',0,NULL,8,1,17,0,NULL,NULL),(3309,650475242002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 09:15:44',0,NULL,8,1,17,0,NULL,NULL),(3310,650475583002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','robiem72','tremk@triera.net','Emersic Robert','Rospoh 31b','Maribor','','SLOVENIA','SI2000','+38670899750','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 09:15:44',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡  2\råŒ…  1\r115w  220v   2\rå€’å½±æ¿   1\r60cm æ£š   1 \rCP219437323CN\ræ–°å•å·æ¢æˆï¼š CP179509855CN\r'),(3311,611273742001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ilos9179','ivanlos@yahoo.com','IVAN LOSADA','AGASTIA 35 2 C','MADRID','Madrid','SPAIN','28027','646542166','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 10:13:48',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  ç™½ç›’  1 \rRR815346190CN\r'),(3312,611303044001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','timay554v','timay@hotmail.com','Sylvain Guimond','2850, des Hirondelles','BÃ©cancour','QC','CANADA','G9H 4M5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 11:53:52',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815346138CN\r'),(3313,611305422001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','philipnz20','philip@smartchat.net.au','Philip Cheng','Unit 2405<br>7 Riverside Quay','Southbank','Victoria','AUSTRALIA','3006','0422717535','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 12:07:29',0,NULL,3,1,2,1,NULL,NULL),(3314,708618787015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','zoumi1959','king1kty007@hotmail.fr','BONNETAUD Jeffrey','56 rue de lagrange','Manom','Lorraine','FRANCE','57100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-21 12:18:08',0,NULL,3,1,3,1,NULL,'1.6x3m ç™½è‰²èƒŒæ™¯å¸ƒ   1\rRR815346362CN\r '),(3315,694865587016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','pete0303','pete@zoapz.com','Peter marshall','Admiraal de Ruyterweg 3','amsterdam','','NETHERLANDS','1057 jt','0621874282','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-21 12:35:57',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶   2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   2\råŒ…   1\r110cm 5in1   1\rYW863600116CN\r\r '),(3316,650509102002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ariel.sharhabi','ariels.h@012.net.il','ariel sharhabi','or haganooz','or haganooz','marom hagalil','ISRAEL','13909','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:40:07',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR815346186CN\r'),(3317,650511388002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','gtgaute','gtgaute@gmail.com','Gaute Thogersen','Skrenten 48 C','Larvik','Vestfold','NORWAY','3258','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:46:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡   1\råå…‰ä¼ž   1 \rRR815346067CN\r'),(3318,650512341002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 12:51:46',0,NULL,3,1,2,1,NULL,NULL),(3319,611314370001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','palagorn2006','plgorn@hotmail.com','Palagorn Raybumrung','888/104 Panuch Village<br>Pracharajbumpen Road,Samseannok,','Huaikhang','Bangkok','THAILAND','10320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 12:57:07',0,NULL,3,1,3,1,NULL,'æ¸å˜ç°ï¼Œæ¸å˜çº¢ï¼Œ æ¸å˜è“ \rND2  ND4  ND8   \r6ç‰‡è£… æ»¤é•œè¢‹   1 \ré•œç‰‡ä¸è¦ç›’å­\rRR815346107CN\r'),(3320,694874525016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'',9.78,'hutongstore','pete0303','pete@zoapz.com','Peter marshall','Admiraal de Ruyterweg 3','amsterdam','','NETHERLANDS','1057 jt','0621874282','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-21 13:12:42',0,NULL,8,1,17,0,NULL,NULL),(3322,650533706002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','ernestfigueras','ernest.figueras@gmail.com','Ernest Figueras','Corcega 180, bajos derecha, CIBERehd','Barcelona','CataluÃ±a','SPAIN','08036','656348675','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 14:42:55',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863600131CN\r'),(3323,708657669015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','simongorin61','simongorin@yahoo.co.uk','simon gorin','21 St Andrews Road st helier','Jersey','Channel Islands','UNITED KINGDOM','JE2 3JF','07797727359','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-21 14:57:30',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1 '),(3324,611340435001,110583278297,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',7.1,'hermeshine','ogoxsam','sam.ogox@gmail.com','Ha Sam Vinh Hao','Blk 717 #22-105<br>Clementi West St 2','default','','SINGAPORE','120717','90941910','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 15:02:15',0,NULL,3,1,11,1,NULL,'å¤©æ¶¯  77mm cpl  1 '),(3327,611355048001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','harald0344','haraldbonke@hotmail.com','Harald Bonke','Veertien Hond 16','TIEL','','NETHERLANDS','4003GK','0344 633341','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 16:07:20',0,NULL,8,1,17,0,NULL,NULL),(3328,650554507002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','harald0344','haraldbonke@hotmail.com','Harald Bonke','Veertien Hond 16','TIEL','','NETHERLANDS','4003GK','0344 633341','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 16:07:21',0,NULL,3,1,3,1,NULL,'å°å·ç°å¡   1\rå€’å½±æ¿   1 \rRR815346141CN\r'),(3329,611160940001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','greels','mgreels@yahoo.com','MATTHEW GREELEY','320 16th St NE','MENOMONIE','WI','UNITED STATES','54751-2062','(715) 233-3059','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 16:14:59',0,NULL,3,1,1,1,NULL,NULL),(3330,708700504015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','slabrocker','kivilarmola@gmail.com','Kivi Larmola','70 Tootal Drive','Salford','Lancashire','UNITED KINGDOM','M5 5ER','01617377663','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-21 17:20:59',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\råŒç¯å¤´  è‹±æ ‡   2\råå…‰ä¼ž  2\r115w 220v   4\rlighting kit   $30\råŒ…    1\rYW863600120CN\r\r '),(3331,611377523001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','victor16554','vs_drammen@hotmail.com','Victor Pedersen','Dueveien 25','Hokksund','Hokksund','NORWAY','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 17:26:55',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3332,611379408001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','serg70_2009','sergyuzhakov@gmail.com','Sergey Yuzhakov','19/43,Ul.Arkhangelskaya','Cherepovets','Vologodskaya obl','RUSSIAN FEDERATION','162603','78202623941','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 17:34:00',0,NULL,3,1,2,1,NULL,' '),(3333,611209837001,110532007471,'HB-7 HB7 Lens Hood for Nikon AF 80mm-200mm f/2.8D NEW',1,'AA3403',9.8,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 18:37:02',0,NULL,3,1,2,1,NULL,NULL),(3334,611409951001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','wlad2318','wladneto@uol.com.br','Wladimir Nequesaurt Pereira Neto','Rua Lucio Vitorino de Souza 186','Florianopolis','Santa Catarina','BRAZIL','88035060','48-32346911','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 19:08:22',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3335,649417321002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeffreyhuntfish','hotfish@comcast.net','jeffrey lester','4301 NW 12th Way','pompano beach','FL','UNITED STATES','33064-1178','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 18:59:55',0,NULL,3,1,1,1,NULL,NULL),(3338,695029870016,260660053640,'New TianYa Star 4 points filters for Cokin P Series',1,'',7.8,'hutongstore','smithdw1','dereksmith60@hotmail.com','Derek Smith','10 Overstand Close','Beckenham','Kent','UNITED KINGDOM','BR3 3JY','02086586794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-21 20:52:45',0,NULL,3,1,2,1,NULL,'æ˜Ÿå…‰é•œ   star4    1 '),(3339,650635519002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','se25itamar','se25@inter.net.il','itamar saida','box 2574','shoam','','ISRAEL','60850','972528898677','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 20:18:57',0,NULL,3,1,3,1,NULL,' æ–œè‡‚  1\rRR815346115CN\r'),(3340,650650722002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','max_d_solomko','max_solomko@bigmir.net','Max Solomko','Viljamsa st. home 15 corpus 3 ap. 63','Kiev','Kiev','UKRAINE','03191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 21:07:17',0,NULL,3,1,2,1,NULL,NULL),(3342,650670879002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','tomi10090','t_balija@yahoo.com','tomislav balija','banski vinogradi 44a','zagreb','CA','CROATIA','10090','0918811883','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:11:33',0,NULL,3,1,3,1,NULL,' RR815346075CN\r'),(3344,610845110001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','jchi2889','jimmystu102@tds.net','james chiarella','12744 Kingston Pike<br>Ste 102','Knoxville','TN','UNITED STATES','37934-0941','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-21 22:13:30',0,NULL,3,1,1,1,NULL,NULL),(3345,611470056001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 22:15:03',0,NULL,3,1,3,1,NULL,' RR815346124CN\r'),(3346,611471078001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:20:41',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346155CN\r'),(3347,650677178002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:36:03',0,NULL,3,1,3,1,NULL,' 2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815346084CN\r'),(3348,650677507002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','omerpiposh','hfg666@bezeqint.net','Omer Yaari','The Galil 34','Kfar Saba','Sharon','ISRAEL','44233','972 52 4507156','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-21 22:37:43',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815346098CN\r'),(3349,611480259001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','siretorre','asaad@me.com','RÃ©jean Harvey','496 Boniface','Le Gardeur','QC','CANADA','J5Z4K6','(450) 654-2636','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-21 23:01:11',0,NULL,3,1,2,1,NULL,NULL),(3351,611497736001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','prepaee','kayjet64@gmail.com','Mitchell Wolfrom','PO BOX 1362','Vieques','PR','UNITED STATES','00765-1362','(787) 435-9252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 00:28:42',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(3352,708857911015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 00:39:37',0,NULL,8,1,17,0,NULL,NULL),(3353,695095620016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-22 00:39:36',0,NULL,8,1,17,0,NULL,''),(3354,708858417015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'',25,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','ÃŽle-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 00:39:37',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\r50-70 æ£š  æ¬§æ ‡   1\r115w 220v   2\rlighting kit  $25\rYW863600175CN\r\r '),(3355,650711966002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2401',49.9,'hermeshine','koseofthewest','westkose@frontier.com','Cheryl Kose','7470 SW 140th Ave','Beaverton','OR','UNITED STATES','97008-8652','(503) 526-1322','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-22 01:24:58',0,NULL,3,1,1,1,NULL,'50-70 æŸ”å…‰æ£š é€šç”¨å¡å£   2\rå…ˆå‘ä¸€ä¸ªLK014121366CN\rè¿˜å·®ä¸€ä¸ªLK014380119CN'),(3357,611515709001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lungfishman','ebaytrade@netscape.net','Robert Willmore','163 S John St','Crown Point','IN','UNITED STATES','46307-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 02:04:59',0,NULL,3,1,1,1,NULL,NULL),(3358,650717760002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','typhoon220','sgagne2@midco.net','Sarah Gagne','2883 Highway 11 S','Loman','MN','UNITED STATES','56654-8009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 01:54:29',0,NULL,3,1,1,1,NULL,NULL),(3360,611518929001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','darare','davidrafael@gmail.com','David Reyes','7801 NW 37th St<br># DO80Q22750N','DORAL','FL','UNITED STATES','33166-6503','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 02:22:57',0,NULL,3,1,1,1,NULL,' '),(3361,650725705002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mnncoop','mnncoop@verizon.net','Filomena Cooper','24 Sesame St','Kings Park','NY','UNITED STATES','11754-2836','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'LK014374665CN'),(3362,708893420015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','jazzrena','jazzrena@yahoo.com','Renatas Fominichas','103 Hurworth Avenue','Slough','Berkshire','UNITED KINGDOM','SL3 7FG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-22 03:26:04',0,NULL,3,1,2,1,NULL,NULL),(3363,611540891001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','sn74','support@creograf.ru','Anastasiya Deeva','Solnechnaya street 12A-34','Chelyabinsk','','RUSSIAN FEDERATION','454014','+7 909-746-6433','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 04:39:29',0,NULL,3,1,2,1,NULL,NULL),(3364,650748359002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','tuoc22gh7','tuoc2@juno.com','Joseph Nguyen','2309 Gaylord St','Denver','CO','UNITED STATES','80205-5627','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 04:55:32',0,NULL,3,1,1,1,NULL,NULL),(3365,611544040001,110534333216,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',2,'AA1201',8,'hermeshine','truesharp','fond@radiolink.ru','Andrey Smirnov','Zelenograd, kor. 1606, kv. 392','Moscow','','RUSSIAN FEDERATION','124365','+7(903)726-1110','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:05:34',0,NULL,8,1,17,0,NULL,NULL),(3366,611541482001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','truesharp','fond@radiolink.ru','Andrey Smirnov','Zelenograd, kor. 1606, kv. 392','Moscow','','RUSSIAN FEDERATION','124365','+7(903)726-1110','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:05:35',0,NULL,3,1,2,1,NULL,'450dçœ¼ç½©  2\rå¤§å·ç°å¡   1 '),(3368,611547254001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','1pslabo1','pslabo@gmail.com','Pavel Slabodkin','ul. Dekabristov d.34 kv.6','Moscow','','RUSSIAN FEDERATION','127273','+79036185228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 05:31:03',0,NULL,3,1,2,1,NULL,' '),(3370,650769046002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 07:45:36',0,NULL,3,1,3,1,NULL,'æ¡Œé¢ç¯   1 \rRR815346481CN\r'),(3371,649072524002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','4rchangel','g4briel@shaw.ca','Gabriel Martin','354 Shawnessy Drv SW','Calgary','AB','CANADA','T2Y1J1','(403) 560-6158','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 07:21:23',0,NULL,8,1,17,1,NULL,NULL),(3372,611576169001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',2,'AB3321',53.98,'hermeshine','mizer357','mizer357@yahoo.com','Henry Cho','610 W 42nd St<br>Apt 53G','New York','NY','UNITED STATES','10036-1997','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 09:36:57',0,NULL,3,1,1,1,NULL,'ttlçº¿  1m   2 '),(3373,611581118001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','wellingtonrlimawellington','wellingtonrlima@gmail.com','Wellington Rodrigues Lima','PraÃ§a Carlos Chagas, 49Âº / 10Âº andar<br>Lourdes','Belo Horizonte','Minas Gerais','BRAZIL','30170-913','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 10:13:29',0,NULL,3,1,2,1,NULL,NULL),(3374,650789817002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','tomash_15','toms.element@gmail.com','tomer ifrach','yehuda halevi 21','herzelia','il','ISRAEL','46480','(972)544443223','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-22 10:24:34',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRR815346420CN\r'),(3375,695207137016,260660052146,'New 62mm 62 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','franziska4532','franzi-leo@web.de','Franziska Leonhardi','48 Carnock Road','Dunfermline','Fife','UNITED KINGDOM','ky 129nt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-22 11:07:42',0,NULL,3,1,2,1,NULL,'62mm çŽ¯æž¶   1 '),(3376,611624362001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','dhwteb','dhwieringa@planet.nl','derk  wieringa','ludgerstraat 12','bedum','','NETHERLANDS','9781GG','0648563412','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 14:26:02',0,NULL,3,1,2,1,NULL,NULL),(3377,611615301001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',94.9,'hermeshine','perhan195','per@phpwebtech.com','Per Hanson','Urb. Terrazas del Rodeo<br>Bloque 6-1C','Nueva Andalucia','AndalucÃ­a Ceuta y Melilla','SPAIN','29660','600012841','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-22 15:26:19',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ ï¼‰ \rä¸¤ä¸ªèƒŒæ™¯å¸ƒéƒ½æ˜¯1.6x3m   1\rbackground support   1\rYW863684575CN'),(3378,650859802002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',8,'AA1310',43.92,'hermeshine','lolica007','rcararo@ig.com.br','LOURDES LISE CARARO','RUA BORTOLO ZANI, 97<br>SALA 1','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','054 3228 5664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:27:54',0,NULL,3,1,3,1,NULL,' RR815346447CN\r'),(3379,611652981001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','pisnou','fc888@club-internet.fr','Francois CARREZ','17 rue JEAN JACQUES ROUSSEAU<br>App 122','CORBEIL ESSONNES','ÃŽle-de-France','FRANCE','91100','0675085353','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:36:38',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°   1\r77mm çŽ¯æž¶   1 '),(3380,650863662002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','hansasd.eb','hansasd@gmail.com','Hansa Dharmapriya','10<br>Araliya Mawatha','Sirimal Uyana','Ratmalana','SRI LANKA','10370','+94776256383','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 16:40:13',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(3381,709110110015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','kriginasm','kriginas.marius@gmail.com','Mar Kriginas','Ziedu 4 Pajiesmeniai','Pasvalio raj','','LITHUANIA','39449','+37061592593','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 19:21:01',0,NULL,3,1,2,1,NULL,'1è½¬4 ç¯å¤´   1 '),(3382,650913923002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','itzikelisha','iel8@walla.com','itzik elisha','yarkon 34<br>isrel','baer yakov','MD','ISRAEL','70300','0506537779','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 19:34:15',0,NULL,3,1,2,1,NULL,NULL),(3383,611712787001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',4,'AA1309',9.8,'hermeshine','swingfishnut','marksebay@verizon.net','Mark J. Gucker','1525 5th PL','Kirkland','WA','UNITED STATES','98033','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 19:57:19',0,NULL,3,1,1,1,NULL,NULL),(3384,611717611001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','dimaster7','dimasmotta@yahoo.com','DIMAS MOTTA','3235 30th Street Apt D1','Astoria','NY','UNITED STATES','11106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 20:12:34',0,NULL,3,1,1,1,NULL,NULL),(3385,611721838001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','concept-tango','concept-tango@hotmail.com','Claudia Gherzetich','Colectora AU Ricchieri, Barrio Autopista,<br>Torre 8, 10Â° C','Tapiales','Buenos Aires','ARGENTINA','1770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 20:26:16',0,NULL,3,1,2,1,NULL,NULL),(3386,650955136002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','stephaniejeansouthard','stephaniejeansouthard@gmail.com','Stephanie Southard','2163 N Brandywine St','Arlington','VA','UNITED STATES','22207-2225','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 21:43:39',0,NULL,3,1,1,1,NULL,NULL),(3387,650960518002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0014',18,'hermeshine','ruslanl','ruslanla@ukr.net','Ruslan Lyulya','11 Dudykina<br>108','Zaporizhzhya','Zaporizhzhya','UKRAINE','69065','38-050-6610745','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 22:06:51',0,NULL,3,1,3,1,NULL,'1.6x3m èƒŒæ™¯å¸ƒ   é»‘è‰² RR815346570CN\r'),(3388,611752214001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','hands2u','ray@hands2u.com','Raymond Stover','69 W Anchor Dr','Little Egg Harbor','NJ','UNITED STATES','08087-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 22:16:59',0,NULL,3,1,1,1,NULL,NULL),(3389,611754648001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','cuemeister','tekdiver@metrocast.net','Daniel Butler','70 Dalton Dr','Center Barnstead','NH','UNITED STATES','03225','(603) 509-2885','NoPaymentFailure','CheckoutComplete','Other','2010-12-22 22:30:14',0,NULL,3,1,3,1,NULL,'RR815346478CN\r '),(3390,650967639002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE1301',19.36,'hermeshine','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-22 22:35:34',0,NULL,8,1,17,0,NULL,' '),(3391,695408414016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'',28.99,'hutongstore','litobocon','miguelginermg@gmail.com','miguel giner','polo y peyrolon n5 pta 19','valencia','Comunidad Valenciana','SPAIN','46021','963695436','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-22 22:41:39',0,NULL,3,1,4,1,NULL,'3m æ¨ªæ†   1 \rCåž‹å¤¹  2\rYW863684623CN'),(3392,611754534001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','acwaits','andrew.waits@gmail.com','Andrew Waits','725 15th Ave','Seattle','WA','UNITED STATES','98122','(206) 931-2221','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 22:49:14',0,NULL,3,1,1,1,NULL,NULL),(3393,611768707001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1304',12.99,'hermeshine','rozzikat','marzi@q.com','Marlene Romuar','2500 S Broadway<br>Trlr 13','Cortez','CO','UNITED STATES','81321-8502','(970) 564-9360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-22 23:38:41',0,NULL,3,1,1,1,NULL,'æ–°æ¬¾å†…èƒ†åŒ…   1 '),(3395,650989369002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','smkhan57','skhan511@hotmail.com','Saad Khan','11 Municipal Square','Clarenville','NL','CANADA','A5A1T4','(709) 466-2659','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:24:14',0,NULL,3,1,2,1,NULL,NULL),(3396,611777394001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','graham186','grahamrobson@talktalk.net','Graham Robson','186 Inchbonnie Road','South Woodham Ferrers','Essex','UNITED KINGDOM','CM3  5WU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:30:21',0,NULL,3,1,2,1,NULL,'6663aå¿«è£…æ¿  1 '),(3397,650992552002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','fisheggie','vian.c@hotmail.com','Vian Cheng','#86-3260 E58th Ave','Vancouver','BC','CANADA','V5S 3T3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 00:38:27',0,NULL,3,1,2,1,NULL,NULL),(3398,651002805002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ivanebeoulve','ivane.beoulve@hotmail.com','Ivan Negrete','317 Heffernan Ave<br>PMB 10918','Calexico','CA','UNITED STATES','92231-2739','(020) 234-2342','NoPaymentFailure','CheckoutComplete','Other','2010-12-23 01:37:50',0,NULL,3,1,3,1,NULL,' RR815346433CN\r'),(3399,695453393016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'',24.99,'hutongstore','chrissie_n02','lanxxoo@yahoo.com.au','Lan Nguyen','8 Border Close','Hinchinbrook','New South Wales','AUSTRALIA','2168','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-23 02:13:29',0,NULL,3,1,3,1,NULL,'115w 220v   2 \rRR815346495CN\r'),(3400,611796289001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','pitukmercerago','mercerago@hotmail.com','PITUK KARNYOO','104 Moo 12 Soi Tanasit Teparak Rd. Bangpla','Bangplee','Samutprakarn','THAILAND','10540','086-233-8407','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 02:32:39',0,NULL,3,1,11,1,NULL,NULL),(3401,611801130001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',28.99,'hermeshine','seratolvinyl','seratovinyl@gmail.com','Paul Vollmer','2720 S Highland Ave<br>Apt 750','Lombard','IL','UNITED STATES','60148-7156','(815) 557-7746','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-23 02:57:29',0,NULL,3,1,1,1,NULL,'ttl çº¿  canon   3m   1 '),(3402,651022235002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','henrckw001','henrckw001@yahoo.com','Ket Wai Chu','No. 53A, Jln Apollo U5/187,<br>Bandar Pinggiran Subang','Shah Alam','Selangor Darul Ehsan','MALAYSIA','40150','0122375800','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 03:30:39',0,NULL,3,1,2,1,NULL,NULL),(3403,610869274001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','andrelorente','andrelorente@ig.com.br','Helio Bressan','Rua Dr. Candido Espinheira, 396<br>Terreo','Sao Paulo','SP','BRAZIL','05004000','(551) 199-2691 ext.: 14','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 04:50:32',0,NULL,3,1,5,1,NULL,'\rCP219437283CN'),(3404,611823716001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','econspiracydesign','econ@econ.net','Brian Walls','255 4th St<br>Ste 104','Oakland','CA','UNITED STATES','94607-4389','(510) 836-0683','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 05:52:20',0,NULL,3,1,1,1,NULL,NULL),(3405,651041950002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','cowgirl4040','cowboy44@shaw.ca','Wendy Sherlock','#202 - 8830 Montcalm Street','Vancouver','BC','CANADA','V6P 4R3','(604) 267-0057','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 06:02:56',0,NULL,3,1,2,1,NULL,NULL),(3406,611828852001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','farinhasbr','digite@hotmail.com','Mauricio Farias','Av Governador Valadares 54','Monte Santo de Minas','Minas gerais','BRAZIL','37958000','513535912535','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 06:39:52',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´   2 '),(3407,611834470001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','liongld','lion_dg@mail.ru','Gabaraev Levan','Sverdlova 22 - 59','Tyumen','Tyumen Region','RUSSIAN FEDERATION','625002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 07:32:11',0,NULL,3,1,2,1,NULL,NULL),(3408,611582638001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','theblueman','bluemanchurian@gmail.com','Mark H Hopper','1740 Chopin Dr','Charlottesville','VA','UNITED STATES','22903','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 08:30:47',0,NULL,3,1,1,1,NULL,NULL),(3410,709284226015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','rasjep09','peterpbo@gmail.com','Peter Bornaes','Soparken 97','Roskilde','SjÃ¦lland','DENMARK','4000','+45 23232323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 08:32:07',0,NULL,3,1,2,1,NULL,NULL),(3411,651075141002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','onmyaeroplane','michele@myaeroplane.it','michele piazza','via a. volta 24','chiampo','VI','ITALY','36072','0444625776','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 10:48:23',0,NULL,3,1,3,1,NULL,'2mç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡  1\råå…‰ä¼ž   1 \rRR815346671CN\r'),(3412,611884383001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','gustavof','gustavoguantay@gmail.com','Gustavo Guantay','Tomas Cabrera 623','Salta','Salta','ARGENTINA','4400','4340961','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 13:42:34',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0è†œ   1 '),(3413,611885365001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','iraklis05','kesidisi@hotmail.com','Mr. Iraklis Kesidis','Kirkis 3 flat 102','Paphos','Paphos','CYPRUS','8049','+35799783602','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 13:46:07',0,NULL,3,1,2,1,NULL,NULL),(3414,709343072015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','greymancyclist','graham.fielder@gmail.com','Graham Fielder','4 THORNESS CLOSE MILLBROOK','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO16 9JE','02380579524','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 14:01:22',0,NULL,3,1,3,1,NULL,' RR815346711CN\r'),(3415,611888186001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','robalo8k','mons@mundo-r.com','Mauricio Bechler','CXG VIAXES<br>SÃ¡nchez Bregua, 5-3Âº','A CORUÃ‘A','Galicia','SPAIN','15004','902116882','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 14:01:42',0,NULL,3,1,2,1,NULL,NULL),(3416,709308411015,250619797712,'Photo Studio Background Support (2mÃ—2m)+ Free Backdrop',1,'',51.9,'hutongstore','chi26zach','chiarazach@btopenworld.com','Chiara Zachary','37 Westdale Drive','Moodiesburn','North Lanarkshire','UNITED KINGDOM','G69 0NP','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-23 14:23:38',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰ 1\ré•¿çš„ \rbackground support  $20\rYW863684553CN\ræ¢æˆsaläº†ï¼šCP219637024CN \r'),(3417,709346876015,250692236297,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 14:53:22',0,NULL,8,1,17,0,NULL,NULL),(3418,709348379015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','aldo1052','eelcpo@tin.it','Aldo Porretta','Le Quadra ,3','Castelliri','Frosinone','ITALY','03030','3287160778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 14:53:22',0,NULL,3,1,2,1,NULL,'67mm uv   1\r77mm uv    1 '),(3419,709363642015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'',9.15,'hutongstore','soares197150','fsfotosoares@gmail.com','Francisco Soares','Largoda Barreira nÂº2','Vilarandelo','ValpaÃ§os','PORTUGAL','5430-635','252419575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 15:32:29',0,NULL,3,1,2,1,NULL,'1è½¬4 ç¯å¤´   1 '),(3420,611906940001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','talat417','talat_417@hotmail.com','talat arslan','82 evler 3122 sok. no:14<br>berdan ogrenci yurdu tarsus','mersin','','TURKEY','33460','905425942912','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 15:40:21',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(3421,611908661001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','soloaki','robobby@ymail.com','Roberto Guadarrama','Reforma # 7','Iguala de la independencia','guerrero','MEXICO','40000','557333337193','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(3422,651128488002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bbemis5150','bbemis@san.rr.com','Bryan Bemis','9584 Via Pereza','San Diego','CA','UNITED STATES','92129-2730','(858) 414-5898','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 16:03:18',0,NULL,3,1,1,1,NULL,NULL),(3423,709372732015,250692238780,'New Desktop Photography light Stand 10-15\" Tall',2,'',41.8,'hutongstore','thebrontelife','buysomeflowers@gmail.com','Rebeca Santamaria Bretones','C/ Mesena NÂº 18, bloque b, escalera b-1, piso 2Âº A','Madrid','Madrid','SPAIN','28033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 16:07:33',0,NULL,3,1,4,1,NULL,'æ¡Œé¢ç¯   2 \rlight  $26\rYW863684590CN\r'),(3424,651132878002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','mohabdellah','abdellah21211@yahoo.com','Mohamed Aly Abdellah','Riqqa Street , Deria , Dubai','Dubai','','UNITED ARAB EMIRATES','14568','00971558229325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 16:21:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rå•ç¯å¤´   1  è‹±æ ‡\råå…‰ä¼ž   1 \rRR815346685CN\r'),(3425,651133511002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2401',24.95,'hermeshine','mohabdellah','abdellah21211@yahoo.com','Mohamed Aly Abdellah','Riqqa Street , Deria , Dubai','Dubai','','UNITED ARAB EMIRATES','14568','00971558229325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 16:22:52',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£  1 \rRR815346950CN\r'),(3426,651146911002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','rufat_abas','rufatabas@gmail.com','Rufat Abas','2942A Mahammad Hadi street, apt 74','Baku','','AZERBAIJAN','AZ1129','(99450)2222809','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 17:24:05',0,NULL,3,1,2,1,NULL,'60cm 2in1   1 '),(3427,651151362002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lemeilleurencherisseurcmoa','francois.pavee@free.fr','Thibault PAVEE','42 rue de Dantzig','Paris','ÃŽle-de-France','FRANCE','75015','08.30.70.18.33','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 17:41:02',0,NULL,3,1,2,1,NULL,NULL),(3428,611899035001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','nudawest','dolbit@list.ru','Denis Moskvin','prospekt Karla Marksa 324-10',' Samara','','RUSSIAN FEDERATION','443016','+7 927-608-80-10','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 18:01:08',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m èƒŒæ™¯å¸ƒ  ç™½è‰²   1\r2mç¯æž¶   2\r50-70 æ£š æ¬§æ ‡  2\r115w 220v   1\råŒ…   1\r CP219436985CN\r'),(3429,611943435001,110566021441,'TianYa ND4 Filter for Cokin P Series Neutral Density',1,'AA2324',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:16',0,NULL,8,1,17,0,NULL,NULL),(3430,651159700002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:15',0,NULL,8,1,17,0,NULL,NULL),(3431,651158340002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:15',0,NULL,8,1,17,0,NULL,NULL),(3432,611943935001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:14',0,NULL,8,1,17,0,NULL,NULL),(3433,651159067002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:16',0,NULL,8,1,17,0,NULL,NULL),(3434,611942738001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','vromeago','vicenteromea@gmail.com','vicente romea gomez','Gasca, 36','villarroya de la sierra','AragÃ³n','SPAIN','50310','647986066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 18:24:17',0,NULL,3,1,3,1,NULL,'æ¸å˜æ£•   1\r77mm æŽ¥å£çŽ¯  1\réº‚çš®   1\rå¹¿è§’æ‰˜æž¶   1\ræ¸å˜ç°    1\rND4    1 \rRR815346739CN\r'),(3435,611981118001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','jojodel1','luc@execphoto.ca','Luc St-Amour','15 des Poiriers','Cantley','QC','CANADA','J8V3R5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 20:44:00',0,NULL,3,1,3,1,NULL,'nikon åŽŸè£…èƒŒå¿ƒ  XL   1 \rRR815346725CN\r'),(3436,695677392016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','blues-riff','pals@lyra.cc','Stephen Morton','548 Avenue Andre Gide','Cabris','Alpes Maritime','FRANCE','06530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 20:55:11',0,NULL,3,1,2,1,NULL,'450D  çœ¼ç½©  1 '),(3437,695680235016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','rszulia','rszulia@wp.pl','Ryszard Szulia','18 Glebe Road','Stratford upon Avon','Warwickshire','UNITED KINGDOM','CV37 9JU','07756939620','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 21:04:36',0,NULL,3,1,2,1,NULL,'67mm çŽ¯æž¶    1 '),(3438,611990102001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 21:24:44',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346668CN\r'),(3439,709476742015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','jekas69','joel.pereira@iol.pt','Joel Pereira','Tv dos Unidos, 2','Tamel S. Verissimo','Barcelos','PORTUGAL','4750-726','+351 918904656','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-23 21:49:49',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3440,695557457016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','raonipz','raoniz@hotmail.com','Raoni Zopolato','29 Grendon House/ Shore Place','London','London','UNITED KINGDOM','E9 7qg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-23 21:55:09',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 '),(3441,651217221002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','johnnyalves75','alvesjohnny@sapo.pt','Johnny Alves','Rua 12 - nr.936 - 3Âºesq.Âº','Espinho','PA','PORTUGAL','4500','917774940','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-23 22:01:21',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(3442,612006231001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','smartpoppoppop','baysmartpop@hotmail.com','Mr.Teeraphon Sunteeraparp (POP)','465 Plubplachai Road Tambon Pom-Parp<br>Pom-parp-sattru-phai District','Bangkok','à¸›à¸£à¸°à¹€à¸—à¸¨à¹„à¸—à¸¢','THAILAND','10100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-23 22:44:33',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 \rRR815346742CN\r'),(3443,651229320002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','thetawaves','vinhboi28@yahoo.com','Vinh-Boi Nguyen','1149 Mountain Gate Rd','Upland','CA','UNITED STATES','91786-2668','(909) 451-1225','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-23 23:01:57',0,NULL,3,1,1,1,NULL,' '),(3444,651270538002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','lottiemcdottie1','lottie_mcdottie@hotmail.com','Charlotte Bell','103-1915 E Georgia Street','Vancouver','BC','CANADA','V5L 2B7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 03:22:21',0,NULL,3,1,2,1,NULL,''),(3445,651181733002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',185,'hermeshine','soulsoothe','jrweaver@gmail.com','James Weaver','6201 Chapel Hill Blvd<br>Apt 2113','Plano','TX','UNITED STATES','75093-8887','(972) 971-2156','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-24 04:05:08',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯  3\r800w110v   3\rç‡•æ–‡  light $30 \rYW863684601CN\r'),(3446,612054427001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'',13.99,'hermeshine','fujiyamasensei','robert.arbour@cgocable.ca','Robert Arbour','4510 Papineau','Trois-RiviÃ¨res','QC','CANADA','G8Y 1R1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 04:14:43',0,NULL,3,1,3,1,NULL,'90th é•œå¤´ç­’    1 \rRR815346875CN\r'),(3447,709549696015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','janberg','janfal@gmail.com','Jan F. Stetzelberg','58 Queens Gate Terrace Flat 5','London','London','UNITED KINGDOM','SW7 5PJ','07510304157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 04:15:25',0,NULL,3,1,3,1,NULL,' RR815346889CN\r'),(3448,612057628001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','got2ebuyitnow','tlambrou100@hotmail.com','Anthony C Lambrou','Calle 49 No 519 x 62 y 64<br>Centro','Merida','Yucatan','MEXICO','C.P. 97000','011-999-52-928-6694','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 04:37:48',0,NULL,3,1,2,1,NULL,NULL),(3449,651278083002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wencam1225','wencam318i@usa.com','Wendell Campbell','PO Box 1164<br>807 Fox St','Elizabethtown','NC','UNITED STATES','28337-1164','(910) 876-3106','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 04:56:22',0,NULL,3,1,1,1,NULL,NULL),(3450,695796552016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'',5.5,'hutongstore','angonzi','angonzi@gmail.com','Ana GONZÃLEZ','Francisco de Quevedo 9, 3Âª F','LogroÃ±o','La Rioja','SPAIN','26006','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 08:46:49',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3451,612083458001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','jacek3210','jacek.dojnikowski@jaswily.pl','JACEK DOJNIKOWSKI','JAÅšWIÅY 71A/17, JAÅšWIÅY','JAÅšWIÅY','podlaskie','POLAND','19-124','606 655441','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 09:09:25',0,NULL,3,1,3,1,NULL,'58mm cpl, nd8, +4, æ¸å˜ç° æ”¾åœ¨4pcs æ»¤é•œè¢‹é‡Œ \rRR815340064CN'),(3452,612085785001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','cekk81','andreacekk@libero.it','andrea cecchetti','via maresciallo diaz 55','marcellina','RM','ITALY','00010','339-8655240','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 10:04:03',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶ 1\r æ–œè‡‚   1 \r\rlight stand  $20\rYW863684704CN\r'),(3453,695825385016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','hoogy4','a_hoogy@yahoo.co.uk','Alwyn Hoogwerf','59 Cumberland Road','Hanwell','London','UNITED KINGDOM','W7 2EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 11:56:51',0,NULL,3,1,2,1,NULL,'67mm çŽ¯æž¶   1 '),(3454,651336178002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','diamond196406','diamond2000@sympatico.ca','DANIEL DIAMOND','7815, 55 iÃ¨me AVENUE','LAVAL','QC','CANADA','H7R 4E3','(450) 962-7325','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 12:51:00',0,NULL,3,1,2,1,NULL,NULL),(3455,709625138015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'',22,'hutongstore','wockerjabb','genieysjp2@hotmail.com','Jean-Philippe Genieys','27 rue Haxo','Paris','IDF','FRANCE','75020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 13:06:57',0,NULL,3,1,3,1,' ','åå…‰æ¿æ”¯æž¶  1 RA022498106CN'),(3456,695844199016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','numbo-boss','nortel@nm.ru','Boris Bolotin','Novinskiy bulvar,15-35','Moscow','Russia','RUSSIAN FEDERATION','121099','79851309697','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 13:41:03',0,NULL,3,1,2,1,NULL,' '),(3457,695851276016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','28330042','kenneth.barr@virgin.net','kenneth barr','105 tottenham crescent kingstanding','birmingham','West Midlands','UNITED KINGDOM','B44 0ST','01213555245','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 14:18:04',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶  1\r2m ç¯æž¶   1 \rreflector holder   $20\rYW863684693CN\r'),(3458,612126677001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',5,'AB1305',18.95,'hermeshine','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 14:26:53',0,NULL,3,1,3,1,NULL,'67mm æ©¡èƒ¶ç½©    5 RA022498083CN'),(3459,612128114001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','ecosvit','mv68@yandex.ru','Vyacheslav Makogon or Oleksandra Makogon','vul.E.Konovaltsa, b.14, kv.19.','Rivne','Rivne','UKRAINE','33016','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 14:37:05',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \rCP219437031CN\r'),(3460,651364834002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','rs2783','robert.sideserf@btinternet.com','Robert Sideserf','46 Randall Road, Chandlers Ford','Eastleigh','Hampshire','UNITED KINGDOM','SO535AL','02380267193','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 15:36:28',0,NULL,3,1,4,1,NULL,'717AH   1 \rBallhead  $20\rYW863684682CN\r'),(3461,612139831001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 15:38:07',0,NULL,8,1,17,0,NULL,''),(3462,612141997001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','malleyjf912','francis@des-tek.ca','Francis Malley','683 King George Highway','Miramichi','NB','CANADA','E1V 1N9','(506) 622-8228','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 15:49:16',0,NULL,3,1,2,1,NULL,' 58mm çŽ¯æž¶   1 \r67mm uv    1'),(3465,709671507015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'',1.88,'hutongstore','kimberley5954','kimberleydewar@hotmail.co.uk','Kimberley Dewar','The Old School Ancroft','BERWICK-UPON-TWEED','Northumberland','UNITED KINGDOM','TD151TE','07825604566','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 16:41:36',0,NULL,3,1,2,1,NULL,NULL),(3466,651378116002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','konischev','paraidey@yandex.ru','Maxim Konischev','N. Ostrovskogo St.<br>162/1, 104','Astrakhan','','RUSSIAN FEDERATION','414022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 16:44:49',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´ æ£š  æ¬§æ ‡   2\r45w  8\råŒ…  1 \rCP219437028CN\r'),(3467,709677699015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',8,'',28.96,'hutongstore','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:11:00',0,NULL,8,1,17,0,NULL,''),(3468,695889928016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',9,'',32.22,'hutongstore','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:18:07',0,NULL,3,1,3,1,NULL,'67mm cpl   9\r72mm cpl  8 RA022498097CN'),(3469,651364234002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nexcellpower','lynn@skycom.com.sg','Yee Chiang Yin','84 Flora Road #04-16','Singapore','','SINGAPORE','507001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 17:19:38',0,NULL,3,1,11,1,NULL,NULL),(3470,695890511016,260660051378,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','spamkil','deusexmachina@bk.ru','Igor Shatochin','str. Stavropolskaj haus 1331 apartment 46','Krasnodar','Krasnodarskij kraj','RUSSIAN FEDERATION','350040','+79286606285','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 17:21:07',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ sony   1 '),(3471,612178261001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','dimitrina2010','photodim@walla.com','Dima Noff','7 Kikar Magness','Jerusalem','','ISRAEL','92304','972-545-791720','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 19:13:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RA022498018CN'),(3472,612179969001,110513729693,'Remote Control Wireless Shutter Release Canon 40D 5DII ',1,'AA3228',35.5,'hermeshine','jmaysen','john@maysen.com','John Maysenhoelder','2845 ch Glenday','Sherbrooke','QC','CANADA','J1M0C2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:24:00',0,NULL,3,1,3,1,NULL,'yn126 - c3  1 \rRR815340444CN'),(3473,651410174002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','fardochepq','dominicfortier@videotron.ca','Fortier Dominic','264 Place de Blois','Ste-Julie','QC','CANADA','J3E 2P1','(450) 338-0973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:40:51',0,NULL,8,1,17,0,NULL,NULL),(3474,612182709001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fardochepq','dominicfortier@videotron.ca','Fortier Dominic','264 Place de Blois','Ste-Julie','QC','CANADA','J3E 2P1','(450) 338-0973','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 19:40:51',0,NULL,3,1,2,1,NULL,'72mm é•œå¤´ç›–   canon 1\r77mm é•œå¤´ç›–  canon  1 '),(3475,651411551002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:36',0,NULL,8,1,17,0,NULL,NULL),(3476,651407650002,120564178624,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:36',0,NULL,8,1,17,0,NULL,NULL),(3477,651411420002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:37',0,NULL,8,1,17,0,NULL,NULL),(3478,651407542002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3306',8.4,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:38',0,NULL,8,1,17,0,NULL,' '),(3479,651411489002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','87outlawracer','ronshubin@skinnerautoplex.com','Ron Shubin','2177 S Pacific Hwy','Medford','OR','UNITED STATES','97501','(541) 826-9267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 20:02:38',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ star6    1\r72mm uv      2\r58mm é•œå¤´ç›–   canon   1\rcpl    1\ræ¸å˜è“   + æ¸å˜æ©™  + nd4 + 72mm çŽ¯æž¶   1\r '),(3480,695926172016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','bussyness-martin','bussyness@email.cz','Urbanak Martin','Smilovskeho 12/1391','SlezskÃ¡ Ostrava','Moravskoslezsky Kraj','CZECH REPUBLIC','71000','+420723739708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-24 20:13:34',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3481,651419926002,120601698609,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','vlporton','vporton@012.net.il','Vladislav Porton','Har Metsada 107/39','Ashdod','','ISRAEL','77711','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:34:00',0,NULL,3,1,3,1,NULL,'wf1005    1 RA022498049CN'),(3482,612192475001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:40:43',0,NULL,3,1,2,1,NULL,NULL),(3483,651423562002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','norsk_voyager','mario@mariotomic.com','Mario Tomic','Kornelija Stankovica 11/4','Novi Sad','EUROPE','SERBIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 20:58:12',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3484,651434337002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:06',0,NULL,8,1,17,0,NULL,NULL),(3485,612204820001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:07',0,NULL,8,1,17,0,NULL,NULL),(3486,651434186002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',2,'AA1315',5.98,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 22:01:08',0,NULL,8,1,17,0,NULL,NULL),(3487,651434074002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 22:01:07',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ L   1\ræœºèº«ç›–/é•œå¤´åŽç›–  canon  2\r77mm é•œå¤´ç›– canon 2\r67mm é•œå¤´ç›–  canon 2 RA022498208CN'),(3488,651440476002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','skabbott','scott.abbott@gmail.com','Scott Abbott','7568 Silver View Ln','Raleigh','NC','UNITED STATES','27613-1071','(919) 449-2600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 22:37:46',0,NULL,3,1,1,1,NULL,NULL),(3489,709751724015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','day130369','adamdaydecorator@aol.com','Adam Day','19 Chester Road Lavister','Wrexham','Wrexham','UNITED KINGDOM','LL12 0DN','01244570583','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-24 23:06:03',0,NULL,3,1,2,1,NULL,' æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3490,612215636001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','gkreis','sub@pioneerdatasys.com','Greg Kreis','3710 Running Fox Dr','Marietta','GA','UNITED STATES','30062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-24 23:08:55',0,NULL,3,1,1,1,NULL,NULL),(3491,651448988002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-24 23:46:19',0,NULL,8,1,17,0,NULL,NULL),(3492,651446579002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:20',0,NULL,8,1,17,0,NULL,NULL),(3493,612218438001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:20',0,NULL,8,1,17,0,NULL,'\r'),(3494,612216879001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','ganchor41','alneyuribe@gmail.com','Jose A. Uribe','Calle P esq. Presa de Taveras, Res. E<br>Las Praderas','Santo Domingo','','DOMINICAN REPUBLIC','0001','(829)285-7733','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-24 23:46:21',0,NULL,3,1,3,1,NULL,'å¤§å·ç°å¡   1\r100-150 åå…‰æ¿   1\rcpl   1\ræ¸å˜ç° + 58mm çŽ¯æž¶   1 \rRA022498667CN\ræ¬¾çš„'),(3495,695964646016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','lowstarr2010','leeramsay27@yahoo.co.uk','lee ramsay','5 weedon close carlton','nottingham','Nottinghamshire','UNITED KINGDOM','ng3 7de','01159120047','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-24 23:48:01',0,NULL,3,1,4,1,NULL,'2mx3mèƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡  2\r115w 220v   2\råŒ…   1 \rlighting kit  $30\rYW863684671CN\r'),(3496,709768952015,250601901408,'Wireless Remote Control Cord for Canon 500D/1000D/450D',1,'',11.47,'hutongstore','andrejsaz','andrewaz@inbox.lv','Andrejs Zeicmanis','114 Curragh Birin Castletroy','Limerick','Limerick','IRELAND','353','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 01:02:07',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C1   1 '),(3497,651468407002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','japs14','cezann14@yahoo.ca','cezar alocada','#701-350 Mill Road','toronto','ON','CANADA','M9C5R7','(647) 341-5804','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 02:27:38',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 RA022498199CN'),(3498,651473567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','madermotors','madermotors@hotmail.com','David Mader','28 First St.','Lr. Sackville','NS','CANADA','b4e 1s8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 03:23:43',0,NULL,3,1,2,1,NULL,NULL),(3499,612246881001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','rickblcharlotte','rblong@carolina.rr.com','Rick Blong','2017 Olde Towne Dr','Monroe','NC','UNITED STATES','28110-8806','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 04:11:53',0,NULL,3,1,1,1,NULL,NULL),(3500,651480560002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','bigmikeflan','gtg548u@mail.gatech.edu','Michael James Flanigan','1917 Wedgewood Dr.','Stone Mountain','GA','UNITED STATES','30088','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-25 04:36:10',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹  1 '),(3501,612248872001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','kyle_kuztom','kelix@hotmail.com','Kelix Budiadi','Gedung Kompas-Gramedia<br>Jalan Panjang No.8A , Kebon Jeruk','Jakarta Barat','DKI Jaya','INDONESIA','11530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 04:36:30',0,NULL,3,1,2,1,NULL,'6663a å¿«è£…æ¿    1 '),(3503,651339000002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','thita103','thita@diu.org','rudchadapan ittivarakorn(v.thitasudtho)','40   m  8<br>khlongsong','khlongluang','pathumtani','THAILAND','12120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 05:32:20',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ  M   1 RA022498137CN'),(3504,612259293001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:40',0,NULL,8,1,17,0,NULL,NULL),(3505,651490787002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:40',0,NULL,8,1,17,0,NULL,NULL),(3506,612259155001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:41',0,NULL,8,1,17,0,NULL,NULL),(3507,651490948002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','glrnsh','afekuri@netvision.net.il','&#1493;uri afek','hashomrim 36','tivon','','ISRAEL','36034','972-54-5680539','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 06:55:41',0,NULL,3,1,3,1,NULL,'55mm æ©¡èƒ¶ç½©   1\r58mm æ©¡èƒ¶ç½©   1\r67mm æ©¡èƒ¶ç½©   1\r77mm æ©¡èƒ¶ç½©    1 RA022498145CN'),(3508,612260468001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','hellog','hellog001@gmail.com','ZHI LI GUAN','189 10th St','Oakland','CA','UNITED STATES','94607-4838','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 07:09:40',0,NULL,3,1,1,1,NULL,NULL),(3509,612295702001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','img59','henrik_edberg@msn.com','Henrik Edberg','SandstensvÃ¤gen 9','Uppsala','Uppsala','SWEDEN','75267','073-507 37 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 12:11:17',0,NULL,3,1,2,1,NULL,NULL),(3510,651552807002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran BaÄ‡a','PavletiÄ‡eva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 15:02:23',0,NULL,3,1,5,1,NULL,'4ç¯å¤´ æ£š   2  æ¬§æ ‡  \rCP219437014CN\r'),(3511,612325227001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','spacefly70','wouter.w.v.d.kwaak@versatel.nl','wouter van der kwaak','preludeweg 44','Alphen aan den rijn','','NETHERLANDS','2402HD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 15:12:34',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´   1  æ¬§æ ‡  1 '),(3512,651555922002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','rajasekaranamie','rajay1000@yahoo.com','R. Rajasekaran, Assistant Engineer','4/998, TNEB Office, Sathy main road,<br>GANESAPURAM, S.S Kulam Via','Coimbatore  107','TN','INDIA','641 107','9443087381','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 15:23:53',0,NULL,3,1,2,1,NULL,NULL),(3513,651558871002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',2,'AC1203',11.2,'hermeshine','sdsia','weiming88@gmail.com','Steve Sia','502 winding rose dr','rockville','md','UNITED STATES','20850-2869','(301) 762-6508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 15:36:19',0,NULL,3,1,1,1,NULL,'å¤§å·é•œå¤´ç­’   2 '),(3514,709895313015,250746712937,'55mm Graduated Neutral Density Filter Gradual Grey 55',1,'',4.8,'hutongstore','lerroyjenkins','npmullins@hotmail.co.uk','NEIL MULLINS','53 CARISBROOKE CRES','POOLE','DORSET','UNITED KINGDOM','BH15 4LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 15:56:57',0,NULL,3,1,2,1,NULL,'ç»¿å¶55mm æ¸å˜ç°  1 '),(3515,651607712002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','goodiegraber','hugzankizzez@hotmail.com','Cassandra Norman','147 Rougebank dr','markham','ON','CANADA','l3s4k5','(647) 209-2277','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 19:10:07',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…   1 RA022498052CN'),(3516,651609582002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','54lynne','lmuellernyc@gmail.com','Lynne  Feerick','255 cabrini blvd<br>Apt. 6c','new york','NY','UNITED STATES','10040-3614','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 19:18:53',0,NULL,3,1,1,1,NULL,NULL),(3517,709955039015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','garywilliams11','garywilliams0604@hotmail.com','gary williams','11 tomlinson street','rochdale','Lancashire','UNITED KINGDOM','OL11 3EW','01706668756','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 19:28:02',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3518,696155011016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','kareca1982','bruno__reis@hotmail.com','BRUNO FONSECA','FLAT 1 WARRIOR COURT 244 COLD HARBOUR LANE','LONDON','London','UNITED KINGDOM','SW9 8SE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-25 19:28:14',0,NULL,3,1,2,1,NULL,'  æœºèº«ç›–/é•œå¤´åŽç›–  canon   1 '),(3519,612391599001,110566891585,'Photo Studio Background Support 2m x 3m (7Ã—10 ft) BAG',1,'AO0016',79.99,'hermeshine','barji13','barbara.kundolff@jahmasta.com','barbara kundolff','9 av gaston cabrier','salon de provence','Provence-Alpes-CÃ´te d\'Azur','FRANCE','13300','0645270493','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 20:00:18',0,NULL,8,1,17,0,NULL,''),(3520,612393664001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','kolan07','kokulan07@msn.com','Kokulan Shanmuganathan','23 Mare Cres.','Etobicoke','ON','CANADA','M9W7E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 20:09:24',0,NULL,3,1,2,1,NULL,NULL),(3521,612398325001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','barji13','barbara.kundolff@jahmasta.com','barbara kundolff','9 av gaston cabrier','salon de provence','Provence-Alpes-CÃ´te d\'Azur','FRANCE','13300','0645270493','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-25 20:29:21',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶   3 \r 2mx3m èƒŒæ™¯æž¶   1          reflector holder  $30\rYW863684660CN\r'),(3522,651632267002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','bloem32','onnobloemers@zonnet.nl','Onno Bloemers','Wikveld 18','\'s-Hertogenbosch','','NETHERLANDS','5236 EA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 20:54:18',0,NULL,3,1,2,1,NULL,NULL),(3523,709982426015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','a.ziakova07','a.ziakova@gmail.com','Andrea Ziakova','Zaporozska 6','Bratislava 5','Slovakia','SLOVAK REPUBLIC','851 01','+421905871436','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:03:59',0,NULL,3,1,2,1,NULL,NULL),(3524,612408230001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','jdavis9184','jeffdavis82778@gmail.com','jeffrey Davis','12689 stallion CT','Jacksonville','FL','UNITED STATES','32223-2094','(904) 260-9793','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 21:14:40',0,NULL,3,1,3,1,NULL,'RA022498110CN '),(3525,651640190002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','migel_999','migel999@gmail.com','Mikhail Belenkov','street Twardowski, House 4, Building 2, apartment 33','Moskow','','RUSSIAN FEDERATION','123458','89267190998','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 21:30:39',0,NULL,3,1,2,1,NULL,NULL),(3526,709965591015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','kavacca','kavacca@hotmail.com','Jenny Rothwell','Sunnyside Dunmore East','Co.Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:51:37',0,NULL,8,1,17,0,NULL,NULL),(3527,709964996015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'',3.76,'hutongstore','kavacca','kavacca@hotmail.com','Jenny Rothwell','Sunnyside Dunmore East','Co.Waterford','Waterford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-25 21:51:39',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›– canon  2\r58mm é•œå¤´ç›– canon 2 '),(3528,651647136002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','ingeborgsta123','ingeborg.stoea@c2i.net','Ingeborg StÃ¸a SÃ¸land','Gamle Tempelvei','Eggedal','Eggedal','NORWAY','3359','99637804','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-25 22:09:10',0,NULL,3,1,2,1,NULL,NULL),(3530,651651072002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bourbonbuzz','johngordon@worldnet.att.net','john gordon','1620 SW 27th St','troutdale','OR','UNITED STATES','97060-1983','(503) 206-9942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-25 22:26:28',0,NULL,3,1,1,1,NULL,NULL),(3531,651654412002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','nestorpr1','nestorapr1@hotmail.com','Nestor A Reyes','Str. 17 D-3<br>Urb. Villa Nueva','Caguas','PR','UNITED STATES','00727','','NoPaymentFailure','CheckoutComplete','Other','2010-12-25 22:44:41',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RA022498066CN'),(3532,651676191002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','eugepark','elpbus@gmail.com','Gene Park','10115 Palace Way<br>Apt C','Richmond','VA','UNITED STATES','23238-5653','(520) 205-2391','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 01:00:27',0,NULL,3,1,1,1,NULL,NULL),(3533,651670386002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','luisaccardoso','luisaccardoso@gmail.com','Luisa Cardoso','12620 Ranger Rd','Leavenworth','WA','UNITED STATES','98826-9174','(206) 390-1685','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 01:56:37',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(3534,612459071001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','dajedi88','ijedi88@sbcglobal.net','george michael francisco','3808 Amy Ct','union city','CA','UNITED STATES','94587','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:45:46',0,NULL,3,1,1,1,NULL,'æ™®é€šçƒ­é´ç›–  1 '),(3535,612459009001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:09',0,NULL,8,1,18,0,NULL,NULL),(3536,612458486001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:10',0,NULL,8,1,17,0,NULL,NULL),(3537,651690269002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB3402',6.99,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:11',0,NULL,8,1,17,0,NULL,NULL),(3538,651690196002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5,'hermeshine','lsheltie65ld','lsheltie@bellsouth.net','Laurie Sanderson','1511 Valley Brook Rd','Millbrook','AL','UNITED STATES','36054-4342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:48:11',0,NULL,3,1,1,1,NULL,'52mm é•œå¤´ç›– nikon  2\rjjc hs-1 è…•å¸¦   1\rå°å·å†…èƒ†åŒ… nikon  1\rlenspen    1 '),(3539,612460344001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','missxalohaxhula','f_lagpacan@hotmail.com','Flordeliz Lagpacan','2 EMBARCADERO CENTER, PROMENADE LEVEL<br>EMBARCADERO DENTISTRY','SAN FRANCISCO','CA','UNITED STATES','94111','(408) 666-0365','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 02:54:28',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3540,612466354001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','coyote488','imwilley@telusplanet.net','ian willey','1020 Moyer Drive','Sherwood Park','AB','CANADA','t8a1e6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 03:45:25',0,NULL,3,1,2,1,NULL,' '),(3541,651701044002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',29.4,'hermeshine','evabluecanada','eva@evablue.com','eva blue','2025 Parthenais Suite 259','Montreal','QC','CANADA','h2k 3t2','(514) 808-2583','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 04:03:42',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´   3 RA022498070CN'),(3543,612473601001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','windblown466','windblown466@mchsi.com','David Umphfleet','6110 E. Oakwood Dr.','Pleasant Hill','IA','UNITED STATES','50327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 04:50:53',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ  star 6   1 '),(3544,710083058015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'',5.8,'hutongstore','thotties','cher_jughead@hotmail.com','Cheryl Ou','4B Boon Tiong Road #07-33','default','','SINGAPORE','165004','97640206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 07:22:10',0,NULL,3,1,11,1,NULL,'72mm æ¸å˜ç°  1 ç»¿å¶ '),(3545,696285355016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'',7.56,'hutongstore','ruslan201074','polonij210@mail.ru','Ruslan Bekjashev','Agrarnaya-14 Alexandrovskaya','S.Peterburg','','RUSSIAN FEDERATION','196631','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 08:20:35',0,NULL,3,1,2,1,NULL,NULL),(3546,651297480002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','oho75','t_ketchala75@hotmail.com','TATTIWAT TARADAMRONGLERD','797 Samsen Road,Tanonnakornchaisri<br>Dusit','default','BA','THAILAND','10300','66848919585','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 08:57:29',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹   1 '),(3547,612499662001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','dor_guy','dor_guy@netvision.net.il','Guy Dushansky','Elishva Kaplan 28','Kiryat-Haim','Israel','ISRAEL','26262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 09:04:21',0,NULL,3,1,3,1,NULL,'RA022498123CN '),(3548,651738408002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','1234beanz','4dnewson@gmail.com','Dean Newson','36a Popes Road','Woonona','New South Wales','AUSTRALIA','2517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 09:35:30',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3549,612516264001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','arnaud6794','arnaud94@gmail.com','Arnaud  CHOQUART','7 rue de Choisy','ALFORTVILLE','ÃŽle-de-France','FRANCE','94140','01.43.78.18.77','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 10:34:09',0,NULL,3,1,4,1,NULL,'6662a   1 \rtripod  $15\rYW863684656CN\r'),(3550,612522082001,110532007214,'77mm CPL Circular Polarizing Filter 77 D40 D60 D80',1,'AA3314',6.5,'hermeshine','vijars84','vijars.prieditis@gmail.com','Vijars Prieditis','Hospitalu 28/4<br>Riga','Riga','','LATVIA','LV-1013','+371 29501449','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 11:06:50',0,NULL,3,1,2,1,NULL,NULL),(3551,651760475002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','twogiantscoops','twogiantscoops@aol.com','Chris Marshall','4 Veasy Park<br>Wembury','Plymouth','Devon','UNITED KINGDOM','PL9 0ES','01752862116','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 11:28:12',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3552,651771017002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','squd','aliaksandr.kokhno@gmail.com','Aliaksandr Kokhna','Esenina str<br>35-1-144','Minsk','','BELARUS','220025','+375296872411','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 12:22:40',0,NULL,3,1,2,1,NULL,'æ¸å˜è“   1 '),(3553,710149405015,250692240254,'Remote Control Cord Shutter Nikon D300/D200/D700â€‹ MC-30',1,'',2.98,'hutongstore','4tatanka','f.verhoef@hetnet.nl','Frank Verhoef-Roosenburg','Dolderseweg 164','Den Dolder','','NETHERLANDS','NL 3734 BN','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 12:39:35',0,NULL,3,1,2,1,NULL,'RS-N1   1 '),(3554,651777128002,120564178812,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','miki4853','ecines@gmail.com','Miguel Toral Garcia','calle Medico Pedro Herrero 23 6Âº B','Alicante','Comunidad Valenciana','SPAIN','03006','680331197','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 12:53:57',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  + 52mm çŽ¯æž¶  1 '),(3555,651782484002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mauricetsl','maurice.tjonsoeilen@gmail.com','Suralco Aireen Ranoesendjojo','3640 Nw 115th Ave<br>Ferm Suralco','Doral','FL','UNITED STATES','33178-1863','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 13:18:20',0,NULL,3,1,1,1,NULL,NULL),(3556,651788453002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','martisak','martin.isaksson@gmail.com','Martin Isaksson','Bergsgatan 30','Stockholm','','SWEDEN','11223','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 13:46:18',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 RA022498154CN'),(3557,696365708016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'',4.38,'hutongstore','rysavabrada1961','rysavabrada@seznam.cz','Jaromir Fajkus','Frantiska Krizka 26','Praha 7','','CZECH REPUBLIC','17000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 14:05:00',0,NULL,3,1,2,1,NULL,'XLé•œå¤´ç­’   1 '),(3558,651828813002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jayv99','jvance@rogers.com','Jason   Vance','22 Hunt St','Guelph','ON','CANADA','N1L1T7','(519) 822-7769','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 16:19:48',0,NULL,3,1,2,1,NULL,NULL),(3559,650750625002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',4,'AA3202',74,'hermeshine','ame200968','quicolaras@hotmail.com','lara martinez fenoll','Escultor ValentÃ­n GarcÃ­a Quinto nÂº7 4ÂºA','Albatera','Alicante','SPAIN','03340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 17:04:51',0,NULL,3,1,3,1,NULL,'çˆµå½±æ— çº¿  N3   4 RA022498021CN'),(3560,696426495016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'',6.1,'hutongstore','adaslux','adaslux@wp.pl','Julia Skupny','43 Ashley Road','London','London','UNITED KINGDOM','N19 3AG','07518297453','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-26 17:11:33',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  nikon  1 '),(3561,651844415002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rangercb11','ranger_cb@mail.ru','Yuriy Kuznecov','Korablestroiteley 38/2, 83','Nizhny Novgorod','Nizhegorodskaya','RUSSIAN FEDERATION','603158','+7904-398-2495','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 17:14:14',0,NULL,3,1,2,1,NULL,NULL),(3562,612616769001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','spinifer','spinifer@aol.com','Nathan H. Nazdrowicz','817 Elkton Rd','Newark','DE','UNITED STATES','19711-7725','(302) 893-3645','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 17:20:50',0,NULL,3,1,1,1,NULL,'çƒ­é´ç›–  1 '),(3563,710290931015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','dmcd1973','tinoran@gmail.com','David  McDermott','Tinoran Hill','Baltinglass','Wicklow','IRELAND','ww','0879888750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-26 19:01:27',0,NULL,3,1,2,1,NULL,' '),(3564,612658468001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','onthere','onderyapici@gmail.com','Ã–NDER YAPICI','uludag.cad.pehlivan sok.<br>anadolu apt.31/10 Osmangazi/Ã‡ekirge','Busa','','TURKEY','16010','2396837','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:02:03',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  58mm çŽ¯æž¶ 1 RA022498450CN\r'),(3565,612661207001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','ferdepalma','gongorafernando@gmail.com','Fernando Gongora','Gabriel Roca 14 1 a','Palma Mallorca','Baleares','SPAIN','07014','687548134','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:06:55',0,NULL,3,1,2,1,NULL,NULL),(3566,651897216002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:19:52',0,NULL,3,1,5,1,NULL,'4ç¯å¤´æ£š    2   æ¬§æ ‡  CP219437005CN\r'),(3567,651904606002,120581161784,'Light Stand 2m / 6\'56\" for photo studio lighting Ã—2',1,'AKT031',59,'hermeshine','jusosa','jusosa@msn.com','juan soberats','Taronger nÂº1   1Âº-4Âª','palma de mallorca','Baleares','SPAIN','07008','639771560','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 19:49:15',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  ç™½ç›’   2 \rlight stand   $18\rYW863684645CN\r'),(3568,612648567001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','littlemamajan','janbates@eastlink.ca','Janine Bates','199 Pictou Road','Truro','NS','CANADA','B2N 2S7','(902) 895-2459','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:54:28',0,NULL,8,1,17,0,NULL,NULL),(3569,651878553002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','littlemamajan','janbates@eastlink.ca','Janine Bates','199 Pictou Road','Truro','NS','CANADA','B2N 2S7','(902) 895-2459','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 19:54:29',0,NULL,3,1,2,1,NULL,'58mm é•œå¤´ç›–  canon  1\r58mm uv    1 '),(3570,612697096001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','stephane_rp_91','slesmond@free.fr','StÃ©phane Lesmond','7, allÃ©e CÃ©zanne','Les Ulis','Ile de France','FRANCE','91940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 20:40:54',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°   1 '),(3571,612705432001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','maxl_71','dmarkus@gmx.at','Markus Dobersberger','Spazenhofstrasse 26','Linz','','AUSTRIA','4040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 21:05:13',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…   æ— å­—   1 '),(3572,612708976001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','etkdlk','david.kyle10@gmail.com','David Kyle','100 Glade Spgs','Anderson','SC','UNITED STATES','29621','(864) 224-5199','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 21:16:34',0,NULL,3,1,1,1,NULL,NULL),(3573,612704606001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','sifami','sifami26@hotmail.com','simon  fariza miralles','C/Alcoy n 1 pta 6','valencia','Comunidad Valenciana','SPAIN','46004','653352744','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-26 21:30:18',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶  ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶  2\r50-70 æ£š   æ¬§æ ‡  2\r115w 220v    2\råŒ…    1\rlighting kit   $30\r YW863684634CN\r'),(3574,612151539001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','nooosa89','eaak89@hotmail.com','Enas Alkhudairy','320 Memorial Dr<br>Rm 221','Cambridge','MA','UNITED STATES','02139','(617) 999-2376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-26 21:49:33',0,NULL,3,1,1,1,NULL,'æ˜Ÿå…‰é•œ star4   1 '),(3576,612723341001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','rafael.chiti','rafaelchiti@gmail.com','Rafael Chiti','Av. Callao 410. 5th Floor','Capital Federal','Buenos Aires','ARGENTINA','1022','541130615564','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 22:08:59',0,NULL,3,1,2,1,NULL,'52mm æŽ¥å£çŽ¯   1 '),(3577,612743005001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','mikhail_kriviniouk','mikhail_kriviniouk@yahoo.co.uk','Mikhail Kriviniouk','ul. Karla Libknekhta<br>d. 16, kv. 21, tel. +79122401191','Ekaterinburg','','RUSSIAN FEDERATION','620000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-26 23:30:17',0,NULL,3,1,2,1,NULL,NULL),(3578,612754304001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','melisme1972','melody@polakow.com','melody polakow','4 Freedom Cir<br>Apt 10','portsmouth','NH','UNITED STATES','03801-5942','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 00:25:34',0,NULL,8,1,17,1,NULL,''),(3579,651989313002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','melisme1972','melody@polakow.com','melody polakow','4 Freedom Cir<br>Apt 10','portsmouth','NH','UNITED STATES','03801-5942','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 00:27:11',0,NULL,3,1,1,1,NULL,'60cm 2in1 åå…‰æ¿   1 \r40CM æ£š   1 '),(3580,612749914001,110513730296,'Remote Control Wireless Shutter Release Canon 450D 500D',1,'AA3227',35.5,'hermeshine','roch4t','roch4t@yahoo.com','Ken Rochefort','1858 Cherrywood Trail','London','ON','CANADA','N6H0E2','(519) 452-2750','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 00:35:31',0,NULL,3,1,3,1,NULL,'YN126-C1   1 RA022498035CN'),(3581,612767889001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 01:34:34',0,NULL,8,1,17,0,NULL,NULL),(3582,652002011002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 01:34:34',0,NULL,8,1,17,0,NULL,NULL),(3583,612766565001,110316941375,'Remote Shutter Release for Canon PowerShot G10 =RS-60E3',1,'AA3210',4.3,'hermeshine','nogood204','ndepass@cogeco.ca','Neil DePass','3002- 100 Main St. East','Hamilton','ON','CANADA','L8N 3W4','(905) 818-4598','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 01:36:01',0,NULL,3,1,2,1,NULL,'RS-C1   1 \r58mm é•œå¤´ç›– canon   1\rlenspen   1'),(3584,612777796001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 02:19:41',0,NULL,3,1,2,1,NULL,NULL),(3585,612778092001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','piscies75','stephen.dunn@rogers.com','Stephen Dunn','42 Haslett Ave.','Toronto','ON','CANADA','M4l 3r2','(416) 691-3436','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 02:19:52',0,NULL,3,1,2,1,NULL,'nikon -52  åæŽ¥çŽ¯  1 '),(3586,612781094001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','clu014','chiehfu@gmail.com','Chieh Fu Lu','5364 Kalanianaole Hwy','Honolulu','HI','UNITED STATES','96821-1961','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 02:34:45',0,NULL,3,1,1,1,NULL,NULL),(3587,612789256001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','beneluxboy','gary@encanto.org','Gary Moore','6920 Roosevelt Way NE<br>PMB 283','Seattle','WA','UNITED STATES','98115-6635','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 03:21:22',0,NULL,3,1,1,1,NULL,NULL),(3588,652033734002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','wwiijeep','jgcg99@usa.com','James Gray','63 Palomino Rd','Springfield','IL','UNITED STATES','62702-1590','','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 03:57:45',0,NULL,3,1,1,1,NULL,'sony èƒŒå¿ƒ åŽš  xxxl   1 '),(3589,612813713001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1301',10.02,'hermeshine','vdrum4250','onlay@cox.net','Tuan Duc Pham','20 Goldstone','Irvine','CA','UNITED STATES','92614-7050','(323) 691-7426','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 06:19:46',0,NULL,3,1,1,1,NULL,NULL),(3591,652064373002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','aksirmaj','jamrro@gmail.com','Peter Jamriska','Matuskova 7','Dolny Kubin','Dolny Kubin','SLOVAK REPUBLIC','02601','00421907813628','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 08:04:33',0,NULL,3,1,2,1,NULL,NULL),(3592,696684092016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'',2.75,'hutongstore','paul123evenlegs','pauldhoult2@msn.com','Paul Hoult','16 legion Way East Wittering','CHICHESTER','West Sussex','UNITED KINGDOM','PO20 8PA','01243673189','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 08:29:57',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ å¥¥æž—å·´æ–¯  1 '),(3603,612860926001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','vag_dr','vdrainas@mech.upatras.gr','Vagelis Drainas','Terma Geo.Xaralampopoulou/Leukwsias<br>Agios Vasilis/Rio','Patras','Achaias','GREECE','26500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 11:59:24',0,NULL,8,1,17,0,NULL,''),(3593,652071748002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',28.99,'hermeshine','duanec26','duanec26@yahoo.com','Duane Cornish','21618 115th Ct','Cambria Heights','NY','UNITED STATES','11411-1109','(718) 200-2678','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-27 09:03:58',0,NULL,3,1,1,1,NULL,'nikon 3m ttlçº¿   1 '),(3594,696292083016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'',43.8,'hutongstore','sharabanstudio','asya.lukin@gmail.com','Asya (Anna) Lukin','22 A / 9  Bruria str','Jerusalem','Jerusalem','ISRAEL','93184','+972545588075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 09:13:51',0,NULL,3,1,3,1,NULL,'æ–œè‡‚ 1\r2m ç¯æž¶  1 \rRR815340095CN'),(3595,652075402002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','kravtsovas','kravtsovas@gmail.com','Kravtsov Alexandr','Aliya Moldagulova, 2/1 - 3','Aktobe','','KAZAKHSTAN','030019','701-244-1484','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 09:29:45',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´ æ¬§æ ‡   1\råå…‰ä¼ž    1 \rRR815340104CN'),(3596,652078225002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mani_esperpento','lovecore_s@hotmail.com','Jesus Javier Queizan Perez','c/ Las Lilas NÂº5 1ÂºA','Salamanca','Castilla y LeÃ³n','SPAIN','37004','680623596','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 09:48:52',0,NULL,3,1,2,1,NULL,NULL),(3597,710529492015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','efecu','germz666@hotmail.com','GERARD0 MARTÃN ZERPA','Pasaje la barca nÂº 3 - bajo A - B San AndrÃ©s','Arucas','Canarias','SPAIN','35414','616403544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 10:29:54',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  canon  1 '),(3599,652093585002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,â€‹A350,A380 user',1,'AA2106',40,'hermeshine','follabotes13','polite13@hotmail.com','Pierre L TORNERO','94 Church Crescent','Newtownabbey','Co Antrim','UNITED KINGDOM','BT36 6ET','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 11:19:59',0,NULL,3,1,3,1,NULL,'sony æ‘„å½±èƒŒå¿ƒ XXXL  1 \rRR815340020CN\r'),(3600,612854442001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','spinebass','udu.wudu@gmail.com','Deniss Arsenins','Anninmuizas bulvaris 38/3-46C','Riga','Latvia','LATVIA','LV-1067','+371 26411374','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 11:20:19',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ æ¬§æ ‡  1 '),(3601,710541546015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'',1.88,'hutongstore','khan2510','elston.teresa@googlemail.com','douglas elston',' 9 park road','holbeach','Lincolnshire','UNITED KINGDOM','pe12 7ee','01406423682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 11:26:11',0,NULL,3,1,2,1,NULL,NULL),(3604,652100826002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3201',70,'hermeshine','sifami','sifami26@hotmail.com','simon  fariza miralles','C/Alcoy n 1 pta 6','valencia','Comunidad Valenciana','SPAIN','46004','653352744','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 12:04:36',0,NULL,3,1,3,1,NULL,'ç»¿è‰²/è“è‰² èƒŒæ™¯å¸ƒ 1 \rRA022498684CN\r\r'),(3605,612868454001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','theleff','leif.madland@lyse.net','Leif Arne Madland','Kalamyrveien 15','hommersaak','','NORWAY','4310','+4748023721','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 12:37:46',0,NULL,3,1,2,1,NULL,NULL),(3606,612875181001,110531023352,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','vag_dr','vdrainas@mech.upatras.gr','Vagelis Drainas','Terma Geo.Xaralampopoulou/Leukwsias<br>Agios Vasilis/Rio','Patras','Achaias','GREECE','26500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:14:08',0,NULL,3,1,2,1,NULL,' 52-58 åŒé˜³çŽ¯  1 \r58-58 åŒé˜³çŽ¯  1'),(3607,612878652001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','bledixhafa','bledix@gmail.com','Bledar Xhafaj','Rruga: \"Vllazen Huta\" Nd:7 , H:11 , Ap:19 , Kodi Postar: 1017<br>Tirane','Tirane','Albania','ALBANIA','00355','00355694007155','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:31:10',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›– Nikon  1 '),(3608,710571547015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'',45.99,'hutongstore','lapexxx','lapexxx1@gmail.com','Tomas Lapenas','1 rossorry court  rossorry church rd.','enniskillen','Fermanagh','UNITED KINGDOM','bt74 7nh','07518635459','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-27 13:38:40',0,NULL,3,1,4,1,NULL,'6662a+6160h   1\rtripod $20 \rYW863684774CN\r'),(3609,612880312001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','portokali-2008','photo.linap@gmail.com','lina petrauskiene','P.Box 938 Ag. Nikolaou<br>Paiania','Athens','Europe','GREECE','19002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 13:40:30',0,NULL,3,1,2,1,NULL,NULL),(3610,696745356016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','fuzzywitch43','fuzzywitch@hotmail.co.uk','M CHAPMAN','59 TIBBATTS CLOSE WOODGATE VALLEY','Birmingham','West Midlands','UNITED KINGDOM','B32 3TE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 13:46:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3611,612876785001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','rosalesproductions','rommar_10@yahoo.com','ROMMEL ROSALES','c/o ROSALES PRODUCTIONS<br>B3 STC Shopping Arcade (Back of Unicity Store)','Quezon Ave., Iligan City','LANAO DEL NORTE','PHILIPPINES','9200','0632214305','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 14:04:42',0,NULL,3,1,2,1,NULL,NULL),(3613,612892919001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','taladrin.simon','taladrin@andaluciajunta.es','Jose Luis SimÃ³nLÃ³pez','C/ CÃ¡novas del Castillo nÂº14 2ÂºB','AlcalÃ¡ de Henares','Madrid','SPAIN','28807','619661971','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 14:39:36',0,NULL,3,1,2,1,NULL,NULL),(3614,696765243016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'',3.58,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 14:43:49',0,NULL,3,1,2,1,NULL,NULL),(3615,696770078016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','funsingh','amaroffrance@hotmail.co.uk','Amar Singh','25 Avenue George Pompidou','Suresnes','Ile-de-France','FRANCE','92150','0033687725889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 15:02:12',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3618,612897903001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','nakmus','fruityfroob@hotmail.com','Erlend Aunan','Njords Vei 43a','Trondheim','','NORWAY','7032','90217255','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 15:02:16',0,NULL,3,1,2,1,NULL,NULL),(3619,707944610015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','camilasketch2010','camilasketch@yahoo.com','ruby','58a marchmont st','london','London','UNITED KINGDOM','wc1n 1ab','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-27 15:31:23',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š  è‹±æ ‡   2\r115w 220v   2\råŒ…    1\rlighting kit  $30 \rYW863684741CN\r'),(3620,710609719015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'',4.5,'hutongstore','mncompmn','mncomputers@abv.bg','MN Computers','Slavcho Karnalov 4a','Bratsigovo','Pazardjik','BULGARIA','4579','+359879608088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 15:51:15',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  canon   1 '),(3621,710615616015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,8,1,17,0,NULL,NULL),(3622,652158976002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','sarahrwallace','sarah.wallace@lonoke.k12.ar.us','Sarah Wallace','102 Cotton Ln','Lonoke','AR','UNITED STATES','72086','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 16:20:10',0,NULL,3,1,1,1,NULL,NULL),(3623,652168031002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0024',9,'hermeshine','volkswfreak','rvacjd@hotmail.com','Ruben Vanlauwe','Philemon Sabbestraat 14','Staden','West Vlaanderen','BELGIUM','8840','0496485885','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 16:51:28',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…   1 '),(3624,710617125015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,8,1,17,0,NULL,NULL),(3625,710618781015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'',3.99,'hutongstore','argyllrab','argyll9193@msn.com','Robert Maclennan','16 Maxwelton Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G331LR','01417706446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 16:19:02',0,NULL,3,1,2,1,NULL,'3pcs æ»¤é•œè¢‹  2\r77mm çŽ¯æž¶   1\r '),(3626,710638397015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','garcia8914','salva.garcia.gil@gmail.com','Salvador Garcia Gil','Universitat Jaume I - Rectorado Avda. Sos Baynat, S/N','CastellÃ³n de la Plana','Comunidad Valenciana','SPAIN','12071','696408557','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 17:13:52',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3627,612939019001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','giannispatra1972','giannisclick@gmail.com','Giannis Sarigiannis','Zakynthou 27','Patra','Ahaia','GREECE','24441','6938929178','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 17:26:25',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3628,612944086001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:41',0,NULL,8,1,17,0,NULL,NULL),(3629,652178018002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:42',0,NULL,8,1,17,0,NULL,NULL),(3630,612942751001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','sparcules','sparko1976@yahoo.com','Kevin Carlborg','5636 Pershing Blvd','Kenosha','WI','UNITED STATES','53144-2426','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 17:44:42',0,NULL,3,1,1,1,NULL,'å“èƒœ 3.0  è†œ   1\r58mm é•œå¤´ç›–  canon   3\r58mm æ©¡èƒ¶ç½©    1 '),(3631,612951767001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','xsolp','petter.solbakken@gmail.com','Petter Solbakken','Bratsbergvegen 34B','Trondheim','SÃ¸r-TrÃ¸nderlag','NORWAY','7037','95892295','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 18:05:04',0,NULL,3,1,2,1,NULL,NULL),(3632,612952959001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE1301',9.8,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÃ‰LIX ARRANZ MARTÃN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÃA DE EDUCACIÃ“N','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 18:07:56',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ çƒå°   1 '),(3633,612954102001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','megmoser3','meganhmoser@gmail.com','Megan Moser','1680 Aliwood Way','Bountiful','UT','UNITED STATES','84010-5990','(801) 928-1868','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 18:11:34',0,NULL,3,1,1,1,NULL,NULL),(3634,652196243002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bahus57','bahus1957@aol.com','john kudlacz','8657 village park ct','orangevale','CA','UNITED STATES','95662','','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 18:19:34',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xxl   1 \rRR815340152CN'),(3636,652207021002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mista5four','l.hoover@yahoo.com','Linda  Hoover','4333 14th Ave S','Minneapolis','MN','UNITED STATES','55407-3225','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 18:50:37',0,NULL,3,1,1,1,NULL,NULL),(3637,652211033002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','bsery974','ben.sery@orange.fr','Benjamin SERY','109 route Jules Reydellet<br>La Bretagne','SAINTE-CLOTILDE','RÃ©union','REUNION','97490','0692929840','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 19:00:44',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ ND8   1 '),(3638,612974043001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','pobiefuna','pobiefuna@gmail.com','peter Obiefuna','4711 190 St','Edmonton','AB','CANADA','t6m 2s9','(780) 707-2561','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 19:09:19',0,NULL,3,1,3,1,NULL,'ç¢—ç½© p1    1 \rRR815340121CN\r'),(3639,696897459016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',3,'',11.34,'hutongstore','r3dm4nn','r3dm4n_n@hotmail.com','Sam  Cooper','5 York Way','St.Ives','Cambridgeshire','UNITED KINGDOM','pe27 3du','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 20:38:46',0,NULL,3,1,2,1,NULL,NULL),(3640,710730222015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'',13.9,'hutongstore','chacho16','rbordon16@yahoo.es','Roberto  Bordon Aleman','Parroco Roman Navarro 16','Castillo del Romeral','Las Palmas de Gran Canaria','SPAIN','35107','928732440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 20:52:04',0,NULL,3,1,2,1,NULL,'50cm æ£š  1 '),(3641,652251432002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','isinhcanon','sinhvuhoang@yahoo.com','Sinh VU HOANG','6 boulevard Joseph Vallier','Grenoble','Franche-ComtÃ©','FRANCE','38000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-27 20:57:22',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 \rRR815340078CN\r'),(3642,613011873001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:05:02',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  2  æ¬§æ ‡  '),(3643,613013007001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE1301',31.8,'hermeshine','viperagp','gts@omikron.tv','George Tsartsianidis','Aristotelous 29','kozani','Kozani','GREECE','50100','003012461037711','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:06:09',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   4 \rRR815340016CN'),(3644,710737126015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'',6.1,'hutongstore','opietro77','piotrp77@interia.pl','Piotr Poprawski','22 Robins Way','Bicester','Oxfordshire','UNITED KINGDOM','OX26 6XJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-27 21:08:29',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… canon 1 '),(3645,613014049001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',2,'AE3601',36,'hermeshine','je21nn','je72184nn@yahoo.com','F & M Bank attn: JENN','2205 hanover pike','hampstead','md','UNITED STATES','21074','(410) 374-3436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 21:08:52',0,NULL,3,1,3,1,NULL,'115w 110v   2 \rRR815340055CN\r'),(3646,652168898002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hudsioo61','hudsioo@gmail.com','Sommart Sukmanee','61/13 Lamun Cafe\' Chongpon Rd.<br>T.Phapathomjadee Maung','Nakornpathom','Thailand','THAILAND','73000','(087)7009004','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 21:42:10',0,NULL,3,1,2,1,NULL,NULL),(3647,613028284001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','russellnedo','gayle_russell@mac.com','Gayle Russell','20789 Sam Rd','Albemarle','NC','UNITED STATES','28001','(704) 986-2559','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-27 22:00:43',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3648,710771013015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',29,'hutongstore','ilmaffobay','ilmaffo@gmail.com','Daniele Maffeis','Via Leopardi n.4','Corsico','MI','ITALY','20094','3476358398','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-27 22:47:28',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 \rRR815340081CN'),(3649,652281714002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','ylellanclaudia','nallelygarcia88@hotmail.com','Eduardo  garcia','501 S Carter St.','clarksville','AR','UNITED STATES','72830','(479) 774-4173','NoPaymentFailure','CheckoutComplete','Other','2010-12-27 22:49:12',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   2\råŒ…   1 \rlighting kit   $30\rYW863684752CN\r'),(3650,613051897001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT007',64.99,'hermeshine','expatriate_ca','pasadenabear@gmail.com','Kevin Bishop','542 E Claremont St','Pasadena','CA','UNITED STATES','91104-3640','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-27 23:41:06',0,NULL,3,1,4,1,NULL,'çº¢å¤´ç¯   1\r800w 110v   1 \rlight  $20\rYW863684763CN\r'),(3651,696950516016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'',5.8,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:56',0,NULL,8,1,17,0,NULL,NULL),(3652,696949457016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:56',0,NULL,8,1,17,0,NULL,NULL),(3653,710778203015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'',3.5,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:57',0,NULL,8,1,17,0,NULL,NULL),(3654,696949621016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','samaudi1','sam.sun@portugalmail.pt','samuel ferreira','estrada lavradio 95, Tornada','Caldas da Rainha','Portugal','PORTUGAL','2504-912','00351965811578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-27 23:41:57',0,NULL,3,1,3,1,NULL,'æ°”å¹ + å¸ƒ   1\r62mm cpl   1\rlenspen   1\rcanon ä¸‰è§’åŒ…   1\rRR815340033CN\r '),(3655,652297671002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.96,'hermeshine','gizzje','e-bayelwin@hotmail.com','Elwin Varkevisser','Clara Bartonstraat 18','AMSTERDAM','','NETHERLANDS','1025KT','020-6372734','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-27 23:50:48',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   æ¬§æ ‡   2 \rRR815340149CN'),(3656,613061009001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',2,'AB2214',3,'hermeshine','chris_pavez','chris_cvpp@hotmail.com','Cristian Vicente Pavez Ponce','7 Norte A #2086 - 13 y 14 Oriente<br>Villa Los Conquistadores','Talca','Talca/Talca/Region del Maule','CHILE','3460000','+56997746990','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 00:32:17',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0 è†œ   2 '),(3657,710802622015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','matthewringo','matthewandhispuntomk1@gmail.com','Matthew Bonnici','94 Iz-Zebbuga Triq Dun Luret Callus','Zebbug','','MALTA','zbg06','21461324','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 00:49:22',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³  1 '),(3658,696976823016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','radoslaw24','radoslawlukaszewski@wp.pl','Radoslaw Lukaszewski','Tranumparken 25, 2 TH','BRONDBY STRAND','','DENMARK','2660','004550216463','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-28 01:03:38',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(3659,710802985015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','jamieshore4','moonstonecrafts@hotmail.co.uk','James Milligan','Moonstone Crafts 113 Dalrymple Street','Girvan','South Ayrshire','UNITED KINGDOM','KA26 9BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 01:57:39',0,NULL,3,1,2,1,NULL,'45w 220v   2 '),(3669,652362279002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','curlly1980','votoy@yandex.ru','Vladimir Kryuchkov','N. Fedorova<br>16-9','Tyumen','Tyumen region','RUSSIAN FEDERATION','625007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 05:46:42',0,NULL,3,1,5,1,NULL,'717 180cm   1 \rCP219437080CN\r'),(3661,652329017002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','hergeek','herge@live.ca','Raymond Gaudreault','47 De La Croix','Sherbrooke','QC','CANADA','J1C 0M3','(819) 821-3636 ext.: 238','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:19:46',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1 '),(3662,652330892002,120570270250,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 02:28:34',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…   nikon   1 '),(3663,652317768002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE1301',23.67,'hermeshine','bargain109','miro.sabic@gmail.com','Miro Sabic','Eosstraat 336','AMSTERDAM','','NETHERLANDS','1076DR','0617316262','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:34:50',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  3 \rRR815340047CN\r'),(3664,652332096002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AE2501',54,'hermeshine','sandpitbrow','binrow@gmail.com','Robyn Payne','9 John street','Redcliffe','Queensland','AUSTRALIA','4020','0732838361','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 02:38:25',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder  $20\rYW863684730CN\r'),(3665,613096034001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',19.67,'hermeshine','luciannem','rockgirl696@hotmail.com','Lucianne Guardiola','FK44 Calle Polaris<br>Santa Juanita','Bayamon','PR','UNITED STATES','00956-5501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 03:46:43',0,NULL,5,1,18,0,NULL,NULL),(3666,652346651002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','dtsmith68','dtsmith@nctc.com','DOUGLAS SMITH','72 Brooks Hollow Ln','PLEASANT SHADE','TN','UNITED STATES','37145-3416','(615) 774-3307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 03:55:53',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(3667,652353149002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0006',12.8,'hermeshine','mb155','burtonmj@hotmail.com','Melissa Burton','4 Champagne Court','Irymple','Victoria','AUSTRALIA','3498','0448506326','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-28 04:36:35',0,NULL,3,1,2,1,NULL,'1.6 x 2.1  é»‘è‰²èƒŒæ™¯å¸ƒ   1 '),(3668,652356739002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',9.25,'hermeshine','artkrot','adzhelali@gmail.com','Arthur Dzhelali','30 Lincoln Ave<br>Apt 2','New London','CT','UNITED STATES','06320','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 05:04:42',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… canon   1 '),(3670,613114100001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','gastec56','gastec@shaw.ca','Tom Hamilton','119 Stein Close SE','Medicine Hat','AB','CANADA','T1B 4M8','(403) 526-0094','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 05:50:39',0,NULL,3,1,3,1,NULL,'nikon åŽŸè£…èƒŒå¿ƒ  xl   1 \rRR815340135CN'),(3671,697048873016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'',22,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK Syntagma','ATHENS','','GREECE','10557','306972999050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 08:03:16',0,NULL,3,1,3,1,NULL,' RA022498675CN\r'),(3672,652396117002,120568073075,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',6.5,'hermeshine','hessel2001','thomashessel@yahoo.com','THOMAS HESSEL','DREYERSVEJ 35','Rungsted Kyst','','DENMARK','DK-2960','45865897','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 10:18:41',0,NULL,8,1,17,0,NULL,NULL),(3673,652395764002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','hessel2001','thomashessel@yahoo.com','THOMAS HESSEL','DREYERSVEJ 35','Rungsted Kyst','','DENMARK','DK-2960','45865897','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 10:18:41',0,NULL,3,1,2,1,NULL,'ä¸­å·å†…èƒ†åŒ… canon   1\rä¸­å·é•œå¤´ç­’   1 '),(3674,652403434002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','einar8984','einar.schoyen@getmail.no','Einar Schoyen','Etterstadsletta 112','Oslo','Oslo','NORWAY','0659','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:00:55',0,NULL,3,1,4,1,NULL,'717ah   1 \r717 å¿«è£…æ¿  1\rballhead  $20\rYW863684962CN\r'),(3675,613155697001,110566021619,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','bisti1010','hasseltax@ya.ru','Yury Oprya','Kollontai street 26-81','Saint-Petersburg','','RUSSIAN FEDERATION','193231','(960)2434377','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:10:31',0,NULL,3,1,3,1,NULL,'sf18-canon   1 '),(3676,613157787001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','einar8984','einar.schoyen@getmail.no','Einar Schoyen','Etterstadsletta 112','Oslo','Oslo','NORWAY','0659','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 11:16:24',0,NULL,8,1,17,0,NULL,NULL),(3677,710917094015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','tirc83','gary83@gmail.com','Gary Martin','83 Tir Capel','Llanelli','Carms','UNITED KINGDOM','SA14 8SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 11:20:16',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3678,613157774001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','norasonlydad','terryshaw@trytel.net','Terry Shaw','573 Beech Terrace<br>Box 8076 RR#1','Peterborough','ON','CANADA','K9J 6X2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:20:25',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(3679,652409331002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','bigos_74','arevva@gmail.com','Oleksandr Revva','3A Smolenskaya st. ap.4','Kiev','UA','UKRAINE','03057','(050) 462-3910','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:34:24',0,NULL,3,1,3,1,NULL,' RA022498741CN\r'),(3680,613164073001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','rajurajgopal','rajgopal18@gmail.com','Rajagopal Balasubramanian','F 57 Sector 39 Noida','Noida','UP','INDIA','201303','9811322855','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 11:50:16',0,NULL,3,1,2,1,NULL,'canon-58 åæŽ¥çŽ¯  1\ræ–°åœ°å€ï¼š\rRajagopal Balasubramanian \rChitra Swaminathan\r2/3 Norton 1st Street\rMandevali \rChennai - 600028\rINDIA\r9811322855\r '),(3681,613166872001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE1301',19.6,'hermeshine','georgebwmf','gcrook13@hotmail.com','George  Z Hantzis','Dilvoi 13-15 Byron','Athens','Greece','GREECE','16232','010 - 7629640','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 12:04:18',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹ çƒå°   2 \rRA022498755CN\r'),(3682,710940277015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'',4.99,'hutongstore','jodyboy10','jodyboy1@hotmail.com','joseph ryan','24 woodlands','portmarnock','Dublin','IRELAND','default','0864066949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 13:00:04',0,NULL,3,1,2,1,NULL,'6662a å¿«è£…æ¿   1 '),(3683,710942853015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'',2.52,'hutongstore','swo0p360','j.c.r.bakker@kpnmail.nl','Richard Bakker','Joris Ivenslaan 63','ALMERE','','NETHERLANDS','1325LZ','036-5353616','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 13:12:02',0,NULL,3,1,2,1,NULL,'52-58mm åŒé˜³çŽ¯   1 '),(3684,697121850016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','joewright10','benkoch88@gmail.com','Ben Koch','19 Wollaton Close','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 3gd','01623650539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 13:53:44',0,NULL,3,1,2,1,NULL,' '),(3685,710966807015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','punisher_1972','punisher_1972@hotmail.co.uk','mr d williams','1 the paddock','stubbington','Hampshire','UNITED KINGDOM','po143ns','07881868456','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-28 14:42:30',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  + 58mm çŽ¯æž¶  1 \rRR815340197CN\r'),(3686,613205996001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','duratec421','andrej.dosek@gmail.com','Andrej Dosek','Porzellangasse 30<br>(Zimmer 222)','Wien','','AUSTRIA','1090','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 15:15:40',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRA022498830CN\r'),(3688,652472687002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','hoganator','chogan1971@gmail.com','Chris Hogan','26693 Yale St','Hemet','CA','UNITED STATES','92544','(951) 551-0995','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 16:33:47',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  nikon   1 '),(3689,613255188001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1601',87,'hermeshine','arzta','mr.arzta@gmail.com','Mattias Sandell','YttrÃ¶ 147','Tierp','','SWEDEN','81591','0739337275','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 18:08:45',0,NULL,3,1,4,1,NULL,'6663a   1\rtripod  $22 \rYW863684973CN\r'),(3690,711042737015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','michaelf3032','fjoelner@hotmail.com','Michael Fjoelner','Schleppegrellsgade 17, 2. th.','Aarhus C','','DENMARK','8000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 18:18:41',0,NULL,3,1,2,1,NULL,'60cm 2in1  åå…‰æ¿  1 '),(3691,652488633002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','chicago1924','peter@kadisnet.se','Peter BodÃ©n','Kaddisvagen 42','905 92 Umea','Vasterbottens Lan','SWEDEN','....','4690148050','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 18:23:27',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  1 æ¬§æ ‡  \råå…‰ä¼ž   1 \rRA022498857CN\r'),(3692,652538314002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','arghiropolg','gabriel.arghiropol@gmail.com','Gabriel ARGHIROPOL','P-ta Victoriei<br>Bloc B.est, sc.A, et.2, apt 5','Ploiesti','Prahova','ROMANIA','100001','40723508555','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:32:12',0,NULL,3,1,2,1,NULL,' '),(3693,652540009002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','kathie828','joe@pciflortech.com','Kathie Tomazin','962 E Castlewood Ln','Bartlett','IL','UNITED STATES','60103-5078','(630) 830-0788','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 19:36:24',0,NULL,3,1,1,1,NULL,NULL),(3694,652540291002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','rvribeiro','ruivazribeiro@gmail.com','Rui Vaz Ribeiro','Rua do Ervideiro, 117 - Aguda','Arcozelo','Vila Nova da Gaia','PORTUGAL','4410-421','+351919928774','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:37:20',0,NULL,3,1,2,1,NULL,NULL),(3695,697241935016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'',2.75,'hutongstore','kekko64','fcarrani@gmail.com','Francesco Carrani c/o Clinica Veterinaria Cascina','via tosco romagnola 338','Fornacette','PI','ITALY','56012','0587-423123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-28 19:38:04',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ olympus   1 '),(3696,652544860002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:49:26',0,NULL,8,1,17,0,NULL,NULL),(3697,652545379002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:50:41',0,NULL,8,1,17,0,NULL,NULL),(3698,652545815002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:51:53',0,NULL,3,1,2,1,NULL,'77mm æŽ¥å£çŽ¯   1\rå¹¿è§’æ‰˜æž¶   1\ræ¸å˜ç°   1 '),(3699,652545819002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:30',0,NULL,8,1,17,0,NULL,NULL),(3700,652545547002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:31',0,NULL,8,1,17,0,NULL,NULL),(3701,613291252001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 19:52:31',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\ræ¸å˜è“   1\ræ¸å˜æ©™    1 '),(3702,652556180002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',9.89,'hermeshine','croziercain','gregory_cain@csumb.edu','gregory cain','230 N Rios Ave','solana beach','CA','UNITED STATES','92075','(760) 224-9998','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 20:22:59',0,NULL,3,1,1,1,NULL,'æ— å­—è‚©å¸¦  1 '),(3703,613305140001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jsm1467','magginnis@frontier.com','Joanna Magginnis','401 Deer Walk Trce','Westfield','IN','UNITED STATES','46074-9437','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 20:27:30',0,NULL,3,1,1,1,NULL,' '),(3704,613296272001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 20:30:30',0,NULL,3,1,3,1,NULL,' RA022498769CN\r'),(3705,613299222001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 20:30:29',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(3706,613305030001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','rabid_clam','aarrow-ranch@i-c.net','J Gordon Bengtson','7302 Hunterbrook Dr<br>AARROW-RANCH Aviation Ste 100','Mechanicsville','VA','UNITED STATES','23111','(804) 730-4035','NoPaymentFailure','CheckoutComplete','Other','2010-12-28 20:30:57',0,NULL,3,1,3,1,NULL,'nikon æ‘„å½±èƒŒå¿ƒ xl   1\rRA022498772CN\r '),(3707,613323413001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','yanachek','goodseller@email.cz','Tomas Janacek','Priseka 111','Svetla nad Sazavou','Vysocina','CZECH REPUBLIC','58291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:27:59',0,NULL,8,1,17,0,NULL,NULL),(3708,613323320001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE1301',19.6,'hermeshine','yanachek','goodseller@email.cz','Tomas Janacek','Priseka 111','Svetla nad Sazavou','Vysocina','CZECH REPUBLIC','58291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:28:00',0,NULL,3,1,3,1,NULL,'60cm æ£š   1\rå¤§åŠ›å¤¹ äº‘å°   2 \rRA022498738CN\r'),(3709,652435564002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mikedeparis','mikael.deltin@gmail.com','Del-Tin MikaÃ«l','2 chemin de l\'orient<br>Appartement nÂ°301 RDC Gauche','Lisses','ÃŽle-de-France','FRANCE','91090','0661462048','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 20:57:51',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRA022498786CN\r'),(3710,612804647001,110320736753,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',5,'AB1302',106.95,'hermeshine','garciapablo38-2008','garciapablo38@hotmail.com','PABLO ENRIQUE GARCIA INTERIAN','49 # 510-B X 62 Y 64 CENTRO','MERIDA','YUCATAN','MEXICO','97000','9999239171','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 21:36:44',0,NULL,3,1,3,1,NULL,'52mm æ©¡èƒ¶ç½©   5\r55mm æ©¡èƒ¶ç½©   5\r58mm æ©¡èƒ¶ç½©   5\r62mm æ©¡èƒ¶ç½©   5\r72mm æ©¡èƒ¶ç½©  5\r77mm æ©¡èƒ¶ç½©   5 \rRA022498812CN\r'),(3711,613334193001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',5,'AA1309',12.2,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 22:08:00',0,NULL,3,1,3,1,NULL,' \rRA022498790CN\r'),(3712,613335189001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','xete4motion','blainfalcon@hotmail.com','Nacho Oms','C/Ermitana nÂº 14 1Âº','PeÃ±iscola','Comunidad Valenciana','SPAIN','12598','649147617','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-28 22:13:45',0,NULL,8,1,17,0,NULL,NULL),(3713,652589896002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','xete4motion','blainfalcon@hotmail.com','Nacho Oms','C/Ermitana nÂº 14 1Âº','PeÃ±iscola','Comunidad Valenciana','SPAIN','12598','649147617','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 22:13:46',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰   1 \rbackground support  $25YW863684800CN\r'),(3714,613339933001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','racing-memorabilia','jelpspeed@hotmail.com','Ever Lopez','callejon del sereno 4257','zapopan','jalisco','MEXICO','45110','(523) 338-5681 ext.: 54','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 22:30:36',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRA022498809CN\r'),(3715,613352906001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','srl700','srlittle@rocketmail.com','Steven Little','6101 Lake Shore Dr','Fort Worth','TX','UNITED STATES','76179','(214) 274-7752','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 23:22:46',0,NULL,3,1,1,1,NULL,NULL),(3716,613195206001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','dazz-j','dazz_77keus10@hotmail.com','joel elhadj (chez Mlle Sarah Bellagamba)','40 avenue de la grande armÃ©e','Paris','Ile-de-France','FRANCE','75017','0686850928','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 23:28:51',0,NULL,8,1,17,0,NULL,NULL),(3717,613207151001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','dazz-j','dazz_77keus10@hotmail.com','joel elhadj (chez Mlle Sarah Bellagamba)','40 avenue de la grande armÃ©e','Paris','Ile-de-France','FRANCE','75017','0686850928','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-28 23:28:50',0,NULL,3,1,4,1,NULL,'æ–œè‡‚  1\råå…‰æ¿æ”¯æž¶   1\r2m ç¯æž¶   1\rlighting kit  $25 \rYW863684984CN\r'),(3718,613225709001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','jdraluck','jdraluck@yahoo.com','Alissa Dolderer','1007 Arezzo Cir','Boynton Beach','FL','UNITED STATES','33436-1113','(310) 980-1685','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-28 23:33:49',0,NULL,3,1,1,1,NULL,NULL),(3719,613359916001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','elcarlicos81','elcarlicos@mixmail.com','Carlos Perez Gracia','Avda. Gomez Laguna 28 2c','Zaragoza','AragÃ³n','SPAIN','50009','976751648','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 00:01:39',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3720,652618258002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','johntiedeman7710','johntiedeman@gmail.com','JOHN TIEDEMAN','3680 BRAEDEN CT','Middleburg','FL','UNITED STATES','32068-3966','(904) 534-8280','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-29 00:05:17',0,NULL,3,1,1,1,NULL,'sony å•è‚©åŒ…   1 '),(3721,697331438016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nÂº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 00:17:41',0,NULL,8,1,17,0,NULL,' FRANCISCO IVAN GARCIA PEREZ\rC/Lope de Vega n?5 Chalet\rFuenlabrada (Loranca) Madrid 28942\rSPAIN\r669625244\r\r'),(3722,711170454015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'',48.9,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nÂº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 00:17:42',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3m x 6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  3\r50-70 æ£š  3 æ¬§æ ‡  \ræ–œè‡‚   1\r115w 220v  2\r åŒ…   1\r lighting kit  $30 \rYW863684995CN\r'),(3723,652624838002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','negger99','palfaro@proseal.cl','Patricio Alfaro','Curtiduria 7701<br>La Florida','Santiago','Region Metropolitana','CHILE','8271237','56-2-3137191','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 00:35:11',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRA022498724CN\r'),(3724,652626038002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','nickgb83','home@nickandleash.com','N Bryant','39 Callum Place, Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 00:40:59',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rlight stand  $22\rYW863685006CN'),(3725,613374782001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bacaramaschi','bcaramaschi@gmail.com','Barbara Caramaschi','Rua Nestor do Val, 281','Piraju','SP','BRAZIL','18800-000','1488081027','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 01:10:57',0,NULL,3,1,2,1,NULL,NULL),(3726,613379570001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','thebalkanking','edin.ramicevic@gmail.com','Edin Ramicevic','Industrigata 71','Oslo','','NORWAY','0357','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 01:36:32',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 \rRA022498715CN\r'),(3727,652651072002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','kameron808-123','torres_kameron@yahoo.com','Kameron Torres','1636 Gold St','Marysville','CA','UNITED STATES','95901-6812','(530) 926-2462','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-29 02:38:30',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(3728,652652229002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','globalestudio','tonrcc@gmail.com','weliton souza','Rua Couto MagalhÃ£es, NÂ° 2668 - CENTRO<br>Rua  Major Claudiano , NÂ° 2609 - Centro','Franca','SÃ£o Paulo','BRAZIL','14400-020','(016) 9256-2300','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 02:43:44',0,NULL,3,1,2,1,NULL,NULL),(3729,613399625001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tonenino01','tonenino17@yahoo.com','Luis Pagan','166 Grand ave','Rochester','NY','UNITED STATES','14609-6348','(585) 576-8510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 03:18:41',0,NULL,3,1,1,1,NULL,NULL),(3730,652660125002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE1301',15.78,'hermeshine','jinlsui123','jinlsui@yahoo.com','jinliang sui','180 rice ave','northborough','MA','UNITED STATES','01532','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-29 03:22:58',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  2 '),(3731,613400582001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','5_bueckertrustic','wiebe@cciwireless.ca','Margaret Wiebe','Po Box 21','Purple Springs','AB','CANADA','T0K 1X0','(403) 655-2582','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 03:25:06',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(3732,613219738001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','cristian_abcflor.com','cristian@abcflor.com','Cristian D. Nechuta','Av. Congreso 4937<br>Villa Urquiza','Buenos Aires','Buenos Aires','ARGENTINA','C1431AAE','5491169570101','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 04:17:08',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rRA022498905CN\r'),(3733,613409962001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','originalfrankiman','frankiman@hotmail.com','Francois Theriault Rehel','3848 Grand-Boulevard','Saint-Hubert','QC','CANADA','j4t 2m2','(450) 656-9429','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 04:23:06',0,NULL,3,1,2,1,NULL,' '),(3734,652324862002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0024',27.9,'hermeshine','axelzule','axel_12_700@hotmail.com','axel cuevas','PO Box 990<br>PMB 681','san luis','AZ','UNITED STATES','85349','(623) 606-4893','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2010-12-29 04:41:59',0,NULL,3,1,1,1,NULL,'sonyå•è‚©åŒ…   1 '),(3735,652677832002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','totallytutus*com','totallytutus@hotmail.com','jackie heath','5918 Woodmere Dr','Corpus Christi','TX','UNITED STATES','78414','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 05:14:24',0,NULL,3,1,1,1,NULL,NULL),(3736,652680770002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','id4alexey','alexeypetrov@ngs.ru','Alexey Petrov','Uritskogo 12, 7','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630099','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 05:37:24',0,NULL,3,1,3,1,NULL,' RA022498826CN\r'),(3737,613423239001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2101',59,'hermeshine','gkeith1','gkeithc@msn.com','Keith Clements','475 Heritage Ln','Johnstown','CO','UNITED STATES','80534-7815','(970) 587-9312','NoPaymentFailure','CheckoutComplete','Other','2010-12-29 06:07:45',0,NULL,3,1,1,1,NULL,'åŽŸè£…nikon èƒŒå¿ƒ L   1 '),(3740,652692578002,120571007047,'Green.L 77mm Neutral Density ND4 Filter 77 Nikon D90',1,'AE2307',8.2,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:32',0,NULL,8,1,17,0,NULL,NULL),(3741,652691766002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE1301',9.68,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:33',0,NULL,8,1,17,0,NULL,NULL),(3742,613430207001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE1301',7.95,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:33',0,NULL,8,1,17,0,NULL,NULL),(3743,613429697001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 07:22:34',0,NULL,8,1,17,0,NULL,NULL),(3744,613429443001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 07:22:34',0,NULL,8,1,17,0,NULL,NULL),(3745,613430641001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 07:22:35',0,NULL,3,1,5,1,NULL,'77mm ND8   1\ræ–œè‡‚  1\r2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶   1\rå¤§åŠ›å¤¹   1\rcåž‹å¤§åŠ›å¤¹   1\r77mm nd4    1 \rCP219437266CN'),(3746,711255728015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'',15,'hutongstore','bastelmonimo','monika.gutentag@googlemail.com','Monika Metzler','Pestalozzistrasse 3','Mainz','','GERMANY','55120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-29 07:24:34',0,NULL,3,1,2,1,NULL,NULL),(3751,711271049015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','chrisf9439','christopher-faulder@sky.com','Mr C Faulder','168 West Street','Gorseinon','Swansea','UNITED KINGDOM','SA4 4AQ','01792894463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 09:23:58',0,NULL,8,1,17,0,NULL,NULL),(3748,710956469015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',61,'hutongstore','stefanov.stefan','stefan@stefanovs.com','Stefan Stefanov','23, James Baucher blvd.','Sofia','','BULGARIA','1164','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 08:24:00',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ çº¢ ç»¿ ï¼‰   1 \rç”µè¯æ˜¯ï¼š +359888510027\rCP219437252CN\r'),(3749,652706935002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sladboy','sladkovic@gmail.com','Lubomir Sladkovic','Spartakovska 11','Trnava','','SLOVAK REPUBLIC','91701','+421944094249','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 09:12:28',0,NULL,3,1,3,1,NULL,'RR815340458CN '),(3752,711274935015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'',3,'hutongstore','chrisf9439','christopher-faulder@sky.com','Mr C Faulder','168 West Street','Gorseinon','Swansea','UNITED KINGDOM','SA4 4AQ','01792894463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 09:23:58',0,NULL,3,1,2,1,NULL,'450dçœ¼ç½©   1 \r58mm é•œå¤´ç›– canon   1'),(3753,652718198002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0006',12.8,'hermeshine','dpspstewart','dan2452@hotmail.com.au','dan stewart','53 amaroo cres','Toormina','New South Wales','AUSTRALIA','2452','0266582803','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-29 10:18:54',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  ç™½è‰²  '),(3754,652722990002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','chumkratok9094','chatetha@hotmail.com','Chatetha Chumkratoke','546 Moo 1<br>Huatala Subdistrict, Maung District','Nakhon Ratchasima','','THAILAND','30000','66862555445','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 10:49:10',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3755,613461271001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','drummer_hu','ebay@drummer.hu','Lorant Dobos','Haller u. 23-25 B116','Budapest','Budapest','HUNGARY','1096','+36204498687','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 10:51:02',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´  1 æ¬§æ ‡   '),(3756,697452947016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','6016michael','info@thefxworks.co.uk','michael gane','46 bath road, beckington','frome','Somerset','UNITED KINGDOM','BA11 6SH','01373831117','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 11:13:11',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(3757,652734914002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','canaillarcos','ruizgonzalezjesus@gmail.com','JosÃ© Luis GonzÃ¡lez Almazo','C. Solis, NÂº 2 Bajo','San Fernando','AndalucÃ­a Ceuta y Melilla','SPAIN','11100','651148181','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 11:59:24',0,NULL,3,1,3,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  2 RR815340427CN\r'),(3758,652758738002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','nemo350z','nemo_ee14@hotmail.com','Pornthep Puttharangsee','101/7 Moo3. Bangkruay-sianoy Rd. Bangrakpattana','Bangbuatong','Nonthaburi','THAILAND','11110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 13:53:04',0,NULL,3,1,2,1,NULL,'éº‚çš®  1 '),(3759,697497682016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','sebastian.bober','sebastian.bober@wp.pl','Sebastian Bober','Impellam, IT Helpdesk 800 The Boulevard, Capability Green','Luton','Bedfordshire','UNITED KINGDOM','LU1 3BA','01582692613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 14:23:37',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹   1 '),(3760,613508610001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',9.9,'hermeshine','hyttipelto','erkki.hillukkala@netti.fi','Erkki Hillukkala','Kuovintie 3 B 6','MynÃ¤mÃ¤ki','Oletus','FINLAND','23100','258503588438','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 14:45:17',0,NULL,3,1,2,1,NULL,'è‚©å¸¦ pentax   1 '),(3761,652798305002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','sergey*gusty','lysikov@gmail.com','Sergey Lysikov','Gostenskaya 7/138','Belgorod','','RUSSIAN FEDERATION','308015','+79056796010','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 16:30:10',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰    1 \rCP219437221CN\r'),(3762,652799389002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:32:17',0,NULL,8,1,17,0,NULL,NULL),(3763,613537113001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','computer-tec','pctec101@yahoo.com','Tim O\'Dell','39 New Rd.','Salt Springs','NB','CANADA','E5N4J8','(506) 832-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 16:33:15',0,NULL,3,1,2,1,NULL,NULL),(3764,652800360002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:35:24',0,NULL,8,1,17,0,NULL,NULL),(3765,711388012015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'',3.62,'hutongstore','timjohnfish2000','timfishy@googlemail.com','Tim Fish','BOC Maxwell Rd','Plymouth','Devon','UNITED KINGDOM','Pl4 0RT','01752255033','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 16:36:16',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶   1 '),(3766,613538219001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','vetdickg','docrhg@aol.com','Richard Galley','1601 Ranch House Rd','Willow Park','TX','UNITED STATES','76087-7691','(817) 441-7595','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 16:37:00',0,NULL,3,1,1,1,NULL,'67mm æ©¡èƒ¶ç½©   1\r72mm æ©¡èƒ¶ç½©   1\r77mm æ©¡èƒ¶ç½©   1 '),(3768,613547964001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','halg59','garner1@rogers.com','Hal Garner','115 William Roe Blvd','Newmarket','ON','CANADA','L3Y1B1','(905) 953-1926','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 17:09:42',0,NULL,3,1,2,1,NULL,NULL),(3769,613560422001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','dufranche','johannefrancis@sympatico.ca','RenÃ© Dumouchel','977, rue Chouinard','SteThÃ©rÃ¨se','QC','CANADA','J7E5M8','(450) 437-6545','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 17:50:18',0,NULL,3,1,2,1,NULL,NULL),(3770,613565849001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','lp_merino','len@ya.com','Lucia Palacios Merino','c/ Madres de la Plaza de Mayo<br>43, 1ÂºA','Artica','Navarra','SPAIN','31013','605503295','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 18:07:15',0,NULL,3,1,2,1,NULL,'40cm æ£š  1 '),(3771,652839064002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis nÂ°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 18:36:37',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815340360CN\r'),(3772,652864795002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','danten0sense','dante.n0sense@gmail.com','Javier Hermosilla Jorge','Calvo Acacio 33 8','Valencia','Comunidad Valenciana','SPAIN','46017','678220722','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 19:50:37',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW863684833CN\r'),(3773,613608821001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','aeebilly','billy1463@yahoo.com','William Vazquez','9-J-13<br>Condado Moderno','Caguas','PR','UNITED STATES','00725','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 20:11:26',0,NULL,3,1,1,1,NULL,NULL),(3774,652872766002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pantyusz85','pantyusz@gmail.com','Istvan Pantya','Berzsenyi 6','Veszto','','HUNGARY','5530','36305270671','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 20:12:17',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž    1 RR815340395CN\r'),(3775,652875442002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wxytiramisu','wxycp3@gmail.com','Xiaoyang Wu','550 Bloomsdorf Dr','State College','PA','UNITED STATES','16801-2444','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 20:19:38',0,NULL,3,1,1,1,NULL,NULL),(3776,613612499001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','twistedstuff','twistedcory@gmail.com','Cory Breton','44 Welbourn Drive','Hamilton','ON','CANADA','L9A3N3','(905) 746-0661','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 20:20:30',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815340387CN\r'),(3777,711489096015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'',134,'hutongstore','h_salci','hunkar.salci@gmail.com','Hunkar Salci','Seher Yildizi Sok. Adak Apt. No:16 D:2 Etiler','Istanbul','Istanbul','TURKEY','34337','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-29 20:50:37',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶   2\råŒç¯å¤´ æ¬§æ ‡   2\ræŸ”å…‰ä¼ž  2\r45w 220v  4\råŒ…   1 \rç”³æŠ¥$25\rCP219437155CN\r\rlighting kit  GBP55\r\r'),(3778,711495251015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'',1.88,'hutongstore','ronniepickles','darren.odonnell@gmail.com','Darren O\'Donnell','48 Moat Road','Oldbury','West Midlands','UNITED KINGDOM','B688EB','07736395417','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-29 20:53:15',0,NULL,3,1,2,1,NULL,NULL),(3779,652897255002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','wlad2318','wladneto@uol.com.br','Wladimir Nequesaurt Pereira Neto','Rua Lucio Vitorino de Souza 186','Florianopolis','Santa Catarina','BRAZIL','88035060','48-32346911','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 21:25:52',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3780,652901441002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','mcaaway','michi8613@yahoo.com','Michelle Caaway','10857 Wallingford Rd','San Diego','CA','UNITED STATES','92126-2560','(858) 722-2820','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 21:40:10',0,NULL,3,1,1,1,NULL,NULL),(3781,652903071002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','ranianas','raniamns@yahoo.com','Despina Manasi','Thettalon<br>19','Karditsa','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 21:46:08',0,NULL,3,1,5,1,NULL,'light  $20 \r4 ç¯å¤´ æ£š  æ¬§æ ‡   2\rCP219437195CN\r\r'),(3782,652223458002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','honestbuy22','ra.alexis@gmail.com','Ranjeet Alexis','2872 Aberdeen Ln','El Dorado Hills','CA','UNITED STATES','95762-5683','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 21:58:12',0,NULL,3,1,1,1,NULL,NULL),(3784,613645560001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mariafg94','elry@online.no','ellen rygg','pasvikveien 23','Kirkenes','','NORWAY','9900','78992962','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 22:18:53',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815340311CN\r'),(3785,652915265002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT014',37.15,'hermeshine','admir.b','champ071@hotmail.com','admir begovic','Grbavicka 40','Sarajevo','ba','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 22:29:33',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´  æ¬§æ ‡  1\råå…‰ä¼ž    1 RR815340373CN'),(3786,652921509002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','dylanthanhcao','tcao1966@yahoo.com','NGOC CAO','1901 Long Prairie Rd<br>Ste 1037','FLOWER MOUND','TX','UNITED STATES','75022-4226','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-29 22:54:09',0,NULL,3,1,1,1,NULL,'å°å·ç°å¡   1 '),(3787,652921558002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0002',45,'hermeshine','fh_53','fh53@hetnet.nl','Ferry Horvath','Wilgenkamp 1','Losser','','NETHERLANDS','7581HA','053-5364964','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-29 22:54:29',0,NULL,3,1,3,1,NULL,'3m ä¼¸ç¼©æ¨ªæ†   1 RR815340339CN\r'),(3788,613664771001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','muhaimin1986','muhaimin86@gmail.com','Mohd Muhaimin','Kediaman PPP, Tingkat 3<br>kolej Kenanga 1, UiTM Shah Alam','Shah Alam','Selangor','MALAYSIA','40450','0194797139','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 23:32:21',0,NULL,3,1,3,1,NULL,'sf18-sb900   1 RR815340400CN'),(3789,652929856002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pete_bean','peter@azuredigital.co.uk','Peter Smith','109 Orchard Way<br>Churchdown','Gloucester','Gloucestershire','UNITED KINGDOM','GL3 2AP','01452855666','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-29 23:33:23',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW863684811CN\r'),(3790,711558409015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','mooneystephen','stephenjpmooney@gmail.com','Stephen Mooney','Heatherdale, Crutt, Clogh,','Castlecomer,','Kilkenny','IRELAND','default','0879126280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 00:06:22',0,NULL,8,1,17,0,NULL,NULL),(3791,697702623016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'',3.5,'hutongstore','mooneystephen','stephenjpmooney@gmail.com','Stephen Mooney','Heatherdale, Crutt, Clogh,','Castlecomer,','Kilkenny','IRELAND','default','0879126280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 00:12:50',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1\rlenspen   1 '),(3792,613687390001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','julzzz111','videojewels@yahoo.com','Juliusz Pokora','12045 N Pebble Beach Dr','SUN CITY','AZ','UNITED STATES','85351-3757','(623) 933-5525','NoPaymentFailure','CheckoutComplete','Other','2010-12-30 01:27:43',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815340342CN'),(3793,652961895002,120601699113,'EW-83E Lens Hood lenshood for Canon EF 16-35mm 10-22mm',1,'AA3406',8.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 02:22:44',0,NULL,3,1,11,1,NULL,NULL),(3794,652971498002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','larrable','landerton@comcast.net','Larry Anderton','2782 W 6870 S','West Jordan','UT','UNITED STATES','84084','(801) 971-7372','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 02:50:07',0,NULL,3,1,1,1,NULL,NULL),(3795,613709880001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','88pelican','tom_wilmers@hotmail.com','Tom Wilmers','2816 Central Ave','Big Pine Key','FL','UNITED STATES','33043-6215','(305) 872-5475','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 03:28:20',0,NULL,3,1,1,1,NULL,NULL),(3796,613712601001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','precisionartistics','philiparagones@gmail.com','Philip Aragones','71 Bacolod Street<br>Alabang Hills Village','Muntinlupa City','Metro Manila','PHILIPPINES','1770','9175099346','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 03:43:10',0,NULL,3,1,2,1,NULL,NULL),(3797,613713630001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3401',37.95,'hermeshine','ftwb5658','ftwbnet@gmail.com','Matthew Cilia','84, Il-Hirondella Triq il-Barbagann','Kappara','MLT','MALTA','SGN02','0035699273990','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 03:48:49',0,NULL,3,1,3,1,NULL,'çº¢ç›’2m ç¯æž¶   1 RR815340356CN\r'),(3798,613717914001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bandeparker2010','bandeparker@telus.net','Brian Parker','165 McTavish Cresent','Fort McMurray','AB','CANADA','T9K 2N9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 04:17:56',0,NULL,3,1,3,1,NULL,'2mç¯æž¶ ç™½ç›’   1 RR815340325CN'),(3799,652993315002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','poseur1234','leecf76@yahoo.com.sg','Lee Chien Fong','21B Kim Keat Close<br>Republic of Singapore','Singapore','','SINGAPORE','328931','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 04:56:06',0,NULL,3,1,11,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3800,613724443001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','cul-de-sacs','loh_lcy@yahoo.com','Chong Yeou Loh','25 Main Road,<br>Bukit Jenun,','Pendang','Kedah','MALAYSIA','06720','0105662456','NoPaymentFailure','CheckoutComplete','AU_ExpressCourierInternational','2010-12-30 05:06:10',0,NULL,3,1,2,1,NULL,'2m ç¯æž¶  2\råŒç¯å¤´   2 è‹±æ ‡\råå…‰ä¼ž   2\råŒ…   1      3881\ré€’å››æ–¹é©¬æ¥è¥¿äºšä¸“çº¿ æ½˜\r89013446093'),(3801,652995214002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','lrmaruo','lucas.maruo@gmail.com','Lucas Ryoiti Maruo','Rua Frei Henrique de Coimbra,2116','Curitiba','PARANA','BRAZIL','81630220','+554199131465','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 05:08:33',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3802,613635434001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',26,'hermeshine','rahollings','rahollings@shaw.ca','Ryan Hollings','268 Tuscany Estates Rise N.W.','Calgary','AB','CANADA','T3L0C5','(403) 208-3013','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 05:20:20',0,NULL,3,1,3,1,NULL,' RR815340435CN'),(3803,613730049001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','holistichealth','drnyvlt@hotmail.com','Pavel Nyvlt','Masarykovo nam.175','Podivin','','CZECH REPUBLIC','69145','(420) 739-4428 ext.: 66','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 05:52:25',0,NULL,3,1,5,1,NULL,'CP219437249CN\r'),(3804,653006004002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rb1m3b','rhkplam@verizon.net','Wilson Lam','5 Barnes Ave','Johnston','RI','UNITED STATES','02919-2601','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 06:36:15',0,NULL,3,1,1,1,NULL,NULL),(3805,653014017002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 07:50:01',0,NULL,3,1,2,1,NULL,' '),(3806,613746896001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','bxbe','bxbeworks@gmail.com','Dameng Wang','382 N Lemon Ave<br># 229','Walnut','CA','UNITED STATES','91789-2344','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2010-12-30 08:26:02',0,NULL,3,1,1,1,NULL,'å†æ”¹ä¸ªåœ°å€ï¼Œeé‚®å® \rå•å‘ä¸€ä¸ªé»‘è‰²çš„å†\rå®¢æˆ·è¦ä¸¤ä¸ªé»‘çš„ï¼Œå‘é”™äº†LK015764849CN'),(3807,697645205016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',44.58,'hutongstore','h_salci','hunkar.salci@gmail.com','Hunkar Salci','Seher Yildizi Sok. Adak Apt. No:16 D:2 Etiler','Istanbul','Istanbul','TURKEY','34337','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 08:31:38',0,NULL,3,1,5,1,NULL,'åå…‰æ¿æ”¯æž¶ 1\r2m ç¯æž¶  1\råå…‰ä¼ž   1\rlenspen    1\rå’Œå‰é¢çš„ä¸€ç¥¨åŒ…åœ¨ä¸€èµ·, å‰é¢çš„æˆ‘å¬å›žäº†,å°çŽ‹æ˜Žå¤©æ‹¿å›žæ¥\rCP219437155CN\r\r '),(3809,613753445001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','wuvzoo','kiarawoodsebay@gmail.com',' Kiara Woods','24 Dewhurst Street','Narrabri','New South Wales','AUSTRALIA','2390','0267944641','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 09:15:14',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815340722CN\r'),(3810,613760568001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0024',20.99,'hermeshine','cserantesc','cserantesc@gmail.com','CÃ©sar Serantes Caballero','C/ Virgen de los Desamparados, 10 - 1ÂºD','Madrid','Madrid','SPAIN','28041','617733390','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 10:00:47',0,NULL,3,1,3,1,NULL,'nikon D1 å•è‚©åŒ…   1 \rRR815340719CN\r'),(3811,653041928002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.96,'hermeshine','freewinguk','ndt_ugur@hotmail.com','uÄŸur kÄ±lÄ±c','harmanlar mah.baharkent sitesi<br>3a blok daire:2','merzifon','amasya','TURKEY','05300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 11:07:01',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  æ¬§æ ‡   2 \rRR815340665CN\r'),(3812,697829637016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','tompod1974','hairbear1974@btinternet.com','Thomas Podesta','39 Kilmersdon Road Haydon','Radstock','Somerset','UNITED KINGDOM','BA3 3QL','01761438978','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 11:36:14',0,NULL,3,1,2,1,NULL,'52-58 åŒé˜³   1 '),(3813,653060149002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',43.9,'hermeshine','iz5165','ilanziv@bezeqint.net','49223ilan ziv','14 Moshe Sneh St.','Petach Tikva','','ISRAEL','49223','0545337325','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 12:41:30',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\räº‘å°   1\ræŸ”å…‰ä¼ž   1 \rRR815340740CN\r'),(3814,697851913016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','enchere_et_en_os','victorboissel@yahoo.fr','Cortex Ink. - Victor Boissel','37, rue du Faubourg PoissonniÃ¨re','Paris','','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 13:18:58',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m èƒŒæ™¯å¸ƒ  ç»¿è‰²  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡   2\r115w 220v   2\råŒ…    1\rlighting kit  $30\rYW863684870CN\r\r '),(3815,711718434015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'',1.88,'hutongstore','jnejne','johannes.ne@gmail.com','Johannes Enevoldsen','Heboltoft 88','RingkÃ¸bing','','DENMARK','6950','+4528405305','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 13:28:55',0,NULL,3,1,2,1,NULL,NULL),(3816,711721504015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','jimboweb','jim.webster@sky.com','Jim Webster','27 Comrie Crescent','Hamilton','South Lanarkshire','UNITED KINGDOM','ML3 9QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 13:40:49',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3817,711721680015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'',125,'hutongstore','michaelf3032','fjoelner@hotmail.com','Michael Fjoelner','Schleppegrellsgade 17, 2. th.','Aarhus C','','DENMARK','8000','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 13:42:25',0,NULL,3,1,4,1,NULL,'2m  ç¯æž¶  2\r50-70 æ£š  æ¬§æ ‡  2\r115w 220v   2\rèƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰    1\råŒ…   1 \rlighting kit   $30\rYW863684881CN\r'),(3818,653072923002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','915lily','crypul2000@yahoo.com','Crystal Diaz','7090 NW 7th St','Plantation','FL','UNITED STATES','33317-1108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 13:43:28',0,NULL,3,1,1,1,NULL,NULL),(3820,653072488002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0006',25.6,'hermeshine','krose-1910','kdoyle@live.com.au','krystle Walter','30 Moore Cres','Mount Isa','Queensland','AUSTRALIA','4825','0401081910','NoPaymentFailure','CheckoutComplete','AU_Other','2010-12-30 13:46:49',0,NULL,3,1,3,1,NULL,'1.6m x 2.1m  èƒŒæ™¯å¸ƒ 2\rç™½è‰² + é»‘è‰² \rRR815340784CN\r\r'),(3821,653077566002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','theartharindra','harindranishshanka@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 14:08:09',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶   2\r50-70 æ£š   è‹±æ ‡   2\r115w 220v   2\råŒ…    1 \rused lighting kit  $20\rCP219437164CN\r'),(3822,697869679016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'',14.5,'hutongstore','jdealmeida61','phportjose@hotmail.com','Jose de Almeida','Peterson Mitra Indonesia Jl Jendral Surdiman Blok G2/5','Balikpapan Permai','Kalimantan Timur','INDONESIA','76114','062 081520324739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-30 14:23:34',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å¤å­£ xl   1\rRR815340682CN\r'),(3823,653082757002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','mayoula_jewelry','mayoula.jewelry@gmail.com','tamar mandil','25 HaHistadroot street','Raanana','','ISRAEL','43404','972-54-7746107','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 14:27:58',0,NULL,3,1,3,1,NULL,'50cm æ£š   1 \rRR815340679CN\r'),(3824,653083535002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','jayhyunjaekim','kimh2@corning.com','Jay Kim','30 Hunters Run','Horseheads','NY','UNITED STATES','14845-2285','(607) 329-7214','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 14:31:21',0,NULL,3,1,1,1,NULL,NULL),(3826,652329098002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','urak81','verinicola@virgilio.it','caterina colanzi','VIA PORTELLE<br>n. 65','SAN VITO CHIETINO','CH','ITALY','66035','3207633318','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 14:43:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§     1\ræŸ”å…‰ä¼ž   1 \rRR815340736CN\r'),(3827,613831068001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','antozone','antoantous@yahoo.com','Adianto Adianto','Jl Percetakan Negara GG Muhirin I/4C<br>RT:002 RW:006 Kel Cempaka Putih Barat','Jakarta','Jakarta','INDONESIA','10520','6281328352308','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 15:56:34',0,NULL,3,1,2,1,NULL,NULL),(3828,613833488001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','valrval','valrichards7@gmail.com','Valerie Richards','Autumn Graphics<br>669 Sovereign Rd','London','ON','CANADA','N5V 4K8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 16:06:12',0,NULL,3,1,2,1,NULL,NULL),(3829,653114291002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','naalsund','nathalie_1991@msn.com','nathalie naalsund','nordre husebytun 8b','trondheim','','NORWAY','7097','92270799','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 16:28:36',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 67mm ND8   1 '),(3830,653113989002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','jtharris1984','jtharris@ameritech.net','Jeffrey Harris','23303 Vance Ave','Hazel Park','MI','UNITED STATES','48030-1624','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 16:28:39',0,NULL,3,1,1,1,NULL,NULL),(3831,613869726001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','guillaume68490','guillaume.fels@gmail.com','guillaume fels','6, rue de gontaud','bantzenheim','Alsace','FRANCE','68490','0686893375','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 18:07:03',0,NULL,3,1,4,1,NULL,'6663a   1\rTripod   $22 \rYW863684866CN\r'),(3832,697599003016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'',54.5,'hutongstore','rozgon','rozgon.taras@gmail.com','Taras Rozgon','Crown Fort Club, B8, ap.158','Sveti Vlas','','BULGARIA','8256','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2010-12-30 18:43:59',0,NULL,3,1,5,1,NULL,'6663a   1 \rCP219437178CN\r'),(3833,653160750002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bretskyswanson','bretsky_swanson@hotmail.com','Brett Swanson','2303 College Ave<br>Huntington University','Huntington','IN','UNITED STATES','46750-1237','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 19:09:58',0,NULL,3,1,1,1,NULL,NULL),(3834,613894571001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','korn2402','zoltan.simon.rs@gmail.com','ZoltÃ¡n Simon','MalohontskÃ¡ 26/27','RimavskÃ¡ Sobota','','SLOVAK REPUBLIC','97901','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 19:22:45',0,NULL,3,1,3,1,NULL,'è‚©æž¶    1 \rRR815340753CN\r'),(3836,613930404001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','butleram10','butleram@iuk.edu','Amber Butler','1012 N Armstrong St','Kokomo','IN','UNITED STATES','46901-2824','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 21:20:27',0,NULL,3,1,1,1,NULL,NULL),(3837,711907370015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','binksley','susan@iklektik.co.uk','susan fraser','108 lossiemouth road','Elgin','Moray','UNITED KINGDOM','iv30 4ld','01343546328','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 22:22:21',0,NULL,3,1,2,1,NULL,'45w  2 '),(3838,613863798001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AE2301',5.95,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 22:23:09',0,NULL,3,1,2,1,NULL,'52mm æ¸å˜ç°   1 '),(3839,653223258002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','adri25an','adri25anebay@gmail.com','AdriÃ¡n Batista Trenzado','C/Camino Lomo de Quintanilla, 62','Arucas','Canarias','SPAIN','35413','619993502','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-30 22:29:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§    1\ræŸ”å…‰ä¼ž    1 \rRR815340696CN\r'),(3840,653231937002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','m1shka66','michael.soroka@worleyparsons.com','Michael Soroka','217-23 Observatory lane','Richmond Hill','ON','CANADA','L4C 0M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-30 22:48:18',0,NULL,3,1,2,1,NULL,NULL),(3841,613957106001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',6.98,'hermeshine','browngirl0864','browngirl864@yahoo.com','Shonna  Jackson','4419 Colomba St','Houston','TX','UNITED STATES','77045-3523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-30 23:01:56',0,NULL,3,1,1,1,NULL,'RS-C1    1 '),(3842,711923564015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.6,'hutongstore','p_trav','paultraviss@hotmail.com','Paul s Traviss','32 Kings Close Kingsdown','Nr Deal','Kent','UNITED KINGDOM','CT14 8BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-30 23:13:05',0,NULL,3,1,2,1,NULL,NULL),(3843,711941683015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'',85,'hutongstore','littlewolver','honzavlcek@seznam.cz','Jan Vlcek','5 The Terrace Fengate Drove','Weeting, Brandon','Norfolk','UNITED KINGDOM','IP27 0XP','07870512901','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2010-12-31 00:21:52',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r50-70 æ£š   è‹±æ ‡   2\r115w 220v   2\råŒ…    1 \rå•ç¯å¤´  è‹±æ ‡  2 \rlighting kit   $30\rYW863684855CN\r'),(3845,711941684015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'',15.5,'hutongstore','littlewolver','honzavlcek@seznam.cz','Jan Vlcek','5 The Terrace Fengate Drove','Weeting, Brandon','Norfolk','UNITED KINGDOM','IP27 0XP','07870512901','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 00:21:55',0,NULL,8,1,17,0,NULL,''),(3847,653255278002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','leol985','tan.leo@gmail.com','Leo Tan','309 Shunfu Road<br>#13-179','Singapore','Singapore','SINGAPORE','570309','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 00:30:20',0,NULL,3,1,11,1,NULL,NULL),(3848,653273353002,120626873273,'New wide angle holder for Cokin P series filter',2,'AKT024',7.98,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol NÂº 72 1Âº Esq.','Cova da Piedade - Almada','SetÃºbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 01:58:27',0,NULL,3,1,2,1,NULL,NULL),(3849,711974392015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'',3.5,'hutongstore','zubair_samat','rasarasa10@gmail.com','rosnani hasan','smk tunku putra 07000 langkawi, kedah darul aman','Langkawi','Kedah','MALAYSIA','07000','0195696939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 02:45:35',0,NULL,3,1,2,1,NULL,NULL),(3850,653306098002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','vincecraft','vincecraft@msn.com','Samuel Vincent','349 Kimberly Ln','Los Alamos','NM','UNITED STATES','87544-3527','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 05:15:16',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  canon   1 '),(3851,653308685002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0002',70.9,'hermeshine','expatyorkshire','mwindle@singnet.com.sg','Windle Martin','28 Boon Teck Road','default','','SINGAPORE','329600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 05:35:19',0,NULL,3,1,10,1,NULL,'é€’å››æ–¹æ–°åŠ å¡ä¸“çº¿\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰  2mçš„ æ½˜\r89013446115'),(3852,614028817001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','sanphoto251982','sanphoto25@yahoo.com','sandiren parianen','gentilly branch road<br>petit - verger','saint-pierre','..','MAURITIUS','...','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 05:58:26',0,NULL,5,1,18,0,NULL,'3mx6m ç™½è‰²èƒŒæ™¯å¸ƒ  1 '),(3853,653315828002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','seraphsky','derekhaochen@hotmail.com','Hao Chen','717 Flannery St','Santa Clara','CA','UNITED STATES','95051-5546','(408) 332-0269','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 06:36:50',0,NULL,3,1,1,1,NULL,NULL),(3854,653317672002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','traberw','wtraber@sunrise.ch','Werner Traber','rue de la Servette 30A','GenÃ¨ve','','SWITZERLAND','1202','41795079226','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 06:55:09',0,NULL,3,1,2,1,NULL,NULL),(3855,653325594002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','empo_vit','empo.vit@gmail.com','Vitaliy Emporopulo','PO Box 219<br>Hagefen 35','Elyakhin','','ISRAEL','38908','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 08:13:06',0,NULL,3,1,3,1,NULL,'RR815340974CN\r'),(3856,613797241001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',53.79,'hermeshine','pauliusb18','pbareika@yahoo.com','Paulius Bareika','Migliu 4','Ukmerge','','LITHUANIA','20136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 09:13:34',0,NULL,3,1,3,1,NULL,'Lenspen   1\rå¹¿è§’æ‰˜æž¶   1\rcpl   1\ræ¸å˜æ£•   1\ræ¸å˜æ©™   1\ræ¸å˜ç»¿    1\ræ¸å˜ç°    1\r52mm çŽ¯æž¶   1\rç”³æŠ¥$25\rRR815342343CN\r\r '),(3857,653340429002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','kb-diver','kb-diver@bezeqint.net','jacov breznikov','beniyamin 40/10, rehovot','rehovot','','ISRAEL','NON','972546445647','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 10:05:55',0,NULL,3,1,2,1,NULL,NULL),(3858,614059025001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 10:11:44',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815342175CN\r'),(3859,614058960001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','kim_brutis07','kim_brutis@msn.com','Kim Huynh','202/250 Barkly Street','Footscray','Victoria','AUSTRALIA','3011','0423583387','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 10:12:47',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(3860,698170980016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'',8.99,'hutongstore','zegarek777','zegar777@wp.pl','Przemyslaw Ruszkowski','22 Cardinal Road','Leeds','West Yorkshire','UNITED KINGDOM','LS11 8AL','07590073936','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 10:20:01',0,NULL,3,1,2,1,NULL,'æ¸å˜ç°  1\r55mm çŽ¯æž¶   1 '),(3861,653353629002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','schrat17','dirk.doeding@gmx.net','Dirk DÃ¶ding','Bonner Str. 10','KÃ¶ln','','GERMANY','50677','','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 11:29:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815342184CN\r'),(3862,712063036015,250746712937,'55mm Graduated Neutral Density Filter Gradual Grey 55',1,'',4.8,'hutongstore','skuuunk','m.pesenti@hotmail.fr','Maxence pesenti','684 route du badoit Domaine de la gargodiere','Estrablin','RhÃ´ne-Alpes','FRANCE','38780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:39:05',0,NULL,8,1,17,0,NULL,NULL),(3863,712063178015,250599364553,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',2.1,'hutongstore','skuuunk','m.pesenti@hotmail.fr','Maxence pesenti','684 route du badoit Domaine de la gargodiere','Estrablin','RhÃ´ne-Alpes','FRANCE','38780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:39:05',0,NULL,3,1,2,1,NULL,'55mm æ¸å˜ç°  1\r55mm uv    1 '),(3864,712064301015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','soares197150','fsfotosoares@gmail.com','Francisco Soares','Largoda Barreira nÂº2','Vilarandelo','ValpaÃ§os','PORTUGAL','5430-635','252419575','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 11:43:35',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(3865,712075414015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'',6.1,'hutongstore','the_zakman9','the_zakman9@hotmail.com','Zakariyya  Chowdhury','44 oxney road','Manchester','Lancashire','UNITED KINGDOM','m14 5sz','07743900678','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 12:33:45',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ… æ— å­—  1 '),(3866,653373231002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','marialuciaph','marianaphph@yahoo.com.br','maria lucia','rua retiro dos artistas <br>1081','rio de janeiro','rio de janeiro','BRAZIL','22770104','2132566257','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 13:20:03',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815342198CN\r'),(3867,712123805015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'',7.75,'hutongstore','pantharotsa','mevlutizci@hotmail.com','mevlut izci','9 Rivergate Apartments Creywell','Newross','Wexford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2010-12-31 15:29:23',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡  1 '),(3868,653395112002,120564178624,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','rafihay_123','hayat57@gmail.com','rafi hayat','kaliser 1/4','reson-lezion','reson lezion','ISRAEL','75754','0523-862080','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 15:36:41',0,NULL,3,1,3,1,NULL,'ND2/4/8   1\r62mm çŽ¯æž¶    1\rRR815342207CN\r'),(3869,653407288002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','lolica007','rcararo@ig.com.br','LOURDES LISE CARARO','RUA BORTOLO ZANI, 97<br>SALA 1','CAXIAS DO SUL','RIO GRANDE DO SUL','BRAZIL','95072-000','054 3228 5664','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 15:42:21',0,NULL,3,1,3,1,NULL,'RR815342119CN\r '),(3870,653408364002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jayjay689','chung.jerome@gmail.com','jerome chung','bp 9242','papeete','tahiti','FRENCH POLYNESIA','98715','+689 789868','NoPaymentFailure','CheckoutComplete','OtherInternational','2010-12-31 15:46:55',0,NULL,3,1,3,1,NULL,' RR815342122CN\r'),(3871,614135214001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','platonkhegai','pkhegai@gmail.com','Platon Khegai','3-b Butomy str., ap. 105','Nikolaev','','UKRAINE','54040','+380682704430','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 16:23:40',0,NULL,3,1,2,1,NULL,NULL),(3872,653429116002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','compraslagi','lagartillo_13@hotmail.com','ROBERTO  GONZALEZ ENCINAR','CALLE PASAJE DEL PINTOR MURILLO NÂº3','COLLADO VILLALBA','Madrid','SPAIN','28400','627965418','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 17:02:11',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864144081CN\r'),(3873,698291822016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','cia1976','chrisallen1976@live.com','Chris Allen','30 Loftin Way','CHELMSFORD','Essex','UNITED KINGDOM','CM2 9TW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 17:59:19',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 '),(3874,614160976001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','allstar-dj','allstardj@optonline.net','Factory Brands','117 Nassau Ave','Manhasset','NY','UNITED STATES','11030-2403','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 18:01:42',0,NULL,3,1,1,1,NULL,NULL),(3875,712174069015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','cannibalism84','gaspuitis25@gmail.com','Sarunas Gaspuitis','15 Kilmarnock gardens','Dagenham','London','UNITED KINGDOM','RM8 2RE','07787083669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 18:03:08',0,NULL,3,1,2,1,NULL,NULL),(3876,653444078002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','fivedollarngatgmail','fivedollarng@gmail.com','Hak Man Ng','Room 1808, Fu Ming House,<br>Wah Ming Estate, Fanling','default','','HONG KONG','default','(852) 6488 - 0671','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 18:03:52',0,NULL,3,1,2,1,NULL,NULL),(3877,712188629015,250692237083,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',2,'',9.6,'hutongstore','lee2001uk','leigh20034567@yahoo.co.uk','Leigh Hogben','184-6 the street Boughton','Faversham','Kent','UNITED KINGDOM','ME13 9AL','441227751586','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 18:52:37',0,NULL,3,1,2,1,NULL,'77mm ND4   1\r77mm ND8   1 '),(3878,653472520002,120626873273,'New wide angle holder for Cokin P series filter',1,'AKT024',3.99,'hermeshine','bootje1974','corne@agrios.nl','Corne Boogaard','Zandbergsestraat 5','Graauw','','NETHERLANDS','4569TC','(06)55190592','NoPaymentFailure','CheckoutComplete','StandardInternational','2010-12-31 20:19:15',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(3879,614198758001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','edgar.ulises','edgar.cortes@prodigy.net.mx','Edgar Ulises CortÃ©s Ortega','Av. TecomÃ¡n Sur #99<br>Col. El moralete','Colima','Colima','MEXICO','28060','','NoPaymentFailure','CheckoutComplete','NotSelected','2010-12-31 21:14:46',0,NULL,3,1,2,1,NULL,NULL),(3880,653494563002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','jdmkun','jdmkun@yahoo.com','Jon Moody','5935 Crescent Ln','Colleyville','TX','UNITED STATES','76034','(817) 723-5085','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 21:59:00',0,NULL,3,1,1,1,NULL,NULL),(3881,653507170002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','plantseeds4him','blwong2@mac.com','Barb Wong','5585 NW Konigs Ct','Issaquah','WA','UNITED STATES','98027','(206) 940-8671','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2010-12-31 23:16:09',0,NULL,3,1,1,1,NULL,NULL),(3882,712256250015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'',2.98,'hutongstore','thesewords04','thesewords@fsmail.net','andrew taylor','43 polden close','peterlee','Durham','UNITED KINGDOM','sr8 2lh','01915862109','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2010-12-31 23:53:48',0,NULL,3,1,2,1,NULL,'RS-C3   1 '),(3883,653515902002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','fibro66','fitbro@online.no','Finn Brodal','Ingerfjellveien 2<br>Berg','Halden','Ostfold','NORWAY','1788','+47 99539357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 00:12:25',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3884,653526550002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','lungemos','joachim@ringstad.cc','Joachim Ringstad','Grenseveien 58','Oslo','Oslo','NORWAY','0579','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 01:20:37',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW863600083CN\r'),(3885,614242198001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','randall.gerhart','randall.gerhart@gmail.com','Randall Gerhart','14517 32nd Ave NE','Shoreline','WA','UNITED STATES','98155-7523','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 01:48:49',0,NULL,3,1,1,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(3886,653451101002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',71.3,'hermeshine','therapy171275','therapy2005@gmail.com','Roberto Vergara','Huerfanos 2328,. Depto 101','Santiago, Chile','RegiÃ³n Metropolitana','CHILE','6520248','56-09-74760541','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 03:58:18',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  2\rbåº§    2\ræŸ”å…‰ä¼ž  1\råå…‰ä¼ž   1 \rCP219487925CN\r'),(3887,653555526002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','abkaroh1','abkaroh@hotmail.com','Abkar Alawi','3445 Cote-des neiges Apt: 511','Montreal','QC','CANADA','H3H1T5','(514) 550-2020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 05:15:43',0,NULL,3,1,2,1,NULL,NULL),(3888,698434652016,260660053846,'Photo Studio Background Support 2mÃ—3m 7 x 10 ft + BAG',1,'',54.6,'hutongstore','valasakis','valasakis@gmail.com','LOGOTHETIS VALASAKIS','ANAXIMENOUS 59 K. TOUMPA','THESSALONIKI','GREECE','GREECE','54454','6948207802','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 08:19:14',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶   1 \rCP219487934CN\r'),(3889,614279366001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','softital','talbruchiel85@walla.com','tal bruchiel','menachem begin 7/3<br>ramat poleg','netanya','israel','ISRAEL','42201','0547828798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 08:29:37',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´  1  æ¬§æ ‡ '),(3890,614300991001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','koklv53','ekok1207@yahoo.com','yevgeni kokizov','arbel 12/19','karmiel','','ISRAEL','21821','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 11:24:35',0,NULL,3,1,2,1,NULL,NULL),(3891,698474268016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'',2.52,'hutongstore','taffytubby','taffytubby@another.com','Owen LLewellyn','56, Blenheim Gardens','London','n/a','UNITED KINGDOM','SW2 5DA','02086714110','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 12:19:05',0,NULL,3,1,2,1,NULL,NULL),(3892,698471212016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'',12,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:46',0,NULL,8,1,17,0,NULL,NULL),(3893,698155123016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 12:21:46',0,NULL,8,1,17,0,NULL,NULL),(3894,698473298016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'',5.88,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:47',0,NULL,8,1,17,0,NULL,NULL),(3895,712031310015,250606686008,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'',2.75,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:47',0,NULL,8,1,17,0,NULL,NULL),(3896,712041101015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'',6.8,'hutongstore','rtohome','seng@renttoownhome.com.au','Seng Wong','P O Box 137','Forest Hill','Victoria','AUSTRALIA','3131','61412271336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 12:21:48',0,NULL,3,1,4,1,NULL,'NG128   1\rçº¢å¤–é¥æŽ§ nikon   1\r60cm  2in1   1\r2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v   2\råŒ…    1\r1.6m x 3m é»‘è‰²èƒŒæ™¯å¸ƒ  1\rSeng Wong\r32 Jolimont Road, Forest \rHill, VIC 3131,\r Australia.\r61412271336\rYW863600072CN\r\r\r\r '),(3897,712364960015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','1584stefan','aikistef@hotmail.co.uk','stefan tofari','16 clammas way uxbridge','uxbridge','Middlesex','UNITED KINGDOM','ub83an','01895234591','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 12:23:45',0,NULL,3,1,2,1,NULL,'RS-S1   1 '),(3898,653603040002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','emmo2011','sherryhuang2010@gmail.com','Sherry Huang','21B, Tower 3, Bel-air on the Peak<br>68 Bel-air Peak Avenue','default','','HONG KONG','default','(852)98126036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 12:24:24',0,NULL,3,1,2,1,NULL,NULL),(3899,653604509002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kephihx','hhxx@msn.com','XIN HU','Unit 3, No.19 Collins St<br>Preston','Melbourne','Victoria','AUSTRALIA','3072','61425825298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 12:31:43',0,NULL,3,1,2,1,NULL,NULL),(3900,698466006016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'',132,'hutongstore','1mewant','anthonypalaje1@optusnet.com.au','Anthony Palaje','46B Attunga Rd','Yowie Bay','New South Wales','AUSTRALIA','2228','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-01 13:04:22',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m èƒŒæ™¯å¸ƒ  ç»¿è‰²  1\r2m ç¯æž¶  2\r50-70 æ£š  æ¾³æ ‡  2\r115w 220v   2\råŒ…   1 \rYW863600061CN\r'),(3901,614346134001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','show_needs','tpetrosky@showneeds.com','Thomas  Petrosky','15726 Drake St','Southgate','MI','UNITED STATES','48195-3251','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 15:15:41',0,NULL,3,1,1,1,NULL,'58mmæ©¡èƒ¶ç½©   4\r52mmæ©¡èƒ¶ç½©  1\r55mmæ©¡èƒ¶ç½©   2\r77mmæ©¡èƒ¶ç½©  1\r72mmæ©¡èƒ¶ç½©   2'),(3902,653640245002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','mcvetnic1985','mcvetnic@gmail.com','Matija Cvetnic','Stanka Vraza 7a','Sisak','CROATIA','CROATIA','44000','00385992694624','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 15:20:48',0,NULL,3,1,3,1,NULL,'50-70 å¡‘æ–™å¡å£  1 RR815342136CN\r'),(3903,698515366016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'',5.8,'hutongstore','dustyblue05','tasha_s_25@hotmail.com','Natasha Strelzyn','243 Pendlebury Drive West Knighton','Leicester','Leicestershire','UNITED KINGDOM','LE2 6GU','01162920613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-01 15:07:13',0,NULL,3,1,2,1,NULL,'canon ä¸‰è§’åŒ…  1 '),(3904,653648769002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','hope4success','kdta@aol.com','Brad Link','315 Dodge St','Delta','CO','UNITED STATES','81416-1715','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 15:52:05',0,NULL,3,1,1,1,NULL,NULL),(3905,653648732002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',1,'AA3202',18.5,'hermeshine','xuestong','guostong@gmail.com','Qiang Guo','331 Hillside Dr','Mississauga','ON','CANADA','L5M2N3','(905) 826-6904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 15:52:19',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿  N3   1 '),(3906,653651387002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hakka69','nakka@internode.on.net','Lincoln Harrison','42 Ellis st','bendigo','Victoria','AUSTRALIA','3550','0437386554','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶  1 '),(3907,653672290002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','malinovskii','mauglispb@rambler.ru','Andrei Malinovskii','prospect Sizova 32-1-386','Saint-Petersburg','','RUSSIAN FEDERATION','197349','+7(911)959-5130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 17:11:42',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ï¼‰ 2mçš„  1 \rCP219437120CN\r'),(3908,614397654001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','oddgeirn','ebay@oddgeir.no','Oddgeir Nossen','VÃ¥gnesvegen 9','LangevÃ¥g','MÃ¸re og romsdal','NORWAY','6030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 18:08:35',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 \rç”³æŠ¥ ï¼„9.80 '),(3909,614424764001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1301',53.7,'hermeshine','tucorigo','erigaut@wanadoo.fr','Emmanuel RIGAUT','2 ROUTE DE VILLENOTTE','SAINT-EUPHRÃ”NE','CÃ”TE D\'OR','FRANCE','21140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:20:03',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   3 æ¬§æ ‡\r1543  RR815342710CN\r'),(3910,614434020001,110566019962,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:34',0,NULL,8,1,17,0,NULL,NULL),(3911,653725631002,120581555818,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:35',0,NULL,8,1,17,0,NULL,NULL),(3912,614433827001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','samael96','borralla@wanadoo.es','Santiago Hernaez Arzua','Avda Finisterre 187-195 portal 2<br>6 Dcha','A Coruna','Galicia','SPAIN','15010','881918176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 19:48:35',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\r52mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯   1 '),(3913,653735706002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kazachok','ak-al@mail.ru','aleksey chebykin','Kurganskaya, 3-206','Moscow','Ru','RUSSIAN FEDERATION','107065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 20:25:07',0,NULL,8,1,17,0,NULL,NULL),(3914,614443203001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kazachok','ak-al@mail.ru','aleksey chebykin','Kurganskaya, 3-206','Moscow','Ru','RUSSIAN FEDERATION','107065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 20:25:07',0,NULL,3,1,2,1,NULL,'80cm 5in1   1\rlenspen   1 '),(3915,614463788001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','swetlitme81','duffie81@yahoo.com','Casandra Cross','14 Walker ave','Bradford','PA','UNITED STATES','16701-1229','(814) 598-9259','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 21:25:43',0,NULL,3,1,1,1,NULL,NULL),(3916,653757431002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','tlamo20','lamo@epost.no','Thomas Lamo','Malmvegen 126','Tromso','Krokelvdalen','NORWAY','9022','91858178','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 21:34:42',0,NULL,3,1,3,1,NULL,'sony a1 å•è‚©åŒ…  1 RR815342140CN\r'),(3917,712557592015,250692236297,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',2,'',6,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:01',0,NULL,8,1,17,0,NULL,NULL),(3918,698657512016,260661403957,'TianYa 82mm UV filter New 82 Protects Your Lens NIB',1,'',5.2,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:01',0,NULL,8,1,17,0,NULL,NULL),(3919,712557383015,250692242462,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'',3.5,'hutongstore','instantclassic','subasaudio@gmail.com','Hans I. Jonsson','SolvÃ¤gen 7','Ã–rnskoldsvik','VT','SWEDEN','S-89142','+46 660 560 30','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-01 21:38:02',0,NULL,3,1,2,1,NULL,'77mm uv   1\r67mm uv  2\rå¤©æ¶¯ 82mm uv   1 '),(3920,653778766002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pedro_tdm','pedro.tdm@gmail.com','Pedro Mateus','Praceta das Comunidades LusÃ­adas, Bloco B, Lote 2, 6Âºdto','Agualva-CacÃ©m','','PORTUGAL','2735-093','+351966579783','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-01 22:51:44',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW863600094CN\r'),(3921,653786681002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','repeterka','rpeterka@juno.com','robert peterka','3011 62nd Ave E','bradenton','FL','UNITED STATES','34203','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-01 23:25:11',0,NULL,3,1,1,1,NULL,NULL),(3922,614498792001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','leifern83','leiferns@gmail.com','Leif Roger Olsen','GangsÃ¥sveien 45','Harstad','','NORWAY','9408','+47 99749639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-01 23:52:38',0,NULL,3,1,2,1,NULL,NULL),(3923,614507570001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','motorola_01','macjus@gmail.com','Jun Miyagi','2-24-2F Teramachi Nakaku','Hiroshima','Hiroshima','JAPAN','7300801','082-909-3071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 00:37:10',0,NULL,3,1,3,1,NULL,'50-70 å•ç¯å¤´æ£š  1 RR815342286CN\r\r'),(3924,614510502001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','godov09roman','godov09@rambler.ru','Roman Godovanyk','st. Voroshilov, 12 kv.48','Uman','Cherkasy','UKRAINE','20300','380977530073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 00:52:47',0,NULL,3,1,2,1,NULL,NULL),(3925,653808959002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','mikewest1977','mikewest13@hotmail.com','mike west','1214 tredmore dr','mississauga','ON','CANADA','l5j 3v3','(416) 436-8494','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 00:58:23',0,NULL,3,1,3,1,NULL,'84cm ç¯æž¶   1 RR815342290CN\r'),(3926,614511793001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','garnet44','angelaeds@yahoo.com','andrew hagaman','328 Ixora Dr','palm harbor','FL','UNITED STATES','34684-3419','(727) 946-7312','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-02 01:01:00',0,NULL,3,1,3,1,NULL,'nikon  å•è‚©åŒ…  d1   1 RR815342309CN\r'),(3927,653817527002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lrargerich','lrargerich@gmail.com','Luis Argerich','Rastreador Fournier 2233','Olivos','Buenos Aires','ARGENTINA','1636','+541147979908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:42:16',0,NULL,3,1,2,1,NULL,NULL),(3928,653818746002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','a-l-r2624367','a-l-r@e1.ru','Alexandr Senkevich','Kuibushev str.<br>house â„–121 apartment â„–23','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620026','79022797111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:47:49',0,NULL,8,1,17,0,NULL,NULL),(3929,653818716002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','a-l-r2624367','a-l-r@e1.ru','Alexandr Senkevich','Kuibushev str.<br>house â„–121 apartment â„–23','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620026','79022797111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:47:49',0,NULL,3,1,3,1,NULL,'50-70 æ£š  é€šç”¨å¡å£  2 RR815342215CN\r'),(3930,653818987002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','nicdotnet','niccjd@gmail.com','Nic Duthie','17 Connock Street<br>Urangan','Hervey Bay','Queensland','AUSTRALIA','4655','0401924846','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-02 01:51:36',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ é»‘è‰²  1 '),(3931,653819415002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fotoz09','zubpho@yahoo.com','zubeyr kureemun','7A, Paul et Virginie Street','Port-Louis','Port-Louis','MAURITIUS','00230','(230) 7683969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 01:51:44',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ 1 '),(3932,712627740015,250600489459,'New Hairlight photostudio boom arm ',1,'',20.9,'hutongstore','tenderowicz123','rick.tz@hotmail.co.uk','Mr Rick Tenderowicz','96 Fathoms Reach','Hayling Island','Hampshire','UNITED KINGDOM','PO11 0RS','07507545900','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 03:23:54',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342224CN\r'),(3933,614541807001,110489360129,'JueYing Lambency Flash Diffuser for Nikon SB600 SB800 ',1,'AB3306',22,'hermeshine','eighteenvision','fleaustar@hotmail.com','FrÃ©dÃ©ric Garneau','6304 St-AndrÃ©','MontrÃ©al','QC','CANADA','H2S2K5','(514) 686-8217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 03:51:13',0,NULL,3,1,3,1,NULL,'çˆµå½±ç¢—ç½© P1   1 RR815342238CN\r'),(3934,653845759002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','sp.f828','sp@kloda.com','Stephane Poirier','2130 Park','St-Hubert','QC','CANADA','J3Y4Y3','(450) 462-9166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 04:16:22',0,NULL,3,1,3,1,NULL,'40cm é—ªå…‰ç¯ç½©   1 RR815342241CN\r'),(3935,614547249001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 04:26:51',0,NULL,3,1,2,1,NULL,NULL),(3936,653849209002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fkaviani50','fk1002000@yahoo.com','Fred Kaviani','117c South Route 70','Marlton','NJ','UNITED STATES','08053-3024','(856) 396-2490','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 04:39:58',0,NULL,3,1,1,1,NULL,NULL),(3937,653850161002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','davevanrheenen','davidvanrheenen@yahoo.com','David Van Rheenen','1201 Enterprise Ave #701','League City','TX','UNITED STATES','77573','(832) 472-1744','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'echeckï¼Œ æ”¹ä¸ªåœ°å€å‘å§ LK016323065CN'),(3938,653855561002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','jackjen006','p21ras@gmail.com','Jongyun Heo','700 Planetarium Place Room 351<br>Dept. of Chemistry and Biochemistry','Arlington','TX','UNITED STATES','76019','(817) 272-1076','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 05:26:35',0,NULL,3,1,1,1,NULL,'6662a å¿«è£…æ¿ 3 \ræ”¹ä¸ªåœ°å€LK016549104CN'),(3939,712662818015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'',4.5,'hutongstore','rjohnj','ryansexcellentadventure@hotmail.com','Ryan Jephcott','49 Hurst Court','Horsham','West Sussex','UNITED KINGDOM','RH12 2EW','07862990309','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 05:37:49',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3940,614558459001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','guru_lurks','mrcroft@gmail.com','David Croft','40 Gray St.','Woonona','New South Wales','AUSTRALIA','2517','0242849228','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-02 06:10:26',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   2 RR815342255CN\r'),(3941,614569713001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','cikuba','nafizreza@gmail.com','Nafiz Reza','4375 Fairlands Dr<br>Apt 2','Pleasanton','CA','UNITED STATES','94588-3444','(925) 895-3978','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 07:44:01',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ…  æ— å­—  1 '),(3942,653888590002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','d_totzev','d_totzev@yahoo.com','Dimitar Totsev','Tapulintie 14 A 2','Kangasala','','FINLAND','36200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 09:42:31',0,NULL,3,1,2,1,NULL,NULL),(3943,653894945002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','thinredline2006','zhang_miaoyan@yahoo.com','Miaoyan Zhang','2118 Junction Ave','El Cerrito','CA','UNITED STATES','94530','','NoPaymentFailure','CheckoutComplete','Other','2011-01-02 10:12:35',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342167CN\r'),(3944,653917823002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','habeebali2010','habeeeb@gmail.com','Habeeb Ali M. Al Maateeq/DHA 9090','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','966506805260','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-02 11:53:06',0,NULL,3,1,1,1,NULL,'301p ä¸€æ‹–äºŒ  1 '),(3945,698849771016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sizmonz77','sizmonz@yahoo.com','Kiang Kim Lee','8 Ellendale Way','South Morang','Victoria','AUSTRALIA','3752','0394042616','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 12:06:36',0,NULL,3,1,2,1,NULL,NULL),(3946,653920608002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 12:09:26',0,NULL,3,1,3,1,NULL,'50cm æ£š   1 RR815342153CN\r'),(3947,653933852002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','odepropa','otso.alanko@gmail.com','Otso Alanko','Laurinpolku 4 B 20','JyvÃ¤skylÃ¤','','FINLAND','40500','+358407407733','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 12:54:52',0,NULL,3,1,4,1,NULL,'717ah   1 \rballhead $20\rYW863600105CN\r'),(3948,613585003001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',86.9,'hermeshine','zabousik','zabous@zabous.cz','Gabriela Homolova','Rabstejnska 49','Plzen','Czech Republic','CZECH REPUBLIC','32300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 13:33:49',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ é»‘ç™½ç°ï¼‰  1 \rCP219437133CN\r'),(3949,653956358002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','615mikel','lovinma@bellsouth.net','Mike Lovin','1227 Coffee Avenue','Murfreesboro','TN','UNITED STATES','37129','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 14:11:27',0,NULL,3,1,1,1,NULL,NULL),(3950,698901124016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'',40,'hutongstore','xmartin86x','xmartin86x@yahoo.com','Low Martin','BLK 698C Hougang St 52 #03-31 Singapore 533698','Singapore','','SINGAPORE','533698','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 14:39:30',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…  1\r58mm çŽ¯æž¶   1 RR815342272CN\r'),(3951,614674051001,110569963962,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10 ft)',1,'AO0018',45,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 15:05:51',0,NULL,3,1,3,1,NULL,'èƒŒæ™¯å¸ƒ ç™½è‰²  3mx3m   1\råŽšçš„ 1457RR815342723CN\r'),(3952,653978297002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','spettan80','wargert@hotmail.com','Petter Wargert','Dragarbrunnsgatan 66A','Uppsala','Uppsala','SWEDEN','75320','0704-822572','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 15:34:55',0,NULL,3,1,4,1,NULL,'ball head  $20 \rYW863684940CN\r'),(3953,614707073001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','dr.abd','dr-abdallah-fr@wanadoo.fr','FDMJ C/O Dr.Milcent','17B rue de la glaciÃ¨re','Schiltigheim','Alsace','FRANCE','67300','0388196444','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:37:56',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   1\ræ–œè‡‚  1\r50-70 æ£š æ¬§æ ‡   1\r115w 220v   1 \rYW863684914CN\r'),(3954,614709541001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','hucho31.1978','zerho@msn.com','angel del alamo caÃ±amero ','calle monegros / 34 / 1c','leganes','Madrid','SPAIN','28915','679438307','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:40:47',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶   1 RR815342065CN\r'),(3955,614713103001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tolikid','toliknik@gmail.com','ANATOLIY NYKILCHYK','317 - 3160 CASORSO RD','KELOWNA','BC','CANADA','V1W 3L7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 16:49:09',0,NULL,3,1,3,1,NULL,' åå…‰æ¿æ”¯æž¶   1 RR815342079CN\r'),(3956,614717163001,110531023352,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','popihmt','popihmt@hotmail.com','Hugo MaÃ±ez Tamariz','Avda/ Sierra de Aralar<br>nÂº21 / 2Âº C','san SebastiÃ¡n','PaÃ­s Vasco','SPAIN','20014','617222008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 16:58:23',0,NULL,3,1,2,1,NULL,NULL),(3957,654000080002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',5,'AA1301',12.2,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:04',0,NULL,8,1,17,0,NULL,NULL),(3958,654000939002,120560203127,'72mm Lens lenscap for Canon Combined shipping discounts',2,'AA1303',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:03',0,NULL,8,1,17,0,NULL,NULL),(3959,614700044001,110532007043,'67mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',2,'AA1302',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:04',0,NULL,8,1,17,0,NULL,NULL),(3960,614700365001,110532007244,'77mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',2,'AA1304',5,'hermeshine','star031','eric.gueant@aliceadsl.fr','GuÃ©ant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-PyrÃ©nÃ©es','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 17:02:05',0,NULL,3,1,3,1,NULL,'58mm é•œå¤´ç›– canon   5\r72mm é•œå¤´ç›– canon   2\r67mm é•œå¤´ç›–  canon   2\r77mm é•œå¤´ç›–   canon   2 RR815342082CN\r'),(3962,614725085001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','vtectegs','vtectegs@hotmail.com','John P Strott','625 Marine St','La Jolla','CA','UNITED STATES','92037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 17:17:29',0,NULL,3,1,1,1,NULL,NULL),(3963,614727832001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','gregajekos','psiho1@gmail.com','Grega JekoÅ¡','ÄŒanje 25','Blanca','Sevnica','SLOVENIA','8283','051248845','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 17:24:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815342096CN\r'),(3964,654048175002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ofigetj','zjamka@inbox.lv','Julija Antonovica','Staraja Rusas 5 - 23','Riga','','LATVIA','LV-1048','+37126595119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 18:00:34',0,NULL,3,1,2,1,NULL,NULL),(3965,614782514001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jscraire','piccolo999000@hotmail.com','Jean-SÃ©bastien Scraire','12 Rue Deschambault','Ste-ThÃ©rÃ¨se','QC','CANADA','J7E3N7','(450) 420-9974','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 19:05:53',0,NULL,3,1,5,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 \rCP219437116CN\r'),(3966,654095995002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','wzwlwh','kgrweiss9@roadrunner.com','Gary Weiss','235 Smoke Tree Ave','Oak Park','CA','UNITED STATES','91377','(818) 399-2989','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 19:24:21',0,NULL,3,1,1,1,NULL,''),(3967,654097105002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ditatev','ditatev61@mail.ru','Yury Ditatev','severnoe chertanovo, h 5 \"b\", flat 258','Moscow','Russia','RUSSIAN FEDERATION','117648','+79035846093','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 19:26:36',0,NULL,3,1,3,1,NULL,'sony a1 å•è‚©åŒ…   1RR815342105CN\r'),(3968,654105623002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','windslave2110','ghwilson@gmail.com','Gregory H Wilson','1982 Dakin Ave','Menlo Park','CA','UNITED STATES','94025-6045','(650) 561-9817','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 19:42:37',0,NULL,3,1,1,1,NULL,'90th è‚©å¸¦   1 '),(3969,712982020015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'',1.88,'hutongstore','buysellprofit_bsp','buysellprofit@live.co.uk','Lisa Whitehead','32 Regent Street Willenhall','Wolverhampton','West Midlands','UNITED KINGDOM','wv13 1dj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 19:47:03',0,NULL,3,1,2,1,NULL,NULL),(3970,713009529015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'',3.62,'hutongstore','jose_luis_t','joseluistrullo@yahoo.es','JosÃ© Luis Trullo Herrera','Alberche 3, 3Âº Dcha.','Sevilla','AndalucÃ­a','SPAIN','41005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 20:21:26',0,NULL,3,1,2,1,NULL,NULL),(3971,713010134015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'',26,'hutongstore','businjka','marija.sinutkina@inbox.lv','Marija Sinutkina','4a Ballysimon crescen Fairgreen','Limerick','','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-02 20:22:00',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815342670CN\r'),(3972,654016523002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','09klaasjan','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','06-10657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 20:36:27',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(3973,654133701002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','watchthis32','lenz32@gmail.com','Len Zielenski','10124 Haines Canyon Ave','Tujunga','CA','UNITED STATES','91042','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-02 20:38:49',0,NULL,3,1,1,1,NULL,NULL),(3974,614830067001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','snezokk2009','violet@planet.ee','Natalja Grigorjeva','Kivikalme pÃµik 2','Kopli kÃ¼la','Harjumaa','ESTONIA','75321','+37253482549','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 20:38:51',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶ ç™½ç›’  1 RR815342025CN\r'),(3975,614834750001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 20:51:13',0,NULL,8,1,17,0,NULL,NULL),(3976,654138080002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 20:51:13',0,NULL,3,1,5,1,NULL,'æ¡Œé¢ç¯   2\rèƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰ 2m  1 \rCP219437102CN\r'),(3977,699126804016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'',7.52,'hutongstore','gastate09','rhagen1@student.gsu.edu','Rashad Hagen','240 North Ave Apt# 1316','Atlanta','GA','UNITED STATES','30308','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 21:18:51',0,NULL,3,1,1,1,NULL,NULL),(3978,654158734002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jalstton','jalston@wanadoo.es','Antonio Teva Ruiz','Porto, 5 1Âº 3Âª','Sabadell','CataluÃ±a','SPAIN','08206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 21:35:56',0,NULL,3,1,2,1,NULL,NULL),(3979,614872736001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','vaiaphay','ashleypha@verizon.net','Khambeng Aphayaraj','1111 Entrada dr','oxnard','CA','UNITED STATES','93030-2592','','NoPaymentFailure','CheckoutComplete','Other','2011-01-02 22:30:42',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 RR815342697CN\r'),(3980,713078541015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'',3.38,'hutongstore','porsche94462','ianbattlezone@hotmail.co.uk','ian price','78 chiltern road','st albans','Hertfordshire','UNITED KINGDOM','al4 9tb','01727762134','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 22:35:04',0,NULL,3,1,2,1,NULL,' '),(3981,614874934001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3307',9,'hermeshine','scroc_fr','scroc@hotmail.com','Guillaume ALEXANDRE','68, les Casses Vivert','La Batie Neuve','Provence-Alpes-CÃ´te d\'Azur','FRANCE','05230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 22:37:38',0,NULL,3,1,3,1,NULL,' 77mm uv   2\rå¹¿è§’æ‰˜æž¶  1RR815342017CN\r'),(3982,614878169001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','drx-604','drx604@yahoo.com','Dennis Taruc','#9 8250 158th Street','Surrey','BC','CANADA','V4N0R5','(604) 501-9189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-02 22:46:50',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon  1'),(3983,713090773015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'',4.5,'hutongstore','icouldntfindnemo','mrdavidpchapman@yahoo.co.uk','David Chapman','P&O, Suite 12, Alcora Building Mucklows Hill','Halesowen','West midlands','UNITED KINGDOM','B62 8DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 23:05:01',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  nikon  1 '),(3984,698886290016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'',2.2,'hutongstore','mortija2004','mortija2004@hotmail.com','Caron Mortimer','2 Pettits Boulevard','Romford','Essex','UNITED KINGDOM','RM1 4PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-02 23:21:04',0,NULL,3,1,2,1,NULL,'æœºèº«ç›–/é•œå¤´åŽç›–  canon  1 '),(3985,713092394015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',2,'',6.76,'hutongstore','beijer82','stefan.beijer@surfbox.se','Stefan Beijer','BjÃ¤rka Lund 2','Skara','','SWEDEN','53294','0702917441','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-02 23:26:47',0,NULL,3,1,2,1,NULL,NULL),(3986,654196782002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','evita_11','e.giger@hotmail.com','Eva Giger','LÃ¼rlibadstrasse 30','Chur','','SWITZERLAND','7000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 23:27:21',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 æ½˜'),(3987,654200836002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','vinhtran75','vinhtran@hotmail.ca','vinh tran','7-11745 126 ST NW','Edmonton','AB','CANADA','T5M 0S1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-02 23:41:50',0,NULL,3,1,3,1,NULL,'sf18  nikon sb800   1 RR815342048CN\r'),(3988,654211939002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chitalina','denisesaura@gmail.com','Denise Saura','Rua Visconde de Nacar, 1200 / 105<br>Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 00:19:32',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 RR815342051CN\r'),(3989,713142299015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','mapnunes77','mapnunes@gmail.com','Marco Nunes','Av. das ForÃ§as Armadas, 125, 6Âº SECIL - CTRI','Lisboa','Lisboa','PORTUGAL','1600-079','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 01:36:22',0,NULL,3,1,2,1,NULL,NULL),(3990,654238387002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','joaolferreira','boizaum@gmail.com','Joao Lucas Ferreira','Av Buenos Aires 139','Pocos de Caldas','Minas Gerais','BRAZIL','37701367','553588689301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 01:51:03',0,NULL,3,1,2,1,NULL,'åŒç¯å¤´ æ¬§æ ‡  1 '),(3991,713157067015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'',5.8,'hutongstore','pumalives','ianbowers@usa.net','Ian Bowers','3 Melbourne Square Leconfield','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU17 7LG','07947822012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 02:22:42',0,NULL,3,1,2,1,NULL,'72mm æ¸å˜ç°   1 '),(3992,654247865002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','123botas123','desipp@msn.com','Juan RamÃ³n PÃ©rez Pozo','C/RÃ­o Tajo 10, 8ÂºD','AlcorcÃ³n','Madrid','SPAIN','28923','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 02:23:00',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW863684925CN\r'),(3994,614952661001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','global-security','jordan@shattergard.com','ShatterGARD- Frankel','3065 McCall Dr<br>Ste 3','Atlanta','GA','UNITED STATES','30340','(888) 380-9350','NoPaymentFailure','CheckoutComplete','Other','2011-01-03 03:28:06',0,NULL,3,1,1,1,NULL,NULL),(3995,713202777015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'',4.5,'hutongstore','stracj','stracj@btinternet.com','John Strachan','EBC Civic Centre, High Street','Esher','Surrey','UNITED KINGDOM','KT10 9SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 05:23:01',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(3996,654292105002,120618815419,'TianYa 77mm ND8 filter New 77 Neutral Density Grey NIB',1,'AA2314',7.9,'hermeshine','irrubesco','chrislueshing@gmail.com','Christopher  Lue-Shing','19 Valemount Way','Aurora','ON','CANADA','L4G7S7','(905) 726-4055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 05:53:17',0,NULL,3,1,2,1,NULL,'å¤©æ¶¯ 77mm nd8   1 '),(3997,654236832002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','amalia0910','miss.amalia@hotmail.com','Amalia Wakid','98 Lakemba Street<br>Lakemba','Sydney','New South Wales','AUSTRALIA','2195','0297033555','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-03 06:03:48',0,NULL,3,1,3,1,NULL,'1.6x2.1m èƒŒæ™¯å¸ƒ 2\rç™½è‰²ï¼Œ ç°è‰² RR815342683CN\r'),(3998,654293668002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','glamourbomb','burncast@gmail.com','GlamourBomb + BURNcast','7005 Woodley Ave','Van Nuys','CA','UNITED STATES','91406-3924','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 06:06:04',0,NULL,3,1,1,1,NULL,'\r '),(3999,614989730001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','terencen60','terenceng@telus.net','Terence Ng','4450 Fraserside Drive','Richmond','BC','CANADA','V6V 2L7','(604) 522-8319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:49:58',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—   1 '),(4000,614989576001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','capitan.jack','kiril.kirilov.bg1@gmail.com','Kiril Kirilov','1 Kiril Tzonev Str.','Sofia','','BULGARIA','1172','359885730714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:50:21',0,NULL,8,1,17,0,NULL,NULL),(4001,614989639001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','capitan.jack','kiril.kirilov.bg1@gmail.com','Kiril Kirilov','1 Kiril Tzonev Str.','Sofia','','BULGARIA','1172','359885730714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 07:50:22',0,NULL,3,1,5,1,NULL,'ä¸€è½¬å›› ç¯å¤´  2\r45w    8 \rCP219487894CN\r'),(4004,654307261002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','fanxun2009','fanxun@hotmail.com','Xun Fan','2102 Oak St<br>Apt 1','Los Angeles','CA','UNITED STATES','90007-6001','(626) 354-3877','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 08:07:44',0,NULL,3,1,1,1,NULL,NULL),(4005,654317560002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','tropheus72','bluetang@iinet.net.au','Mr S Faulkner','5/9 Hamilton Street','Osborne Park','Western Australia','AUSTRALIA','6017','0412098071','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-03 09:15:30',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  1\rç™½è‰² '),(4006,713240508015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'',2.98,'hutongstore','red_october','harrypilling2@aol.com','Tony Thornton','18 Witton Road Duston','Northampton','Northamptonshire','UNITED KINGDOM','NN56TS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 09:17:34',0,NULL,3,1,2,1,NULL,'rs-s1   1 '),(4007,615000999001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',2,'AB3318',15.8,'hermeshine','miguel.barreiro','miguel_barreiro_docampo@hotmail.com','Miguel Barreiro Docampo','Barrio do Redondo<br>117A','MoaÃ±a','Galicia','SPAIN','36950','654715233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 09:17:45',0,NULL,3,1,2,1,NULL,'æ°¸è¯º sony è½¬æ¢å™¨  2 '),(4008,615006805001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','cheetahnl','frankderoos69@hotmail.com','Frank de Roos','Hendrik Piersonstraat 1','Zetten','','NETHERLANDS','6671CK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 09:50:46',0,NULL,3,1,2,1,NULL,NULL),(4009,615005912001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','sukie057','sukitha_ranaba@yahoo.com','Sukitha Udugamasooriya','369/23, 2nd Lane,<br>Shanthi Mawatha,','Makumbura, Pannipitiya','Colombo','SRI LANKA','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 10:06:15',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(4010,713256998015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',4,'',7.52,'hutongstore','webgeoff1961','g_a_harrison@hotmail.com','G. Harrison','Carril de Don Cecilio 11 Alfacar','Granada','AndalucÃ­a Ceuta y Melilla','SPAIN','18170','661855676','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 10:32:00',0,NULL,3,1,2,1,NULL,NULL),(4011,654334123002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','afonja2000','rusimport@brevet.se','Maxim Agafonov','Lofotengatan 21','Kista','none','SWEDEN','16433','+46739989420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 10:50:03',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿  1 '),(4012,654337909002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','enzo22071985','enzo2207@hotmail.com','Renaud Holtzinger','11 rue Ste CÃ©cile','Neufchef','Lorraine','FRANCE','57700','03.82.55.39.71','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 11:16:28',0,NULL,3,1,3,1,NULL,'è‚©æž¶ 1 \rRR815342992CN\r'),(4013,654339803002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','clivealpine14011970','alpine14011970@yahoo.com.au','Clive Baumann','43 Imperial Pde','Labrador','Queensland','AUSTRALIA','4215','0755376576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:18:59',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°   1 '),(4014,654339504002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dvdark','pichanjr@yahoo.com','pichan jaraswatcharin','1424/234 Soi Prachasongkhro16<br>Dindaeng Hwaikwang','bangkok','bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:19:18',0,NULL,3,1,2,1,NULL,''),(4015,615025628001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','andonigruevski','deepandblue9@gmail.com','andoni gruevski','marrbella 20 piso 2 puerta 209','palma del mallorca','Baleares','SPAIN','07610','658472122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 11:30:12',0,NULL,3,1,2,1,NULL,NULL),(4016,653927977002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','alcintas','alcintas@gmail.com','Antonio Luis Cintas GarcÃ­a','TomÃ¡s Romero de Castilla nÂº4 1ÂºA','Badajoz','Badajoz','SPAIN','06011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-03 12:07:02',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2 \rlight kit  $25\rYW864144044CN\r'),(4017,654356503002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','palaeuffer','palaeuffer@hotmail.com','Pierre-Antoine Laeuffer','25 (flat 3) Colingwood street','Auckland (freemans Bay)','','NEW ZEALAND','1011','(022) 692-5935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 12:38:59',0,NULL,3,1,2,1,NULL,NULL),(4018,654366211002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','ojellav','roger_vallejo@hotmail.com','Roger Vallejo','2905 Bushnell Dr','Austin','TX','UNITED STATES','78745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:21:44',0,NULL,3,1,1,1,NULL,' '),(4019,654366709002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','kapicka','kapicka@msn.com','Kapicka','1609 41st St','Sacramento','CA','UNITED STATES','95819','(916) 705-3160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:23:54',0,NULL,8,1,17,0,NULL,NULL),(4020,654366475002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','kapicka','kapicka@msn.com','Kapicka','1609 41st St','Sacramento','CA','UNITED STATES','95819','(916) 705-3160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 13:23:55',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›– canon  1\ræœºèº«ç›–/é•œå¤´åŽç›– canon 1 '),(4021,615051540001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','waviralw','ford_10avi@hotmail.com','Ajay kochhar','# 24 denbigh ave<br>Mt.Roskill','Auckland','OR','NEW ZEALAND','1041','0212615916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 13:27:07',0,NULL,3,1,2,1,NULL,NULL),(4022,713305853015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',2,'',3.76,'hutongstore','owen.thomas','owen@thethumbwebsite.com','Owen Thomas','Thumb 63 Westgate Rd','Newcastle upon Tyne','Tyne & Wear','UNITED KINGDOM','NE1 1SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 13:36:22',0,NULL,3,1,2,1,NULL,NULL),(4023,614979249001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','sweetbabylaine11','sweetbabylaine11@yahoo.com','CHRISTIAN BALUYUT','3394 Redpath Circle','Mississauga','ON','CANADA','L5N8R8','(905) 820-1240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 14:05:24',0,NULL,3,1,2,1,NULL,NULL),(4024,654378628002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bigbird11','glmarkle@energage.com','Gary Markle','327 Riverview Dr<br>Unit 5728','Ellijay','GA','UNITED STATES','30540-5486','(706) 636-3429','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 14:18:48',0,NULL,3,1,1,1,NULL,NULL),(4025,615066231001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','guitar4pax','kidz2raise@gmail.com','David Hanvey','404 Shoemaker Dr','Chesapeake','VA','UNITED STATES','23325-4825','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 14:29:34',0,NULL,3,1,1,1,NULL,NULL),(4026,713328887015,250692240830,'Wireless Remote Control for Olympus E-420/E-410/E-400',1,'',11.47,'hutongstore','eavi7102','medi11158@telefonica.net','Emilio Avila Marquez','Avinguda del Montgo 16 bajo','paiporta','Comunidad Valenciana','SPAIN','46200','677382249','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 14:51:25',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ E2    1 '),(4027,615074556001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','jakubnozicka','nozicka.jakub@gmail.com','Jakub Nozicka','U Dvora 1076','Uherske Hradiste','','CZECH REPUBLIC','68605','00420-723-131-668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:01:31',0,NULL,3,1,2,1,NULL,NULL),(4028,615077581001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','zens_nl','zen_stolk@hotmail.com','Jaap Stolk','EMI Music<br>Paul van Vlissingenstraat 10-C','Amsterdam','','NETHERLANDS','1096 BK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:09:03',0,NULL,3,1,2,1,NULL,NULL),(4029,614818471001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','terechka','terenaz@bigpond.com.au','Theresa Zagorski','12 Daffodil Court<br>GOWANBRAE','Melbourne','Victoria','AUSTRALIA','3043','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:15:36',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… Nikon  1 '),(4030,615083615001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','chacablue','carolannphelps@sbcglobal.net','Carol Ann Phelps','309 Quinnipiac Ave','North Haven','CT','UNITED STATES','06473','(203) 752-9925','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 15:33:07',0,NULL,3,1,1,1,NULL,'RS-N1   1 '),(4031,615088798001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 15:48:27',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´æ£š  æ¬§æ ‡    1 \rRR815342913CN\r'),(4032,654410460002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','gontzal84','gontzal20@hotmail.com','Gonzalo Rubinos Artolozaga','arebeta bidea 10 bajo','Berango','PaÃ­s Vasco','SPAIN','48640','946680889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 16:05:28',0,NULL,3,1,4,1,NULL,'6662a   1 \rYW864144033CN\r'),(4033,615094514001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','kerkuan','shellshocking@yahoo.com','Ho Pang Cheng','118, Serangoon Ave 3, #14-09','default','','SINGAPORE','554773','96421046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 16:09:16',0,NULL,3,1,11,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4034,654420449002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','corndogpilot','acorn@progress.com','Aaron Corn','141 Wallace Hill Rd','Townsend','MA','UNITED STATES','01469','(978) 597-0123','NoPaymentFailure','CheckoutComplete','Other','2011-01-03 16:35:46',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   1 \rRR815342961CN\r'),(4035,654425567002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ryanisaitebruh','aitebruh@yahoo.com','Ryan Ricklefs','1796 Dexter Oaks Ln<br>Apt 204','Cordova','TN','UNITED STATES','38016-1581','(901) 757-2985','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 16:51:38',0,NULL,3,1,1,1,NULL,NULL),(4036,615113093001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','soundcoast','adriankangkl@gmail.com','Adrian Kang','Blk. 22 Eunos Crescent #16-3003','Singapore','','SINGAPORE','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 17:02:12',0,NULL,3,1,11,1,NULL,'å“èƒœ3.0   1 '),(4037,654429958002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','evilkido','evil_kid_o@hotmail.com','Alberto Juarbe','1932 Calle Perafan Rivera','San Juan','PR','UNITED STATES','00926-7744','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 17:03:01',0,NULL,3,1,1,1,NULL,NULL),(4038,615119309001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',12,'AA1309',29,'hermeshine','t-minustom','thomjrogers@tminusproductions.com','Thom Rogers','40213 N La Cantera Dr','Phoenix','AZ','UNITED STATES','85086-2973','(928) 699-4041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 17:18:26',0,NULL,3,1,1,1,NULL,NULL),(4039,615136246001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','losangeles8264','csinetpro@gmail.com','Ingo Lehmann','6331 Hollywood Blvd<br>Ste 1200','Los Angeles','CA','UNITED STATES','90028-6340','(323) 960-3500','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 18:05:31',0,NULL,3,1,1,1,NULL,'éº‚çš®  3 '),(4040,699483423016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'',5.8,'hutongstore','aldav33','ales.vym@tiscali.cz','Ales Vymetal','Zlutava 63','Napajedla','Czech Republic','CZECH REPUBLIC','76361','604855020','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-03 18:09:37',0,NULL,3,1,2,1,NULL,'77mm æ¸å˜ç°  1 '),(4041,654467635002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','matje56','matje_kater@hotmail.com','Matthijs Kater','Pr. Bernhardlaan 36','maartensdijk','','NETHERLANDS','3738 DP','06-17194733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 18:37:45',0,NULL,3,1,2,1,NULL,NULL),(4042,699505471016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'',120,'hutongstore','adbidonline','andylong1969@googlemail.com','Andrew Long','6 Sancroft Way','Fressingfield','Eye, Suffolk','UNITED KINGDOM','IP21 5QN','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-03 18:53:32',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´ æ£š  è‹±æ ‡   2\r45w   8\råŒ…   1\rlighting kit  $30 \rYW864144022CN\r'),(4043,654476345002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','northshore96712','taydork@hotmail.com','Taylor Vollrath','58-130 Kamehameha Hwy','Haleiwa','HI','UNITED STATES','96712-9714','(808) 638-7101','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 18:57:45',0,NULL,3,1,1,1,NULL,NULL),(4044,615150726001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','rinse68','rina@bcbnet.dk','Rina Torp','Soeborg Hovedgade 42 C, 4. tv','Gladsaxe','Gladsaxe','DENMARK','2860','(0045) 28122954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 18:59:41',0,NULL,3,1,2,1,NULL,'éº‚çš®   1 '),(4045,654479506002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','grnath09','ranganath.gogineni@gmail.com','Ranganadh Gogineni','1427 Valley Lake Dr<br>Apt 404','Schaumburg','IL','UNITED STATES','60195-3629','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 19:06:46',0,NULL,3,1,1,1,NULL,NULL),(4046,615176317001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','jen_n_lena','gowithwindap@gmail.com','Jieyi Xu','1808 Van Wickle Dr','Franklin Park','NJ','UNITED STATES','08823-2613','(816) 256-1206','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 19:38:42',0,NULL,3,1,1,1,NULL,NULL),(4047,615194241001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',2,'AA2326',21.6,'hermeshine','blueandy963','andy@jobbii.fsnet.co.uk','ANDREW M JOBBINS','25 HONITON WAY ALDRIDGE','WALSALL','West Midlands','UNITED KINGDOM','WS9 0JS','','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-01-03 20:21:58',0,NULL,3,1,3,1,NULL,'cpl   2 \rRR815342975CN\r'),(4048,713502454015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'',3.62,'hutongstore','andy7777777rugby','andyread40@hotmail.com','Andy Read','Greenham A1/A2 Gellihirion Ind Est','Pontypridd','Mid Glamorgan','UNITED KINGDOM','CF37 5SX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 21:01:50',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶   1 '),(4049,654529980002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kallirae21','kallirae21@yahoo.com','Kalli Sterling','33 Alamosa Dr','Trophy Club','TX','UNITED STATES','76262','(817) 490-5149','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 21:11:19',0,NULL,3,1,1,1,NULL,NULL),(4050,654539510002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','beautyhest','bjorn.setekleiv@powermail.no','BjÃ¸rn Setekleiv','Anders Henriksensvei 10','SaltrÃ¸d','','NORWAY','4815','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:30:44',0,NULL,3,1,4,1,NULL,'åå…‰æ¿æ”¯æž¶   1\r2m ç¯æž¶   1 \rreflector holder   $20\rYW864144011CN\r'),(4051,615225282001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','pia_kl','siri.krohn@gmail.com','Siri Alice Krohn','Pegasusveien 21','TÃ¸nsberg','','NORWAY','3113','4793267161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:42:42',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4052,713522845015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'',3.76,'hutongstore','peters3298','petersaunders@nhs.net','Peter Saunders','3 Woodperry Hill Woodperry','Oxford','Oxfordshire','UNITED KINGDOM','OX33 1AL','01865351045','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 21:44:37',0,NULL,3,1,2,1,NULL,NULL),(4053,615226498001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','gemplayer','cs_support@gemplayer.com','Pongchanok Poonnotok','940/103 Soi Udomsuk56','Bangna','Bangkok','THAILAND','10260','(084)121-3132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 21:47:50',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´   1 \rRR815342989CN\r'),(4055,615230975001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','charlieking20','charlieking20@hotmail.com','karine brousseau','1474    46rue','shawinigan','QC','CANADA','g9n5b8','(819) 539-6024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:01:22',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ  ç™½è‰²  1 '),(4056,615232872001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','cubebleu','imwt@hotmail.com','Mathieu Pelletier','1-3620 Henri-Weber','Trois-Rivieres','QC','CANADA','G8Y6H1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:04:26',0,NULL,3,1,2,1,NULL,'æ°”å¹+ å¸ƒ   1 '),(4057,654557443002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','mapleridgeauction','sales@mapleridgeauction.com','Maple Ridge Auction','21730 121 Ave','Maple Ridge','BC','CANADA','V2X 3S6','(604) 805-1148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 22:20:31',0,NULL,3,1,2,1,NULL,'115w 110v  1 '),(4058,713538912015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'',2.58,'hutongstore','beata1980s','kstrycharz@op.pl','Beata Pastuszak','Flat 4 Chapel House Club Lane','Halifax','West Yorkshire','UNITED KINGDOM','hx2 8ae','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-03 22:21:17',0,NULL,3,1,2,1,NULL,NULL),(4059,654567443002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ksalicat','alisonebright@yahoo.com','Alison Ebright','6041 Locust St','Kansas City','MO','UNITED STATES','64110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 22:57:04',0,NULL,3,1,1,1,NULL,NULL),(4060,654570960002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','elysiachoo','chooeunzi@naver.com','Elysia Choo','201 Husson Ave<br>Apt T4','Bangor','ME','UNITED STATES','04401-3242','(818) 454-0637','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:06:12',0,NULL,3,1,1,1,NULL,NULL),(4061,615255537001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','yamahagreg','shellcullen@hotmail.com','Shelley Cullen','N7870 Creekside Drive','Sherwood','WI','UNITED STATES','54169','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:22:57',0,NULL,3,1,1,1,NULL,NULL),(4062,654578114002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tiancew','wangtiance@gmail.com','Tiance Wang','10 Lawrence Dr<br>Apt 202','Princeton','NJ','UNITED STATES','08540-7139','(609) 865-6855','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-03 23:33:12',0,NULL,3,1,1,1,NULL,NULL),(4063,615264398001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',3,'AA1204',4.97,'hermeshine','henzmeeali','henzmee@yahoo.com','MdRapi Jomain','No 12,Lot 10917<br>Taman Selasih Perdana Fasa 2','Dungun','Terengganu','MALAYSIA','23000','013-9375010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-03 23:58:26',0,NULL,3,1,2,1,NULL,'çƒ­é´ç›– 3 '),(4064,615281462001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','esp0715','epoysp@yahoo.com','efren san pedro','10063 Canyon Hills Ave','las vegas','NV','UNITED STATES','89148-7646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 01:09:43',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… nikon   1 '),(4065,713593273015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'',7.99,'hutongstore','n-gauge-2topcat2','duncandown@aol.com','  CLIVE THORNE','LAHAI-ROI BORSTAL AVENUE','WHITSTABLE','KENT','UNITED KINGDOM','CT5 4NX','01227275389','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 01:11:25',0,NULL,3,1,2,1,NULL,'1.6x2.1 èƒŒæ™¯å¸ƒ ç™½è‰²  1 '),(4066,699665043016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'',19.5,'hutongstore','shaw_bob','shaw_bob@hotmail.com','Robert Shaw','c/o Ihnen Electronics 236 Battlefield Road','Battlefield','Glasgow','UNITED KINGDOM','G42 9HN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 01:41:21',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ å†¬å¤  xl   1\råŽŸæ¥ç°è‰²çš„é‚£æ¬¾ \rRR815343009CN\r'),(4067,615043713001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','kurtsin','kerhhk2000@yahoo.com','Haun Keey Kerh','63 Tampines Ave 1 #13-06 The Tropica<br>Singapore 529777','default','','SINGAPORE','529777','6597847212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 01:53:35',0,NULL,3,1,11,1,NULL,'å°å·å†…èƒ†åŒ…  nikon   1'),(4068,654619392002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','mtg-978','probbob@gmail.com','Connor Scanlon','178 Sterling Rd','Princeton','MA','UNITED STATES','01541-1201','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 02:24:31',0,NULL,3,1,1,1,NULL,'58mm æ¸å˜ç°  1 '),(4069,654624184002,120571006893,'Green.L 67mm Neutral Density ND8 Filter  67 D90 D300s',1,'AE2312',6.7,'hermeshine','trixot23','daniel.hedberg92@hotmail.com','Daniel Hedberg','alftavÃ¤gen 58','BollnÃ¤s','BollnÃ¤s','SWEDEN','82130','0705267814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 02:42:34',0,NULL,8,1,17,0,NULL,NULL),(4070,654623207002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','trixot23','daniel.hedberg92@hotmail.com','Daniel Hedberg','alftavÃ¤gen 58','BollnÃ¤s','BollnÃ¤s','SWEDEN','82130','0705267814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 02:42:34',0,NULL,3,1,2,1,NULL,'80cm 2in1 åå…‰æ¿ 1\r67mm ND8   1 '),(4071,654631558002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','nonefilm85','j.hanna.filmmaker@gmail.com','Jay Hanna','po box 4163','valley village','CA','UNITED STATES','91617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 03:07:46',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   1 '),(4072,654641157002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','alancole2000','alan@alancole.com','Alan Cole','17411 Kirstin Ct','Olney','MD','UNITED STATES','20832-2542','(301) 794-1131','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 03:52:43',0,NULL,8,1,17,0,NULL,NULL),(4073,615317108001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5,'hermeshine','alancole2000','alan@alancole.com','Alan Cole','17411 Kirstin Ct','Olney','MD','UNITED STATES','20832-2542','(301) 794-1131','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 03:53:41',0,NULL,3,1,1,1,NULL,'67mm é•œå¤´ç›–  nikon  2\r77mm é•œå¤´ç›–  nikon  1 '),(4074,615324771001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kian0212','acg1612@optonline.net','ANDY DEGUZMAN','209 Comly R. Apt. G-13','Lincoln Park','NJ','UNITED STATES','07035','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 04:34:50',0,NULL,3,1,1,1,NULL,NULL),(4075,615325298001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','tarabaman','masiegel.esq@gmail.com','Marcus A Siegel','35 James Street<br>Windsor','Melbourne','Victoria','AUSTRALIA','3181','0395211177','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-04 04:41:27',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ ï¼ˆ ç™½ é»‘ï¼‰  1 \rbackground support $20\rYW864144000CN\r'),(4076,654654074002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','thomasjavier','thomasjcastillo@gmail.com','Thomas Castillo','445 S 5th Ave','Tucson','AZ','UNITED STATES','85701-2446','(520) 403-1467','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 05:08:44',0,NULL,3,1,1,1,NULL,'cåž‹å¤¹   2 '),(4077,615331038001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','manna1722','manna1722@aol.com','Anna Kearns','4869 Village Gardens Dr.','Sarasota','FL','UNITED STATES','34234','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 05:15:02',0,NULL,3,1,2,1,NULL,'Thomas Richard Meszaros\rBudapest Horanszky u. 6\r1085 Hungary \r\r'),(4078,654660397002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fritz4003','alphy27@cox.net','James Olivier','123 Evergreen St','Providence','RI','UNITED STATES','02906-2510','(401) 527-4238','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 05:54:42',0,NULL,3,1,1,1,NULL,NULL),(4079,654679053002,120601698743,'Canon 52mm Reverse Adapter 450D 50mm 1.8 500D Macro',1,'AA1207',4.4,'hermeshine','xtrobe','xtrobe@gmail.com','Reamur David','32 Viceroy St., East Fairview','Quezon City','Metro Manila','PHILIPPINES','1118','6325834754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 08:21:20',0,NULL,3,1,2,1,NULL,NULL),(4080,654675791002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nina-0047','ninae-k@online.no','nina karlsen','godÃ¸ynes','tverlandet','bodÃ¸','NORWAY','8050','004790293266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 08:39:11',0,NULL,3,1,3,1,NULL,'50-70 å½±è§†ç¯æ£š å¡‘æ–™å¡å£   1 \rRR815341303CN\r'),(4081,713701759015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','alanreed53','alanreed53@talktalk.net','Alan Reed','17 Postwick Lane, Brundall','Norwich','Norfolk','UNITED KINGDOM','NR135RQ','01603713216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 09:49:35',0,NULL,3,1,2,1,NULL,NULL),(4082,713709858015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',2,'',3.76,'hutongstore','rudomadar','rudo.madar@gmail.com','Rudolf Madar','Ovrucska 12','Kosice','Slovakia','SLOVAK REPUBLIC','04022','421902139908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 10:25:31',0,NULL,3,1,2,1,NULL,NULL),(4083,654698797002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','arojasb','arojasb76@gmail.com','Antonio Rojas Borrego','Paseo la Florida, 70A 1Âº1Âº','Santa Perpetua de Mogoda','CataluÃ±a','SPAIN','08130','935742234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 10:26:48',0,NULL,3,1,4,1,NULL,'æ¡Œé¢ç¯   2 å¥—\rç¯æž¶+ç¯å¤´ \rYW864143974CN\r'),(4084,699771254016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'',38,'hutongstore','jphotographyb','jamesbianchi88@gmail.com','James Bianchi','13, Olive Street The Gardens','St Julains','Malta','MALTA','stj 1953','0035621359413','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 10:30:06',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\råå…‰æ¿æ”¯æž¶    1 \rRR815341215CN\r'),(4085,654701966002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chitalina','denisesaura@gmail.com','Jason Silva','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 10:45:20',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž    1 \rRR815341229CN\r'),(4086,654703351002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','niktos26','jozef.hanak@gmail.com','Jozef HanÃ¡k - s IT Solutions CZ','Antala Staska 32','Prague','','CZECH REPUBLIC','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 10:51:05',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(4087,654707274002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','ibedo75','aliibedo@gmail.com','ALI IBEDO','ABU DHABI - AL SAADA STREET','ABU DHABI','ABU DHABI','UNITED ARAB EMIRATES','31414','00971508198689','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 11:12:22',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ canon L   1 \rRR815341232CN\r'),(4088,654706505002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','v11555','cyclone.15@msn.com','Umur Derinyar','1.Murat Mah. Gungor Mazlum Cad. Umit Apt. A/2 Blok - D:7','Edirne / Merkez','','TURKEY','22030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 11:13:13',0,NULL,3,1,3,1,NULL,' RR815341246CN\r'),(4089,709735005015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'',127,'hutongstore','huhucool','ailin.ohearchai@gmail.com','Alan Harrison','Knockegan Cloona','Ballina','Mayo','IRELAND','096','09621940','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-04 11:26:09',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰   1\r2m ç¯æž¶   2\råŒç¯å¤´ è‹±æ ‡   2\råå…‰ä¼ž   2\r115w 220v    4\råŒ…    1\r lighting kit   $30 \rYW864143985CN\r'),(4090,654719944002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','johnsonxu1121','haojixu@hotmail.com','JOHNSON XU','6 LIZ PLACE<br>SUNNYBANK HILLS','BRISBANE','Queensland','AUSTRALIA','4109','61433570227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 12:13:11',0,NULL,3,1,2,1,NULL,'lenspen   1 '),(4091,615398502001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vadbe2l2','vadimbelya@gmail.com','vadim belya','haliya 74/23','beer sheva','n/a','ISRAEL','84742','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 12:29:27',0,NULL,3,1,11,1,NULL,NULL),(4092,713741341015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','asor3084','antoinesorin@ebuyclub.com','antoine sorin','51 rue migault','frontenay rohan rohan','Poitou-Charentes','FRANCE','79270','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 12:36:22',0,NULL,3,1,2,1,NULL,NULL),(4093,654725493002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','lyuboslav.asenov','lyubo.asenov@gmail.com','Lyuboslav Asenov - GeoCon','Boris Hristov 2A / et.2 office GeoCon','Sofia','Sofia','BULGARIA','1111','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 12:39:41',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶    1\räº‘å°   1\ræŸ”å…‰ä¼ž    1 \rRR815341250CN\r'),(4094,713752152015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'',1.88,'hutongstore','arazi145','sentaur14@gmail.com','Akhtar Ramzan','65a Devonshire Street','Keighley','West Yorkshire','UNITED KINGDOM','BD21 2BJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 13:15:07',0,NULL,3,1,2,1,NULL,NULL),(4095,615414881001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','cave.explorer2008','cave.explorer@yahoo.com','Manuel Jimenez','Calle Alameda #8<br>Munoz Rivera','Guaynabo','PR','PUERTO RICO','00969','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-04 13:43:13',0,NULL,3,1,3,1,NULL,'301p ä¸€æ‹–ä¸‰   1 \rRR815341161CN\r'),(4096,699820182016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'',4.5,'hutongstore','caterham7go','axfordg@googlemail.com','Graham Axford','The Creative Assembly, Southern Housing Group 2nd Floor, Spire Court, Albion Way','Horsham','West Sussex','UNITED KINGDOM','RH12 1FB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 13:45:04',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4097,654742342002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','fabianopasold','fabianopasold@brturbo.com.br','fabiano pasold','rua bernardo dornbusch, 1973<br>vila lalau','jaraguÃ¡ do sul','santa catarina','BRAZIL','89256100','47 3371-2464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 13:49:25',0,NULL,3,1,3,1,NULL,'40cm é—ªå…‰ç¯æ£š   1 \rRR815341175CN\r'),(4098,654738808002,120568891616,'Male-Male 52mm-52mm Reverse Macro 40D 450D 550D D90',1,'AA1211',7.6,'hermeshine','auc1','agmail48-buy10ebay@yahoo.com','Gabriel Ash','Rte de Bardonnex 23','Plan les Ouates','','SWITZERLAND','1228','(022) 340-0005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 14:29:49',0,NULL,3,1,2,1,NULL,'52-52mm åŒé˜³çŽ¯ 1\r52-58mm åŒé˜³çŽ¯  1\r '),(4099,654768967002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','ajrogers111','ajrogers111@hotmail.com','John Rogers','4908 Boundview Ct','Summerville','SC','UNITED STATES','29485-8683','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 15:38:53',0,NULL,3,1,1,1,NULL,NULL),(4100,654774709002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','danpont','danielaaronpont@gmail.com','Dan Pont','PO Box 81<br>916 W. Buffalo','Rawlins','WY','UNITED STATES','82301-0081','(307) 321-0307','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 15:50:27',0,NULL,3,1,1,1,NULL,NULL),(4101,615458860001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','closetm','info@closetm.com','Mark Sher','2210 Forest Haven Blvd','Edison','NJ','UNITED STATES','08817','(732) 241-5100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 16:27:39',0,NULL,3,1,1,1,NULL,'éº‚çš®   1 '),(4102,699874052016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'',5.8,'hutongstore','jerseymermaid1','sue@suedalyproductions.com','Sue Daly','La Retraite Sark','Guernsey','Channel Islands','GG','GY9 0SF','01481 832175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 16:28:06',0,NULL,5,1,18,0,NULL,'77mm æ¸å˜ç°  1 \rSue Daly\rLa Retraite\rSark\rGuernsey, Channel Islands\rGY9 0SF\rGuernsey\r'),(4103,615508119001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',9.9,'hermeshine','sd1609','d.plantrou@laposte.net','David plantrou','2 avenue des abattoirs','Louviers','Haute-Normandie','FRANCE','27400','02.32.25.55.88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 18:46:30',0,NULL,3,1,2,1,NULL,'pentax è‚©å¸¦   1 '),(4104,713881317015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'',12.99,'hutongstore','legros555','rudy.terras@wanadoo.fr','RUDY TERRAS','15 COURS GAMBETTA','TARBES','Midi-PyrÃ©nÃ©es','FRANCE','65000','0562930559','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 18:54:15',0,NULL,3,1,2,1,NULL,NULL),(4105,654847023002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kitenut1','dzke06109@hotmail.com','Richard M. Johnson','4 David St','Greenville','RI','UNITED STATES','02828-2307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 19:17:24',0,NULL,3,1,1,1,NULL,NULL),(4106,654848597002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','kjeteriks','kjet.erik@yahoo.no','kjetil Eriksen','Hamningbergveien 14','BÃ¥tsfjord','','NORWAY','9990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 19:17:52',0,NULL,3,1,2,1,NULL,NULL),(4107,654861881002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','chadan2009','danny1968@live.fr','Danny Jack','151 McConville','Joliette','QC','CANADA','J6E 4L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 19:47:21',0,NULL,8,1,17,1,NULL,' '),(4108,615543129001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','olegluft','olegl72@gmail.com','Oleg Luft','Ezra Sofer 17/4','Ashdod','','ISRAEL','77468','0508116967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 20:10:07',0,NULL,3,1,11,1,NULL,'åŒç¯å¤´   æ¬§æ ‡   1 '),(4109,615562466001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','450_belisle','lbelisle@videotron.ca','Luc Belisle','67 Varin','Repentingy','QC','CANADA','J5Y1L8','(450) 585-2279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 20:58:32',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡  1 '),(4110,615571993001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','p2auctions','jeckalbr69@msn.com','Pierre Chambrin','310 Berry Bush Ct','Wildwood','MO','UNITED STATES','63011-2086','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 21:24:25',0,NULL,3,1,1,1,NULL,'40cm æ£š   1 '),(4111,654902835002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','dtadeuribeiro','dtadeu@gmail.com','Daniel Tadeu Ribeiro','Rua Padre Questor, 91<br>Bairro Timirim','TimÃ³teo','Minas Gerais','BRAZIL','35180-304','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 21:28:29',0,NULL,8,1,17,0,NULL,''),(4112,700027332016,260660051378,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'',2.75,'hutongstore','koolsony','koolsony@hotmail.com','SCHMITT Pierre','3 rue de la Verrerie Les Balladines B2','Cannes La Bocca','Provence-Alpes-CÃ´te d\'Azur','FRANCE','06150','0493902405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:56:41',0,NULL,8,1,17,0,NULL,''),(4113,615583182001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','henkslot','henk@theidea.nl','Henk Slotboom','Willem Alexanderweg 73B','Cothen','','NETHERLANDS','3945 CH','06 5333 1778','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-04 21:57:09',0,NULL,3,1,2,1,NULL,'canon å°åŒ…  1 '),(4114,700027666016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','falderro','mjhager@uwalumni.com','Mitchell Hager','2124 Winterberry Ln','Shakopee','MN','UNITED STATES','55379-5901','(612) 483-5821','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:57:37',0,NULL,3,1,1,1,NULL,NULL),(4115,700027900016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'',2.3,'hutongstore','koolsony','koolsony@hotmail.com','SCHMITT Pierre','3 rue de la Verrerie Les Balladines B2','Cannes La Bocca','Provence-Alpes-CÃ´te d\'Azur','FRANCE','06150','0493902405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 21:57:57',0,NULL,3,1,2,1,NULL,' sony çº¢å¤–é¥æŽ§  1 \rsony çš„çƒ­é´ç›–   1'),(4116,713983750015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'',2.39,'hutongstore','pajr777','pajr777@hotmail.com','Paul Robinson','21 Chesterton Lane','Cirencester','Gloucestershire','UNITED KINGDOM','GL7 1XQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 22:19:34',0,NULL,3,1,2,1,NULL,'67mm æŽ¥å£çŽ¯   1 '),(4117,615581701001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','mellena88','mellena88@yahoo.com','Matt Ellena','12118 Crystal Glen Way','Northridge','CA','UNITED STATES','91326','(818) 360-8383','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-04 22:27:17',0,NULL,3,1,1,1,NULL,NULL),(4118,654927005002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ckelton','kelton@uwindsor.ca','Chrissy Kelton','1781 Cottonwood Avenue','Kingsville','ON','CANADA','N9Y 2W2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 22:36:10',0,NULL,3,1,2,1,NULL,NULL),(4119,700044340016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'',3.78,'hutongstore','sramolu','sramo@svetielko.sk','Lubomir Sramo','Kvetoslavov 456','Kvetoslavov','','SLOVAK REPUBLIC','93041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 22:47:13',0,NULL,8,1,17,0,NULL,NULL),(4120,713992118015,250600523996,'Shutter Release Remote Cord For Pentax K20D K10D K-7 K7',1,'',2.98,'hutongstore','sramolu','sramo@svetielko.sk','Lubomir Sramo','Kvetoslavov 456','Kvetoslavov','','SLOVAK REPUBLIC','93041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-04 22:47:14',0,NULL,3,1,2,1,NULL,'lenspen   1\rRS-C1   1 '),(4121,615539399001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','lunka1979','alya_lunina@mail.ru','Aliya Lunina','Universitetskaya, 52/48','Donetsk','donetsk','UKRAINE','83050','+38095-137-11-72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-04 22:58:16',0,NULL,3,1,2,1,NULL,NULL),(4123,615597550001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','mtg-978','probbob@gmail.com','mine','178 Sterling Rd.','Princeton','MA','UNITED STATES','01541','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-01-04 23:30:12',0,NULL,3,1,1,1,NULL,'77mm æ¸å˜ç°  1 '),(4124,714010210015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'',5.2,'hutongstore','bormio2003maloneyx','hughedwards@supanet.com','Hugh Edwards','7 Bryn Heulog Ysceifiog','Holywell','Flintshire','UNITED KINGDOM','CH88NR','01352720837','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-04 23:33:47',0,NULL,3,1,2,1,NULL,'62mm æ¸å˜ç°   1 '),(4125,714025751015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'',7.48,'hutongstore','pols0074031','ilmarsguza@inbox.lv','Ilmars Guza','Ilukstes34-139','default','','LATVIA','LV-1082','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 00:26:31',0,NULL,3,1,2,1,NULL,'å¤§å·ç°å¡   1 '),(4126,615623302001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','zouwen10','wenzou@thewenstudio.com','wen zou','1209 Richmond St. APT# 1009','London','ON','CANADA','n6a 3l7','(519) 433-9334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 00:29:45',0,NULL,3,1,2,1,NULL,'2.1X1.6MèƒŒæ™¯å¸ƒ  1 é»‘è‰² '),(4127,615643983001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','jan.juan','jan.juan@yahoo.com','Janette Juan','134 31 Avenue NW','Calgary','AB','CANADA','T2M 2N9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 01:56:56',0,NULL,3,1,2,1,NULL,NULL),(4128,654979992002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','pukko21','sydneythaitown@hotmail.com','peerapong yenchaisit','179/303 castleragh st.','sydney','New South Wales','AUSTRALIA','2000','0413378434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 02:02:15',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(4129,654980992002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','dtadeuribeiro','dtadeu@gmail.com','Daniel Tadeu Ribeiro','Rua Padre Questor, 91<br>Bairro Timirim','TimÃ³teo','Minas Gerais','BRAZIL','35180-304','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 02:06:06',0,NULL,3,1,3,1,NULL,' D8å•è‚©åŒ… ï¼ˆ olympus logo ï¼‰ 2 \r1605\rRR815341365CN'),(4130,615648155001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chadan2009','danny1968@live.fr','Danny Jack','151 McConville','Joliette','QC','CANADA','J6E 4L2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 02:15:31',0,NULL,3,1,2,1,NULL,'58mm æ©¡èƒ¶ç½©   1\r58mm é•œå¤´ç›– canon  1 '),(4131,654988126002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','jbone1101','justinrthom@gmail.com','Justin Thom','414 Cross Hill Rd','Monroe','CT','UNITED STATES','06468-2710','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 02:35:58',0,NULL,3,1,1,1,NULL,NULL),(4132,615653180001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','emul5552','mulleneddie10@gmail.com','Edward Mullen','PO BOX 689','Paddington','New South Wales','AUSTRALIA','2021','0405699325','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-05 02:37:17',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰   1 \rç­‰æ–°åœ°å€\rbackground support $20\rEdward Mullen\r1/212 Oxford St, \rPaddington New South Wales 2021\rAUSTRALIA\r0405699325\rYW864143930CN\r\r'),(4133,655023942002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bruno_monteiro','bruno_mm21@hotmail.com','Bruno Monteiro','Neudelia Monte, 700','Fortaleza','Ceara','BRAZIL','60830-135','558532731633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 05:39:22',0,NULL,3,1,2,1,NULL,NULL),(4134,615687179001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','gailinbc','gailalcock@telus.net','Gail e Alcock','114 Dunant Crs','Penticton,','BC','CANADA','V2A 3E9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 05:53:58',0,NULL,3,1,2,1,NULL,NULL),(4136,655037151002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 07:20:08',0,NULL,8,1,17,0,NULL,''),(4137,655038881002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 07:33:47',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹   1 \ræ–œè‡‚   1 \rRR815341453CN\r'),(4138,615707301001,110529627209,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:30:34',0,NULL,8,1,17,0,NULL,NULL),(4140,655046646002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:36:24',0,NULL,8,1,17,0,NULL,NULL),(4141,655046653002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.99,'hermeshine','equipossoftes','m_escanciano@hotmail.com','Miguel  Martin Escanciano','c/ Monasterio de las Huelgas 25<br>Portal D 3ÂºA','Madrid','Madrid','SPAIN','28049','635548055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 08:36:24',0,NULL,3,1,2,1,NULL,'cpl   1\réº‚çš®   1\rsonyçš„çƒ­é´ç›–   1 '),(4142,615721778001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',2,'AB2214',3,'hermeshine','zvika26','zvyu26@gmail.com','Zvika Mizrahi','Dreyfus st. 25/24','Haifa','','ISRAEL','35434','972523794650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:57:33',0,NULL,3,1,2,1,NULL,'å“èƒœ3.0   2 '),(4143,615721438001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','lalune05','petitbisous@gmail.com','Julia Kristina','Digue des peupliers 86A','Mons','','BELGIUM','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:59:57',0,NULL,8,1,17,0,NULL,NULL),(4144,655057327002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','lalune05','petitbisous@gmail.com','Julia Kristina','Digue des peupliers 86A','Mons','','BELGIUM','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 09:59:58',0,NULL,3,1,3,1,NULL,'1.6mx2.1m= PINK 1.6mx3m= WHITE  \rRR815344097CN\r'),(4145,714152665015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'',4.8,'hutongstore','boyanvaltchev','boyan.valtchev@gmail.com','Boyan Valtchev','WTC Interpred, Block B, Office 604, 36 Dragan Tsankov Blvd','Sofia','Bulgaria','BULGARIA','1040','00359 886 00 93 76','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 10:07:16',0,NULL,3,1,2,1,NULL,'52mm æ¸å˜ç°  1 '),(4146,714168958015,250692240898,'Wireless Remote Shutter Release for Sony A900/A200/â€‹A10',1,'',11.47,'hutongstore','hee_siong01','hee_siong@yahoo.com','YBK ENGINEERING - ONG HEE SIONG','NO.17-1, Jalan 3/93, Taman Miharja, Cheras','Kuala Lumpur','Kuala Lumpur','MALAYSIA','55200','0166106390','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 11:17:49',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ S1   1 '),(4147,615417976001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','amperel2010','service@amperel.co.il','Amperel Danny','Shderot Jerusalem 168 Street<br>P.O. Box 2161','Holon','Israel','ISRAEL','58829','+97235594299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 11:30:06',0,NULL,3,1,3,1,NULL,'ä¸€è½¬å››ç¯å¤´  3\rè¦æŽ§åˆ¶åœ¨2kgä»¥å†…ï¼Œä¸è¡Œçš„è¯å°±å¾—å‘ä¸¤ä¸ªåŒ…äº†RR815341422CN\r'),(4148,655077966002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ronnialbert','ronnymp@yahoo.com','roni albert','silver<br>4 / 4','nahariya','','ISRAEL','22385','+97240779500415','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 11:30:21',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  2\rbåº§  2\ræŸ”å…‰ä¼ž  2\r åˆ†ä¸¤ç¥¨æŒ‚å·å°åŒ…å‘ï¼Œ2kgä»¥å†…ä¸€ä¸ª RR815341475CN\rRR815341440CN\r'),(4149,615745953001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','sreenivasamurthy','rrsreenu@gmail.com','SREENIVASAMAURTHY RAJANAHALLI','HANUMANTHAPPA BUILDING<br>POONA, BANGALORE ROAD','DAVANGERE','KA','INDIA','577002','918192258834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:02:23',0,NULL,3,1,2,1,NULL,'çƒ­é´ç›–  1 '),(4150,615746925001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','l.khabaz','lutfimk@gmail.com','Lutfi M. Al-Khabaz','P.O.Box # 11627<br>Saudi Aramco','Dhahran','Eastern','SAUDI ARABIA','31311','00966504908852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:06:56',0,NULL,3,1,2,1,NULL,' '),(4151,655093315002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dhubhh','dhubhe@vodafone.es','Jose Manuel Beltran Puig','C/ Clapisa nÂº32','BenicarlÃ³','Castellon','SPAIN','12580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 12:39:43',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶ '),(4152,714192327015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','burlaks.q','austris.birkans@gmail.com','Austris Birkans','Ciekurkalns 6sk.l 19','Riga','','LATVIA','LV1026','+37129116007','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 12:43:32',0,NULL,3,1,2,1,NULL,NULL),(4153,700241408016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'',8.99,'hutongstore','hamoniaux123','steve.hamoniaux@hotmail.co.uk','steve hamoniaux','4 windsor ave','corringham','essex','UNITED KINGDOM','ss17 7nu','01375643754','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 12:46:19',0,NULL,3,1,2,1,NULL,'52mm çŽ¯æž¶  1\ræ¸å˜æ©™   1 '),(4154,654811024002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jlojosnegros','jl.ojosnegros.manchon@gmail.com','Jose Luis Ojosnegros Manchon','Avenida de Portugal,49 4ÂºD Esc Izq','Mostoles','Madrid','SPAIN','28931','916175419','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 13:13:33',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864143926CN\r'),(4156,655106527002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mp34life','alex@acpu.se','Alexander Papacosta','Anthimou Panaretou 5<br>Apartment 3','Paphos','Paphos','CYPRUS','8036','00357 99 164158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 13:37:34',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶  1 RR815341691CN\r'),(4157,714212089015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',7.8,'hutongstore','nick7131','nick.oates20@ntlworld.com','Nick Oates','C/O Windsor Partners Ltd 71 Fenchurch Street','London','London','UNITED KINGDOM','EC3M 4BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 13:51:24',0,NULL,3,1,2,1,NULL,NULL),(4158,614724911001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','larsdok7.5','larsdok@hotmail.com','Lars DoksÃ¦ter','Valkendorfsgaten 2c','Bergen','Hordaland','NORWAY','5012','92410814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 14:08:39',0,NULL,3,1,3,1,NULL,'RR815341419CN\r '),(4159,714229264015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','unitedtrev','trevorharrop1@btinternet.com','Trevor Harrop','26 Church Lane Backford','Chester','Cheshire','UNITED KINGDOM','CH2 4BE','01244851877','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 14:46:03',0,NULL,3,1,2,1,NULL,NULL),(4160,615498655001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','garjang13','garjang_13@yahoo.com','Reza Joana Lacsamana','308<br>Rizal Avenue Extension','Batangas','Batangas','PHILIPPINES','4200','9175121322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 15:08:15',0,NULL,3,1,2,1,NULL,NULL),(4161,615805241001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','soldier6685','samuel6685@gmail.com','Samuel Hall','14580 McElroy Rd','Auburn','CA','UNITED STATES','95602-8823','(706) 526-8471','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-05 16:09:14',0,NULL,3,1,3,1,NULL,'Nikon D1 å•è‚©åŒ…  1 RR815341524CN\r'),(4162,615806221001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','macvsog_23','macvsog_23@yahoo.co.uk','Robert Marklew','19 Goslet Road<br>Stockwood','Bristol','Bristol','UNITED KINGDOM','BS14 8SP','01275836164','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 16:42:17',0,NULL,8,1,17,0,NULL,''),(4163,615806865001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','macvsog_23','macvsog_23@yahoo.co.uk','Robert Marklew','19 Goslet Road<br>Stockwood','Bristol','Bristol','UNITED KINGDOM','BS14 8SP','01275836164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 16:42:17',0,NULL,3,1,3,1,NULL,'1 x52mm lens cap for Nikon\r4 x62mm lens cap for Nikon\r1 x67mm lens cap for Nikon\r2 x72mm lens cap for Nikon\r2x77mm lens cap for Nikon \rnikon 90th é•œå¤´ç­’   1 \rRR815341802CN\r\r'),(4164,700318832016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','bartvic','grizzlyr@yandex.com','Victoria Bartunova','Osennyaya, 5','Krasnogorsk','Moscow region','RUSSIAN FEDERATION','143444','(985)973-5957','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 16:46:30',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(4165,655175636002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','jwilliamsdms87','jacob.ryan.w@gmail.com','Jacob Williams','190 Willow Way Rd','Barboursville','VA','UNITED STATES','22923','(434) 760-0672','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 17:30:30',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£å¡‘æ–™  1 RR815341498CN\r'),(4166,700367706016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','garfield-26','nick@nickhall.net','Nick Hall','Connect Internet Cafe, Centra Commercial Calle Aquario, Las Terrazas Miraflores Golf','Riviera del Sol, Mijas Costa','AndalucÃ­a Ceuta y Melilla','SPAIN','29649','951273242','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-05 18:37:17',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶   1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š æ¬§æ ‡   2\r115w 220v   2\r åŒ…   1\rlighting kit  $30 \rYW864143941CN\r\r'),(4167,714323886015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',5,'AA1304',9.4,'hutongstore','jameschetwode','jameschetwoderam@hotmail.com','james ram','number 8 elm court gardens','truro','cornwall','UNITED KINGDOM','tr11ds','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 18:39:40',0,NULL,3,1,3,1,NULL,' RR815341538CN\r'),(4168,655206088002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','mivsr08','smruud@gmail.com','Svein Mikael Ruud','Vestre Furmyrvei 26','Ã…lesund','','NORWAY','6017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 18:49:16',0,NULL,3,1,3,1,NULL,'é˜²å¯’ç½©   1 RR815341507CN\r'),(4169,615864721001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','zahi150','zahi1500@gmail.com','Zahi Zamir','12 Andersn st.<br>apartment 9','Petach-Tikva','','ISRAEL','49203','972523811919','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 18:52:48',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815341847CN'),(4172,700399256016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',3,'AKT056',114,'hutongstore','*banis*','alanbanis@live.com','Alan Banis','Furugatan 8','BorÃ¥s','','SWEDEN','50439','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-05 19:40:14',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  3\råå…‰æ¿æ”¯æž¶   3 \rreflector holder  $30\rYW864143963CN\r'),(4173,700405133016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','gryph0n','rowangee@gmail.com','Rowan Griffin','Flat G, Oakmount Mansions 11a Oakmount Avenue','Southampton','Hampshire','UNITED KINGDOM','SO17 1EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 19:50:39',0,NULL,3,1,2,1,NULL,NULL),(4174,655256316002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',14.6,'hermeshine','oldschool03','atrentacost@aol.com','Anthony N. Trentacost','28243 leticia','mission viejo','CA','UNITED STATES','92692-2329','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 20:49:28',0,NULL,3,1,1,1,NULL,' '),(4175,655265132002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','cards_comics_jax','cardscomicsjax@yahoo.com','T. Martin c/o Martin and Associates','8823 San Jose Blvd<br>Ste 103','Jacksonville','FL','UNITED STATES','32217-4288','(904) 334-1351','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 21:13:27',0,NULL,3,1,1,1,NULL,NULL),(4176,615591982001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','arturbq','arturgmlcosta@gmail.com','Artur Costa','Rua das Marinhas, nÂº 59, M14<br>Gulpilhares','Vila Nova de Gaia','Porto','PORTUGAL','4405-663','351914746250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 21:29:25',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(4177,700455491016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','1nish2rule_them_all','nishmania@yahoo.com','Rajnishpal Udhian','24 Manor Road','West Ealing','London','UNITED KINGDOM','W130JA','07966094942','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-05 21:37:54',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4179,615936038001,110531023243,'JJC Leather Hand Strap Grip for NIKON AH-4 D3x D90 D300',1,'AB1411',17.99,'hermeshine','c130','cc130h@yahoo.com','Marc Favre','R. R. #3<br>(561 Scriver Rd)','Brighton','ON','CANADA','K0K 1H0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 21:56:15',0,NULL,3,1,2,1,NULL,'JJC-4   1 '),(4180,615938636001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',50.99,'hermeshine','santoku87','jruyson@yahoo.com','Rodolfo R Uyson III','314 Scott St S','Shakopee','MN','UNITED STATES','55379-1248','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 22:05:08',0,NULL,3,1,3,1,NULL,'50cm é—ªå…‰ç¯æŸ”å…‰æ£š  1 RR815341541CN\r'),(4181,655285913002,120581555598,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',9.25,'hermeshine','donnat-missy','donnatcd@aol.com','D. Turner','4325 Kendall St','Wheat Ridge','CO','UNITED STATES','80033-5031','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 22:10:01',0,NULL,3,1,1,1,NULL,'å¤§å·å†…èƒ†åŒ… nikon   1 '),(4183,615953843001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','yhoel','yhoel19@gmail.com','Jose Manuel Martinez Cases','Asuncion ParreÃ±o Garcia NÂº 75 - 4Âº Iz','Elche','Comunidad Valenciana','SPAIN','03205','965446980','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 22:54:39',0,NULL,3,1,3,1,NULL,'äº•å­—æ‰³æ‰‹   1 RR815341484CN\r'),(4184,615953359001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','kraedson','ekraemer@pop.com.br','EDSON KRAEMER','Qd 105 Norte, Al. Mangueiras, LT 26<br>QI 02','Palmas','TOCANTINS','BRAZIL','77001-050','(63)8405-7845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 22:55:54',0,NULL,3,1,2,1,NULL,NULL),(4185,615957916001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','victorlizana','victorantoniohp@hotmail.com','Victor Lizana','Vichuquen 1498<br>Conchali','Santiago','Region Metropolitana','CHILE','8560313','56987072497','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-05 23:10:07',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚   1 RR815341467CN\r'),(4186,615960011001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','evie1964','madcrazyartist@yahoo.com.au','Yvonne Warren','191 Gleniffer Rd','Bonville','New South Wales','AUSTRALIA','2441','0266535638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-05 23:18:31',0,NULL,3,1,2,1,NULL,NULL),(4187,655313351002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','melissacopebeaty','melissacancope@yahoo.com','Melissa Beaty','226 Freeman Dr','Biloxi','MS','UNITED STATES','39531-3244','(478) 213-0103','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 23:37:32',0,NULL,3,1,1,1,NULL,NULL),(4188,615967528001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','renoboydz','renoboyd@charter.net','Boyd Zegers','1285 Baring Blvd<br># 240','Sparks','NV','UNITED STATES','89434','(775) 842-4160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-05 23:47:21',0,NULL,3,1,1,1,NULL,NULL),(4189,615966777001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','stephan.dcosta','dcosta.stephan@gmail.com','Stephan DCosta','233 Sun Arbor Ter<br>Apt 1188','Salt Lake City','UT','UNITED STATES','84116-4558','(801) 683-7004','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-05 23:51:14',0,NULL,3,1,1,1,NULL,NULL),(4190,714471185015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',4,'AA1301',7.52,'hutongstore','lobopl','camelgd@gmail.com','Kamil Nasuta','136 Wigan lane','WIGAN','Lancashire','UNITED KINGDOM','WN1 2LA',' 07732798335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 00:14:17',0,NULL,3,1,2,1,NULL,NULL),(4191,714472679015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pajka2007','pajka@inbox.ru','Pavel Alekno','16 Sebert road','London','London','UNITED KINGDOM','e7 0nq','07708619085','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 00:20:02',0,NULL,3,1,2,1,NULL,NULL),(4192,655325562002,120581555818,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','gclaudiu','gclaudiu2007@gmail.com','Claudiu Georgescu','358B East Coast Road','default','','SINGAPORE','428975','93865433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 00:26:56',0,NULL,8,1,17,0,NULL,NULL),(4193,615976591001,110502916198,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.55,'hermeshine','gclaudiu','gclaudiu2007@gmail.com','Claudiu Georgescu','358B East Coast Road','default','','SINGAPORE','428975','93865433','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 00:26:57',0,NULL,3,1,11,1,NULL,'58mm æŽ¥å£çŽ¯  1\r67mm æŽ¥å£çŽ¯  1 '),(4194,655333405002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','sherman026','selina_y7@hotmail.com','yin tang','139 Midway Dr','Negaunee','MI','UNITED STATES','49866','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 01:00:16',0,NULL,3,1,1,1,NULL,'åŒç¯å¤´  1 '),(4195,655340274002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','electronicnecessities','electronic_necessities@hotmail.com','Eamonn Wall','58 Tinigira Cres','Kiama','New South Wales','AUSTRALIA','2533','6142331901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 01:28:20',0,NULL,3,1,2,1,NULL,NULL),(4196,616009936001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','novikov1729','alex.746@gmail.com','Alexander Novikov','2817 Rue Des Perce-Neige','Vaudreuil-Dorion','QC','CANADA','J7V 0C4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 02:56:49',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´   2 '),(4197,714523332015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','grifter06','gergriffin05@yahoo.co.uk','Gerard Griffin','48 Dun Na Manach Quin','Ennis','Clare','IRELAND','default','0863675005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 03:23:30',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1 RR815341555CN\r'),(4198,714542689015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','superpig106','jack_sky@yahoo.com','Jacky Shum','EO(CSD)1, Room 1346, 13/F, West Wing, Central Government Offices, Lower Albert Rd, Central, Hong Kong','default','','HONG KONG','default','(852)91065135','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 04:49:30',0,NULL,3,1,2,1,NULL,'72mm cpl   1 '),(4200,616043792001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','googieburra','leishy22@hotmail.com','Aleisha Goiran','Level 11<br>172 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-06 06:27:34',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰1 \rbackground support  $20\rYW864143915CN\r'),(4201,616044527001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','bigboatdaddy','adrian_rumney@yahoo.com','Adrian Rumney','c/- Medical Assurance Society<br>19-21 Broderick Road, Johnsonville','Wellington','.','NEW ZEALAND','6037','+64 4 4941372','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 06:33:05',0,NULL,3,1,3,1,NULL,'æ‘„å½±èƒŒå¿ƒ ç»¿è‰² canon  xxl   1 \rRR815341731CN\r'),(4202,615935901001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',133.92,'hermeshine','wontfix123','omeryairmail@gmail.com','Omer Yair','20 Havradim Street','Yehud','Gush Dan','ISRAEL','56275','97235362750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 06:37:00',0,NULL,3,1,3,1,' ','110cm 5in1  2\r80cm 5in1   3\r60cm æ£š  1\r2kgä»¥å†…ï¼Œçœ‹åŒ…å‡ ä¸ªåŒ…\rRR815341714CN\rRR815341728CN\r'),(4204,655406718002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','helperi','seppo.helpio@iki.fi','Seppo HelpiÃ¶','Salomaantie 5 H 57','Valkeakoski','Pirkanmaa','FINLAND','37630','0400632565','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 07:43:59',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815341776CN'),(4206,616064880001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','iwangun','ione_6@hotmail.com','Iwan Gunardi','Jl. Rawa Sumur II Kavling BB3<br>Kawasan Industri Pulo Gadung','Jakarta','DKI - Jakarta','INDONESIA','13930','+6281513603656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 09:29:52',0,NULL,3,1,2,1,NULL,' '),(4207,616081899001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','ostad07','ohusta@hotmail.com','Ã˜yvind Hustad','Skrenten<br>5 F','Molde','','NORWAY','6411','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 10:38:23',0,NULL,3,1,3,1,NULL,'52mm~77mm æŽ¥å£çŽ¯  1\ræ‰˜æž¶   1 \r\rRR815341864CN'),(4208,700655374016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jacek1702','fotojacek@diginet.ie','Marian Pieciak','11 Laurelmount Avenue Rock Road','Carrigaline','Cork','IRELAND','000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 11:27:33',0,NULL,3,1,3,1,NULL,'1.6x3m çº¢è‰²èƒŒæ™¯å¸ƒ  1 \rRR815341952CN'),(4209,652865657002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','geiolima','geiolima@hotmail.com','Rogerio Silva','Estrada do Capuava, 2530 - casa 205','COTIA','SP','BRAZIL','06715-685','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 11:42:23',0,NULL,3,1,2,1,NULL,NULL),(4210,616105903001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','lestournelles682','diolots@free.fr','jeanclaude BOUCHEZ','8,rue du poirier de sauge','MONTIGNY SUR LOING','Ile-de-France','FRANCE','77690','0687200936','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 12:28:13',0,NULL,3,1,4,1,NULL,'6663a   1 \rtripod  $22\rYW864143904CN\r'),(4211,714650469015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','zephyr0161','lukedevereux@btinternet.com','paul devereux','4 griffiths close salford','manchester','Lancashire','UNITED KINGDOM','m7 1td','01618396846','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 13:08:34',0,NULL,3,1,2,1,NULL,NULL),(4212,714654654015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','tatitt','tania_dim@abv.bg','Tsvetan Todorov','Hadzi Dimitar bl. 130, entr. 3, fl. 4, ap. 69','Sofia','Bulgaria','BULGARIA','1510','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 13:22:00',0,NULL,3,1,2,1,NULL,NULL),(4213,700693182016,260675927807,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',21,'hutongstore','martyn190189','mart_morris4321@hotmail.co.uk','martyn morris','47 cradley park road','dudley','West Midlands','UNITED KINGDOM','dy2 9sp','075055825838','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 13:39:37',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  A1   1 \rRR815341904CN'),(4214,655489895002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','tolga5484','tolga00@gmail.com','Tolga Tosun','Fethiye Mahellesi FSM BulvarÄ±<br>EryÄ±l Ap. kat:2 no:141-3','Bursa','NilÃ¼fer','TURKEY','16140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 14:25:03',0,NULL,3,1,3,1,NULL,'60cm é—ªå…‰ç¯æŸ”å…‰æ£š  1 \rRR815341895CN'),(4215,714698523015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','tony1409','tonyuttley@tiscali.co.uk','Tony Uttley','1 Palmer Crescent','Dronfield','Derbyshire','UNITED KINGDOM','S181XW','01246415688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 15:34:13',0,NULL,3,1,2,1,NULL,NULL),(4216,655498440002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','sdora2010','stalter_harrison@yahoo.co.uk','Sylvia Banszki','72 B Ranelagh Road','London','London','UNITED KINGDOM','W5 5RP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 15:50:55',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   1 '),(4217,655517400002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','xbusterx82','xbusterx@gmail.com','Olga Dolgopolova','Respublika Avenue<br>30 , 22','Shymkent','South Kazakhstan , KAZ','KAZAKHSTAN','160005','+77017892862','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 15:59:51',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  A1    1\rRR815341780CN '),(4218,616162937001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sinjon01','simon.jonssons@gmail.com','simon jÃ¶nsson','vittervÃ¤gen 175','UMEÃ…','none','SWEDEN','90751','070-299 78 34','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 16:03:39',0,NULL,8,1,17,0,NULL,NULL),(4219,616163687001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',1,'AA3222',45.9,'hermeshine','sinjon01','simon.jonssons@gmail.com','simon jÃ¶nsson','vittervÃ¤gen 175','UMEÃ…','none','SWEDEN','90751','070-299 78 34','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 16:06:42',0,NULL,3,1,3,1,NULL,'è‚©æž¶   1\rMC-C3    1 \r\rRR815341833CN'),(4220,616165420001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','tmldesignstyle','twenzel@redeye-inc.com','Tara Wenzel','5835 S Broad St','Yardville','NJ','UNITED STATES','08620-9508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 16:10:26',0,NULL,3,1,1,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4221,655282619002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','olinko5','bergl@zoznam.sk','Oliver Bergl','Mandlova 70','Bratislava','','SLOVAK REPUBLIC','85110','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 16:35:05',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶( ç™½)   1 \rCP219486752CN\r'),(4222,616169995001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','toni2929-2007','modi_29@hotmail.com','Antonio Salaverri Leiras','Carrascal 6','MondoÃ±edo','Galicia','SPAIN','27740','651958916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 16:29:59',0,NULL,3,1,3,1,NULL,'60cm æ£š   1 \rRR815341878CN'),(4223,700789349016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','nchris198705','nchris1987@gmail.com','Krisztian Nyvelt','Radnoti ltp. 10/2','Abda','GY-M-S','HUNGARY','9151','0036204329390','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-06 17:52:58',0,NULL,3,1,5,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m èƒŒæ™¯å¸ƒç»¿è‰²   1\r2m ç¯æž¶  2\r50-70 æ£š  2  æ¬§æ ‡  \r115w 220v   2\råŒ…    1\rCP219486766CN\r\r'),(4224,655578126002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','miga_29','miguelasselin@hotmail.com','Miguel Asselin','2630 bellerose apt. 1','Longueuil','QC','CANADA','j4l4h9','(514) 208-6458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 18:42:54',0,NULL,8,1,17,0,NULL,NULL),(4225,616222617001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','miga_29','miguelasselin@hotmail.com','Miguel Asselin','2630 bellerose apt. 1','Longueuil','QC','CANADA','j4l4h9','(514) 208-6458','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 18:42:53',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  1\rè‚©æž¶    1 \rRR815341762CN'),(4226,616234254001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','firecrowlives','firecrowlives@yahoo.com','nick perez','1211 S 1st Ave','arcadia','CA','UNITED STATES','91006-4130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 19:08:48',0,NULL,3,1,3,1,NULL,'åŒç¯å¤´  2 \rRR815341816CN'),(4227,616235346001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','evabluecanada','eva@evablue.com','eva blue','2025 Parthenais Suite 259','Montreal','QC','CANADA','h2k 3t2','(514) 808-2583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 19:12:17',0,NULL,3,1,2,1,NULL,NULL),(4228,714798863015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','rado8307','rado126@gmail.com','Radovan Holly','L. Novomeskeho 2671/3','Trencin','','SLOVAK REPUBLIC','91108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 19:13:53',0,NULL,3,1,2,1,NULL,NULL),(4229,655609887002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','popocarrocao','popo@carrocao.com.br','Manoel Leite','PraÃ§a da Bandeira, 32','Tatui','SP','BRAZIL','18270390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 19:54:49',0,NULL,3,1,2,1,NULL,NULL),(4230,616255657001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','Other','2011-01-06 20:00:47',0,NULL,3,1,1,1,NULL,'æ‘„å½±èƒŒå¿ƒ è–„ é»‘è‰² canon  xxl  1 '),(4231,655618421002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elenapavlova','elenkapavlova@gmail.com','Elena Pavlova','ul. Shotmana 60-46','Petrozavodsk','Respublika Karelia','RUSSIAN FEDERATION','185001','+7 9114021469','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-06 20:15:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°   1\ræŸ”å…‰ä¼ž  1 \rRR815341855CN'),(4232,714636089015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','kennyipcu','kmclellon@aol.com','Kenneth   McLennan','58 Ness Circle','Ellon','Aberdeenshire','UNITED KINGDOM','AB419BR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 20:27:29',0,NULL,3,1,2,1,NULL,'72mm çŽ¯æž¶  1 '),(4233,655627160002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','joshk51','joshk@brooklynunderground.org','Josh  Koury','75 Monitor St<br>Apt 3R','Brooklyn','NY','UNITED STATES','11222-5125','(646) 541-6916','NoPaymentFailure','CheckoutComplete','Other','2011-01-06 20:33:38',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815341881CN'),(4234,655635107002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','swim311977','fionapyke2@bigpond.com','Fiona Pyke','216 cane street<br>Redland Bay','Brisbane','Queensland','AUSTRALIA','4165','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°  1 '),(4235,616282528001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','gasdocmusic','rgmatalon@gmail.com','Ralph Matalon','105 Rock Squirrel','Shavano Park','TX','UNITED STATES','78231-1426','(210) 602-5558','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:06:45',0,NULL,3,1,1,1,NULL,NULL),(4236,655641432002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','jazzinid','jazzinid@yahoo.com','Trevor Little','1923 Autumn Sage Ave','North Las Vegas','NV','UNITED STATES','89031-1699','(702) 334-3700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:09:07',0,NULL,3,1,1,1,NULL,'MC-C1  1 '),(4237,655647404002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',8.69,'hermeshine','prepaee','kayjet64@gmail.com','Mitchell Wolfrom','PO BOX 1362','Vieques','PR','UNITED STATES','00765-1362','(787) 435-9252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 21:24:39',0,NULL,3,1,1,1,NULL,'ä¸­å·å†…èƒ†åŒ… nikon   1 '),(4238,714872260015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','hannahlewis2010','hvl@hotmail.co.uk','Hannah Lewis','11 Union Street','Glossop','Derbyshire','UNITED KINGDOM','SK13 8LT','01457899430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 21:38:02',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4239,616309957001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','manur2009','manuel_rivas@vodafone.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 22:23:03',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 '),(4240,700927761016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.28,'hutongstore','sterrydent308','nessrob1@aol.com','ROB CURTIS','10 BROOMHOUSE PARK, WITHERIDGE','TIVERTON','Devon','UNITED KINGDOM','EX16 8HB','01884860185','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-06 22:35:44',0,NULL,3,1,2,1,NULL,' '),(4241,616297651001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ecurb13z','bchapin1@cox.net','Bruce Chapin','207 S Bonnie Brae St','Wichita','KS','UNITED STATES','67207-1103','(316) 634-1665','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-06 22:41:31',0,NULL,3,1,1,1,NULL,NULL),(4242,616323477001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','steelie13steelie','steelie14@hotmail.com','John L Durfee','401 Chestnut Ave','Red Bluff','CA','UNITED STATES','96080','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-06 23:08:46',0,NULL,3,1,1,1,NULL,'52mm æ¸å˜ç°   1 '),(4243,616323692001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','leondcx','allan_hudson@hotmail.com','Allan Hudson','Av. General Rondon, 3542<br>Vila Leopodina','Duque de Caxias','Rio de Janeiro','BRAZIL','25050-230','552126528640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-06 23:09:28',0,NULL,3,1,3,1,NULL,'RR815341820CN '),(4244,700946634016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','wilsonpazos','wilsonpazos@hotmail.com','Wilson Pazos','Ekkodalen 16 2.tv','Aarhus','Danmark','DENMARK','8210','004528814877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-06 23:31:49',0,NULL,3,1,2,1,NULL,NULL),(4245,655702575002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','mickkennally','mkennally@hotmail.com','Michael Kennally','28 Quasons Path','Brewster','ma','UNITED STATES','02631','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 00:18:48',0,NULL,3,1,1,1,NULL,NULL),(4247,655478876002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','perthsimon','simon.may8@gmail.com','Simon May','19 Mayfair Mews','Meadow Springs','Western Australia','AUSTRALIA','6210','610417703000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 01:05:41',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  1 '),(4248,616371788001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','mdspace76','mdspace@yahoo.com','David Masuoka','Prol. Zaragoza 206 Privilege C21<br>Fracc. Fatima','Aguascalientes','Aguascalientes','MEXICO','20130','(449) 996-6797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 02:34:22',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4249,655737776002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','tiggergr81','tiggergr81@sbcglobal.net','Lora J Russell','770 Glen Vista Dr','Sparks','NV','UNITED STATES','89434-1545','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 02:45:12',0,NULL,3,1,1,1,NULL,'rs-c3   1 '),(4250,655759329002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hailstone421','rickdicks@rickdicks.com','Rick J Dicks','939 Southfork Dr','Allen','TX','UNITED STATES','75013','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 04:24:41',0,NULL,3,1,1,1,NULL,NULL),(4252,616404212001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','airmac3131','shapka@hotmail.com','Igor Synayuk','1928 Main St W Apt # 615','Hamilton','ON','CANADA','L8S 1J4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 05:38:20',0,NULL,3,1,2,1,NULL,NULL),(4253,654738316002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','ronnialbert','ronnymp@yahoo.com','roni albert','silver<br>4 / 4','nahariya','','ISRAEL','22385','+97240779500415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 05:28:30',0,NULL,3,1,3,1,NULL,'æ¡Œé¢ç¯   2 \rRR815343689CN\r'),(4254,655776122002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','lpnan','obk6260@gmail.com','ooi bkai','7, Cangkat Minden Lorong 6,<br>11700 Gelugor, Penang.','Gelugor','Penang','MALAYSIA','11700','012-5856674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 06:14:57',0,NULL,3,1,3,1,NULL,'50-70 å¡‘æ–™å¡å£  æ£š  2 \rRR815343882CN\r'),(4255,715019351015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','lacza66','vancsol@freemail.hu','Volvo Auto Hungary, Laszlo Vancso','Kulso Vaci ut 50-58.','Budapest','','HUNGARY','H-1044','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 06:16:19',0,NULL,3,1,2,1,NULL,NULL),(4256,701055961016,260660055110,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',15.5,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:58',0,NULL,8,1,17,0,NULL,NULL),(4257,715029059015,250692237499,'Large size Neoprene Lens Pouch Case 90mm x 220mm L',1,'AC1203',4.18,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:59',0,NULL,8,1,17,0,NULL,NULL),(4258,715028414015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.16,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:26:59',0,NULL,8,1,17,0,NULL,' '),(4259,715028188015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:27:00',0,NULL,8,1,17,0,NULL,' '),(4260,701054344016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','spiderlakesprings','wcheng55@netscape.net','willie cheng','4240 kincaid street','victoria','BC','CANADA','V8X4R3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 07:27:00',0,NULL,3,1,3,1,NULL,'52-52mm åŒé˜³çŽ¯   1\rcanon-58mm åæŽ¥çŽ¯   1\rcanon-52mm åæŽ¥çŽ¯   1\rå¤§å·é•œå¤´ç­’   1\r40cm  æ£š   1 \rRR815344021CN\r'),(4261,616425247001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','duaneorriss8','duaneorriss@gmail.com','Duane Orriss','14 Delafield Way','Balcatta','Western Australia','AUSTRALIA','6021','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 08:15:35',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\råŒç¯å¤´   æ¾³æ ‡  2\råå…‰ä¼ž  2\r45w   4\råŒ…   1\rlighting kit   $30\rYW864614830CN\r\r '),(4262,655795208002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','johnny_bjorling','johnny.bjorling@gmail.com','Johnny Bjorling','Bergdalsvagen 5','Aby','','SWEDEN','61633','+461160535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 08:34:26',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815343825CN'),(4263,655795392002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','ozkingdom','13week@gmail.com','Nitzan Oz','27481 Grassland Dr','Laguna Niguel','CA','UNITED STATES','92677-6032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-07 08:35:52',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹   2 '),(4264,715044621015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','nikonistad80','nikon1971@hotmail.es','MIGUEL ANGEL PELAEZ GONZALEZ','UNIVERSIDAD DE CANTABRIA (PabellÃ³n de Gobierno) Avda Los Castros s/n','Santander','Cantabria','SPAIN','39005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 08:50:17',0,NULL,3,1,2,1,NULL,'50cm æ£š   1 '),(4266,714916110015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',16.97,'hutongstore','kurtl42','kurt@hanauer-automaten.de','Kurt Hanauer','Marktplatz 30','Pfreimd','','GERMANY','92536','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 09:10:35',0,NULL,3,1,3,1,NULL,'canon æœºèº«ç›–/é•œå¤´åŽç›–  1 \rå¤§å·ç°å¡   1\rçƒ­é´ç›–   1\rRE-A   1\rRR815344035CN\r\r'),(4267,616436310001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','lagunshop','lagun_shop@hotmail.com','Ozkan Gozu','Rasim pasa Mah. Uzunhafiz Sk.<br>no:25 kat:3 No:9','istanbul','Kadikoy','TURKEY','34716','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 09:27:46',0,NULL,3,1,5,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ   1\r2m ç¯æž¶  2\råŒç¯å¤´   æ¬§æ ‡ 2\ræŸ”å…‰ä¼ž  2\r45w   4\råŒ…   1\rç”³æŠ¥$50\rCP219486868CN'),(4268,655813406002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pincianito','briskdal@hotmail.com','JOSE ALBERTO DUQUE VICENTE','BERNESGA, 9 6Âº D','LEÃ“N','Castilla y LeÃ³n','SPAIN','24010','654051136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 10:23:10',0,NULL,8,1,17,0,NULL,NULL),(4269,655813277002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','pincianito','briskdal@hotmail.com','JOSE ALBERTO DUQUE VICENTE','BERNESGA, 9 6Âº D','LEÃ“N','Castilla y LeÃ³n','SPAIN','24010','654051136','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 10:23:11',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ 2m ( ç™½ï¼‰   1\r2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rYW864614841CN\r'),(4270,655839729002,120568891616,'Male-Male 52mm-52mm Reverse Macro 40D 450D 550D D90',1,'AA1211',3.8,'hermeshine','nikon2704','raven645@iol.cz','rene novak','zborovska 6','prague 5','CZ','CZECH REPUBLIC','150 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 12:22:05',0,NULL,8,1,17,0,NULL,NULL),(4271,616474180001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','nikon2704','raven645@iol.cz','rene novak','zborovska 6','prague 5','CZ','CZECH REPUBLIC','150 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 12:23:54',0,NULL,3,1,3,1,NULL,'52-52mm åŒé˜³  1\r52mm-nikon åæŽ¥çŽ¯  1\rRR815343967CN\r '),(4272,616485585001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','banhtruong','vanmien@gmail.com','van nguyen','10 conley st<br>noble park','Mel','Victoria','AUSTRALIA','3174','0397983751','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 13:13:05',0,NULL,3,1,3,1,NULL,'717å¿«è£…æ¿  2 \rRR815343851CN\r'),(4273,715116299015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','innerarmour','innerarmoursales@gmail.com','Adrian O Donnell','6 River Road Rhebouge','Limerick','Limerick','IRELAND','default','0872727624','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 13:23:42',0,NULL,3,1,3,1,NULL,'45w   4 \rRR815344004CN\r'),(4274,616489539001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','yekovekim','mike.vokey@gmail.com','Michael Vokey','13 Cahill Dr.','St. John\'s','Newfoundland','CANADA','A1A5H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 13:28:48',0,NULL,3,1,3,1,NULL,'\r60cm æ£š   1 \rRR815343848CN\r\r'),(4275,715124720015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','nickreuland','nickreuland@eircom.net','Nicolas Reuland','4 Grange Park Close','Raheny','Dublin','IRELAND','D5','0876685013','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 13:49:17',0,NULL,3,1,2,1,NULL,NULL),(4276,616017175001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','rockforli','rockforli@libero.it','Luca Castellani','via Giuseppe Orceoli nÂ° 3 -  47122 FC','Forli - FC','FO','ITALY','47100','0543-796534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 14:07:44',0,NULL,3,1,2,1,NULL,NULL),(4277,655869490002,120439964418,'MACRO CLOSE UP Filter Lens kit +2 +3 +4 +8 40d d80 d90',1,'AKT012',23.6,'hermeshine','evolpexx','evolpe@smith.edu','elena volpe','221 Park Hill Rd','florence','MA','UNITED STATES','01062-9723','(413) 695-9799','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 14:21:25',0,NULL,3,1,1,1,NULL,'67mm   +2 +3 +4 +8 1 '),(4278,655879088002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rogiwi','rogiwi@bluewin.ch','Roger Giger','Talmattring 4','Muhen','','SWITZERLAND','5037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 14:48:05',0,NULL,3,1,3,1,NULL,'Canon èƒŒå¿ƒ  M  1\rè€ç‰ˆ \rRR815343777CN\r'),(4279,654418770002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','gasfire58','claudio.piovesana@fastwebnet.it','Claudio Piovesana','Via Ferrante Aporti, 32','Milano','MI','ITALY','20125','0039022822300','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 14:52:46',0,NULL,3,1,4,1,NULL,'717AH   1 \rhead ball  $20\rYW864614804CN'),(4280,715152005015,250692241952,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',2.4,'hutongstore','gianluca3735','gianluca.marinelli@tin.it','Gianluca Marinelli','Via dell\'annunziatella 129','ROMA','Roma','ITALY','00147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 15:06:20',0,NULL,8,1,17,0,NULL,NULL),(4281,715151808015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','gianluca3735','gianluca.marinelli@tin.it','Gianluca Marinelli','Via dell\'annunziatella 129','ROMA','Roma','ITALY','00147','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 15:06:20',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ C3   1\r58mmé•œå¤´ç›– canon  1 '),(4282,715160493015,250692242733,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',2.4,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 15:29:21',0,NULL,8,1,17,0,NULL,NULL),(4283,655872909002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',24.3,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 15:29:21',0,NULL,3,1,3,1,NULL,'ND4 + ND8+ æ¸å˜ç°  1\r52mm çŽ¯æž¶  1\réº‚çš®  1\rRR815344049CN\r'),(4284,701185890016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',2,'hutongstore','klausnjules','kanj@blueyonder.co.uk','David Harrison','43 Runshaw Avenue Appley Bridge','Wigan','Lancashire','UNITED KINGDOM','WN6 9JP','01257253157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 15:32:21',0,NULL,3,1,2,1,NULL,'77mm é•œå¤´ç›–  nikon  1\r52mm é•œå¤´ç›–  nikon  1 '),(4285,700832949016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','jromey19','jromey@hotmail.co.uk','Jeremiah Williams','12 The Grove','Luton','Bedfordshire','UNITED KINGDOM','LU1 5PE','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-07 16:08:18',0,NULL,3,1,4,1,NULL,'2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 è‹±æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rYW864614815CN\r\r '),(4286,715181072015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','markusandre1992','markus_andre1992@hotmail.com','Markus MollandsÃ¸y','Heiane 101','Bergen','Bergen','NORWAY','5131','+4794164348','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-07 16:21:34',0,NULL,3,1,4,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ é»‘ï¼‰   1\r2må®½çš„ \rbackground support  $25\rYW864614771CN'),(4287,715182955015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','diarek73','jar3@o2.pl','Jaroslaw Krausewicz','Ty\'n Rhos Country House','Seion, Caernarfon','Gwynedd','UNITED KINGDOM','ll55 3ae','01248670489','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 16:26:28',0,NULL,3,1,2,1,NULL,NULL),(4288,655918231002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','sadolkz','dolzhenko.sergei@gmail.com','Sergey Dolzhenko','Ch.Valihanova st., h-19/1, r-24','Temirtau','KZ','KAZAKHSTAN','101400','77015301392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 16:50:45',0,NULL,3,1,2,1,NULL,NULL),(4289,655926443002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cdn_smiles','krae89@gmail.com','Kaitlynne-Rae Landry','301 Carlisle Road','Carlisle','ON','CANADA','L0R 1H2','(905) 689-5268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:16:20',0,NULL,3,1,2,1,NULL,' '),(4290,655928084002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','lucysdua','kiev.ua@gmail.com','Kateryna Cherepanova','PO Box 6143<br>a/c 6143','Lviv','UKRAINE','UKRAINE','79000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:16:33',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£æ£š å¡‘æ–™  1 \rRR815343817CN'),(4292,616517390001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','golfinkar','peterrichnak@zoznam.sk','Peter Richnak','Nedarska 43','Surovce','','SLOVAK REPUBLIC','91925','421949455988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:17:19',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ æ¬§æ ‡  1 '),(4293,616569674001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:34',0,NULL,8,1,17,0,NULL,NULL),(4294,616569108001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:34',0,NULL,8,1,17,0,NULL,NULL),(4295,616568748001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 17:40:35',0,NULL,3,1,3,1,NULL,'45w 2\rå¤§å·ç°å¡  1\r80cm 5in1 åå…‰æ¿  1 \rRR815344083CN\r'),(4296,655947255002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','2400flying','kk@kkwil.com','Karl K. Wilson','505 S State','La Verkin','UT','UNITED STATES','84745','(435) 635-2400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 18:07:14',0,NULL,3,1,1,1,NULL,NULL),(4297,655952096002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5,'hermeshine','lukek145','jessekeady@hotmail.com','luke keady','P.O. Box 985, Cowes','phillip island','Victoria','AUSTRALIA','3922','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:20:03',0,NULL,3,1,2,1,NULL,NULL),(4298,616592125001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:44',0,NULL,8,1,17,0,NULL,NULL),(4299,655947088002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:45',0,NULL,8,1,17,0,NULL,NULL),(4300,655959898002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 18:40:44',0,NULL,8,1,17,0,NULL,NULL),(4301,616579831001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:45',0,NULL,8,1,17,0,NULL,NULL),(4302,616579575001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:46',0,NULL,8,1,17,0,NULL,NULL),(4303,616587493001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jiristojdl','jiri.stojdl@gmail.com','Jiri Stojdl','Prazska 97','Teplice','Ustecky kraj','CZECH REPUBLIC','41501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 18:40:46',0,NULL,3,1,5,1,NULL,'æŸ”å…‰ä¼ž  1\råå…‰ä¼ž  1\rå•ç¯å¤´ æ¬§æ ‡  2\r45w   2\r50cm æ£š   1\rå¤§åŠ›å¤¹   1 \r2m ç¯æž¶  1\rCP219487320CN\r'),(4304,616602632001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','djuxa_pk','djuxapk@inbox.lv','Andrejs Turanovs','A.Saharova 19-42','Riga','Latvia','LATVIA','LV-1082','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 19:06:51',0,NULL,3,1,3,1,NULL,'肩架 1RR815344874CN'),(4305,655973190002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','ahcm','andre.mehta@gmail.com','Andre Mehta','2 Brookside Rd','Southborough','MA','UNITED STATES','01772-2046','(508) 229-2456','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 19:10:21',0,NULL,3,1,1,1,NULL,NULL),(4306,616332466001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1303',6.68,'hermeshine','foreverphotonashville1','foreverphotonashville@yahoo.com','rachel walker','320 W Maple St','morrison','TN','UNITED STATES','37357-7717','(615) 586-0743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 19:20:49',0,NULL,3,1,1,1,NULL,NULL),(4307,655979533002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','joaobatista55','joao-fotografo@bol.com.br','JOÃƒO BATISTA MACÃŠDO DE ARAÃšJO','RUA ODILON SATOS ,19 ,RIO VERMELHO','SALVADOR','BAHIA','BRAZIL','41940-350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 19:26:37',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£å¡‘æ–™  2 \rRR815343905CN\r'),(4308,715273575015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','micky-cantona','info@creanfoto.com','Michael J Crean','48 Monastery Drive','clondalkin','Dublin','IRELAND','D22','0035314573166','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 19:38:14',0,NULL,3,1,2,1,NULL,NULL),(4309,715288932015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','pmaccounts','pmservices1@hotmail.co.uk','scott Jefferies','141 Henley Avenue','North Cheam','Surrey','UNITED KINGDOM','SM3 9SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-07 20:10:47',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡  1 '),(4310,715299079015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','changkailung','kailung.chang@gmail.com','Kai Lung CHANG','17, rue des Pastoureaux','OrlÃ©ans','Centre','FRANCE','45000','0238543340','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-07 20:29:57',0,NULL,3,1,2,1,NULL,'45w    2 '),(4311,656008546002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','stafordyull','sk9875@gmail.com','Sergejs Kisils','6.Berwick Place, Swords Manor,<br>Swords','Dublin','Dublin','IRELAND','IRL','0876713245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 20:39:42',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\råå…‰æ¿æ”¯æž¶   1 \rreflector holder   $25\rYW864614793CN'),(4312,656011372002,120550514695,'Remote Control Wireless Shutter Release NIKON D90 D5000',1,'AA3226',35.5,'hermeshine','r.norvaisas22','r.norvaisas@yahoo.com','Ramunas  Norvaisas','574a rainham road<br>Dagenham','london','London','UNITED KINGDOM','rm10 7xd','447576865825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 20:47:16',0,NULL,5,1,18,0,NULL,'YN126-N3   1 '),(4314,616665234001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','sunnhippie','sunnhippie@hawaii.rr.com','Kimberly Kessler','PO Box 8197','Honolulu','HI','UNITED STATES','96830-0197','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 21:55:20',0,NULL,3,1,1,1,NULL,NULL),(4315,656050529002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kaksl','kasias1@yahoo.com','Elisabeth Siwanowicz','5901 Spaatz Pl','Rockville','MD','UNITED STATES','20851','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-07 22:38:38',0,NULL,3,1,1,1,NULL,NULL),(4316,656060677002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','sladboy','sladkovic@gmail.com','Lubomir Sladkovic','Spartakovska 11','Trnava','','SLOVAK REPUBLIC','91701','+421944094249','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 23:12:09',0,NULL,3,1,3,1,NULL,'肩架 1RR815344931CN'),(4317,656063921002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexbelik','alex@alexbelik.com','Aleksander Belik','Naberegnaja 26-176','Energodar','Zaporizka','UKRAINE','71500','380502189039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-07 23:24:22',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4318,701391033016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','raijakee','raimond@harta.ee','RAIMOND JAKOBS','VARSAALLIKA 36','TALLINN','','ESTONIA','12013','(372) 600-6508','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-07 23:33:44',0,NULL,3,1,5,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m é»‘è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¬§æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rCP219486854CN\r\r '),(4319,616692019001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',6,'AA3315',35.7,'hermeshine','blue_bomber_gt-s','christian.fiore@gmail.com','Christian Fiore','15877 SW 11th Terrace Road','Ocala','FL','UNITED STATES','34473','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-07 23:41:52',0,NULL,3,1,1,1,NULL,'绿叶52mm 渐变灰 6片 '),(4320,616697925001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jonm19670824','jonmalagon67@gmail.com','JON MALAGON ZALDUA','ARROBITXULO BIDEA, 13 1A ','ASTIGARRAGA','PaÃ­s Vasco','SPAIN','20115','658739287','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-07 23:52:30',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864614782CN'),(4321,656062683002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',14.6,'hermeshine','vicki6347','vmayhew@comcast.net','Vicki Mayhew','4503 Menaul Blvd NE','Albuquerque','NM','UNITED STATES','87110-2953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 00:13:30',0,NULL,3,1,1,1,NULL,NULL),(4322,616704205001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','dave_075','davidpascolo@gmail.com','David Pascolo','Via Principe di Piemonte, 24','Campoformido','UD','ITALY','33030','3396563614','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 00:19:02',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ… æ— å­—  1 '),(4323,616712467001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','anderskristoffer','anderss@stokkes.net','Anders Stokke','Prost Castbergs veg 11','Trondheim','SÃ¸r TrÃ¸ndelag','NORWAY','7051','(+47) 97197901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 00:56:07',0,NULL,3,1,2,1,NULL,NULL),(4324,656091185002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',28.99,'hermeshine','and-the-greatest-of-these-is-love','lifetastic@gmail.com','Justin Morgan','1376 Miners Dr<br>STE 106','Lafayette','CO','UNITED STATES','80026-2988','(303) 219-0020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-08 01:16:20',0,NULL,3,1,1,1,NULL,'nikon ttl çº¿  3m   1 '),(4325,656091506002,120439974540,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','eliseogozalvez','eliseo_gozalvez@yahoo.com','ELISEO GOZALVEZ','BULNES 1642 PISO 8 DEPTO B','CAPITAL FEDERAL','BUENOS AIRES','ARGENTINA','1425','5411-4822-2946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 01:18:05',0,NULL,3,1,2,1,NULL,NULL),(4326,616723033001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','brcash','rosscash@bellsouth.net','Ross Cash','5768 Descartes Cir','Boynton Beach','FL','UNITED STATES','33472-2429','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-08 01:48:23',0,NULL,3,1,1,1,NULL,'nikon å•è‚©åŒ… D1   1 '),(4327,616692113001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','bapsite','bapsite@hotmail.com','Baptiste Nobre','29 Nassau Street','Toronto','ON','CANADA','M5T1M3','(336) 838-5141 ext.: 0','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 02:15:47',0,NULL,3,1,3,1,NULL,'æ–œè‡‚  1 \rRR815343750CN\r'),(4328,656115200002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lucky_soi','irvia2000@yahoo.com','Oana Stan','2527 Crescent St<br>ap. Walk In','Astoria','NY','UNITED STATES','11102-2937','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 03:14:56',0,NULL,3,1,1,1,NULL,NULL),(4329,656126285002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','iceyfiery87','iceyfiery@singnet.com.sg','Wen Hao Wong','Hawkins Hall, Room 02010<br>430 Wood Street','West Lafayette','IN','UNITED STATES','47906','(765) 201-5093','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 04:06:01',0,NULL,3,1,11,1,NULL,' æ–°åœ°å€ï¼š\rWen Hao Wong\rBlk 457 Choa Chu Kang Ave 4\r#11-187\rSingapore 680457\rSingaporeRR815344463CN\r\r'),(4330,615775401001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','bquan94545','vir94545@yahoo.com','bruce quan','3490 savage ave','pinole','ca','UNITED STATES','94564','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 04:30:27',0,NULL,3,1,1,1,NULL,'é•œå¤´ç­’ xl   1 '),(4331,616756680001,110615440719,'Photo Spring Cushioned tripod Light Stand 7â€˜/ 210cm x 1',1,'AE3403',37.95,'hermeshine','shriekingvioletta','shriekingvioletta@yahoo.com','april colby','260 forest street','chatham','ON','CANADA','N7L 2A9','(519) 397-3853','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 04:52:57',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  çº¢ç›’  1 \rRR815343675CN\r'),(4332,616766513001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','rajeshau1505','rajeshau15@gmail.com','parimala Karthigeyan','38 Castleton Rd','Princeton','NJ','UNITED STATES','08540-1647','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 06:07:34',0,NULL,3,1,1,1,NULL,NULL),(4333,715469902015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','andyvanddetta','andyvandetta@hotmail.com','AbdulRedha Ahmed','C/o Natalie Hollyman HR Manager Alghanim Industries Ext 3204 PF12920 P O Box 223 Safat 13003','Kuwait','','KUWAIT','965','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-08 06:53:22',0,NULL,8,1,17,0,NULL,'\r'),(4334,715472607015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','andyvanddetta','andyvandetta@hotmail.com','AbdulRedha Ahmed','C/o Natalie Hollyman HR Manager Alghanim Industries Ext 3204 PF12920 P O Box 223 Safat 13003','Kuwait','','KUWAIT','965','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 07:10:45',0,NULL,3,1,8,1,NULL,'2m ç¯æž¶  2\r4ç¯å¤´æ£š   2\r115w 220v   8\råŒ…   1\rCP219487347CN\r\r'),(4336,701495392016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 07:45:22',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343661CN\r'),(4337,701498970016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','gerhold03','gerhold@btinternet.com','darren gerhold','90 kennerley rd, davenport','stockport','Cheshire','UNITED KINGDOM','SK2 6EY','01614560660','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 08:07:05',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…æ— å­—  1 '),(4338,701500405016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',3,'hutongstore','vyrusu','vyrusu_18@yahoo.com','Popa Razvan','25 Frunzei street, apartment 11','Timisoara','timis','ROMANIA','300495','40724866325','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 08:16:30',0,NULL,3,1,2,1,NULL,'450d çœ¼ç½©   1 '),(4339,656166852002,120568984583,'Promotionï¼EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zeonstrike','wattanadejj@hotmail.com','Wattanadej Jutacharoensuk','89/1 Soi Saparnqua Pracharaj2 road Bangsue','Bangkok','Bangkok','THAILAND','10800','66891371772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 08:54:48',0,NULL,3,1,3,1,NULL,'RR815343834CN\r '),(4340,656168682002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','www.photostudio.ch','ebay@photostudio.ch','Patrick Geissmann','Foto LÃ¼thard AG<br>Seminarstrasse 91','Wettingen','','SWITZERLAND','5430','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 09:05:53',0,NULL,3,1,3,1,NULL,'canon èƒŒå¿ƒ xl   1\rè€æ¬¾ \rRR815343763CN\r'),(4342,616800715001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','david.wien','nachname.vorname@gmx.at','David Moser','Abelegasse 13-15','Wien','','AUSTRIA','1160','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 10:00:08',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815343879CN\r'),(4343,616811445001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','furouribarri','paugomis@hotmail.com','Pau Gomis','Calle Segria 46 , 5Âº ,2Âª','Lleida','CataluÃ±a','SPAIN','25006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 10:47:33',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4344,616824229001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',5,'AB1201',85,'hermeshine','hans2900','hanzelmans@gmail.com','Hans Heins','Carrouselweg 117','Apeldoorn','','NETHERLANDS','7335PM','0031558431977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 11:42:47',0,NULL,3,1,4,1,NULL,'å€’å½±æ¿  5 \rYW864614826CN'),(4345,656204189002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','smar3250','scottmar@istar.ca','J. P McConnell','3 rue du Moulin','Courtauly','Languedoc-Roussillon','FRANCE','11230','(046) 869-5752','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 11:52:29',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864614874CN\r'),(4347,656214962002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','hanif0856','maninerror@gmail.com','Hanif, Muhammad','Gedung Temprint Lt.3<br>Jl. Palmerah Barat No.8','Jakarta Selatan','','INDONESIA','12210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 12:39:13',0,NULL,3,1,3,1,NULL,'100-150 5in1 åå…‰æ¿  1 \rRR815343692CN\r'),(4348,656226680002,120587378716,'Photo Studio Background Support (7Ã—7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','prokudin-pavel','propadi@list.ru','Pavel Prokudin','Altayskaya st. 23-68','Nizhny Tagil','Sverdlovskaya obl','RUSSIAN FEDERATION','622004','+7-912-22-000-66','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 13:19:52',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ 2m ( ç™½ï¼‰   1\rCP219486871CN '),(4349,616851428001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','telezini','studio1@telezini.com','Sergio Marranzino','45 Gramercy Ave','Yonkers','NY','UNITED STATES','10701-5123','(914) 424-1066','NoPaymentFailure','CheckoutComplete','Other','2011-01-08 13:30:07',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343715CN\r'),(4350,616868193001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','avibarami','avi_barami@walla.co.il','Avi Barami','Binyamin 1','RAMAT GAN','','ISRAEL','52512','972506923925','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 14:24:43',0,NULL,5,1,18,0,NULL,NULL),(4351,701519697016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','marcelloparola','m.stroh@gmx.ch','Marcel Stroh','In der WÃ¤sseri 37','ZÃ¼rich','','SWITZERLAND','8047','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 14:34:46',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4352,715611088015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','nottingham-forest','dmm@ebusinesslogic.com','David Mason','29 Boundary Close Kingsdown','Swindon','Wiltshire','UNITED KINGDOM','SN2 7TF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 15:20:52',0,NULL,3,1,2,1,NULL,'45w   2 '),(4353,616889283001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mixajura','mixajiri@gmail.com','Jiri Mixa','Bozeny Nemcove 1','Vyskov','','CZECH REPUBLIC','682 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 15:27:38',0,NULL,3,1,2,1,NULL,NULL),(4354,656276155002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','holcaul','holcaul22@yahoo.com','Philipp Voloshin','admonit 11, apt. 17','Lod','','ISRAEL','71338','97289203711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 15:50:43',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩  1\r77mm 橡胶罩   1'),(4355,616899375001,110566018419,'72mm 3-Stage Rubber Lens Hood for 80-200mm 24-105mm',1,'AB1306',3.79,'hermeshine','holcaul','holcaul22@yahoo.com','Trecia Thomas','744 Noble Ave','Bronx','NY','UNITED STATES','10473-4115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 16:01:38',0,NULL,8,1,17,1,NULL,'\r'),(4356,616932305001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','qqlll88','qiqilili88@gmail.com','Qiang Li','249 Colonnade Dr<br>Apt 6','Charlottesville','VA','UNITED STATES','22903-4931','(434) 284-0390','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 17:12:43',0,NULL,3,1,1,1,NULL,NULL),(4357,656317480002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','daniels3145','drdanny@earthlink.net','Daniel Schainholz, MPH','630 Lake St<br>Apt 303','San Francisco','CA','UNITED STATES','94118-1201','(415) 666-3765','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 17:29:18',0,NULL,3,1,1,1,NULL,NULL),(4359,616977855001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','atmapower2k','vinchy1@gmail.com','Jacques Baudoux','rue de la Chapelle 35','TriviÃ¨res','','BELGIUM','7100','0472551410','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 18:53:23',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343729CN\r'),(4360,656377984002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','alinochka14','alinochka14@yahoo.com','alina ozeruga','2201 Northview Dr<br>Apt 71','sacramento','CA','UNITED STATES','95833-2459','(916) 564-7315','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 19:43:09',0,NULL,3,1,1,1,NULL,'çˆµå½±æ— çº¿ N1  1 '),(4361,656374862002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3306',21,'hermeshine','minasnoivaswagner','minasnoivas-wagner@bol.com.br','wagner pereira da silva','av afonso pena 526 sl 708<br>centro','belo horizonte','Minas Gerais','BRAZIL','30130-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 19:50:06',0,NULL,3,1,3,1,NULL,'RR815343785CN '),(4362,715758494015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','oscarius87','oskars-miesnieks@inbox.lv','Oskars Miesnieks','Ciekurkalns 5. skerslinija 15/2 - 3','Riga','','LATVIA','LV-1026','26103660','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-08 19:56:24',0,NULL,3,1,2,1,NULL,'58mm-canon åæŽ¥çŽ¯  1 '),(4363,617020488001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','monatemplada','jmuyshondt@gmail.com','iTrader Online','7801 NW 37TH ST<br>Ste VIP-2892','Doral','FL','UNITED STATES','33166-6503','(305) 394-6605','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 20:31:34',0,NULL,3,1,3,1,NULL,'æŸ”å…‰ç®± 50-70cm å•ç¯å¤´   2 \rRR815343940CN\r'),(4364,656402483002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','kizsoli10','kizsoli@gmail.com','Zsolt KirÃ¡ly','FÅ‘ utca 19. 3. emelet 2.','Budapest','','HUNGARY','1011','+36209758028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 20:41:06',0,NULL,3,1,3,1,NULL,'50-70 é€šç”¨å¡å£ å¡‘æ–™  1 \rRR815343896CN\r'),(4365,617034066001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','bobzimlich','rzimlich@ussa.edu','Robert Zimlich','1 Academy Dr','Daphne','AL','UNITED STATES','36526-7055','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 21:03:55',0,NULL,3,1,3,1,NULL,'æŸ”å…‰ç®± 50-70cm å•ç¯å¤´  1 \r867RR815344517CN'),(4366,656415773002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hamber_russia','hamber@bk.ru','Mikhail Kuznetsov','Tatyany Makarovoy street 3,307','Moscow','RU','RUSSIAN FEDERATION','111674','(926)566-4200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-08 21:08:07',0,NULL,3,1,2,1,NULL,NULL),(4367,656411519002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','kbra3748','kenyatta.brame@cascadeng.com','kenyatta brame','2531 Barfield Dr SE','grand rapids','MI','UNITED STATES','49546-5507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 21:16:02',0,NULL,3,1,1,1,NULL,NULL),(4368,617037185001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','aimerladybird','samuelcapdeville@hotmail.com','Buizard David','ThÃ©Ã¢tre du Soleil Cartoucherie<br>Route des grandes manoeuvres','Paris','Ile-de-France','FRANCE','75012','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-08 21:17:32',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \rRR815343865CN\r'),(4369,715818243015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','sick.pig','thomasbuckley1@hotmail.com','Thomas Buckley','51 Intake Lane Rodley','Leeds','West Yorkshire','UNITED KINGDOM','LS13 1BT','01132561244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-08 21:54:30',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´ è‹±æ ‡   1 '),(4370,656449257002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','psasacp17hg','number1oregonbroker@yahoo.com','Erik Berglund','1831 SW Park Ave<br>Apt 404','Portland','OR','UNITED STATES','97201-3279','(971) 226-5874','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-08 22:36:46',0,NULL,3,1,1,1,NULL,NULL),(4371,617098159001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','1mans_tresjya','nweideman@bigpond.com','Nick Weideman','Level 5, 440 Collins St','Melbourne','Victoria','AUSTRALIA','3000','0359774555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 00:32:12',0,NULL,3,1,3,1,NULL,'è‚©æž¶  1 \ræ½˜'),(4372,715880801015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','love_bat','dennissterne@hotmail.com','Dennis Sterne','59 Pageant Rd','St Albans','Herts','UNITED KINGDOM','AL1 1NB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 00:41:26',0,NULL,3,1,2,1,NULL,NULL);
INSERT INTO `hmsh_ebay_transaction` VALUES (4373,715850452015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','d-missy-p','debsiporter@googlemail.com','Debi Porter','15 Lanhydrock Close Compton Vale','Paignton','Devon','UNITED KINGDOM','TQ3 3GP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 00:41:53',0,NULL,3,1,2,1,NULL,NULL),(4374,656489358002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bockcaron','mcgignac@gmail.com','hugues caron','43 ste-julienne','trois-rivieres','QC','CANADA','g8t4r6','(819) 909-1839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 00:54:11',0,NULL,3,1,2,1,NULL,NULL),(4375,617106722001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',2,'AKT029',48,'hermeshine','kq','d29501@gmail.com','Dan Hicks','137 S Coit St','Florence','SC','UNITED STATES','29501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 00:57:22',0,NULL,3,1,1,1,NULL,' 8-      52mm lens cap for Nikon \r6-      62mm lens cap for Nikon\r2-      67mm lens cap for Nikon\r2-      72mm lens cap for Nikon\r2-      77mm lens cap for Nikon\r\r'),(4376,656501347002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sammysue2u','samantha.roth2u@gmail.com','Samantha Roth','500 Rainbow Dr','Kokomo','IN','UNITED STATES','46902','(765) 453-3002','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 01:43:34',0,NULL,3,1,1,1,NULL,NULL),(4377,617117870001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','kirwinj','kirwinja@knology.net','John Kirwin','709 Wynsom Dr SE','Huntsville','AL','UNITED STATES','35803','(256) 508-3448','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 01:45:27',0,NULL,3,1,1,1,NULL,'sf18-sb900   1 '),(4378,656502415002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','shabas.muhammed','shabasmuhammed@gmail.com','Shabas Muhammed','21/17<br>Park St','Hawthorn','Victoria','AUSTRALIA','3122','00610431947765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 01:45:42',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿  1 '),(4379,656460241002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','stef0303','stefanidangelo@gmail.com','Stefani D\'Angelo','909 E Broad St<br>Apt 530','Athens','GA','UNITED STATES','30601-4841','(678) 276-5939','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 02:06:59',0,NULL,3,1,1,1,NULL,NULL),(4380,617128691001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','hassanteyx','hassanteyz@hotmail.com','hassan thalhath','ma.pashens','male\'','machan goalhi','MALDIVES','00960','(960)9743604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 02:33:10',0,NULL,3,1,2,1,NULL,'canon-58mm åæŽ¥çŽ¯  1 '),(4381,701929852016,260660053110,'New IR Remote Control for Pentax K10D K20D K200D',1,'AA2205',2.75,'hutongstore','countcharlie','charles.dp@ntlworld.com','Charles de Podesta','46 Filbert Street East','Leicester','Leicestershire','UNITED KINGDOM','LE27JE','0116228059','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 03:05:29',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ 5in1   1 '),(4382,656530758002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','wrc78','pdenys@wp.pl','Paul Denys','140 Maranda Close NE','Calgary','AB','CANADA','T2A 3E8','(403) 539-8933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 03:50:33',0,NULL,3,1,2,1,NULL,NULL),(4383,617160160001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','appenzeller98','hjstehr@web.de','Hans Joachim Stehr','HÃ¼nninghausenweg 29','Essen','NRW','GERMANY','45276','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 05:16:13',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  1\ræ–œè‡‚  1 \rlight stand  $20 \rYW864143860CNåŠ åˆ°è¿™è¡Œäº†'),(4385,617161815001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','djkramer1','djkramer@aol.com','Darren Kramer','92 Genesee Ln','Madison','CT','UNITED STATES','06443-1666','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 05:27:37',0,NULL,3,1,1,1,NULL,NULL),(4386,617162835001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','blackmajj','info@bassment.se','Petri Jokinen','Kverndalslinna 2','Gran','','NORWAY','2750','4798830923','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 05:32:58',0,NULL,3,1,3,1,NULL,'肩架 1\rRR815344959CN\r'),(4387,617185295001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','jantanjo','jan@cbbe.tv','jan tanjo','47 - 9870 151 st','surrey','BC','CANADA','v3r 8c9','(760) 705-8888','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 08:19:04',0,NULL,3,1,3,1,NULL,'RR815343919CN\r '),(4388,656576882002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','maoriboy.nz','rgcampbell.nz@gmail.com','Ross Campbell','Smales Farm, Telstraclear Building, Taharoto and Northcote Rd<br>Takapuna','Auckland','','NEW ZEALAND','0622','64299125740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 08:42:50',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4389,617200147001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','beecacher','edcylam@yahoo.com','Edmund Lam','170 West Tasman Dr','San Jose','CA','UNITED STATES','95134','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 09:27:23',0,NULL,3,1,1,1,NULL,NULL),(4390,617201711001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','jjacek59','jacekjackiewicz@bredband.net','Jacek Jackiewicz','Nobelv.89','MalmÃ¶','SkÃ¥ne','SWEDEN','21433','0704547235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 09:35:59',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹çƒå° 2 \rRR815343936CN\r'),(4392,702016995016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4393,702020403016,260660055606,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',2,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4394,702018664016,260660052333,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.39,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:04',0,NULL,8,1,17,0,NULL,NULL),(4395,702019261016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:05',0,NULL,8,1,17,0,NULL,NULL),(4396,716010932015,250599947231,'New 3 filters & Ring set for Cokin System P Series',1,'AKT062',15,'hutongstore','prendydo','prendydor@pt.lu','Dorothee Prendergast','5 Rue Michel Welter','OLM','','LUXEMBOURG','L-8339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 10:15:05',0,NULL,3,1,3,1,NULL,'ND2, 4, 8   \ræ¸å˜ç°  1\r72mm æŽ¥å£çŽ¯  1\r52mm çŽ¯æž¶  1\r52mm é•œå¤´ç›–  nikon   1 æ½˜RR815344830CN\r'),(4397,617222280001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',65.96,'hermeshine','l.khabaz','lutfimk@gmail.com','Lutfi M. Al-Khabaz','P.O.Box # 11627<br>Saudi Aramco','Dhahran','Eastern','SAUDI ARABIA','31311','00966504908852','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 10:42:49',0,NULL,3,1,3,1,NULL,'æ–œè‡‚   2 \r2kgä»¥å†…\rRR815343746CN\r'),(4398,617223741001,110566018453,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','haavard79','haavard_myhre@yahoo.no','HÃ¥vard Myhre','BrÃ¸drene Bergs vei 7','VÃ¥ler','Moss','NORWAY','1592','+47 90958397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 10:48:12',0,NULL,8,1,17,0,NULL,''),(4399,617227289001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','haavard79','haavard_myhre@yahoo.no','HÃ¥vard Myhre','BrÃ¸drene Bergs vei 7','VÃ¥ler','Moss','NORWAY','1592','+47 90958397','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 10:58:06',0,NULL,3,1,3,1,NULL,'10ç‰‡è£…   1\r77mm çŽ¯æž¶  1\r72mm çŽ¯æž¶  1 \rRR815344052CN\r'),(4400,656613545002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','falinicesc','faliniji17@gmail.com','Chakkij Israngoor Na Ayoothaya','87/243 Karnkanok 1 Village<br>M.12 T.Sankampang A.Sankampang','Chiangmai','','THAILAND','50130','0819611476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 10:58:12',0,NULL,3,1,2,1,NULL,NULL),(4401,702054526016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.39,'hutongstore','dilon44','gmurillomendez1@elmejor.e.telefonica.net','Gaspar Murillo Mendez','lopez de tovar 14 2A','badajoz','Extremadura','SPAIN','06008','696427065','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 11:29:48',0,NULL,3,1,2,1,NULL,'58mm æŽ¥å£çŽ¯  1 '),(4402,702049062016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','stephenebi01','ebi01@hotmail.com','Stephen Agisilaou','1/146 St Kilda Road St Kilda','Melbourne','Victoria','AUSTRALIA','1382','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-09 11:53:43',0,NULL,3,1,4,1,NULL,' 2mx3m èƒŒæ™¯æž¶  1\r3mx6m ç»¿è‰²èƒŒæ™¯å¸ƒ  1\r2m ç¯æž¶  2\r50-70 æ£š  2 æ¾³æ ‡\r115w 220v  2\råŒ…   1\rlighting kit  $30\rYW864143856CN\r '),(4403,617250716001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','rocio779','mafiosa_779@hotmail.com','Rocio Garcia Alonso','Sambara 55 1ÂºB','Madrid','Madrid','SPAIN','28027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 12:06:10',0,NULL,3,1,2,1,NULL,NULL),(4404,656651906002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','alexbraso','alex.bra@gmail.com','Alexandre Braso','al. barao de limeira, 511 - ap62','sao paulo','SP','BRAZIL','01202001','55-11-33617442','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 12:49:02',0,NULL,3,1,5,1,NULL,'4ç¯å¤´æ£š  æ¬§æ ‡   2\rCP219486845CN '),(4405,656677895002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','lepreghaun','lepreghaun@hotmail.com','Hakan Oztopcu','IBM ISSC<br>KÃ¶ztelek utca 6','Budapest','Hungary','HUNGARY','1092','362053312825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 13:56:00',0,NULL,3,1,2,1,NULL,'90th è‚©å¸¦  1 '),(4406,617298278001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','isocron','morgan.morleh@gmail.com','Morgan MorlÃ©h','Ã– LinnÃ©gatan 5','Kumla','Sweden','SWEDEN','69232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:09:05',0,NULL,8,1,17,0,NULL,''),(4407,656687001002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','isocron','morgan.morleh@gmail.com','Morgan MorlÃ©h','Ã– LinnÃ©gatan 5','Kumla','Sweden','SWEDEN','69232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:15:50',0,NULL,3,1,2,1,NULL,'RS-C3    1 \r40cm æ£š  1 '),(4408,656697124002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','gogogottshall','riptidebumblingbee@gmail.com','Beth Gottshall','106 S Miller St','Shillington','PA','UNITED STATES','19607','','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 14:41:29',0,NULL,3,1,1,1,NULL,'ç¢—ç½© P1  1 '),(4409,617313367001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','massimolc','maxlc@fastwebnet.it','Massimo La Cecilia','via Amerigo Vespucci 41','Roma','Roma','ITALY','00153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 14:44:08',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹çƒå°  1 '),(4410,656700181002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','spirou54250','yvan.bombarde@free.fr','Yvan Bombarde','54 rue Charles Martel','Champigneulles','Lorraine','FRANCE','54250','06.07.59.44.92','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 14:48:25',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶  2\rbåº§   2\ræŸ”å…‰ä¼ž   2\rlight kit  $25 \rYW864143882CN'),(4411,716180037015,250692240830,'Wireless Remote Control for Olympus E-420/E-410/E-400',1,'AA3229',11.47,'hutongstore','rolfinge12','rolf.kvernstad@online.no','Rolf Inge Kvernstad','HansÃ¸yveien 5','6520 Frei','Frei','NORWAY','6520','+4799722279','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 15:55:04',0,NULL,3,1,2,1,NULL,'çˆµå½±æ— çº¿ olympus  1 '),(4412,617348102001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','chantilly_mckinnon','chantilly.mckinnon@gmail.com','Chantilly McKinnon','B - 532 Bolivar Street','Peterborough','ON','CANADA','K9J 4R8','(705) 768-4725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 15:59:32',0,NULL,8,1,17,0,NULL,''),(4413,617350031001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','chantilly_mckinnon','chantilly.mckinnon@gmail.com','Chantilly McKinnon','B - 532 Bolivar Street','Peterborough','ON','CANADA','K9J 4R8','(705) 768-4725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 15:59:31',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1 \réº‚çš®  1 '),(4414,617351088001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','pellejodirt','locomoteros@yahoo.es','Jose Ignacio Guio Antolin','C/ Montemayor de Pililla nÂº15 3ÂºC','MADRID','Madrid','SPAIN','28043','913886058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:00:53',0,NULL,3,1,2,1,NULL,'å°å·å†…èƒ†åŒ…  æ— å­—  1  '),(4415,617353771001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bxhylander','wjlappe@hotmail.com','William Lappe','1239 Mayflower Ave','Bronx','NY','UNITED STATES','10461-6109','(646) 924-9095','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 16:06:19',0,NULL,3,1,1,1,NULL,NULL),(4416,656743049002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','icmatyi1','icmatyi@gmail.com','GÃ¡bor Fekete','TÃ¡ncsics M utca 150.','MezÅ‘keresztes','','HUNGARY','3441','0036703738980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:16:13',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4417,656745416002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',6,'AA1312',9,'hermeshine','guillaume0987','guillaumenadeau@videotron.ca','Guillaume Nadeau','595 d\'Aiguillon','Quebec','QC','CANADA','g1r 1m6','(418) 522-1512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 16:17:23',0,NULL,3,1,3,1,NULL,'éº‚çš®  6\rRR815343984CN\r'),(4418,656782518002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','arl999261','kaczmarskir@op.pl','Ewelina KACZMARSKA','35 ALEXANDRA ROAD','Southampton','Hampshire','UNITED KINGDOM','SO15 5DH','02380636131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 17:16:39',0,NULL,3,1,3,1,NULL,'sony å•è‚©åŒ…  a1   1 \rRR815343998CN\r'),(4419,617466783001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 18:50:45',0,NULL,3,1,3,1,NULL,'1è½¬4ç¯å¤´   2 \rRR815343794CN\r'),(4420,617478980001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','copperdoggi','e.k.choy@gmail.com','Evan Choy','2202 Erin Centre Blvd.','Mississauga','ON','CANADA','L5M 5C1','(226) 220-3788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 19:05:27',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 \rRR815343803CN\r'),(4421,716345833015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1307',5.16,'hutongstore','christianhylse','christian.hylse@telia.com','Christian Hylse','GrÃ¥bovÃ¤gen 5','Ronneby','Blekinge','SWEDEN','37239','0705-275714','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 19:07:22',0,NULL,3,1,2,1,NULL,' '),(4422,617486776001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','rpm_916','ebay.6qv@gishpuppy.com','Rex Mendoza','1425 Leaf Ter','San Diego','CA','UNITED STATES','92114-6820','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 19:11:16',0,NULL,3,1,1,1,NULL,'è‚¥çš‚ç›’ 430ex   1 '),(4423,617500498001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','trinity_studios','lovefoundanew@gmail.com','Paul Griffith','14344 Polo Ranch St','Haslet','TX','UNITED STATES','76052-3327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-09 19:28:06',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4424,656902158002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 19:49:52',0,NULL,3,1,2,1,NULL,'æ°”å¹+å¸ƒ   1 '),(4425,702395731016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','barb3jp','roger.barbaraplatt@googlemail.com','Mrs B Platt','36 Monument Way','Ulverston','Cumbria','UNITED KINGDOM','LA12 9SY','07791130563','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:01:03',0,NULL,3,1,2,1,NULL,NULL),(4426,656924746002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:41',0,NULL,8,1,17,0,NULL,NULL),(4427,656918232002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',17.99,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:42',0,NULL,8,1,17,0,NULL,NULL),(4428,617535565001,110533631226,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','tocklee8831','tocklee@live.ca','Tock Lee','15131 Kennedy Road','Stouffville','ON','CANADA','L4A 7X5','(905) 888-8831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:25:42',0,NULL,3,1,3,1,NULL,'72mm æ©¡èƒ¶ç½©   1\ré˜²é›¨ç½©   1\rè‚¥çš‚ç›’ 580exII     1 \rRR815343975CN\r'),(4429,716427876015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.62,'hutongstore','bilbo_baggins1','abartup@aol.com','Andrew Bartup','21 Cowley Drive Woodingdean','Brighton','East Sussex','UNITED KINGDOM','BN2 6WB','01273302218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:34:15',0,NULL,8,1,17,0,NULL,NULL),(4430,716430169015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','bilbo_baggins1','abartup@aol.com','Andrew Bartup','21 Cowley Drive Woodingdean','Brighton','East Sussex','UNITED KINGDOM','BN2 6WB','01273302218','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 20:37:02',0,NULL,3,1,2,1,NULL,'77mm çŽ¯æž¶  1\r67mm æŽ¥å£çŽ¯  1 '),(4431,656938037002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','cbarrondj','cbarron88@gmail.com','Cory Barron','11500 N Dale Mabry Hwy<br>APT 1402','Tampa','FL','UNITED STATES','33618-3854','(813) 679-5737','NoPaymentFailure','CheckoutComplete','Other','2011-01-09 20:40:44',0,NULL,3,1,1,1,NULL,NULL),(4432,617550698001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kazakh082010','chompy@mail.ru','Alyona Burova','Chokin 23/1-31','Pavlodar','','KAZAKHSTAN','140008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:42:38',0,NULL,3,1,2,1,NULL,NULL),(4433,617556666001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','ecourtey','evelyne_courteyn@yahoo.com','Evelyne Courteyn','Kerkstraat 24A bus1','Deftinge','','BELGIUM','9570','+3254245665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:50:44',0,NULL,3,1,2,1,NULL,'ggs 3.0â€™ è†œ   1 '),(4434,702436742016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','wysecom','antti.mikkola@netti.fi','Antti Mikkola','Kammintie 6','SF','JyvÃ¤skylÃ¤','FINLAND','40520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 20:56:37',0,NULL,3,1,2,1,NULL,'çº¢å¤–é¥æŽ§ olympus  1 '),(4435,617561197001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','czinbr','czinovich@sasktel.net','Celina Zinovich','101 4th Ave S<br>PO Box 858','Big River','SK','CANADA','S0J0E0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 20:58:53',0,NULL,3,1,2,1,NULL,NULL),(4436,716448364015,250643703886,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','crucialpro2010','alex@alexhibbert.com','Alexander Hibbert','314 The Bridge 334 Queenstown Road','London','London','UNITED KINGDOM','SW8 4NP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 21:02:26',0,NULL,3,1,2,1,NULL,'1.6x2.1 é»‘è‰²èƒŒæ™¯å¸ƒ  1 '),(4437,617566204001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','gidi2011','gidi.binder@gmail.com','gidi binder','amizur shimshon 9/6','beer sheva','beer sheva','ISRAEL','84717','972544718723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 21:09:13',0,NULL,3,1,2,1,NULL,'nikon-52mm åæŽ¥çŽ¯  1 '),(4438,656956570002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','kzoo10s','m_malvitz@hotmail.com','Michael Malvitz','352 Calkins Ave SE','Grand Rapids','MI','UNITED STATES','49506-1522','(269) 377-3500','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-09 21:12:36',0,NULL,3,1,1,1,NULL,NULL),(4439,617570151001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.8,'hermeshine','imkratelsinore','irelsinore@yahoo.co.uk','Ian Robertson','7 elsinore<br>Castletroy','Limerick','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 21:14:53',0,NULL,3,1,2,1,NULL,' '),(4440,716476468015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','stuinboro','emma.c.232@btinternet.com','Stuart Carter','10 Water End Brompton','Northallerton','N Yorkshire','UNITED KINGDOM','DL6 2RL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 21:43:43',0,NULL,3,1,2,1,NULL,NULL),(4441,716489896015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','ivolondon','ivo__g@hotmail.com','Ivo Gormley','3 Elwin Street','Tower Hamlets','London','UNITED KINGDOM','E2 7BU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 22:10:48',0,NULL,3,1,2,1,NULL,NULL),(4442,716497690015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','trifasic13','anxel13@hotmail.com','Angel Badia Guix','Barri de Coma nÂº37','CARDONA','BARCELONA','SPAIN','08261','652676743','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-09 22:21:59',0,NULL,3,1,3,1,NULL,'4ç¯å¤´æ£š   1  æ¬§æ ‡  1 \rRR815343922CN'),(4443,702502818016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','smokeybluecat1','djnstafford@gmail.com','David Stafford','48 Eleanor Road','London','London','UNITED KINGDOM','N11 2QS','07702329959','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-09 22:39:45',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4444,657002369002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','klong09','avalino@yahoo.com','Al Valino','35 Poppy Place','Scarborough','ON','CANADA','M1X1Y7','(647) 567-2200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 22:43:57',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡  1 '),(4445,617621168001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','tatikaltatiana','tatikalantzi@yahoo.gr','Kalantzi Tatiana','mithridatou 13-15','Athens','Greece','GREECE','11632','(0030)6974634689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-09 23:12:28',0,NULL,8,1,17,0,NULL,NULL),(4446,657012389002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AO0024',40.99,'hermeshine','tatikaltatiana','tatikalantzi@yahoo.gr','Kalantzi Tatiana','mithridatou 13-15','Athens','Greece','GREECE','11632','(0030)6974634689','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-09 23:12:28',0,NULL,3,1,3,1,NULL,'60cm æ£š  1\rcanon å•è‚©åŒ…  N4   1 RR815344525CN'),(4447,657032026002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','artboolid','pechenyy@gmail.com','Pechenyy Vasil','Prostornaya st. 8 ap. 152','Moscow','','RUSSIAN FEDERATION','107392','+7(925)0065940','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 00:13:16',0,NULL,3,1,5,1,NULL,'èƒŒæ™¯æž¶ï¼ˆ ç™½ï¼‰ 1.6å®½çš„ 1\r2m ç¯æž¶  2\råŒç¯å¤´  æ¬§æ ‡   2\råå…‰ä¼ž   2\r115w   220v   4\råŒ…   1 \rCP219486823CN'),(4448,657037371002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','fashion-rtn','enzons78@gmail.com','Onur Kaya','13 rue richard Byrd','Mantes La Jolie','ÃŽle-de-France','FRANCE','78200','0615271775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 00:18:31',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§   1\ræŸ”å…‰ä¼ž   1 \rRR815343732CN\r'),(4449,657050479002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','kampong_boy','eric@treasure-images.com','Eric and Cheryl Madeja','Taman Hilton, Lrg Hilton 6, House 62<br>Jalan Penampang','Kota Kinabalu','Sabah','MALAYSIA','88200','0128382272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 00:59:22',0,NULL,3,1,2,1,NULL,'58mm æ¸å˜ç°  1 '),(4450,617361725001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','mstr2438','mironstrutinski@gmail.com','Miron Strutinski','611  28thStreetWest','Saskatoon','SK','CANADA','S7L 0L2','(306) 384-4392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 01:02:10',0,NULL,8,1,17,0,NULL,NULL),(4451,656745917002,120560203215,'Nikon 52mm Reverse Adapter Combined shipping discounts',1,'AA1210',4.4,'hermeshine','mstr2438','mironstrutinski@gmail.com','Miron Strutinski','611  28thStreetWest','Saskatoon','SK','CANADA','S7L 0L2','(306) 384-4392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 01:02:11',0,NULL,3,1,2,1,NULL,'52mm-nikon  åæŽ¥çŽ¯  1\r55mm æ©¡èƒ¶   1 '),(4452,617666338001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:13:53',0,NULL,8,1,17,0,NULL,NULL),(4453,617665715001,110625498117,'Photo  Background Support 2 x 2m (7Ã—2 ft) + Backdrop',1,'AO0010',70,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 02:13:54',0,NULL,8,1,17,0,NULL,NULL),(4454,657077925002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',111.98,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:18:25',0,NULL,8,1,17,0,NULL,NULL),(4455,657080045002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',70,'hermeshine','rix3783','mrix@bigpond.net.au','Mike Rix','8 Aldag Court','Karratha','Western Australia','AUSTRALIA','6714','610891441648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 02:24:02',0,NULL,3,1,4,1,NULL,'è“è‰²ï¼Œç»¿è‰²èƒŒæ™¯æ¿   1\r60cm é—ªå…‰ç¯æ£š   2\rèƒŒæ™¯æž¶ï¼ˆæ²³åŒ—ï¼‰  ç™½è‰²å¸ƒ   1\r50-70 å•ç¯å¤´æ£š  æ¾³æ ‡  2\rYW864614852CN\r\r'),(4456,657095425002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','setiya_tarun','setiya_tarun@yahoo.com','Tarun Setiya','4020 St. Jean, Apt#610','Dollard Des Ormeaux','QC','CANADA','H9G2L6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 03:13:29',0,NULL,3,1,2,1,NULL,NULL),(4457,617724741001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3401',59.25,'hermeshine','rconline2010','remielcomia@gmail.com','Remiel Comia','c/o Ansari Engineering Services 3rd Floor, House 338 Sabha Bldg<br>Rd 1705, Diplomatic Area 317','Manama','Diplomatic Area','BAHRAIN','10122','97339881831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 05:30:30',0,NULL,3,1,3,1,NULL,'110cm 5in1   2 RR815344485CN'),(4458,617727047001,110541376393,'1.6m(5.2ft)Ã—2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','sazamora26','sazamora23@aol.com','Sean Zamora','21307 E Venton St','Covina','CA','UNITED STATES','91724-1937','(626) 827-3553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 05:51:36',0,NULL,3,1,1,1,NULL,'1.6m x2.1m  èƒŒæ™¯å¸ƒ  2\ré»‘è‰² + çº¢è‰²  '),(4459,657136444002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rudygree','lolobartolo@hotmail.com','francisco manuel cano rodriguez','c/ joan josep amengual i reus nÂº51 2ÂºA','binissalem','Islas Baleares','SPAIN','07350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 06:32:09',0,NULL,3,1,2,1,NULL,NULL),(4460,657136443002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jiriv','j.vanek@email.cz','Jana Langrova','Hulvacka 11','Ostrava Zabreh','','CZECH REPUBLIC','70030','420776276152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 07:11:40',0,NULL,3,1,2,1,NULL,'å¹¿è§’æ‰˜æž¶   1 '),(4461,657152432002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','emeuvede','emeuvede@hotmail.com','Marco ValdÃ©s DÃaz','Calle del MosÃ©n Jacinto Verdaguer<br>Portal 9 Puerta 8','Valencia','Comunidad Valenciana','SPAIN','46008','656873563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:20:45',0,NULL,8,1,17,1,NULL,''),(4462,617752165001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','michaelkl2009','michaelkl@mail.ru','Michael Klimenko','Gaydara 27-55','Ozersk','Chelyabinsk region','RUSSIAN FEDERATION','456785','79222350750','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 08:38:48',0,NULL,3,1,5,1,NULL,' CP219487846CN\r'),(4464,657153652002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','terpus','bterpus@yahoo.com','Boris Terpinov','Permyakova, 43 building, 41 apt.','Tyumen','Tyumen region','RUSSIAN FEDERATION','625051','(3452)339789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:43:00',0,NULL,8,1,17,0,NULL,NULL),(4465,617750493001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','terpus','bterpus@yahoo.com','Boris Terpinov','Permyakova, 43 building, 41 apt.','Tyumen','Tyumen region','RUSSIAN FEDERATION','625051','(3452)339789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 08:43:01',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶   1\rbåº§    1\ræŸ”å…‰ä¼ž    1\rå¤§åŠ›å¤¹çƒå°  1 RR815344432CN'),(4466,617752686001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','2011code','setsero02@gmail.com','orestes martinez','isla de la graciosa 14 bajo B<br>vecindario','las palmas','Canarias','SPAIN','35110','928716246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 09:28:30',0,NULL,3,1,2,1,NULL,'RS-N1   1 '),(4467,656581302002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 09:43:31',0,NULL,3,1,4,1,NULL,'4ç¯å¤´æ£š   2 \rYW864614863CN\r'),(4468,657170183002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','albiertas','apa@dge-baltic.lt','Albertas Paplauskas','Bajoru kelias 5-29','Vilnius','','LITHUANIA','08459','(370) 68618648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 10:03:47',0,NULL,3,1,2,1,NULL,'\r '),(4469,616807921001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','bigmommapaul','bumblebel@hotmail.com','Belinda Turpin','290 Everard Road','Kyabram','Victoria','AUSTRALIA','3620','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-10 10:08:03',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\räº‘å°  1\ræŸ”å…‰ä¼ž  1 RR815344450CN'),(4470,716707505015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','aadr2673','albertino.adriani@gmail.com','Alberto adriani','500 archway road','London','London','UNITED KINGDOM','N6 4NA','07763185423','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-10 10:20:06',0,NULL,3,1,2,1,NULL,NULL),(4471,657179830002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','11_remix_11','11remix11@rambler.ru','Aleksander Remishevskiy','Kurchatova str. 4/1, ap.108','Khmelnitskiy','Khmelnitskiy','UKRAINE','29025','+38-068-202-102-7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 10:45:23',0,NULL,3,1,2,1,NULL,NULL),(4472,657190222002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','jds31415','jdsebay1@xemaps.com','James  Schroeder','1988 Ririe Cir','Idaho Falls','ID','UNITED STATES','83404-5709','(208) 524-4143','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-10 11:36:53',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4473,617687723001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',44.78,'hermeshine','boogii1','gabortoronto@gmail.com','Gabor Bognar','902-555 Sheppard Ave W','Toronto','ON','CANADA','M3H 2R7','(647) 299-1394','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 11:48:38',0,NULL,3,1,3,1,NULL,'å¤§åŠ›å¤¹  2\råå…‰æ¿ æ”¯æž¶   1 RR815344551CN'),(4474,657211660002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','natuska76','natasheorlovoj@gmail.com','Natasha Orlova','dom.36 kv.185','poselok Mosrentgen','Moskovskaya obl','RUSSIAN FEDERATION','142771','79161285354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:00:41',0,NULL,8,1,17,0,NULL,NULL),(4475,657211614002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','natuska76','natasheorlovoj@gmail.com','Natasha Orlova','dom.36 kv.185','poselok Mosrentgen','Moskovskaya obl','RUSSIAN FEDERATION','142771','79161285354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:00:42',0,NULL,3,1,3,1,NULL,'å•ç¯å¤´ æ¬§æ ‡   1\r115w 220v   1 RR815344503CN'),(4478,657221257002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','polkan-irk','pavel_arsentev@s268604749.onlinehome.us','Pavel M. Arsentev','Dalnevostochnaya str, 61-73','Irkutsk','','RUSSIAN FEDERATION','664046','+79501128600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 13:37:24',0,NULL,3,1,2,1,NULL,'80cm 2in1   1 '),(4480,702756101016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',11.8,'hutongstore','dasagi10','dsg_tgn@hotmail.com','OMNIA SOLUTIONS (Sr. David Sanz GironÃ¨s)','C/ del Plom 109 nave 4 PolÃ­gon Industrial Riu Clar','Tarragona','CataluÃ±a','SPAIN','43006','680737427','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-10 13:43:39',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹  2 '),(4481,617832519001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','comprador2os','udistritaljohn@yahoo.com','John Martinez','504 Forest Cir<br>Apt 317','Walterboro','SC','UNITED STATES','29488-2973','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'6663a å¿«è£…æ¿  1 \ræ”¹ä¸ªåœ°å€LK018103270CN'),(4482,617803403001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','cf3sk8','cf3rules@gmail.com','Charles Farina III','1821 W McGalliard Ave','Hamilton','NJ','UNITED STATES','08610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 14:43:00',0,NULL,3,1,1,1,NULL,'æ°”å¹ + å¸ƒ   1 '),(4483,657256680002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','sindilevich','sindilrv@mail.jct.ac.il','Matanel Sindilevich','73/16 Shahal St.','Jerusalem','Jerusalem','ISRAEL','93721','+972544705353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 15:40:12',0,NULL,3,1,2,1,NULL,NULL),(4484,656092002002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',68,'hermeshine','antonia8058','er_goza@hotmail.com','antonia pichardo ramirez','palos de la frontera nÂº 23','la palma del condado','AndalucÃ­a Ceuta y Melilla','SPAIN','21700','628681432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 16:40:50',0,NULL,3,1,3,1,NULL,'canon è€æ¬¾èƒŒå¿ƒ m  1\rcanon è€æ¬¾èƒŒå¿ƒ xl   1 \r1291RR815344605CN'),(4485,617887269001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:13:13',0,NULL,8,1,17,0,NULL,NULL),(4486,617885881001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:13:14',0,NULL,8,1,17,0,NULL,''),(4487,657300847002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','planet-earth-2008','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 17:31:23',0,NULL,3,1,1,1,NULL,'58mm æ©¡èƒ¶ç½©  1\r52mm æ©¡èƒ¶ç½©   1 \r58mm é•œå¤´ç›–   canon 1 '),(4488,616539510001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','twobabys_rig','norali2004@mac.com','Maria Gonzalez','7684 Whitsett Ave','Los Angeles','CA','UNITED STATES','90001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 18:15:34',0,NULL,3,1,1,1,NULL,'æ–°æ¬¾å†…èƒ†åŒ…   1 '),(4489,657320930002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mirivah','njanja_2003@yahoo.com','Anna Gaspotic','Olge Ban 13','Pula','Istra','CROATIA','52100','+385981766645','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 18:18:40',0,NULL,3,1,2,1,NULL,'58mm镜头盖 1个'),(4490,657202079002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','cotxero','cotxero@yahoo.es','David   Saez Forner','C mig nÂº1','Canet d\'en Berenguer','Comunidad Valenciana','SPAIN','46529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 18:48:13',0,NULL,3,1,4,1,NULL,'2m ç¯æž¶   2\rbåº§    2\ræŸ”å…‰ä¼ž   2 \rlighting stand  $22\rYW864614896CN\r'),(4491,617936091001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','foxmulderebe','kittie4ebay@yahoo.com','Kittie M. Aleman','3404 Fillmore St','Riverside','CA','UNITED STATES','92503','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-10 19:01:09',0,NULL,3,1,1,1,NULL,'40cm æ£š  1 '),(4492,617942338001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',3,'AE3601',54,'hermeshine','niggaphil','philippe.gaudens@photomask.com','GAUDENS Philippe','TOPPAN PHOTOMASKS<br>224, Bd John Kennedy','CORBEIL ESSONNES','ESSONNES','FRANCE','91100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 19:16:31',0,NULL,3,1,3,1,NULL,'115w 220v   3 RR815344477CN'),(4495,657363123002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','csuc1980','timmyc2000@hotmail.com','Tim Cook','401 Crescent Ct<br>Apt 4104','San Francisco','CA','UNITED STATES','94134-3384','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 19:42:22',0,NULL,3,1,1,1,NULL,' '),(4496,617959313001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','citronyecki','eszenyi.david@freemail.hu','Eszenyi DÃ¡vid','TÃ©glÃ¡skert utca 97.','Debrecen','HajdÃº-Bihar','HUNGARY','4030','0036206692806','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 19:47:22',0,NULL,3,1,3,1,NULL,'åå…‰æ¿æ”¯æž¶  1 RR815344534CN'),(4497,617966108001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','isabellajewelry','scarlet@actcom.co.il','isabella lam','108 hagalil st<br>neveshaanan','haifa','israel','ISRAEL','32683','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:04:38',0,NULL,8,1,17,0,NULL,NULL),(4498,617966517001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','isabellajewelry','scarlet@actcom.co.il','isabella lam','108 hagalil st<br>neveshaanan','haifa','israel','ISRAEL','32683','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:04:39',0,NULL,3,1,3,1,NULL,'40cm æ£š   1\rå€’å½±æ¿   1 RR815344494CN'),(4499,657384586002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jbenben09','johanbencker@gmail.com','johan bencker','segervÃ¤gen 204','Ã„lvsjÃ¶','Stockholm','SWEDEN','12534','+46708614662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:23:19',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815344548CN'),(4500,617984203001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','thedoyman','thedoyman@hotmail.com','Sebastien Doyon','5220 ST-LAURENT','MONTREAL','QC','CANADA','H2T1S1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 20:38:43',0,NULL,3,1,2,1,NULL,'å¤§åŠ›å¤¹ çƒå°  1 '),(4501,617981743001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','nadine220661','legroux.daniel@neuf.fr','nadine legroux','23 rue cerfeuille','ollainville','ÃŽle-de-France','FRANCE','91340','01 69 26 94 80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-10 20:39:21',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864614900CN\r'),(4502,617999887001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','cardiff800i','kcelldweller@gmail.com','Berislav Kovacevic','vukovarska 4','Cakovec','PW','CROATIA','40000','00385959012763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 21:13:22',0,NULL,3,1,2,1,NULL,' '),(4503,657419812002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','9003peter','jukebox_74@hotmail.com','p.westheim','bernhardlaan 18','sint odilienberg','','NETHERLANDS','6077 at','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 21:41:40',0,NULL,3,1,2,1,NULL,'cåž‹å¤¹   2 '),(4505,618026940001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','mil_bot','boslitterbox@aol.com','Mike Ho','942 S Stanley Ave','Los Angeles','CA','UNITED STATES','90036-4602','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-10 22:21:51',0,NULL,3,1,1,1,NULL,'éº‚çš®  2 '),(4506,657446372002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','llhgantz','llhgantz1@yahoo.ca','Judy Tailby','53 221 RR #183<br>Box 8032','Edson','AB','CANADA','T7E1W2','(780) 712-1147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 22:45:52',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   2'),(4507,703033593016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','davidclimb85','david.toncic@gmail.com','David TonÄiÄ','TomÅ¡iÄeva 17/B','Idrija','Slovenia','SLOVENIA','0386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-10 23:14:54',0,NULL,3,1,2,1,NULL,' '),(4508,657446209002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','keeper_25','rbf0069@gmail.com','Raul Bustos Fernandez','Calle Finestrat 33-46<br>Calle Finestrat 33-58','Valencia','Comunidad Valenciana','SPAIN','46006','619935988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-10 23:16:19',0,NULL,3,1,2,1,NULL,'6662aå¿«è£…æ¿   1  '),(4509,717062307015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','bezejmeny2','bezejmeny@gmail.com','Tibor BalÃ¡zs','RÃ¡kocziho 41','Å tÃºrovo','vÃ½chozÃ­','SLOVAK REPUBLIC','94301','+421948508788','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-10 23:46:36',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rbåº§  1\ræŸ”å…‰ä¼ž   1 RR815344429CN'),(4510,717067126015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'AA1304',5.64,'hutongstore','classy.sassy','bashori_bmw@yahoo.com','bashar mudar waleed','GudingvÃ¤gen 17','Ã¥kersberga','','SWEDEN','18461','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 00:00:17',0,NULL,3,1,2,1,NULL,NULL),(4511,717071122015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',6.1,'hutongstore','whatashottiger','nuno.costacampos@gmail.com','Nuno Costa Campos','Rua das Macieiras, 124 Torre','Cascais','','PORTUGAL','2750-010','+351 93 698 45 42','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 00:14:14',0,NULL,3,1,2,1,NULL,'å¤§å·å†…èƒ†åŒ…  canon  1 '),(4512,618070991001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','123szymanowski','adam.nycity@gmail.com','Frank Kohner','340 E 80th St<br>Apt 7B','New York','NY','UNITED STATES','10075-0988','(917) 945-7005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 00:57:30',0,NULL,3,1,1,1,NULL,NULL),(4513,618072284001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','colcampbell07','colcamp@gmail.com','Colin Campbell','280 Wellesley St.E<br>Suite 2409','Toronto','ON','CANADA','M4X1G7','(416) 727-6402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 01:02:50',0,NULL,3,1,2,1,NULL,NULL),(4516,657496594002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','sonthesun','hbms65@yahoo.ca','hazim aldujaili','2439 yeovil road','mississauga','ON','CANADA','l5j2g1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 01:43:28',0,NULL,3,1,3,1,NULL,'2m ç¯æž¶  1\rå•ç¯å¤´   1\råå…‰ä¼ž   1 RR815344446CN'),(4517,618087347001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','doan_andrew','iayla_vz@hotmail.com','Trinh My Kien','7905 21 avenue','montreal','QC','CANADA','h1z3s9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:01:57',0,NULL,3,1,2,1,NULL,'å°å·ç°å¡   1 '),(4518,657511730002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','scrapladycamping','tnbluegrassfan@aol.com','Bishop Rebecca','246 County Road 728','Riceville','TN','UNITED STATES','37370','(423) 462-2063','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 02:43:04',0,NULL,3,1,1,1,NULL,NULL),(4519,657514142002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','*wildlifewatcher*','abelocastro@hotmail.com','Abel LÃ³pez Castro','Colonia San JosÃ©, bloque 1, piso 2Âº pta.8','El Escorial','Madrid','SPAIN','28280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:55:58',0,NULL,8,1,17,0,NULL,''),(4520,657517403002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','*wildlifewatcher*','abelocastro@hotmail.com','Abel LÃ³pez Castro','Colonia San JosÃ©, bloque 1, piso 2Âº pta.8','El Escorial','Madrid','SPAIN','28280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 02:58:23',0,NULL,3,1,3,1,NULL,'å¹¿è§’æ‰˜æž¶   1  \r77mm æŽ¥å£çŽ¯  1RR815344415CNåŠ åˆ°è¿™è¡Œäº†'),(4522,618102102001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','emeuvede','emeuvede@hotmail.com','Marco ValdÃ©s DÃaz','Calle del MosÃ©n Jacinto Verdaguer<br>Portal 9 Puerta 8','Valencia','Comunidad Valenciana','SPAIN','46008','656873563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 03:01:27',0,NULL,3,1,2,1,NULL,'å•ç¯å¤´æ¬§æ ‡   1 \rCåž‹å¤¹   1 '),(4524,618126215001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sarhan.ahmed','shab.t@hotmail.com','SARHAN AHMED','Apt. 11, 54 Munroe Place','Regina','SK','CANADA','S4S4P7','(306) 351-0088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 05:04:13',0,NULL,3,1,2,1,NULL,NULL),(4530,657569641002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','lhkisses','wswseee@hotmail.com','Jung Min Lee','330810 Georgia Tech Station','Atlanta','GA','UNITED STATES','30332-0001','(229) 389-9403','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 07:56:31',0,NULL,3,1,1,1,NULL,'小号canon内胆包  1 '),(4525,657546114002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nadarola','xboxdaniel@gmail.com','Daniel Moreira','223 E Hyde Park Blvd<br>APT 9','Inglewood','CA','UNITED STATES','90302-5591','(323) 868-1479','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 05:15:48',0,NULL,3,1,1,1,NULL,'å¤§åŠ›å¤¹  1 '),(4526,618135206001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','quincibea','quincy@thegrindhouse.com','Brent Buchanan','230 Crown St<br>(Upstairs)','Darlinghurst','New South Wales','AUSTRALIA','2010','0299501500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:05:35',0,NULL,8,1,17,0,NULL,NULL),(4527,618135428001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','quincibea','quincy@thegrindhouse.com','Brent Buchanan','230 Crown St<br>(Upstairs)','Darlinghurst','New South Wales','AUSTRALIA','2010','0299501500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:06:41',0,NULL,3,1,2,1,NULL,'80cm 5in1 åå…‰æ¿  1\r77mm é•œå¤´ç›–  canon  1 '),(4528,617995135001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:56:51',0,NULL,8,1,17,0,NULL,NULL),(4529,616529960001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',230.36,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 06:56:52',0,NULL,3,1,5,1,NULL,'50cm æ£š   1\rMC-N3   1\rNIKON D1 å•è‚©åŒ…  1\r115w 220v   2\r45w  2\r50-70å•ç¯å¤´æ£š  æ¬§æ ‡ 2\r40cm æ£š   1\r67mm uv   1\r55mm uv  1 æ½˜\rCP219486956CN\r'),(4531,657582435002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','williamt84','williamt84@tvisuals.net','William Townley','2669 Fleet St','Detroit','MI','UNITED STATES','48238-2727','(313) 571-1000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 09:14:13',0,NULL,3,1,1,1,NULL,' '),(4532,717214390015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','basiliss77','hex001@hotmail.com','Vasilis Sfiridakis','Alikianos','Chania','','GREECE','73005','00302821078395','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 10:16:23',0,NULL,3,1,3,1,NULL,'2m 灯架 1\r柔光伞 1\r云台 1RR815344769CN\r'),(4533,715820622015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','nikki_leigh18','nikkis_2006@hotmail.co.uk','nikki swimby','18 harpford drive breightmet','bolton','Greater Manchester','UNITED KINGDOM','bl2 6tw','01204370366','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 10:57:41',0,NULL,3,1,2,1,NULL,'1.6x3m 白色背景布 1 '),(4534,618185596001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','rohit1_blore','rohit.sharma2@in.unisys.com','Rohit Sharma','Flat # 804, Block-1C (Senswe), Divyasree Elan Homes<br>Opp. Total Mall, Sarjapur Road','BANGALORE','KA','INDIA','560035','09741513700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:18:31',0,NULL,3,1,2,1,NULL,' '),(4535,657609967002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jr123rj','jrada@volny.cz','Jiri Rada','Dysinska 9','Plzen','','CZECH REPUBLIC','312 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:31:46',0,NULL,3,1,3,1,NULL,'2m灯架  1\rB座 1\r柔光伞   1 RR815344715CN\r'),(4536,657610183002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',17.99,'hermeshine','revivevision','hadjivasilev@gmail.com','Andrey Hadjivasilev','Professor N. Mihailov 1','Sofia','','BULGARIA','1142','+359-888-736-822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:31:49',0,NULL,3,1,2,1,NULL,'防雨罩 1 '),(4537,618189575001,110534333190,'Green.L 77mm Neutral Density ND8 Filter 550D D90 5DII',1,'AE2314',8.2,'hermeshine','yannr5362','ron_kalezz@hotmail.com','Yann Romming','9.imp E Manet','Folschviller','Lorraine','FRANCE','57730','0387910159','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 11:34:05',0,NULL,3,1,2,1,NULL,'77mm ND8   1 '),(4538,618195530001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','alexbarket','barket@mail.ru','Alexey Barket','Perovskaya str. 22 k.2, 156','Moscow','','RUSSIAN FEDERATION','111398','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 12:10:19',0,NULL,3,1,5,1,NULL,'WT600    1 \rCP219487364CN\r'),(4539,717246871015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','fayem2880','linese2001@yahoo.com','faye manuel','31 crossfield road kitts green','birmingham','West Midlands','UNITED KINGDOM','b33 9hs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 12:21:36',0,NULL,8,1,17,0,NULL,' '),(4540,717247891015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',2,'AC3201',53.12,'hutongstore','fayem2880','linese2001@yahoo.com','faye manuel','31 crossfield road kitts green','birmingham','West Midlands','UNITED KINGDOM','b33 9hs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 12:23:45',0,NULL,3,1,4,1,NULL,'40×60 5合1 反光板 2个\r\r反光板支架  2个\rYW864615003CN\r'),(4541,657634866002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','imogenkimmel','imogenkimmel@yahoo.de','Imogen Kimmel','Tengstr.25','MÃ¼nchen','','GERMANY','80798','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 13:27:00',0,NULL,3,1,3,1,NULL,'肩架 1 \rRR815344928CN\r试着召回吧，客户改地址了\r新地址：\rImogen Kimmel\rc/o Mrs. Yeuth Sothary\rNo 5 street 410\rSangkat Boeung Trabek\rKhan Chamkamorn\rPhnom Penh\rCambodia\rRR843879022CN\r\r'),(4543,618216861001,110566018873,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',17.99,'hermeshine','sonthesun','hbms65@yahoo.ca','hazim aldujaili','2439 yeovil road','mississauga','ON','CANADA','l5j2g1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 13:36:22',0,NULL,3,1,2,1,NULL,'防雨罩 1 '),(4544,618219967001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','stoicov2p','cstoicov@iname.com','Chris Stoicovici','4330 Dufferin St.','Toronto','ON','CANADA','M3H 5R9','(416) 523-4482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 13:47:52',0,NULL,3,1,2,1,NULL,' '),(4546,618226779001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','masterphone75','protestand21@gmail.com','ANDRYIANAU SIARHEI','JUKOVA str<br>26 - kor 2 - 128','GOMEL','BLR','BELARUS','246029','(375) 293880382','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 14:14:50',0,NULL,3,1,5,1,NULL,' CP219487378CN\r'),(4547,618239885001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','luis3648','luis.jimenez.delgado@gmail.com','Luis Jimenez Delgado','Pablo Picasso, 3','Algeciras','AndalucÃ­a Ceuta y Melilla','SPAIN','11203','600516593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 15:01:56',0,NULL,3,1,2,1,NULL,' '),(4548,657673775002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','druitas','druitas@hotmail.com','Iskander Barrena','Aita Patxi Ugalde 12, 4ÂºC','Larrabetzu','PaÃ­s Vasco','SPAIN','48195','678654334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 15:35:06',0,NULL,3,1,2,1,NULL,''),(4549,657687100002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AO0024',40.99,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 16:15:16',0,NULL,8,1,17,0,NULL,' '),(4550,618265972001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','rccroker-2008','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 16:24:10',0,NULL,3,1,3,1,NULL,'黑白倒影板 各1\rCanon N4   1\rRR843879053CN\r\r'),(4551,618266064001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','shotov2007','shotov@mail.ru','Alexey Shotov','pr-t Gazety Pravda, d.62, kv.13','Dnepropetrovsk','','UKRAINE','49051','(+38)067-2954731','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 16:26:49',0,NULL,3,1,3,1,NULL,'绿色nikon标XL背心 1RR843879036CN\r\r'),(4552,657693099002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','cicomare','raniz@libero.it','Ranieri Costa','Via Ugo Betti, 69','Milano','MI','ITALY','20151','3387524483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 16:33:45',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座 1\r柔光伞 1RR815344724CN\r'),(4553,618281459001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','open331964','yossi888@gmail.com','Joseph Schwartz','mitzpe 34 apt 8','shoham','israel','ISRAEL','60850','972778103887','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 17:05:50',0,NULL,3,1,3,1,NULL,'黑色Canon标XXXL背心 1RR815344891CN\r薄的新款 黑\r'),(4554,717347283015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',7.5,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:09:52',0,NULL,8,1,17,0,NULL,NULL),(4555,717348781015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 17:09:52',0,NULL,8,1,17,0,NULL,NULL),(4556,703321119016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:09:51',0,NULL,8,1,17,0,NULL,' '),(4557,717346069015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 17:09:51',0,NULL,3,1,4,1,NULL,'背景架（白） 1.6m  1\r背景架（ 白 黑）  2m   1\r2m 灯架   2\r双灯头 欧标  2\r反光伞   2\r柔光伞   1\r115w 220v   4\r包   1\r80cm 2in1   1\rYW864489246CN\r\r\r'),(4558,618287080001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','magican4','trond@solem.nu','Trond Solem','Furuhaugvegen 35','N-7550 Hommelvik','','NORWAY','7550','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 17:21:37',0,NULL,3,1,3,1,NULL,'斜臂 1\rRR815344786CN\r发错了，补发一个2m 灯架  1  和上面的反光板支架一起\r'),(4559,703343545016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','handsomesteve','istvan@prenergia.hu','Ferenczi IstvÃ¡n','Ugron Gabor u. 28','Budapest','','HUNGARY','1118','0036302009172','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 17:47:35',0,NULL,3,1,3,1,NULL,' RR815344826CN\r'),(4560,653772041002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','unoqueno','maciatico@hotmail.com','David MaciÃ¡','Porta de la Morera, nÂº12. Museo del Palmeral','Elche','Comunidad Valenciana','SPAIN','03203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 17:53:29',0,NULL,3,1,2,1,NULL,'大号无字内胆包 1'),(4561,618300842001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','jb_chrome','john.b.poisson@maine.gov','John B Poisson','9 Prospect St','Livermore Falls','ME','UNITED STATES','04254-1518','(207) 287-7176','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 17:54:56',0,NULL,3,1,1,1,NULL,' '),(4562,717389378015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','jerzyk69-2008','jerzyk.j1@wp.pl','Jerzy Jerzmanowski','212 King Arthurs Walk Castelfields','Runcorn','Cheshire','UNITED KINGDOM','WA7 2NE','07709994966','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 18:22:55',0,NULL,3,1,2,1,NULL,' '),(4563,618325237001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','duncemedia','coffeelover1973@hotmail.com','Jason Rossi','87 Fort Sullivan Cir','Dalzell','SC','UNITED STATES','29040','','NoPaymentFailure','CheckoutComplete','Other','2011-01-11 18:50:57',0,NULL,3,1,3,1,NULL,'黑色Canon标 XL背心 1 RR815344888CN\r'),(4564,657752408002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','playtaf','playvision@ono.com','CRISTOBAL BELLES VIDAL','c/ SAN FEDERICO NÂº1 2Âºd','ALMASSORA','Comunidad Valenciana','SPAIN','12550','964563106','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 18:56:22',0,NULL,3,1,3,1,NULL,'肩架 1\rRR815344865CN'),(4565,717405644015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','piccies4j','juliesalam@jsalam.fsnet.co.uk','Omar Salam','12 cairnsmore way bourtreehill','irvine','North Ayrshire','UNITED KINGDOM','KA11 1EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 19:03:03',0,NULL,3,1,2,1,NULL,' '),(4566,618336403001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ferblues70','fernandomblues@gmail.com','David Fernando Miranda','San Miguel Bloque L#35<br>P.O.BOx 312 350','La Paz - Bolivia','La Paz','BOLIVIA','P.O 312 350','2 795762','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 19:14:00',0,NULL,3,1,3,1,NULL,'2m灯架 1 RR815344790CN\r'),(4567,717408752015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','guszty81','guszty23@freemail.hu','TamÃ¡s Hornyacsek','Fok u. 18.','KomÃ¡rom','','HUNGARY','2921','36702476923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 19:51:23',0,NULL,3,1,2,1,NULL,' 单灯头 2个  欧标'),(4568,717442898015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','tosan1980','tu_luna@hotmail.com','Anh Thu Nguyen Hoang','GrÃ¤sholmsvÃ¤gen 9D','SkÃ¤rholmen','','SWEDEN','12746','0046709273456','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-11 19:54:56',0,NULL,3,1,2,1,NULL,'77mmCanon镜头盖 2个 '),(4569,618356266001,110445658116,'New YONGNUO  LCD Timer Remote Control  for Nikon MC-DC1',1,'AA3219',48.9,'hermeshine','clibanq96','queyquep@earthlink.net','Cesar Queyquep','7837 Cape Charles Dr','Raleigh','NC','UNITED STATES','27617','(865) 712-7016','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 19:55:32',0,NULL,3,1,1,1,NULL,'MC-N2   1 '),(4570,618301999001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:39:24',0,NULL,8,1,17,0,NULL,' '),(4571,618301172001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',2.6,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:39:25',0,NULL,8,1,17,0,NULL,' '),(4572,618300898001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+356 79008973','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 20:39:26',0,NULL,3,1,3,1,NULL,'反光板支架 1\r72 NIKON镜头盖 1\r 大力夹球台    1 1RR815344857CN\r'),(4573,618379079001,110534333084,'Green.L 67mm Neutral Density ND4 Filter 67  550D 5DII',1,'AE2305',6.7,'hermeshine','delgado8610','dani_delgado_@hotmail.com','daniel delgado','urb. las torres 18. 4Âº A4','las palmas','Canarias','SPAIN','35010','686690929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 20:41:41',0,NULL,3,1,2,1,NULL,' '),(4574,717465275015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','ozlemyusuf','ozlemsakally@gmail.com','Ozlem Sakalli','4 Lowick Court','Newcastle Upon Tyne','Northumberland','UNITED KINGDOM','NE3 1YQ','07570031819','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 21:05:26',0,NULL,3,1,2,1,NULL,' 小号canon标内胆包 1'),(4575,657814571002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','lobis78','lobis22@hotmail.com','Rogerio Policarpo','688 Boston Post Rd E<br>Apt 105','Marlborough','MA','UNITED STATES','01752-3710','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-11 21:07:27',0,NULL,3,1,1,1,NULL,'CTR-301P 1拖2 '),(4576,657820176002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 21:14:53',0,NULL,3,1,3,1,NULL,'2m灯架+B座+柔光伞 1RR815344809CN\r'),(4577,618069686001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',6.68,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-11 21:16:36',0,NULL,3,1,2,1,NULL,'58mm 橡胶罩  1\r52mm 橡胶罩  1\r应该是漏发了58mm的,如果是再发一下 \r已经发货'),(4578,618138045001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',155.64,'hermeshine','lars3389','larsisachsen@hotmail.com','lars isachsen','bjerregaardsgate 22','oslo','N/A','NORWAY','0172','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 21:29:00',0,NULL,3,1,4,1,NULL,'2m灯架+云台+柔光伞 2套\rCTR-301P 1拖3\r大号无字内胆包 1\rSB-800肥皂盒 1\rlighting kit  $26\rYW864489202CN\r\r '),(4579,717500481015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','baldyfudgepacker7','andrew.hall137@ntlworld.com','andrew hall','41 county st, hollinwood','oldham','Lancashire','UNITED KINGDOM','OL8 3RN','07876213253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 21:37:10',0,NULL,3,1,3,1,NULL,'40×60 5合1反光板 1 RR815344843CN\r'),(4580,717515666015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','josh125897463','goodshipalbion@hotmail.com','Josh Taylor','253 Neasham Road','Darlington','Durham','UNITED KINGDOM','DL1 4DH','07817622183','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-11 22:03:50',0,NULL,3,1,2,1,NULL,'72mm CPL 1'),(4581,703499900016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','jeromeamb','jeromeamb@aol.com','Jerome RAOULT','310 rue Serval - Appt E03','DOUAI','Nord-Pas-de-Calais','FRANCE','59500','06.78.91.49.57','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-11 22:35:30',0,NULL,3,1,4,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚 欧标   2\r115w 220v   2\r包    1\rlighting kit   $30\rYW864489213CN\r'),(4582,618423783001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','masteret1234','eric_tardif1@hotmail.com','eric tardif','154 St-Germain Est<br>Apt. 18','Rimouski','QC','CANADA','G5L 1A8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 22:36:28',0,NULL,3,1,3,1,NULL,'肩架 1 RR815344945CN\r'),(4583,618429838001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','nmoh6141','ndmohrmann@gmail.com','Noel Mohrmann','180 West Brooks #3510','Norman','OK','UNITED STATES','73019','(405) 213-7949','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-11 22:53:21',0,NULL,3,1,1,1,NULL,' '),(4584,657861388002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','briz30','brijesh_aryal@hotmail.com','Brijesh Aryal','3/45-49 Gladstone Street<br>Kogarah','Sydney','New South Wales','AUSTRALIA','2217','0295872782','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 23:00:10',0,NULL,3,1,3,1,NULL,'SONY A1单肩包 1 RR843879291CN\r'),(4585,618439783001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',2,'AKT006',123,'hermeshine','smoofe33','swisschick33@hotmail.com','Michaela Preston','55 Church Street','Alliston','ON','CANADA','L9R1G9','(705) 434-9410','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-11 23:29:32',0,NULL,3,1,3,1,NULL,'10片装 58mm环架 2套\r\rRR843879725CN\r'),(4587,717564719015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','tommyv203','matthew.dixon4@ntlworld.com','Matthew Dixon','5 Whites Row','Kenilworth','Warwickshire','UNITED KINGDOM','cv8 1hw','01926777468','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 00:15:35',0,NULL,3,1,3,1,NULL,'2m灯架 1\r\rB座 1\r\r柔光伞 1 RR815344772CN\r'),(4588,618452018001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','1215zaphod','sgvanhoose@gmail.com','Steve Van Hoose','4149 Mount Alifan Pl<br>Unit B','San Diego','CA','UNITED STATES','92111-2837','(858) 277-3231','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 00:16:40',0,NULL,3,1,1,1,NULL,' '),(4590,618486922001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','sergeantcigar','sammy@derezes.com','Sammy Derezes','1916 NE 127th St','Seattle','WA','UNITED STATES','98125','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 02:42:35',0,NULL,3,1,1,1,NULL,'77mm 绿叶渐变灰 1 '),(4591,703584683016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',5,'AA1310',18.9,'hutongstore','lovelylovelygifts','anh.phan@iinet.net.au','Anh Phan','Suite 293 66 Kingsway','Glen Waverley','Victoria','AUSTRALIA','3150','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 03:06:17',0,NULL,3,1,3,1,NULL,'镜头笔 5支 RR815344905CN\r'),(4592,657931988002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','rebber1224','dots.are.stylish@gmail.com','Rebecca Lin','356 Greenfield Ave.','Toronto','ON','CANADA','M2N3E8','(416) 318-2919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 03:14:01',0,NULL,3,1,2,1,NULL,'小号canon标内胆包 1 '),(4593,618507180001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','sidebysidepartsforless','crashegordon@yahoo.com','Earl Gordon','269 N Keeneland Dr<br>Apt 2','Richmond','KY','UNITED STATES','40475','(859) 321-2485','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 04:10:46',0,NULL,3,1,1,1,NULL,' '),(4594,618514526001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','nightguest8826','night_guest2000@yahoo.com','Azer Aliyev','814 Oakcrest st','Iowa city','IA','UNITED STATES','52246-3417','(515) 520-7961','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 04:55:02',0,NULL,3,1,1,1,NULL,'镜头筒 xl   1 '),(4595,657962138002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','denybarboza','denyzinho@gmail.com','Deny Barboza','Rua Ver. Severo Ribeiro, 912','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 05:55:16',0,NULL,3,1,3,1,NULL,'50-70 通用卡口 塑料  1 RR843879331CN\r'),(4856,705539719016,260661734966,'NEW 55mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT043',15.2,'hutongstore','kahlanka','pieczarka1900@o2.pl','Kamila Mielczarek','27 Suffolk Avenue','Southampton','Hampshire','UNITED KINGDOM','so155ef','07874273879','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 01:59:04',0,NULL,3,1,3,1,NULL,'55mm CPL+ND8+ close-up+4 +Gradual grey RR843877097CN'),(4597,618535389001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','flyinslovak','svk1@windsurfing.sk','Patrik POLLAK','Jantarova 2','Kosice','Kosice','SLOVAK REPUBLIC','04001','421905785001','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 07:19:43',0,NULL,3,1,5,1,NULL,'717 135高   1 \rCP219487418CN\r'),(4598,618542478001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jorgengrytoyr','jorgen@grytoyr.no','Jørgen Grytøyr','Hertug Skules vei 6','GAMLE FREDRIKSTAD','','NORWAY','1639','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 08:08:16',0,NULL,3,1,3,1,NULL,'肩架  1 RR843879274CN\r'),(4599,618542049001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ildar2010','uldar@mail.ru','ildar abulhanov','Rabochaya, dom 7, kv. 17','ulyanovsk','ulyanovsk','RUSSIAN FEDERATION','432007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 08:10:22',0,NULL,3,1,3,1,NULL,'肩架  1 RR843879212CN\r'),(4600,657983494002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:23:25',0,NULL,8,1,17,0,NULL,' '),(4601,618543474001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','vitalmax2009','alfast@inbox.ru','Vitaly Maksimchuk','Narvskaya street 6-105','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690011','+79147077862','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:23:26',0,NULL,3,1,2,1,NULL,'ND8   1\rCPL   1 '),(4602,657988571002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ac9999ac','a_c9999@hotmail.com','choo anthony','blk 984c buangkok link #09-39 singapore','Singapore','','SINGAPORE','533984','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 08:45:08',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843879257CN\r'),(4604,618557087001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','2005audun','asjoeset@online.no','Audun Sjoeseth','Oevre Hylla 8','Glomfjord','','NORWAY','N-8160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 09:35:46',0,NULL,3,1,2,1,NULL,NULL),(4603,618553015001,110523102341,'77mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1309',2.6,'hermeshine','nitsum14','amfleica@gmail.com','Agustin Moreno Fernandez','c./ Jose Ignacio de Pineda, nº 5<br>Bloque 2, Bajo C','Jerez de la Frontera','Cadiz','SPAIN','11405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 09:12:14',0,NULL,3,1,2,1,NULL,NULL),(4605,657791002002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','numberone_kiev','sergey_pets@list.ru','Sergey Prokopets','Chokolovskiy Boulevard, 18, flat 42','Kiev','','UKRAINE','03186','+380967602992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 10:11:17',0,NULL,3,1,3,1,NULL,' RR843879305CN\r'),(4606,658010399002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','fkisicek','filipkisicek@yahoo.com','Filip Kišiček','Lipovnik 139','Klenovnik','','CROATIA','42244','+385989127807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 10:38:23',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖  canon   1 '),(4607,717725341015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','palabe-h','palabe61@gmail.com','László Papp','Dózsa György utca 15/A','Balatonfüred','','HUNGARY','8230','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 11:28:07',0,NULL,3,1,2,1,NULL,' '),(4608,654640082002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','indal77','saindal@gmail.com','S.A. Indal','Kirkeveien 200','Nesoddtangen','Akershus','NORWAY','1450','+4793699573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 11:41:59',0,NULL,8,1,17,0,NULL,''),(4609,615316898001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','indal77','saindal@gmail.com','S.A. Indal','Kirkeveien 200','Nesoddtangen','Akershus','NORWAY','1450','+4793699573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 11:41:59',0,NULL,3,1,4,1,NULL,'6662a    1\r倒影板  1\r\r tripod $18 \rYW864489176CN\r'),(4610,717734177015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','argirius','seunam@gmail.com','Andre Stavrakis','rue des Begonias 17','Rhode-Saint-Genese','','BELGIUM','1640','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 11:59:43',0,NULL,3,1,2,1,NULL,NULL),(4611,618591778001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','wangmarco','marcowang@gmail.com','Marco Wang','5135 Forest Sage Ln','Katy','TX','UNITED STATES','77494-5839','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 12:22:21',0,NULL,3,1,1,1,NULL,NULL),(4612,717746083015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','170jazmin','bobnield@aol.com','Robert Nield','5 Belle Vue Road','Exmouth','Devon','UNITED KINGDOM','EX8 3DR','01395279537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 12:41:52',0,NULL,3,1,2,1,NULL,'45w   2 '),(4613,658038691002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','malaseda02','pejiosisima@gmail.com','Lidia Esther Diaz Gil','Bateria de San Juan, 12','Las Palmas de G C','Canarias','SPAIN','35015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 12:47:15',0,NULL,3,1,3,1,NULL,'大力夹  4 RR843879288CN\r'),(4614,658045247002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','chickgirdoug2000','mike-odonnell@austin.rr.com','Mike O\'Donnell','6801 Beckett Rd<br>Unit 142L','Austin','TX','UNITED STATES','78749','(512) 895-2304','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 13:12:41',0,NULL,3,1,1,1,NULL,'肥皂盒  580ex   1 '),(4615,658045608002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','juancoffi','juan.coffi@gmail.com','Juan Carlos Coffi da Silva','Atlantida 232','Porto Alegre','Rio Grande do Sul','BRAZIL','91760150','555132497088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 13:14:22',0,NULL,8,1,17,0,NULL,NULL),(4616,658046246002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','juancoffi','juan.coffi@gmail.com','Juan Carlos Coffi da Silva','Atlantida 232','Porto Alegre','Rio Grande do Sul','BRAZIL','91760150','555132497088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 13:15:50',0,NULL,3,1,2,1,NULL,'67mm 天涯 nd8  1\r67mm 绿叶 cpl   1 '),(4617,717758490015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','dpspstewart','dan2452@hotmail.com.au','dan stewart','53 amaroo cres','Toormina','New South Wales','AUSTRALIA','2452','0266582803','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 13:22:46',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843879169CN\r'),(4619,658060151002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','jcruizduarte','jcruizduarte@msn.com','juan carlos ruiz duarte','C. Venecia 18','jerez de la frontera','Andalucía Ceuta y Melilla','SPAIN','11408','659978054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 14:07:13',0,NULL,3,1,2,1,NULL,NULL),(4620,618639804001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','jandoctor','avershov@gmail.com','Alexey Ershov','Zaharinskie dvoriki 1-1-184','Moscow','RU','RUSSIAN FEDERATION','117148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 15:21:55',0,NULL,3,1,2,1,NULL,NULL),(4622,618658410001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','iamtorpe','manuelhigueras@gmail.com','manuel higueras garcia','reina sofia, 10','los villares, jaen','Andalucía Ceuta y Melilla','SPAIN','23160','953323199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 16:22:53',0,NULL,3,1,2,1,NULL,'55mm 环架  1 '),(4623,658112357002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','kamomyete','dafeen@free.fr','Mlle Miozzo','8 b rue de reims','Paris','Ile-de-France','FRANCE','75013','0627611928','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 16:51:00',0,NULL,3,1,3,1,NULL,'115w220v   2 RR843879172CN\r'),(4624,703845742016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','sawber67','billkemmy@eircom.net','Bill Kemmy','Bishop\'s House Dublin Road','Carlow','Carlow','IRELAND','default','0872308053','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-12 18:19:47',0,NULL,3,1,4,1,NULL,'2mx3m 背景架 1\r3mx6m 绿色背景布  1\r2m 灯架   2\r50-70 棚  英标   2\r115w 220v 灯泡  2\r包   1\rlighting kit  $30 \rYW864489224CN\r'),(4625,618724134001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',4,'AC3301',58.24,'hermeshine','mystery_ghosttrain','anders_1@ukr.net','Andriy Yermak','Revutskogo 7, kv. 229','Kyiv','','UKRAINE','02091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 18:57:52',0,NULL,3,1,3,1,NULL,' RR843879345CN\r'),(4626,717925790015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','dplatakis','dplatakis@yahoo.com','Darius Platakis','34 Gleann Na Ri Druid Valley','Cabinteely','Dublin 18','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 19:23:32',0,NULL,3,1,2,1,NULL,'爵影无线 C3   1 '),(4627,618740244001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','flevofred','f.wilcke@hetnet.nl','Fred Wilcke','Kamp','Lelystad','','NETHERLANDS','8225GD','+31612867336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 19:29:36',0,NULL,3,1,2,1,NULL,NULL),(4628,658185142002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.9,'hermeshine','b2y_ni','b2y_ni@yahoo.com','Beethoven Awit , Jr.','108 N Varner St','Bonifay','FL','UNITED STATES','32425-2324','(850) 849-1080','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 19:29:49',0,NULL,3,1,1,1,NULL,'301p 一拖二   1 '),(4629,717932349015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','7500nigel','nigelchadwick@btinternet.com','Nigel Chadwick','17 Biggar Bank Road Walney','Barrow in Furness','Cumbria','UNITED KINGDOM','LA14 3YF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:33:48',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1 \r柔光伞   1RR843879243CN\r'),(4630,717934463015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',5.5,'hutongstore','bmonteiro05','bmonteiro@gmail.com','Elzbieta Karasinska','62 Upper Cheltenham Place','Bristol','Bristol','UNITED KINGDOM','BS65HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:36:52',0,NULL,3,1,2,1,NULL,'中号内胆包  canon  1 '),(4631,717941460015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dicksue16','dickrsfabs@googlemail.com','RICHARD TURNER','24 TWYFORD AVE','GREAT WAKERING','Essex','UNITED KINGDOM','SS30EU','07867544494','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 19:48:24',0,NULL,3,1,2,1,NULL,' '),(4632,618748134001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','wamper','martin.almasi@gmail.com','Zuzana Almasi Korenova','Borovianska 1994/49','Zvolen','Zvolen','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 19:50:47',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1 \rCP219487381CN'),(4633,658201152002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','romikos','roman_z@walla.co.il','roman oren','asaifan 2/31','ashdod','','ISRAEL','77430','0542571780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 19:57:53',0,NULL,3,1,2,1,NULL,NULL),(4634,618767929001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.48,'hermeshine','timandnat','natfrank@yahoo.com','Timothy M. Frank','230 Pershing Way','West Palm Beach','FL','UNITED STATES','33401-8036','(561) 820-0099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-12 20:26:49',0,NULL,3,1,1,1,NULL,NULL),(4635,658219451002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jiffemann','taulen@gmail.com','Jonny Taulen','Fagerliveien 28','Gjøvik','Oppland','NORWAY','2818','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 20:34:52',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843879230CN\r'),(4636,618535342001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','diveevo2009','divmult@gmail.com','Pavel Sushkov','50 Sitnova street','Diveevo vilage','Nizhegorodskaya oblast','RUSSIAN FEDERATION','607320','79030582922','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 20:38:21',0,NULL,3,1,5,1,NULL,'2mx3m背景架  1 \rCP219487395CN\r'),(4637,618770672001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','dkdiaz','davidkarldiaz@hotmail.com','David Diaz','9582 Roan Fields Pl','elk grove','CA','UNITED STATES','95624-6064','(916) 647-4270','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 21:05:33',0,NULL,3,1,1,1,NULL,NULL),(4638,717991448015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','docsharp66','sharp-andrew2@sky.com','Andrew Sharp','8 Beaumaris Road Connah\'s Quay','Deeside','Flintshire','UNITED KINGDOM','CH5 4 YA','01244819917','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-12 21:10:20',0,NULL,3,1,2,1,NULL,'可以发了 '),(4639,717996499015,250600489459,'New Hairlight photostudio boom arm ',2,'AE3101',41.8,'hutongstore','raijakee','raimond@harta.ee','RAIMOND JAKOBS','VARSAALLIKA 36','TALLINN','','ESTONIA','12013','(372) 600-6508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 21:21:45',0,NULL,3,1,3,1,NULL,'斜臂   2 RR843879226CN\r'),(4641,658253794002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','bobbyddixon117','bobbyddixon@hotmail.com','Bobby D. Dixon','1617 Country Meadows Dr','Sevierville','TN','UNITED STATES','37862-9335','(865) 441-1859','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-12 21:48:36',0,NULL,3,1,1,1,NULL,NULL),(4642,658259951002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pawee.th','pond79@hotmail.com','Pawee Lorsuwannarat','14 Jompol Rd.','Amphur Muang','Nakhon Ratchasima','THAILAND','30000','6644267671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 22:04:20',0,NULL,3,1,2,1,NULL,NULL),(4643,703979766016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','pmangan1234','pmangan@oceanfree.net','Patrick Mangan','The Glebe Ramelton Road','Letterkenny','Donegal','IRELAND','default','0749124012','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-12 22:19:14',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4644,618781938001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','zathos123','xathorm@gmail.com','Rubén López Reina','Av. Conselheiro Fernando de Sousa, 25, 4ºA','Lisbon','Lisbon','PORTUGAL','1070','00351913944272','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 22:28:19',0,NULL,3,1,4,1,NULL,'2mx3m 背景架   1\rYW864489666CN\r \r这个燕文拿走了，但是燕文815（李月红）说邮编不对，我写信问了，等答复。\r重打'),(4645,658282494002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','hs*88','lamhs2@mcmaster.ca','Hoishing Lam','Apt#2107, 100 Main Street East,','Hamilton','ON','CANADA','L8N3W4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-12 23:04:41',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(4646,658284240002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','jertui','ville.koivumaki@tut.fi','Ville Koivumäki','Insinöörinkatu 60 b 107','Tampere','Länsi-Suomen lääni','FINLAND','33270','040 7780956','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 23:10:31',0,NULL,3,1,4,1,NULL,'ballhead  $20 \rYW864489180CN\r'),(4647,658289262002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','bvdq68','bvdq68@yahoo.ca','Belron Canada','a/s Pierre-Paul Blanchette<br>8288 Pie-Ix Blvd','Montreal','QC','CANADA','H1Z 3T6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-12 23:27:00',0,NULL,3,1,3,1,NULL,'sony A1 单肩包   1 RR843879265CN\r'),(4648,618526883001,110597207686,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',150,'hermeshine','rouxbynne04','rouxbynne.m@optusnet.com.au','Rubin Miller','10 Robinson Street','Croydon','Victoria','AUSTRALIA','3136','0387113546','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-12 23:29:43',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rlight stand  $20\rYW864489191CN\r'),(4649,704034609016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','alanroseman','alanroseman@comcast.net','Alan M. Roseman','6 Old Pine St','Rehoboth','MA','UNITED STATES','02769-1421','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 00:57:15',0,NULL,3,1,1,1,NULL,NULL),(4650,658314915002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 01:00:25',0,NULL,3,1,5,1,NULL,'红头灯   1\r800w 110v  灯泡  1\rCP219487435CN\r'),(4652,658321662002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','marymom1220','aadams38975@everestkc.net','Alan Adams','12612 W 121st Ter','Overland Park','KS','UNITED STATES','66213','(913) 897-3721','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 01:24:15',0,NULL,3,1,1,1,NULL,'摄影背心 canon xxxl  老款  1 '),(4653,658337324002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','mona123mona','marandym@yahoo.com','mona marandy','21441 providencia st','woodland hills','CA','UNITED STATES','91364','(818) 676-0840','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 02:20:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r单灯头  1\r反光伞   1 RR843878185CN\r'),(4654,618288573001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','magican4','trond@solem.nu','Trond Solem','Furuhaugvegen 35','N-7550 Hommelvik','','NORWAY','7550','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 02:39:34',0,NULL,3,1,3,1,NULL,'2m灯架   1\r反光板支架   1 RR843879186CN\r'),(4655,658352996002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',8.69,'hermeshine','dirge168','kyk1082@gmail.com','Ken Kee','Blk 132 Bedok Reservoir Road #09-1257<br>(S)470132','default','','SINGAPORE','470132','6582337483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 03:23:19',0,NULL,3,1,11,1,NULL,'中号内胆包 nikon   1 \r'),(4656,658359785002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','zhengkai136','zhengkai136@hotmail.com','Kai Zheng','11 Farina Millway','North York','ON','CANADA','M2L1S2','(416) 388-1362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 03:57:59',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4657,618905421001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 04:13:06',0,NULL,8,1,17,0,NULL,NULL),(4658,618905275001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 04:13:07',0,NULL,3,1,3,1,NULL,'反光板支架   1\r大力夹   2 RR843879190CN\r'),(4659,658367013002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','us.chotikorn','us.chotikorn@gmail.com','Chotikorn Buranarachada','291 Martin Luther King Jr Blvd','Newark','NJ','UNITED STATES','07102-2012','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 04:29:11',0,NULL,3,1,1,1,NULL,'广角托架  1 '),(4660,618928513001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','okidoky1','onetwothreemike@gmail.com','Michael Pot','25 Kolo Drive<br>RR 4','Ashton','ON','CANADA','K0A1B0','(613) 257-5584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 06:42:18',0,NULL,8,1,17,0,NULL,' '),(4661,618930487001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','okidoky1','onetwothreemike@gmail.com','Michael Pot','25 Kolo Drive<br>RR 4','Ashton','ON','CANADA','K0A1B0','(613) 257-5584','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 06:57:06',0,NULL,3,1,2,1,NULL,'这票应该是2个55橡胶罩， 发了几个？ \r发了两个    王'),(4662,618934508001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','guru_lurks','mrcroft@gmail.com','David Croft','40 Gray St.','Woonona','New South Wales','AUSTRALIA','2517','0242849228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 07:27:01',0,NULL,3,1,2,1,NULL,'大力夹球台  2 '),(4663,704133915016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',5.5,'hutongstore','paranoid73','seventy_three@hotmail.co.uk','Karl Fennell','Mill Cottage Norwich Road','Chedgrave','Norwich','UNITED KINGDOM','NR14 6ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 08:16:55',0,NULL,3,1,2,1,NULL,'中号内胆包 nikon   1 '),(4664,618953870001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','randop84123','randop84@hotmail.com','Rando Pitkäärt','Pikk 76-5','Tartu','Tartumaa','ESTONIA','50603','+3725220702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:27:52',0,NULL,3,1,2,1,NULL,' '),(4665,618953772001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:18',0,NULL,8,1,17,0,NULL,NULL),(4666,658409313002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:18',0,NULL,8,1,17,0,NULL,NULL),(4667,618948573001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1309',7.4,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:19',0,NULL,8,1,17,0,NULL,NULL),(4668,618951652001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','katechiangmai','katerous@hotmail.com','Rermphant Promnuchanont','Pair Wedding Studio   158/4  ChiangMai - Lamphang Rd.<br>Tambon PaThun    Aumphur Muang','ChiangMai','Thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 09:31:19',0,NULL,3,1,3,1,NULL,'77mm 镜头盖 canon   3\r58mm 镜头盖  canon  1\r430ex 肥皂盒   1\r渐变灰  1\r77mm 环架   1 RR843879504CN\r'),(4669,704151575016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','dblenk89','domen.blenkus@gmail.com','Domen Blenkuš','Ulica prvoborcev 5','Ljubljana','Ljubljana','SLOVENIA','1131','+386 31 307060','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 09:39:17',0,NULL,3,1,3,1,NULL,'sf18-canon  1 RR843879495CN\r'),(4670,704153271016,260675927807,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',21,'hutongstore','niko-nik1967','mayer_nk@mail.ru','Nikolay Mayer','Semafornaya 189 \"b\"  - 30','Krasnoyarsk','','RUSSIAN FEDERATION','660012','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 09:45:32',0,NULL,3,1,3,1,NULL,'sony a1 单肩包  1 RR843879420CN\r'),(4671,718227697015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','capnemo101','credlands@googlemail.com','Peter Credland','Island Cottage Island Road','Garthorpe','Lincolnshire','UNITED KINGDOM','DN17 4AA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 11:19:42',0,NULL,3,1,2,1,NULL,'爵影无线c3   1 '),(4672,618978855001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','pixz12','susanefong@hotmail.com','Susan Zamolo','4 Driffield Street<br>Anula','Darwin','Northern Territory','AUSTRALIA','0812','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 11:30:19',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂  1 \rYW864489272CN\r'),(4673,704184357016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','goborut','borut.gorenjak@gmail.com','Borut Gorenjak','Ulica Staneta Severja 15','Maribor','','SLOVENIA','2000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 11:46:18',0,NULL,3,1,3,1,NULL,'sf18-canon  1  RR815344962CN\r'),(4674,718240719015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',25.98,'hutongstore','beautch173','beautchbailey@hotmail.com','steven martin bailey','41 elgar drive maltby','nr rotherham','South Yorkshire','UNITED KINGDOM','s66 7qe','07984607679','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 12:11:24',0,NULL,3,1,3,1,NULL,'717快装板  2 RR843879464CN\r'),(4675,718248620015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','daitaylor54','daitaylor@live.co.uk','David  TAYLOR','19 BELLAMY\'S COURT ABBOTSHADE ROAD','LONDON','London','UNITED KINGDOM','SE16 5RF','02072376071','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 12:33:24',0,NULL,3,1,2,1,NULL,' '),(4676,658458775002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 12:52:01',0,NULL,3,1,3,1,NULL,'50-70 塑料卡口棚   2 RR843879376CN\r'),(4677,658469877002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alex17wiper','alex17wiper@hotmail.com','Alexandre Martin','7-A rue Corno','St-Basile','NB','CANADA','e7c 1p6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 13:42:33',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879455CN\r'),(4678,619010805001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','larbyrne','lar_byrne@hotmail.com','Lar byrne','104 saunders lane','Rathnew','Wicklow','IRELAND','00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 13:44:35',0,NULL,3,1,2,1,NULL,'小号镜头筒  1 '),(4679,618957215001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','philosomatographer','dawidl@solms.co.za','Dawid Loubser','113 Barry Hertzog avenue<br>Emmarentia','Johannesburg','Gauteng','SOUTH AFRICA','2029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 14:19:24',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843879478CN\r'),(4680,618930958001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',125.05,'hermeshine','voux','byronwee@gmail.com','Wee Eng Peen','24 Jalan Daud','Singapore','','SINGAPORE','419567','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:20:27',0,NULL,3,1,10,1,NULL,'c型大力夹  1\r大力夹 球台  1\r斜臂  2\r1.6x2.1 背景布 2 （ 白+黑）\r渐变灰  1\rND8  1\r渐变橙   1\r72mm 环架  1\r递四方新加坡专线\r '),(4681,658489192002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michele88catena','michelecatena@hotmail.it','Michele Catena','via montefanese 79','Osimo','AN','ITALY','60027','349-4516530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:47:59',0,NULL,3,1,2,1,NULL,' '),(4682,657659435002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sfwangphg','sfwang1973@yahoo.com.tw','WANG SWEE FOCK','5,LRG PELINDUNG PANTAI 9<br>TMN PELINDUNG PANTAI','BESERAH,KUANTAN,','PAHANG','MALAYSIA','26100','019-9457999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 14:57:07',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座  1\r柔光伞 1 RR815345000CN\r'),(4683,619032021001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','terjefro','tfrostad@gmail.com','Terje Frostad','Kuhaugen 47','Melhus','ST','NORWAY','N7224','+4793098048','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 15:00:36',0,NULL,3,1,3,1,NULL,'nikon标黑色 XL背心\r\r新款RR815344980CN\r发错了，应该是老款的（看客户反映吧）\r'),(4684,619044929001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo Street<br>64-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','8-902-7918020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 15:45:58',0,NULL,3,1,3,1,NULL,'肩架 1 RR815344914CN\r'),(4685,718317569015,250599414645,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'AE2314',4.8,'hutongstore','klum8997','lumsdenkevin@ymail.com','Kevin Lumsden','49 Standhouse Lawns','Newbridge','Kildare','IRELAND','nil','045438375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 15:51:43',0,NULL,3,1,2,1,NULL,' '),(4686,658512234002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','bjslatham','bobbie.latham@cox.net','Bobbie Latham','8225 Crown Court Road','Alexandria','VA','UNITED STATES','22308','','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 15:56:55',0,NULL,3,1,1,1,NULL,'无字XL背心 冬夏'),(4687,658513619002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','williams_43_1728','billy_corleone@hotmail.com','Guillermo Blasco Jiménez','Paseo.ZonaFranca 145 escalera A 6º 1ª','Barcelona','Cataluña','SPAIN','08038','933328883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:03:35',0,NULL,3,1,4,1,NULL,'\rYW864489261CN'),(4688,658522167002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','dimans89','dimans@i.ua','Dmytro Ganzhus','Danyla Galytskogo 9/206','Rivne','','UKRAINE','33027','380985253027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:25:44',0,NULL,3,1,2,1,NULL,''),(4689,658533431002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','paul780','ptrawick37@gmail.com','Paul Trawick','Site 8, Lot 8,<br>RR1','Westerose','AB','CANADA','T0C 2V0','(780) 497-0005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 16:57:25',0,NULL,3,1,2,1,NULL,' 小号灰卡 1'),(4691,718361351015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','sakisti','a_tsivas@hotmail.com','ATHANASIOS TSIVAS','MITROPOLITOU IOAKEIM 6','ALEXANDROUPOLI','EVROS','GREECE','68100','00302551026440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-13 17:28:37',0,NULL,3,1,2,1,NULL,'【 '),(4692,619099020001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','suziecutiepatootie','robnsuzie@earthlink.net','Suzanna M. Swift','8206 Blairton Rd','Springfield','VA','UNITED STATES','22152','(925) 408-4473','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 18:08:30',0,NULL,3,1,1,1,NULL,' '),(4694,619104143001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vladimir_17','r17studio@yahoo.com','Vladimir Eskin','Anilevich st. 15/16','Raanana','Hasharon','ISRAEL','43321','972-547972118','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 18:26:35',0,NULL,3,1,3,1,NULL,'反光板支架 1 RR843879393CN\r'),(4695,619108858001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','botjeti','doordouwers@hotmail.com','Andy Bothof','kloosterstraat 4','Venlo','','NETHERLANDS','5921HC','0628971293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 18:31:16',0,NULL,3,1,4,1,NULL,'3m×6m 白色背景布\rYW864489283CN\r '),(4696,658141863002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','azat-juni','azat.juni@gmail.com','Azat Shakirzyanov','Bigicheva<br>d.3 kv.44','Kazan','Tatarstan','RUSSIAN FEDERATION','420100','+79033887866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 18:32:15',0,NULL,3,1,3,1,NULL,'2m灯架 1\rB座 1\r柔光伞 1 RR815344993CN\r'),(4697,718397018015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','v27xxx','mini_v69@hotmail.com','Vanessa Nguyen','83 Lesney Gardens','Rochford','Essex','UNITED KINGDOM','SS4 1TZ','07769171785','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 18:41:32',0,NULL,3,1,3,1,NULL,'斜臂1RR843879362CN\r'),(4698,658587538002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','evri4mann','evri4man@gmail.com','Mikhlyayev Yevgeniy','Respubliki 39/4-82','Temirtau','Karagandinskaya obl','KAZAKHSTAN','101400','87053002969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 19:03:31',0,NULL,3,1,2,1,NULL,' '),(4699,619134482001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','kozlik5lion','igor.kozel@gmail.com','Mr Igor Kozel','Svatoplukovo 210','Nitra','Nitra','SLOVAK REPUBLIC','95116','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 19:23:59',0,NULL,3,1,3,1,NULL,'反光板支架 1 RR815344976CN\r'),(4700,619132924001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 20:08:06',0,NULL,3,1,2,1,NULL,'小号灰卡 1 '),(4701,619176419001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','bobdrake','drbobdrake@gmail.com','Robert F. Drake','3489 Fort Independence St<br>Apt 7D','Bronx','NY','UNITED STATES','10463','(718) 601-8735','NoPaymentFailure','CheckoutComplete','Other','2011-01-13 20:52:08',0,NULL,3,1,1,1,NULL,' '),(4702,619195866001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','chris1gina','chris1gina@peoplepc.com','christopher cordaro','24 Harding Dr','new rochelle','NY','UNITED STATES','10801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 21:38:39',0,NULL,3,1,1,1,NULL,' '),(4703,619197123001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','gavnshez','gavin.mca@gmail.com','Gavin & Sheree McArthur','5 Narambi Street','Warana','Queensland','AUSTRALIA','4575','0408187789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 21:42:02',0,NULL,3,1,4,1,NULL,' 背景架2m（黑白） 1\rYW864489493CN\r'),(4704,619212629001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','tag1967andrey','tag1967@mail.ru','Andrey Tolokov','Ak.Glushkova 10/5','Volodymyr-Volynskiy','Volynska','UKRAINE','44700','+380637270683','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-13 22:24:45',0,NULL,3,1,5,1,NULL,'背景架2m（黑白）  1\rCP219487789CN\r'),(4705,718545539015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','jekyll_1001','steven.heide@blueyonder.co.uk','Steven Heide','7 Stamfordham Close','Wallsend','Tyne and Wear','UNITED KINGDOM','NE288ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:14:40',0,NULL,3,1,2,1,NULL,NULL),(4706,658700955002,120601698401,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','scatteredpictures','scatteredpictures@msn.com','John Malott','630 Cypress Dr','Prescott','AZ','UNITED STATES','86303','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-13 23:30:57',0,NULL,3,1,1,1,NULL,' '),(4707,658701370002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','ebit4e2009','ebit4e@hotmail.com','Hungyi Lai','397/122 Regent Home Condo Building B<br>Soi Phongpetniwej , Leapkhongprapa Road Jatujuk','Bangkok','Bangkok','THAILAND','10900','+66805592088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-13 23:32:49',0,NULL,3,1,2,1,NULL,'渐变灰  1 '),(4708,718553201015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','020pinstripethug','pinstripethug@googlemail.com','Charles Kilkenny','15 Shepherd House, York Way,','London','London','UNITED KINGDOM','N7 9QB','02076078654','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:37:00',0,NULL,3,1,2,1,NULL,'热靴盖 1'),(4709,718560761015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3204',2.98,'hutongstore','fingermouse1911','fingermouse1911@hotmail.com','Simon Gill','22 Strickland Street','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU3 4AQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-13 23:59:54',0,NULL,3,1,2,1,NULL,' RS-C3 1'),(4710,658710186002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vtlively09','vtlively@gmail.com','Vitaliy Golobotchansky','Mishmar HaYarden str. 5/3','Ramat Gan','','ISRAEL','52271','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 00:05:05',0,NULL,3,1,2,1,NULL,' '),(4712,619261249001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','volcomscout822','cjhoken@yahoo.com','Chris Hokenson','6265 Meadow Crest Drive','La Mesa','CA','UNITED STATES','91942','(619) 589-6129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 01:17:46',0,NULL,3,1,1,1,NULL,' '),(4713,658739008002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 01:53:36',0,NULL,8,1,17,0,NULL,''),(4714,658743296002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','delgado8610','dani_delgado_@hotmail.com','daniel delgado','urb. las torres 18. 4º A4','las palmas','Canarias','SPAIN','35010','686690929','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 02:10:23',0,NULL,3,1,4,1,NULL,' YW864489250CN\r'),(4715,619276554001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','jlpoletti','jabespoletti@terra.com.br','Jabes Levi Poletti','Rua 8A nº 828 - Vila Nova','Rio Claro','São Paulo','BRAZIL','13506544','(55-19) 3524-1208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:19:49',0,NULL,3,1,2,1,NULL,'单灯头 2 \r没发欧标吧， 等客户反映'),(4716,619278777001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','dvbxu','dan.villanueva@oracle.com','Dan Villanueva','12 Oakhill Dr','Castle Hill','New South Wales','AUSTRALIA','2154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:38:21',0,NULL,3,1,2,1,NULL,'小号灰卡 1 '),(4717,619284396001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 02:51:04',0,NULL,8,1,17,0,NULL,''),(4718,658772845002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','alexanderowl09','kaliv@bk.ru','Alexander Kachan','Margelova<br>354-57','Omsk','Omskaya','RUSSIAN FEDERATION','644025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 04:11:52',0,NULL,3,1,3,1,NULL,' RR843879402CN'),(4719,619312432001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','chompachompin','orbemax@gmail.com','Adrian Ramirez','La Villa 2012<br>Campo de Polo Chapalita','Zapopan','Jalisco','MEXICO','45050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 05:20:00',0,NULL,3,1,3,1,NULL,' \rRR843879433CN\r'),(4720,718293801015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',88.83,'hutongstore','macchia1960','macchia60@hotmail.com','MASSIMO CHIACCHIARO','VIA FORNILLI, N. 86','CAPACCIO','SA','ITALY','84047','3333091082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 08:17:44',0,NULL,3,1,4,1,NULL,'50cm棚 1\r4合1灯头 1\r镜头笔 1\r斜臂 1\r2m灯架 1\r50×70棚 1\r115W  220v灯 1\r欧标转换器头 1\r\r\r\r'),(4721,619343428001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','phoenixsoaring','phoenixsoaring2008@gmail.com','Glen Chin','8778 24th Ave','Brooklyn','NY','UNITED STATES','11214','(646) 807-8182','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 08:41:04',0,NULL,3,1,1,1,NULL,' '),(4722,618184518001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','ferokabat','ferokabat@pro-com.sk','frantisek kabat','hostovce 34','hostovce','slovakia','SLOVAK REPUBLIC','951 91','00421 905 664 025','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 08:48:22',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878265CN\r'),(4724,658817299002,120531377860,'JueYing Lambency Flash Diffuser for 430EX F36AM',1,'AB3308',22,'hermeshine','2pinguelos','jvalgon@telefonica.net','Juan pedro valdes gonzález','Calle Achaman, 63','Santa Cruz de Tenerife','Canarias','SPAIN','38111','922686464','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 08:57:51',0,NULL,3,1,3,1,NULL,'碗罩  P2   1 RR843878424CN\r'),(4725,619346403001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','morpheus_t','morpheus.dt@gmail.com','Morpheus Believer','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:05:15',0,NULL,8,1,17,0,NULL,NULL),(4726,619346843001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','morpheus_t','morpheus.dt@gmail.com','Morpheus Believer','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 09:05:15',0,NULL,3,1,8,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r双灯头  欧标  2\r柔光伞  2\r45w   4\r110cm 5in 1  反光板  1\r包   1\r算算看吧\r申报 $60\rCP219487761CN\r\r '),(4727,658819665002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','caposaure','capcav@neuf.fr','Gilles Bangratz','8 rue du moulin','HILSENHEIM','Alsace','FRANCE','67600','0388859493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:11:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878407CN\r\\'),(4728,658829239002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','erik_efv','erik@u2us.nl','Erik Vries','Stellingmolenstraat 56','Culemborg','GL','NETHERLANDS','4105 XG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 09:58:53',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1  RR843878194CN\r'),(4729,619386989001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','sortjensen','jannicksort@hotmail.com','Jannick Jensen','43 Sycamore, Trimbleston<br>Goatstown Road','Clonskeagh','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:12:35',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(4730,619389187001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','tom_dror','tomdror155@walla.com','Tom Dror','David Elazar<br>77','Holon','ID','ISRAEL','58558','03-5595303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:25:11',0,NULL,3,1,3,1,NULL,'110cm 5in1  反光板  1 RR843878490CN\r'),(4731,658864087002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:33:58',0,NULL,8,1,17,0,NULL,''),(4732,658864678002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','fali_fribi','fali_ibi@hotmail.com','Rafael Girón','c/marques de mondejar 19 - 5ºB','granada','Andalucía Ceuta y Melilla','SPAIN','18004','958262947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:36:05',0,NULL,3,1,3,1,NULL,'50-70 柔光箱   塑料卡口  1 RR843878472CN\r'),(4733,618218535001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',72.72,'hermeshine','sukasurf','sukatechnologies@gmail.com','Cathal Furey','138 The Waterside Apts<br>Ringsend Road','Dublin 4','Dublin','IRELAND','4','0868100148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:38:21',0,NULL,3,1,3,1,NULL,'肩架  1\r67mm 镜头盖  canon  1\r中号镜头筒   1\r小号镜头筒    2\rLenspen  1\r大号内胆包  canon  1RR843878225CN\r\r\r\r\r '),(4734,619395996001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3305',18,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:48:35',0,NULL,3,1,3,1,NULL,'EW-73B   2 \r67mm uv   5 RR843878628CN\r'),(4735,658868151002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 12:53:13',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(4736,617884242001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','thecrow5msr','agrogin@nycap.rr.com','Adam Grogin','1095c central ave','albany','NY','UNITED STATES','12205','','NoPaymentFailure','CheckoutComplete','Other','2011-01-14 13:10:07',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r斜臂  1 \rYW864489482CN\r'),(4737,619408439001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','chitalina','denisesaura@gmail.com','Jason Silva','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:35:54',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂  1 RR843878336CN\r'),(4738,658749989002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','gegapm2008','gegapm@hotmail.com','Rolando Villaroel','Curicó # 380<br>Departamento 212','Santiago','Chile','CHILE','8330145','0056989411899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 13:44:01',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4739,619017294001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','stix_bizz','steven.pribilinskiy@gmail.com','Steven Pribilinskij','Generala Petrova str., 10/56','Mukachevo','Zakarpatye','UKRAINE','89600','380509667377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:34:11',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878282CN\r'),(4740,658880082002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','shabshay','shabshay@hotmail.com','Pavel Shabshay','Ha-Tizmoret 26/6','Rishon Le-Zion','','ISRAEL','75562','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 13:34:38',0,NULL,3,1,3,1,NULL,' RR843878509CN\r'),(4741,718783110015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','leanneoliewright','leanne_nicole_wright@hotmail.co.uk','Leanne Wright','Dunston House Pump Lane','Fenton','Nottinghamshire','UNITED KINGDOM','NG23 5DF','01476408316','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 14:19:19',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878203CN\r'),(4742,658894729002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','mikewest1977','mikewest13@hotmail.com','mike west','1214 tredmore dr','mississauga','ON','CANADA','l5j 3v3','(416) 436-8494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 14:23:55',0,NULL,3,1,2,1,NULL,'800w 110v   2 '),(4743,658907236002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','blake_bilbo','ikerblake@gmail.com','iker lago','federico garcia lorca nº2 Bj. H','sestao','País Vasco','SPAIN','48910','686326820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:06:07',0,NULL,3,1,4,1,NULL,'tripod $20 \rYW864489471CN\r'),(4744,658755117002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:16:18',0,NULL,3,1,5,1,NULL,'红头灯×1  欧标转美标的头 2个\r800w  110V 灯泡×3\r800w 220v 灯泡   5\r\rCP219487792CN\r'),(4745,658908512002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:08',0,NULL,8,1,17,0,NULL,NULL),(4746,619434906001,110407881132,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:11',0,NULL,8,1,17,0,NULL,NULL),(4747,619434922001,110464610934,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',5.6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:24',0,NULL,8,1,17,0,NULL,NULL),(4748,658908526002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:25',0,NULL,8,1,17,0,NULL,NULL),(4749,619434978001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',2,'AA3314',13,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:17:38',0,NULL,3,1,3,1,NULL,'77mm  cpl   2\r72mm  cpl   1\r55mm cpl    1\r52mm cpl   1\r67mm cpl   1 RR843878591CN\r'),(4750,658916263002,120601698198,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','teddbg','chazi@abv.bg','Teodor Georgiev','13 block, floor 6, apt.6C<br>Studentski grad distr.','Sofia','Bulgaria','BULGARIA','1700','(359)878659354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 15:30:07',0,NULL,3,1,2,1,NULL,'52mm 环架  1 '),(4752,718826129015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:46',0,NULL,8,1,17,0,NULL,NULL),(4753,704755942016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',2.8,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:46',0,NULL,8,1,17,0,NULL,NULL),(4754,718825536015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:47',0,NULL,8,1,17,0,NULL,NULL),(4755,718824432015,250635198378,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.16,'hutongstore','dezm0nnd','demonn-90@yandex.ru','Ptitsyn Dmitry','60 let SSSR st. 5/43','Skovorodino','Amurskaya oblast\'','RUSSIAN FEDERATION','676014','+7 924 144 1226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 16:28:47',0,NULL,3,1,3,1,NULL,'58mm-canon 反接环  1\r52-58mm 双阳环   1\r430肥皂盒   1\r58mm cpl    1 RR843876281CN\r'),(4756,658948001002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','-jm1-','juergen_m@web.de','Juergen Meier','K.-Schumacher-Str. 20','Mitterteich','','GERMANY','95666','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 16:56:05',0,NULL,3,1,3,1,NULL,'斜臂    1 RR843878322CN\r'),(4758,704812118016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','brukner3571','brukner@seznam.cz','Vladimir Brukner','Stritez 91','Trebic','Vysocina','CZECH REPUBLIC','67401','00420721873760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 18:05:58',0,NULL,3,1,2,1,NULL,'红外无线 olympus  1 '),(4759,619512842001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','danceman_vvs','va98saf@gmail.com','Yuganov Konstantin','51\"A\" Sony Krivoy street #6','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454048','(514) 804-3839','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 18:40:26',0,NULL,3,1,3,1,NULL,'tripod $15 RR843878319CN\r'),(4760,718912535015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','manur2009','manuel_rivas@vodafone.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-14 18:57:11',0,NULL,3,1,4,1,NULL,'背景架（ 白 黑)   1  2m\rbackground support $18 \rYW864489460CN\r'),(4761,619523863001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','little.beef','m@manzin.it','Massimiliano Manzin','Via Giulia 56','Trieste','TS','ITALY','34126','040-575233','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 19:01:32',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rYW864489456CN\r'),(4762,619524368001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','justinvs','justinvs@sff.net','Justin Stanchfield','62920 Mt Highway 43<br>.','Wise River','MT','UNITED STATES','59762-9708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 19:02:08',0,NULL,3,1,1,1,NULL,NULL),(4763,718915001015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','killachase01','bobmoyler@yahoo.co.uk','bob moyler','34 orford street','LIVERPOOL','Merseyside','UNITED KINGDOM','L15 8HX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 19:04:29',0,NULL,3,1,2,1,NULL,'717快装板  1 '),(4764,659006109002,120560203032,'58mm Lens lenscap for Canon Combined shipping discounts',1,'AA1301',2.6,'hermeshine','jorgevalle86-2008','jorgevalle86@yahoo.com','JORGE VALLE DEL CARPIO','Jr. Huallaga 920','Lima','Lima','PERU','Lima1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 19:12:22',0,NULL,8,1,17,0,NULL,NULL),(4765,619531171001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','jorgevalle86-2008','jorgevalle86@yahoo.com','JORGE VALLE DEL CARPIO','Jr. Huallaga 920','Lima','Lima','PERU','Lima1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 19:15:47',0,NULL,3,1,3,1,'RA117727909CN\r ','新款内胆包  1\r58mm 镜头盖  canon  1 \r第一次没收到，再发一次'),(4766,619534839001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','karrfan','christopher@rogueshollow.net','Christopher Brielmaier','62 Broadway St','Kenton','OH','UNITED STATES','43326','(614) 408-3137','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-14 19:23:33',0,NULL,3,1,4,1,NULL,'红头灯   1 欧标转美标的头\r800w 110v  1 \rYW864489445CN\r'),(4767,659026473002,120568891628,'Male-Male 52mm-58mm Macro Combined shipping discounts',2,'AA1212',7.1,'hermeshine','dualiteis','crolke@dualite.com','james cropp','1 dualite ln','williamsburg','OH','UNITED STATES','45176','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 19:56:28',0,NULL,3,1,1,1,NULL,NULL),(4768,619564431001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','terrypope1','tpope1@hotmail.com','Terry Pope','6 S Laflin St<br>Apt 722','Chicago','IL','UNITED STATES','60607-2442','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 20:33:22',0,NULL,3,1,1,1,NULL,NULL),(4769,704900703016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','cesmad83','cescoronado@gmail.com','Cesar Coronado Garcia','Calle del Rey 35','San Lorenzo Escorial','Madrid','SPAIN','28200','637822838','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-14 20:55:52',0,NULL,3,1,4,1,NULL,'6663a   1 \rYW864489434CN\r'),(4771,619576578001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','sander_jacobsen','sander@cardinalrg.org','Sander Jacobsen','Hellestadgangen 49','Dal','Dal','NORWAY','2072','+4790826339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:00:56',0,NULL,8,1,17,0,NULL,' '),(4772,619576077001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sander_jacobsen','sander@cardinalrg.org','Sander Jacobsen','Hellestadgangen 49','Dal','Dal','NORWAY','2072','+4790826339','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-14 21:00:57',0,NULL,3,1,4,1,NULL,'背景架2m ( 白  黑  绿   黄 ）   1\rYW864489423CN\r '),(4773,659054426002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','jl9br','jeffluppinoesposito@gmail.com','Anna McGrady','474 Lambeth Field, apartment 3<br>University of Virginia','Charlottesville','VA','UNITED STATES','22904','(240) 412-3972','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-14 21:05:10',0,NULL,3,1,1,1,NULL,'反光板支架   1\r110cm 5in1    1\r分两票发挂号小包吧 RR843878985CN\rRR843878971CN'),(4774,704697214016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',6,'AA1310',22.68,'hutongstore','paquito05','cesarcheca@gmail.com','César Checa Manrique de Lara','Maria de Molina, 39 Bassat - Ogilvy','Madrid','Madrid','SPAIN','28006','628306690','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 20:57:36',0,NULL,3,1,3,1,NULL,'2m 灯架   2\r双灯头 欧标   2\r反光伞   2\r115w 220v   4\r包    1 \rCP219487801CN\r'),(4775,659062345002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',8.69,'hermeshine','coco.and.me','jlao22@hotmail.com','J L','90 Des Soeurs Grises #705','Montreal','QC','CANADA','H3C 6N1','(514) 510-1823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:15:02',0,NULL,3,1,2,1,NULL,'中号内胆包 canon  1 '),(4776,619587585001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','amnon2009718','karate1975@gmail.com','Amnon Suodai','6485 Booth St<br>Apt 6B','Rego Park','NY','UNITED STATES','11374-4020','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 21:26:36',0,NULL,3,1,1,1,NULL,'77mm 接口环  2\r广角托架  2 '),(4777,719004513015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','binki737','ebayer@paulbarnes.me.uk','Paul Barnes','Charlton, Church Lane, Bursledon','Southampton,','Hampshire','UNITED KINGDOM','SO31 8AB','07810547754','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-14 21:43:16',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843878115CN\r'),(4778,704932114016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','jacek1702','fotojacek@diginet.ie','Marian Pieciak','11 Laurelmount Avenue Rock Road','Carrigaline','Cork','IRELAND','000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-14 21:51:41',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r反光板支架   1\rreflector holder   $22 \rYW864489412CN\r'),(4779,659078160002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','triathlonroco','roger_couture@yahoo.com','Roger Couture','344   12 Ave','Pintendre','QC','CANADA','G6C1K7','(418) 835-6016','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 21:53:02',0,NULL,3,1,2,1,NULL,'6662a快装板  1 '),(4780,619624313001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lostbider','oliverpenny7738@yahoo.com','SZE-HUA WU','8650 Spicewood Springs Rd<br>Ste 122','Austin','TX','UNITED STATES','78759-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:15:36',0,NULL,3,1,1,1,NULL,NULL),(4781,619586060001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','chmwilki','chmwilki@gmail.com','Morgan Wilkins','1638 E Lindley Rd','Mooresville','IN','UNITED STATES','46158-6575','(317) 831-1832','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:18:41',0,NULL,8,1,17,0,NULL,'77mm  cpl   1\r58mm cpl   1\r80cm 5in1    1\r60cm 棚     1 RR843877018CN'),(4782,619585725001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',3,'AB1303',10.02,'hermeshine','chmwilki','chmwilki@gmail.com','Morgan Wilkins','1638 E Lindley Rd','Mooresville','IN','UNITED STATES','46158-6575','(317) 831-1832','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-14 23:18:43',0,NULL,3,1,1,1,NULL,'58mm 橡胶罩   3\r52mm 橡胶罩    2 '),(4783,659114472002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zeltser1812','zeltser.iliya@gmail.com','Iliya Zeltser','shapira str.44 app.30<br>postcode.78210','ashkelon','','ISRAEL','78210','(972)054-5889278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-14 23:42:15',0,NULL,3,1,3,1,NULL,'RR843878645CN\r '),(4784,704983382016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','francislm520','franc520@hotmail.com','Francisco Silva','Travessa Artur Azevedo nº165 Touguinha','Vila do Conde','Porto','PORTUGAL','4480-514','963170764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 00:06:57',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(4785,619480934001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','astro3661','robtaylor3661@comcast.net','Robert Taylor','1645 Galbraith Ln','Kaysville','UT','UNITED STATES','84037-9796','(801) 599-3925','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 00:24:24',0,NULL,3,1,1,1,NULL,' '),(4786,619643691001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','paulocarmona1948','paulocarmona@yahoo.com.br','Paulo Carmona','Rua das Jacutingas, 350<br>Parque dos Pássaros','São Bernardo do Campo','São Paulo','BRAZIL','09861-310','55-(11)-43435259','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 00:27:54',0,NULL,3,1,3,1,NULL,'tripod $16 \rYW864489316CN\r'),(4787,619382442001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 01:01:52',0,NULL,8,1,17,0,NULL,NULL),(4788,658853449002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0293981243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 01:01:52',0,NULL,3,1,4,1,NULL,'桌面灯   1（38cm 灯架+ 桌面灯头）   \r大力夹球台   2 \rYW864489596CN'),(4790,619675357001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','la-dealer','jraulcastillo@sbcglobal.net','Raul Castillo','1049 E 32nd St','Los Angeles','CA','UNITED STATES','90011-2547','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 02:48:41',0,NULL,3,1,1,1,NULL,NULL),(4791,659165660002,120539340436,'New 77mm ring adapter replacement for cokin P series',2,'AA2214',7.1,'hermeshine','davemillr','davemiller@mindspring.com','Dave Miller','6048 Breton Pl','Newark','CA','UNITED STATES','94560','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-15 03:12:43',0,NULL,3,1,1,1,NULL,'77mm 接口环  2 '),(4792,619689368001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','pirineo.i','pirineo.i@gmail.com','Diego Arnedo','5333 Av Casgrain (suite 1001)','Montreal','QC','CANADA','H2T1X3','(514) 214-6454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 03:57:11',0,NULL,3,1,2,1,NULL,'新款内胆包   1 '),(4793,659189137002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.55,'hermeshine','bridgebolt','bridgebolt@yahoo.com','Jaime Rosaria','6121 Willoughby Cir','Lake worth','FL','UNITED STATES','33463-9309','(561) 968-5901','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-15 05:17:06',0,NULL,3,1,1,1,NULL,'72mm 渐变灰   1 '),(4795,619708234001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ijavigarcia','ijavi.garcia@gmail.com','javier garcia cabezudo','passeig urrutia 37 , esc 2 , 3o.2a.','barcelona','Cataluña','SPAIN','08042','935177027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 05:58:48',0,NULL,3,1,2,1,NULL,NULL),(4796,659203867002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','iceman132004','icemanbtnh@hotmail.com','callum taylor','20/9 Hull Dr','Campbellfield','Victoria','AUSTRALIA','3061','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 07:00:36',0,NULL,3,1,3,1,NULL,'sony 单肩包 a1    1 RR843878574CN\r'),(4797,719161102015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','paulb1884','imagebyb@bigpond.com','Paul Burdett','14 Peatling Lane','Twin Waters','Queensland','AUSTRALIA','4564','0419744984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 07:25:06',0,NULL,3,1,2,1,NULL,'45w    2 '),(4798,659207867002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','yinszu360','yinszu@hotmail.com','SIMON HUANG','1911 SE 189th Ct','VANCOUVER','WA','UNITED STATES','98683-9770','(360) 901-5660','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 07:31:41',0,NULL,3,1,1,1,NULL,'摄影背心 夏  xl   1 '),(4799,619724677001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 08:00:39',0,NULL,3,1,2,1,NULL,'大号灰卡   1 \r'),(4800,659224002002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','molassy','wormold@hotmail.com','Richard Connors','Kwang-hae Leadville Apt. 102-dong, 1011-ho<br>Nam-gu, Juan 6-dong, 966-3','Incheon','Incheon','KOREA,REPUBLIC OF','402-848','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 09:06:41',0,NULL,3,1,11,1,NULL,'c型大力夹   1 '),(4801,719187040015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','emulsion120','exposure.120@hotmail.co.uk','Colin Rogers','63 Yealmpstone Drive Plympton','Plymouth','Devon','UNITED KINGDOM','PL7 1HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 09:22:59',0,NULL,3,1,2,1,NULL,'单灯头 英标   2 '),(4802,619741182001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','celter','to@kjellevand.no','Tor Ole Kjellevand','Inkognito terrasse 7B','Oslo','','NORWAY','0256','4722558085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 09:30:41',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(4803,619778718001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','gigglemonster22','voodoolady70@hotmail.com','Sophie Muir','Unit 3/60 Northernhay Street<br>Reservoir','Melbourne','Victoria','AUSTRALIA','3073','030421961451','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'RR843878469CN\r '),(4804,719249776015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',8.99,'hutongstore','dultius','marcoduz@hotmail.com','Marco Duz','Weipers Centre For Equine Welfare 464 Bearsden Road','Glasgow','Glasgow (City of)','UNITED KINGDOM','G61 1QH','1413305999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 12:36:29',0,NULL,3,1,2,1,NULL,'防雨罩   1 '),(4805,705169221016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','kegetyss','kegetys@gmail.com','Keijo Ruotsalainen','Piekanankuja 1 C 46','Kuopio','','FINLAND','70820','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 12:46:04',0,NULL,3,1,2,1,NULL,'77mm 渐变灰  1 '),(4806,619805391001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mikelynn2011','mikelynn@nb.sympatico.ca','Michael Steeves','96 Pasadena Dr','Moncton','NB','CANADA','E1G 1H5','(506) 576-9098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 13:29:37',0,NULL,3,1,2,1,NULL,NULL),(4807,658621311002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','super-detka','supra-tatyana@narod.ru','Tatyana Razdobydina','5-2 Pogranichnika Gorkavogo Str. , Apt.8','Sankt-Peterburg','krasnoselskiy rayon','RUSSIAN FEDERATION','198206','+79312443440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 13:35:26',0,NULL,8,1,17,0,NULL,NULL),(4808,619151542001,110462204958,'Continuous Lighting System：light stand/bulb holder/um',1,'AKT009',60,'hermeshine','super-detka','supra-tatyana@narod.ru','Tatyana Razdobydina','5-2 Pogranichnika Gorkavogo Str. , Apt.8','Sankt-Peterburg','krasnoselskiy rayon','RUSSIAN FEDERATION','198206','+79312443440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 13:36:37',0,NULL,3,1,5,1,NULL,'2m 灯架   2\r双灯头 欧标   2\r反光伞   2\r115w 220v   4\r包    1 \rCP219487801CN\r'),(4809,619809109001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','paxcz007','pavel.repka@gmail.com','Pavel Repka','Podrouzkova 6047','Ostrava - Poruba','Czech Republic','CZECH REPUBLIC','70800','732829841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 13:39:48',0,NULL,3,1,2,1,NULL,'67mm 环架  1 '),(4810,705196847016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','gunner-g','sirgbolalot@hotmail.co.uk','gbola gbadamosi','7 acworth house barnfield road','woolwhich','London','UNITED KINGDOM','se18 3tw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 13:57:46',0,NULL,3,1,2,1,NULL,' '),(4811,705216992016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:58',0,NULL,8,1,17,0,NULL,NULL),(4812,705212870016,260660053692,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',7.8,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:59',0,NULL,8,1,17,0,NULL,NULL),(4813,705213738016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',2.8,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 14:49:59',0,NULL,3,1,3,1,NULL,'430肥皂盒  1\rstar8 星光镜  1\rlenspen   1 RR843878530CN\r'),(4814,619840595001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','cuba_treasures','gilbertosuarezluis@yahoo.com','Gilberto Suarez','440 W 35th Pl','hialeah','FL','UNITED STATES','33012-5133','(786) 342-5688','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 15:08:41',0,NULL,3,1,4,1,NULL,'反光板支架   3 \rreflector holder   $21\rYW864489401CN\r'),(4815,619621433001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','cosdab','cosdab@hotmail.it','Cosimo Dabanello','De Curtis ,7','Marcianise','CE','ITALY','81025','3392163763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 15:22:15',0,NULL,3,1,2,1,NULL,NULL),(4816,659339619002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','tomernn','tnakar@gmail.com','Tomer Nakar','Geva st. 12','Givatayim','IL','ISRAEL','53316','052-3655882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 15:37:36',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4817,705245394016,260660052183,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',2.39,'hutongstore','taintin0','taintin@btinternet.com','Terry Flood','124,Crompton Ave,, Sprotbrough.','Doncaster','South Yorkshire','UNITED KINGDOM','dn5 8eg','01302784202','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 15:48:42',0,NULL,3,1,2,1,NULL,'62mm 接口环  1 '),(4818,619871409001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','evri4mann','evri4man@gmail.com','Mikhlyayev Yevgeniy','Respubliki 39/4-82','Temirtau','Karagandinskaya obl','KAZAKHSTAN','101400','87053002969','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 16:23:01',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878279CN\r'),(4819,705264405016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','snnpa6','nikolaos@cosmosproductions.com','Nikolaos Papadopoulos','Akrotiri Terian','Mytilini','Lesvos','GREECE','81100','302251047907','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 16:25:12',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚  欧标  2\r115w 220v   2\r包   1\rCP219487815CN\r\r '),(4820,705275038016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','tonomag','antofan@free.fr','Antoine Chez Hughes Delforges','29 Avenue Victor Hugo','Pierrefitte sur Seine','Ile-de-France','FRANCE','93380','0676931989','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 16:50:58',0,NULL,3,1,4,1,NULL,'YW864489390CN\r '),(4821,619885316001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','criss_t','ibecriss@comcast.net','Christina Payton','418 Buren Pl','INDIANAPOLIS','IN','UNITED STATES','46219','(317) 869-0188','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 16:52:47',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r斜臂  2 \rYW864489386CN\r'),(4822,659392694002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','fmes3058','beaumistral@gmail.com','fernand Messiaen','rue Rousseau 26','Jemeppe sur meuse','','BELGIUM','4101','0494057099','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 17:32:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878177CN\r'),(4823,619904102001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','felixtotuga','corazonrie@yahoo.com','veronica noboa','4/79<br>gould st','campsie','New South Wales','AUSTRALIA','2194','0280653212','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-15 17:33:45',0,NULL,3,1,4,1,' ','2m 灯架  1\r反光板支架   1 \rreflector holder   $22\rYW864489375CN\r'),(4824,659393436002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:34:13',0,NULL,8,1,17,0,NULL,NULL),(4825,705278792016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','bombeira2007','rosabva@hotmail.com','Rosa maria santos Guerra','quinta da palmeira rua da oliveira lote 14 fração c 1º dto','albufeira','algarve','PORTUGAL','8200','(00351)914451496','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-15 17:35:57',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(4826,619911019001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 17:44:19',0,NULL,3,1,3,1,NULL,'2m 灯架  1 白盒 RR843878248CN\r'),(4827,619912356001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:47:14',0,NULL,8,1,17,0,NULL,NULL),(4828,619912684001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','y_s_k','s.jusupov@gmail.com','Sergey Yusupov','190, 31/1, Krylatskaya ulitsa','Moscow','','RUSSIAN FEDERATION','121614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:48:09',0,NULL,3,1,2,1,NULL,'40cm 棚   1 '),(4829,619916913001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 17:56:31',0,NULL,8,1,17,0,NULL,NULL),(4830,659406138002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','kiamao09','retro1lah@gmail.com','samuel phun','Blk 113, Potong Pasir Ave 1, #13-840','default','','SINGAPORE','350113','96693021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:00:05',0,NULL,8,1,17,0,NULL,''),(4831,659409039002,120664105116,'Promotion EW-78D Lens Hood for Canon 18-200mm flocking',1,'AA3405',9.99,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 18:04:47',0,NULL,8,1,17,0,NULL,NULL),(4832,619924138001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',4,'hermeshine','migueldeveza2010','migueldeveza@gmail.com','João Miguel Deveza da Silva','Rua Quinta da Nora N 2 - 4 A','Carnaxide','Carnaxide','PORTUGAL','2790 -140','351961509555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 18:10:14',0,NULL,3,1,3,1,NULL,'50d眼罩   1\rew-78d 有植绒的   1\ret-65b   1\r58mm 橡胶罩   1\r72mm 橡胶罩    1 RR843878659CN\r'),(4833,719418542015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','adbidonline','andylong1969@googlemail.com','Andrew Long','6 Sancroft Way','Fressingfield','Eye, Suffolk','UNITED KINGDOM','IP21 5QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-15 18:13:36',0,NULL,3,1,2,1,NULL,'45w   2 '),(4834,659415454002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ingeneermk','kolodin69@mail.ru','Mikhail Kolodin','35 Kotrekhova st.<br>appartment 1','Plesetsk','Arkhangel\'skaya oblast','RUSSIAN FEDERATION','164262','818-327-2119','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:20:26',0,NULL,3,1,5,1,NULL,'背景架  （ 白）  2m  1 \rCP219487829CN\r'),(4835,619931385001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','kiamao09','retro1lah@gmail.com','samuel phun','Blk 113, Potong Pasir Ave 1, #13-840','default','','SINGAPORE','350113','96693021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 18:24:48',0,NULL,3,1,3,1,NULL,'绿色摄影背心  canon xxxl   1 \rcanon 摄影背心 xxxl  1\r老款   RR843878415CN\r'),(4837,659450823002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 19:27:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878251CN\r'),(4839,619045159001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nkingh','king_onell@hotmail.com','ng king hung','rua odilon santos nº19 - rio vermelho','salvador','bahia','BRAZIL','41940-350','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 19:49:17',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878217CN\r'),(4840,619997900001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','foltynet','foltynet@gmail.com','Tomer Foltyn','58 Shderot Benyamin','Netanya','','ISRAEL','42314','972-50-5810058','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-15 20:40:00',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878398CN\r'),(4841,620000952001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','don340photography','rawsthorne@shaw.ca','Don Rawsthorne','340 Hartford Ave','Winnipeg','MB','CANADA','R2V0W5','(204) 339-2914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 20:50:40',0,NULL,8,1,17,0,NULL,NULL),(4842,659489484002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','don340photography','rawsthorne@shaw.ca','Don Rawsthorne','340 Hartford Ave','Winnipeg','MB','CANADA','R2V0W5','(204) 339-2914','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 20:50:41',0,NULL,3,1,3,1,NULL,'b座  2\r柔光伞   2 RR843878631CN\r'),(4843,659506098002,120601698567,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','ritchieritchie19','lritchie10@cogeco.ca','MARK RITCHIE','7515 VIVIAN COURT','NIAGARA FALLS','ON','CANADA','L2H 2J6','(905) 357-7224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:20:39',0,NULL,3,1,3,1,NULL,'wf1007   1 RR843878486CN\r'),(4844,620025877001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','satyronline','snowter@gmail.com','Carlos alvarez garcia','ibaizabal 14 3ºD','galdakao','País Vasco','SPAIN','48960','657845077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:47:25',0,NULL,3,1,2,1,NULL,'柔光伞  1 '),(4845,620026519001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:50:59',0,NULL,8,1,17,0,NULL,NULL),(4846,659516795002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:50:59',0,NULL,8,1,17,0,NULL,NULL),(4847,620025964001,110598078864,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64.99,'hermeshine','giulix99','sy99@hotmail.it','VIALARDI ANDREA','VIA DELLE GINESTRE 16/16','GENOVA','GE','ITALY','16137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 21:51:00',0,NULL,3,1,4,1,NULL,'红头灯   2\r800w 220v   2\r50-70 柔光棚 塑料卡口  1\rYW864489364CN\r\r '),(4848,659525395002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','2murales','gruber1974@mixmail.com','Guillermo Gruber Herrero','Plaza de Olavide, nº5, 5º C I','Madrid','Madrid','SPAIN','28010','660603402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 22:08:19',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(4849,620046443001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','radiodjontheair','radiodjontheair@aol.com','Evan Nine','4620 SW Keats St','Port Saint Lucie','FL','UNITED STATES','34953','(561) 719-4805','NoPaymentFailure','CheckoutComplete','Other','2011-01-15 22:41:02',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878305CN\r'),(4850,719587963015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','boerkejos','bjorn.pira@skynet.be','Pira Björn','Nieuwstraat 33 3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-15 23:26:23',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑）   1 2m    \rbackground support  $20\rYW864489353CN\r'),(4851,659555983002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','kalimna-kreations','leoniedragon@wideband.net.au','Leonie James','4 Oak Crt','Morwell','Victoria','AUSTRALIA','3840','0351336606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 23:38:50',0,NULL,3,1,2,1,NULL,NULL),(4852,620063717001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','1_d_x_ahi','jonpalomar@hotmail.com','Jon Palomar','Perez Galdos   Nº11    2ºA','Valladolid','Castilla y León','SPAIN','47005','676467581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-15 23:39:25',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(4853,620081153001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','318snoopy','chrisconlin@bellsouth.net','Loretta  Conlin','4864 Tropicana Ave','Cooper City','FL','UNITED STATES','33330-4428','(954) 434-5496','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 00:37:52',0,NULL,3,1,1,1,NULL,'小号内胆包 nikon  1 '),(4854,659573718002,120570270887,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',26.99,'hermeshine','cajx7589','kh_cheung7589@hotmail.com','Kom Hung Cheung','Crooswijksestraat 164','ROTTERDAM','','NETHERLANDS','3034AR','+31648034801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 00:40:16',0,NULL,3,1,2,1,NULL,'ttl线  canon  1m   1 '),(4855,719617598015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','cipher-666','lewis_milnes@yahoo.co.uk','Lewis Milnes','63 Sefton Street','Southport','Merseyside','UNITED KINGDOM','pr8 6sh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 00:50:51',0,NULL,3,1,2,1,NULL,'49mm 接口环  1 '),(4857,620099342001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','donventa','dontienda@gmail.com','Israel Ramirez Rios','C/ Buen Pastor Nº 276','San Fernando ( Cádiz )','Andalucía Ceuta y Melilla','SPAIN','11100','669959191','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 01:59:35',0,NULL,3,1,4,1,NULL,'tripod  $22\r 打单子的时候注意，这个是电话+34644420242\rYW864489342CN\r'),(4858,620104104001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','9rosee','paypal@kitp.ru','Nikita Pavlov','HaYabok 22','Jerusalem','','ISRAEL','94515','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 02:11:54',0,NULL,3,1,3,1,NULL,'肩架  1\rRR843878296CN\r\r'),(4859,620108789001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','kayakernorth','rickmattatall@gmail.com','Richard Mattatall','2315 Whirlpool St<br>Ste 704','Niagara Falls','NY','UNITED STATES','14305-2413','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 02:31:57',0,NULL,3,1,1,1,NULL,NULL),(4860,620117944001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','remy288','remy333@verizon.net','Bill Remington','12 Robin Vale Dr','North Scituate','RI','UNITED STATES','02857-3011','(401) 228-5990','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 03:12:39',0,NULL,3,1,1,1,NULL,'麂皮  1 '),(4861,620119949001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','pablorwc','pablo206@live.com.ar','Pablo Andres Barraza','Diaz Velez 2263','Benavidez','Buenos Aires','ARGENTINA','1621','47361631','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 03:56:51',0,NULL,3,1,3,1,NULL,'nikon 摄影背心 M 老款  1 RR843878375CN\r'),(4862,620130900001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','megadeth199','segumarc@hotmail.com','Marc Seguin','29 Beaupre','Mercier','QC','CANADA','J6R 2J2','(514) 531-3969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 04:21:40',0,NULL,3,1,2,1,NULL,NULL),(4863,620132199001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','slee2669','lee.seungmin@hotmail.com','Leo Lee','427 Vaughan Road','Toronto','ON','CANADA','M6C2P1','(647) 244-2353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 04:22:46',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(4864,620149819001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','fma','sloskier@cox.net','Frank M Andrews','220 S 2nd Ave','HAILEY','ID','UNITED STATES','83333-8431','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 06:16:45',0,NULL,3,1,1,1,NULL,'机身盖/镜头后盖 nikon  1 '),(4865,620167968001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:21',0,NULL,8,1,17,0,NULL,NULL),(4866,659664006002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:21',0,NULL,8,1,17,0,NULL,NULL),(4867,659664332002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:22',0,NULL,8,1,17,0,NULL,NULL),(4868,659664522002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:22',0,NULL,8,1,17,0,NULL,NULL),(4869,659664208002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:21:23',0,NULL,8,1,17,0,NULL,NULL),(4870,659665887002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 08:23:12',0,NULL,3,1,3,1,NULL,'天涯 52mm nd8   1\r广角托架  1\r渐变灰  1\r渐变棕  1\r渐变橙   1\r67mm 接口环  1\rRR843876065CN\r\r '),(4871,620182757001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','pmson3','peter.mattsson.mm@telia.com','peter mattsson','björnbärsgatan 3','götene','','SWEDEN','53334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 09:20:24',0,NULL,3,1,2,1,NULL,NULL),(4872,659687661002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','lelabiff','mrobelin@gmail.com','Morgan Robelin','56 avenue dubrocq','bayonne','Aquitaine','FRANCE','64100','0622221783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 09:49:35',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架   1\rreflector holder  $22\rYW864489331CN\r '),(4873,620197808001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','alazaki','the_titan_m@hotmail.com','Marianne Andersen','Thomas Aasgaards gate 25','Kristiansund','Møre og Romsdal','NORWAY','6507','93874049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 10:09:45',0,NULL,3,1,3,1,NULL,'110cm 5in1 反光板  1 RR843878455CN\r'),(4874,659708758002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','collectorrpm','ejordan1949@comcast.net','Earl Jordan','5 Gamache Rd','Derry','NH','UNITED STATES','03038','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 10:46:39',0,NULL,3,1,1,1,NULL,NULL),(4875,719782818015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','jc7xx7','john.carrette@tesco.net','John Carrette','157 High Street','Wetherby','West Yorkshire','UNITED KINGDOM','LS236BH','01937123456','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 11:10:23',0,NULL,3,1,2,1,NULL,NULL),(4876,719810355015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',2.9,'hutongstore','jonash0_0','j.ashthorpe@btconnect.com','Jon Ashthorpe','98 Bishops Road','Southampton','Hampshire','UNITED KINGDOM','SO192FE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 12:00:24',0,NULL,3,1,2,1,NULL,NULL),(4877,620269482001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','cocodrieboy','pearson26od@aol.com','John Dixon','4724 Newcomb DR','Baton Rouge','LA','UNITED STATES','70808','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 13:13:18',0,NULL,3,1,1,1,NULL,'60cm 棚  1 '),(4878,620269630001,110534332901,'New Flash Hot Shoe Adapter YN-H3 for Alpha and Minolta',1,'AB3318',7.9,'hermeshine','bikbaeva','alcywork@yandex.ru','Alcy Bikbaeva','Admiral Makarova st., 16/87','Ufa','RF','RUSSIAN FEDERATION','450081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:14:02',0,NULL,5,1,2,1,NULL,'sony 热靴转换  1 '),(4879,620273490001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:22:24',0,NULL,8,1,17,0,NULL,''),(4880,659782274002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jakkefromfinland','jakke1979@hotmail.com','Jari Sietiö','välimaankatu 7 A 22','Tampere','Finland','FINLAND','33500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 13:47:24',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(4881,705786962016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','alan_grech','linu@maltanet.net','Alan Grech','International Hotel Investments plc Europa Centre','Floriana','','MALTA','FRN1400','+35679211671','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 14:35:08',0,NULL,3,1,2,1,NULL,'lenspen  2 '),(4882,659807298002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','aircruiser1','justin.le@iinet.net.au','Justin Le','UNIT 1, 38 TENNANT ST<br>WELSHPOOL','PERTH','Western Australia','AUSTRALIA','6106','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 14:39:34',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878163CN\r'),(4883,719899970015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','taffytank','pete.brabham@ntlworld.com','Peter Brabham','12 Meliden Road','Penarth','The Vale of Glamorgan','UNITED KINGDOM','CF64 3UH','02920712322','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 14:44:59',0,NULL,3,1,2,1,NULL,NULL),(4884,719813723015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',125,'hutongstore','maskare','teemu.p.saarinen@gmail.com','Teemu Saarinen','Lahdensivuntie 31 A 11','Hämeenlinna','Oletus','FINLAND','13100','+358415076144','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-16 14:58:29',0,NULL,3,1,4,1,NULL,'717 135高   1 \rYW864489320CN\r'),(4885,659817120002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','1436winnie','winniepooh@altrionet.com','JOSEPH POON','1007 Rancho Rd','ARCADIA','CA','UNITED STATES','91006-2225','(626) 445-7505','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 14:59:34',0,NULL,3,1,1,1,NULL,'b座  2 '),(4886,620319896001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 15:01:54',0,NULL,3,1,3,1,NULL,'大力夹球台  2 \r80cm 5in1   1 RR843878954CN\r'),(4887,620329166001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','vlad-limer','vlad.limer@gmail.com','Vlad Limer','zalman shezar<br>3430','kiryat yam','','ISRAEL','29082','+972547588251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 15:20:06',0,NULL,3,1,3,1,NULL,'40cm 棚  1 RR843878557CN\r'),(4888,705824711016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','lozlozloz21','mouses99@live.com','Lauren Saunders','8 Heron Drive Stansted Abbotts','Ware','Hertfordshire','UNITED KINGDOM','SG12 8TU','01920872688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 15:36:29',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(4889,620339923001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','borisjs','sakic@mcmaster.ca','Boris Sakic','150 Charlton St. East<br>apt. 3208','Hamilton','ON','CANADA','L8N 3X3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 15:39:37',0,NULL,3,1,3,1,NULL,'nikon 摄影背心  xl  老款  1 RR843878367CN\r'),(4890,719960171015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','8159christine','hellocw@btinternet.com','christine wheeler','mayland, low road','strumpshaw','Norfolk','UNITED KINGDOM','NR134HU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 16:12:51',0,NULL,3,1,2,1,NULL,NULL),(4891,659870384002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','luchertolac','lucianacaporaletti@gmail.com','Luciana Caporaletti','Calle Las Hortensias, 2<br>Nueva Andalucía','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','952811354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:30:22',0,NULL,3,1,2,1,NULL,NULL),(4892,620389981001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','undead.demidov','nikolay.demidov@gmail.com','Николай Демидов','Pyatnitskoe shosse, 9, 92','Moskva','','RUSSIAN FEDERATION','125464','926-617-9921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:59:49',0,NULL,8,1,17,0,NULL,NULL),(4893,659841939002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','undead.demidov','nikolay.demidov@gmail.com','Николай Демидов','Pyatnitskoe shosse, 9, 92','Moskva','','RUSSIAN FEDERATION','125464','926-617-9921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 16:59:50',0,NULL,3,1,2,1,NULL,'82mm 接口环  1\r广角托架   1 '),(4894,705902417016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','ballyroan16','kolettewithak@gmail.com','Kolette Enright','9 Garranbane Green Ballinroad','Dungarvan','Waterford','IRELAND','default','3536402370','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 17:12:32',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4895,720095363015,250620017234,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','cainnech','kness@btinternet.com','Kenneth Ness','3 Kingsfield Road Wirksworth','Matlock','Derbyshire','UNITED KINGDOM','DE4 4BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 18:31:45',0,NULL,3,1,2,1,NULL,'49mm 接口环  1 '),(4896,620379874001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','csurdak','jerk1n@yahoo.com','Chris Surdak','164 Five Points Rd','Rush','NY','UNITED STATES','14543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 19:00:01',0,NULL,3,1,1,1,NULL,NULL),(4897,620510497001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','triumphron','triumphron@sbcglobal.net','Ron  Maurer','3502 Knollwood Dr','Carlsbad','CA','UNITED STATES','92010-5505','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 19:12:16',0,NULL,3,1,1,1,NULL,'小号内胆包 无字  1 '),(4898,620523995001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','philipped9138','phil-delo@orange.fr','philippe deloffre','37 rue eugène pottier','bobigny','Île-de-France','FRANCE','93000','06.80.85.38.17.','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 19:27:01',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843878438CN\r'),(4899,706069452016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','jean_vallettacity','jeanmic1982@hotmail.com','JEAN PAUL MICALLEF','80/5 MERCHANTS STR','VALLETTA','ME','MALTA','VLT03','21238757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 19:44:04',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(4901,706075065016,260660050897,'Green.L 52mm Neutral Density ND4 Filter ND 4 New',1,'AE2301',3.85,'hutongstore','ivanko65','bergl@chello.sk','Ivan Bergl','Podzáhradná 49','Bratislava','','SLOVAK REPUBLIC','82106','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 19:48:57',0,NULL,3,1,2,1,NULL,NULL),(4902,620543913001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','tolga5484','tolga00@gmail.com','Tolga Tosun','Fethiye Mahellesi FSM Bulvarı<br>Eryıl Ap. kat:2 no:141-3','Bursa','Nilüfer','TURKEY','16140','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 19:49:45',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843878234CN\r'),(4903,720194546015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.5,'hutongstore','dlee654','dlee654724@aol.com','David Lee','17 Bewick Crescent','Newton Aycliffe','Durham','UNITED KINGDOM','DL5 5LQ','01325312866','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 19:54:12',0,NULL,3,1,2,1,NULL,NULL),(4904,706097041016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','s1diddy','sister.suzie@tiscali.co.uk','Suzanne Barber','Isfryn Pencader','Carmarthenshire','Carmarthenshire','UNITED KINGDOM','SA39 9HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 20:09:24',0,NULL,3,1,3,1,NULL,'摄影背心 夏  xl   1 RR843878441CN\r'),(4905,660112599002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','estopiko','estopiko@hotmail.com','roger uceda molera','pau casals nº 28','sant climent de llobregat','Cataluña','SPAIN','08849','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 21:13:12',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864489316CN\r'),(4906,620613866001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',9.9,'hermeshine','vivholland','vivandlee@aol.com','VIVIAN HOLLAND','7930 NW 7th St<br>Apt 101','PEMBROKE PINES','FL','UNITED STATES','33024','(954) 966-4408','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-16 21:34:27',0,NULL,3,1,1,1,NULL,'nikon肩带  黄字  1 '),(4907,620628972001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shacoshe','shay.te@gmail.com','Shay Tessler','jorden<br>mailbox:542','ein vered','sharon area','ISRAEL','40696','972-502134955','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-16 22:06:48',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843878340CN\r'),(4908,719748696015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','bimbolaoduns','adethomasleo@gmail.com','Ade Thomas','7N Goldworthy Gardens 7N Goldworthy Gardens','LONDON','London','UNITED KINGDOM','SE16 2TB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-16 22:58:44',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843878384CN\r'),(4909,620659076001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:06:07',0,NULL,8,1,17,0,NULL,''),(4910,660171018002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:11:22',0,NULL,8,1,17,0,NULL,NULL),(4913,719645947015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',4,'AO0005',31.96,'hutongstore','p_ronto','p_ronto@hotmail.com','Panos Rontogiannis','5 Tzoumerkon street Papagos','Athens','Attiki','GREECE','15669','++302106544955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-16 23:21:41',0,NULL,3,1,3,1,NULL,'1.6x2.1  背景布  4\r黑 灰  绿  蓝   RR843878897CN'),(4914,660173174002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-16 23:16:36',0,NULL,3,1,3,1,NULL,' 渐变橙  1 \r58mm 环架  1\r渐变棕  1\r渐变灰   1RR843878543CN\r'),(4915,620681213001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','suafcu1','wvt1@sbcglobal.net','walter tun','202 S Cedar Ave','wood dale','IL','UNITED STATES','60191-2210','','NoPaymentFailure','CheckoutComplete','Other','2011-01-17 00:12:57',0,NULL,3,1,1,1,NULL,'井字扳手   1 '),(4916,660195351002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','zahn0010','asebok@sympatico.ca','Anthony Sebok','195 Wynford Drive<br>Apt. #2701','Toronto','ON','CANADA','M3C 3P3','(416) 425-6615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 00:22:11',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4917,706263480016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jpdois','saraiva.mr@gmail.com','Mario Rui Saraiva','Rua Cap Jose Vieira Branco, N 3 - 1 Esq','Faro','Algarve','PORTUGAL','8000-239','289803454','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 01:02:36',0,NULL,3,1,2,1,NULL,'lenspen   2 '),(4918,660205229002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','22pke','cesar_senda_r1@hotmail.com','Cesar Moreno','Calle Azorin 35, 4ºA,','Mostoles','Madrid','SPAIN','28935','916131126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 01:06:50',0,NULL,3,1,2,1,NULL,NULL),(4919,620711881001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 01:54:45',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878353CN\r'),(4920,620713618001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','wrestle4garden','eirefresh@yahoo.com','Michele W Brennan','2539 Mayer Lane E','Maplewood','MN','UNITED STATES','55119','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 01:58:24',0,NULL,3,1,1,1,NULL,NULL),(4921,620713435001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',55.99,'hermeshine','truettanderin','truettanderin@hotmail.com','Truett Standefer','2325 Nashville Pike<br>Apt 928','Gallatin','TN','UNITED STATES','37066-6027','(432) 288-0120','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 02:03:39',0,NULL,3,1,1,1,NULL,'301p 一拖三   1 '),(4922,620715609001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','valbraga-2008','valdineia.braga@gmail.com','Roberto Kazuo Otsuki','Rua Walter Fontana, 32<br>Vila Paulista','São Paulo','SP - São Paulo','BRAZIL','04634-045','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 02:05:09',0,NULL,3,1,5,1,NULL,'2mx3m 背景架   1\r申报 $35 \rCP219487832CN\r'),(4923,660229737002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','pddean2011','plddean@gmail.com','P Dean','PO Box 1643','Kernville','CA','UNITED STATES','93238-1643','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 02:06:28',0,NULL,3,1,1,1,NULL,' '),(4925,660239678002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','daggetth','daggetth@hotmail.com','Thomas R. Daggett III','57 Fields End Dr','Glenmont','ny','UNITED STATES','12077-2960','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 02:35:16',0,NULL,3,1,1,1,NULL,NULL),(4926,660236607002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','joeg2774','jgalica@nexicom.net','Joe Galica','25 Ottawa Street','Havelock','ON','CANADA','K0L1Z0','(705) 778-7008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 02:35:28',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(4927,720439062015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','jupiter1uk','indiansinmoscow@googlemail.com','Pete Riches','80c Sinclair Road West Kensington','London','London','UNITED KINGDOM','W14 0NJ','02073716702','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 03:31:00',0,NULL,3,1,2,1,NULL,'58mm 渐变灰  1 '),(4928,620744111001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tool62johans','dennisjohansen@comcast.net','Dennis Johansen','1022 Oakridge Ln','Bountiful','UT','UNITED STATES','84010-2029','(801) 755-8360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 03:40:19',0,NULL,3,1,1,1,NULL,NULL),(4929,620746861001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','probenurass2b4v','probenurass@hotmail.com','Zack Lowe','2264 byrd mill road','louisa','VA','UNITED STATES','23093','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 03:51:59',0,NULL,3,1,1,1,NULL,NULL),(4930,660267146002,120581161644,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','robl03','beamholder@shaw.ca','Robert Leedham','211 Sunmeadows Cres SE','Calgary','AB','CANADA','T2X3G9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 04:07:11',0,NULL,3,1,3,1,NULL,'爵影碗罩  P1   1 RR843877070CN\r'),(4931,660266676002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','lars583164','larsfalcongreen@hotmail.com','Lars Falcongreen','35 / 40 Boundary Street<br>South Brisbane','Brisbane','Queensland','AUSTRALIA','4101','0412368991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 04:15:44',0,NULL,3,1,2,1,NULL,'麂皮  1 '),(4932,660272558002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','rma2005','roldan@live.ca','Roldan Castillo','765 Limeridge Rd. East','Hamilton','ON','CANADA','L8W 1A4','(905) 515-8540','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 04:38:40',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878910CN\r'),(4933,620783818001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','mestre_jogador','angello_49@hotmail.fr','Kévin Moisan','21 rue Frédéric Chopin','Saint Sebastien Sur Loire','Pays de la Loire','FRANCE','44230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:32:34',0,NULL,3,1,2,1,NULL,NULL),(4934,620784644001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','alexey_gureev','alexey.gureev@gmail.com','Alexey Gureev','30-17<br>Kirova','Murom','Vladimirskaya Oblast','RUSSIAN FEDERATION','602253','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 07:39:15',0,NULL,3,1,3,1,NULL,'肩架   1 RR843878937CN'),(4935,620784009001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','billybnugroho','billybnugroho@gmail.com','Billy Nugroho','353 Burwood Highway','Blackburn','Victoria','AUSTRALIA','3131','0388334167','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-17 07:39:37',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843878945CN\r'),(4936,620786396001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','dimana-fnet','yeeeti@gmail.com','Dmitry Kharchenkov','Kropotkina, 9b - 14','Voronezh','','RUSSIAN FEDERATION','394030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:51:49',0,NULL,3,1,2,1,NULL,'40cm 棚   1 '),(4938,660305626002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hornyakbalazs','2rok.mail@gmail.com','Hornyák Balázs','Megyeri út 2/a','Kisújszállás','','HUNGARY','5310','+36304536161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 07:54:56',0,NULL,3,1,2,1,NULL,NULL),(4939,720499083015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.5,'hutongstore','kairimantas','mantaskairys@gmail.com','Mantas Kairys','Vandentiekio 32-16','Vilnius','Lithuania','LITHUANIA','03151','+37062577639','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 08:09:03',0,NULL,3,1,2,1,NULL,NULL),(4940,660308189002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','apacerllo','llodad@yahoo.com','Lawrence Lo, Apacer','386 fairview way<br>suite 102','Milpitas','CA','UNITED STATES','95035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 08:11:56',0,NULL,3,1,1,1,NULL,'c型大力夹  1 '),(4941,720499284015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','sedrik35','pokus4@pobox.sk','Martin Svoboda','Holicska 28','Bratislava 5','Bratislava','SLOVAK REPUBLIC','85105','00421254435052','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 08:13:01',0,NULL,3,1,3,1,NULL,' RR843878883CN'),(4942,660309580002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ppvvld791','ppvvld@mail.ru','Vladimir Popov','ul. Lelushenko 1A kv 28','Rostov-on-Don','','RUSSIAN FEDERATION','344045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:20:49',0,NULL,3,1,2,1,NULL,NULL),(4943,620792084001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','lucialetizia82','lucialetizia.litrico@virgilio.it','lucia letizia litrico','via salvatore Santangelo n°1','san giovanni galermo','CT','ITALY','95123','3489580807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:25:22',0,NULL,3,1,2,1,NULL,'大力夹 球台   1 '),(4944,620683597001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',60.67,'hermeshine','zuikoshark','steal86@mail.ru','Aleksey Stepanov','Veresaeva street, 10-34','Moscow','Moscow','RUSSIAN FEDERATION','121357','(903) 281-6220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 08:33:01',0,NULL,3,1,3,1,NULL,'反光板支架   1\r110cm 5in1    1\r分两票发挂号小包吧 RR843878985CN\rRR843878971CN'),(4945,620795901001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','supercompulsivebuyer','pablo.davilafernandez@gmail.com','Pablo Davila','Paseo de la Ermita 43, v20<br>Urb. Pinar de Santa Ana','Pedrezuela','Madrid','SPAIN','28723','656587112','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 08:51:07',0,NULL,3,1,4,1,NULL,'tripod  $22 \rYW864489585CN\r'),(4946,620799559001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera Martínez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 09:08:19',0,NULL,5,1,18,0,NULL,NULL),(4947,616897893001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','christiano700','christianoopel@hotmail.com','christiano opel','18 carrigmore terrace saggart<br>citywest','Dublin','Dublin','IRELAND','24','0852050379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 09:12:26',0,NULL,3,1,2,1,NULL,NULL),(4948,660324725002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','pankaj4318','thepankazz@gmail.com','Pankaj Patil','8116 Coppercreek Dr','Louisville','KY','UNITED STATES','40222-6812','(765) 413-5986','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 09:47:39',0,NULL,3,1,1,1,NULL,NULL),(4950,620817125001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','sass_a_frass_quatch','chrisohare@rogers.com','Twenty-Eight Dollar Films','45 - Eastgate Circle','Whitby','ON','CANADA','l1m 2n4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 10:36:21',0,NULL,3,1,3,1,NULL,'1转4 灯头  2 RR843877021CN\r'),(4951,620814768001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','lucractius','ebay@lucractius.otherinbox.com','Samuel Bishop','Unit 12 / 3 Greenway Street','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_Express','2011-01-17 11:00:57',0,NULL,3,1,4,1,NULL,'2m灯架   2\r双灯头 澳标   2\r反光伞   2\r包   1 \rlighitng kit  $22\rYW864489574CN\r'),(4952,706421103016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','blithespirit.com','paul@olive-house.co.uk','paul szelesi','221 Burnley Road','Rawtenstall','Lancashire','UNITED KINGDOM','BB4 8LA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 11:13:54',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(4953,660347601002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:44',0,NULL,8,1,17,0,NULL,''),(4954,620828115001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:45',0,NULL,8,1,17,0,NULL,NULL),(4955,660346857002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:38:45',0,NULL,8,1,17,0,NULL,NULL),(4956,660347171002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 11:38:46',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r单灯头  欧标  2\r反光伞  2\r柔光伞  1\rb座    1 \rCP219487775CN\r'),(4958,660347615002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','boerkejos','bjorn.pira@skynet.be','Pira Björn','Nieuwstraat 33<br>3071 Erps-Kwerps','Erps-Kwerps','','BELGIUM','3071','0496743055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 11:29:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879005CN'),(4959,620839953001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','tbr369','tibor@wombatoz.com','TIBOR HEGEDUS','PO Box 87','Hepburn Springs','Victoria','AUSTRALIA','3461','0419369333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:18:57',0,NULL,8,1,17,0,NULL,''),(4960,660358793002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','tbr369','tibor@wombatoz.com','TIBOR HEGEDUS','PO Box 87','Hepburn Springs','Victoria','AUSTRALIA','3461','0419369333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:18:57',0,NULL,3,1,4,1,NULL,'717ah   1 \r717快装板   1 \rTibor Hegedus\r36 Lakeside Drive\rHepburn Springs VIC 3461\rAustralia\r0419369333\rYW864614992CN\r\r\r'),(4961,720554714015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','brech22','alisonbrech@googlemail.com','Alison Brech','31 Wharf Road','Wraysbury','Middlesex','UNITED KINGDOM','TW19 5JQ','01784481808','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 11:50:27',0,NULL,3,1,2,1,NULL,'倒影板  1 '),(4962,620843572001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vj-ammonite','vj-ammonite@terra.es','Jesus Plata Mateos','C/ las margaritas, 41 buzon 44<br>Siestamar','Santa eulalia','Baleares','SPAIN','07849','600505906','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 12:32:31',0,NULL,3,1,3,1,NULL,'肩架  1 RR843878999CN\r'),(4965,720594072015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','scottdalkin','scottdalkin@hotmail.co.uk','Scott  Dalkin','4 Falcon Crescent','Flitwick','Bedfordshire','UNITED KINGDOM','MK45 1LY','01525630001','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 14:04:14',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843878870CN\r'),(4966,660388038002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','lotenlooser','stig_lovas@yahoo.no','Stig Lovas','Mellombolgen 77','Oslo','','NORWAY','1157','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 14:10:10',0,NULL,3,1,3,1,NULL,'50-70塑料卡口棚   2 RR843877083CN\r'),(4967,620870720001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','kr5andm','post@sandmark.no','Kristian Sandmark','Tegnestiften 14','Gjøvik','','NORWAY','2821','+4740467177','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 14:16:49',0,NULL,3,1,3,1,NULL,'井字扳手  1 RR843877154CN'),(4968,720602885015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','spgxk','kwgo1@hotmail.com','Kazuhiro Watanabe','5707-1 Kamisuwa Oaza','Suwa','Nagano','JAPAN','3920003','(080) 412-4835 ext.: 5','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-17 14:29:48',0,NULL,3,1,6,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(4972,620879806001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','soozette3','andrea.lacasse@gmail.com','Andrea Lacasse','4600 Wedgewood Blvd<br>Ste X','Frederick','MD','UNITED STATES','21703-7167','(301) 712-6565','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 15:04:38',0,NULL,3,1,1,1,NULL,NULL),(4973,720627943015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','inetarimas','inetuke@yahoo.com','Rimas Trakselis','Slotsgade 6','Horsens','','DENMARK','8700','4560329296','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 15:32:17',0,NULL,3,1,2,1,NULL,'45w   2 '),(4974,660416652002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','+2306971479','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 15:42:36',0,NULL,3,1,2,1,NULL,'大力夹   2 '),(4975,620902940001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','billrees','bill@billrees.com','William Rees','577 Lake Forest Dr.','Bay Village','OH','UNITED STATES','44140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 16:01:45',0,NULL,3,1,1,1,NULL,'小号内胆包 无字  1 '),(4976,706525338016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',3,'hutongstore','kcobby40','keith.cobby@supplydynamics.net','Keith Cobby','PO Box 113863 416 Al Awir Road, Nadd Al Hamar','Dubai','','UNITED ARAB EMIRATES','0000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 16:29:19',0,NULL,3,1,2,1,NULL,'450d 眼罩   1 '),(4977,660434515002,120626873273,'New wide angle holder for Cokin P series filter',5,'AA2216',19.95,'hermeshine','barao1961','amgp@netvisao.pt','Antonio Manuel Gomes Paulino Paulino','R. Alves Redol Nº 72 1º Esq.','Cova da Piedade - Almada','Setúbal','PORTUGAL','2805-071','936494274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 16:31:30',0,NULL,3,1,3,1,NULL,'广角托架   5 RR843877066CN'),(4978,620916351001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','jderson','jdderson@gmail.com','David Anderson','12350 S Parker Ter','Olathe','KS','UNITED STATES','66061','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 16:38:49',0,NULL,3,1,1,1,NULL,NULL),(4979,660456498002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','mvglorenz25','mlorenz@infonegocio.com','Michael Garcia Lorenz','Universidad Carlos III de Madrid [Q2818029G]<br>Avenida de la Universidad, 30','Leganes','Madrid','SPAIN','28911','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 17:24:12',0,NULL,3,1,2,1,NULL,'广角托架   1 '),(4980,620934402001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lau.cl','laurent.cloquette@gmail.com','Marcia Kubrusly','Gonçalves Dias 577 apto. 301.','Curitiba','Paraná','BRAZIL','80240340','55 41 8712 6553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 17:24:27',0,NULL,3,1,2,1,NULL,NULL),(4981,660464558002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','3742giovanni','pettigio@tiscali.it','giovanni petti','viale galvano della volpe n 3','roma','Roma','ITALY','00133','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 17:43:06',0,NULL,3,1,3,1,'RR843877035CN','黑色摄影背心 无字的 厚的    xxxl  1 \r'),(4982,660464230002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','opies1','oscar@thelensdepot.com','Oscar Pastrana','2789 Wrights Rd<br>Ste 1029','Oviedo','FL','UNITED STATES','32765-8528','(407) 964-1075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-17 17:43:44',0,NULL,3,1,1,1,NULL,NULL),(4983,720696126015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','drusilla_filth','dru@druwatts.co.uk','Dru Watts','24 Shotley Close Pinewood','Ipswich','Suffolk','UNITED KINGDOM','IP2 9RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 17:57:36',0,NULL,3,1,2,1,NULL,'1.6x2.1 白色背景布  1 '),(4984,660474192002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','meryjougs','mjgs_04@hotmail.com','Maria Jose Gavilan Sanchez','Avenida Villamayor,<br>40, 4º G','Salamanca','Castilla y León','SPAIN','37007','636756615','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 18:04:47',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843877049CN\r'),(4985,620923939001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:58',0,NULL,8,1,17,0,NULL,''),(4986,620954220001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:59',0,NULL,8,1,17,0,NULL,NULL),(4987,620932320001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:58',0,NULL,8,1,17,0,NULL,NULL),(4988,620954337001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.5,'hermeshine','danielzavadszky','zavadszky@gmail.com','Daniel Zavadszky','Av. Rondeau 2396 / Ap. 1001','Montevideo','Montevideo','URUGUAY','11800','09899261190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:21:59',0,NULL,3,1,3,1,NULL,'77mm  cpl   1\r58mm cpl   1\r80cm 5in1    1\r60cm 棚     1 RR843877018CN文娟'),(4989,620965634001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','jira_d','plamineks@volny.cz','Jiri Durdil','Ceskolipska 400','Praha 9','','CZECH REPUBLIC','19000','+420603744703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:33:35',0,NULL,8,1,17,0,NULL,NULL),(4990,660484712002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','jira_d','plamineks@volny.cz','Jiri Durdil','Ceskolipska 400','Praha 9','','CZECH REPUBLIC','19000','+420603744703','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:33:36',0,NULL,3,1,2,1,NULL,'品胜3.0膜   1\r40cm 棚   1 '),(4991,660491141002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','solaaris65','solaaris65@hotmail.com','Sebastien Barreau','Res Aramis, 49 rue Brauhauban<br>Etage 2 , Appt 5','Tarbes','Midi-Pyrénées','FRANCE','65000','06?67?36.07.25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 18:37:58',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(4996,660509517002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shabashevich86','shabashevich@rambler.ru','Evgeniy Shabashevich','Hameri Haivri<br>521','Qiryat-Gat','','ISRAEL','82252','0527726818','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 19:12:27',0,NULL,3,1,2,1,NULL,NULL),(4997,660527648002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','misstrinity8','virginie_lz@hotmail.com','Virginie LOPEZ','30 route d\'Eguilles<br>villa amadour, bat O','Aix en provence','Provence-Alpes-Côte d\'Azur','FRANCE','13090','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-17 19:46:02',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843878866CN'),(4998,660577821002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','cekisieda','cemkastrat@hotmail.com','eda kastrat','ahmet kutsi tecer caddesi 55/d<br>merter/güngören','istanbul','','TURKEY','34010','2125547718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 21:23:54',0,NULL,3,1,3,1,NULL,'301p 一拖一  1 RR843877106CN'),(4999,660580690002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','argassd','argasd@gmail.com','Skirmantas Rocka','Baltu 6-77','Kaunas','Lithuania','LITHUANIA','lt-48166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-17 21:29:36',0,NULL,3,1,3,1,NULL,'115w 220v   1 RR843877052CN'),(5000,706700073016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','ptdnice','songkim2000@aol.com','PHAM Tu  Dung','\" Restaurant Fleur de Jade\" 8, rue d\'Italie','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-17 21:46:44',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(5001,660596366002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','alvaro19561','aneira65@yahoo.com','Alvaro Neira','340 NW 19th St<br>Apt 200','boca raton','FL','UNITED STATES','33432','(561) 929-2877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-17 22:06:33',0,NULL,3,1,1,1,NULL,'800w 110v   5 '),(5002,720856363015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.98,'hutongstore','sepotter114','sarah.potter40@ntlworld.com','Sarah Potter','54 Rose Avenue Irlam','Manchester','Lancashire','UNITED KINGDOM','M44 6AG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-17 22:17:05',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋   2 '),(5003,621109277001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','bear789tem','kosmo0308@aol.com','terry mewhorter','2109 Holland St','west columbia','SC','UNITED STATES','29169','(803) 394-9927','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 00:17:19',0,NULL,3,1,1,1,NULL,NULL),(5004,618900012001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',13.37,'hermeshine','jedonet','jedott@yahoo.com','J.Edgar Calingacion','#79-17, Yeongcheon-Ri<br>Dongtan-Myeon','Hwaseong City','Gyeonggi-Do','KOREA,REPUBLIC OF','445-813','821051300728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 00:51:16',0,NULL,3,1,11,1,NULL,'lenspen   1\r77mm 环架   1 '),(5005,655102944002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','vinczebalintakos','hhfishebay@gmail.com','Balint Vincze','Semmelweis utca 6.','Gyula','Bekes megye','HUNGARY','5700','0036302199809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 00:55:00',0,NULL,3,1,2,1,NULL,NULL),(5006,660652490002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:12:06',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5007,660653190002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','moxermax','gorkagoikoetxe@hotmail.com','Gorka Goikoetxea Aguirre (Presso Guzzeloni)','Viale Gran Sasso 50','Milano','MI','ITALY','20131','3278592636','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 01:18:18',0,NULL,3,1,4,1,NULL,'6662a   1 \rYW864489552CN\r'),(5008,660655666002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','paganaki','phil_paganias@yahoo.com','Philippos Paganias','Eptalofou 12','Attica','maroussi','GREECE','15124','00306942473896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:23:50',0,NULL,3,1,2,1,NULL,'c型大力夹  1 '),(5009,621126548001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ferblues70','fernandomblues@gmail.com','David Fernando Miranda','San Miguel Bloque L#35<br>P.O.BOx 312 350','La Paz - Bolivia','La Paz','BOLIVIA','P.O 312 350','2 795762','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 01:26:56',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843878923CN\r'),(5010,660656687002,120500391259,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',9.25,'hermeshine','leofioravanti','leofioravanti@uol.com.br','Leonardo Fioravanti','R Professor Tranquilli 212 Apto 62','São Paulo','São Paulo','BRAZIL','04126-010','55 11 50849086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:27:20',0,NULL,3,1,2,1,NULL,'大号内胆包无字   1 '),(5011,660663183002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ndrlndr','ndrlndr@btinternet.com','Henk-Jan Bussink','230 South Ealing Road<br>1st floor flat','Ealing','London','UNITED KINGDOM','W5 4RP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 01:51:49',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5012,621141548001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','melbastian2','melbastian@yahoo.com','Melanie Bastian','11140 N Alger Rd','Alma','MI','UNITED STATES','48801-9769','(989) 681-4502','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-18 02:28:20',0,NULL,8,1,17,0,NULL,NULL),(5013,621140994001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','melbastian2','melbastian@yahoo.com','Melanie Bastian','11140 N Alger Rd','Alma','MI','UNITED STATES','48801-9769','(989) 681-4502','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-18 02:28:20',0,NULL,3,1,1,1,NULL,'大力夹 球台  2 '),(5014,660257806002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','hasnulyakin2009','marketgarden77@yahoo.co.uk','HASNULYAKIN MOHAMMED','BERJAYA LANGKAWI RESORT<br>BURAU BAY, LANGKAWI','KEDAH','kedah','MALAYSIA','07000','04-9671175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 02:44:26',0,NULL,3,1,2,1,NULL,'90th 肩带  1 '),(5015,660702480002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','skaliboy','ska@xpressionsinforms.com','eliseo gomez','4318 el cebra way','las vegas','NV','UNITED STATES','89121','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 04:37:17',0,NULL,3,1,1,1,NULL,NULL),(5016,621170261001,110532007108,'72mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1303',2.6,'hermeshine','hollywood_ca','george@signaturexavier.com','GEORGE OHAN','1665 N Sycamore Ave<br>Apt 309','Hollywood','CA','UNITED STATES','90028-6062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 04:37:51',0,NULL,3,1,1,1,NULL,NULL),(5017,620943845001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',32.06,'hermeshine','tkptrt','cparhan@gmail.com','Chandra Parhan','Jl. Kismis No. 15<br>Rancakendal, Cigadung','Bandung','JI','INDONESIA','40191','6285885689861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 07:02:37',0,NULL,3,1,3,1,NULL,' lenspen   1\r气吹+布   1\r麂皮  4\r58mm 橡胶罩  1\r52mm 橡胶罩  1\r52-58 双阳   1\r58mm +4\rRR843877636CN\r\r\r'),(5018,721013576015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','tauer77','tauer@ktkadan.cz','Pavel Tauer','Klasterecka 1294','Kadan','','CZECH REPUBLIC','43201','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-18 07:58:28',0,NULL,3,1,3,1,NULL,'2m  灯架  1\rb座  1\r柔光伞   1 RR843877450CN\r'),(5019,660735565002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','lukacsa','alukacs@raszputyincat.com','Adrienn Lukacs','Temeto utca 9','Mogyorod','','HUNGARY','2146','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 08:17:57',0,NULL,3,1,3,1,NULL,' RR843877534CN\r'),(5020,706397286016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',133,'hutongstore','houselinen_uk','robertorocco@tiscali.co.uk','R. Miranda','48 Thorpe rd','kingston upon thames','Surrey','UNITED KINGDOM','kt2 5eu','07773712658','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-18 08:47:39',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5021,621209056001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','rasskazov_mv','rasskazov.mv@ya.ru','Михаил Рассказов','ул. Осипова, д. 24, кв. 121','Саратов','','RUSSIAN FEDERATION','410010','+79272264040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 08:55:50',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5022,660743399002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ridzuan60','ridzuanismail@gmail.com','Ridzuan Ismail','Fumakilla Malaysia Bhd,<br>Plot No. 256, Tingkat Perusahaan 5, Kawasan Perindustrian Perai 2','Perai','Penang','MALAYSIA','13600','0124930088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:02:43',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5023,660749343002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:51',0,NULL,8,1,17,0,NULL,NULL),(5024,621218147001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 09:45:50',0,NULL,8,1,17,0,NULL,NULL),(5025,621216967001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:51',0,NULL,8,1,17,0,NULL,' '),(5026,621216506001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','Gauteng','SOUTH AFRICA','2006','+27 835928562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 09:45:52',0,NULL,3,1,3,1,NULL,'52mm 镜头盖  nikon  1\r小号镜头筒   1\r90th 镜头筒   1\r机身盖/镜头后盖 nikon   1 RR843877640CN\r'),(5027,621220613001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','bahalam','mehdi@pacbell.net','Mehdi Asgarinejad','61 Shady Ln','Irvine','CA','UNITED STATES','92603-0127','(949) 509-6161','NoPaymentFailure','CheckoutComplete','Other','2011-01-18 09:56:24',0,NULL,8,1,17,0,NULL,''),(5029,660756089002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bahalam','mehdi@pacbell.net','Mehdi Asgarinejad','61 Shady Ln','Irvine','CA','UNITED STATES','92603-0127','(949) 509-6161','NoPaymentFailure','CheckoutComplete','Other','2011-01-18 10:07:30',0,NULL,3,1,4,1,NULL,'反光板支架  2 \r斜臂  1 \rreflector holder   $20\rYW864614981CN\r'),(5030,660763944002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ntlbd','ntlbd@dezzanet.net.au','Paul Ellis','73 Oriole Drive','Werribee','Victoria','AUSTRALIA','3030','0397341717','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 10:46:32',0,NULL,3,1,3,1,NULL,'sony 单肩包  a1  1 RR843877579CN\r'),(5031,660689527002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 10:58:27',0,NULL,3,1,3,1,NULL,'红头灯  1\r800w 220v 灯泡  1\r2m 灯架 红盒   1 \r不好包就分开发吧RR843877551CN\rRR843877525CN\r'),(5032,660768742002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','emarinas','enmarinas@yahoo.es','Enrique Mariñas','Anabel Segura 7<br>2ª planta NEC Iberica','Alcobendas','Madrid','SPAIN','28108','649179235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 11:41:12',0,NULL,3,1,3,1,NULL,'肩架 1 RR843877494CN\r'),(5033,721084437015,250599921846,'New 52mm 52 Ring adapter and Holder for Cokin P Series ',1,'AKT018',3.62,'hutongstore','rwdfoote','robinfoote@hotmail.com','Robin Foote','87, Hanover Terrace','Brighton','East Sussex','UNITED KINGDOM','BN2 9SP','07970319759','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 12:41:51',0,NULL,3,1,2,1,NULL,'52mm环架  1 '),(5034,660797033002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','talamer','talamer2000@hotmail.com','Talal AlAamer','Villa 203 Road 1009 Block 110','Hidd','','BAHRAIN','100','(973) 366-3609 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:13:55',0,NULL,3,1,2,1,NULL,NULL),(5035,706964052016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','margaret841955','margaretdunlop@tiscali.co.uk','Josh Dunlop','Easdale Towpath','Shepperton','Surrey','UNITED KINGDOM','TW179LL','01932223783','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 13:38:15',0,NULL,3,1,2,1,NULL,'canon 三角包  1 '),(5036,660806025002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',40,'AA1310',219.6,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:50:34',0,NULL,3,1,3,1,NULL,'lenspen  40 拆包装 RR843877619CN'),(5037,660809030002,120564178883,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','mentepoluida','rodrigosantiago2005@gmail.com','Rodrigo Santiago','Rua Helena Vaz da Silva nº13-6ºA','Lisboa','Lisboa','PORTUGAL','1750-405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 13:57:26',0,NULL,3,1,2,1,NULL,'ND8   1 '),(5038,618396654001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',139.88,'hermeshine','adeje_dario','dario_adeje@hotmail.com','Dario Bascones Carrodeguas','Residencial Los Abalos nº1 El Galeon','Adeje','Canarias','SPAIN','38670','617441150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 14:02:15',0,NULL,3,1,4,1,NULL,'背景架  （白）   2m   1\r一转四 灯头  1\r115w 220v  2\r2m 灯架   1\r单灯头  2  欧标\r反光伞   1\rlighting kit  $25\rYW864614922CN\r\r '),(5040,660817873002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','yankeerutter','yankeerutter@aol.com','GEORGE RUTTER','395 Essex St<br>Centerville Woods APT#102B','Beverly','MA','UNITED STATES','01915','(978) 998-4719','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 14:29:56',0,NULL,3,1,1,1,NULL,'lenspen   2 '),(5042,619974688001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',74.9,'hermeshine','dinmarisa','dinaelmarcela@hotmail.com','Dinael Andrade de Lima','Rua Joaquim Ferreira Gomes 685<br>bloco D apt 21','Sumare','Sao Paulo','BRAZIL','13171120','19-3873-9623','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 14:53:55',0,NULL,3,1,5,1,NULL,'2m 弹簧灯架  2 \r红盒\rCP219487421CN\r'),(5043,621291175001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','chitalina','denisesaura@gmail.com','Denise Bernardes Chaves','Rua Visconde de Nacar, 1200 / 105 Bairro Centro','Curitiba','PR','BRAZIL','80410-201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 14:54:08',0,NULL,3,1,5,1,NULL,'2m x 3m 背景架   1 \rCP219487727CN\r'),(5044,718766276015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.89,'hutongstore','vichento0','vianton@hotmail.com','David Anton Rovira','Ruperto Chapi, 16-5','Elche','Alicante','SPAIN','03201','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 15:28:30',0,NULL,3,1,2,1,NULL,'优永佳 b    1  N1  '),(5045,660838802002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 15:39:53',0,NULL,8,1,17,0,NULL,'肩架   1 '),(5046,621306179001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 15:43:05',0,NULL,8,1,18,0,NULL,NULL),(5050,721175560015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','kumi-tarzan','kumitarzan@gmail.com','Markus Lehtinen','Lounaankatu 1 a 13','Lahti','','FINLAND','15150','+358407438006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 16:51:07',0,NULL,3,1,3,1,NULL,'肩架  1 RR843877503CN\r'),(5051,621338522001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lostbider','oliverpenny7738@yahoo.com','SZE-HUA WU','8650 Spicewood Springs Rd<br>Ste 122','Austin','TX','UNITED STATES','78759-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 17:16:46',0,NULL,3,1,1,1,NULL,NULL),(5052,660872108002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','serg204','k2041@bezeqint.net','Sergei Katsov','Tapuah 3/8','Arad','-Israe','ISRAEL','80700','972-050-493-4474','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:16:46',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞    1 RR843877962CN\r'),(5053,660874657002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 17:20:05',0,NULL,3,1,3,1,NULL,'肩架    1\r580肥皂盒  1\r52mm 接口环   1\r52mm +8   1\r77mm 环架   1\r58mm 环架  1\rND2/4/8   1\r RR843877843CN\r'),(5054,660875797002,120601699344,'JueYing Lambency Flash Diffuser for 430EX F36AM P2',1,'AB3308',22,'hermeshine','kirillk09','kkirsanov2@gmail.com','Kirill Kirsanov','Dzhambula street 221, apt. - 17','Almaty','','KAZAKHSTAN','050009','+77776876333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:25:27',0,NULL,3,1,3,1,NULL,'碗罩  P2   1 RR843877565CN\r'),(5055,621348260001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ivanhurba1976','ivanhurba@gmail.com','Ivan José Hurtado Barón','Carmenes de Rolando n 33','Granada','Andalucía Ceuta y Melilla','SPAIN','18011','958208210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 17:40:17',0,NULL,3,1,3,1,NULL,'肩架  1 RR843877432CN\r'),(5056,660889351002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',21.96,'hermeshine','arildberdahl','arild.berdahl@gmail.com','Arild Berdahl','Leitetunet 17<br>H0201','Bodø','','NORWAY','8009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 17:57:44',0,NULL,3,1,3,1,NULL,'lenspen   4 RR843877653CN\r'),(5057,707064418016,260687503075,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',28.99,'hutongstore','dadoomars','daddoo@orange.fr','Decourdemanche Daniel','29 traverse Olive','Marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13013','0491705288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-18 17:58:15',0,NULL,3,1,3,1,NULL,'3m 横杆   1 RR843877548CN\r'),(5058,621375630001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','tipsinartok','catchthewind@shaw.ca','Lindsay Wilson','12-815 Lodi Avenue','Victoria','BC','CANADA','V8Z 6T3','(250) 483-3453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 18:42:18',0,NULL,3,1,2,1,NULL,NULL),(5059,660919252002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 19:00:37',0,NULL,3,1,3,1,NULL,'100-150 5in1  反光板  1 RR843877605CN\r'),(5060,721252597015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','2010ish','ish.ib@hotmail.co.uk','Ismail Ibrahim','23, Malmesbury Road','Gloucester','Gloucestershire','UNITED KINGDOM','GL4 6BH','01452534723','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 19:14:40',0,NULL,3,1,2,1,NULL,'2m 灯架  2\r单灯头  2\r反光伞   2\rCP219487744CN\r\r '),(5061,660929332002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','yu_yong','yu_yong@hotmail.com','yu_yingli yu','1605 26 st.se.','calgary','AB','CANADA','T2A5W5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 19:20:53',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5062,621419545001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','micky62910','mickadubruck@hotmail.fr','mickael dubruck','163 rue de loosthoucq','eperlecques','Nord-Pas-de-Calais','FRANCE','62910','0321936579','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 20:11:11',0,NULL,3,1,4,1,NULL,'2m 灯架  1 白盒 RR843878248CN\r'),(5063,621434180001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','jgim7923','shop@surfmaktub.com','Juan Manuel Giménez','Rambla Turo 12, primero segunda','Montgat','Cataluña','SPAIN','08390','660171552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 20:40:12',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(5064,660970460002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','grahamjbell','graham@bell1.demon.co.uk','Graham Bell','1440 N Gardner St<br>Apt 201','Los Angeles','CA','UNITED STATES','90046-4153','(323) 697-6944','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 20:44:27',0,NULL,3,1,1,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864614966CN\r'),(5065,660973501002,120536002412,'New Neoprene Camera Neck Strap for D80 D90 D300 D700',1,'AB1403',9.9,'hermeshine','aykut2011','aykut_erk@hotmail.com','aykut erken','kurtulus mah.<br>turgut sok.no:1','izmir','bergama','TURKEY','35700','+905424820530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 20:51:11',0,NULL,3,1,2,1,NULL,'nikon 肩带  黄字   1 '),(5066,621442410001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',2,'AC1301',17.38,'hermeshine','fotofog712','fotofog@yahoo.com','Fernando Orrego','Juan de Luigi  3675','Santiago','Metropolitana','CHILE','7830063','5622216999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 20:58:27',0,NULL,3,1,2,1,NULL,'中号内胆包 无字   2 '),(5067,721318950015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.5,'hutongstore','jamie1178','jamie@hutchin6.orangehome.co.uk','james hutchin','35 Danesbower Lane Blofield','Norwich','Norfolk','UNITED KINGDOM','NR13 4LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-18 21:01:40',0,NULL,3,1,2,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843878945CN\r'),(5068,660979403002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','emretunali','emrekarizma_1992@hotmail.com','Emre Tunalı','İnkılap Mah. Harputlu Cad. No:22','Bergama','İzmir','TURKEY','35700','5079509376','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:06:03',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843877980CN\r'),(5069,620595318001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',53.94,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 21:14:22',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843879005CN'),(5070,621457434001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',107.96,'hermeshine','sezeryadigar10','sezeryadigar@hotmail.com','Sezer Yadigar','telsiz mah. 85/10 sk. no:2 d:3<br>zeytinburnu','istanbul','Marmara','TURKEY','34025','+905556848606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:34:01',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r斜臂  2\r发两个国内小包挂号 RR843877415CN\rRR843878968CN\r'),(5071,621461886001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','igabi600','gl6600@gmail.com','Gabriel Leventhal','Radak 10/4<br>Azza 30/4','Jerusalem','','ISRAEL','92382','(026) 274-042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 21:45:56',0,NULL,3,1,3,1,NULL,'国内小包挂号 RR843877976CN\r'),(5072,621466033001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bubble_wrap21','bubble_wrap21@hotmail.com','Alisha Lange','6480 Troy Sidney Rd','Piqua','OH','UNITED STATES','45356-9213','','NoPaymentFailure','CheckoutIncomplete','Other','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843877361CN\r'),(5073,661006480002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 22:13:11',0,NULL,8,1,17,0,NULL,''),(5074,661013146002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','mariettapm82','mariettapm@hotmail.com','MARIA PEREZ MARTIN','CALLE ZARAGOZA, 21-5','TORRENT','Comunidad Valenciana','SPAIN','46900','656903644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:27:12',0,NULL,3,1,3,1,NULL,'2mx3m 白色背景布 厚的  1RR843877596CN\r '),(5075,621478640001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','lesrechinsp','paul.menager@gmail.com','Menager Paul','18 rue gérald thiboutôt','blainville','QC','CANADA','J7C0G4','(514) 815-3989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:32:12',0,NULL,3,1,2,1,NULL,'40cm 棚 1 '),(5076,621480249001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','phwocean','pyroskater00@yahoo.com','Weston Sheldon','1400 Hancock Blvd<br>LEAVE PACKAGE AT OFFICE','Daytona Beach','FL','UNITED STATES','32114-5648','(404) 735-5107','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 22:37:16',0,NULL,3,1,1,1,NULL,NULL),(5077,621482571001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:44:38',0,NULL,8,1,17,0,NULL,NULL),(5078,621485389001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kovic123','kimkovic@optusnet.com.au','Kim Kovic','178 A\'Beckett Road','Narre Warren Nth','Victoria','AUSTRALIA','3804','0397968869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-18 22:55:16',0,NULL,3,1,4,1,NULL,' canon D8 单肩包  1 \r77mm 橡胶罩    1\r摄影背心 canon 黑色薄款 xxl    1\rbag  $20\rYW864489600CN\r'),(5079,621486731001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'== '),(5080,661023630002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ollazc','cont3stant@hotmail.com','Oliver Tsupsman','Kaluri 20','Haapsalu','Läänemaa','ESTONIA','90502','+37253653162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 22:59:49',0,NULL,3,1,2,1,NULL,' '),(5081,621495477001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cgro9131','chantalgrondin@tlb.sympatico.ca','Chantal Grondin','4, chemin du Lac Sport','Lac St-Paul','QC','FRANCE','j0w1k0','819 585 2347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-18 23:27:10',0,NULL,3,1,2,1,NULL,NULL),(5082,661035922002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','rachelmlewis87','armywife32808@aol.com','Rachel Lewis','5546 McCullough Dr<br>Apt B','Colorado Springs','CO','UNITED STATES','80902-1632','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-18 23:41:23',0,NULL,3,1,1,1,NULL,'60cm 2in1   1 '),(5084,661053254002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','foltynet','foltynet@gmail.com','Tomer Foltyn','58 Shderot Benyamin','Netanya','','ISRAEL','42314','972-50-5810058','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 00:47:29',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843877429CN\r'),(5085,661063956002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','gajanandi','gaja@live.ca','RAJAKULENTHIRAN POOPALU','1906- 320 DIXON ROAD','ETOBICOKE','ON','CANADA','M9R 1S8','(416) 877-8846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 01:28:37',0,NULL,3,1,5,1,NULL,'RR843877755CN '),(5086,661062448002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','jamal2588','jamalross@hotmail.com','Jamal Ross','28 Winchester House<br>Beaufort street','London','London','UNITED KINGDOM','Sw3 5bj','07950870422','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 01:50:08',0,NULL,3,1,4,1,NULL,'717ah   1 \rball head  $20\rYW864614933CN\r'),(5087,661074035002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','dave77177','dave7717@hotmail.com','David Leblanc','222 Ottawa<br>app 2','cowansville','QC','CANADA','J2K2C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:04:13',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5088,621541212001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','xoselaf','xoselaf@yahoo.es','José Luis Álvarez Fernández','C./ M. R. Sinde, 17','A Guarda','Galicia','SPAIN','36780','660212816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:32:12',0,NULL,3,1,2,1,NULL,'717ah   1 \rball head  $20\rYW864614933CN\r'),(5089,661080348002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','evets','s_t_e_v_e_h@hotmail.com','Stephen Hurne','203 Park St','south Melbourne','Victoria','AUSTRALIA','3205','0431600170','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 02:38:17',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864614966CN\r'),(5090,621551254001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ckshene','shene@acm.org','Ching-Kuang Shene','19226 Copper Ridge Road','Houghton','MI','UNITED STATES','49931','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 03:12:43',0,NULL,3,1,1,1,NULL,NULL),(5092,621558723001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','spillnermail','marko.peter@yahoo.com','Peter Marko','Unit 25, 27-51 Charles Street','Melbourne/Bentleigh East','Victoria','AUSTRALIA','3165','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-19 03:47:30',0,NULL,3,1,3,1,NULL,'3m 横杆   1 RR843877548CN\r'),(5093,621562328001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dopeynsleepy','briand917@gmail.com','Brian Doyle','74 S 3rd St<br>Apt 1','Brooklyn','NY','UNITED STATES','11211-5103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 04:10:39',0,NULL,8,1,17,0,NULL,'2mx3m 白色背景布 厚的  1RR843877596CN\r '),(5094,621562277001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','dopeynsleepy','briand917@gmail.com','Brian Doyle','74 S 3rd St<br>Apt 1','Brooklyn','NY','UNITED STATES','11211-5103','','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 04:10:39',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r斜臂  2\r发两个国内小包挂号 RR843877415CN\rRR843878968CN\r'),(5095,621563636001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','helias007','heliasfotografo@hotmail.com','Elias Huaman Corterreal','Jr Hermenegildo Rojas 125<br>distrito Carabayllo','Lima','Lima','PERU','51','5440277','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 04:10:44',0,NULL,3,1,3,1,NULL,'RR843877755CN '),(5096,621570208001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sjursen','kent.erik@sjursendesign.no','Kent-Erik Sjursen','Bekkefaret 3','Mo i Rana','Nordland','NORWAY','8618','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 04:50:50',0,NULL,3,1,3,1,NULL,'2m 灯架  2\r4灯头棚  英标   2\r115w 220v   4\r45w 220v   4\r 包   1\rlighting kit  $30\rYW864614955CN\r\r '),(5097,661119963002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pedry85','dcpedry@gmail.com','Daniel Pedry','1959 Wellington Ln<br>Unit 4','Vista','CA','UNITED STATES','92081-7930','(760) 672-7208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 05:44:20',0,NULL,3,1,1,1,NULL,NULL),(5099,661120675002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','h.k.pikal','hubert@pikal.com','H.K.Pikal - Clay River Studio','906 Koerner Ln','Austin','TX','UNITED STATES','78721','','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 05:48:00',0,NULL,3,1,4,1,NULL,'tripod  $20\rYW864614970CN\r '),(5100,621585403001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','anderson*calvin','anderson.calvin@gmail.com','Calvin Anderson','6331 Hollywood Blvd','Los Angeles','CA','UNITED STATES','90028-6321','(323) 960-3500 ext.: 0000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 06:37:18',0,NULL,3,1,1,1,NULL,NULL),(5102,661138584002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','nnazmy','ayob.nazmy@gmail.com','AYOB NAZMY NANYAN','20/70 Grange Boulevard','Bundoora','Victoria','AUSTRALIA','3083','0430788084','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 07:50:22',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864614944CN\r'),(5103,621606821001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','maccess8','m.kastner@gmx.at','Markus Kastner','Mitterdörfl 31','Bad Kreuzen','','AUSTRIA','4362','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 08:52:24',0,NULL,3,1,2,1,NULL,'单灯头 欧标 1 '),(5104,660302026002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','cubicwarlock','cubicwizard@gmail.com','Shilin Alexandr','800-letiya Moscow str., house 14, flat 93','Moscow','Moscow','RUSSIAN FEDERATION','127247','+79031513000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 09:15:21',0,NULL,3,1,3,1,NULL,' RR843877675CN'),(5107,721545589015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','luigi73452','l.burgi@tin.it','Luigi Filippo Burgi','Via Lombardia 66','Corgeno - Vergiate','Varese','ITALY','21029','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 10:08:33',0,NULL,3,1,2,1,NULL,'45w   2'),(5109,621622873001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelić','Trg Republike 1','Županja','Slavonija','CROATIA','32270','00385032845640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 10:13:14',0,NULL,8,1,17,0,NULL,NULL),(5110,621623195001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelić','Trg Republike 1','Županja','Slavonija','CROATIA','32270','00385032845640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 10:14:48',0,NULL,3,1,2,1,NULL,'55mm 橡胶罩   2 '),(5111,661167650002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','hildham','hamin@hildgrim.com','Hamin Mousavi','Spangatan 1B LGH1701','Malmo','','SWEDEN','21144','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 10:25:08',0,NULL,3,1,3,1,NULL,' \rRR843877790CN\r'),(5112,661168074002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','macratus','peter@macadam.se','Peter Adamsson','Mölledalsgatan 41','Malmö','','SWEDEN','212 40','+46705417441','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 10:25:50',0,NULL,3,1,3,1,NULL,' RR843877809CN\r'),(5114,621634706001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','tictac7775','laura.grassi@gmail.com','Massimiliano Cappello','via De Amicis 71','Sedriano','Milano','ITALY','20018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 11:10:18',0,NULL,3,1,2,1,NULL,NULL),(5116,661184524002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','georgebwmf','gcrook13@hotmail.com','George  Z Hantzis','Dilvoi 13-15 Byron','Athens','Greece','GREECE','16232','010 - 7629640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 11:41:23',0,NULL,3,1,2,1,NULL,'72mm 环架  1\r渐变灰  + ND4 + ND8  '),(5117,621648386001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','tommy1919ros','sergeyyurchenkoros@gmail.com','Sergey Yurchenko','Komarova 11, flat 109','Rostov-on-Don','RU','RUSSIAN FEDERATION','344092','(863) 235-68-34','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 12:08:06',0,NULL,3,1,2,1,NULL,'品胜3.0 膜  1 '),(5118,621651122001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',5.9,'hermeshine','pwords','sgani@mail25.com','Sohail Gani','9003 Hampton Landing Dr E','Jacksonville','FL','UNITED STATES','32256','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 12:19:34',0,NULL,3,1,1,1,NULL,'万用柔光罩  1\r新的，我来吧 '),(5119,661194800002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','surfer_jokin','surfer_jokin@hotmail.com','jokin guinea fernandez','KUKADA Bizenta Mogel 8 bajo','Vitoria','País Vasco','SPAIN','01008','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 12:23:12',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489622CN\r'),(5120,621651131001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','g8chu','g8percy@gmail.com','Wai Yin Chu','4/72-74 Carlisle Street<br>St Kilda','Melbourne','Victoria','AUSTRALIA','3182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 12:25:13',0,NULL,3,1,2,1,NULL,'气吹+ 布  1 '),(5122,661196161002,120497752222,'62mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1304',4.35,'hermeshine','acgenealogy','brianhildick@talktalk.net','Brian Hildick','52,Coniston Rd.,','Barnehurst, Bexleyheath','Kent','UNITED KINGDOM','DA7 6PY','01322332293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2011-01-19 12:27:51',0,NULL,3,1,2,1,NULL,NULL),(5123,721615013015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','yl3bf','yl3gbf@one.lv','Janis Bruders','O.Kalpaka 99A, flat 4','Liepaja','','LATVIA','LV3405','(371)29495926','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 13:57:22',0,NULL,3,1,3,1,NULL,' RR843877715CN\r'),(5124,661233793002,120564178467,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fkaviani50','fk1002000@yahoo.com','Fred Kaviani','117c South Route 70','Marlton','NJ','UNITED STATES','08053-3024','(856) 396-2490','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 14:45:27',0,NULL,3,1,1,1,NULL,NULL),(5126,661234197002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','tdllondru','ferranitu@gmail.com','Ferran Pérez','c. Sant Narcis 16, 1º 1ª','Argentona','Cataluña','SPAIN','08310','937560942','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 14:49:16',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489633CN\r'),(5127,661260031002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','danibram','nemz00@gmail.com','Daniel Biedma Ramos','CLur gorri 28 3D','Barañain','Navarra','SPAIN','31010','948074685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 16:06:44',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5128,661264851002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','airmel','mooney56u@aol.com','Mark Lester','6197 Palau St','Cypress','CA','UNITED STATES','90630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 16:19:54',0,NULL,3,1,1,1,NULL,NULL),(5129,621733073001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','krokys2010','bivibo@yandex.ru','VITALIY BILYK','vul. Konyakina 14a/85','Lutsk','','UKRAINE','43023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 16:56:37',0,NULL,3,1,2,1,NULL,NULL),(5130,621736909001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','popihmt','popihmt@hotmail.com','Hugo Mañez Tamariz','Avda/ Sierra de Aralar<br>nº21 / 2º C','san Sebastián','País Vasco','SPAIN','20014','617222008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 17:05:36',0,NULL,3,1,2,1,NULL,NULL),(5131,621737655001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','orlando-42','mtansley@mtansley.ca','Michael Tansley','43 Tudor Avenue','Ajax','ON','CANADA','L1S 2A2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 17:07:21',0,NULL,3,1,2,1,NULL,'大号灰卡   1 '),(5132,621762278001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cdmira01','corbinmiranda@aol.com','Corbin Miranda','5701 Delhi Rd<br>Seton Hall Box #329','Cincinnati','OH','UNITED STATES','45233-1669','(502) 457-9845','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 18:07:47',0,NULL,3,1,1,1,NULL,NULL),(5134,661320941002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','marina7345','marinamitsakaki@hotmail.com','Marina Mitsakaki','Dahliastraat 40','Eindhoven','','NETHERLANDS','5644 PP','0031657032377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 18:38:36',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5135,661322565002,120581555897,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','athalakian','gathalakian@yahoo.fr','gerard athalakian','68628 J St','Cathedral City','CA','UNITED STATES','92234-2015','(760) 202-7478','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 18:40:46',0,NULL,3,1,1,1,NULL,'77接口环  1 '),(5136,621795985001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','stparadox1','z.man2@centrum.cz','Zdenek Konecny','Slunecna 16','Hodonin','','CZECH REPUBLIC','69501','042 739 131 135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 19:19:38',0,NULL,3,1,2,1,NULL,NULL),(5137,661368626002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','christian26042010','christian@olsendesign.com','Christian Olsen','Rue schaub 6','Genève','','SWITZERLAND','1202','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 20:14:06',0,NULL,3,1,4,1,NULL,'717AH   1 \rballhead  $20\rYW864489644CN\r'),(5138,621832437001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','johnypr07','jonathan_mora7@hotmail.com','Andress Bourasseu','Ruiz Velviz  #118<br>Rio Piedras','San Juan','PR','PUERTO RICO','00917','(787) 675-2897','NoPaymentFailure','CheckoutComplete','Other','2011-01-19 20:36:26',0,NULL,3,1,8,1,NULL,'2m 灯架  2\r50-70 棚   2\r115w 110v   2 \r包   1\rCP219487713CN\r'),(5139,661382036002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','rover46','ferz46@mail.ru','Konstantin Grachev','240, korp. 1649','Zelenograd','Moscow','RUSSIAN FEDERATION','124365','74997172781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 20:43:04',0,NULL,8,1,17,0,NULL,''),(5140,621835225001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rover46','ferz46@mail.ru','Konstantin Grachev','240, korp. 1649','Zelenograd','Moscow','RUSSIAN FEDERATION','124365','74997172781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 20:43:05',0,NULL,3,1,3,1,NULL,' 2m 灯架 1\rb座   1\r柔光伞   1 \r80cm 5in1    1\rRR843877772CN\r未发出去，燕文退回来了2月18日，等客户问退钱吧。\r'),(5141,621844184001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','aleksey_fotograf','zaharov-aleksey-foto@yandex.ru','Aleksey Zakharov','Polesskaja 12/42','Orjol','RU','RUSSIAN FEDERATION','302028','74862457518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 20:59:30',0,NULL,3,1,2,1,NULL,' '),(5142,621844646001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','thiagomu','tsframos@hotmail.com','THIAGO RAMOS','RUA JOSE VARGAS DE FIGUEIREDO<br>NUMBER 46','VARRE-SAI','RIO DE JANEIRO / RJ','BRAZIL','28375000','(22)3843-3321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 21:00:18',0,NULL,3,1,2,1,NULL,'大力夹  2 '),(5144,721830974015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','brianw7537','wilkinson150@btinternet.com','BRIAN WILKINSON','22 BUDDLE ST','CONSETT','Durham','UNITED KINGDOM','DH87JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-19 21:01:56',0,NULL,3,1,2,1,NULL,NULL),(5145,707683977016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','idlm2010','idlm2010@hotmail.com','David Alonso','C Andres Benito 24','Zaragoza','Aragón','SPAIN','50016','976588792','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 21:31:12',0,NULL,3,1,2,1,NULL,'canon 小包  1 '),(5148,621865439001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',70,'hermeshine','lakesdales','info@thelakesanddales.com','Simon Wells','The Sheiling<br>Thornton in Lonsdale','Ingleton','North Yorkshire','UNITED KINGDOM','LA6 3PB','01524241906','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-19 21:49:58',0,NULL,3,1,3,1,NULL,'nikon 老款摄影背心 xl \r2\rRR843876159CN\r'),(5149,661423132002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','vakomin','vadim.mynyaylovsky@gmail.com','Vadim Mynyaylovsky','7b-12 Shoalej Shimshon','Kfar Saba','','ISRAEL','44391','972-526989867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 22:11:47',0,NULL,3,1,3,1,NULL,'50-70 棚  塑料卡口  1 \rRR843877724CN\r'),(5150,621880996001,110464615814,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',8.69,'hermeshine','bredb71','bre_7171@yahoo.com','bryan balzomo','6925 Haskell Ave<br>Apt 109','van nuys','CA','UNITED STATES','91406-5076','(818) 300-7523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-19 22:34:06',0,NULL,3,1,1,1,NULL,'中号内胆包 无字   1 '),(5151,661437648002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','nigelflus','nigelflus@yahoo.es','NIGEL FELIX LORENZO O´FLAHERTY','AVENIDA TANAUSU Nº21','LOS LLANOS DE ARIDANE','','SPAIN','38760','699089808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 22:52:16',0,NULL,3,1,4,1,NULL,'tripod $16 \rYW864489655CN\r'),(5152,661450044002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nina-0047','ninae-k@online.no','nina karlsen','godøynes','tverlandet','bodø','NORWAY','8050','004790293266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 23:33:55',0,NULL,3,1,3,1,NULL,'50-70 棚  塑料卡口  1  \rRR843877738CN\r'),(5153,707740408016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','thepishkin','chrisx2@gofree.indigo.ie','Chris Slattery','4 Hill View Woodlawn','Killarney','Co Kerry','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-19 23:48:13',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5154,621903705001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','modelbear','ebay@modelbear.com','Pierre Lacroix','39-2296 Orient Park Dr.','Gloucester','ON','CANADA','K1B4N6','(613) 834-5550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-19 23:51:48',0,NULL,3,1,2,1,NULL,NULL),(5155,621908201001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','hideriders','zzpapi@gmail.com','HIDEAKI KODAMA','7811 Kew Forest Ln<br>Apt 3DA','FOREST HILLS','NY','UNITED STATES','11375-6171','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-20 00:11:32',0,NULL,3,1,1,1,NULL,'40cm  棚  1 '),(5156,661460675002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','fbk43','fbkerr@tds.net','Francis B. Kerr','406 N Grove Blvd','Kingsland','GA','UNITED STATES','31548','(912) 729-4103','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 00:15:01',0,NULL,3,1,1,1,NULL,' '),(5158,621920381001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','dsims9t','dsims@sleekworks.com','David Sims','1450 Springfield Dr<br>Apt 146','Chico','CA','UNITED STATES','95928-7313','(707) 321-6237','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 01:04:33',0,NULL,3,1,1,1,NULL,' '),(5159,661478920002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',13.9,'hermeshine','bnbjones291','bnbjones29@hotmail.com','Benjamin Jones','683 Chestnut St','Liberty Center','OH','UNITED STATES','43532-9779','(419) 613-7022 ext.: 20','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 01:29:50',0,NULL,3,1,1,1,NULL,'90th 肩带  1 '),(5160,661484927002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','fa1len_ange1','davidgwon@hotmail.com','Joon Gwon','6001C 194th St<br>Apt 3C','FRESH MEADOWS','NY','UNITED STATES','11365-2812','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-20 01:54:02',0,NULL,3,1,1,1,NULL,'canon 三角包  1 '),(5161,621938801001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','ozricsfan','ozr1csfan@yahoo.com.au','Mr. A G Boyd','55 LOWAN Avenue<br>ph: 0418373709','TEMPLESTOWE LOWER','Victoria','AUSTRALIA','3107','0418373709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 02:34:34',0,NULL,3,1,2,1,NULL,NULL),(5162,661497863002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 02:45:10',0,NULL,3,1,5,1,NULL,'2m 灯架 2\rb座   2\r柔光伞  2 \rCP219487700CN\r'),(5163,661490746002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','bigrexj','rexdjohnson@gmail.com','Rex D. Johnson','1050 Techwood Dr NW<br>C/O Turner Broadcasting Systems, Inc. Ste 300','Atlanta','GA','UNITED STATES','30318-5604','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 03:10:19',0,NULL,3,1,1,1,NULL,' '),(5164,661506878002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','anissang','anissangarcia@gmail.com','anissa garcia','5933 Amos Ave','Lakewood','CA','UNITED STATES','90712-1322','(562) 972-2099','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 03:22:18',0,NULL,3,1,1,1,NULL,NULL),(5165,621956000001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','pukeko2','fulcher@xtra.co.nz','mike fulcher','16 Putter Place<br>Howick','Auckland','','NEW ZEALAND','2013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 03:45:32',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5166,621966745001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fieldmouth','love@remus.dti.ne.jp','Masaharu Noguchi','2-73-3 Higashionari','Saitama City','Saitama','JAPAN','331-0814','(048)663-3139','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 04:46:59',0,NULL,3,1,3,1,NULL,'肩架  1 \rRR843877769CN\r'),(5167,661530424002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','fugenie','fugenie@gmail.com','Eiji Iwakawa','3-30-14, CoreCity Nakano Sakaue 702<br>Honcho, Nakano-ku','Tokyo','Tokyo','JAPAN','164-0012','0351566986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 05:31:31',0,NULL,3,1,2,1,NULL,'c型夹   1 '),(5169,661533730002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jmil5514','miller.j914@yahoo.com','joshua miller','1498 BOX CIRCLE','winder','GA','UNITED STATES','30680','(404) 839-7036','NoPaymentFailure','CheckoutComplete','Other','2011-01-20 05:50:34',0,NULL,3,1,3,1,NULL,'肩架  1 \rRR843877857CN\r'),(5171,621977422001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',171.9,'hermeshine','kittynlucy','samieami@uqconnect.net','Samantha Whittaker','5 Henry Court','Glasshouse Mountains','Queensland','AUSTRALIA','4518','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 07:19:32',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r双灯头 澳标  2\r反光伞  2\r包  1\r背景架 2m （ 白 黑 绿）  1\rlighting kit  $30\rYW864489714CN\r\r '),(5172,621988440001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','ulti1980','pavel.marintsev@gmail.com','pavel marintsev','26 mkr., dom 2, kv.82','aktau','','KAZAKHSTAN','130000','+77013042266','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 07:19:57',0,NULL,3,1,5,1,NULL,'背景架 （ 白）  2m  1\r布是1.6x3m的\r2m 灯架  2\r50-70 棚欧标  2\r115w 220v   2\r包   1\r CP219487673CN\r'),(5173,661552182002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ad_riano','adrianotorii@hotmail.com','Adriano Leite','Av. 11 de Junho, 875<br>(apto 122)','São Paulo','São Paulo','BRAZIL','04041-053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 08:03:34',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5174,722032837015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','ninjastyle.7930','natachiavecsi@hotmail.co.uk','Natachia Vecsi','6 Greenacre Close','Herne Bay','Kent','UNITED KINGDOM','CT6 7EP','07930390322','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-20 08:43:23',0,NULL,3,1,4,1,NULL,'背景架（ 白， 黑 ，灰） 2m   1 \rbackground support\r $22\rYW864489294CN\r'),(5175,661558684002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','qwq1122','zxxb111@gmail.com','mansour albuainasn','Bulding 8448 , Unit 1<br>3886-35514','jubail','','SAUDI ARABIA','35514','+966505903606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 08:44:05',0,NULL,5,1,18,0,NULL,'== '),(5176,622004300001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','paradoo','chipie_md@hotmail.com','Panuwat  Triwatcharaporn','17     Dej-udom  Rd.<br>Naimueng  sub-district.','Mueng','Nakornrachasima','THAILAND','30000','(+66)44255834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 09:02:00',0,NULL,3,1,2,1,NULL,NULL),(5177,722041864015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK Syntagma','ATHENS','','GREECE','10557','306972999050','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-20 09:26:11',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云台   1\r柔光伞   1 RR843876255CN\r'),(5178,661567666002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','iereminciucc','iereminciuc_catalin@yahoo.com','Ignat Vladimir','B-dul. I.C. Bratianu, NR. 61C, Bl. MA4, Sc. B, Et.2, Ap.25','Constanta','Constanta','ROMANIA','900247','0040722679517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 09:47:36',0,NULL,3,1,2,1,NULL,NULL),(5179,661578988002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 10:34:23',0,NULL,3,1,2,1,NULL,'b座   2 '),(5180,661586666002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 11:08:47',0,NULL,3,1,3,1,NULL,'反光板支架  1\r2m灯架  1 RR843876180CN\r'),(5181,661591973002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','belia74','debeli74@hotmail.com','Carlos Daniel Cejas Rodero','Pablo Picasso 2 dto 9<br>Pablo Picasso 2 dto 9','Caleta de Fuste - Antigua','Canarias','SPAIN','35610','','NoPaymentFailure','CheckoutIncomplete','OtherInternational','0000-00-00 00:00:00',0,NULL,8,1,17,0,NULL,''),(5182,622036727001,110517146857,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',52.99,'hermeshine','rusty270173','rusty_sandy1@bigpond.com','Russell Brigg','48 Cobb St Nth','Murgon','Queensland','AUSTRALIA','4605','0741683773','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-20 11:48:17',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r云天  1\r柔光伞   1 RR843876193CN\r'),(5183,622048021001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','belia74','debeli74@hotmail.com','Carlos Daniel Cejas Rodero','Pablo Picasso 2 dto 9<br>Pablo Picasso 2 dto 9','Caleta de Fuste - Antigua','Canarias','SPAIN','35610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 12:35:50',0,NULL,3,1,4,1,NULL,'2m 灯架  1\rb座  1\r柔光伞    1 \r2m x3m 背景架   1 \rlighting kit  $25\rYW864489703CN\r'),(5184,661602738002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','helperi','seppo.helpio@iki.fi','Seppo Helpiö','Salomaantie 5 H 57','Valkeakoski','Pirkanmaa','FINLAND','37630','0400632565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 12:23:37',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞   1 RR843876202CN\r'),(5185,661610155002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',8,'AA1310',43.92,'hermeshine','fulviopp74','fulviopp@gmail.com','FULVIO PARMEJJANI','RUA HERMETO GUILHERME, 35<br>PQ XANGRILA','CAMPINAS','SP','BRAZIL','13098604','551932570422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 13:18:14',0,NULL,3,1,3,1,NULL,'lenspen  8 RR843876278CN\r'),(5186,707979111016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','fsmsteve','allwrights@hotmail.co.uk','stephen allwright','23 Vicarage close','Langford','Bedfordshire','UNITED KINGDOM','SG18 9QS','01462700767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 15:33:03',0,NULL,3,1,2,1,NULL,''),(5187,722149533015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','bernard0368','bernard0368@yahoo.ie','Bernard Roche','25 Belfry Square City West','Dublin ','Dublin','IRELAND','d24','0868547474','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-20 15:43:32',0,NULL,3,1,2,1,NULL,NULL),(5188,622105843001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','aircruiser1','justin.le@iinet.net.au','Justin Le','UNIT 1, 38 TENNANT ST<br>WELSHPOOL','PERTH','Western Australia','AUSTRALIA','6106','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 16:10:27',0,NULL,3,1,3,1,NULL,'2m 灯架  1 RR843876304CN\r'),(5189,622108549001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','zgman77','zgerman@live.com','Zoltan German','1122 Pierce Ave<br>Fl 2','Bronx','NY','UNITED STATES','10461-1525','(646) 350-5736','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 16:17:25',0,NULL,3,1,1,1,NULL,'\r'),(5190,661551963002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',71.9,'hermeshine','ladybugie*','lu.desousa@gmail.com','Luciana de Sousa','Rua São Clemente 10, ap. 409, Botafogo','Rio de Janeiro','RJ','BRAZIL','22260-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 16:28:51',0,NULL,3,1,5,1,NULL,'红头灯  1   800  110  6 \rCP219487660CN\r'),(5191,622134614001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','shaharstroh','shaharstroh@gmail.com','Shahar Stroh','45 Hicks St<br>Basement Level','Brooklyn','NY','UNITED STATES','11201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 17:30:47',0,NULL,3,1,1,1,NULL,'\r'),(5192,661695425002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','busterml2010','matthijs@liethof.net','Matthijs Liethof','Horizon 32','ELST GLD','','NETHERLANDS','6661PA','0651088990','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r斜臂   1\r50-70 棚    1 \rEE442466426CN\r'),(5194,622163588001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','janaka44','janaka44@gmail.com','JANAKA PEIRIS','IFS R&D INTERNATIONAL<br>501, GALLE ROAD','COLOMBO-6','','SRI LANKA','00600','94727855424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 18:42:35',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5195,661750208002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','erin5296','erin.conley@yahoo.ca','erin','11 beach drive','furry creek','BC','CANADA','v0n3z1','(604) 880-8244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 19:42:03',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5196,622197860001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mo_tord','tord_cj@hotmail.com','Christer Johansson','Saltfjellveien 28','Mo i Rana','Rana','NORWAY','8613','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 19:57:14',0,NULL,3,1,3,1,NULL,'反光板支架   1 RR843876162CN\r'),(5197,661760877002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','coppernico','peace4pr@yahoo.com','Jaime Ruiz','PMB 162 - Box 80,000','Isabela','PR','UNITED STATES','00662','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 20:05:15',0,NULL,3,1,1,1,NULL,'小号内胆包 canon  1 '),(5198,661787387002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','oshten','o_s_h@list.ru','Sergey Skritskiy','Pionerskaya st. 379/2-98<br>Republic Adygea','Maykop','RU','RUSSIAN FEDERATION','385011','79094711069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 21:03:37',0,NULL,3,1,2,1,NULL,'麂皮  2 '),(5199,661784444002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','sercan.akar','sercanakar@hotmail.com','Sercan Akar','Mesrutiyet Mah. Ruzgarlimese Cami alti<br>Ugur Market','Zonguldak','Merkez','TURKEY','67030','(372) 253 - 5679','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 21:15:08',0,NULL,3,1,2,1,NULL,'canon 三角包   1 '),(5200,708166733016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','pennyblackcat','ianandrew.perry@ntlworld.com','Ian A Perry','90 Smithies Moor Lane','Batley','West Yorkshire','UNITED KINGDOM','WF17 9AN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 21:44:05',0,NULL,3,1,2,1,NULL,NULL),(5201,661802010002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','omnialx','alexcahiz+ebay@gmail.com','Alexander Cahiz','18 Alcott St<br>Apt 1','Allston','MA','UNITED STATES','02134-1420','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-20 21:54:44',0,NULL,3,1,1,1,NULL,'c型夹   2 '),(5202,708179435016,260660053110,'New IR Remote Control for Pentax K10D K20D K200D',1,'AA2205',2.75,'hutongstore','frankdthebruce','fdpatton@hotmail.com','frank patton','206 burnfield road','glasgow','Glasgow (City of)','UNITED KINGDOM','g43 1eb','07873339907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 22:09:44',0,NULL,3,1,2,1,NULL,'红外5in1  1 '),(5203,622259310001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','slerberonline','slerber@online.no','Steinar Lerberg','Ørretveien 8<br>3322','Darbu','Buskerud','NORWAY','3322','95222367','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 22:17:57',0,NULL,3,1,3,1,NULL,'nikon 原装背心 xl   1 RR843876128CN\r'),(5204,722361045015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','cristinarosianu','cristina_rosianu@yahoo.com','Cristina Rosianu','16 Canterbury Road','Watford','Hertfordshire','UNITED KINGDOM','WD171QT','07583117798','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 22:23:41',0,NULL,3,1,2,1,NULL,'45w  2 '),(5205,661827450002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','sermiloumax','sergelambert100@videotron.ca','Serge Lambert','3010 Cousineau','Montréal','QC','CANADA','H4K1P2','(514) 334-5356','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'新款黑色厚的背心 无字的 xxxl   1 RR843876247CN\r'),(5207,661830277002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',105,'hermeshine','pboom','pverboom@ns.sympatico.ca','Paul Verboom','3237 Connolly Steet','Halifax','NS','CANADA','B3L 3P6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 22:58:47',0,NULL,5,1,18,0,NULL,NULL),(5208,661831583002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','surachaij','jiddey@hotmail.com','Surachai Jiwapibantanakit','46 Florence St','nutley','NJ','UNITED STATES','07110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 23:04:16',0,NULL,3,1,1,1,NULL,NULL),(5209,708207910016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','housefromhell2010','jony212@live.co.uk','Christine stephens','6 coker way','chard','Somerset','UNITED KINGDOM','ta20 1bf','0146062907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 23:22:47',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5210,661838660002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','kilar73','ksoth2000@gmail.com','Félix Rodríguez Garrucho','C/ Los Toros, 18','Espera (Cádiz)','Andalucía Ceuta y Melilla','SPAIN','11648','689853581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 23:29:07',0,NULL,3,1,4,1,NULL,'tripod  $15 \rYW864489692CN\r'),(5212,661841816002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gtrblitz','pan.allen@gmail.com','Wei-Feng Chuang','88 Grandview Way. Apt 901','North York','ON','CANADA','M2N6V6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-20 23:37:48',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876295CN\r'),(5213,708213995016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','fraxinus256','ian.thompson01@gmail.com','Ian Thompson','9 Bramley Court Kelsall','Tarporley','Cheshire','UNITED KINGDOM','CW6 0RF','07798838308','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-20 23:40:56',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(5214,661843386002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','lechuck_spain','cjimeno@gmail.com','Carlos Jimeno Jiménez','C/ Tembleque 134, 7º A','Madrid','Madrid','SPAIN','28024','649133137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-20 23:47:14',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞   1 RR843876233CN\r'),(5215,622287979001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','hey_danny','danzekevideo@yahoo.com','Dan Mizicko','1821 Sodom Hutchings Rd NE','Vienna','OH','UNITED STATES','44473-9724','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-20 23:56:11',0,NULL,3,1,1,1,NULL,NULL),(5216,661850147002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 00:11:20',0,NULL,3,1,3,1,NULL,'斜臂  1 RR843876216CN\r\r'),(5217,661852016002,120601700210,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','igasparini','alfonsojtr@bol.com.br','Ineli A. Gasparini','Rua Dr. Goulart Penteado, 85 - Apto. 72 - Vl. Diva','Sao Paulo','SP','BRAZIL','03351090','551126717542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 00:17:05',0,NULL,3,1,3,1,NULL,'桌面灯  1 RR843876114CN\r'),(5218,661862439002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','orenjuz','vintageversion@yahoo.com','SK Indra Rukmana','Jl. Kopo Bihbul Km 6.5 No. 20/18','Bandung','West Java','INDONESIA','40225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 00:59:03',0,NULL,3,1,3,1,NULL,'2m 灯架   1\r反光板支架   1 RR843876220CN\r'),(5219,622306146001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','maxs212','maxs212@013.net.il','Maxim Shevtsov','Eilat 26/3','Holon','','ISRAEL','58309','(972) 544750774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 01:10:38',0,NULL,3,1,3,1,NULL,'lenspen\r2 RR843876264CN\r'),(5220,661868427002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','armin0889','yaboyice01@yahoo.com','Armin Alic','226 Oakwood Dr','Casselberry','FL','UNITED STATES','32707','(407) 462-3885','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 01:23:49',0,NULL,3,1,1,1,NULL,'lenspen  1 '),(5221,722424427015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','drrobe','robert.kos@gmail.com','Robert Kos','Polanskova 3','Ljubljana','','SLOVENIA','1000','+38631210765','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 01:38:59',0,NULL,3,1,2,1,NULL,'62mm 渐变灰  1 '),(5222,622316770001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','fredy_declercq','fredy_declercq@uol.com.br','Frederic Declercq','Rua Doutor José Gustavo Bush 155<br>apart.: 101-A  bairro:Morumbi','São Paulo','SP','BRAZIL','05705-190','+55-11-96257763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 01:54:04',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5224,722435067015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','mikeyb999','mikeyb8999@yahoo.com','Michael Bradley','3 Dunsuvinish Drive','Portstewart','Londonderry','UNITED KINGDOM','BT557EW','02870836704','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-21 02:07:35',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 2m   1\rYW864489681CN\r '),(5225,622320659001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xyren_poh','jenner.alagao@gmail.com','Jenner Alagao','49-D Nueva Ecija St.<br>Bago Bantay, Quezon City','Quezon City','Metro Manila','PHILIPPINES','1105','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 02:09:46',0,NULL,3,1,2,1,NULL,'52mm 渐变灰  1 '),(5227,661891435002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-21 02:53:57',0,NULL,3,1,1,1,NULL,'c型夹   1 '),(5228,707927422016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','liboltoc','thibault.dentel@caboche.fr','Thibault Dentel','La Grateliere','Saint Pierre du Chemin','Pays de la Loire','FRANCE','85120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-20 12:59:38',0,NULL,3,1,2,1,NULL,'717 手柄  1 '),(5229,661903226002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','crowtalks','jim@jimbussell.net','james bussell','365 doe creek loop','sparta','TN','UNITED STATES','38583','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 03:43:44',0,NULL,3,1,1,1,NULL,NULL),(5230,661907339002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lpknight','lpkni@yahoo.com','LOUIS KNIGHT','403 Hilltop Rd','GLENNVILLE','GA','UNITED STATES','30427','(912) 654-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:04:24',0,NULL,3,1,1,1,NULL,'lenspen   1 '),(5231,661905422002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:10:34',0,NULL,8,1,17,0,NULL,NULL),(5232,661908754002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 04:14:18',0,NULL,3,1,1,1,NULL,NULL),(5233,622349850001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bandeparker2010','bandeparker@telus.net','Brian Parker','165 McTavish Cresent','Fort McMurray','AB','CANADA','T9K 2N9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 04:26:30',0,NULL,3,1,3,1,NULL,'2m 灯架  1 RR843876410CN\r'),(5235,622355818001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','pachunino','chichogonzalez@gmail.com','ariel gonzalez','zeballos 5451','avellaneda','buenos aires','ARGENTINA','1875','42068337','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 05:03:36',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843876508CN\r'),(5236,661920504002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','blumelus','blumelus@yahoo.com','Melanie Leandro','1190 28th st','oakland','CA','UNITED STATES','94608-4442','(786) 395-2155','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-01-21 05:20:46',0,NULL,3,1,1,1,NULL,'canon 三角包 1 '),(5237,622363401001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','lozhkinsn','lozhkin@mail.ru','SERGEY LOZHKIN','STEPANA KUVYKINA ST<br>BLDG 11/2, 19','UFA','BASHKORTOSTAN','RUSSIAN FEDERATION','450103','+79050000004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 05:56:38',0,NULL,3,1,2,1,NULL,'大号灰卡  1 '),(5238,622369307001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',4,'AE1302',39.2,'hermeshine','sifiszach','zackouria@gmail.com','Zacharias Andreadakis','Profiti Ilia 7','Chania','Chalepa','GREECE','73133','0030-6947891285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:36:23',0,NULL,3,1,3,1,NULL,'单灯头  欧标  4 RR843876423CN'),(5239,661931427002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',2,'AA2217',17.96,'hermeshine','yanis_novikov','gespenst@inbox.ru','Yanis Novikov','Pantusovskaya,80','Kostroma','kostroma','RUSSIAN FEDERATION','156011','(915) 922-8596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:37:29',0,NULL,3,1,2,1,NULL,'小号灰卡  2 '),(5240,622369847001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','theartharindra','harindra.art@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:40:30',0,NULL,8,1,17,0,NULL,' '),(5241,622367313001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','fred97127','fpasbeau@gmail.com','Frederic PASBEAU','73 rue des maraichers','PARIS','Île-de-France','FRANCE','75020','06 15 11 72 82','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 06:40:50',0,NULL,3,1,4,1,NULL,'tripod $22 \rYW864489670CN\r'),(5242,622370434001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','theartharindra','harindra.art@gmail.com','Harindra Nishshanka','30/1, Godellawaththa,<br>Mahawila','Panadura','Western','SRI LANKA','12500','0094773040696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 06:44:34',0,NULL,3,1,2,1,NULL,'58mm  uv   1\r58mm 橡胶罩  1 '),(5243,622389865001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','nestand','nest_and@mail.ru','Andrey Nesterenko','Konstitucii Str. h.9 of.61','Krasnoyarsk','','RUSSIAN FEDERATION','660049','89029425450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 08:45:50',0,NULL,3,1,2,1,NULL,NULL),(5244,722420418015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',180.3,'hutongstore','kidsplanet24','contact1@kidsplanet24.com','MJmark Ltd.','17 Kestrel Road','Hereford','Herefordshire','UNITED KINGDOM','HR2 7TN','07815179574','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 09:37:13',0,NULL,3,1,4,1,NULL,'2m x3m 背景架  1\r3mx6m 绿色背景布  1\r2m 灯架  2\r50-70 棚 英标  2\r115w 220v  2\r包  1\r一转四灯头   2 \rlighting kit  $30\rYW864489773CN\r'),(5245,622400476001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sir_pashka','sir.pashka@gmail.com','Pavel Laptev','pr. Stroiteley 98-132','Penza','Penza region','RUSSIAN FEDERATION','440071','89022046293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 09:43:32',0,NULL,3,1,2,1,NULL,NULL),(5247,722540974015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',3,'AA3308',10.14,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','Kärberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 09:59:48',0,NULL,3,1,2,1,NULL,NULL),(5248,622405253001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','yiannists','tsounet@yahoo.com','Ioannis tsouratzis','Davaki 9<br>Alimos','Athens','','GREECE','17455','6937977698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:04:41',0,NULL,3,1,2,1,NULL,'45   2 '),(5249,722545682015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','kostaschatzoglou','kchatzoglou@gmail.com','Kostas Chatzoglou','Aristotelous 4 ','Agios Athanasios Thessaloniki','προεπιλογή','GREECE','57003','030 6974370745','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 10:17:31',0,NULL,3,1,2,1,NULL,'大号灰卡   1 '),(5250,622412167001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','karsimodo','marcel.kars@gmail.com','Marcel Kars','Moddermanstraat 26','Leiden','','NETHERLANDS','2313GR','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 10:36:44',0,NULL,3,1,3,1,NULL,'摄影背心  nikon  xxl  1\r老款 黑色 RR843874776CN\r'),(5251,661974662002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','compramc','mario.chorolqui@gmail.com','Mario Chorolqui','Marcos Sastre<br>5630','Ciudad de Buenos Aires','Buenos Aires','ARGENTINA','1408','+541131281161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:41:32',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5252,622411827001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:53:06',0,NULL,8,1,17,0,NULL,''),(5253,661974608002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 10:53:07',0,NULL,3,1,2,1,NULL,'倒影板   1 \r58mm canon 镜头盖  2 '),(5254,722556464015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','howarda2005','howard.allum@orange.fr','howard allum','4 Rue du Patis','la roche bernard','Bretagne','FRANCE','56130','02 23 10 18 56','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 10:57:24',0,NULL,3,1,2,1,NULL,'62mm 渐变灰  1 '),(5255,622417413001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','indexofvoid','voidindex@gmx.at','Andreas Danzer','Fichtnergasse 12','Wien','','AUSTRIA','1130','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 10:59:53',0,NULL,3,1,3,1,NULL,'58mm CPL+ND8+Macro+4 +Gradual grey+filter case \rRR843875290CN\r'),(5257,708377420016,260660054646,'Wireless Remote Control Cord for Canon 50D/40D/ 5D 5DII',1,'AA3210',11.47,'hutongstore','neilscott100','neilscott@jntservicios.com','Neil Scott','Calle Venus 21, Las Colinas Nord','Olivella','Barcelona','SPAIN','08818','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 11:11:14',0,NULL,3,1,2,1,NULL,'爵影无线c3  1 '),(5258,622429754001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','stephane_rp_91','slesmond@free.fr','Stéphane Lesmond','7, allée Cézanne','Les Ulis','Ile de France','FRANCE','91940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 11:55:56',0,NULL,3,1,2,1,NULL,'大力夹 球台  1 '),(5259,661992136002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','glauco.stephan','glstephan@gmail.com','Glauco Stephan','Charles Astor, 247','Sao Paulo','Sao Paulo','BRAZIL','04118050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 12:01:38',0,NULL,3,1,2,1,NULL,NULL),(5260,722574382015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',5.5,'hutongstore','cragonator','cragonator@hotmail.com','Craig Harris','60 Canterbury Way','Exmouth','Devon','UNITED KINGDOM','EX8 5QQ','01395273727','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 12:02:12',0,NULL,3,1,2,1,NULL,'中号内胆包  canon  1 '),(5261,661992889002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',3,'AO0034',27,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 12:05:02',0,NULL,3,1,3,1,NULL,'canon 三角包  2 RR843876763CN\r'),(5262,622441681001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','0572marcel61','m.vaanhold@ziggo.nl','Marcel Vaanhold','twickel 61','raalte','','NETHERLANDS','8103 HJ','0572-357187','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 12:51:48',0,NULL,3,1,3,1,NULL,'摄影背心  绿色 薄  nikon  xxxl  1 RR843876785CN\r'),(5263,722591848015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','tyrone1854','digital.photography@ntlworld.com','Tyrone Williams','Top Flat 30 Tydraw Street','Port Talbot','Neath Port Talbot','UNITED KINGDOM','SA13 1BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 12:59:08',0,NULL,3,1,2,1,NULL,NULL),(5264,622448824001,110464610859,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','administratsia','kumi51@yandex.ru','Evgeny Frolov','Zelionaya st. 29','Kurganinsk','Krasnodarsky kray','RUSSIAN FEDERATION','352430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 13:14:14',0,NULL,3,1,2,1,NULL,NULL),(5265,708414422016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','pawelgro','variatiadelecta@wp.pl','Pawel Grochola','1 Frederick House Woodthorpe Road','Ashford','Surrey','UNITED KINGDOM','TW15 2SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 13:18:33',0,NULL,8,1,17,0,NULL,''),(5266,722599164015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','pawelgro','variatiadelecta@wp.pl','Pawel Grochola','1 Frederick House Woodthorpe Road','Ashford','Surrey','UNITED KINGDOM','TW15 2SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 13:20:57',0,NULL,3,1,3,1,NULL,'一转四灯头  1 \r1.6x3m 蓝色背景布  1 \rRR843875255CN\r'),(5267,722601083015,250599932668,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',41,'hutongstore','poblitto','sedo@isand.sk','Pro Building Development / Pavol Sedo','Venturska 16','Bratislava','','SLOVAK REPUBLIC','81101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 13:32:03',0,NULL,3,1,3,1,NULL,'天涯10片装 + 72mm 环架  1 \r优永佳  re-a  c3   1 RR843874847CN'),(5269,722605852015,250692240149,'Remote Control Cord For Canon 5D Mark II 50D 40D RS-80N',1,'AA2219',2.89,'hutongstore','poblitto','sedo@isand.sk','Pro Building Development / Pavol Sedo','Venturska 16','Bratislava','','SLOVAK REPUBLIC','81101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 13:44:22',0,NULL,8,1,17,0,NULL,''),(5271,622464621001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','wortango','wortango@aol.com','BRIAN WORMAN','43 MEADOW DRIVE,  BISCOVEY','PAR','Cornwall','UNITED KINGDOM','PL24 2HL','01726812368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 14:12:58',0,NULL,3,1,2,1,NULL,NULL),(5272,622474461001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','fotosforo','pablosannazzaro@hotmail.com','pablo sebastian sannazzaro fernandez','la peña 80 traspando','siero','Asturias','SPAIN','33518','637168968','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 14:46:27',0,NULL,3,1,2,1,NULL,'单灯头 欧标  1 '),(5273,622496158001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 15:52:00',0,NULL,8,1,17,0,NULL,NULL),(5274,622493069001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 15:52:01',0,NULL,3,1,1,1,NULL,'52mm 橡胶罩   2 \r58mm 镜头盖 canon  1'),(5275,622514201001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','n0_exit','lene-@bk.ru','Elena Prosolupova','Akademika Anokhina<br>463 kv.13','Moscow','','RUSSIAN FEDERATION','119571','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 16:42:35',0,NULL,3,1,2,1,NULL,NULL),(5276,620918658001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',32.97,'hermeshine','mougios1983','1983mougios@gmail.com','Antonis Hadjinicolaou','Stimfalidon 1A','Larnaca','Larnaca','CYPRUS','6046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 16:50:56',0,NULL,3,1,3,1,NULL,'1.6x2.1 背景布  3\r白色， 黑色， 蓝色   RR843876661CN\r\r'),(5277,622521834001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','2009darko2009','dhero@koncarsp.hr','Darko HERO','Davorina Bazjanca3A','ZAGREB','','CROATIA','1000','0038513836809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 17:14:22',0,NULL,3,1,2,1,NULL,NULL),(5278,662097596002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','drakenman','donyeager@gmail.com','Don Yeager','2153 Aberdeen Cir','Murfreesboro','TN','UNITED STATES','37130','(615) 473-6242','NoPaymentFailure','CheckoutComplete','Other','2011-01-21 17:40:47',0,NULL,3,1,1,1,NULL,'sf18 for nikon （ sb800）  1 '),(5279,622524367001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xlorke','dariuzas@gmail.com','Darius Zvirzdinas','Debreceno st. 90-14','Klaipeda','','LITHUANIA','LT-94156','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 17:57:15',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876692CN\r'),(5280,662109658002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ejamga','erica.goya@gmail.com','Erica','Tres Arroyos 2964 7°C','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1416','45826554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 18:13:30',0,NULL,3,1,2,1,NULL,NULL),(5281,622443615001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','gasnur','gasnur@aol.com','Ralph','531 Valley Rd','Oxford','NJ','UNITED STATES','07863-3359','','NoPaymentFailure','CheckoutComplete','Other','2011-01-21 18:21:57',0,NULL,3,1,1,1,NULL,'摄影背心 nikon  xl   1\r老款 黑色 厚   '),(5283,622565330001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','pavlinbl4','x79046309437@gmail.com','Evgeniy Pavlenko','Narodnogo Opolchenija 141 - 70','St.Petersburg','','RUSSIAN FEDERATION','198217','7533440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 18:46:05',0,NULL,3,1,3,1,NULL,'肩架   1 RR843876689CN\r'),(5284,708562542016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','bickyz','abudhathoki@gmail.com','Bicky','University Tutorial College 12 Friar Street','Reading','Berkshire','UNITED KINGDOM','RG1 1DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 19:05:14',0,NULL,3,1,2,1,NULL,NULL),(5285,622575621001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','photoengineering','clementhun@gmail.com','Clement Hun','530/ 20 Montague Road','South Brisbane','Queensland','AUSTRALIA','4101','0433898990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:08:51',0,NULL,3,1,2,1,NULL,'大力夹  球体  1 '),(5286,662138533002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jagonik','jagogalpin@hotmail.com','Juan Antonio Ortega','Micaela Aramburu,4','El Puerto de Santa Maria','Andalucía Ceuta y Melilla','SPAIN','11500','956853328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:15:06',0,NULL,3,1,2,1,NULL,'柔光伞  1 '),(5287,622597542001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 19:58:14',0,NULL,8,1,17,0,NULL,NULL),(5288,622598595001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tomsnetwork','tomi.jelic@gmail.com','Tomislav Jelic','J.J. Strossmayera 51','Bosnjaci','Croatia (Hrvatska)','CROATIA','32275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:00:09',0,NULL,3,1,2,1,NULL,'55mm 橡胶罩   2 '),(5289,662159492002,120601698256,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','rhayton','richhayton@me.com','Richard Hayton','Unit 1d<br>23 Emily Place','Auckland','North Island','NEW ZEALAND','1010','0064 9 5736567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:02:03',0,NULL,3,1,2,1,NULL,'58mm 环架  1 '),(5291,622611716001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pantux','artshea61@yahoo.com','Arthur Shea','Box 336','Boyle','AB','CANADA','T0A 0M0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-21 20:31:08',0,NULL,3,1,3,1,NULL,'摄影背心 nikon xxxl   1\r老款 黑色 厚    RR843876729CN\r'),(5293,722811570015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.99,'hutongstore','bvladov','boyan.vladov@itrade.bg','Boyan Vladov','Apostol Karamitev Str. 2, Entr. V, fl.2, ap.3','Sofia','Bulgaria','BULGARIA','1172','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-21 20:54:05',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  1 '),(5294,662182572002,120581161241,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.98,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 20:56:58',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(5296,662192342002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','lgmus','lgmkin@gmail.com','Nikita Mikhalkov','17/10/18, Otkritoe shosse','Moscow','','RUSSIAN FEDERATION','107143','79265684211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 21:19:50',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5298,722844959015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','bartlondyn','bartlondyn@o2.pl','Daria Szwarc','Studio 3.4 50 Carnwath Road','London','London','UNITED KINGDOM','SW6 3EG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-21 22:02:52',0,NULL,3,1,2,1,NULL,NULL),(5299,662214601002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lsteacherls','lwreggitt@mts.net','Laureen M Wreggitt','16 Egerton Rd','Winnipeg','MB','CANADA','R2M 2V5','(204) 231-0759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 22:20:04',0,NULL,3,1,2,1,NULL,NULL),(5301,662234487002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rebyun','rebyun1@yahoo.com','Rob Byun','777 Via Colinas','Westlake Village','CA','UNITED STATES','91362-5043','(805) 990-5415','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-21 23:22:57',0,NULL,3,1,1,1,NULL,NULL),(5302,622676741001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','nachet70','ncabanes@gmail.com','José Ignacio Cabanes','C/ Lillo Juan, 104, 4 B','San Vicente del Raspeig (Alicante)','Comunidad Valenciana','SPAIN','03690','649242223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-21 23:37:44',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5304,662254298002,120601698793,'Canon 58mm Reverse Adapter 50mm 1.4 40D 7D 5DII Macro',1,'AA1208',4.4,'hermeshine','lav1105','velez_68@yahoo.com','LUIS VELEZ','PO Box 1166','SAN SEBASTIAN','PR','UNITED STATES','00685','(787) 429-0661','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 00:40:33',0,NULL,8,1,17,0,NULL,NULL),(5305,662254469002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lav1105','velez_68@yahoo.com','LUIS VELEZ','PO Box 1166','SAN SEBASTIAN','PR','UNITED STATES','00685','(787) 429-0661','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 00:40:32',0,NULL,3,1,1,1,NULL,'canon -58mm 反接环  1\r58mm canon 镜头盖  1 '),(5306,662269855002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','8e-chen8','felix.erner@gmail.com','Felix Erner','5300 W Baseline Rd<br>Apt 148','Hillsboro','OR','UNITED STATES','97123-6415','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-22 01:51:26',0,NULL,3,1,1,1,NULL,'58mm 渐变灰  1 '),(5307,622731733001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','namipasa','myjunkdownloads@gmail.com','Nate Larson','41303 N Palm Springs Trl','San Tan Valley','AZ','UNITED STATES','85140-4236','(602) 694-6873','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 03:54:06',0,NULL,3,1,1,1,NULL,NULL),(5308,622734842001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','lion14615','macdang73@gmail.com','Hoang Dang','2190 Glenridge Rd','EUCLID','OH','UNITED STATES','44117','(216) 692-2106','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 04:18:06',0,NULL,3,1,1,1,NULL,NULL),(5309,622737789001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','ennaialan','zmyjewel@yahoo.com','Romeo Alan','171B Edgedale Plains #09-448','default','','SINGAPORE','822171','6585188889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 04:34:51',0,NULL,3,1,11,1,NULL,'canon-58mm 反接环  1 '),(5311,722989143015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','rojinbahrain','rojlambert@hotmail.com','ROGER F LAMBERT','61 THE MEADOWS','SEDGEFIELD','Co DURHAM','UNITED KINGDOM','TS212DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 07:36:47',0,NULL,3,1,2,1,NULL,'45w  2 '),(5312,662345794002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','kn_wa','kam@kamplaza.com','Kam Ngai','2 Coogee Street','Mount Hawthorn','Western Australia','AUSTRALIA','6016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:14:16',0,NULL,3,1,4,1,NULL,'2m 灯架 1\r反光板支架  1 \rYW864489762CN\r'),(5313,661977491002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','xylocain','gr_lim@web.de','Ingenieurbüro Pickel','Herbsttal 2','Happurg','','GERMANY','91230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:46:14',0,NULL,8,1,17,0,NULL,NULL),(5315,622416012001,110534332881,'CTR-301P Wireless Flash Trigger 2 Receiver SB800 580EX',1,'AKT001',41.9,'hermeshine','xylocain','gr_lim@web.de','Ingenieurbüro Pickel','Herbsttal 2','Happurg','','GERMANY','91230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 09:48:19',0,NULL,3,1,3,1,NULL,'301p 一拖二  1\r50-70 塑料卡口棚  1 RR843876635CN\r'),(5317,708824437016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','johnrichs','john@do1thingwell.com','John Richards','23 Trevor Close','Hayes','Kent','UNITED KINGDOM','BR27NS','02084622713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 09:59:41',0,NULL,3,1,2,1,NULL,NULL),(5319,662360956002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','alexandrlos','los.alexandr@gmail.com','Alexandr Los','1 Oktyabr\'skaya<br>ap. 9','Vishneviy','Kiev Region','UKRAINE','08132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 10:21:09',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5320,662370825002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','rbpai','rajasekhr@gmail.com','Rajasekhar B Pai','APT 303, Vedhas Vantage Apts, PLOT No. 204,<br>SURVEY OF INDIA SOCIETY, Near 100 Ft ROAD, MADHAPUR,','HYDERABAD','Andhra Pradesh','INDIA','500081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 11:18:32',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5321,662383088002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','hickoryswitch2u','oleyone@gmail.com','Mr. R. E. Olsen','4794 S Route 62','Kennedy','NY','UNITED STATES','14747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-22 11:59:51',0,NULL,3,1,1,1,NULL,'c型夹   1 '),(5322,723061187015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.5,'hutongstore','sim007on','plestenjaksimon@gmail.com','Simon Plestenjak','Vrzdenec 44/B','Horjul','','SLOVENIA','1354','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 12:03:40',0,NULL,3,1,2,1,NULL,'小号内胆包nikon  1 '),(5323,662398613002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nueaszeb','bazsi@jelenet.info','Balázs Csapó','Winkelstrasse 6a','Sulgen','','SWITZERLAND','8583','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 12:51:17',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座  1\r柔光伞  1 RR843876613CN\r'),(5325,662407407002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','flylynx38','flylynx@gmail.com','Evgeny Kodnevskiy','Sovetskaya 124B-4','Irkutsk','Irkutskaya oblast\'','RUSSIAN FEDERATION','664047','+79149134970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 13:17:52',0,NULL,3,1,2,1,NULL,' '),(5326,622854513001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','imrak1','viper83@bk.ru','Shaposhnikov Alexey','Botkina 5-78','Rybinsk','YAROSLAVL REGION','RUSSIAN FEDERATION','152919','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 13:46:23',0,NULL,3,1,2,1,NULL,NULL),(5328,723112450015,250615147105,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB900',1,'AB3311',32.99,'hutongstore','*sue23*','sueandarthur@googlemail.com','Arthur Garlick','in4tek ltd 20 Barrington Road','Altrincham','Cheshire','UNITED KINGDOM','WA14 1HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 14:26:56',0,NULL,3,1,3,1,NULL,'sf18 sb900   1 RR843876817CN\r'),(5329,622868945001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','2begolfer','eglide02@yahoo.com','scott behnke','2621 Gemini Rd','green bay','wi','UNITED STATES','54311-4611','(920) 639-0045','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:28:59',0,NULL,3,1,1,1,NULL,'6663a 快装板  1 '),(5330,622872008001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1309',5,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:39:32',0,NULL,8,1,17,0,NULL,NULL),(5331,622875408001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','gregaudet','gpaudet@yahoo.com','Gregory Audet','5262 Shephard Rd','Brown City','MI','UNITED STATES','48416','(810) 837-1262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:47:52',0,NULL,3,1,1,1,NULL,'爵影无线 C3   1\r77mm 镜头盖 canon  2 '),(5332,622879637001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.6,'hermeshine','madbury','bobc@hopper.unh.edu','bob champoux','291 Mast road<br>Cole Hall/ Thompson School/UNH','Durham','NH','UNITED STATES','03824','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 14:59:32',0,NULL,3,1,1,1,NULL,NULL),(5334,662443682002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dorikvolodymyr','inozemtsev@ukr.net','Volodymyr Inozemtsev','7 Sechenova str., ap.3','Kyiv','','UKRAINE','03127','+380672381125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:07:59',0,NULL,3,1,2,1,NULL,NULL),(5339,708947284016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','woodalbert','albert.wood1@btopenworld.com','Albert Wood','14 Woodstock Court Bowesfield Crescent','Stockton on tees','Cleveland','UNITED KINGDOM','TS17 0XH','07881930902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 15:46:45',0,NULL,3,1,2,1,NULL,'1.6x3m 背景布 白色  1 '),(5340,622898051001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:57:31',0,NULL,8,1,17,0,NULL,NULL),(5342,662459752002,120601699242,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:57:30',0,NULL,8,1,17,0,NULL,NULL),(5343,662459344002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:57:30',0,NULL,3,1,5,1,NULL,'2mx3m 背景架  1\r3mx6m 绿色背景布 1\r2m 灯架  4\r50-70 棚 欧标  2\r双灯头  欧标  2\r反光伞  2\r115w 220v  2\r包  2\rNG128   1\rCP219487599CN\r\r '),(5344,622911613001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','yury1356','nerof@mail.ru','Yury Oganesov','Tuhachevskogo 3/9-45','Stavropol','','RUSSIAN FEDERATION','355040','+79624503370','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 16:23:24',0,NULL,3,1,5,1,NULL,'2mx3m背景架  1 \rCP219487608CN\r'),(5346,662459144002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','red-hot-seven','schwarz.friedrich@arcor.de','friedrich schwarz','schillerstr. 35','heuchelheim','','GERMANY','35452','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:51:08',0,NULL,3,1,2,1,NULL,'大力夹  1 '),(5347,662455544002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 15:39:18',0,NULL,3,1,2,1,NULL,'c型夹   1 '),(5349,662451500002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rotel54','fam.r.hunziker@bluewin.ch','Hunziker Rolf','Tannmättli 6','Tägerig','','SWITZERLAND','5522','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 15:46:30',0,NULL,3,1,3,1,NULL,'摄影背心  canon  xl  1\r老款 RR843876905CN\r'),(5350,622933487001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','77danas','t.danas@gmail.com','Violeta Blaziene','Pasirvincio k. Sirvintu sen. 1','Sirvintos','','LITHUANIA','19129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 17:15:56',0,NULL,3,1,2,1,NULL,'40cm 棚  1 '),(5351,723216058015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','dwynnep','dwynnepercival@msn.com','dwynne percival','108 Chaucer Road Parson Cross','Sheffield','South Yorkshire','UNITED KINGDOM','S5 9QL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 17:41:12',0,NULL,3,1,2,1,NULL,NULL),(5352,723217361015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','loveccz2009','p.prichy@seznam.cz','Pavel Přichystal','hnevotinska 46','Olomouc','Olomoucky kraj','CZECH REPUBLIC','77900','723611151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 17:43:15',0,NULL,8,1,17,0,NULL,NULL),(5353,723218192015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','loveccz2009','p.prichy@seznam.cz','Pavel Přichystal','hnevotinska 46','Olomouc','Olomoucky kraj','CZECH REPUBLIC','77900','723611151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-22 17:44:39',0,NULL,3,1,2,1,NULL,'62mm cpl   1\r72mm cpl   1 '),(5354,662513163002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zalkor72','zalkor72@hotmail.com','Jose Antonio Garcia Sosa','Pasaje Miramar del Palo, 2, 3ºA','Malaga','Malaga','SPAIN','29017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 17:52:26',0,NULL,3,1,2,1,NULL,NULL),(5355,622963117001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','slawek324','slawek@koziel.org','Slawomir Koziel','Joklasel 3','Reykjavik','','ICELAND','109','+3548256376','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 18:10:05',0,NULL,5,1,18,1,NULL,'爵影无线 C3   1 '),(5356,723233422015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','chrischr15','fu33yhead@sky.com','Chris Flowers','21 Downsview Road','Horsham','East Sussex','UNITED KINGDOM','RH12 4PF','01403210927','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 18:11:17',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖 canon   1 '),(5358,723257507015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',3.98,'hutongstore','chr1s57','christopher.ariss@ntlworld.com','Christopher Ariss','18 Turmore Dale','Welwyn Garden City','Hertfordshire','UNITED KINGDOM','AL8 6HS','01707372477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 18:49:31',0,NULL,3,1,2,1,NULL,'中号镜头筒   1 '),(5359,622986539001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','vicenza67','yosemite@virgilio.it','LOVATO LUCIANO','VIA MARANI 44','(VI)','VICENZA','ITALY','36100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 18:57:55',0,NULL,3,1,3,1,NULL,'2m 灯架 红盒  1 RR843876644CN\r'),(5360,662551392002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','colinjane','colinjmurphy@sky.com','colin murphy','105 langdale road','runcorn','Cheshire','UNITED KINGDOM','WA75PR','01928573705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 19:07:35',0,NULL,3,1,2,1,NULL,'6662a 快装板  1 '),(5361,662556681002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','mj_amaro','maurojamaro@gmail.com','MAURO DE JESUS AMARO','R. JOÃO BAPTISTA D\'ALASCIO, 75<br>AP 302 BLOCO A','FLORIANÓPOLIS','SC','BRAZIL','88080-145','(11) 9112-4025','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 19:20:41',0,NULL,3,1,3,1,NULL,'sf18 nikon （ sb800）  1 RR843876851CN\r'),(5362,623001560001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','no_fake_shemps','hurdg@chartermi.net','Greg Hurd','105 Barry St.','Alpena','MI','UNITED STATES','49707','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 19:26:58',0,NULL,3,1,1,1,NULL,NULL),(5364,662566794002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','cricrihydro','fardoche26@hotmail.com','LAPORTE CHRISTIAN','1827 MARMIER APP.6','LONGUEUIL','QC','CANADA','J4K 4T3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 19:39:11',0,NULL,3,1,3,1,NULL,'斜臂 1 RR843876560CN\r'),(5365,662576555002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jornlyder','jolohans@me.com','Jørn Lyder Hansen','Heslebergveien 6a','Vollen','Norway','NORWAY','1390','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 20:04:51',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876627CN\r'),(5366,623022122001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','a5tippmann','rwd1960@gmail.com','Robert W Dawes','350 Walker Dr','vienna','Il','UNITED STATES','62995-2638','(618) 658-2273','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:10:01',0,NULL,3,1,1,1,NULL,NULL),(5368,723289960015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','jodhi_d','jo_dymond@hotmail.com','Jo Dymond','Keepers Cottage Cricket St Thomas','Chard','Somerset','UNITED KINGDOM','TA20 4DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-22 19:42:17',0,NULL,3,1,2,1,NULL,'77mm 接口环  1 '),(5369,662590879002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','bigkahuna-2008','lakuzich@charter.net','larry kuzich','4112 S Otter Creek Rd','la salle','MI','UNITED STATES','48145-9728','(734) 243-6461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:30:56',0,NULL,8,1,17,0,NULL,''),(5370,662591994002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bigkahuna-2008','lakuzich@charter.net','larry kuzich','4112 S Otter Creek Rd','la salle','MI','UNITED STATES','48145-9728','(734) 243-6461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-22 20:33:04',0,NULL,3,1,1,1,NULL,'canon 镜头后盖/机身盖  1 \r58mm 镜头盖 canon  1 '),(5372,622986420001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 20:44:54',0,NULL,8,1,17,0,NULL,NULL),(5373,622976271001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 20:44:55',0,NULL,3,1,3,1,NULL,'反光板支架   1\r中号镜头筒   1 RR843876675CN\r'),(5374,623042427001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 21:24:21',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876701CN\r'),(5375,623061085001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','mio_cz','miroslav.sitner@gmail.com','Radka Durcikova','Rabasova 3195/43','Usti nad Labem','','CZECH REPUBLIC','40011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 21:41:23',0,NULL,3,1,2,1,NULL,'ND 8   1 '),(5376,662620883002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','a.smart.kid','j.arenas@me.com','Jesus Arenas Mesa','Aragon, 576, 4-1','Barcelona','Barcelona','SPAIN','08026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 21:43:36',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864489821CN\r'),(5378,662633962002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','leahav91','leander_91@hotmail.com','Leander Håvik','Ørevikvegen 37','Haugesund','Rogaland','NORWAY','5515','95261902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 22:14:27',0,NULL,3,1,3,1,NULL,' RR843876715CN\r'),(5379,623076773001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',2,'AB2401',27.98,'hermeshine','atttmobile','davidnorwood2010@yahoo.com','Zhi Pei','1357 Calle Wilson<br>Apt 402','San Juan','PR','UNITED STATES','00907-2234','','NoPaymentFailure','CheckoutComplete','Other','2011-01-22 22:26:28',0,NULL,3,1,1,1,NULL,'90th 镜头筒   2 '),(5380,661024558002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','kiddiboy','janoveiversen@mac.com','Jan-Ove Iversen','Kraakstadveien 21 A','SKI','','NORWAY','1400','004790568338','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-22 23:01:09',0,NULL,3,1,4,1,NULL,'2m 灯架  2\rb座  2\r柔光伞   2\rlight stand  $20 \rYW864489832CN\r'),(5381,623091457001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','aepanebianco','alexandre.panebianco@uol.com.br','Alexandre Panebianco','Rua Afonso Braz<br>473 - 9 andar','São Paulo','São Paulo','BRAZIL','04511-011','551138493066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-22 23:06:24',0,NULL,3,1,2,1,NULL,'77mm 环架  1 '),(5383,623160263001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','juan3412','juan.a.martinez@am.sony.com','Juan Martinez','1762 Clinton Rd','Hewitt','NJ','UNITED STATES','07421-2601','(973) 853-5628','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 03:40:51',0,NULL,3,1,1,1,NULL,NULL),(5384,623209610001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','eradnort','trondaret@gmail.com','Trond Are Thomassen','Vågsveien','Hjørungavåg','Møre og Romsdal','NORWAY','6063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 08:42:45',0,NULL,3,1,3,1,NULL,'反光板支架  1 RR843876573CN\r'),(5385,623213872001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','alnikos','al_nikos@hotmail.com','Nicolas Ortiz Vaquerizas','Paseo Xavier Azqueta nº 3 bajos 1ª','Sant Cugat del Valles','Cataluña','SPAIN','08173','616727883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:00:39',0,NULL,3,1,2,1,NULL,NULL),(5386,623216046001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','1atom','dautov100@rambler.ru','Vadim Dautov','ul. Zheleznodorozhnaya d.31 kv. 8','Yugorsk','HMAO','RUSSIAN FEDERATION','628260','+7-902-8254794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:14:06',0,NULL,3,1,2,1,NULL,NULL),(5387,623224808001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','ruby0185','n.j.bergmann@windowslive.com','Jürg N. Bergmann','Strickweg 12','Gränichen','','SWITZERLAND','5722','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 09:43:05',0,NULL,3,1,3,1,NULL,'原装nikon 背心 xl  1 RR843876803CN\r'),(5389,623228465001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','monona33','margolin33@seznam.cz','Monika Vecerova','V drahach','V drahach 133','Bohunovice','CZECH REPUBLIC','78314','773543133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 09:51:39',0,NULL,3,1,3,1,NULL,'45w 4 RR843876882CN\r'),(5390,623261989001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','nerevar1988','nerevaro@gmail.com','Paulius Venckus','Laukininku 8-12','Klaipeda','Klaipeda','LITHUANIA','95140','+37066265417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 11:24:04',0,NULL,3,1,3,1,NULL,'nikon 单肩包  D1  1 RR843876834CN\r'),(5391,622914914001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','katufi4ek','katestar017@mail.ru','Dave Geoghegan','Unit B15<br>South City Business Centre','Tallaght 24','Dublin','IRELAND','default','0079063378278','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 11:24:50',0,NULL,3,1,2,1,NULL,NULL),(5393,723627269015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','bikesprint','coops595@hotmail.com','Paul Cooper','117 Ewell by pass','Epsom','Surrey','UNITED KINGDOM','KT172PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:05:46',0,NULL,3,1,2,1,NULL,'45w  2 '),(5394,662841712002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',106,'hermeshine','plant305','plantmo@bigpond.com','Norman Plant','30 Henry Sutton Cct<br>Dunlop','Canberra','Australian Capital Territory','AUSTRALIA','2615','0262595662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 12:13:52',0,NULL,3,1,4,1,NULL,'2m 灯架   2\r反光板支架  2 \rreflector holder  $28\rYW864489843CN\r'),(5395,722145451015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','rufus_blackwell','rufusfxblackwell@yahoo.co.uk','Rufus Blackwell','Rushes Post Production 66 old compton st','london','London','UNITED KINGDOM','W1D4UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:22:37',0,NULL,3,1,2,1,NULL,'45w  2  '),(5396,723643015015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','hkggfs2010','hkggfs@gmail.com','William Yeung','48 Shieldhill Court','Carluke','South Lanarkshire','UNITED KINGDOM','ML8 5GL',' 07919093811','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:35:37',0,NULL,3,1,2,1,NULL,NULL),(5397,723642820015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','binzius','rimvydasm@gmail.com','Rimvydas Masalis','S. Zukausko str. 18-4','Vilnius','Vilnius','LITHUANIA','08234','+37061222828','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 12:36:15',0,NULL,3,1,2,1,NULL,NULL),(5398,723644646015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','spartan1876','terryowens100@hotmail.com','TERRY OWENS','28 DYFED NORTHCLIFFE','PENARTH','The Vale of Glamorgan','UNITED KINGDOM','CF64 1DX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:38:44',0,NULL,3,1,2,1,NULL,NULL),(5399,723644439015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','pumalives','ianbowers@usa.net','Ian Bowers','3 Melbourne Square Leconfield','Beverley','East Riding of Yorkshire','UNITED KINGDOM','HU17 7LG','07947822012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 12:38:51',0,NULL,3,1,2,1,NULL,NULL),(5400,723649538015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','ogpog','paypal@timfy.ie','Tim Wood','Middle Cottage Culliagh Beg','Leenane','Galway','IRELAND','default','09542912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 12:49:24',0,NULL,3,1,2,1,NULL,NULL),(5403,723657286015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','arunas167','arunas_stanaitis@yahoo.co.uk','Arunas Stanaitis','Cullenwood 12','Mountmellick','Laois','IRELAND','default','0876927596','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 13:04:23',0,NULL,3,1,2,1,NULL,'6662a 快装板  1 '),(5404,662861529002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','osco1955','fabiosbest+ebay@gmail.com','Fabio Coppini','Via del Colle n° 26','Prato','PO','ITALY','59100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 13:04:41',0,NULL,3,1,3,1,NULL,'2m灯架  1\rb座  1\r柔光伞  1 RR843876658CN\r'),(5406,723671510015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',68,'hutongstore','scottlet','scott@ethosuk.org.uk','Scott van Looy','21 Gainsborough House Cassilis Road','London','London','UNITED KINGDOM','E14 9LQ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-23 13:33:05',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r50-70 棚  英标  2\r包   1 \rlighting kit  $26\rYW864489854CN\r'),(5407,709470473016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','roksan74','mj74uk@yahoo.co.uk','Mark Ellis','7 Boultham Park Road','Lincoln','Lincolnshire','UNITED KINGDOM','LN67BE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 14:10:53',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5408,662895001002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',47,'hermeshine','idomingozz','macdocz@me.com','Dmitry Danilov','Smolnaya str. 12<br>TBSS Ltd.','Moscow','Russia','RUSSIAN FEDERATION','125493','(985) 4111082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 14:20:49',0,NULL,3,1,3,1,NULL,'MC-C1   1 RR843876848CN\r'),(5410,723704083015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','emidio_santos','emidio_santos@hotmail.com','Emidio Santos','Praceta Moreira Feio torre 2 - 2º D','Stº. António dos Cavaleiros - Loures','Loures','PORTUGAL','2670-121','916656178','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 14:28:34',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843876587CN\r'),(5411,662901673002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 14:35:42',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876600CN\r'),(5412,709504169016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','7_zab','vinyl.prime@gmail.com','Alexander Zabotkin','Akademgorodok, 27-32','Krasnoyarsk','','RUSSIAN FEDERATION','660036','9029225317','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 15:09:28',0,NULL,3,1,2,1,NULL,NULL),(5413,622485484001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','nickieruss','nickieruss@aol.com','Nickie Russell','736 Lee Road 304','Marianna','AR','UNITED STATES','72360-8432','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 15:12:37',0,NULL,3,1,1,1,NULL,'450D 眼罩  1 '),(5414,723770425015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.98,'hutongstore','kona1508','royst1968@gmail.com','Royston Palmer','Gwyndir Coolnacon,Clonroche','Enniscorthy','Wexford','IRELAND','ROI','0876892479','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 16:08:38',0,NULL,3,1,2,1,NULL,'3pcs 滤镜袋  2 '),(5415,623413795001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','alcachi','javier.lopez.cacheiro@gmail.com','Javier Lopez Cacheiro','CESGA Avda. de Vigo s/n<br>Campus Sur','Santiago de Compostela','Galicia','SPAIN','15705','655547687','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:41:08',0,NULL,3,1,4,1,NULL,'6663a   1 \rtripod $15\rYW864489865CN\r'),(5416,662980470002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 16:58:04',0,NULL,8,1,17,0,NULL,NULL),(5417,623422589001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:58:04',0,NULL,8,1,17,0,NULL,NULL),(5418,662979082002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 16:58:05',0,NULL,8,1,17,0,NULL,NULL),(5419,662979934002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bunaaleksandar','aleksandarbunevski@yahoo.com','Aleksandar Bunevski','Prilepska 53A/8','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38970562350','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 16:58:05',0,NULL,3,1,5,1,NULL,'斜臂   1\r52mm 镜头盖 nikon  1\r反光板支架  1\r50-70 塑料卡口棚   1 \r看看重量？   2448\rCP219487611CN\r'),(5420,723815862015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','hcleslie','hcleslie@hotmail.com','Hui Chai','19 Parsons Close','Aldershot','Hampshire','UNITED KINGDOM','GU11 2EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 17:11:04',0,NULL,3,1,2,1,NULL,NULL),(5421,662994660002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:56',0,NULL,8,1,17,0,NULL,NULL),(5422,623437061001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:56',0,NULL,8,1,17,0,NULL,NULL),(5423,622919381001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',2,'AA2217',17.98,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:57',0,NULL,8,1,17,0,NULL,NULL),(5424,622920066001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:57',0,NULL,8,1,17,0,NULL,NULL),(5425,622919448001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','alekseyvk','avkonovalov@bk.ru','ALEXEY KONOVALOV','7 Chuksin tupik st. Apt. 45','Moscow','','RUSSIAN FEDERATION','127206','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:14:58',0,NULL,3,1,5,1,NULL,'倒影板  1\r60cm 棚  1\r小号灰卡  2\r桌面灯   2\r45w   2 \rCP219487625CN\r\r'),(5426,662998739002,120571006893,'Green.L 67mm Neutral Density ND8 Filter  67 D90 D300s',1,'AE2312',6.7,'hermeshine','tom6667','tlink100@gmail.com','Thomas Link','1976 Topeka Cir','Sparks','NV','UNITED STATES','89434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 17:18:12',0,NULL,3,1,1,1,NULL,NULL),(5427,663001229002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','tie1103','tie@stagezoom.net','Milan Skrob','Susilovo nam. 53','Rousinov','','CZECH REPUBLIC','68301','+420776181460','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 17:21:32',0,NULL,3,1,3,1,NULL,' RR843876595CN\r'),(5428,623457710001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','leonbos27','leonbos@absamail.co.za','Leon Boshoff','P.O. Box 186<br>Garsfontein','Pretoria','Gauteng','SOUTH AFRICA','0042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:40:53',0,NULL,3,1,2,1,NULL,NULL),(5429,623464701001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','cscruzmoreira','cscmoreira@gmail.com','Cláudia Moreira','Rua de S. Pedro N.º 239','Paços de Ferreira','Porto','PORTUGAL','4595-032','+351255872912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 17:49:40',0,NULL,3,1,2,1,NULL,'大力夹 球台  1 '),(5430,723864049015,250599421893,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','brice2971','bricester@hotmail.com','Simon Brice','1 Redwoods','Hertford','Hertfordshire','UNITED KINGDOM','SG14 3BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 17:53:36',0,NULL,3,1,2,1,NULL,NULL),(5431,709643880016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','blackdwarrf','r.palacz@yahoo.ie','Rafal Palacz','Apt. 9 Chapel Meaws Chapel Lane','Sallins','Kildare','IRELAND','default','0851575073','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 18:03:15',0,NULL,3,1,2,1,NULL,NULL),(5433,623484397001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mrpikkusika','nordstrom.joakim@suomi24.fi','Joakim Nordström','Tavastilankatu 8 D 27','Turku','','FINLAND','20610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 18:12:35',0,NULL,3,1,2,1,NULL,'45w   2 '),(5434,663042382002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','v--a--n','alex.n.vereshchagin@gmail.com','Aleksandr N Vereshchagin','Karla Marksa str. 70-30','Berdsk','Novosibirsk region','RUSSIAN FEDERATION','633004','+79137187142','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 18:13:49',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876525CN\r'),(5436,623486461001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','highlife!','miller-time@shaw.ca','Brett Slutker','2444 Harmon Road','West Kelowna','BC','CANADA','V1Z 3A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 18:14:37',0,NULL,3,1,2,1,NULL,NULL),(5437,709666721016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','vvvsk','vvvsk.mail@googlemail.com','Vojtech Pisca','49 Ferndene Bradley Stoke','BRISTOL','Avon','UNITED KINGDOM','BS32 9DG','07845474515','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 18:24:30',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1 '),(5438,623557083001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','asalaqeel','hajs_400@hotmail.com','aqeel salmman','p.o.box 13666<br>dammam 31414','adammam','','SAUDI ARABIA','31414','00966506052299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 19:31:07',0,NULL,3,1,2,1,NULL,'72mm 橡胶罩   1 '),(5439,663071465002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','deeneshen','incu_bus_17@yahoo.co.uk','Deeneshen Sabapathee','Mootoo Lane<br>Allee Brillant','Vacoas','','MAURITIUS','0000','+2304903234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 19:44:20',0,NULL,3,1,3,1,NULL,'60cm 闪光灯棚   1 RR843876896CN\r'),(5440,663097824002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','asgeirkolberg','akolberg@start.no','Asgeir Kolberg','Verven 34','Drammen','','NORWAY','3041','004795060443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:05:55',0,NULL,3,1,2,1,NULL,'渐变棕    1 '),(5441,663154953002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','braveheart1804','gordon-shumway1@gmx.de','Mike Braune','Am Stadtblick 32','Magdeburg','','GERMANY','39128','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 20:18:35',0,NULL,3,1,3,1,NULL,'摄影背心 canon xl 1\r老款 RR843876777CN\r'),(5443,663154424002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','vertten','aldusvertten@gmail.com','Alfredo Del Busto Tarancon','C/ Esteve Victoria 5-1','Valencia','Valencia','SPAIN','46006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:24:39',0,NULL,8,1,17,1,NULL,' \r'),(5444,663133221002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','vertten','aldusvertten@gmail.com','Alfredo Del Busto Tarancon','C/ Esteve Victoria 5-1','Valencia','Valencia','SPAIN','46006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 20:24:40',0,NULL,3,1,3,1,NULL,'肩架   1 \r机身盖/镜头后盖  canon  1\rRR843876511CN'),(5445,623620351001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','peterzsolt1976','peterzsolti@freemail.hu','Péter Zsolt','Derkovits 54. 1/3','Miskolc','','HUNGARY','3529','0036306543456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 20:44:55',0,NULL,3,1,2,1,NULL,NULL),(5446,709836485016,260660053613,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','kumi-tarzan','kumitarzan@gmail.com','Markus Lehtinen','Lounaankatu 1 a 13','Lahti','','FINLAND','15150','+358407438006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-23 21:05:04',0,NULL,3,1,3,1,NULL,'防寒罩   1 RR843876794CN\r'),(5447,663188960002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','ddav9357','tutucute_creations@yahoo.com','Debbie Davis','PO Box 204<br>306 East Main Street','Fouke','AR','UNITED STATES','71837-0204','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 21:08:27',0,NULL,3,1,1,1,NULL,NULL),(5448,724083723015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','dennisbf20','dennis@byrne-fraser.com','dennis byrne-fraser','59 belvere ave','blackpool','Lancashire','UNITED KINGDOM','FY42LW','01253408943','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-23 21:23:17',0,NULL,3,1,2,1,NULL,'镜头后盖/机身盖 canon  1 '),(5449,663225888002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','soegnen_123','soegnen@gmail.com','Rasmus Søgnen','C.J. Hambrosvei 48','Bergen','Hordalan','NORWAY','5148','55168248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 22:15:51',0,NULL,3,1,2,1,NULL,NULL),(5450,663230291002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','gigistella10','debibobi@gmail.com','Deborah Besana','27 Noel Road<br>Acton','London','London','UNITED KINGDOM','W3 0JD','0754076780','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 22:22:20',0,NULL,3,1,3,1,NULL,'肩架  1 RR843876750CN\r'),(5451,663232032002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','berrynate','nbninja8@yahoo.com','Nate Berry','1533 S Main St<br># 1188','Winston Salem','NC','UNITED STATES','27127-2738','(336) 816-6653','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-23 22:26:49',0,NULL,3,1,1,1,NULL,NULL),(5452,623690845001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','zephyr064','martin.lee@rogers.com','Yam Lee','423 Avondale Ave.','Ottawa','ON','CANADA','K2A 0S1','(613) 729-4936','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-23 23:00:38',0,NULL,3,1,3,1,NULL,'摄影背心 nikon xxl  1\r老款 黑 厚   RR843876732CN\r'),(5453,663266269002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','arronio','_f_i_l_e_m_o_n_@terra.es','Antonio Ramos','C/ O Rio, 8, Entlo','Burela','Lugo','SPAIN','27880','982581000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-23 23:55:37',0,NULL,3,1,2,1,NULL,'广角托架   1 '),(5455,724175754015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','manleypursuits','carl_and_laura@hotmail.com','Carl Manley','Network Rail James Forbes House 2/C/130','27 Great Suffolk Street','London','UNITED KINGDOM','SE1 0NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 00:20:14',0,NULL,3,1,3,1,NULL,'斜臂   1 RR843876746CN\r'),(5456,623724024001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','jocelynpritchard','pritchard.jocelyn@gmail.com','Jocelyn Pritchard','28 Bells Blvd','Jan Juc','Victoria','AUSTRALIA','3228','0352612345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 00:40:16',0,NULL,3,1,2,1,NULL,'小号内胆包 无字  1\rJocelyn Pritchard\r91B Pokfulam Road\rPokfulam\rHong Kong Island\rHong Kong\r '),(5457,724185237015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',3.59,'hutongstore','bodruz','bodruz@hotmail.com','Bodruz Zaman','93 Upney Lane','Barking','London','UNITED KINGDOM','IG11 9LD','07951729209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 00:46:04',0,NULL,3,1,2,1,NULL,'小号镜头筒   1 '),(5458,623728083001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.9,'hermeshine','caroleott','ceott@bendbroadband.com','Daniel Ott','19670 Manzanita Ln','Bend','OR','UNITED STATES','97702','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-01-24 00:52:02',0,NULL,3,1,1,1,NULL,'大力夹  2 '),(5459,623779011001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AO0025',40.99,'hermeshine','timi_ppt','timi.wong-yut@mail.pf','Timi Wong Yut','41 rue du bon pasteur<br>Papeete - Island of Tahiti','PAPEETE','French Polynesia','FRENCH POLYNESIA','98714','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 03:28:42',0,NULL,3,1,3,1,NULL,'nikon N4  单肩包  1 RR843874855CN'),(5460,623792446001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','mercamerca','matthew.mercadante@gmail.com','Matthew Mercadante','5 Malua cres','Mill Park','Victoria','AUSTRALIA','3082','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-01-24 04:23:33',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r反光板支架  1 \rYW864489924CN\r'),(5461,623795725001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','smolinkabkru','smolinka@bk.ru','Smolina Natalia','20 Safonova st, app#70','Vladivostok','Primorye','RUSSIAN FEDERATION','690011','89025066887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 04:47:33',0,NULL,8,1,17,0,NULL,NULL),(5462,623795916001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','smolinkabkru','smolinka@bk.ru','Smolina Natalia','20 Safonova st, app#70','Vladivostok','Primorye','RUSSIAN FEDERATION','690011','89025066887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 04:47:33',0,NULL,3,1,3,1,NULL,'倒影板  1\r40cm 棚  1 RR843874612CN'),(5463,623803469001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',10,'AE3102',100,'hermeshine','des2653','des@lensartphotography.com.au','Desmond McMillan','41 O\'Loughlan street','Ormond','Victoria','AUSTRALIA','3204','0395786884','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-01-24 05:24:14',0,NULL,3,1,3,1,NULL,'大力夹 10 RR843874572CN'),(5464,663374369002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','dendome60','dkpez@platinum.ca','Denise Pezderic','Box 1114','Claresholm','AB','CANADA','T0L 0T0','(403) 687-2149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:20:40',0,NULL,3,1,2,1,NULL,'b座   1 '),(5466,623813776001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','ralphonline','ralph95@hotmail.com','Ralph Reynolds','16 Fredericksburg Dr','Middletown','DE','UNITED STATES','19709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 06:33:41',0,NULL,3,1,1,1,NULL,NULL),(5467,623814220001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',2,'AA2120',64,'hermeshine','v.kolyshev','berliozz@gmail.com','Victor Kolyshev','c/o Eastbiz Corp., 2964 Columbia St., Suite # 26961','Torrance','CA','UNITED STATES','90503','7 926 503 3850','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 06:36:23',0,NULL,3,1,3,1,NULL,'Kolyshev Victor\rLubereckiy r-on\rOzernaya d.4, kv.3\rKorenevo Moscow region 140052\rRussian Federation\r RR843874816CN'),(5468,663376985002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','armenak*84','armenak84@mail.ru','Armenak Baghdasaryan','David Beki str. 90','Yerevan','Erebuni','ARMENIA','0008','(374)91010024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:38:47',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5469,623814739001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',4,'AB2214',4.5,'hermeshine','tinandrew','andrewtran@tinandrew.com','Andrew Tran','27450 Tourney Rd<br>Suite 130','Valencia','CA','UNITED STATES','91355-1851','(661) 799-7912','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 06:39:51',0,NULL,3,1,1,1,NULL,' '),(5470,663379506002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','keith_thum','keith@ridocolor.com','THUM TZY YIN','6795, Jalan Raja Uda','Butterworth','Penang','MALAYSIA','12300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 06:55:43',0,NULL,3,1,10,1,NULL,'2m 灯架 2\rb座  2\r柔光伞  2 \r递四方专线\rBJ8723007\r'),(5471,623817778001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',2,'AA1210',8.8,'hermeshine','yinyifanivan','yinyifan0324@hotmail.com','yifan yin','816 Peace Portal Dr','Blaine','WA','UNITED STATES','98230-4010','(778) 317-3323','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 07:06:11',0,NULL,3,1,1,1,NULL,NULL),(5476,623844367001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','ki-po','p62@ya.ru','Kirill Poltava','Prajskaya 15-58','Volgograd','','RUSSIAN FEDERATION','400005','89023644298','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 09:40:07',0,NULL,3,1,3,1,NULL,'2m 灯架  白盒  1 RR843874643CN'),(5472,724314392015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','mip69hoganas','mip69@hotmail.com','263Michael Persson','Tulpangatan 6','Höganäs','','SWEDEN','263 33','+46 42 352266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 08:23:53',0,NULL,8,1,17,0,NULL,NULL),(5473,710073719016,260660054522,'TianYa NEUTRAL DENSITY ND4 Filter replaces for Cokin P',1,'AA2324',4.65,'hutongstore','mip69hoganas','mip69@hotmail.com','263Michael Persson','Tulpangatan 6','Höganäs','','SWEDEN','263 33','+46 42 352266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 08:25:21',0,NULL,3,1,2,1,NULL,'ND4  1\rND8   1 '),(5474,623831731001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','h_o_h_o_l','www.dvdtechnik@dvdtechnik.com','Yuriy Davidenko','94 Chervonoarmiyska Street, Ap. 117','Kiev','Kiev','UKRAINE','03150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 08:29:13',0,NULL,3,1,3,1,NULL,' RR843874569CN'),(5475,663399224002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','martinsubrt','mar_s@centrum.cz','Martin Šubrt','Příčná 254/5','Bolatice','','CZECH REPUBLIC','74723','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 08:53:29',0,NULL,3,1,3,1,NULL,'115w 220v   4 \rRR843875034CN\r'),(5477,663266714002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',40.89,'hermeshine','motopittabay','scemo_chi_scrive@hotmail.it','marco pittaluga','via franco antolini 10/16','genova','GE','ITALY','16143','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 09:40:11',0,NULL,3,1,3,1,NULL,'斜臂  1\rcanon 三角包   1 RR843874657CN'),(5478,724351213015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','joa.net','joakim@3dwired.com','Joakim Brodendal','Lyngenvägen 2','Falkenberg','Halland','SWEDEN','SE31171','+4634697075','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 10:49:54',0,NULL,3,1,2,1,NULL,' '),(5479,659353954002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','deboe034','w.g.m.deboer@wxs.nl','willy de boer','schuttersdreef 68','elsloo','','NETHERLANDS','6181 ds','046-4379963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:09:58',0,NULL,3,1,2,1,NULL,'小号灰卡   1 '),(5480,623862549001,110445658830,'YONGNUO LCD Timer Remote Control for Sony RM-S1AM A700',1,'AA3223',48.9,'hermeshine','istomin2010','svi76@mail.ru','Sergey Istomin','Nikolaeva, b. 4, f. 65','Moscow','','RUSSIAN FEDERATION','123100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:14:14',0,NULL,3,1,3,1,NULL,'mc-s1   1 RR843874626CN'),(5481,663426903002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',109.5,'hermeshine','crunchgmbh','info@crunch.ch','Daniel Kunz','Mattenstrasse 90<br>CRUNCH GmbH','Biel','','SWITZERLAND','2503','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 11:31:54',0,NULL,3,1,4,1,NULL,'肩架  3 \rYW864489913CN\r'),(5482,663380701002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','joe_rocket_1','joerocket63@shaw.ca','Joel Macapagal','103 Tallman St.','Winnipeg','MB','CANADA','R2R 2P7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:42:32',0,NULL,3,1,2,1,NULL,'6662a 快装板  2 '),(5484,623276745001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',36.89,'hermeshine','konkolas1987','konkolas@gmail.com','Audrius Reipa','chemiku 15-10','Jonava','LT','LITHUANIA','55240','863720224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 11:51:12',0,NULL,3,1,3,1,NULL,'双灯头 欧标  1\r45w  2 RR843874630CN'),(5485,663440806002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 12:04:10',0,NULL,3,1,3,1,NULL,'ND2/4/8  + 52mm环架  1 RR843874802CN\r'),(5487,722914734015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',54.89,'hutongstore','rogerse1471','rogerse@hotmail.com','Edmund Rogers','49 Hazel Drive','Ferndown','Dorset','UNITED KINGDOM','BH22 9SP','07941462656','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 12:14:31',0,NULL,3,1,4,1,NULL,'背景架  （ 白 ） 2m  1\r1.6x2.1m 绿色背景布  1 \rbackground support   \r$22\rYW864489946CN\r'),(5489,623890137001,110533631499,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.6,'hermeshine','aupov','aupovy@yandex.ru','Денис Аюпов','Лежневская<br>211Б-134','Иваново','Ивановская обл','RUSSIAN FEDERATION','153038','+79612462681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 12:53:00',0,NULL,3,1,2,1,NULL,' '),(5490,724388160015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','sampos2','sampo.salmi@gmail.com','sampo  salmi','kivakatu 14a9','lahti','hame','FINLAND','15210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 12:57:14',0,NULL,3,1,2,1,NULL,'50cm  棚     1 '),(5491,623899522001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 13:30:07',0,NULL,3,1,3,1,NULL,'肩架   1 RR843874759CN\r'),(5492,663474156002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:07:03',0,NULL,8,1,17,0,NULL,''),(5493,663480203002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shuricat','poyanov@gmail.com','Alexander Poyanov','pr. Solidarnosti, d. 10, korp. 3, kv. 18','St. Petersburg','RU','RUSSIAN FEDERATION','193312','+7 921 1888935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:30:24',0,NULL,3,1,2,1,NULL,NULL),(5494,663483391002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:36:13',0,NULL,8,1,17,0,NULL,NULL),(5495,623917974001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','jacques_bay','zpiljak@gmail.com','Zarko Piljak','Zagrebacka 3','Zlatar','','CROATIA','49250','0038549467613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:36:14',0,NULL,3,1,3,1,NULL,'柔光伞   1\r反光伞  1\r大力夹   1 RR843874833CN'),(5496,623919340001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','yosigur84','yosi1984@gmail.com','Yossi Gurovich','Harav Naria','Rishon Lzion','israel','ISRAEL','75751','0523556450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 14:37:48',0,NULL,3,1,2,1,NULL,'RS-C1   1 '),(5497,623931429001,110583278297,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',7.1,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:16:54',0,NULL,8,1,17,0,NULL,NULL),(5498,663436601002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:32',0,NULL,8,1,17,0,NULL,NULL),(5499,623852537001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:33',0,NULL,8,1,17,0,NULL,NULL),(5500,663439710002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','serrol77','serzunov@yandex.ru','Sergey Erzunov','ul. Pravdy, 2-56','Volgograd','','RUSSIAN FEDERATION','400127','89177288981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:18:34',0,NULL,3,1,3,1,NULL,'72mm uv   1\r77mm uv   1\r72mm cpl   1\r天涯 77mm cpl   1 \rRR843875445CN\r'),(5501,663500855002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',3,'AA2217',26.94,'hermeshine','highflyer_gfs','highflyer_gfs@yahoo.com.br','Gustavo Fujinami Sugawara','Av. Miguel Stefano 379 ap 141','Sao Paulo','SP','BRAZIL','04301010','11 8253 8082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:30:16',0,NULL,3,1,3,1,NULL,'小号灰卡   3 \rRR843874983CN'),(5502,663501422002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 15:32:06',0,NULL,8,1,17,0,NULL,NULL),(5503,623934476001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:32:07',0,NULL,8,1,17,0,NULL,NULL),(5504,663491951002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 15:32:08',0,NULL,3,1,4,1,NULL,'52mm 镜头盖  nikon   1\r防寒罩   1\r6662a   1 \rtripod  $16\rYW864489961CN\r'),(5505,623938213001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','carlbovee','carlhbovee@hotmail.com','carl h bovee','7023 Baywood Dr','tampa','FL','UNITED STATES','33637-6463','(813) 445-1301','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 15:39:47',0,NULL,3,1,1,1,NULL,NULL),(5506,623943610001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jaymusclerussell','calgarydeluxe@hotmail.com','Jay Russell','6130 3st SE','Calgary','AB','CANADA','T2H1K4','(403) 692-3845','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 15:55:47',0,NULL,3,1,5,1,NULL,'2m 灯架  1\r斜臂   1 \rCP219487449CN\r'),(5507,724474999015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:20',0,NULL,8,1,17,0,NULL,NULL),(5508,724474755015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:21',0,NULL,8,1,17,0,NULL,NULL),(5509,710230502016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:20',0,NULL,8,1,17,0,NULL,' '),(5510,724474535015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.5,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 16:38:22',0,NULL,3,1,3,1,NULL,'62mm cpl   1\r67mm cpl   1\r58mm cpl   1\r72mm cpl   1 \rRR843874745CN\r'),(5511,662605329002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','*euazteca*','cotz@euazteca.com','EUAZTECA C/O ANHE20','2098 HARVEST RD<br># A055','SAN DIEGO','CA','UNITED STATES','92154-7609','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:03:35',0,NULL,3,1,1,1,NULL,'NG128   1 '),(5512,663431399002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mybloodygore','bobxcorex@yahoo.com','Bobby Wallad','komplek Budi Indah blok A43','cimahi utara','jawa barat','INDONESIA','40415','6281321132328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 17:09:45',0,NULL,3,1,2,1,NULL,' '),(5514,663546905002,120458029512,'Marco O Flash o-flash Ring Light For SB800 SB600 F160 ',1,'AO0026',38.49,'hermeshine','imustbeasailor','mark.duehmig@encompassfilmworks.com','Mark Duehmig','938 Langdon Ct','Annapolis','MD','UNITED STATES','21403-2811','(410) 263-2622','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 17:30:46',0,NULL,8,1,17,0,NULL,NULL),(5515,623976061001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','imustbeasailor','mark.duehmig@encompassfilmworks.com','Mark Duehmig','938 Langdon Ct','Annapolis','MD','UNITED STATES','21403-2811','(410) 263-2622','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:30:46',0,NULL,3,1,1,1,NULL,'O-FLASH 160   1\r77 环架   1 '),(5518,623986645001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','percecus','khaledmfmg@yahoo.com','Khaled M AlGhanem kwi 17058','14729 182nd St','Springfield Gardens','NY','UNITED STATES','11413-4028','718 553 8740','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 17:46:30',0,NULL,3,1,1,1,NULL,'sf18-canon   1 '),(5519,724517276015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',68,'hutongstore','chrismcparker','chrismcparker@yahoo.com','Chris Parker','14 Meadow View Frampton Cotterell','Bristol','Avon','UNITED KINGDOM','bs36 2ng','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 17:56:24',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r50-70 棚英标  2\r包   1 \rlighting kit  $25\rYW864489972CN\r'),(5520,623992484001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','coriumtech','ale@coriumtech.com','Anthony Le-Engineer','235 constitution dr','menlo park','CA','UNITED STATES','94025-1108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 17:57:56',0,NULL,3,1,1,1,NULL,'40cm 棚   1 '),(5521,724520230015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','evet_nurse','sldifford@googlemail.com','Shannon Difford','8 Verriers','North Petherton','Somerset','UNITED KINGDOM','TA6 6SX','01278662843','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-01-24 18:00:14',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 2m  1\rYW864490005CN\rbackgroundsupport  $22 '),(5522,663585568002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','cekisieda','cemkastrat@hotmail.com','eda kastrat','ahmet kutsi tecer caddesi 55/d<br>merter/güngören','istanbul','','TURKEY','34010','2125547718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 18:50:31',0,NULL,3,1,3,1,NULL,'2m 灯架  1\r反光板支架   1 RR843874691CN\r'),(5524,710311288016,260646728395,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',23.9,'hutongstore','tomaspaypal123','tomas.dolejsi@fotoradce.cz','Tomas Dolejsi','Pod Radnici 3183','Havlickuv Brod','','CZECH REPUBLIC','58001','(0420) 737164334','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 19:09:56',0,NULL,3,1,3,1,NULL,'白色的厚的3m x2m 背景布   1 RR843874762CN'),(5525,663622731002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','cmcg2366','caitmcgill@yahoo.com','Caitlin McGill','94A S 6th Ave','Clarion','PA','UNITED STATES','16214-2032','(724) 316-8736','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 19:57:41',0,NULL,3,1,1,1,NULL,NULL),(5526,624066857001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alexjap','alex_olson_oki@hotmail.com','Alex Olson','19 Pena Parda','La Herradura, granada','','SPAIN','18697','628077459','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 20:19:22',0,NULL,3,1,4,1,NULL,'2m 灯架  1\r斜臂   1 \rboom arm    $20\rYW864489950CN\r'),(5527,663639814002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','davidfge75','davidfge@gmail.com','david Fdez de Gamarra','Calle Comercio 17, Bajo C','Legutiano','País Vasco','SPAIN','01170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 20:28:52',0,NULL,3,1,4,1,NULL,'2m 灯架   2\rb座   2\r柔光伞  2\rlight stand  $20 \rYW864489983CN\r'),(5528,623912696001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','snap_to_it','duffie81@yahoo.com','Casandra Cross','14 Walker ave','Bradford','PA','UNITED STATES','16701-1229','(814) 598-9259','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 20:29:56',0,NULL,3,1,1,1,NULL,NULL),(5529,624090832001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:49',0,NULL,8,1,17,0,NULL,NULL),(5530,663654334002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:50',0,NULL,8,1,17,0,NULL,NULL),(5531,663657627002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:51',0,NULL,8,1,17,0,NULL,NULL),(5532,663656334002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:51',0,NULL,8,1,17,0,NULL,NULL),(5533,624081034001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','perjorgen','pjsoerbo@online.no','per jørgen sørbø','Kirkeveien 11','Kjøllefkord','finnmark','NORWAY','9790','004741308733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:07:52',0,NULL,3,1,3,1,NULL,'67mm 环架  1 \r渐变灰  1\r72mm cpl   1\r广角托架   2\r67mm 镜头盖  nikon   1RR843874731CN\r'),(5535,724653938015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','sherrykey123','sherryk@hotmail.co.uk','sherriden key','60 Corby Park North Ferriby','Nr Hull','Humberside','UNITED KINGDOM','HU14 3AY','01482631886','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 21:27:12',0,NULL,3,1,4,1,NULL,'2m 灯架  2\rb座  2\r柔光伞  2\rlight stand  $20 \rYW864489994CN\r'),(5536,661846342002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','stlkrush','glennb91111@yahoo.com','GLENN BILLINGSLEY','25 Lee Ave','FERGUSON','MO','UNITED STATES','63135-2951','(314) 524-3214','NoPaymentFailure','CheckoutComplete','Other','2011-01-24 21:32:18',0,NULL,3,1,1,1,NULL,'sony 背心  xxxl   1\r新款 黑 厚   '),(5538,624105204001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',3,'AB2214',4.5,'hermeshine','izidororenato','renato.carlos.izidoro@gmail.com','Renato Izidoro','r. Genebra, 143<br>Pq. Novo Oratório','Santo André','São Paulo','BRAZIL','09260-260','55-11-44792647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:37:41',0,NULL,3,1,2,1,NULL,'品胜3.0 膜  3 '),(5539,663676466002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','mjcecchini','maurice_cecchini@hotmail.com','Maurice J Cecchini','1739 Shady Leaf Dr','Valrico','FL','UNITED STATES','33596-6130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-24 21:39:13',0,NULL,3,1,1,1,NULL,NULL),(5541,710410848016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','mr-butters','unclesond@gmail.com','Toby Maloy','18 Kingfisher Drive Sandhills','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','LU7 4SG','07828463466','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-24 21:41:40',0,NULL,5,1,18,1,NULL,'sf18-canon  1 '),(5542,724665190015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','marco_sartori','m_sartori@alice.it','Maurizio Sartori','Via Bodoni,13','Verona','VR','ITALY','37131','340-9227445','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 21:47:06',0,NULL,8,1,17,0,NULL,NULL),(5543,724659292015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',12.99,'hutongstore','marco_sartori','m_sartori@alice.it','Maurizio Sartori','Via Bodoni,13','Verona','VR','ITALY','37131','340-9227445','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-24 21:47:07',0,NULL,3,1,3,1,NULL,'单灯头 欧标  1\r115w 220v   1 \rRR843875048CN\r'),(5544,624111173001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','tonytiger321','tony.tiger321@ntlworld.com','ANTHONY JOHNSON','12 RECREATION CLOSE','FELIXSTOWE','Suffolk','UNITED KINGDOM','IP11 9BE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:51:50',0,NULL,3,1,2,1,NULL,'star6   1 '),(5545,624112302001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','andreysuchkov','fiap-sas@rambler.ru','Andrey Suchkov','ul.Parovoznaya<br>10-28','Orel','','RUSSIAN FEDERATION','302029','+7-910-302-7820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 21:54:35',0,NULL,8,1,17,0,NULL,NULL),(5546,663686363002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','andreysuchkov','fiap-sas@rambler.ru','Andrey Suchkov','ul.Parovoznaya<br>10-28','Orel','','RUSSIAN FEDERATION','302029','+7-910-302-7820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:03:08',0,NULL,3,1,2,1,NULL,'52mm 镜头盖  nikon   1\r72mm 橡胶罩   1 '),(5547,663686975002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','tkhagapsu','desperado.mail@gmail.com','Timur Tkhagapsu','ul. Budennogo d.480','Krasnodar','','RUSSIAN FEDERATION','350038',' 8918-348-0690','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:05:50',0,NULL,3,1,5,1,NULL,'2m 灯架  1\r斜臂  1 RR843874674CN改号了\rCP219636956CN\r'),(5548,663687600002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','karduc2','karduc@hotmail.com','pedro angel ducar legua','monasterio de veruela  28/30','alagon','Aragón','SPAIN','50630','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:06:19',0,NULL,3,1,3,1,NULL,'2m灯架 1\r云台   1\r柔光伞   1 RR843874714CN\r'),(5549,624117743001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','stevea1957','stevea57@gmail.com','Stephen Armstrong','6 Leeside Road','North Avoca','New South Wales','AUSTRALIA','2260','0409982202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:08:48',0,NULL,3,1,2,1,NULL,'小号镜头筒   1 '),(5550,663688789002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 22:11:30',0,NULL,3,1,3,1,NULL,'100-150 反光板  1 RR843874665CN'),(5551,624119345001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',4.4,'hermeshine','klemgor','klemen977@gmail.com','klemen gorup','kobdilj 34','default','štanjel','SLOVENIA','6222','00386 31 273 279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:14:07',0,NULL,3,1,2,1,NULL,' '),(5554,710435415016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','garrapiu','kelpalacin@hotmail.com','Miquel Palacin Alonso','Av. Bisbe Iglesies 48b 3º-1ª','Tremp  ( LLeida)','Cataluña','SPAIN','25620','629723788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 22:28:58',0,NULL,3,1,2,1,NULL,'77mm 渐变灰  1 '),(5555,624124631001,110528443567,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','kiphoto2011','kilmer.ribeiro@hotmail.com','KILMER RIBEIRO','RUA TREVISO 501 APTO 02','SIDERÓPOLIS','SANTA CATARINA','BRAZIL','88860-000','(48) 8416-0072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-24 22:29:28',0,NULL,3,1,2,1,NULL,NULL),(5556,663708192002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','sandren10','sandren_82@hotmail.com','Thurairatnam Uthayachandran','Rødetvet veien 9c','Oslo','OSlo','NORWAY','0955','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-24 23:11:07',0,NULL,3,1,3,1,NULL,'摄影背心  canon  m  1\r老款  RR843874780CN\r'),(5557,621489335001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','robin0onibus','robin159951@gmail.com','Mohammad Hossain','76 Silvio Ave','Toronto','ON','CANADA','M1K1V3','(647) 244-3683','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(5559,724695852015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','ealpozo','alpozo@cajamar.es','Antonio Luis Pozo Marín','Avd José Antonio, 16','Tíjola','Almeria','SPAIN','04880','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-24 23:36:04',0,NULL,3,1,2,1,NULL,'一转四灯头   1 '),(5560,624156029001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','assmoll','quintosarvin@yahoo.com','arvinquintos','apartment #5 G. Dochall building 4 ewing st.','hamilton','','BERMUDA','hm17','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:12:17',0,NULL,3,1,2,1,NULL,NULL),(5561,663727767002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','p_ronto','p_ronto@hotmail.com','Panos Rontogiannis','5 Tzoumerkon street<br>Papagos','Athens','Attiki','GREECE','15669','++302106544955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:13:39',0,NULL,3,1,2,1,NULL,'小号灰卡  1 '),(5562,663730513002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','michele2310','mshirer23@yahoo.com','MICHELE SHIRER','432 CENTER STREET','GRATIOT','OH','UNITED STATES','43740','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 00:22:23',0,NULL,3,1,1,1,NULL,NULL),(5563,624153512001,110446398636,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','pixel-photo','fern49@gmail.com','Fernand Larochelle','5292 rue des Violettes','Charlesbourg','QC','CANADA','G1G 1N4','(418) 260-9423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:46:29',0,NULL,3,1,2,1,NULL,NULL),(5564,624165140001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','shoeskate05','skateshoe05@hotmail.com','erick martinez','575 ivy street','san francisco','CA','UNITED STATES','94102','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 00:47:22',0,NULL,3,1,1,1,NULL,'麂皮  1 '),(5565,661048854002,120568071825,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','susantorudy','rudy.sto@gmail.com','Rudy Susanto','Apartemen Gading Mediterania Residences Tower A/19AG<br>Jl.Boulevard BGR Kelapa Gading','Jakarta','DKI Jakarta','INDONESIA','14250','+628179993920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 00:48:14',0,NULL,3,1,2,1,NULL,NULL),(5566,663743729002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','iankoning','bamiballetje@gmail.com','Ian Koning','Bernadottelaan 232','HAARLEM','','NETHERLANDS','2037GX','0613349568','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 01:03:04',0,NULL,3,1,3,1,NULL,'肩架  1 RR843874705CN'),(5568,663744714002,120568071854,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','johnlx-2008','postc@seznam.cz','Jaroslav Lhotsky','Fabianova 511/2','Prague 5','Czech Republic','CZECH REPUBLIC','15000','+420739358514','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 01:07:04',0,NULL,3,1,5,1,NULL,'2m  灯架  2\r双灯头  欧标  2\r反光伞   2\r包    1 \rCP219487470CN\r'),(5569,624195990001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','nathanivy','americanivy@gmail.com','Ryan Ivy','3127 Josephine St','Denver','CO','UNITED STATES','80205-4152','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-01-25 02:46:35',0,NULL,3,1,1,1,NULL,' '),(5571,663793056002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','jjelicich','jjelicich@citipointe.com.au','Verona Saints','PO BOX 2141','Mansfield BC','Queensland','AUSTRALIA','4122','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 04:14:30',0,NULL,3,1,3,1,NULL,' 肩架   1RR843874688CN'),(5573,663805038002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','deefadug','duggy@exemail.com.au','doug woods','24 Atami Crescent','Corio','Victoria','AUSTRALIA','3214','0352757636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 05:13:34',0,NULL,3,1,2,1,NULL,'广角托架  1 '),(5574,624226557001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','t.u.k.a','2-ka@mail.ru','Arthur Zakirov','103 Lunacharskogo Str. App. 48.','Perm','Permskiy Kray','RUSSIAN FEDERATION','614015','+79655658152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 05:14:59',0,NULL,3,1,3,1,NULL,'40cm 棚  1 RR843874728CN\r'),(5575,710562233016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:55',0,NULL,8,1,17,0,NULL,NULL),(5576,724817398015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5577,724816918015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5578,724816786015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:56',0,NULL,8,1,17,0,NULL,NULL),(5579,710561677016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','tcd_davo','dharte@iinet.net.au','David Harte','190 Delgado Parade','Perth','Western Australia','AUSTRALIA','6028','0893040659','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 05:56:57',0,NULL,3,1,3,1,NULL,'cpl  1\r77mm 接口环  1\r52mm 接口环  1\rnd8   1\r渐变灰   1 .\rRR843874966CN\r'),(5580,624221997001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','robinmaness2009','kiwedin@gmail.com','Robin Maness','1060 Chippewa cres','Sarnia','ON','CANADA','N7T8A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 06:32:40',0,NULL,3,1,2,1,NULL,'机身盖/镜头后盖 nikon  2 '),(5582,724828381015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','perugorria','pedro_etxaniz@donostia.org','Pedro Echaniz Rojo','Apartado 35','Pasaia','Euskadi','SPAIN','20110','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 06:59:07',0,NULL,3,1,2,1,NULL,'50cm 棚  1 '),(5583,624243987001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lantal007','lantal87@optusnet.com.au','Laurie Antal','8 Garfield Ave','Kurralta Pk','South Australia','AUSTRALIA','5037','0882935856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 07:15:21',0,NULL,3,1,2,1,NULL,NULL),(5585,663826368002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','t_isoviita','tapio_isoviita@hotmail.com','Tapio Isoviita','Lestikatu 4b','Kankaanpää','','FINLAND','38700','0405271406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 07:41:14',0,NULL,3,1,2,1,NULL,NULL),(5586,624251366001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','michelaterreur','achvend@orange.fr','Michel Berger','3 allée des serins','St Gilles','Réunion','REUNION','97434','0262245104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:03:46',0,NULL,3,1,2,1,NULL,NULL),(5587,624250522001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:37',0,NULL,8,1,17,0,NULL,NULL),(5588,624250441001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:38',0,NULL,8,1,17,0,NULL,NULL),(5589,624249954001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:09:38',0,NULL,8,1,17,0,NULL,NULL),(5590,624249780001,110566019079,'Full Set 52mm-77mm 7 Adapter Ring Filter Holder 4 cokin',1,'AKT025',25.98,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 08:09:39',0,NULL,8,1,17,0,NULL,NULL),(5591,624250231001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','gohher','hher@hknews.co.kr','Her Sung Ho','Kuro 5-Dong 23-2<br>Kuro-Goo','Seoul','','KOREA,REPUBLIC OF','152-838','82-2-3282-1812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 08:09:39',0,NULL,3,1,3,1,NULL,'渐变灰  渐变橙  渐变蓝 \rND2   ND4  ND8 \r6PCS滤镜袋  1\r52-77mm 接口环 + 托架  1\r82mm 接口环   1\rstar6  1\rstar8   1 .\rRR843874881CN\r'),(5592,724845284015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 08:28:58',0,NULL,8,1,17,0,NULL,''),(5593,710589382016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 08:28:59',0,NULL,3,1,3,1,NULL,'2m 灯架  1\rb座   1\r柔光伞  1 \rRR843876919CN\r'),(5594,724844941015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-25 08:28:59',0,NULL,3,1,3,1,NULL,'大号灰卡  1 \r80cm 5in1  反光板  1\rRR843875051CN\r\r '),(5595,663837470002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gagan.aries','gagan.aries@gmail.com','Gagan Bhatia','Zynga Game Network India Private Limited<br>5th floor, Esquire Center, No.9 MG Road','Bangalore','KA','INDIA','560001','919916222288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-25 08:48:59',0,NULL,3,1,2,1,NULL,'fangbo1234 '),(5596,724853437015,250606688659,'New IR Remote Control for Pentax K10D K20D K100D',1,'AA2205',2.75,'hutongstore','kissmukk','szentesi.adam@gmail.com','Adam Szentesi','Keszkeno u 1.','Budapest','','HUNGARY','1131','+36-1-3706090','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-01-25 09:12:20',0,NULL,3,1,2,1,NULL,'红外遥控 5in1   1 '),(5598,663661188002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-01-25 10:53:22',0,NULL,3,1,3,1,NULL,'碗罩  p4   1 \rRR843874970CN\r'),(5600,663832132002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',3,'AO0005',38.4,'hermeshine','maisy_mouse66','bodger4@optusnet.com.au','Carey Donoghoe','7 Weiske Street','Narre Warren, Melbourne','Victoria','AUSTRALIA','3805','0423565015','NoPaymentFailure','CheckoutComplete','AU_Other','2011-01-25 10:48:28',0,NULL,3,1,3,1,NULL,'1.6x2.1  绿色  粉色  浅蓝 黄色    背景布  4 \rRR843875167CN\r'),(5601,621626461001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','chandler_furt','chandler_furtado@hotmail.com','Chandler Furtado / Roberta LIns','2 Putnam St','Nashua','NH','UNITED STATES','03064-2548','(603) 785-9414','NoPaymentFailure','CheckoutComplete','Other','2011-01-26 01:03:33',0,NULL,3,1,1,1,NULL,'nikon 摄影背心 L   1\r老款 黑 '),(5604,623789257001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','darkwinner','darkwinner@hotmail.com','Victor Campos','1014 W Harvard St','Champaign','IL','UNITED STATES','61821-2533','','NoPaymentFailure','CheckoutComplete','Other','2011-01-27 02:16:44',0,NULL,3,1,3,1,NULL,' RR843875431CN\r'),(5605,622285919001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','progresia','sorocan.irina@gmail.com','Irina Sorocan','Moldova (republic of), Chisinau, str. Piata Garii 2, apt. 9','Chisinau','','MOLDOVA, REPUBLIC OF','2001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-27 16:41:10',0,NULL,5,1,18,0,NULL,NULL),(5606,706950264016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',2,'AB1402',17.98,'hutongstore','shilzo','ub3r.shilzo@gmail.com','James Shilingis','6 Frances Green Springfield','Chelmsford','Essex','UNITED KINGDOM','CM1 6EG','07545592682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-01-28 07:16:58',0,NULL,5,1,18,0,NULL,NULL),(5612,724610228015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','ibtisam-7','ibti-7@hotmail.com','Ibtisam Sadegh','Le monde, 56, censu busuttil','Iklin','Malta','MALTA','IKL1021','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-01-29 13:32:32',0,NULL,5,1,18,0,NULL,NULL),(5614,620584741001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',11,'AA1309',26.6,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-01-30 01:20:54',0,NULL,5,1,18,0,NULL,NULL),(5624,680261173002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','ottawaronin','manjiro@gmail.com','John Tajima','112 Monterey Dr','Ottawa','ON','CANADA','K2H 7A8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 03:33:56',0,NULL,3,1,3,1,NULL,' 黑色的厚的 xl sony 背心 \r  1\rRR843870876CN\r8\r '),(5625,640230290001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','1086_kloda','waldemar_kloda@yahoo.ca','WALDEMAR KLODA','26 HARJOLYN DR','TORONTO','ON','CANADA','m9b3t9','(416) 232-1086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 04:28:42',0,NULL,3,1,2,1,NULL,NULL),(5626,680292879002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','o.g.s.ofilms','kgosidintsi@gmail.com','OREEDITSE KGOSIDINTSI','P O BOX 70593','GABORONE','','BOTSWANA','00267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 06:27:05',0,NULL,3,1,5,1,NULL,'欧标转美标头  2\r申报$5  gift\rCP219487545CN\r'),(5627,680297154002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','stparadox1','z.man2@centrum.cz','Zdenek Konecny','Slunecna 16','Hodonin','','CZECH REPUBLIC','69501','042 739 131 135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 06:47:53',0,NULL,3,1,2,1,NULL,NULL),(5628,640256459001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rs-rons-shop','tzrohn@gmail.com','Yaron Tsezana','Hamaagal 36','Ramat-Gan','Israel','ISRAEL','52472','(972)523631847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 07:09:27',0,NULL,3,1,3,1,NULL,' RR843871029CN\r'),(5629,730163121016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',54.5,'hutongstore','palabe-h','palabe61@gmail.com','László Papp','Dózsa György utca 15/A','Balatonfüred','','HUNGARY','8230','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 07:10:35',0,NULL,3,1,5,1,NULL,' CP219487554CN\r'),(5630,730174866016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3301',19.56,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 08:11:57',0,NULL,8,1,17,0,NULL,NULL),(5631,744989967015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 08:11:59',0,NULL,8,1,17,0,NULL,NULL),(5632,744990199015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',77,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-01 08:11:59',0,NULL,3,1,4,1,NULL,'80cm 反光板  5in 1  2\r背景架2mx 1.6m（白）  1\r灯架  2m  4\r50-70 棚  欧标   2\r双灯头  欧标   2\r反光伞  2\r115w 220v   4\r包   2\rlighting kit  $30\rYW864870620CN\r从这里开始查询'),(5633,640277164001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','guessouzbak','gui_ome@live.fr','guillaume aguilar','3 rue rougeot','chalon sur saone','Bourgogne','FRANCE','71100','0685229509','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 09:02:19',0,NULL,3,1,4,1,NULL,'background $20 \rYW864870594CN'),(5634,680346062002,120568984657,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',1,'AKT013',25.8,'hermeshine','controlaltsup','alex.monjas@gmail.com','Sonia Soriano de Dios','Palex Medical<br>Francesc Viñas, 5','Sant Cugat del Valles','Barcelona','SPAIN','08174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 10:54:12',0,NULL,3,1,3,1,NULL,' RR843871240CN\r'),(5635,680350917002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','fieraz','fieraz@gmail.com','Pedro Ferrer Martino','PABLO GARNICA, 53D1ºC','TORRELAVEGA','Cantabria','SPAIN','39300','606354535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 11:15:20',0,NULL,3,1,2,1,NULL,NULL),(5636,640325161001,110468046436,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',2,'AKT013',51.6,'hermeshine','enriched92','libra-oha@hotmail.com','Hong An Ong','Boon Lay Drive Blk 268a #13-584','default','Boon Lay Drive','SINGAPORE','641268','+65- 96753274','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 12:32:58',0,NULL,3,1,3,1,NULL,' RR843871253CN\r'),(5637,680374529002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','kobayashi516','k516k516.10@gmail.com','koichiro kobayashi','kamitsuruma 6-29-3','minami-ku sagamihara-shi','Kanagawa','JAPAN','252-0302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 12:49:32',0,NULL,3,1,3,1,NULL,' RR843871236CN\r'),(5638,680384168002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 13:24:01',0,NULL,3,1,2,1,NULL,NULL),(5639,745100755015,250599929225,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','juvinar','juvinar22@yahoo.com','juvinar santiago','9 cabot green ducie road','lawrence hill','Bristol','UNITED KINGDOM','bs5 0ar','01173730712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-01 14:17:48',0,NULL,3,1,2,1,NULL,'ND8   1\r77MM 环架  1 '),(5640,640358070001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','slava-svg','svg2003@inbox.ru','Slava Gordienko','Tchaikovskogo 23, kv 48','Blagoveschensk','','RUSSIAN FEDERATION','675025','+79246736884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 14:36:04',0,NULL,3,1,2,1,NULL,NULL),(5641,680409319002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','linaboard78','linarellomarco@tiscali.it','marco linarello','via barengo, 1','agnellengo di momo','NO','ITALY','28015','3938929816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 14:49:55',0,NULL,3,1,4,1,NULL,'YW864870561CN '),(5642,640363191001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',6,'AB1301',20.04,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 14:51:15',0,NULL,8,1,17,0,NULL,''),(5645,730204079016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 15:25:36',0,NULL,3,1,2,1,NULL,' '),(5646,745020954015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',7.5,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 15:25:35',0,NULL,3,1,2,1,NULL,''),(5647,640378410001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',6,'AB1301',20.04,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 15:49:31',0,NULL,3,1,1,1,NULL,'  橡胶遮光罩 52mm  12'),(5657,745262264015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','bibmas_hoff','bibmas@get2net.dk','Thomas Hoff','Tangevej 10','Skovlunde','','DENMARK','2740','(+45) 44538747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 19:36:44',0,NULL,3,1,2,1,NULL,'绿叶 CPL  67mm    1\r绿叶 CPL  77mm   1'),(5656,730435293016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','bibmas_hoff','bibmas@get2net.dk','Thomas Hoff','Tangevej 10','Skovlunde','','DENMARK','2740','(+45) 44538747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 19:36:44',0,NULL,8,1,17,0,NULL,NULL),(5650,680451481002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','kitae42','j.kim2@yahoo.com','HAE SOOK KIM','1395 Tomah Dr','FRISCO','TX','UNITED STATES','75034-0962','(551) 486-2820','NoPaymentFailure','CheckoutComplete','Other','2011-03-01 16:53:01',0,NULL,3,1,1,1,NULL,'老款 厚  m '),(5651,640412669001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mhmarkham','meenahar@yahoo.com','Meena Hari','25 Juneberry Ave','Markham','ON','CANADA','L3s 4B1','(905) 294-5286','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 17:14:37',0,NULL,3,1,2,1,NULL,NULL),(5652,640452356001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','gethomeb4dark','maixue.barrow@gmail.com','Michelle Barrow','Box  3904','Banff','AB','CANADA','T1L 1E4','4939510490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 18:43:49',0,NULL,3,1,2,1,NULL,' '),(5654,640460358001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 19:05:11',0,NULL,3,1,3,1,NULL,' RR843871165CN\r'),(5655,680512937002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 19:08:10',0,NULL,8,1,17,0,NULL,NULL),(5658,640463195001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','misc_items_2010','ebay-sales@talknflirt.com','Ricky Gamble','1 Flanders Row<br>Railway Road','Wisbech','Cambridgeshire','UNITED KINGDOM','PE13 2UP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 19:37:32',0,NULL,3,1,2,1,NULL,NULL),(5659,680360965002,120536002597,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',3,'AB1407',23.67,'hermeshine','ynovikov','portsmann@gmail.com','YURI NOVIKOV','Dunaisky prospekt 24, 48','St.Petersburg','-','RUSSIAN FEDERATION','196158','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 20:05:09',0,NULL,3,1,3,1,NULL,' RR843871179CN\r'),(5660,640510149001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.5,'hermeshine','j_b_luo','j_b_luo@hotmail.com','Jiabin Luo','32 Yellow Birchway','North York','ON','CANADA','M2H 2T3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 20:36:00',0,NULL,3,1,2,1,NULL,NULL),(5661,640510267001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cadlp','mr.clean2@verizon.net','David L. Pinckney','81 Corinne Dr','Newbury Park','CA','UNITED STATES','91320','(805) 796-9894','NoPaymentFailure','CheckoutComplete','Other','2011-03-01 20:36:14',0,NULL,8,1,17,0,NULL,NULL),(5662,680557143002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',9.25,'hermeshine','cadlp','mr.clean2@verizon.net','David L. Pinckney','81 Corinne Dr','Newbury Park','CA','UNITED STATES','91320','(805) 796-9894','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 20:36:14',0,NULL,3,1,1,1,NULL,'摄影背心 Nikon  xxxl  老款 厚  黑   1\r大号内胆包 nikon    1 '),(5663,745318550015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',13.9,'hutongstore','marshia31','pepsoua@hotmail.com','Maria Panagiotou','P.O.BOX 70705','Limassol','Cyprus','CYPRUS','3802','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 21:00:12',0,NULL,3,1,2,1,NULL,' '),(5664,640535157001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','valla34','osquarmm@yahoo.es','Oscar Montero Muñoz','C/ Manuel Jimenez El Alguacil, 1, 9, 1B','Pinto','Madrid','SPAIN','28320','655462124','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 21:29:25',0,NULL,3,1,4,1,NULL,' YW864870572CN'),(5665,680593731002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-01 21:45:31',0,NULL,8,1,17,0,NULL,NULL),(5666,640545353001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-01 21:50:14',0,NULL,3,1,4,1,NULL,'双灯头 欧标   1\r115w 220v   2\r2m 灯架  2\rb座   2\r柔光伞   2 \rYW864870583CN'),(5667,640568774001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5,'hermeshine','j-ric117','jandon@centurylink.net','jan richardson','29180 engoe rd','washburn','WI','UNITED STATES','54891-4899','(715) 373-5427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-01 22:55:07',0,NULL,3,1,1,1,NULL,NULL),(5668,745389283015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','minimalteq','marcinkielek0@wp.pl','Marcin Kielek','53 Degrees North Unit 428, Retail Park 3, Blanchardstown Centre','Dublin','Dublin','IRELAND','15','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-01 23:19:44',0,NULL,3,1,2,1,NULL,NULL),(5669,640610568001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','apcpnp00','tprice@uaw.net','Anthony Price','13130 Dartmouth St','Oak Park','MI','UNITED STATES','48237-1632','(248) 548-1226','NoPaymentFailure','CheckoutComplete','Other','2011-03-02 01:24:20',0,NULL,3,1,1,1,NULL,'摄影背心 nikon 老款 厚  xxxl   1 '),(5670,745432169015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','copelinter','ricoplin@googlemail.com','Richard Copeland','69 Delamere RD Bedworth','Nuneaton','Warwickshire','UNITED KINGDOM','CV12 8SG','02476314961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 01:28:17',0,NULL,3,1,2,1,NULL,NULL),(5671,680663798002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','palenquej','jpalenque@hotmail.com','javier palenque','16575 SW 100th Ter','MIAMI','FL','UNITED STATES','33196-1026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-02 01:21:47',0,NULL,3,1,1,1,NULL,NULL),(5672,730638802016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 03:48:55',0,NULL,3,1,2,1,NULL,'气吹+ 布   1 '),(5673,680710690002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','hot_teg','lukepenfold@hotmail.com','Luke Penfold','14 Candlebark Close','Hampton Park','Victoria','AUSTRALIA','3976','0397997317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 04:22:03',0,NULL,3,1,4,1,NULL,'reflector holder   \r$20 \rYW864870550CN\r'),(10143,676920450001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','bodhitawa','d.acosta@hotmail.com','DANIEL ACOSTA STAJNER. 51675158T','C/ EL FORT, 26. URB. EL PARADISO. BUZÓN 124.','ALTEA LA VELLA. ALICANTE','Comunidad Valenciana','SPAIN','03599','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 09:52:49',0,NULL,3,1,3,1,'RA117738314CN\r ','bodhitawa\rNG128 柔光罩   1\r反光板 110cm 5合1   1'),(5674,640660032001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','malaka_is','malaka.indrajith@gmail.com','Malaka Indrajith','260/25 B, Depot Road,','Katubedda','Western','SRI LANKA','10400','+94777335273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:04:22',0,NULL,3,1,2,1,NULL,NULL),(5675,640606044001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','lucialetizia82','lucialetizia.litrico@virgilio.it','lucia letizia litrico','via salvatore Santangelo n°1','san giovanni galermo','CT','ITALY','95123','3489580807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:56:00',0,NULL,3,1,2,1,NULL,' '),(5676,680727462002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','pinballwizard4who','kendyberaldo@yahoo.com.br','Kendy Beraldo','Rua Afonso de Freitas, 350 apto 21','Sao Paulo','Sao Paulo','BRAZIL','04006-905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 05:58:08',0,NULL,3,1,5,1,NULL,'放2个欧标头 \rCP226630830CN'),(5677,640668298001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','realzordrek','zordrek@gmail.com','Peter Gorbik','Azattyk 5a-10','Atyrau','','KAZAKHSTAN','060002','7122328248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 06:09:00',0,NULL,3,1,2,1,NULL,NULL),(5678,640675496001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','o.g.s.ofilms','kgosidintsi@gmail.com','OREEDITSE KGOSIDINTSI','P O BOX 70593','GABORONE','','BOTSWANA','00267','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 06:44:40',0,NULL,3,1,5,1,NULL,' CP226630826CN'),(5679,640691609001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','wil_buan','wil_buan@hotmail.com','Wilfredo Buan','1270 N Marine Corps Dr<br>STE 101 PMB 481','Tamuning','GU','GUAM','96913-4331','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 08:19:03',0,NULL,3,1,1,1,NULL,NULL),(5680,680752692002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','zs-dedan','zsdedan@gmail.com','Yuriy Artyomov','Novaya 5-19','Zverosovkhoz, Pushkinsky','Moscow Region','RUSSIAN FEDERATION','141214','+79067512597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 08:20:56',0,NULL,8,1,17,0,NULL,NULL),(5681,745536554015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','pdrozda','pdrozda@gmail.com','Peter Drozda','Stalicova 3','Kosice','','SLOVAK REPUBLIC','04012','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 08:23:28',0,NULL,3,1,2,1,NULL,NULL),(5682,640692789001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','zs-dedan','zsdedan@gmail.com','Yuriy Artyomov','Novaya 5-19','Zverosovkhoz, Pushkinsky','Moscow Region','RUSSIAN FEDERATION','141214','+79067512597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 08:26:02',0,NULL,3,1,2,1,NULL,NULL),(5683,680789923002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','jarsjoseantonio','jars.diablo@gmail.com','jose antonio ruiz sanchez','hurb los altos manzana 5 nº73','torrevieja','Comunidad Valenciana','SPAIN','03185','661067167','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 11:09:00',0,NULL,3,1,4,1,NULL,'欧标 \rlighting kit  $30\rYW864870653CN\r'),(5684,680814883002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','sylvain286','sylricha@bell.net','Sylvain Richard','697 du Moulin','Magog','QC','CANADA','J1X 5Z5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 12:45:29',0,NULL,3,1,3,1,NULL,' RR843871372CN\r'),(5685,640753170001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',2,'AA3314',13,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:45',0,NULL,8,1,17,0,NULL,NULL),(5686,680815670002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',2,'AA3313',12,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:47',0,NULL,8,1,17,0,NULL,NULL),(5687,640753138001,110407881132,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',2,'AA3308',11.2,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:48',0,NULL,8,1,17,0,NULL,NULL),(5688,640753145001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',2,'AA3310',11.2,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:50:49',0,NULL,3,1,3,1,NULL,'绿叶 CPL  77mm   2\r 绿叶 CPL 72mm  2\r绿叶 CPL  52mm  2\r绿叶 CPL  58mm  2\rRR843872452CN\r\r'),(5689,680818700002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','hasnahhasim','munirahasim@yahoo.com.my','Hasnah Hasim','No. 6549 , Kampung Guar Kohor , Jalan Changloon','Kodiang','Kedah','MALAYSIA','06100','0195471500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 12:59:48',0,NULL,3,1,2,1,NULL,NULL),(5690,680821493002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','richwhillock','ctsatellites@gmail.com','James Richmond Whillock','3900 Hillcrest Ln','Mobile','AL','UNITED STATES','36693-2832','(251) 666-6030','NoPaymentFailure','CheckoutComplete','Other','2011-03-02 13:09:42',0,NULL,3,1,1,1,NULL,'XL  老款'),(5691,680826352002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','e-paul-info','abrim@op.pl','Pawel Abramczyk','1A DEANWOOD AVE.<br>TOGHER','CORK','','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 13:28:01',0,NULL,8,1,17,0,NULL,' '),(5692,680825724002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','e-paul-info','abrim@op.pl','Pawel Abramczyk','1A DEANWOOD AVE.<br>TOGHER','CORK','','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 13:28:01',0,NULL,3,1,2,1,NULL,'渐变灰  1\r72mm 环架   1 '),(5693,745643400015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ywetka83','ywetka@gmail.com','Iveta Tonhauserova','Madridska 3','Kosice','','SLOVAK REPUBLIC','04013','+421911266303','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-02 14:08:52',0,NULL,3,1,3,1,NULL,' RR843871457CN\r'),(5694,680839942002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','rotel54','fam.r.hunziker@bluewin.ch','Hunziker Rolf','Tannmättli 6','Tägerig','','SWITZERLAND','5522','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 14:13:41',0,NULL,3,1,3,1,NULL,'xxl   老款\rRR843871267CN\r'),(5695,730814419016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT050',132,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-02 15:09:28',0,NULL,8,1,17,0,NULL,NULL),(5696,745659157015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 15:09:28',0,NULL,8,1,17,0,NULL,NULL),(5697,730814108016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','michele.paladino','mike.pala90@hotmail.it','Michele Paladino','Via Carnazza n.31','Tremestieri Etneo','CT','ITALY','95030','3471259560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 15:09:29',0,NULL,3,1,4,1,NULL,'背景架2m x 3m  1\r 背景布 3x6 绿色  1\r灯架  2m  2\r柔光箱 50-70cm 单灯头  2   欧标\r115w 5500k 灯泡  220v  2\r包  1\r100-150 5in1 反光板  1\r1转4 灯头   1\rlighting kit   $30\rYW864870642CN\r\r\r'),(5698,680876900002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','hifromrussia','darkvision@inbox.ru','Sergey Pavlov','37.  Marshala Tyhachevskogo st.<br>app. 98','Saint Petersburg','','RUSSIAN FEDERATION','195067','+7(812)6574842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:02:46',0,NULL,3,1,2,1,NULL,NULL),(5699,680893167002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:26',0,NULL,8,1,17,0,NULL,NULL),(5700,640828516001,110533631256,'77mm 3-Stage Rubber Lens Hood for D90 7D 5DII 550D',1,'AB1307',3.79,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:25',0,NULL,8,1,17,0,NULL,NULL),(5701,640828291001,110532007553,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:27',0,NULL,8,1,17,0,NULL,NULL),(5702,640827869001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 16:47:27',0,NULL,3,1,3,1,NULL,'大力夹云台  1\rc型大力夹  1\r橡胶遮光罩 77mm   1\r气吹 + 布    1\r RR843871386CN\r'),(5703,680896251002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','waltsidney','sid@ivivo.tv','sidney dulev','26 moshe sneh st.<br>0546655114','tel-aviv','ISRAEL','ISRAEL','69350','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 16:52:45',0,NULL,3,1,3,1,NULL,'\rRR843871823CN\r '),(5704,680911281002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','bert593','bert.h@rogers.com','Bert Hoferichter','137 Green Briar Road','Alliston','ON','CANADA','L9R1X9','(705) 435-6960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 17:28:37',0,NULL,3,1,2,1,NULL,'渐变灰   1 '),(5705,640845262001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','holcdt','clop98@hotmail.com','Martin Piche','54 Rte. Petite Manic','Saint-Rosaire','QC','CANADA','G0Z 1K0','(819) 758-9235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 17:28:56',0,NULL,3,1,3,1,NULL,' RR843871390CN\r'),(5706,640852060001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','giselenp','ginardino@gmail.com','Gisele N Pereira','R. Carlos Pioli 133','Curitiba','PR','BRAZIL','80520-170','(041)8855-6239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 17:52:43',0,NULL,3,1,2,1,NULL,NULL),(5707,745773459015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','badgerdid','dave@todayspics.co.uk','david didcote','103 alrewas road kings bromley','burton on trent','staffordshire','UNITED KINGDOM','de13 7hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 18:43:42',0,NULL,8,1,17,0,NULL,NULL),(5708,745773164015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.62,'hutongstore','badgerdid','dave@todayspics.co.uk','david didcote','103 alrewas road kings bromley','burton on trent','staffordshire','UNITED KINGDOM','de13 7hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 18:43:43',0,NULL,3,1,2,1,NULL,'方形滤镜接口环 67mm   1\r方形滤镜接口环 77mm  1\r方形滤镜 镜片卡座   1'),(5709,680917525002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gumanist','de_rulette@pisem.net','Alexey Podenko','str. Respubliki 90 / 283','Tyumen','Tymenskaya','RUSSIAN FEDERATION','625048','+79222670687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 18:58:51',0,NULL,3,1,3,1,NULL,' RR843871369CN\r'),(5710,640889370001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','anirathrix','anirathrix@hotmail.com','RATTHA BURANADILOK','48/27<br>Moo.5','Bangkruai District','Nontaburee','THAILAND','11130','(66)865293539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 19:18:52',0,NULL,3,1,3,1,NULL,' RR843871409CN\r'),(5711,745793012015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','acher1972','pjhtroop@hotmail.co.uk','Paul Troop','108 Langham Rd','Blackburn','Lancashire','UNITED KINGDOM','bb1 8dp','01254605400','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-02 19:21:59',0,NULL,3,1,4,1,NULL,'背景架 （ 白 黑） 1  2m的 \rYW864870631CN\r'),(5712,640902740001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','progrita','o_fr10@yahoo.fr','Volha Yurkevich','8 Mazurova street, app. 83','Gomel','','BELARUS','246006','+375296639995','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 19:29:46',0,NULL,3,1,3,1,NULL,' RR843871338CN\r'),(5713,640920359001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','e-world-2010','ematos2005@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 20:06:17',0,NULL,3,1,1,1,NULL,'橡胶遮光罩 52mm   10'),(5714,680990473002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6,'hermeshine','nebojsa977','radivoj.crni@gnb.ca','Radivoj Crni','457 Kings College Rd','Fredericton','NB','CANADA','E3B2G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:18:19',0,NULL,3,1,2,1,NULL,NULL),(5715,680997758002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 20:22:35',0,NULL,3,1,4,1,NULL,'欧标 YW864870605CN\r'),(5716,680985791002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','kimikocraft','sophie_pelletier_284@hotmail.com','sophie pelletier','492 rue bernard','dundee','NB','CANADA','E8E1W1','(506) 826-1802','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:23:22',0,NULL,3,1,3,1,NULL,' RR843871341CN\r之前发错了     从新给发一票\rRR843872316CN\r'),(5717,681013405002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','bagawiya','bagawiyadesigns@gmail.com','Michele-Anne Hamilton','20 Charlton Rd<br>Townhouse # 2','Kingston 8','St Andrew','JAMAICA','West Indies','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:53:07',0,NULL,3,1,2,1,NULL,' '),(5718,681014188002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','beagle5858','morales@zahav.net.il','Svetlana Zohar','Hatarshish 6','Maale Adumim','israel','ISRAEL','98451','+972523818998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 20:54:27',0,NULL,3,1,2,1,NULL,NULL),(5719,640953526001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',4,'AE3103',39.2,'hermeshine','meir_1','meirberko@gmail.com','meir berkovich','3/5 carmel st\'<br>Ahozot hanasi','Rehovot','','ISRAEL','76305','972-54-2399652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 21:11:34',0,NULL,3,1,3,1,NULL,' RR843871355CN\r'),(5720,681023286002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','s.j.r.j','the_ravent_el_angel_maldito@hotmail.com','salvador j. rueda jaime','c antonio postigo jimenez nº 5','mijas ( pueblo )','Andalucía Ceuta y Melilla','SPAIN','29650','659548819','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 21:15:05',0,NULL,3,1,4,1,NULL,' YW864870675CN\r'),(5721,745877635015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','usernameraymond*','xgadsby@hotmail.co.uk','K Gadsby','61 Burton Street','Melton Mowbray','Leicestershire','UNITED KINGDOM','LE131AF','07973506463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-02 21:22:29',0,NULL,3,1,2,1,NULL,NULL),(5722,640208958001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','konik232','exploit232@yandex.ru','Alexander Konik','B.Sadovaya, 139/150 - 16','Saratov','','RUSSIAN FEDERATION','410054','79272771871','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 21:32:20',0,NULL,3,1,5,1,NULL,' CP226630790CN\r'),(5723,640980425001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','murp81011','murp8101@bears.unco.edu','Ryan Murphy','2730 W Wesley Ave<br>Apt 5','Denver','CO','UNITED STATES','80219-5900','(719) 661-7360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-02 22:15:01',0,NULL,3,1,1,1,NULL,' '),(5724,681057037002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','jay.chan','hopextreme@hotmail.com','Jay Chan','Blk 157 Jalan Teck Whye #16-119<br>Singapore 680157','default','','SINGAPORE','680157','65 93665229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 22:27:39',0,NULL,3,1,11,1,NULL,NULL),(5725,681069378002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB1408',6.99,'hermeshine','bjohund','bjhund@online.no','Bjørnar Hundseth','Bjørnstjerne Bjørnsons veg 63','Molde','','NORWAY','6412','(+47) 45865854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-02 23:06:45',0,NULL,3,1,2,1,NULL,NULL),(5726,745617309015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','moizora','moizora@hotmail.com','domingo santana santana','ceramista alicia martin fernandez 4','las palmas de gran canaria','Canarias','SPAIN','35018','655 777397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-02 23:18:59',0,NULL,3,1,2,1,NULL,' '),(5727,641004950001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moudat','daoust.m@sympatico.ca','Manon Daoust','109, Place Fontainebleau','Saint-Lambert','QC','CANADA','J4S 1X6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-02 23:29:14',0,NULL,3,1,3,1,NULL,'RR843871315CN\r '),(5728,641027934001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.6,'hermeshine','lucascdrosa','lucascrosa@gmail.com','Lucas Rosa','Rua Dr. Carlos Norberto, 15','Socorro','São Paulo','BRAZIL','13960-000','019 3895-6759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 01:00:45',0,NULL,3,1,2,1,NULL,NULL),(5729,641039410001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','ioques','mar.ioques@gmail.com','Mário Marques','Pça Portela nº17, 11º (Atelier) Esq Laranjeiro','ALMADA','ALMADA','PORTUGAL','2810 - 270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 01:46:40',0,NULL,3,1,3,1,NULL,' 第一次发丢了，再发一次挂号小包\r刘\rRA117728586CN\r'),(5730,641051023001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','cinthiamake','cinthiadesign@hotmail.com','cinthia ferreira','rua atibaia 500 apto 44 - valparaiso','santo andré','sao paulo','BRAZIL','09060110','551144269253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 02:34:33',0,NULL,3,1,2,1,NULL,NULL),(5731,641053712001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',91.58,'hermeshine','zero-2010','zero868@gmail.com','mohammed  mazeed','al waha-Sector2-Street8-house22<br>tel:55870555 P.O.BOX.3105 CODE NO.01003','al Jahra','Kuwait','KUWAIT','01003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 03:21:55',0,NULL,3,1,3,1,NULL,'柔光伞   1\r45w 220v   2\r40cm 棚   1\r50-70 单灯头棚   1\r单灯头   1\r\rRR843871899CN\r\r '),(5732,681143888002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',4,'AA2106',140,'hermeshine','dgtesurf09','dgtesurf@yahoo.com.ph','Harry Jones Delos Santos','26 Katada St.','Dumaguete','negros oriental','PHILIPPINES','6200','0352252200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 03:37:17',0,NULL,8,1,17,0,NULL,''),(5733,681144588002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',3,'AA2106',105,'hermeshine','dgtesurf09','dgtesurf@yahoo.com.ph','Harry Jones Delos Santos','26 Katada St.','Dumaguete','negros oriental','PHILIPPINES','6200','0352252200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 03:40:15',0,NULL,3,1,6,1,NULL,'摄影背心 canon M 老款  4 \r摄影背心 canon xl 老款  3  \r4.468\rEE389037458CN\r'),(5734,641073256001,110519774429,'Pro FANCIER WF-531T Tripod with 593H 6662a Upgraded NEW',1,'AE1101',79,'hermeshine','lpg2004_123','lpg2004@msn.com','Leonardo Peñate Giacometto','Calle 127B#14A-12 Apto 402','Bogota','Cundinamarca','COLOMBIA','00000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 04:09:47',0,NULL,7,0,18,0,NULL,NULL),(5735,681153636002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ceewuu20','ceewuu@gmail.com','ceee wuuu','1414 25th ave','san francisco','CA','UNITED STATES','94122-3318','(415) 200-7720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 04:21:45',0,NULL,3,1,1,1,NULL,NULL),(5736,641077588001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',35.8,'hermeshine','superman_celica','jerry_clc@yahoo.com','Big Dog Style','2730 Skyview Ridge Ct','houston','TX','UNITED STATES','77047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 04:31:47',0,NULL,3,1,3,1,NULL,' RR843871576CN\r'),(5737,681160105002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','catokusanagi','trainer_cato@hotmail.com','Juan Antonio Alvarez S.','Av De los Reyes #44<br>Seccion Parques','Cuautitlan Izcalli','Estado de Mexico','MEXICO','54720','5538039347','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 04:57:10',0,NULL,3,1,3,1,NULL,' RR843871324CN\r'),(5738,681166035002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bakar72','alexander.bakiev@gmail.com','Aleksandr Bakiev','kv 3, dom 5, Truda sq.','Volzhsky','Volgograd region','RUSSIAN FEDERATION','404121','79616666001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 05:27:24',0,NULL,3,1,2,1,NULL,NULL),(5739,681172276002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','kassrakalantari','kassrak@gmail.com','kassra kalantari','1613 salal crescent','Coquitlam','BC','CANADA','v3e2y3','(778) 285-9291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 06:08:35',0,NULL,3,1,3,1,NULL,''),(5740,681173581002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','caposaure','capcav@neuf.fr','Gilles Bangratz','8 rue du moulin','HILSENHEIM','Alsace','FRANCE','67600','0388859493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 06:16:02',0,NULL,3,1,3,1,NULL,'\rRR843871956CN\r'),(5741,681182764002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nurken2008','nurken@ya.ru','Nurken Kshibayev','Lenina str., 24-5','Karaganda','','KAZAKHSTAN','100000','+7-7212-569180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:16:40',0,NULL,3,1,2,1,NULL,NULL),(5742,681185714002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','peredaarias','alberto_p40@hotmail.com','Alberto Pereda Arias','Paseo de la Democracia 6','Arganda del Rey','Madrid','SPAIN','28500','627370139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:31:58',0,NULL,3,1,4,1,NULL,' YW864870616CN\r'),(5743,681188905002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',5,'AA1205',12.95,'hermeshine','jaroslawkurek','jaroslaw.kurek@poczta.neostrada.pl','Jarosław Kurek','Kalinowa 1<br>skr.poczt. 84','Nadarzyn','mazowieckie','POLAND','05-830','22 7398568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 07:49:53',0,NULL,3,1,3,1,NULL,' RR843871580CN\r'),(5744,681199986002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','palagorn2006','plgorn@hotmail.com','Palagorn Raybumrung','888/104 Panuch Village<br>Pracharajbumpen Road,Samseannok,','Huaikhang','Bangkok','THAILAND','10320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 08:48:49',0,NULL,3,1,3,1,NULL,' \rRR843871766CN\r'),(5745,641120164001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','sprinred','alxbruce@yahoo.com','Alex Bruce','7823 Garfield Drive','Delta','BC','CANADA','V4C4C9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 08:49:15',0,NULL,3,1,5,1,NULL,' CP226630812CN\r'),(5746,641124348001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 09:10:14',0,NULL,3,1,8,1,NULL,'\rCP226630772CN\r'),(5747,681206949002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','mackey2340','rizekookir@hotmail.com','david mackey','3045 Shauna Dr','highland','CA','UNITED STATES','92346-1738','(909) 864-0974','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-03 09:46:08',0,NULL,3,1,1,1,NULL,'LK028586475CN '),(5748,746098358015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.39,'hutongstore','kobiastangelov','astangelov@gmail.com','kobi astangelov','yekutiel adam 28','or yehuda','israel','ISRAEL','60352','(792) 547127770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-03 09:46:57',0,NULL,3,1,2,1,NULL,NULL),(5790,641492784001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','sonex-mike','kurilenkom@gmail.com','Mihail Kurilenko','Kirova 72/14','Pyatigorsk','RU','RUSSIAN FEDERATION','357500','+78793390387','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 04:37:42',0,NULL,3,1,2,1,NULL,NULL),(5749,641141580001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','maespbandrey','mae_spb@mail.ru','ANDREY MIKHAYLOV','Savushkina<br>133-1-44','Saint-Petersburg','Leningradskaya oblast','RUSSIAN FEDERATION','197374','+79117588434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 10:40:55',0,NULL,3,1,2,1,NULL,NULL),(5750,641149782001,110523102266,'67mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1307',2.6,'hermeshine','corzab72','corzab@dodo.com.au','Corie Blackley','30 Victoria St','Korumburra','Victoria','AUSTRALIA','3950','0403051761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 11:05:42',0,NULL,3,1,2,1,NULL,NULL),(5751,681231890002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 11:16:16',0,NULL,3,1,2,1,NULL,NULL),(5752,641154194001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','the-collezioni','luarecollezioni@gmail.com','Luare Collezioni','PO BOX 400652','Hesperia','CA','UNITED STATES','92340','','NoPaymentFailure','CheckoutIncomplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,NULL),(5753,681245864002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','xarmene','mnrtzs@yahoo.gr','Charalampos Meneretzis','pindou 36','PARALIA DISTOMOU','GU','GREECE','32003','2267042737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 12:15:42',0,NULL,3,1,2,1,NULL,NULL),(5754,641166249001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jweg01','j.gilbert@unb.ca','John Gilbert','2 Conc. 6','Chepstow','ON','CANADA','N0G 1K0','(519) 901-2190','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(5756,681274083002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','kennyken72385','jacky_mong@yahoo.com','Kenneth King','150A Freelon St','San Francisco','CA','UNITED STATES','94107-1625','(415) 240-9531','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-03 14:40:49',0,NULL,3,1,1,1,NULL,NULL),(5757,681288310002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','glenardh301','glenardh@yahoo.com','glenard hall','323 Madison St','frederick','MD','UNITED STATES','21701-6317','(301) 663-3668','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 14:44:05',0,NULL,3,1,1,1,NULL,NULL),(5758,746186852015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pilesofstones','jmwf@me.com','John Fowles','40 Styebank Lane Rothwell','Leeds','West Yorkshire','UNITED KINGDOM','LS26 0HW','07801286332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 14:23:56',0,NULL,3,0,18,1,NULL,NULL),(5759,681304843002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','niruddikasuraj','niruddik@ovi.com','Suraj silva','1224, Rajamalwatha Road,<br>Batharamulla, Sri Lanka','Colombo','','SRI LANKA','10120','0094772394757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 15:36:50',0,NULL,3,1,2,1,NULL,NULL),(5760,681319960002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','samguedes','samuelg.fotografia@gmail.com','Samuel Guedes','Avenida Campinas<br>Chácara do Visconde','Taubaté','São Paulo','BRAZIL','12050-760','+5512 8866-5222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 16:27:29',0,NULL,3,1,3,1,NULL,' RR843871837CN\r'),(5761,731327308016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','mfherbalist','maudfreemantle@hotmail.com','Oscar Freemantle','708 marketgate Bond St S','Bristol','Avon','UNITED KINGDOM','BS1 3PG','07875417713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 17:05:15',0,NULL,3,1,2,1,NULL,NULL),(5762,681338559002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','meckpomm2002','meckpomm2005@web.de','Kurt Berndt','Fritz Peters   Str. 7','Altentreptow','','GERMANY','17087','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 17:09:46',0,NULL,3,1,2,1,NULL,NULL),(5763,681340058002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','alinakiter','alinenok85@inbox.ru','Roman Pichshev','ulica Askarova, dom1, kv.29','Shymkent','Yuzhno-Kazahstanskaya oblast','KAZAKHSTAN','160019','8 (7252) 40 81 02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 17:22:12',0,NULL,3,1,3,1,NULL,' RR843871721CN\r'),(5764,641259928001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','fotopomohnikartem','fotopomohnik@mail.ru','Artem Zabolotskikh','Kluchevoy poselok 41-57','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 17:21:25',0,NULL,3,1,3,1,NULL,' RR843871718CN\r'),(5765,681362445002,120500391259,'Neoprene Protector Camera Cover Case for Canon Nikon L',5,'AC1302',46.25,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Lima 1261<br>Sistemas San Juan','Buenos Aires','CABA','ARGENTINA','1138','5411 43701153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 18:06:37',0,NULL,3,1,3,1,NULL,'RR843871735CN\r '),(5766,745233296015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','bayser2008','contact.infopages@googlemail.com','Nick Pace','24 delaware drive','St leonards on sea','East Sussex','UNITED KINGDOM','tn377tj','01424756840','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 18:59:34',0,NULL,3,1,2,1,NULL,NULL),(5767,731454120016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',4,'AA3312',14.32,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 19:09:02',0,NULL,8,1,17,0,NULL,' '),(5768,746326433015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163 Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 19:13:57',0,NULL,3,1,3,1,NULL,'绿叶 CPL  77mm  4 \r绿叶 CPL  67mm  4\rRR843872364CN\r'),(5770,641355909001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','jamepong','pong_canon@hotmail.com','Kasemsant Sungsumal','75/27 aisarapap Rd.<br>soi aisarapap39','Bangkok','Bangkoknoi bangkok','THAILAND','10700','0832328999','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 20:47:00',0,NULL,3,1,3,1,NULL,' RR843871854CN\r'),(5771,641357352001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:41',0,NULL,8,1,17,0,NULL,NULL),(5772,641356048001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,8,1,17,0,NULL,NULL),(5773,641356282001,110523102158,'62mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1306',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,8,1,17,0,NULL,NULL),(5774,641357098001,110523102341,'77mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1309',2.6,'hermeshine','u3b54','ajt@laudachoir.org','Adrian Taylor','Hordle Walhampton School<br>Walhampton','Lymington','Hampshire','UNITED KINGDOM','SO415ZG','07919883080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 20:50:42',0,NULL,3,1,3,1,NULL,'NIKON 镜头盖 52mm  2\rNIKON 镜头盖 62mm  1\rNIKON 镜头盖 77mm  1\rRR843871783CN\r'),(5775,681468816002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','glentaylormt','glentaylor_mt@hotmail.com','Glen Taylor','127 St.Jude<br>Trieq il Htajriet','Mosta','ME','MALTA','3062','21412542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-03 21:41:05',0,NULL,3,1,3,1,NULL,' RR843871845CN\r3月12号换单\rRA012916032CN \r太长了，没发出去，等客户问就说丢了退钱给他\r'),(5776,681477879002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','bbohnet716','bbohnet18@gmail.com','Brandon Bohnet','4423 109 A Avenue','Edmonton','AB','CANADA','T6A 1S3','(178) 071-6823 ext.: 5','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,5,1,NULL,'庄海峰 bbohnet716\rCP226334942CN'),(5777,681481963002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','prdanv','danielvojta@gmail.com','Daniel Vojta','657 Viewcrest Ter','Burlington','WI','UNITED STATES','53105-1641','(262) 763-3915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 22:13:29',0,NULL,3,1,1,1,NULL,' '),(5778,641396673001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','tool62johans','dennisjohansen@comcast.net','Dennis Johansen','1022 Oakridge Ln','Bountiful','UT','UNITED STATES','84010-2029','(801) 755-8360','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-03 22:22:32',0,NULL,3,1,1,1,NULL,NULL),(5779,641406965001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','lte5280','uqmhrd@yahoo.es','José Ramón Otero Yñiguez de la Torre','C De Las Pozas nº 173 P2 2ºA','San Lorenzo de El Escorial','Madrid','SPAIN','28200','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-03 22:52:04',0,NULL,3,0,3,1,NULL,'xxxl  尼康 老款  1 \rRR843871939CN\r'),(5780,746477583015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',2,'AA1314',4.4,'hutongstore','mikeand2244','mikeholoanderson@aol.com','Michael Anderson','4 Borrowdale Avenue','Harrow','Middlesex','UNITED KINGDOM','HA37PZ','02084279685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-03 23:58:26',0,NULL,3,1,2,1,NULL,NULL),(5781,641428855001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.5,'hermeshine','djuca60','casablancabar@clix.pt','julio silva','rua amorim rosa 44 3º esq','tomar','','PORTUGAL','2300-450','+351919913040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 00:12:08',0,NULL,3,1,2,1,NULL,' '),(5782,681546987002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','man_from_utopia_72','manfromutopia@hotmail.com','Ivan Blecker','37 Arjay Trail','Brampton','ON','CANADA','L6X 4M4','(905) 455-4486','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 01:47:21',0,NULL,3,1,3,1,NULL,' RR843871797CN\r'),(5783,681546860002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','lng22392','lng22392@aol.com','lauryn guerrieri','1200 Galapago St<br>Apt 712','denver','CO','UNITED STATES','80204-3572','(303) 518-8909','NoPaymentFailure','CheckoutComplete','Other','2011-03-04 01:54:19',0,NULL,3,1,3,1,NULL,' RR843871806CN\r'),(5784,641459294001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','trunaza','spokeword@yahoo.com','Andre Coleman','1793 Juniper Lake Rd','DeFuniak Springs','FL','UNITED STATES','32433-5203','(850) 951-0856','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-04 02:12:46',0,NULL,3,1,1,1,NULL,' 575'),(5785,681214948002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',5.99,'hermeshine','moojack123','jackmut114@gmail.com','Nuttaphon Rujinark','41/17 Royal Park Buliding, Room 308, Phaholyothin 8 rd.<br>Samsen Nai, Phayathai','Bangkok','','THAILAND','10400','(+66) 819372816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 02:20:03',0,NULL,3,1,2,1,NULL,NULL),(5786,681562729002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jbooblian','julesrb@paradise.net.nz','Julian Butler','176 Clyde Street<br>Island Bay','Wellington','','NEW ZEALAND','6023','6449721599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 02:44:28',0,NULL,3,1,2,1,NULL,NULL),(5787,641473455001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','kerryn09','kerrynobrien@oracletelecom.net.au','Kerryn O\'Brien','19 Gladstone Street','Paddington','Queensland','AUSTRALIA','4064','0412706067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 03:13:57',0,NULL,8,0,17,0,NULL,NULL),(5788,641190358001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',12.49,'hermeshine','kerryn09','kerrynobrien@oracletelecom.net.au','Kerryn O\'Brien','19 Gladstone Street','Paddington','Queensland','AUSTRALIA','4064','0412706067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 03:13:58',0,NULL,3,0,3,1,NULL,'1.6x2.1m 背景布 3   黑 白 灰  \r麂皮   1\rRR843871942CN\r'),(5789,746541562015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','foxbat404','aj404my@yahoo.com','AHMAD JAMALUDIN','750,JALAN NESAN 4','KUALA TERENGGANU','TERENGGANU','MALAYSIA','20000','609-6226763','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 03:17:32',0,NULL,3,1,2,1,NULL,NULL),(5791,681591676002,120340837696,'New Genuine Nikon 90th Anniversary Camera Neck Strap',4,'AB1402',55.6,'hermeshine','yocom_bro','yoko.aditya@yahoo.com','yoko aditya','boulevard artha gading blok A6B no.30/31<br>kelapa gading','jakarta','jakarta utara','INDONESIA','14240','+6221 93377334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 04:50:57',0,NULL,3,1,3,1,NULL,' RR843871810CN\r'),(5792,641515373001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','placdarms','filips@vilande.com','Filips Baumanis','Paplakas iela 24','Priekule','Priekules novads','LATVIA','lv-3434','+371 26368537','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 06:59:22',0,NULL,3,1,2,1,NULL,NULL),(5793,641518816001,110566018762,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','yocom_bro','yoko.aditya@yahoo.com','yoko aditya','boulevard artha gading blok A6B no.30/31<br>kelapa gading','jakarta','jakarta utara','INDONESIA','14240','+6221 93377334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 07:24:30',0,NULL,5,1,18,0,NULL,NULL),(5794,681630343002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','mrpiewee','mrpiewee@hotmail.com','Piewee Mulder','Hemelstraat 26','Sint Jansteen','','NETHERLANDS','4564 BB','0114322870','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 08:39:58',0,NULL,3,1,3,1,NULL,' RR843872041CN\r'),(5795,641537325001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','vadkozvin','vadkoz@mail.ru','vadim kozlovsky','po box 8152<br>artynow st 559','Vinnitsya','Vinnitsya reg','UKRAINE','21050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 09:04:16',0,NULL,3,1,3,1,NULL,'\rRR843872276CN\r'),(5797,641548200001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','markes1987','victormarques_@hotmail.com','Victor Marques Fernandez','c/ eloy reigada nº33   1º','Bembibre','Castilla y León','SPAIN','24300','690656923','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 09:54:08',0,NULL,3,1,4,1,NULL,' YW864870804CN\r'),(5798,641342352001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kilichenko','ukrban@ua.fm','Yuriy Kilichenko','Filatova street,  52,  flat 39','Odessa','','UKRAINE','65074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 10:08:26',0,NULL,3,1,2,1,NULL,NULL),(5799,681658473002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 10:46:10',0,NULL,8,1,17,0,NULL,NULL),(5800,681659675002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','falconetti10','falcondiets@yahoo.co.uk','Pedro Falcon Marrero','Calle del cedro, 12<br>La Jaca','Arico','Santa Cruz de Tenerife','SPAIN','38588','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 10:51:42',0,NULL,3,1,2,1,NULL,NULL),(5801,641569173001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rocter1963','razvodovskij@gmail.com','Nadezda Razvodovska','Cialkovska 14-41','Daugavpils','','LATVIA','LV-5410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 11:25:50',0,NULL,3,1,2,1,NULL,NULL),(5802,681670275002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 11:38:11',0,NULL,8,1,17,0,NULL,NULL),(5803,641570896001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 11:38:11',0,NULL,3,1,3,1,NULL,'52,55,58,62,67,72,77mm 接口环    一套\r普通托架   1\r广角托架   1 \rRR843872395CN'),(5804,681656241002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','romanfilatov','lubsay@ya.ru','roman filatov','ул.Горького д.27 кв.11','Волжский','Волгоградская область','RUSSIAN FEDERATION','404122','+7 903 315 36 05','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 11:45:05',0,NULL,3,1,3,1,NULL,' RR843872320CN\r'),(5805,681680484002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','abclolo','lolotaula@hispavista.com','manuel mesa bermudez','ventura rodriguez 7, 6º 3º','barcelona','Cataluña','SPAIN','08035','934280738','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 12:16:34',0,NULL,3,1,4,1,NULL,'lighting kit  $20 \rYW864870793CN\r'),(5806,641612403001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3305',36,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 14:07:09',0,NULL,3,1,3,1,NULL,' RR843872347CN\r'),(5807,731841945016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','zalaegerszegi','musikband@mail.ru','Vladislav Zarudniy','48 Marksa Str., App. 45 48 Marksa Str., App. 45','Obninsk','Kaluga Region','RUSSIAN FEDERATION','249039','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 14:31:38',0,NULL,3,1,2,1,NULL,' '),(5808,641624146001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','ketu2','infoketu@gmail.com','Manuel López Guerra','Av. Irlanda<br>13B, 2ºB','Toledo','Castilla-La Mancha','SPAIN','45005','630507741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 14:44:26',0,NULL,3,1,2,1,NULL,' '),(5809,681755432002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','roniofek','roniofek22@gmail.com','ron ofek','post box: 300','rinatia','israel','ISRAEL','73165','972-54-6520766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 16:17:34',0,NULL,3,1,2,1,NULL,NULL),(5810,641653128001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','tomoco318','jesusinarejos1@hotmail.com','Jesus Inarejos Carcelen','Avda. Manuel de Falla Nº 7D Pta 14<br>Valencia','Valencia','Valencia','SPAIN','46015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 16:19:33',0,NULL,3,1,3,1,NULL,'RR843873002CN\r\r'),(5811,641679827001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','safrikacz','kacka.tobi@gmail.com','Amifox Reality, Katerina Tobolova','Ruska 87/11','Ostrava','Czech Republic','CZECH REPUBLIC','703 00','774 279 730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 17:20:59',0,NULL,3,1,2,1,NULL,NULL),(5812,641684220001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','vladislav630','zyryanov@agni.phys.iit.edu','Vladislav Zyryanov','7951 Stewart Dr','Darien','IL','UNITED STATES','60561-5934','(630) 985-1306','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 17:32:53',0,NULL,3,1,1,1,NULL,NULL),(5813,681784786002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','risaku','el_dani206@hotmail.com','DANIEL MARTI MARTINEZ','C/ sant antoni, 28','sant cugat sesgarrigues','Cataluña','SPAIN','08798','606242442','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 17:33:06',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870782CN\r'),(5814,731947952016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','gray_cozmec','cozmec@gmail.com','Giannis Gkantos','Hatzimallousi 27','Naousa','Imathia','GREECE','59200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 18:24:05',0,NULL,3,1,3,1,NULL,' RR843872262CN\r'),(5815,641707116001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','klong09','avalino@yahoo.com','Al Valino','112 Pinery Trail','Scarborough','ON','CANADA','M1B 6C1','(647) 567-2200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 18:25:45',0,NULL,8,1,17,0,NULL,NULL),(5816,731958635016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','battlesurf','plata.mejor@gmail.com','Andrea Battaglia','San Lorenzo n 77','Pisa','PI','ITALY','56127','3931843375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-04 18:57:42',0,NULL,3,1,4,1,NULL,' YW864870771CN\r'),(5817,641708058001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','klong09','avalino@yahoo.com','Al Valino','112 Pinery Trail','Scarborough','ON','CANADA','M1B 6C1','(647) 567-2200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 18:27:41',0,NULL,3,1,3,1,NULL,'RR843872965CN '),(5818,641739512001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','jakub.pavlinec','pavlinec@centrum.cz','Jakub Pavlinec','Rantirovska 28','Jihlava','','CZECH REPUBLIC','58605','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 19:33:49',0,NULL,3,1,2,1,NULL,NULL),(5819,681832522002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jfue6178','josemanviolin@hotmail.com','José Manuel Fuentes Martín','San Marcos 17 Bajo 3','Segovia','Castilla y León','SPAIN','40003','645063836','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 19:19:29',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870760CN\r'),(5820,681851128002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.98,'hermeshine','todos1alexweb','sashaburtsev@gmail.com','Alexander Burtsev','Ul.Gagarina, 14/6','Novozybkov','Bryanskaya obl','RUSSIAN FEDERATION','243020','+7 952 964 68 19','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:00:27',0,NULL,3,1,2,1,NULL,NULL),(5821,641754551001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cjaaronxx92','cjaaron16@yahoo.com','calvin a. mosley jr.','15571 Bow String St','victorville','CA','UNITED STATES','92394-6716','(760) 912-0877','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 20:06:52',0,NULL,3,1,1,1,NULL,NULL),(5822,681863693002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:26:18',0,NULL,8,1,17,0,NULL,NULL),(5823,641771088001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:45:16',0,NULL,8,1,17,0,NULL,NULL),(5824,681874030002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','wildvovan','wildfoxbr@yandex.ru','Vladimir Tshebrov','Aviacionnay 8-45','Bryansk','Russia','RUSSIAN FEDERATION','241037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-04 20:50:44',0,NULL,3,1,3,1,NULL,' RR843872245CN\r'),(5825,681860645002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 20:21:27',0,NULL,8,1,17,0,NULL,' '),(5826,641777984001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','jleo123','jleo@comcast.net','John Leonard','21 Overbrook Pkwy','Wynnewood','PA','UNITED STATES','19096','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-04 20:59:00',0,NULL,3,1,1,1,NULL,NULL),(5827,732058611016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','gillandjoeb','joebarnett41@gmail.com','JOE BARNETT','1 THE OLD RECTORY FLATS BOUGHTON ALUPH','ASHFORD','Kent','UNITED KINGDOM','TN25 4HS','01233638988','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-04 21:41:46',0,NULL,3,1,2,1,NULL,NULL),(5828,681895414002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','goldberg99','valtec99@gmail.com','Maxim Melnikov','Liteyniy pr. 11 kv. 27','Saint-Petersburg','','RUSSIAN FEDERATION','191187','0079219658671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 21:51:52',0,NULL,3,1,2,1,NULL,NULL),(5829,641804931001,110445658116,'New YONGNUO  LCD Timer Remote Control  for Nikon MC-DC1',1,'AA3219',48.9,'hermeshine','sexy6670','gangster3866@mail.ru','Poul Savelyev','Arhangelskaya str.<br>11a-301','Vologda','Vologodskaya obl','RUSSIAN FEDERATION','160032','+79218294798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:06:40',0,NULL,3,1,3,1,NULL,'RR843872982CN '),(5830,681912924002,120644812661,'New Camera shoulder bag a1 for Nikon D80 D90 D3000',1,'AO0030',27.9,'hermeshine','dimadnk','dnk_dimon@te.net.ua','Dima Kupinets','50/2, Shishkina Str., app. 49','Odessa','','UKRAINE','65088','8-067-4890676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:24:15',0,NULL,3,1,3,1,NULL,' RR843872293CN\r'),(5831,681919905002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 22:43:29',0,NULL,3,1,2,1,NULL,NULL),(5832,746984011015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.68,'hutongstore','cheesygrins49','sue@cheesygrins.co.uk','Sue Butcher','49 Firglen drive','Yateley','Hampshire','UNITED KINGDOM','GU46 7TR','01252653323','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-04 23:03:02',0,NULL,3,1,2,1,NULL,NULL),(5833,681938061002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',17.99,'hermeshine','ophermaoz10','ophermaoz@gmail.com','Opher Maoz','Hanevi\'im 11 aprtment 3','Tel Aviv','Israel','ISRAEL','64356','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-04 23:41:31',0,NULL,3,1,3,1,NULL,' RR843872302CN\r'),(5834,681907430002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','latigresa81','guidrycl@hotmail.com','Christie L. Guidry Stryk','10972 Solitude Cir','Anchorage','AK','UNITED STATES','99515','(713) 562-6377','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-04 23:47:04',0,NULL,3,1,1,1,NULL,NULL),(5835,681952364002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','siorcpablo','inspbs00@ucv.udc.es','Pablo Blanco Sampedro','Avda. Castrelos 228 - 5ºD (Atico D)<br>Atico D - 5ºD','Vigo','Pontevedra','SPAIN','36210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 00:35:26',0,NULL,3,1,4,1,NULL,' YW864870756CN\r'),(5836,681947302002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','ml777ml777','mariusl1@bezeqint.net','marius leizer','igael yadin 49/28<br>Tel 972[0]577637799','mod\'in','Israel','ISRAEL','71720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 00:44:37',0,NULL,3,1,2,1,NULL,NULL),(5837,732133170016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','jorabr','jorgen@ribbingsfors.se','Jörgen Abrahamsson','Fyrvaktarkroken 42, 1tr','Stockholm','Enskededalen','SWEDEN','SE-121 32','070-3312321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 01:07:56',0,NULL,8,1,17,0,NULL,NULL),(5838,747025286015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','jorabr','jorgen@ribbingsfors.se','Jörgen Abrahamsson','Fyrvaktarkroken 42, 1tr','Stockholm','Enskededalen','SWEDEN','SE-121 32','070-3312321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 01:09:17',0,NULL,3,1,2,1,NULL,'方形滤镜接口环 55mm  1\r方形滤镜接口环 52mm   1'),(5839,641859701001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','adro3429','alland@pacific.net','Allan Droyan','445 N Harold St','Fort Bragg','CA','UNITED STATES','95437-3305','(707) 964-2130','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 01:22:14',0,NULL,3,1,1,1,NULL,NULL),(5840,681969087002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','oresmaux56','jean-charles-caullery@hotmail.fr','Jean-Charles Caullery','Le vieux Beffroi<br>6, rue du chapeau de violettes','AMIENS','Picardie','FRANCE','80000','06.06.85.84.30','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 01:41:36',0,NULL,3,1,3,1,NULL,' RR843872214CN\r'),(5841,681981487002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bernardogaetani','manager@gamerz.com.br','Bernardo Gaetani','Rua da Bahia<br>Número 2577 APTO 102 - Lourdes','Belo Horizonte','Minas Gerais','BRAZIL','30160-012','5503132212892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 02:44:26',0,NULL,3,1,2,1,NULL,NULL),(5842,641911462001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 05:50:37',0,NULL,3,0,3,1,NULL,'nikon 老款背心 xl   1\rRR843872228CN\r\r'),(5843,641915731001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','ahinojos','anniebhinojos@yahoo.com','Peter Hinojos','15346 Lookout Rd','Apple Valley','CA','UNITED STATES','92307-2175','(760) 946-5577','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 06:21:00',0,NULL,3,0,1,1,NULL,'nikon 老款背心 L 1 \r'),(5844,641751746001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',51.1,'hermeshine','ayukov','asv@ayukov.com','Sergey Ayukov','ul. Krzhizhanovskogo, d.5, korp.1, kv.54','Moscow','','RUSSIAN FEDERATION','117292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 06:32:43',0,NULL,3,0,3,1,NULL,'反光伞  1\r 77mm 镜头盖  nikon   1\r72mm 镜头盖  nikon   1\r115w 220v    1\r77mm nd8    1\r单灯头  欧标   1\r\r77ND8 发了天涯的\rRR843872979CN\r\r\r'),(5845,641919909001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','fbphuket','frank@krabibiz.com','Frank Baganz','314/13 Moo 2<br>T. Ao Nang A. Muang','Krabi','Krabi','THAILAND','81000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 06:46:48',0,NULL,8,1,17,0,NULL,NULL),(5846,682030132002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',86.9,'hermeshine','fbphuket','frank@krabibiz.com','Frank Baganz','314/13 Moo 2<br>T. Ao Nang A. Muang','Krabi','Krabi','THAILAND','81000','','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-03-05 06:48:34',0,NULL,3,0,6,1,NULL,'2mx3m 背景架  1\r3mx6m 白色背景布   1 \rEMS 外地\rEE389037475CN\r'),(5847,641923384001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','helias007','heliasfotografo@hotmail.com','Elias Huaman Corterreal','Jr Hermenegildo Rojas 125<br>distrito Carabayllo','Lima','Lima','PERU','51','5440277','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 07:09:23',0,NULL,3,1,3,1,NULL,' RR843872188CN\r'),(5848,682036465002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 07:27:08',0,NULL,3,1,2,1,NULL,'欧标 '),(5849,641936684001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','peroni_es','correu.por@gmail.com','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 08:20:27',0,NULL,3,1,2,1,NULL,'欧标 '),(5850,682047193002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','excentric_projects','gmdkjpc@gmail.com','Daniel Johnston','4085 Canary Palm Circle','Plant City','FL','UNITED STATES','33566','(813) 494-1551','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-05 08:24:25',0,NULL,3,1,1,1,NULL,NULL),(5851,641943416001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 08:49:40',0,NULL,8,1,17,0,NULL,' '),(5852,641951150001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','antiskeptic','gnikelyk@gmail.com','Kyle King','320 W Polk St<br>Apt 2','Houston','TX','UNITED STATES','77019-4462','','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 09:22:49',0,NULL,3,1,1,1,NULL,'注意是nikon 原厂的那款 '),(5853,641958050001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 09:50:44',0,NULL,3,1,5,1,NULL,' CP226630707CN\r'),(5854,681615074002,120601699362,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','bandarar','srilankanwilds@gmail.com','T Bandara Ranathunge','246, Yatihalagala, Kandy<br>Sri Lanka','Kandy','Central','SRI LANKA','2000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 09:50:54',0,NULL,3,1,3,1,NULL,' RR843872205CN\r'),(5855,641963338001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 10:09:42',0,NULL,3,1,4,1,NULL,'72mm 镜头盖 nikon  1\r2m 灯架  1\r反光板支架   1\r80cm 5in1 反光板   1\r双灯头  欧标    1 \rlighting kit  $20\rYW864870745CN\r'),(5856,682089581002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rdr5377','renaud.derosa@club-internet.fr','Renaud de Rosa','47 rue Cantagrel<br>App. 23','Paris','Ile-de-France','FRANCE','75013','0145837761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 11:13:41',0,NULL,3,1,2,1,NULL,NULL),(5857,732326946016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','ltgeordy','type_r@email.si','Dean Sopic','Na izvir 3','Pobegi','Koper','SLOVENIA','6276','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-05 13:13:20',0,NULL,3,1,3,1,NULL,'看看是否2kg以下 \rRR843872112CN\r'),(5858,682134202002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','dkarakou_86','dkarakou@hotmail.com','Dimos Karakousis','S.Oikonomou 6','Alexandroupoli','','GREECE','68100','+306942611591','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 13:43:47',0,NULL,8,1,17,0,NULL,NULL),(5859,642026990001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dkarakou_86','dkarakou@hotmail.com','Dimos Karakousis','S.Oikonomou 6','Alexandroupoli','','GREECE','68100','+306942611591','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 13:45:04',0,NULL,3,0,5,1,NULL,'背景架  （ 白  黑）   1\r2m 宽的 \rCP226630715CN\r'),(5860,682136098002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','samduran','samduran@yahoo.com','Samuel Duran','9925 NW 116th Way','Medley','FL','UNITED STATES','33178','(786) 282-6204','NoPaymentFailure','CheckoutComplete','Other','2011-03-05 13:49:46',0,NULL,3,1,3,1,NULL,' RR843872126CN\r'),(5861,642057220001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',2,'AE2401',67,'hermeshine','4580190101801800','itzik_sbg@walla.com','itzik sabag','ir ganim<br>hasaifan 2 24','Jerusalem','ir ganim hasaifan 2-24','ISRAEL','0504447673','0504447673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 15:10:14',0,NULL,3,1,3,1,NULL,'欧标 RR843872231CN\r'),(5862,642085239001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','tornis','vadim57@apollo.lv','Vadims Mozeiko','sia VECPILS<br>Pernavas 39-1a','RIGA','','LATVIA','LV1009','371 29541619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 16:15:19',0,NULL,3,1,2,1,NULL,NULL),(5863,642092382001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','eolajos','olajose@vnet.hu','Edit Olajos','8 Vass Str','Hodmezovasarhely','-','HUNGARY','6800','+36304722363','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 16:35:20',0,NULL,3,1,12,1,'2737911750\r','欧标 \rCP226630724CN\r上次的丢了，这次发DHL给他\r'),(5864,747344161015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','causeanddeffect','harris.ssaa@tiscali.co.uk','Stephen Harris','2, Birney Edge, Darras Hall,','Ponteland,','Northumberland,','UNITED KINGDOM','NE20 9jj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-05 17:16:18',0,NULL,3,1,2,1,NULL,NULL),(5865,682244903002,120568891628,'Male-Male 52mm-58mm Macro Combined shipping discounts',1,'AA1212',3.8,'hermeshine','victormff','vmmfdpjc@yahoo.com','Victor Fernandez','11804 Rockaway Beach Blvd<br>Apt 2','Rockaway Park','NY','UNITED STATES','11694-1916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 18:01:34',0,NULL,8,1,17,0,NULL,'\r\r'),(5866,642134019001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','victormff','vmmfdpjc@yahoo.com','Victor Fernandez','11804 Rockaway Beach Blvd<br>Apt 2','Rockaway Park','NY','UNITED STATES','11694-1916','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 18:01:35',0,NULL,3,1,2,1,NULL,'52mm 橡胶罩   1\r52-58 双阳环   1 \r新地址：\rVictor Fernandez\r7-A Rue du Moulin\rDrummondville, QC \rJ2B5N1\r(819) 479-3136\rCanada\r\r819-479-3136'),(5867,747386577015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','hana2491','hannah.teasdale@hotmail.co.uk','Hannah Teasdale','1 William Close Stubbington','Fareham','Hampshire','UNITED KINGDOM','PO14 2PQ','01329668862','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-05 18:23:38',0,NULL,3,1,2,1,NULL,NULL),(5868,642150909001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','davorbalavor','djanjatovic@yahoo.com','Davor Janjatovic','Trg Kralja Zvonimira 6','Koprivnica','Croatia','CROATIA','48000','38598304989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 18:29:20',0,NULL,3,1,2,1,NULL,NULL),(5869,682274934002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:45',0,NULL,8,1,17,0,NULL,NULL),(5870,682271098002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:46',0,NULL,8,1,17,0,NULL,NULL),(5871,642159812001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:46',0,NULL,8,1,17,0,NULL,NULL),(5872,682274431002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','mogensmoldaw','moldaw@mail.tele.dk','Mogens Rasmussen','Majsvej 48','Nyborg','dk','DENMARK','5800','65303846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 19:00:47',0,NULL,3,1,2,1,NULL,'CANON 镜头盖  58mm  1 \r橡胶遮光罩 58mm  1\r绿叶 UV  67mm  1\r机身盖/镜头后盖  Canon  1'),(5873,682289942002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','mountfako','photolancing@aol.com','Victor Ngaling','4221 Heritage Drive','Vadnais Heights','MN','UNITED STATES','55127','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 19:26:38',0,NULL,3,1,1,1,NULL,NULL),(5874,642230004001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','allioli','anagroid@hotmail.com','Adrián Navarro Grossón','C/ Maximiliano Thous Nº15, Pª4','Valencia','Comunidad Valenciana','SPAIN','46009','635694355','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-05 21:06:20',0,NULL,3,1,4,1,NULL,'tripod $15 \rYW864870734CN\r'),(5875,682344946002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-05 21:15:49',0,NULL,3,1,3,1,NULL,' RR843872259CN\r'),(5876,682378545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:23:54',0,NULL,8,1,17,0,NULL,' '),(5877,642282816001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:23:55',0,NULL,8,1,17,0,NULL,NULL),(5878,682402602002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','z950069','j.spaulding@comcast.net','Judith B. Spaulding','1836 Avenida Martina','Roseville','CA','UNITED STATES','95747','(916) 903-8884','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-05 23:44:46',0,NULL,3,1,1,1,NULL,'CANON 镜头盖  58mm  4\r lenspen    1\r橡胶遮光罩 58mm    1\r'),(5879,682421121002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','monwong2001','monwong@afs.org','Monwong Bhadharavit','369 Ladprao 101<br>Wangthonglang','Bangkok','BKK','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 00:46:07',0,NULL,3,1,3,1,NULL,'77mm +8 换成 +4的\r77mm ND8 换成 天涯的77mm ND8\rRR843872165CN\r'),(5880,642309762001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',3,'AE2501',91,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 00:59:04',0,NULL,8,1,17,0,NULL,'3个都要盒子，整个包在一起 \r看重量，如果小于2kg，就小包挂号'),(5881,682426785002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','miroslaw6402','tolo171@gmail.com','miroslaw krekora','969 logan ave','toronto','ON','CANADA','m4k 3e6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 01:06:44',0,NULL,3,1,2,1,NULL,' '),(5882,642317800001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','darkobulat','darkobul@gmail.com','Darko Bulatovic','4831 Reservoir Rd NW','Washington','DC','UNITED STATES','20007-1543','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 01:28:56',0,NULL,3,1,1,1,NULL,' '),(5883,747605135015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','jimbo_kent_uk','jimbo_kent@hotmail.com','Jim Buckley','98 Kingswood Road','Gillingham','Kent','UNITED KINGDOM','ME7 1DX','07884230057','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-06 01:34:16',0,NULL,3,1,3,1,NULL,' RR843872174CN\r'),(5884,682435920002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 01:42:51',0,NULL,3,1,5,1,NULL,'反光板支架  3 \rlenspen  10\r3个反光板支架和lenspen都要盒子，整个包在一起 \r看重量，已经超过2KG\rCP226630738CN\r'),(5885,682446527002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','lthurmon','lthurmon@gmail.com','Lauren Thurmon','202 Appleby Rd','Port Wentworth','GA','UNITED STATES','31407-1108','(912) 966-1584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 02:27:08',0,NULL,3,1,1,1,NULL,NULL),(5886,682461005002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','iselocj','erjalandoon@yahoo.ca','Erlinda Jalandoon','3600 Kilby Court','Richmond','BC','CANADA','V6X 3M9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 03:19:55',0,NULL,3,1,2,1,NULL,NULL),(5887,682482458002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','bconnors7773','wconnors5@comcast.net','William Connors','312 W Ethel Ave','Lombard','IL','UNITED STATES','60148','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 04:52:55',0,NULL,3,1,1,1,NULL,NULL),(5888,682026454002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',18.5,'hermeshine','zbali68','kesuma13@gmail.com','Zuhairi Ali','13, Jalan 7/4<br>Bandar Tasik Kesuma','Beranang','Selangor','MALAYSIA','43700','0129161651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 06:05:37',0,NULL,3,1,2,1,NULL,NULL),(5889,642420887001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','balaboshka','marinamaleryan@yahoo.com','Marina Maleryan','ulica 120 Divizii, d.7, kv.43','Gatchina','Leningradskaya oblast','RUSSIAN FEDERATION','188306','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 09:23:10',0,NULL,3,1,2,1,NULL,NULL),(5890,642451748001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','semircok','gurnik@gmail.com','Martin Gurnik','Farska 59','Huncovce','Slovakia','SLOVAK REPUBLIC','05992','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 10:43:32',0,NULL,3,1,2,1,NULL,NULL),(5891,747773334015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','freestyle2009','oystein.sorli@mimer.no','Øystein Sørli','Fjellstad 26','Hildre','','NORWAY','6272','97461256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 10:48:15',0,NULL,3,1,2,1,NULL,'欧标 '),(5892,642467781001,110533631144,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',2,'AB1303',6.68,'hermeshine','stlg07','stntid@gmail.com','Sherif Tadros','1 Gipps Avenue','Little Bay','New South Wales','AUSTRALIA','2036','0432649565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:23:05',0,NULL,3,1,2,1,NULL,NULL),(5893,642475506001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','kimeline','post@tjelde.no','Kim Tjelde  Fauskrud','Brukroveien 260','Brottum','Brottum','NORWAY','2372','+4741641798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:43:02',0,NULL,3,1,2,1,NULL,NULL),(5894,642263266001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',17.16,'hermeshine','ozlemusta','ozleem@gmail.com','Ozlem Usta','Nortel Netas<br>Alemdag C. No:171 Umraniye','Istanbul','','TURKEY','34768','+905358964872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 11:19:10',0,NULL,3,1,2,1,NULL,'反光板  80cm 5合1   1\r肥皂盒 580ex      1 '),(5895,682592287002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','police024','david.givord@chello.fr','GIVORD David','le moulin','rivolet','Rhône-Alpes','FRANCE','69640','04.26.74.03.86.','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 11:40:20',0,NULL,3,1,4,1,NULL,'light $20 \r欧标\rYW864870723CN\r客户已经收到    但是查询有问题\r'),(5896,642488169001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','titsumi','titsumi.forever@gmail.com','Ильин Андрей (Ilgin Andrey)','Королевка д. 8, кв. 129 (Korolevka 8-129)','Смоленск (Smolensk)','Россия г Смоленск (Russia, Smolensk)','RUSSIAN FEDERATION','214039','(951)715-1827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 12:16:42',0,NULL,3,1,2,1,NULL,NULL),(5897,642499050001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','yoyomadness','jon@yoyomadness.com','jon carreiro','21 lands end way','swansea','MA','UNITED STATES','02777-2909','(508) 496-6092','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 12:43:45',0,NULL,3,1,1,1,NULL,NULL),(5898,642501559001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','vitorseagull','vitor.seagull@gmail.com','Luiz Vitor Vieira','Rua Novo Cruzeiro n °46 apto 301<br>Vila Valqueire','Rio de Janeiro','Rio de Janeiro','BRAZIL','21330-240','5521-246-40753 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 12:52:04',0,NULL,3,1,3,1,NULL,' RR843872130CN\r'),(5899,642511365001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','starsapphire04','starsapphire04@yahoo.com','Ada Lajara','214 Bautista Compd Cor. Felix Y. Manalo St.<br>San Isidro Cainta Rizal','Cainta','Rizal','PHILIPPINES','1900','022492484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:15:34',0,NULL,3,1,2,1,NULL,NULL),(5900,642497998001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','sakuramizuki','psycho_lunatic_poet@hotmail.com','Khatleen Minerve','Royal Road Valetta, Hemraz Road.','Dagotiere','','MAURITIUS','230','9325435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 12:41:23',0,NULL,3,1,2,1,NULL,NULL),(5901,682641445002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:40:18',0,NULL,8,1,17,0,NULL,' '),(5902,642524609001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:42:44',0,NULL,8,1,17,0,NULL,NULL),(5903,642525772001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 13:45:40',0,NULL,8,1,17,0,NULL,NULL),(5904,682645181002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','csabi1965','forster.st@gmail.com','Csaba Vass','Rozsafa 19.','Salgotarjan','','HUNGARY','3104','003620','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:48:00',0,NULL,3,1,5,1,NULL,'2m 灯架  2\r双灯头 欧标  2\r反光伞  2\r柔光伞  2\r45w   2\r115w 220v   2\r包  1\r CP226630741CN\r'),(5905,642528671001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','pup3k01','bigbelly@seznam.cz','Ondřej Gongala','Výškovická 100','Ostrava','Moravskoslezsky kraj','CZECH REPUBLIC','70030','777057048','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 13:57:25',0,NULL,3,1,5,1,NULL,' CP226630755CN\r'),(5906,682675491002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','talnisim','talnisim@gmail.com','Tal Nisim','Reading 6/c','Tel Aviv','','ISRAEL','69022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 14:53:11',0,NULL,3,1,3,1,NULL,' RR843872381CN\r'),(5907,682687159002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','Vanessa Muniz','Rua Ibituruna, 43 Bloco 1 apt 505<br>Maracanã','Rio de Janeiro','Rio de Janeiro','BRAZIL','20271-021','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 15:16:11',0,NULL,3,1,3,1,NULL,' RR843872109CN\r'),(5908,682690358002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','martinyelvira','martin.rodriguez@hispeed.ch','Elvira Navas','Fuessmattli 4 b','Ottenbach','','SWITZERLAND','8913','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 15:25:52',0,NULL,3,1,4,1,NULL,'lighting kit \r$30 \r欧标\rYW864870712CN\r'),(5910,642591113001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','wflame','nick.gulyaev@gmail.com','Nikolay Gulyaev','Tsiolkovskogo 3/3 - 8','Lipetsk','','RUSSIAN FEDERATION','398032','9046850305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 15:58:03',0,NULL,3,1,2,1,NULL,NULL),(5911,642601460001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 16:12:09',0,NULL,3,1,8,1,NULL,' CP226630698CN\r'),(5912,642616561001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','eddy_dc','info@eddydc.be','Eddy De Coster','Ricardplein 17','Deinize','','BELGIUM','9800','32498391890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:35:52',0,NULL,3,1,2,1,NULL,' '),(5913,642620025001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:40:22',0,NULL,3,1,2,1,NULL,NULL),(5914,682741613002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','andrewdem','for_shoping@mail.ru','Andriy Demyanenko','Bogdana Hmelnitskogo st. 33-17','Pereyaslav-Hmelnitskiy','Kievska oblast','UKRAINE','08400','063-960-28-47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 16:47:06',0,NULL,3,1,3,1,NULL,' RR843872157CN\r'),(5915,682802379002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3302',23.96,'hermeshine','jaylasf','vcr@usa.com','Jay Ho','6871 Camrose Dr','Hollywood','CA','UNITED STATES','90068','(310) 926-7596','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 18:03:02',0,NULL,3,1,1,1,NULL,NULL),(5916,682847231002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 18:50:24',0,NULL,3,1,2,1,NULL,NULL),(5917,682499583002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','rookietsai','davidtsai2004@yahoo.com','David Tsai','42848 Fontainebleau Park Ln','Fremont','CA','UNITED STATES','94538-3935','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 19:05:31',0,NULL,3,1,1,1,NULL,NULL),(5918,642711458001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','cla33fr','cla33@free.fr','Christian LAGARDERE','10, rue de la croix du sable','BRUGES','Aquitaine','FRANCE','33520','06 85 71 67 70','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 18:31:39',0,NULL,3,1,3,1,NULL,' RR843872143CN\r'),(5919,748161944015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','redlub','kbmanden@yahoo.dk','kjeld jensen','bispevangen 2','ballerup','','DENMARK','2750','+4550238682','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-06 19:22:19',0,NULL,3,1,2,1,NULL,NULL),(5920,682921391002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 20:03:36',0,NULL,3,1,2,1,NULL,NULL),(5921,682235347002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','spaz1921','puntapalma@gmail.com','salvio paz lorenzo','c/ general yague nº 20  2ºa','los llanos de aridane','Canarias','SPAIN','38760','638809816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 20:45:08',0,NULL,3,1,3,1,NULL,' RR843872069CN\r'),(5922,733320468016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','0208patee','nogamatstudio@hotmail.com','stephen yeboah','2 kenley gardens thornton heath','london','Surrey','UNITED KINGDOM','cr77dd','02086892665','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-06 20:49:02',0,NULL,3,1,4,1,NULL,'light  $18\r需要控制在2kg以下 \r\r英标\rYW864870701CN\r'),(5923,683008455002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',47,'hermeshine','chupachules','bronikita@gmail.com','reyes fernandez hernandez','base aerea de gando 802 escuadron','aeropuerto gran canaria','Canarias','SPAIN','35230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:02:44',0,NULL,3,1,3,1,NULL,' RR843872072CN\r'),(5924,642887824001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:44',0,NULL,8,1,17,0,NULL,NULL),(5925,642887032001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:44',0,NULL,8,1,17,0,NULL,NULL),(5926,642886881001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','gunsooo','gunnargj@gmail.com','Gunnar Geir Johannsson','Kjarrholmi 32','Kopavogur','','ICELAND','200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:06:45',0,NULL,3,1,3,1,NULL,'单灯头   欧标  2\r45w   2\r倒影板   1 \rRR843872086CN\r'),(5927,683013248002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','garym165','smclean31@cogeco.ca','Gary','McLean<br>123 Kingham Road','Acton','ON','CANADA','L7J1S3','(519) 929-9255','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-06 22:11:13',0,NULL,3,1,3,1,NULL,' RR843872090CN\r'),(5928,642891581001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','boskebaba','andras.solymos@yahoo.fr','Andras Solymos','147 Rue de Rennes','Paris','Île-de-France','FRANCE','75006','06.60.27.71.44.','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 22:14:09',0,NULL,3,1,2,1,NULL,'欧标 '),(5929,683033332002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','tampa_investigator','denispizza@yahoo.com','Denis J. Pizza','7108 Dove Meadow Trl','Lakeland','FL','UNITED STATES','33810-8840','(813) 650-3100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-06 22:58:22',0,NULL,3,1,1,1,NULL,NULL),(5930,683042259002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','miririguiver','miririguiver@hotmail.com','Luiz Henrique Boulhosa','Rua Rodrigues Guião, 95','São Paulo','São Paulo','BRAZIL','05429030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-06 23:15:20',0,NULL,3,1,2,1,NULL,NULL),(5931,683079138002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','zyberman','greeno-b@rogers.com','Bryan Greenough','7700 Pine Valley Drive<br>Unit 4A','Woodbridge','ON','CANADA','L4L2X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 00:53:52',0,NULL,3,1,2,1,NULL,NULL),(5932,642988869001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','waxen','carlhebert1967@gmail.com','carl hebert','27 castle hill dr','bethel','CT','UNITED STATES','06801-1202','','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 02:31:55',0,NULL,3,1,1,1,NULL,NULL),(5933,683136125002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ahmadta','tauseeph@gmail.com','Tauseef Ahmad','Chubb Insurance Company of Canada, 15th floor, Mail room<br>1 Adelaide Street East','Toronto','ON','CANADA','M5C 2V9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 03:18:56',0,NULL,3,1,3,1,NULL,' RR843872015CN\r'),(5934,643014946001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','noapro1','alohacam@hotmail.com','NOA Production','324 Ilimalia Loop','Kailua','HI','UNITED STATES','96734','','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 03:50:14',0,NULL,3,1,3,1,NULL,' RR843872024CN\r'),(5935,643020292001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','berny1er','berny1er@hotmail.com','Guillaume Bernier','89, rue des Flocons','Rimouski','QC','CANADA','G5N 5V6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 04:09:23',0,NULL,3,1,3,1,NULL,' RR843872355CN\r'),(5936,683149139002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',4,'AO0014',31.6,'hermeshine','cmu2008','lzelinski50@hotmail.com','Lisa Zelinski','4121 W 14 Mile Rd','Royal Oak','MI','UNITED STATES','48073-1542','(989) 339-1701','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-07 04:10:26',0,NULL,3,1,1,1,NULL,NULL),(5939,683171836002,120451412743,'67mm 67 mm Macro +8 Close-Up Close Up Filter',1,'AE3226',8.5,'hermeshine','sazema2010','sasa.vranic@gmail.com','Saša Vranić','Bulevar Kulina Bana 28D','Zenica','Bosnia and Herzegovina','BOSNIA AND HERZEGOVINA','72000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 05:53:52',0,NULL,3,1,2,1,NULL,NULL),(5940,683186190002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','*.digital','angel.3f@gmail.com','David Barrera Martínez','Independencia No. 40<br>Col. Centro','Mixquiahuala','Hidalgo','MEXICO','42700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 07:20:57',0,NULL,5,0,18,0,NULL,NULL),(5941,683208829002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 09:18:23',0,NULL,8,1,17,0,NULL,'\r'),(5942,683210646002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',2,'AKT040',149.8,'hermeshine','istokka','admoccia@alice.it','pasquale saviano','via GRAMSCI 55','Frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 09:22:11',0,NULL,3,1,4,1,NULL,'2m 灯架  2\r单灯头 欧标  2\r反光伞  2\r4灯头棚  4  欧标 \rlight stand  $25\rYW864870874CN\r'),(5943,748560318015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','philipqs','pdlmatthews@gmail.com','Philip Matthews','2 Ballagh Wood Donadea','Naas','Kildare','IRELAND','4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 09:36:59',0,NULL,3,1,3,1,NULL,' RR843873020CN\r'),(5944,733636843016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','falsifysa3s','falsify@hotmail.co.uk','Dean Cook','17 Lothersdale Stonydelph','Tamworth','Staffordshire','UNITED KINGDOM','B77 4HT','01827896147','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-07 10:41:59',0,NULL,3,1,4,1,NULL,'lighting kit  $30\r英标 \rYW864870863CN\r'),(5945,683236194002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:52',0,NULL,8,1,17,0,NULL,NULL),(5946,683235023002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:52',0,NULL,8,1,17,0,NULL,NULL),(5947,683233543002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jarosgabor','jarosg@gmail.com','Jaros Gábor','3200 Gyöngyös, Gólya u. 125.','Gyöngyös','Heves','HUNGARY','3200','36203283223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:07:53',0,NULL,3,1,2,1,NULL,'渐变灰  1\r3片装滤镜袋  1\r广角托架    1 '),(5948,683240018002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','folooop','foolop@gmail.com','filip bejtner','Carrero Juan Ramon 10 ,4b','madrid','Madrid','SPAIN','28025','600018384','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 11:24:25',0,NULL,3,1,3,1,NULL,' RR843873047CN\r'),(5949,683246469002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','duszekjack','jacek.splawski@gmail.com','Jacek Splawski','25 Raheen Close<br>Springfield, Tallaght','Dublin','Dublin','IRELAND','24','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 11:51:08',0,NULL,3,1,4,1,NULL,'大力夹   4\r反光板支架   1\r斜臂   1 \rLIGHTING KIT  $25\rYW864870852CN\r'),(5950,683261485002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA3205',3.5,'hermeshine','hakon87','pedromolina87@gmail.com','Pedro Molina Blázquez','C/ V Centenario nº1 - 1ºE','Badajoz','Extremadura','SPAIN','06007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 12:49:04',0,NULL,8,0,17,0,NULL,''),(5951,683263800002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','pattama1','vorasak1@gmail.com','vorasak Sombatpiboon','152(1364/62) Trok. Kitao<br>Krungthonburi Rd. Soi 4, Banglumphulang','Klongsan,','Bangkok','THAILAND','10600','(668) 168-4253 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 12:59:02',0,NULL,3,1,2,1,NULL,NULL),(5952,683268579002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','yphotographer112','mtbleb97@hotmail.com','Tyler Berge','9464 Dakota Rd','Bloomington','MN','UNITED STATES','55438-1709','(952) 356-9275','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-07 13:13:56',0,NULL,3,1,1,1,NULL,NULL),(5953,683268553002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','hakon87','pedromolina87@gmail.com','Pedro Molina Blázquez','C/ V Centenario nº1 - 1ºE','Badajoz','Extremadura','SPAIN','06007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 13:14:13',0,NULL,3,1,4,1,NULL,'红外遥控 canon  1 \rtripod $16 \rYW864870841CN\r'),(5954,733698534016,260660052995,'New Genuine Nikon 90th Anniversary Camera Neck Strap',1,'AB1402',8.99,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','0485453192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 13:53:36',0,NULL,5,0,18,0,NULL,NULL),(5955,683282017002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','luckywebsoft','tomaspenalver@gmail.com','tomas peñalver garcia','puerta de hierro 85 b<br>buzon 21','santiago de la ribera','Murcia','SPAIN','30720','968 18 25 10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 14:01:19',0,NULL,3,1,2,1,NULL,NULL),(5956,683284076002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','prince3737','theshot@roadrunner.com','Prince Edwards','153-B  HWY . 42-west','ahoskie','NC','UNITED STATES','27910','(252) 642-5009','NoPaymentFailure','CheckoutComplete','Other','2011-03-07 14:21:21',0,NULL,3,0,1,1,NULL,'xxl \r没减库'),(5957,683293350002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','denybarboza','denyzinho@gmail.com','Jordana Brizolara','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 14:38:54',0,NULL,3,1,3,1,NULL,' RR843873104CN\r'),(5958,683305040002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kiznito','jmanuelmorante@gmail.com','jose manuel nuñez morante','pl/ jazmin nº5 6ºd','alcala de henares','Madrid','SPAIN','28803','679786781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 15:18:11',0,NULL,3,0,3,1,NULL,'\rRR843873149CN\r'),(5959,683316971002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','t_brique','t_brique@yahoo.com','Thomas Brique','48 rue de Chabrol','Paris','Île-de-France','FRANCE','75010','09.54.75.64.44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 15:51:00',0,NULL,3,1,2,1,NULL,NULL),(5960,643189017001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',5,'AB1301',16.7,'hermeshine','sadthachai','snoom@hotmail.com','Ms.Rapee Yamsang','36<br>Chiang Mai-Lamphun Rd T.watket','Muang Chiangmai','Chiangmai','THAILAND','50000','0899559145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 16:11:54',0,NULL,3,1,3,1,NULL,' RR843873095CN\r'),(5961,643210273001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 17:12:09',0,NULL,8,1,17,0,NULL,NULL),(5962,643217256001,110531023440,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','antiloop695','arild.k@loqal.no','Arild Kirkaune','Rihåggåveien.4','Eggkleiva','Skaun','NORWAY','7355','+4740291975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 17:21:34',0,NULL,3,1,2,1,NULL,NULL),(5963,748751945015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','fedleo','effelle@gmail.com','Federico Leoni','Via San Benedetto, 9','Assisi','Perugia','ITALY','06081','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-07 17:52:52',0,NULL,3,1,2,1,NULL,NULL),(5964,643280450001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kdrandgaard','kristine_daland@hotmail.com','Kristine Daland Randgaard','Toraldåsen 50','4886 Grimstad','Grimstad','NORWAY','4886','-47 908 53 555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 19:36:06',0,NULL,3,1,2,1,NULL,NULL),(5965,683422332002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 19:45:28',0,NULL,3,1,3,1,NULL,'\rRR843873152CN\r'),(5966,643292554001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','wayne1hurford','waynehurford@hotmail.com','Wayne Hurford','Box  291','Squamish','BC','CANADA','V8B0A3','(604) 892-4964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 19:53:30',0,NULL,3,1,2,1,NULL,NULL),(5967,683477122002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 21:33:34',0,NULL,3,1,3,1,NULL,'\rRR843873135CN\r'),(5968,643346386001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ldaemg1','enmigar@hotmail.com','Enrique Miralles García','eras nº 75','yuncos','Castilla-La Mancha','SPAIN','45210','606883247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 21:41:12',0,NULL,3,1,2,1,NULL,NULL),(5969,683494632002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pochifon','po_chi81@hotmail.com','alfonso sanchez diez','calle cardenal cisneros 18 1ºb','leon','Castilla y León','SPAIN','24010','659717158','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:06:05',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870830CN\r'),(5970,643365309001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:29:17',0,NULL,3,0,3,1,NULL,'分两票发   RR843873308CN\rRR843873210CN'),(5971,643369598001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','dellm640','dellemail@seznam.cz','Ilja Mašík','Na výsluní 25','Prague','','CZECH REPUBLIC','10000','608861086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 22:40:48',0,NULL,3,1,3,1,NULL,' RR843873016CN\r'),(5972,643370547001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:28',0,NULL,8,1,17,0,NULL,' '),(5973,643370348001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:28',0,NULL,8,1,17,0,NULL,NULL),(5974,643370054001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 22:43:29',0,NULL,3,1,2,1,NULL,' 机身盖/镜头后盖  Nikon  1\rNIKON 镜头盖 52mm  1\r绿叶 渐变镜 52mm  1'),(5975,748951627015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1307',5.16,'hutongstore','cjpxyz','les573@aol.com','mark parvin','42 High Street,','Felling,','Tyne and Wear','UNITED KINGDOM','NE10 9LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-07 23:22:10',0,NULL,3,1,2,1,NULL,NULL),(5976,643382186001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','fabio_drak','fabiojz@gmail.com','Fabio Zimmer','Jose Risseto 26','Curitiba','Parana','BRAZIL','82015010','32723050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-07 23:30:30',0,NULL,3,1,2,1,NULL,NULL),(5977,683531411002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-07 23:44:04',0,NULL,3,1,3,1,NULL,' RR843873078CN\r'),(5978,734008909016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','whyte187','d_o_a_187@hotmail.com','Steven Whyte','11 Mitchell Drive','Rutherglen','Glasgow (City of)','UNITED KINGDOM','G733QP','01415698153','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 00:01:25',0,NULL,3,1,2,1,NULL,NULL),(5979,643398437001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','oceoke','oceoke01@gmail.com','Miguel Angel Ruiz Santaella','Avda. del Mediterraneo nº 7 2º I<br>Salobreña (Granada)','Salobreña   (Granada)','Andalucía Ceuta y Melilla','SPAIN','18680','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:19:07',0,NULL,3,1,3,1,NULL,' RR843873064CN\r'),(5980,748977576015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','alllans','allan.smith@gmx.co.uk','Allan Smith','18 Vancouver Drive London Rd','Crawley','West Sussex','UNITED KINGDOM','RH11 7UR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 00:35:40',0,NULL,3,1,2,1,NULL,NULL),(5981,643404403001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cperaltam','cperaltam@gmail.com','Carlos Peralta Martinez','Calz. Nva. Tulyehualco-Xochimilco 20-A<br>Nativitas Manantiales','Mexico City','Mexico','MEXICO','16450','+52 55 21570902','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:41:18',0,NULL,3,1,3,1,NULL,'717快装板   2\rRR843873081CN\r'),(5982,683551001002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','itsjed','jed.delacruz@gmail.com','Jed De La Cruz','3 Distin Ave.','Toronto','ON','CANADA','M8Z3R6','(416) 201-0093','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 00:52:25',0,NULL,3,1,3,1,NULL,' RR843873033CN\r'),(5983,748997762015,250600522522,'Remote Control Cord Shutter Nikon D80 D70s​ MC-DC1 ',1,'AA3208',2.98,'hutongstore','gialys','gialys@yahoo.it','gioacchino ballo','VIA UGO SOLI 9','PALERMO','Palermo','ITALY','90128','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 01:40:11',0,NULL,8,1,17,0,NULL,NULL),(5984,748994823015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','gialys','gialys@yahoo.it','gioacchino ballo','VIA UGO SOLI 9','PALERMO','Palermo','ITALY','90128','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 01:40:12',0,NULL,3,1,2,1,NULL,'80cm 2in1   反光板   1\rRS-N2    1'),(5985,643466774001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','farozzi','tarute@hotmail.com','Fatima Jantasri','5/1836 Moo 10 Bangtalad Pakkred','Nontaburi','','THAILAND','11120','+66865190501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 04:45:46',0,NULL,8,1,17,0,NULL,' '),(5986,682187000002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','espiritkiller','andrematos@virtualmagic.com.br','Andre de Matos Alves','Rua Travessa da Imprensa, 128<br>Jardim Aliança','Osasco','São Paulo','BRAZIL','06236-180','+55 11 35994110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 05:46:34',0,NULL,3,1,2,1,NULL,'espiritkiller'),(5987,643490393001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','kupriha','kuprik13@gmail.com','Анжелика Куприянова','пр.Яковлева<br>дом 6, корп.2, кв.16','Чебоксары','Чувашская Республика','RUSSIAN FEDERATION','428029','89603051616','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 07:17:02',0,NULL,3,1,5,1,NULL,'背景架 白黑 \rCP226630675CN\r'),(5988,683640342002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','borisovna_e','borisovna.e@gmail.com','Елена Богданова','Полярные зори, 19-23','Мурманск','Мурманская область','RUSSIAN FEDERATION','183039','+79537599911','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 07:17:06',0,NULL,3,1,3,1,NULL,' RR843873206CN\r'),(5989,643495097001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.6,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 07:44:20',0,NULL,3,1,2,1,NULL,'绿叶 UV  67mm  1\r绿叶 UV  55mm   1'),(5990,643494074001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.3,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 07:38:13',0,NULL,8,0,17,0,NULL,NULL),(5991,749100360015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','bonini42','paul.bonini@googlemail.com','Paul Bonini','12 Rimu Street Kaka Point','Balclutha','South Otago','NEW ZEALAND','9271','6434128667','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 08:16:51',0,NULL,3,1,6,1,NULL,'白 黑  \rEE389037501CN\r\r'),(5992,643507303001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','honkyhog','danceup@aol.com','Jerry Hill','2420 SE 6th St','Pompano Beach','FL','UNITED STATES','33062','(954) 785-1536','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-08 08:50:03',0,NULL,3,1,3,1,NULL,' 580\rRR843873886CN\r'),(5993,643516952001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','glentaylormt','glentaylor_mt@hotmail.com','Glen Taylor','127 St.Jude<br>Trieq il Htajriet','Mosta','ME','MALTA','3062','21412542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 09:33:00',0,NULL,3,1,5,1,NULL,' 2.864\rCP226334806CN\r'),(5994,643382091001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','mona.1789','av96739-1@comtv.ru','Ananyev Andrey','S RADONEZHSKOGO ST 8-76','MOSKVA','','RUSSIAN FEDERATION','105120','(919)9681789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 09:51:39',0,NULL,3,1,3,1,NULL,' RR843873943CN\r'),(5995,749125380015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','superamble','alessandro.chiurco@yahoo.it','Alessandro Chiurco','Via G. Cassiani 82','Spezzano Albanese','CS','ITALY','87019','0981953517','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 09:52:42',0,NULL,3,1,2,1,NULL,NULL),(5996,683675797002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','philippe3904','philippe.henchoz@unige.ch','Philippe Henchoz-Corcelle','64, Rue de la Louvatière','St Jean de Gonville','Rhône-Alpes','FRANCE','01630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 10:11:14',0,NULL,3,1,3,1,NULL,' RR843873926CN\r'),(5997,643529732001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','bakhalah','ahmed-bakhalah@hotmail.com','Ahmed Salem Bakhalah','P.O.Box 255701<br>Mobile: 00966562424334','Riyadh','','SAUDI ARABIA','11353','00966562424334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 10:31:23',0,NULL,3,1,2,1,NULL,NULL),(5998,683690267002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','quera1','pr.pregardien@skynet.be','René PREGARDIEN','Rue M. Body, 51','Grâce-Hollogne','','BELGIUM','4460','0475770122','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 11:14:46',0,NULL,3,1,4,1,NULL,'light head  $16 \rYW864870896CN\r\r'),(5999,683683909002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 11:31:07',0,NULL,3,1,3,1,NULL,' RR843873869CN\r'),(6000,683698551002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','kobayashi516','k516k516.10@gmail.com','koichiro kobayashi','kamitsuruma 6-29-3','minami-ku sagamihara-shi','Kanagawa','JAPAN','252-0302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 11:48:31',0,NULL,3,1,3,1,NULL,' RR843873912CN\r'),(6001,643543999001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','leewojones','koliwo@hotmail.com','COLIN ABAYOMI','52 RUSSELL ROAD<br>NORTHOLT','LONDON','London','UNITED KINGDOM','UB54QS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 11:31:30',0,NULL,3,1,2,1,NULL,NULL),(6002,683691331002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','elxanders','svirin@pochtamt.ru','Alexander Svirin','18/1-1 Sverdlova st','Yakutsk','','RUSSIAN FEDERATION','677005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 12:24:18',0,NULL,3,1,5,1,NULL,'\rCP226630667CN\r'),(6003,643558884001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','kuchticek','kuchtik@yahoo.com','Marek Petrovic','Racianska 65','Bratislava','SC','SLOVAK REPUBLIC','83102','0903132267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 12:29:21',0,NULL,3,1,2,1,NULL,NULL),(6004,643580176001,110566021028,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','kreyno','kreynold@energen.com','karen reynolds','449 Oneal Dr','Hoover','AL','UNITED STATES','35226-1646','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 13:49:44',0,NULL,8,1,17,0,NULL,NULL),(6005,643579980001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','kreyno','kreynold@energen.com','karen reynolds','449 Oneal Dr','Hoover','AL','UNITED STATES','35226-1646','','NoPaymentFailure','CheckoutComplete','Other','2011-03-08 13:49:45',0,NULL,3,0,3,1,NULL,' 摄影背心 绿色薄 nikon  XXXL  1\r防寒罩     1\rRR843874008CN\r'),(6006,643583694001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','l0sgleb','losgleb@mail.ru','Gleb Loskutov','Lenina st., 31-96','Krasnogorsk','Moscow region','RUSSIAN FEDERATION','143404','(916) 4423492','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 14:14:30',0,NULL,3,1,2,1,NULL,NULL),(6007,683740718002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:25:41',0,NULL,8,1,17,0,NULL,NULL),(6008,683739231002,120451408213,'52mm 52 mm Macro +4 Close-Up Close Up Filter',1,'AE3215',6.5,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:29:59',0,NULL,8,1,17,0,NULL,NULL),(6009,643588766001,110534332949,'Green.L 52mm Neutral Density ND4 Filter 52 D40 18-55mm',1,'AE2301',5.8,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CARLOS MARTIN ALVAREZ 31 3ºD','MADRID','Madrid','SPAIN','28018','918477995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 14:30:00',0,NULL,3,1,2,1,NULL,' 天涯 cpl 52mm   1\r绿叶近摄镜 +2  52mm  1\r绿叶 ND4  52mm  1'),(6010,643598362001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','sereivax','rodolfo.xavier@mail.telepac.pt','Rodolfo Xavier','R. José Eduardo César nº 4, 1º and letra D/E','Torres Vedras','Torres Vedras','PORTUGAL','2560-680','+351963707228','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 14:52:40',0,NULL,3,0,3,1,NULL,'XXL \rRR843873991CN\r'),(6011,683751504002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','peroni_es','correu.por@gmail.com','Pere Onieva','Av. Barcelona 108 6-2','IGUALADA','SPAIN','SPAIN','08700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 15:01:47',0,NULL,3,1,2,1,NULL,'欧标  '),(6012,683753822002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','sabretex','pmiv@juno.com','Robert Shary','2102 Pecos St<br>Ste 10','San Angelo','TX','UNITED STATES','76901-3061','(325) 947-1281','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 15:09:43',0,NULL,3,1,1,1,NULL,NULL),(6013,683757869002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','farozzi','tarute@hotmail.com','Fatima Jantasri','5/1836 Moo 10 Bangtalad Pakkred','Nontaburi','','THAILAND','11120','+66865190501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 15:23:12',0,NULL,3,1,2,1,NULL,' '),(6014,643611600001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','prince3737','theshot@roadrunner.com','Prince Edwards','153-B  HWY . 42-west','ahoskie','NC','UNITED STATES','27910','(252) 642-5009','NoPaymentFailure','CheckoutComplete','Other','2011-03-08 15:37:30',0,NULL,3,0,1,1,NULL,'xxl '),(6015,683781991002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','torpedoruso','antonio23666@hotmail.com','Antonio López','C/Ravel nº1 portal 4º 5ºA','Almeria','Andalucía Ceuta y Melilla','SPAIN','04007','679170103','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 16:33:53',0,NULL,3,1,3,1,NULL,' RR843873988CN\r'),(6016,749288574015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','crag67','michaelcraig67@hotmail.com','M Craig','141 Ribbleton Avenue','Preston','Lancashire','UNITED KINGDOM','PR26YS','07876790728','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,' '),(6017,683803764002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','iceaxe23','iceaxe23@wi.rr.com','Daniel Yaris','26100 60th st','Salem','WI','UNITED STATES','53168-9246','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 17:30:58',0,NULL,3,1,1,1,NULL,NULL),(6018,643660681001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','raf_ceron','alexceron@gmail.com','Rafael Alexander Cerón Rodríguez','Calle Industria, 43<br>Planta Baja','Santa Maria de Palautordera','Cataluña','SPAIN','08460','938482962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-08 17:53:59',0,NULL,3,1,2,1,NULL,NULL),(6019,643667997001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','alexer1','rozen@te.net.ua','Oleg Rozentsvayg','Nezhinskaya Str3, apt 44','Odessa','UA','UKRAINE','65023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 18:06:31',0,NULL,3,1,3,1,NULL,' RR843873974CN\r'),(6020,683826149002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 18:23:59',0,NULL,3,1,3,1,NULL,' RR843873965CN\r'),(6021,683847112002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','tickhed75','tickhed@gmail.com','Tiffany Melke','1745 Piper Cir SE','Atlanta','GA','UNITED STATES','30316-2253','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 19:08:12',0,NULL,3,1,1,1,NULL,NULL),(6022,683851132002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','haghne1','iness_gv@hotmail.com','Inés García Villegas','Cno/ El Jaraque Nº9','Granada','Andalucía Ceuta y Melilla','SPAIN','18620','647214083','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 19:16:43',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870900CN\r'),(6023,643711614001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nimuravka1','nimuravka@mail.ru','Ekaterina Dang','Severnaya 48-11','Odintsovo','Moskovskaya oblast','RUSSIAN FEDERATION','143000','+7 926 5377557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 19:35:19',0,NULL,3,1,2,1,NULL,NULL),(6024,643718232001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 19:49:51',0,NULL,3,1,2,1,NULL,NULL),(6025,643719874001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotografitty','pablojmutal@yahoo.com.ar','Pablo Javier Mutal','Felix Frias Esq. San Clemente . BºPriv. San Alfonso<br>Lote 06 Mzna.35','Córdoba','Saldán','ARGENTINA','5149','03543-496695','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 19:53:41',0,NULL,3,1,3,1,'RR843873930CN\r ','fotografitty\r'),(6026,643722132001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',5.9,'hermeshine','ralfygurl','ralfygurl@yahoo.com','Christy Reed','203 S Chestnut St','Forney','TX','UNITED STATES','75126-9528','(318) 376-1481','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-08 19:56:07',0,NULL,3,1,1,1,NULL,'新的那个，找不到问我 '),(6027,643729917001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','casillas65','carpaumar@gmail.com','juan manuel casillas delgado','calle universidad hispalense 8','osuna','SEVILLA','SPAIN','41640','629017397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:13:46',0,NULL,3,1,2,1,NULL,NULL),(6028,643737098001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','yanaiamir','yanaiamar@gmail.com','Yanai Amar','Yoseftal 22','Ramla','','ISRAEL','72412','(972)525444404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:29:19',0,NULL,3,1,2,1,NULL,NULL),(6029,643740622001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','irijasan','neribi@gmail.com','Neringa Lavrenove','Rugiu 14-14','Vilnius','','LITHUANIA','08419','+37061075100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 20:33:04',0,NULL,3,1,2,1,NULL,NULL),(6030,749424759015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','eufrat666','nihkeily.jees@gmail.com','Jussi Saarivuori','Teiskontie 8 B 6','Tampere','','FINLAND','33540','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-08 21:04:45',0,NULL,3,1,3,1,NULL,' RR843873957CN\r'),(6031,683913078002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','brokenbmx','brokenbmx@hotmail.com','Gripfruit Joey Terwindt','Hazeleger 189','Cuijk','NB','NETHERLANDS','5431HS','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 21:19:36',0,NULL,3,1,3,1,NULL,'\rRR843873360CN\r'),(6032,749432524015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.28,'hutongstore','hifinut11','thiam.chung@gmail.com','Thiam Chung','11 Manor Close Costock','Loughborough','Leicestershire','UNITED KINGDOM','LE12 6XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-08 21:18:40',0,NULL,3,1,2,1,NULL,NULL),(6033,643781266001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','alessio_1927','alessio.macri@email.it','Alessio Macrì','via Brembate 21','roma','RM','ITALY','00188','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 22:10:47',0,NULL,3,1,2,1,NULL,'欧标 '),(6034,734478974016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ethiopia1.123','empressmenan@yahoo.com','Ife','APARTMENT 27, PLACIDO 34 RYLAND STREET','BIRMINGHAM B16 8DB','West Midlands','UNITED KINGDOM','B16 8DB','07930137656','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-08 22:30:20',0,NULL,3,1,4,1,NULL,'英标 \rlighting  kit   $30\rYW864870922CN\r'),(6035,643795320001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','roger_awright','roger.b8@hotmail.com','Roger Becker','Nossa senhoras das Graças, 95','porto alegre','Rio Grande do sul','BRAZIL','90660-170','55-51-33078878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-08 22:48:46',0,NULL,3,1,2,1,NULL,'接口环尺寸 67mm '),(6036,683946016002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','paluk_fr','psubot@free.fr','SUBOTKIEWIEZ Patrick','30 AVENUE DE L\'HERS','BAZIEGE','Haute garonne','FRANCE','31450','0562711235','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-08 22:41:08',0,NULL,3,1,4,1,NULL,'欧标   背景布白色 \rlighting  kit  $30\rYW864870911CN\r'),(6037,683970488002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 01:55:39',0,NULL,3,1,3,1,NULL,' '),(6038,643847562001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','diyaudioprojects','ebay@diyaudioprojects.com','Giovanni Militano','806-1305 Taylor Avenue','Winnipeg','MB','CANADA','R3M 2K6','(204) 475-3819','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 02:06:41',0,NULL,3,1,2,1,NULL,' '),(6039,684022812002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','malicegarden','malicegarden@yahoo.com','Katharina Raczew','Dietrichsteingasse 9/13','Vienna','','AUSTRIA','1090','(423) 304-4772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 03:13:41',0,NULL,3,1,2,1,NULL,NULL),(6040,643894061001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','imababo','o_j_4_me@yahoo.com','Carlos Ruiz','67105 Garbino Rd','Cathedral City','CA','UNITED STATES','92234-3479','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 05:39:13',0,NULL,3,1,1,1,NULL,NULL),(6041,745284361015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','osbourne91','mmc7373@hotmail.com','Michael Crichton','153 Marion Street','Leichhardt','New South Wales','AUSTRALIA','2040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 07:30:59',0,NULL,3,1,2,1,NULL,NULL),(6042,734525518016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','michaelq66','michael.quinlivan@irishbroadband.net','Michael Quinlivan','329 O\'Malley Park Southill','Limerick City','Limerick','IRELAND','default','0872311815','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 07:40:49',0,NULL,3,1,4,1,NULL,' \rYW864870933CN\r差到这'),(6043,643915832001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','smpimages2011','ops@smpimages.com.au','Scott Powick','P.O.Box 4243 The Pines centre','Elanora','Queensland','AUSTRALIA','4221','0406996773','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 07:52:25',0,NULL,3,0,3,1,NULL,'XXXL \rRR843873719CN\r'),(6044,684097893002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','floppy6518','floppy_fisico@hotmail.com','Mario Diaz Fernandez','C Acanto Nº11<br>Edificia A Planta Baja','Madrid','Madrid','SPAIN','28045','659340342','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 09:44:27',0,NULL,3,1,4,1,NULL,'tripod  $16 \rYW864870992CN\r'),(6045,749670104015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','ola.fvs.pettersson','ola.pettersson@gmail.com','Ola Pettersson','Platmyntsgatan 31','GOTEBORG','','SWEDEN','41479','+46707301122','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 10:26:29',0,NULL,3,1,3,1,NULL,' RR843873515CN\r'),(6046,749141346015,250692236332,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',33.58,'hutongstore','nyquist2011','clocchiatti.dario@gmail.com','Dario Clocchiatti','Via Leonardo da Vinci 14/4','Tavagnacco','UD','ITALY','33010','0432660857','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 10:34:58',0,NULL,3,0,3,1,NULL,'nikon -52mm 反接环  1\rcanon -52mm 反接环  1\r52-58mm  双阳环  1\r52mm 接口环  1\r58mm 接口环  1\r67mm 接口环  1\r77mm 接口环 + 托架  1\rND 2  / 4 / 8     1\r申报： photography accessories  33.58 GBP\r\r申报一定要这么做！\rRR843873753CN\r\r\r\r '),(6047,643956365001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','kristoffer554','kkagentur@msn.com','Kristoffer Klok','Holmkaervej 96','Trige','','DENMARK','8380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 10:58:22',0,NULL,3,1,2,1,NULL,'欧标 '),(6048,643953371001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','elhelado','specialist1982@mail.ru','Yulia Tveritinova','Zhivopisnaya ulitsa, dom 8, kvartira 41','Balashiha','Moscow region','RUSSIAN FEDERATION','143905','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 11:09:47',0,NULL,3,1,2,1,NULL,NULL),(6049,643963651001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0034',9,'hermeshine','wilgo_1981','wilgo_1981@hotmail.com','Javier Gutierrez','calle 20 no 21 - 41','bucaramanga','','COLOMBIA','018000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 11:28:11',0,NULL,3,1,2,1,NULL,'nikon 三角包   1 '),(6050,684145571002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','photobuf','tomandsusan@bellsouth.net','Tommy Jennings','1489 Good Hope Rd','Lake','MS','UNITED STATES','39092','','NoPaymentFailure','CheckoutComplete','Other','2011-03-09 12:57:47',0,NULL,3,0,1,1,NULL,'L '),(6051,684160241002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','kir231','kir2@inbox.ru','Konstantin  Kirilov','CHaykovskogo 41A (company kashtan)','Sochi, RU','Krasnodarskiy kray','RUSSIAN FEDERATION','354071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 13:48:11',0,NULL,8,1,17,0,NULL,NULL),(6052,644001473001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','kir231','kir2@inbox.ru','Konstantin  Kirilov','CHaykovskogo 41A (company kashtan)','Sochi, RU','Krasnodarskiy kray','RUSSIAN FEDERATION','354071','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 13:49:24',0,NULL,3,1,5,1,NULL,'套装再加上一个肩架 \r欧标\rCP226334823CN\r'),(6053,643948522001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','d.irina1975','dumon74.13@gmail.com','Savel\'evu Vladimiru','Proletarskaja dom 7a  kv 12','Kaluzhskaja obl','g Kirov','RUSSIAN FEDERATION','249440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 13:52:57',0,NULL,3,1,2,1,NULL,NULL),(6054,644009217001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','kulakovdarko','kulakov.darko@gmail.com','Darko Kulakov','Marshal Tito 117','Negotino','Negotino','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1440','+38970368087','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 14:15:35',0,NULL,3,1,2,1,NULL,' '),(6055,684180302002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','graf131313','m.prishep@gmail.com','Maksim Prishep','Rokossovskogo 48-4','Bobryisk','','BELARUS','213811','375295428036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 14:51:49',0,NULL,3,1,3,1,NULL,' RR843873427CN\r'),(6056,684182929002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','if_denis','djdenis@ukr.net','Denys Romanchuk','2200 State Rt 10<br>Ste 104','Parsippany','NJ','UNITED STATES','07054-5305','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 15:00:11',0,NULL,3,1,1,1,NULL,NULL),(6057,684183886002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','mandymo_06','mandagray88@gmail.com','Amanda Gray','211 Goingsnake st','Tahlequah','OK','UNITED STATES','74464-2907','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 15:02:04',0,NULL,3,1,1,1,NULL,' '),(6058,734813643016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','daveyfuggles','dave@davelaing.co.uk','david laing','104 the northern road','liverpool','Merseyside','UNITED KINGDOM','L232RH','07702290657','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-09 16:09:48',0,NULL,3,1,4,1,NULL,'英标 \r不控制重量了， 2.5kg以下就可以，包好点\rlight head  $20\rYW864870966CN\r'),(6059,749800727015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','hatititi','i.hatvani@hotmail.com','ifj. Hatvani Istvan','Alispan utca 70','Erd','Erd','HUNGARY','2030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 16:24:25',0,NULL,3,1,3,1,NULL,' RR843873679CN\r'),(6060,734823834016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:06',0,NULL,8,1,17,0,NULL,NULL),(6061,749812232015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:06',0,NULL,8,1,17,0,NULL,NULL),(6062,749808349015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',47,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-09 16:50:07',0,NULL,8,1,17,0,NULL,NULL),(6063,749803842015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 16:50:08',0,NULL,3,1,5,1,NULL,'2m 灯架  2\rb座   2\r柔光伞  2\r50-70 单灯头  棚   2  欧标\r45w    2\r气吹 + 布    1 \rCP226334885CN\r'),(6064,749828083015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.39,'hutongstore','the_dooku','k.bari@btconnect.com','Khalid Bari','5 Walsingham Close','Luton','Bedfordshire','UNITED KINGDOM','LU2 7AP','07939532123','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-09 17:18:44',0,NULL,3,1,2,1,NULL,NULL),(6065,644095632001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','dinoromano71','bernardinoromano@libero.it','AUSIELLO CARMINE','VIA NAZIONALE 372','TORRETTE DI MERCOGLIANO','AV','ITALY','83013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 18:08:09',0,NULL,3,1,2,1,NULL,'欧标 '),(6066,644134186001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','aneshravidas','anesh.r@telkomsa.net','Kamraj Ravidas','P.O.Box 516,Port Shepstone','South Africa','Kwazulu-Natal','SOUTH AFRICA','4240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 19:26:12',0,NULL,3,1,2,1,NULL,NULL),(6067,684312082002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','hilitkacoon11','hilitkacoon@gmail.com','hilit kacoon','nachal uriah 11/1<br>ramat beit shemesh','ramat beit shemesh','','ISRAEL','90945','029951456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 20:26:00',0,NULL,3,1,3,1,NULL,'分两个小包发 \rRR843873444CN\rRR843873461CN\r'),(6068,644176453001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',7.25,'hermeshine','bglytle','blytle@ups.com','Brooke Lytle','15 Ogden Ter','Butler','NJ','UNITED STATES','07405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-09 20:45:36',0,NULL,3,1,1,1,NULL,NULL),(6069,684350355002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','danywise','danieira2@hotmail.it','Daniele Grassi','via pellico 7/e','bareggio','MI','ITALY','20010','347-0404265','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 21:13:23',0,NULL,8,1,17,0,NULL,NULL),(6070,684349822002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',111.98,'hermeshine','danywise','danieira2@hotmail.it','Daniele Grassi','via pellico 7/e','bareggio','MI','ITALY','20010','347-0404265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 21:13:23',0,NULL,3,1,4,1,NULL,'斜臂   1\r闪光的柔光箱   60cm  2\rlight kit  $20\r YW864870955CN\r'),(6071,684358304002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','richardenbridge','edith.richard@enbridge.com','Edith Richard','289 Scout Street','Ottawa','ON','CANADA','K2C 4E7','(613) 792-4123','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,NULL),(6072,684370660002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 21:54:53',0,NULL,3,1,5,1,NULL,'CP226334810CN\r '),(6073,684328946002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','guitzai','sylvainguitz@hotmail.fr','Sylvain Guitz','6, rue francois pinton','Paris','Ile de France','FRANCE','75019','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-09 22:06:11',0,NULL,3,1,2,1,NULL,NULL),(6074,750014751015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',52,'hutongstore','sammie13584','samuli.miettinen@gmail.com','samuli miettinen','laajavuorenrinne 3 c 38','vantaa','Vantaa','FINLAND','01620','358405208834','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-09 22:27:39',0,NULL,3,1,4,1,NULL,'light kit  $20 \rYW864870944CN\r'),(6075,644240318001,110426879616,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',8.99,'hermeshine','slava-grebenkin','xyz100@mail.ru','Vyacheslav Grebenkin','Korpys 449, kv. 68','Moscow, Zelenograd','','RUSSIAN FEDERATION','124498','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-09 23:34:56',0,NULL,3,1,2,1,NULL,' '),(6076,684417029002,120570270785,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 00:11:14',0,NULL,8,1,17,0,NULL,NULL),(6077,684416824002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 00:11:15',0,NULL,8,1,17,0,NULL,NULL),(6078,684416903002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','varie001','jaidevwarrier@gmail.com','jaidev varieth','1401 red hawk cir<br>Apt M101','Fremont','CA','UNITED STATES','94538-4749','(205) 239-7852','NoPaymentFailure','CheckoutComplete','Other','2011-03-10 00:11:15',0,NULL,3,1,3,1,NULL,'2m 灯架   1\rb座    1\r柔光伞   1\r反光伞   1\rNG200     1 \rRR843873529CN\r'),(6079,684427686002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 01:00:40',0,NULL,3,1,3,1,NULL,' RR843873532CN\r'),(6080,644281729001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 02:14:42',0,NULL,8,1,17,0,NULL,NULL),(6082,644289320001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','Other','2011-03-10 02:50:39',0,NULL,3,1,1,1,NULL,' 67  UV     1     \rSF-18  SB900     1'),(6083,750107437015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 03:04:17',0,NULL,5,0,18,0,'jj ','bought by jiangang. No need for shipping'),(6084,644295205001,110534333114,'Green.L 72mm Neutral Density ND4 Filter 72 D90 D300s',1,'AE2306',7.3,'hermeshine','miniatures_on_jazz','cellaga@msn.com','conrad ellaga','60 laguna grande ct','monterey','CA','UNITED STATES','93940-4046','(831) 375-2912','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 03:10:06',0,NULL,3,1,1,1,NULL,NULL),(6085,683965761002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','Joanna Azevedo','Rua Carlos de Vasconcelos, n°148 apt 405','Rio de Janeiro','Rio de Janeiro','BRAZIL','20521-050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 03:20:49',0,NULL,3,1,3,1,NULL,' RR843873435CN\r'),(6086,684473910002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','esdrasrioosbr','esdrasrioos@gmail.com','Esdras Rios Baia','Rua Ataulfo Alves,30','Guarulhos','Sao Paulo','BRAZIL','0712150','551164085467','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 03:48:18',0,NULL,3,1,5,1,NULL,'申报 gift  $43 \r\r灯泡要110v的\rCP226334871CN\r'),(6087,644330603001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','zaldy101972','zlucillo@mcdermott.com','Zaldy Lucillo','Jebel Ali Freezone<br>Between 7th and 8th Roundabout','default','Dubai','UNITED ARAB EMIRATES','PO Box 3098','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 06:32:16',0,NULL,3,1,3,1,' RA117714074CN',' CP226334845CN\r重包一下,发两个小包\r背景架 2m宽的（ 白 黑） 1\rRA022497065CN\rRA022947159CN\r'),(6088,642862739001,110533632263,'New Timer Remote Control for Canon EOS 5DMarkII 40D 7D',3,'AA3222',137.7,'hermeshine','videograph903','videograph@e1.ru','Андрей Тюменцев','Repina, 80-148','Ekaterinburg','Sverdlovsk region','RUSSIAN FEDERATION','620043','+79221139762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 08:23:11',0,NULL,3,1,3,1,NULL,' RR843873603CN\r'),(6089,684525045002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','via4in1via4in1','killa_bee@mail.ru','Sergey Slobodenyuk','Kronshtadtskiy bulvar<br>House 23 Building 1 Flat 47','Moscow','','RUSSIAN FEDERATION','125493','+79647637482','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 08:36:31',0,NULL,3,1,3,1,NULL,'新地址：\r Dmitry Nikiforov\rSvobody Street, House 44, Flat 33\rChelyabinsk\rRussia\r454091\rRR843873563CN\r\r\r'),(6090,684532789002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','miles_tones','jvermie@tiscali.nl','Jerry Vermie','Plevier 95','Hoorn','The Netherlands','NETHERLANDS','1628EX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 09:13:50',0,NULL,3,1,2,1,NULL,NULL),(6091,750192903015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','philipqs','pdlmatthews@gmail.com','Philip Matthews','128 Rathgar Road<br>Rathgar','Dublin 6','Dublin','IRELAND','6','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 09:15:06',0,NULL,3,1,3,1,NULL,'RR843873585CN\r '),(6092,684495720002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',7.49,'hermeshine','frozyfrost','err0rfrost@gmail.com','Vladimir Kurganov','Sagymbaya<br>264-14','Bishkek','Bishkek','KYRGYZSTAN','720010','+996555323076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 09:53:55',0,NULL,3,1,3,1,NULL,'RR843873577CN\r '),(6093,684546290002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','assafk888','assafkonebay@gmail.com','Assaf Krintza','Pashosh<br>2','Nes Ziona','shfela','ISRAEL','70400','97289657852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 10:14:50',0,NULL,3,1,2,1,NULL,' '),(6094,750238443015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','where2b','nesmeryova@aol.com','George Talbot','17 Groom Crescent','Wandsworth','London','UNITED KINGDOM','SW18 3JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 11:50:12',0,NULL,3,1,2,1,NULL,NULL),(6095,644419254001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','khaliq.ahmad','p10past10@hotmail.com','Khaliq Ahmad','No.7, Spg 274, Kg. Lambak, Jln Pasir','Bandar Seri Begawan','','BRUNEI DARUSSALAM','BB2715','6738815945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 13:18:37',0,NULL,3,1,3,1,NULL,'RA022490969CN\r '),(6096,508942312003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',2,'AA3205',7,'hermeshine','cmfialho','cmsfialho@gmail.com','Carlos Fialho','Rua Joao Crisostomo de Sa, 9, RC-B','Queluz','','PORTUGAL','2745-030','+351918788231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 13:36:18',0,NULL,3,0,2,1,NULL,NULL),(6097,750289840015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1604',16,'hutongstore','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 14:24:36',0,NULL,3,0,3,1,NULL,'wf1003    1 \rRA022490986CN\r'),(6098,750295245015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','dyxopelnikow','dyxopelnikov@mail.ru','Духопельников Андрей','пос. Темерницкий, Степная 18, кв1','Ростов-на-Дону','','RUSSIAN FEDERATION','344114','89045010132','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 14:34:12',0,NULL,3,1,3,1,NULL,'RR843873489CN\r '),(6099,684611459002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','vitality-lv','cekc@cekc.lv','Vitalijs Kartupelis','Friedrich-Garves-Str. 2','Bremen','','GERMANY','28199','0049 1701793733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 14:45:34',0,NULL,3,1,2,1,NULL,NULL),(6100,644444713001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 14:46:10',0,NULL,8,1,17,0,NULL,NULL),(6101,644443536001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','kurilovden','red.fox@list.ru','Denis Kurilov','Novokosinskaya 27, 130','Moacow','Moscow','RUSSIAN FEDERATION','111673','9261552567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 14:52:47',0,NULL,3,1,2,1,NULL,NULL),(6102,644449151001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 15:00:17',0,NULL,3,1,6,1,NULL,'柔光箱 60-60cm  四灯头  1 \r灯架  2m   1\r斜臂       1\rEE389037515CN\r'),(6103,735310196016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','irina_ale26','kaktusmoy@hotmail.com','Irina Ale','2100 Cropsey Ave<br>Apt 4D','Brooklyn','NY','UNITED STATES','11214-6431','(347) 578-2643','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 15:19:30',0,NULL,3,1,4,1,NULL,'灯泡是110v的 \rlighting kit  $30\rYW864871025CN   '),(6104,644472449001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','sandyg211','sandy_goh88@yahoo.com.sg','Sandy Goh','Blk 212 Pasir Ris St 21<br>#06-234','default','','SINGAPORE','510212','+6593869837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 16:12:31',0,NULL,3,1,11,1,NULL,NULL),(6105,644480525001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','sotaventear','pedroteruel@hotmail.com','Pedro Teruel Molina','Avda. Santa Clara 15, Edf.Oasis 6-D','Lorca','Murcia','SPAIN','30800','670204207','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 16:35:25',0,NULL,3,1,2,1,NULL,NULL),(6106,644504473001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','kellyannimal','kellyannimal.ebay@gmail.com','kellyann creelman','2948 1/2 B St','San Diego','CA','UNITED STATES','92102-2212','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 17:37:00',0,NULL,3,1,1,1,NULL,NULL),(6107,684684989002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','pinartal','pina.artal.antonio@gmail.com','Antonio Pina Artal','Matilde Sangüesa, 26. 2ºB','Zaragoza','Aragón','SPAIN','50015','669273222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 17:53:57',0,NULL,3,1,2,1,NULL,NULL),(6108,644512765001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','sexycarmelqt','sexycarmelqt2c@gmail.com','Ashley Settles','2507 Farmcrest Dr #1228','HERNDON','VA','UNITED STATES','20171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 17:58:01',0,NULL,3,1,1,1,NULL,NULL),(6109,750397605015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','sokko-sasu','sasu.riikonen@gmail.com','Sasu Riikonen','Hämeenpuisto 40 A 23','Tampere','','FINLAND','33200','+358456711627','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-10 18:14:06',0,NULL,3,1,3,1,NULL,'RR843873492CN\r '),(6110,684696435002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','aod21ink','angelofdeath21ink@yahoo.com','Brandon Vickers','3109 Sheffield St','Irving','TX','UNITED STATES','75062-4316','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-10 18:20:15',0,NULL,3,1,4,1,NULL,'2m 灯架  红盒的   1\r红头灯  欧标转美标   1\r800w  110v     1 \rYW864871036CN\r'),(6111,644545497001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','pddl2010','uy.pablo@gmail.com','Pablo Diego','Uruguayana 3159','Montevideo','Montevideo','URUGUAY','11800','+59822042238','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 19:05:08',0,NULL,3,0,3,1,NULL,'xxl \rRA022496992CN\r'),(6112,750464518015,250599424460,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',1,'AA1308',1.88,'hutongstore','tonyfdrake','anthony@drake4.orangehome.co.uk','ANTHONY DRAKE','31 CAVENDISH AVENUE<br> NORTHUMBERLAND HEATH','ERITH ','Kent','UNITED KINGDOM','DA81EP','01322446855','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 20:02:05',0,NULL,3,1,2,1,NULL,NULL),(6113,684779826002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','micheldesouza','micheldsouza@gmail.com','Michel Souza UD - Ramal 320','Rua do Russel, 434 - 5º Andar<br>Gloria','Rio de Janeiro','RJ','BRAZIL','22210-010','(+55) 21 9653 3202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 21:08:06',0,NULL,3,1,3,1,NULL,'RR843873501CN\r'),(6114,644633600001,110580765864,'Background Support & Light Kit 3m x 6m 10 x 20 ft white',1,'AKT038',224,'hermeshine','leahubogdan','leahubogdan1@yahoo.com','leahu BOGDAN','cuza voda nr 31 ap 7','oradea','bihor','ROMANIA','410097','0040758069663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 22:11:03',0,NULL,8,1,17,0,NULL,NULL),(6115,644633941001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','zurlandskij','paronsuren@yahoo.com','Suren Manvelyan','16 block, house 42, app.44','Yerevan','Capital','ARMENIA','0048','+37491011613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 22:13:16',0,NULL,3,1,2,1,NULL,NULL),(6116,684795957002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oddjohan2004','odd.lundberg@odont.uib.no','Odd Johan Lundberg','Erdalsveien 41','Erdal','','NORWAY','5306','+4790192671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-10 21:42:13',0,NULL,3,1,2,1,NULL,NULL),(6117,644634418001,110568758656,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',199,'hermeshine','leahubogdan','leahubogdan1@yahoo.com','leahu BOGDAN','cuza voda nr 31 ap 7','oradea','bihor','ROMANIA','410097','0040758069663','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-03-10 22:12:26',0,NULL,3,1,5,1,NULL,'这个人还有一个大套，我没有列在这里\r用他的id 查一下吧，包在一起\r\r放欧标头 \rCP226334868CN\r'),(6118,684822011002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',4,'AO0014',31.6,'hermeshine','radioguy911','findyszh@aol.com','Harry Findysz','10032 E Eric Alan Pl','Tucson','AZ','UNITED STATES','85748','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-10 22:49:03',0,NULL,3,1,1,1,NULL,NULL),(6119,750564864015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','al_carphone','ar4z4@hotmail.com','Ali Raza','9 twinegate','Rochdale','Lancashire','UNITED KINGDOM','OL126dw','01706861325','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 23:06:56',0,NULL,3,1,3,1,NULL,'RR843873413CN\r'),(6120,735566964016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','eur0tic','ebay@haargel.nl','Wesley Evers','v.d. klugt wittemansingel 31','Poeldijk','','NETHERLANDS','2685 RV','+31624596996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 23:32:12',0,NULL,8,1,17,0,NULL,NULL),(6121,735567571016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ctracey2006','chrismxtracey@yahoo.co.uk','christopher tracey','Concept Engineering Ltd<br>33 Wiltshire Road,Dairycoats industrial Estate','Hull','East yorkshire','UNITED KINGDOM','HU4 6PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-10 23:33:33',0,NULL,3,1,2,1,NULL,NULL),(6122,750576196015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','eur0tic','ebay@haargel.nl','Wesley Evers','v.d. klugt wittemansingel 31','Poeldijk','','NETHERLANDS','2685 RV','+31624596996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-10 23:38:30',0,NULL,3,1,4,1,NULL,'斜臂   1\r反光板支架    1 \rlight stand  $20\rYW864871040CN'),(6123,684838189002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',7.25,'hermeshine','dgator002','gator002@tampabay.rr.com','David Bennett','13559 Andova Dr','Largo','FL','UNITED STATES','33774-4634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-10 23:44:06',0,NULL,3,1,1,1,NULL,NULL),(6124,644664090001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','jerryjerko2010','arnyc26@hotmail.com','Jerko Jalsovec','Augusta Senoe 29 Senkovec','Cakovec','Cakovec','CROATIA','40000','00385-91-721-5298','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-10 23:51:50',0,NULL,3,1,5,1,NULL,'申报  gift   $20 \rCP226334854CN\r'),(6125,684868415002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','serch48antonio','sergio1234x@hotmail.com','antonio talamantes','solidaridad 66<br>av.zapata 142','yautepec','morelos','MEXICO','62730','7351606104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:02:38',0,NULL,3,1,3,1,NULL,'RR843873475CN\r'),(6126,684877311002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','juangarg','juancruzgaligniana@yahoo.com.br','juan cruz galigniana','rua vitorio sbalqueiro<br>nº 60, casa 03. Bairro Vista Alegre','curitiba','Paraná - Curitiba','BRAZIL','82100-060','55-41-33592241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 02:09:42',0,NULL,3,1,2,1,NULL,NULL),(6127,644701953001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:20:16',0,NULL,3,0,3,1,NULL,'XXL \rRR843873594CN\r'),(6128,644704379001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','christianbernier','info@drakkar.com','Christian Bernier','7628, rue Saint-Dominique','Montréal','QC','CANADA','H2R 1X5','(514) 272-4132','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 02:32:26',0,NULL,3,1,3,1,NULL,'RA022490972CN\r '),(6129,644714862001,110583278510,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'AA2313',7.9,'hermeshine','idansr1981','idansr@gmail.com','Idan Tzror','Vaizman Haim 49','Holon','','ISRAEL','58380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 03:10:21',0,NULL,5,0,18,0,NULL,''),(6130,644766055001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','iamlado','vorobyevvladimir@mail.ru','Vladimir Vorobyev','Mira 34/1 kv.11<br>tel +7 (701) 747-69-20','Astana','Aqmola obl','KAZAKHSTAN','010000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 08:55:23',0,NULL,3,1,3,1,NULL,' RA022490120CN\r'),(6131,684962252002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','alahomoca','zeljko.jurcic@inet.hr','Zeljko Jurcic','Cernik 18','Cavle','','CROATIA','HR - 51219','00385915142655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 09:10:58',0,NULL,3,1,2,1,NULL,NULL),(6132,750739434015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','littlemush','john.bardon@virgin.net','John Bardon','36, Mickleton Close<br>Templetown','Consett','Durham','UNITED KINGDOM','DH87UG','01207588168','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 09:56:23',0,NULL,3,1,2,1,NULL,NULL),(6133,684989911002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','nekto49','king50@012.net.il','Andrei Vasilenko','Livorno 7/23','Bat Yam','','ISRAEL','59646','0546861300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 11:17:03',0,NULL,3,1,2,1,NULL,NULL),(6134,735779697016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','wojtekturbak','w_turbak@wp.pl','Wojciech Turbak','39 The Orchard Way<br>Greenwood Walk','Ayrefield','Dublin','IRELAND','D13','862494971','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-11 12:57:00',0,NULL,3,1,3,1,NULL,' RA022490116CN\r'),(6135,685015348002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','geoffrey7937','gward@iinet.net.au','geoffrey ward','15 corring way-parmelia','perth','Western Australia','AUSTRALIA','6167','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 13:01:12',0,NULL,3,0,3,1,NULL,'XXXL RA022490323CN\r'),(6136,750550023015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','choang2603','choang263@gmail.com','Duc Hoang','92<br>Waddon Road','Croydon','London','UNITED KINGDOM','CR04JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 15:03:05',0,NULL,3,1,2,1,NULL,NULL),(6137,644864006001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','xkarolinevendraminix','karolinevendramini@hotmail.com','Karoline Vendramini','Avenida Joao Bonicenha Numero 6 Quadra 49','Linhares','Espirito Santo','BRAZIL','29905-110','55 27 99215068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 15:16:41',0,NULL,3,1,2,1,NULL,'\r '),(6138,644892156001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','scx21','pic.noir@free.fr','Caux Sylvie','7 rue Cazotte','Dijon','Bourgogne','FRANCE','21000','0682593568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 16:41:04',0,NULL,3,1,2,1,NULL,NULL),(6139,644905210001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','bird_3075','leprochor@post.cz','Jiri Ptacnik','Sechov 16','Ledec nad Sazavou','','CZECH REPUBLIC','58401','(0420)776156300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 17:14:38',0,NULL,3,1,2,1,NULL,NULL),(6140,750901112015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','starmaroon','lelapskilo@yahoo.com','EMMANOUIL LOURAKIS','1st Welligton street','CHANIA','','GREECE','73131','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-11 17:18:08',0,NULL,3,1,2,1,NULL,NULL),(6141,685114635002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','kriasp0047','morten.aspaas@sbnett.no','Morten Aspaas','Nausthågen','Ulvsvåg','','NORWAY','8276','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 17:51:39',0,NULL,3,1,3,1,NULL,' RA022490195CN\r'),(6142,644921717001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:04:21',0,NULL,3,1,5,1,NULL,' Valery Nikiforov\rg.Nurlat ul.Karla Marx, 48 kv.1\rTatarstan,423040\rRussia\rCP226334939CN\r王明明\rrimakbud2009'),(6143,681477879002,120601700533,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','bbohnet716','bbohnet18@gmail.com','Brandon Bohnet','4423 109 A Avenue','Edmonton','AB','CANADA','T6A 1S3','(178) 071-6823 ext.: 5','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:07:11',0,NULL,7,0,18,0,NULL,NULL),(6144,644770923001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','flyfin_ru','flyfin.ru@gmail.com','Ekaterina Karaseva','Solnechnaya Polyana<br>D. 21 KV. 123','Barnaul','Altayskij kraj','RUSSIAN FEDERATION','656060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 18:07:29',0,NULL,3,1,5,1,NULL,'2m 灯架 2个\rCP226334925CN\r\r刘杰 flyfin_ru'),(6145,644927384001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:08:25',0,NULL,8,1,17,0,NULL,NULL),(6146,685124054002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','mycbr400','cbr400@skatemalaysia.com','Wan Muhammad Aznan','Unit 45-0-4, Sri Jelatek,<br>Wangsa Maju, Section 10','Kuala Lumpur','Kuala Lumpur','MALAYSIA','53300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:14:05',0,NULL,3,1,2,1,NULL,NULL),(6147,641166249001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jweg01','j.gilbert@unb.ca','John Gilbert','2 Conc. 6','Chepstow','ON','CANADA','N0G 1K0','(519) 901-2190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 18:30:15',0,NULL,7,0,18,0,NULL,NULL),(6148,640775018001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 19:04:16',0,NULL,8,1,17,0,NULL,NULL),(6149,680838111002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',54,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:04:16',0,NULL,8,0,17,0,NULL,NULL),(6150,680837849002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',76.9,'hermeshine','lady_chemicalxx','ladyxxchemical@gmail.com','Vania Stockwell','9 Karanya Street<br>Mount Louisa','Townsville','Queensland','AUSTRALIA','4814','0432872716','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-11 19:06:13',0,NULL,3,0,4,1,NULL,'lady_chemicalxx\r3mx6m白色背景布  1\r1.6x3m 背景布  3 白黑灰\r反光板支架  1\r王\rYW864871456CN'),(6151,644969819001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','romang123','rva70024@bigpond.net.au','Roger Van Gramberg','156 Explorers Way','St Clair','New South Wales','AUSTRALIA','2759','0298342085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:40:18',0,NULL,8,1,17,0,NULL,NULL),(6152,644969455001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','romang123','rva70024@bigpond.net.au','Roger Van Gramberg','156 Explorers Way','St Clair','New South Wales','AUSTRALIA','2759','0298342085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 19:40:19',0,NULL,3,1,2,1,NULL,'橡胶遮光罩 58mm  1\r橡胶遮光罩 67mm  1\r '),(6153,685167956002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','batatinharj10','batatinharj@gmail.com','André Cysne','Rua Comandante Cordeiro de Faria 40<br>Maracanã','Rio de Janeiro','Rio de Janeiro','BRAZIL','20271-000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 19:49:19',0,NULL,3,1,3,1,NULL,' RA022490204CN\r'),(6154,749345982015,250599921846,'New 52mm 52 Ring adapter and Holder for Cokin P Series ',1,'AKT018',9.17,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-11 19:57:30',0,NULL,3,0,3,1,NULL,'52mm 接口环  2\r托架  1\r52mm nikon 反接环   1 \rRA022490399CN\r'),(6155,685197255002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','mitokondrium0621','koszegi89@gmail.com','Tamás Kőszegi','Vajda János utca 25','Velence','Fejér megye','HUNGARY','2481','36307180472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 20:53:50',0,NULL,3,1,2,1,NULL,NULL),(6156,685216059002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','jcol2694','jmcolomina@gmail.com','JOSE M COLOMINA','C/ COSTA I LLOBERA 126, 2º','INCA','Baleares','SPAIN','07300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 21:35:20',0,NULL,3,1,2,1,NULL,NULL),(6157,685216654002,120601699795,'New 3 filters & Ring holder set 4 Cokin System P Series',1,'AKT026',22.8,'hermeshine','davivan3011','dvimar@hotmail.es','MotorCartagena S.LConcesionario FIAT','C/ Stª Florentina,nº 1- Media Sala<br>A/A. Damian Vivancos Martinez','Cartagena','Murcia','SPAIN','30310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-11 21:37:35',0,NULL,3,1,3,1,NULL,' RA022490385CN'),(6158,645044606001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','rdyk4033','dykstra1114@yahoo.com','Ron Dykstra','524 S 94th St','Tacoma','WA','UNITED STATES','98444','(253) 212-1600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-11 22:42:29',0,NULL,3,1,1,1,NULL,NULL),(6159,685260920002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','rimakbud2009','rimakbud@gmail.com','Rimma Akbudak','Chernyshevsky 49-58','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423465','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-11 23:51:47',0,NULL,3,1,3,1,NULL,'爵影5和1       1  \r100 150        1  \rRA022490252CN\r'),(6160,685276452002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hgarcia470','hgarcia470@hotmail.com','Hilda Garcia','10915 Seguro Dr','Chatsworth','CA','UNITED STATES','91311-1945','(818) 832-9427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 00:54:52',0,NULL,8,1,17,0,NULL,NULL),(6161,685276201002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hgarcia470','hgarcia470@hotmail.com','Hilda Garcia','10915 Seguro Dr','Chatsworth','CA','UNITED STATES','91311-1945','(818) 832-9427','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 00:54:52',0,NULL,3,1,1,1,NULL,'CANON 镜头盖  58mm  2 '),(6162,685272155002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','haakonjack','haakon.jack@gmail.com','Ruxandra Balcangiu','La scuola di Pitagora s.r.l.<br>1. Piazza Santa Maria degli Angeli','Napoli','','ITALY','80132','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 01:07:13',0,NULL,3,1,3,1,NULL,' RA022490297CN\r'),(6163,645117296001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.5,'hermeshine','reinym10','reinym@gmail.com','Dame Reiny E. Manalu','Tebet Timur Dalam V No.27<br>Jakarta Selatan','DKI Jakarta','DKI Jakarta','INDONESIA','12820','(62)816-1343179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 03:52:19',0,NULL,3,1,2,1,NULL,NULL),(6164,645118567001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','r0msman','jerivalu@gmail.com','Jeremy Cole','16637 Foothill Blvd<br>Apt 305','Sylmar','CA','UNITED STATES','91342-1484','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 03:58:02',0,NULL,3,1,1,1,NULL,'canon的镜头盖 '),(6165,645121769001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','lowe5954','leroyowens61@gmail.com','Leroy Owens','5672 Dashshund Ct','columbus','OH','UNITED STATES','43232-7506','(614) 833-4508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-12 04:29:38',0,NULL,3,1,1,1,NULL,' '),(6166,751175448015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',6.1,'hutongstore','chopface1963','topsparks.42@tiscali.co.uk','John Holland','8 Churchside close<br>Biggin Hill','Westerham','Kent','UNITED KINGDOM','TN16 3QF','01959540933','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 04:35:24',0,NULL,3,1,2,1,NULL,NULL),(6167,685350693002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:20:27',0,NULL,8,1,17,0,NULL,NULL),(6168,645150893001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 07:23:14',0,NULL,8,1,17,0,NULL,' '),(6169,685365353002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','fotoz09','zubpho@yahoo.com','zubeyr kureemun','7A, Paul et Virginie Street','Port-Louis','Port-Louis','MAURITIUS','00230','(230) 7683969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 08:37:18',0,NULL,3,1,2,1,NULL,NULL),(6170,751267952015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.28,'hutongstore','efwube','simen@simen.nazwa.pl','HS-TOPP  F H Wojciech Surma','Os. 1000 lecia 1a/9','Stargard Szczecinski','zachodniopomorskie','POLAND','73-110','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 10:53:30',0,NULL,3,1,2,1,NULL,NULL),(6171,685402950002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','arnaud6794','arnaud94@gmail.com','Arnaud  CHOQUART','7 rue de Choisy','ALFORTVILLE','Île-de-France','FRANCE','94140','01.43.78.18.77','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:10:14',0,NULL,3,1,2,1,NULL,NULL),(6172,685414359002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dmitriy7','contact@bukhonov.com','Dmitriy Bukhonov','59 ap. 51, Novo Uglichskaya str.','Sergiev Posad','Moscow','RUSSIAN FEDERATION','141300','+79261126412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:51:38',0,NULL,3,1,2,1,NULL,NULL),(6173,645212390001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:37',0,NULL,8,1,17,0,NULL,NULL),(6174,685413022002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 11:53:38',0,NULL,8,1,17,0,NULL,NULL),(6175,645211710001,110534333419,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:38',0,NULL,8,1,17,0,NULL,NULL),(6176,685413161002,120548351820,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','ulldedeu','ulldedeu@yahoo.es','MART GALLEGO GALIANO','POL. INDUSTRIAL CAN BROS<br>CAMI CAN BROS S/N NAVES 4-5','MARTORELL','Barcelona','SPAIN','08760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 11:53:39',0,NULL,3,1,4,1,NULL,'爵影红外 5 in 1  1\r2m 灯架   1\r单灯头  欧标   1\r反光伞   1 \r柔光伞   2\r115w 5500k 灯泡  220v   1\rphotography acc  $28\rYW864871084CN\rulldedeu\r'),(6177,685438295002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','2011kenhje','kenhje@gmail.com','Kenneth Hjelle','Beregsveien1b','Skodje','møre og romsdal','NORWAY','6260','40032801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 13:15:07',0,NULL,3,1,3,1,NULL,' RA022497573CN'),(6178,645254411001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','kikepereira','kike.pereira@gmail.com','Luis Pereira','Rua Pedro Franco N251','Cascais','Lisboa','PORTUGAL','2750-262','915385446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 14:09:17',0,NULL,3,1,2,1,NULL,NULL),(6179,751342158015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','antonis7161','antonis1610@cytanet.com.cy','Antonis Menelaou','2A  Andrea Miaouli St. <br>Meneou','Larnaca','','CYPRUS','7000','0035799585621','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-12 14:19:55',0,NULL,3,0,3,1,NULL,'如果不能控制在2kg以下，通知我 \rRA022490266CN\r'),(6180,645266223001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','bentebakken','smallbangweb@hotmail.com','Bente Bakken','Håkon Magnussons gate 3c','Trondheim','Trondheim','NORWAY','7041','47 91856220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:44:44',0,NULL,3,1,2,1,NULL,NULL),(6181,645269950001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','chlimallan2009','chlimallan@yahoo.com.sg','Allan lim','Block 163 Toa Payoh Lorong 1<br>#09-1014','default','','SINGAPORE','310163','94576931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:56:24',0,NULL,8,1,17,0,NULL,NULL),(6182,685471389002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','chlimallan2009','chlimallan@yahoo.com.sg','Allan lim','Block 163 Toa Payoh Lorong 1<br>#09-1014','default','','SINGAPORE','310163','94576931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 14:56:25',0,NULL,3,1,3,1,NULL,'中号内胆包 canon   1 \r方形滤镜接口环 72mm  1\r方形滤镜 镜片卡座  1\rRA022490408CN\r'),(6183,645287253001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','strekov-k','strekovk@gmail.com','Kirill Strekov','Bulvar-Pobedi st. 43-286','Voronezh','Voronezhskaja oblast\'','RUSSIAN FEDERATION','394088','+79616133138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:43:11',0,NULL,8,1,17,0,NULL,NULL),(6184,685490386002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','strekov-k','strekovk@gmail.com','Kirill Strekov','Bulvar-Pobedi st. 43-286','Voronezh','Voronezhskaja oblast\'','RUSSIAN FEDERATION','394088','+79616133138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:43:11',0,NULL,3,1,2,1,NULL,'橡胶遮光罩 55mm  1 \r爵影红外 sony  1'),(6185,685111715002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','giacomo6013','giasab@infinito.it','Giacomo Sabatini','viale Gabriele D\'Annunzio, 238','Pescara','PE','ITALY','65127','085-65549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 15:46:05',0,NULL,3,1,2,1,NULL,NULL),(6186,645323070001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',61,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:08:18',0,NULL,8,1,17,0,NULL,NULL),(6187,685528503002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',79.76,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:09:43',0,NULL,8,1,17,0,NULL,NULL),(6188,645324600001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:10:57',0,NULL,8,1,17,0,NULL,NULL),(6189,645325261001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:12:20',0,NULL,8,1,17,0,NULL,NULL),(6190,645327146001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:16:38',0,NULL,8,1,17,0,NULL,NULL),(6191,645327335001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','partyser2009','fabien.dejongdehaas@gmail.com','fabien de jong de haas','jan teulingslaan 58','amstelveen','','NETHERLANDS','1187 sk','06-55852668','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 17:17:00',0,NULL,3,1,4,1,NULL,'背景架 白 黑\rbackground support  $20   \rYW864871073CN\r\r\r刘杰\rpartyser2009'),(6192,736393484016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:48',0,NULL,8,1,17,0,NULL,NULL),(6193,751429111015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',7.8,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:49',0,NULL,8,1,17,0,NULL,NULL),(6194,751430350015,250692242207,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.68,'hutongstore','bikersir','kroome@yahoo.co.uk','karl roome','12, pollard lane','leeds','West Yorkshire','UNITED KINGDOM','LS131EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:18:49',0,NULL,3,1,3,1,NULL,'方形滤镜接口环 67mm  1\r方形滤镜 镜片卡座  1\r天涯方形滤镜系列  星光镜  star6  1\r橡胶遮光罩 67mm   1\rRA022490371CN\r\r '),(6195,736399523016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','c1bassuk','icornwell@vodafone.net','Ian Cornwell','Unit 15 Silvercourt<br>Intercity Way','Leeds','West Yorkshire','UNITED KINGDOM','LS13 4LY','07525248889','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:26:49',0,NULL,3,1,3,1,NULL,' RA022490354CN\r'),(6196,645327816001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','elpoldo','paolocolucci.el@gmail.com','paolo colucci','via principe antonio de curtis n°24','mottola','TA','ITALY','74017','3355944948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:18:12',0,NULL,3,1,4,1,NULL,'反光板支架  2\r反光板 100*150 40*60 5合1  2\r斜臂   1\r橡胶遮光罩 58mm   1\r柔光箱 50-70cm 单灯头 欧标   1\r115w 5500k 灯泡  220v  1\r庄海f峰\relpoldo\rYW864871062CN\r\r\r\r '),(6197,736408877016,260660051690,'Neoprene Lens Pouch Case 9.5cmx23cm 80-200 70-200mm XL',1,'AC1204',4.38,'hutongstore','christobella','christobella@hotmail.co.uk','Chris Lewis','7 The Terrace<br>Creigiau','Cardiff','S Glam','UNITED KINGDOM','CF15 9NG','07980157239','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:37:16',0,NULL,3,1,2,1,NULL,NULL),(6198,751446109015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','beradi1','radoslaw.bednarczyk@btinternet.com','radek bednarczyk','schepherds court 13','banchory','Aberdeenshire','UNITED KINGDOM','ab31 5tg','01330825926','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 17:42:20',0,NULL,3,0,2,1,NULL,'1.6x2.1 白色 '),(6199,685546561002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','mco471','phone-city@hotmail.co.uk','Marco Lopez','Lillevångsgatan 12','Simrishamn','Skåne','SWEDEN','27232','0414-16197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:48:12',0,NULL,3,1,2,1,NULL,NULL),(6200,685546961002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','cuda-k','kaur-@hotmail.com','Kaur Mölder','Elva 10-2','Tartu','','ESTONIA','50404','+37255542044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 17:48:56',0,NULL,3,1,2,1,NULL,NULL),(6201,645356154001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 18:16:02',0,NULL,8,1,17,0,NULL,NULL),(6202,685564347002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariyavoron','vmotom@sibmail.com','Mariya Voronina','pereulok Ovrazhniy, dom 22, kvartira 121<br>pereulok Ovrazhniy, dom 22, kvartira 121','Tomsk','Russian Federation','RUSSIAN FEDERATION','634021','8-913-860-9900','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 18:27:14',0,NULL,8,1,17,0,NULL,NULL),(6203,685568405002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mariyavoron','vmotom@sibmail.com','Mariya Voronina','pereulok Ovrazhniy, dom 22, kvartira 121<br>pereulok Ovrazhniy, dom 22, kvartira 121','Tomsk','Russian Federation','RUSSIAN FEDERATION','634021','8-913-860-9900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 18:37:02',0,NULL,3,1,3,1,NULL,'反光板 100*150 40*60 5合1  1\rlenspen   1 \rRA022490337CN\r'),(6204,645383876001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','guinanet','guinanet88@hotmail.com','Guilherme Camargo','Av. Sapopemba, 8175<br>Jardim Sapopemba','Sao Paulo','São Paulo','BRAZIL','03988-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 19:10:07',0,NULL,3,1,3,1,NULL,' RA022490345CN\r'),(6205,645388990001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','richardhdez','siomsiom@yahoo.es','Ricardo Hernández Arrondo','Avenida Madrid 226 5-D','Zaragoza','Aragón','SPAIN','50017','652200618','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 19:18:33',0,NULL,3,1,3,1,NULL,'RA022490218CN\r '),(6206,736492741016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','nikal01','inkal00@hotmail.com','Nikos Kalpakidis','(TEL. 6946289780)<br>Leoforos Hatzikyriakou 104','Pireaus','','GREECE','18538','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-12 19:51:13',0,NULL,3,1,2,1,NULL,NULL),(6207,751555365015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','judetheob','bcrowcro@gmail.com','Brian Crowcroft','33 Redhill Heights<br>Glasshoughton','Castleford','Yorkshire','UNITED KINGDOM','WF10 4TJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-12 20:35:52',0,NULL,3,1,2,1,NULL,NULL),(6208,645435747001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','pdem2309','nagia.d@hotmail.com','Naya Demetriou','36 Chaucer Court New Dover road','Canterbury','Kent','UNITED KINGDOM','CT13AU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 20:55:13',0,NULL,3,1,2,1,NULL,NULL),(6209,645447365001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','tataferchis','ivetestradas@hotmail.com','Ivet Estrada','Morelos Sur 1019 Colonia Constituyentes','Tehuacán','Puebla','MEXICO','75710','1246677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-12 21:23:13',0,NULL,3,1,3,1,NULL,' RA022490249CN\r'),(6210,645453340001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','gook90','kristian280@hotmail.com','Kristian Hansen','Langerødødegården','Svinndal','Østfold','NORWAY','1593','92642977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:36:30',0,NULL,3,1,2,1,NULL,NULL),(6211,645449582001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','bigbear0072010','ian.cullimore@talktalk.net','Ian Lynton Cullimore','89 Catesby Road<br>Hillmorton','Rugby','Warwickshire','UNITED KINGDOM','CV22 5JL','01788572011','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-03-12 21:40:25',0,NULL,3,1,2,1,NULL,NULL),(6212,645459017001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:24',0,NULL,8,1,17,0,NULL,NULL),(6213,645458672001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:25',0,NULL,8,1,17,0,NULL,NULL),(6214,645458888001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.5,'hermeshine','oyadgar','oyadgar@gmail.com','Omer Yadgar','Pri Megadim 17<br>apt 2','Maale Adommim','','ISRAEL','98480','972528880662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:52:26',0,NULL,3,1,2,1,NULL,'绿叶 UV  58mm  1 \r绿叶 UV  67mm  1\r绿叶 UV  77mm  1'),(6215,685664301002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','sancy77','sancy@datatrans.hu','Sandor Farkas','Csokonai utca 10.','Szekesfehervar','','HUNGARY','8000','+36-20-955-8890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 21:57:03',0,NULL,3,1,3,1,NULL,' RA022490164CN\r'),(6216,645466671001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','roigazit1','roigazit@gmail.com','roi gazit','arlozorov 80','haifa','haifa','ISRAEL','33276','054-673-5209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:11:02',0,NULL,3,1,2,1,NULL,NULL),(6217,751613883015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','stanleys8a9f','stanleys@home.se','Stanley Sjogren','Norra Krokslattsgat 12','Goteborg','','SWEDEN','41264','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-12 22:21:10',0,NULL,3,1,3,1,NULL,' RA022490235CN\r'),(6218,685690554002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','glenn650g','leono000@planet.nl','GMA Leonora','Willemstraat 1','Sneek','','NETHERLANDS','8601 GH','0515432778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-12 22:52:38',0,NULL,3,1,2,1,NULL,NULL),(6219,645478182001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','joaovictorinacio','joao.victor.inacio@gmail.com','João Pereira','Rua Prof Assis Goncalves 1326 Apt 201<br>Água Verde','Curitiba','Paraná','BRAZIL','80620-250','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-12 22:55:26',0,NULL,3,1,2,1,NULL,NULL),(6220,683159313002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','1hectornoel','estudio505@gmail.com','HECTOR RAMOS','VILLA GRANADA<br>ALAMEDA 937','SAN JUAN','PR','UNITED STATES','00924','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,' 649\rRA022490796CN'),(6221,685678303002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','tlqman','jhbray62@ssvecnet.com','James Bray','6275 S Moson Rd','Hereford','AZ','UNITED STATES','85615','(520) 378-5186','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 01:40:23',0,NULL,3,1,1,1,NULL,NULL),(6222,685775188002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','borggu-11','borggu@gmail.com','Timo Spårman','Karvarinaukio  14 A','Oulu','Suomi  Oulu','FINLAND','90650','0408137171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 04:09:44',0,NULL,3,0,3,1,NULL,'XL RA022490221CN'),(6223,685805262002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 06:55:42',0,NULL,3,1,3,1,NULL,' RA022490306CN\r'),(6224,751764899015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',3.82,'hutongstore','sonerics','isakov.spb@gmail.com','Igor Isakov','ul. Zheleznodorozhnaya<br>d.22, kv.63','Otradnoe','Leningradskaya obl','RUSSIAN FEDERATION','187330','+79046174476','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-13 07:08:14',0,NULL,3,1,2,1,NULL,NULL),(6225,685824451002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','zrafal78','rafalzajda@gmail.com','RAFAL ZAJDA','BASEMENT STUDIO FLAT<br>197 BATH ROAD','CHELTENHAM','Gloucestershire','UNITED KINGDOM','GL53 7LZ','07955481556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 08:25:38',0,NULL,3,1,2,1,NULL,NULL),(6226,645608056001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','gfcodo','gianfrancocod@tiscali.it','Gianfranco    Codognotto','Senofonte 16','Baruccana di Seveso - MB','MI','ITALY','20822','3289646230','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 08:34:19',0,NULL,3,0,3,1,NULL,'XXXL \rRA022495042CN\r'),(6227,685859871002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','raimax20','raimaxas@gmail.com','Raimondas Kazlauskas','Ramuniu g. 9<br>Aukstelke','Siauliai','Siauliai region','LITHUANIA','80180','+37067574850','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 10:12:26',0,NULL,3,1,3,1,NULL,' RA022490283CN\r'),(6228,685892171002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 11:37:15',0,NULL,8,1,17,0,NULL,NULL),(6229,645681656001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','r1cc4rd0','r.ongaro@libero.it','riccardo ongaro','via quintino alto 38','bergamo','BG','ITALY','24123','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 12:09:28',0,NULL,3,1,4,1,NULL,'反光板 100*150 40*60 5合1  1\r反光板支架    1\rreflector $20\r一票两件\r\rr1cc4rd0\rYW864871106CN\r\r'),(6230,645693733001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','xlorian10','jiannis1@mail.com','jiannis chloros','oik. eksikonomou 38','larisa','','GREECE','41223','0030 6948262304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 12:25:59',0,NULL,3,1,2,1,NULL,NULL),(6231,751911595015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','kjiva1','kjellivar.mortensen@gmail.com','Kjell Ivar Mortensen','Tverrmoen 9','default','Nodeland','NORWAY','4645','004792080545','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-13 12:52:01',0,NULL,3,1,3,1,NULL,' RA022490270CN\r'),(6232,685929540002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','652volk','volk652@yandex.ru','Валерий Карпов','Сакко 37б 93','Иваново','Ивановская','RUSSIAN FEDERATION','153012','+79023167509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 13:14:59',0,NULL,3,0,3,1,NULL,'1.6m x  3m 黑色背景布   1 \rRA022490178CN\r'),(6234,685814136002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',106.9,'hermeshine','spv_x007','spvmail@mail.ru','Pavel Stasenko','Gagarina 3-45','Zelenogorsk','Krasnoyarsky kray','RUSSIAN FEDERATION','663690','+79233724020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 14:42:25',0,NULL,3,1,5,1,NULL,'背景架 2m   1\r1.6mx3m 背景布  3（白 黑 灰） \rCP226334911CN\r\r刘杰 spv_x007'),(6233,685965545002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','popycock','jgundie@cox.net','James Gundersen','1375 Cerritos Dr','Laguna Beach','CA','UNITED STATES','92651-2816','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 14:24:48',0,NULL,3,1,1,1,NULL,NULL),(6235,645150600001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',53.68,'hermeshine','sane41k','roldugin.alex@gmail.com','Victoria Zemlyanskaya','Krasnoarmeyskaya str. dom 37- kvartira 85','Sochi','Krasnodarskiy kray','RUSSIAN FEDERATION','354065','79180007571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 14:46:56',0,NULL,3,0,3,1,NULL,'天涯 cpl 52mm  1\r天涯 cpl 58mm  1\rlenspen   1\r52-58mm  双阳环  1\rcanon-58mm 反接环  1\r50cm 棚  1\r倒影板    1\rRA022490368CN\r\r\r '),(6236,752004293015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','lynx123cats','heavendesigns7th@aol.com','LYN MITCHELL','4 CASTLE WALK','EGREMONT','Cumbria','UNITED KINGDOM','CA22 2BY','01946824747','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 15:42:55',0,NULL,3,1,2,1,NULL,NULL),(6237,686010136002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',9.25,'hermeshine','cheec_l','rku294@freescale.com','Chee Choy Liew','51, Jalan BU 7/3 Bandar Utama,','Petaling Jaya','Selangor','MALAYSIA','47800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 15:49:38',0,NULL,3,1,2,1,NULL,NULL),(6238,645803615001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','ammaabba','k_mahmood20@yahoo.com','KHALED MAHMOOD','1/20-22 BRANDON AVE','BANKSTOWN','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 16:13:26',0,NULL,8,1,17,0,NULL,NULL),(6239,645806263001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','ammaabba','k_mahmood20@yahoo.com','KHALED MAHMOOD','1/20-22 BRANDON AVE','BANKSTOWN','New South Wales','AUSTRALIA','2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 16:17:11',0,NULL,3,1,2,1,NULL,NULL),(6240,752107287015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',73,'hutongstore','martar1933','mariatarallo@rocketmail.com','maria fionda','Via Liguria 56<br>Sacile','(Pordenone)','PN','ITALY','33077','0434733131','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-13 17:32:03',0,NULL,3,1,4,1,NULL,'欧标 \rlighting kit  $28\rYW864871110CN\r\r\r刘杰\rmartar1933'),(6241,686079543002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','anthony_william','tonybainbridge1@googlemail.com','anthony bainbridge','Oakend<br>Bridge Close','Byfleet','Surrey','UNITED KINGDOM','KT147DE','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 17:36:16',0,NULL,3,0,3,1,NULL,'XXL \rRA022490155CN\r'),(6242,645881280001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','519stasiu','stan.ela@3web.net','Stanislaw Sokolowski','301 General PL','Kitchener','ON','CANADA','n2k 3v5','(519) 568-7676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 17:58:35',0,NULL,3,1,2,1,NULL,NULL),(6243,645961561001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mdwalters120157','mdwalters.sr@gmail.com','Michael Walters','1710 Viking Dr','Houston','TX','UNITED STATES','77018-1819','','NoPaymentFailure','CheckoutComplete','Other','2011-03-13 19:15:28',0,NULL,3,1,3,1,NULL,' RA022490181CN\r'),(6244,645975527001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','matset1966','mat_set@mail.ru','Sergey Matyuhevich','Vesennaya 3 75<br>Ferma','Sergiev Posad','Moscow region','RUSSIAN FEDERATION','141307','+79031906811','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:36:51',0,NULL,3,1,2,1,NULL,NULL),(6245,645972362001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',3,'AB2208',16.8,'hermeshine','christianvinces','vinceschristian@gmail.com','christian vinces','CALLE PASTOR SEVILLA 197 CHORRILLOS','LIMA','LIMA','PERU','LIMA 09','511999085143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 19:39:08',0,NULL,8,1,17,0,NULL,' '),(6246,645973642001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',2,'AB2401',27.98,'hermeshine','christianvinces','vinceschristian@gmail.com','christian vinces','CALLE PASTOR SEVILLA 197 CHORRILLOS','LIMA','LIMA','PERU','LIMA 09','511999085143','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:39:07',0,NULL,3,1,3,1,NULL,' GGS  3.0       3     \r90周年镜头筒   2 \rRA022490133CN'),(6247,752267741015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','gulpedalive','paulybear1956-ebay@yahoo.co.uk','Mr P Elvidge','80 Harcourt Drive','Harrogate','North Yorkshire','UNITED KINGDOM','HG1 5AB','01423561777','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 19:41:03',0,NULL,3,1,2,1,NULL,NULL),(6248,686213048002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','matisko2006','mmatisko@pronet.sk','Milan Matisko','Moyzesova 56','Lucenec','','SLOVAK REPUBLIC','98401','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 19:45:23',0,NULL,3,1,5,1,NULL,'欧标  背景布是1.6x2.1白色 \rCP226334908CN\r加一个反光板支架\r\r庄海峰 matisko2006'),(6249,646024161001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','mmalowic','yurple@hotmail.com','Mark Malowicki','7227 Cowell Rd','Brighton','MI','UNITED STATES','48116-5131','(248) 431-9646','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 20:24:33',0,NULL,3,1,1,1,NULL,NULL),(6250,752281509015,250599412421,'Green.L 67mm 67 Neutral Density ND8 Filter ND 8 New',1,'AE2312',4.3,'hutongstore','fotolanders','jansklubal@seznam.cz','Jan Sklubal','6 Home Park','Plymouth','Devon','UNITED KINGDOM','pl2 1bq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 19:52:24',0,NULL,3,1,2,1,NULL,NULL),(6251,646021389001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rafaelroseiro','rafael_roseiro@hotmail.com','Rafael Roseiro','Rua Amaro Bezerra Cavalcanti, 290','São Paulo','São Paulo','BRAZIL','03513010','11 85052808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:27:49',0,NULL,3,1,2,1,NULL,NULL),(6252,752319751015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','leannetill','leanne@liberocounselling.co.uk','Leanne Till','64 Arundel Close<br>Randlay','Telford','Shropshire','UNITED KINGDOM','TF3 2LX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 20:47:16',0,NULL,3,1,2,1,NULL,NULL),(6253,646043467001,110604485759,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.95,'hermeshine','labrujulainquieta','cerol10@gmail.com','Raul Soler','Ronda de poniente 9','Tres Cantos','Madrid','SPAIN','28760','645837155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 20:52:07',0,NULL,3,1,2,1,NULL,NULL),(6254,686280580002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ellitri62','anfiselec@gmail.com','Angel Figueredo Figueredo','Josep Cuxart 51 5º3ª','Cornella Ll','Barcelona','SPAIN','08940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 21:04:44',0,NULL,3,1,2,1,NULL,NULL),(6255,646080641001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','donald6687','dcaylor@frontiernet.net','Donald Caylor','962 Mulberry Grove Road','Mulberry Grove','IL','UNITED STATES','62262','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:39:49',0,NULL,3,1,1,1,NULL,NULL),(6256,686341289002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1306',7.58,'hermeshine','asifakis','aadubadu@gmail.com','Angela Sifakis','1289 Rippey St','El Cajon','CA','UNITED STATES','92020-1741','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-13 22:53:32',0,NULL,3,1,1,1,NULL,NULL),(6257,645782369001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:11',0,NULL,8,1,17,0,NULL,NULL),(6258,645784766001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:15',0,NULL,8,0,17,0,NULL,NULL),(6259,645783378001,110499652243,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:25',0,NULL,8,1,17,0,NULL,NULL),(6260,645783948001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:28',0,NULL,8,1,17,0,NULL,NULL),(6261,686006647002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:07:31',0,NULL,8,1,17,0,NULL,NULL),(6262,645785212001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','orellanajacobo','orellanajacobo@yahoo.es','Jacobo Orellana Suarez','Malagon 3, 2-2','Madrid','Madrid','SPAIN','28043','655 98 10 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:08:07',0,NULL,3,1,4,1,NULL,'倒影板   1\r双灯头   1 欧标   \r大力夹球台   1\r柔光伞    1\r背景布 1.6x2.1   3（ 白 黑 灰）\r80cm 5in1    1\rphotography acc  $28\rYW864871121CN\rorellanajacobo\r'),(6263,752433707015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','erisej','for.ri4i@gmail.com','Ricardas Kuprys','17 Creighton Road','London','London','UNITED KINGDOM','N17 8JU','07828127856','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-13 23:11:03',0,NULL,3,0,2,1,NULL,'1.6x2.1  灰色 '),(6264,686358111002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 23:33:30',0,NULL,8,1,17,0,NULL,NULL),(6265,686341705002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-13 23:33:31',0,NULL,3,1,3,1,NULL,'背景架2mx2m    2 ( 白) \r改成两票国内挂号重发\r王明明 saud-p\rCP226334899CN\rRA022497499CN\rRA022497508CN\r'),(6266,646131303001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','aidswarrior','managercreative@gmail.com','Stefan Bogdan Terente','str. Pacurari nr.111 bl.603 sc.A et.1 ap.3','Iasi','Iasi','ROMANIA','700523','0754534595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-13 23:54:56',0,NULL,3,1,2,1,NULL,NULL),(6267,686367581002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ashturner850','ashrobin87@gmail.com','Ashley Turner','181 Wildflower Ln','Pensacola','FL','UNITED STATES','32514-6665','(850) 866-7468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 00:00:37',0,NULL,3,1,1,1,NULL,NULL),(6268,686372745002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 00:12:55',0,NULL,8,0,17,0,NULL,'XXXL '),(6269,646138316001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 00:14:43',0,NULL,3,0,3,1,NULL,'摄影背心 Canon  老款 XXXL   1\r摄影背心 绿色薄 canon  XXXL   1\rcanon  肩带     1  \rRA022490456CN\r\r\r看看在不在2kg以下\r '),(6270,686378287002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','rumasa2','ruterin@hotmail.com','Rubén Maestro Sanz','Urb. Las Nieves, calle guadalajara nº19','Nambroca','Toledo','SPAIN','45191','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 00:27:33',0,NULL,3,1,3,1,NULL,' RA022490310CN'),(6271,752468987015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','hachiko777','dushku5x5@hotmail.it','ilaria medda','via emilia levante 34','bologna','BO','ITALY','40139','3403895818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 00:31:19',0,NULL,3,1,2,1,NULL,NULL),(6272,646152438001,110408007449,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',7.3,'hermeshine','penster57','rivait@mnsi.net','Erin Gibb','777 Republic Dr','Allen Park','MI','UNITED STATES','48101-3651','(313) 425-2483','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 00:57:05',0,NULL,3,1,1,1,NULL,NULL),(6273,686392384002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','yuqui','luiscartajena@hotmail.com','Luis cartajena lira','San Luis 1468, El Retiro<br>San Luis 1446, El Retiro','Quilpué','V Region','CHILE','2420678','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 01:09:07',0,NULL,3,1,3,1,NULL,' RA022490147CN\r'),(6274,646157693001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','nllumberco','nllumberco@hotmail.com','Joe Rohrbach','17360 Fontana Path','Farmington','MN','UNITED STATES','55024','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 01:10:26',0,NULL,3,1,1,1,NULL,NULL),(6275,686397201002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ale.sturion','alesturion@gmail.com','Alexandre Graner Sturion','Rua Itamiami, 131<br>Bloco 4 - Apto 104','São Paulo','São Paulo - SP','BRAZIL','04120-100','55 11 6700-0919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 01:17:19',0,NULL,3,1,2,1,NULL,NULL),(6276,646180753001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',8.9,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 02:12:37',0,NULL,8,1,17,0,NULL,NULL),(6277,686425521002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 02:29:12',0,NULL,3,1,3,1,NULL,' RA022490782CN'),(6278,686460143002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arykinroman','arykin@yandex.ru','Roman Arykin','Lunacharskogo st. 29<br>apartment 12','Shadrinsk','Kurgan region','RUSSIAN FEDERATION','641870','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 04:17:02',0,NULL,3,1,3,1,NULL,'RA022490779CN '),(6279,646220034001,110532007043,'67mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1302',2.6,'hermeshine','apporizon','aporizon@gmail.com','Konstantin Makarov','1204 Avenue U<br># 2012','Brooklyn','NY','UNITED STATES','11229-4107','(347) 587-6084','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 05:01:02',0,NULL,3,1,1,1,NULL,' '),(6280,646019721001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',9.1,'hermeshine','fluffypillow1','pmccaleb@surewest.net','Peggy D. McCaleb','2273 Independence Way','Roseville','CA','UNITED STATES','95747','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 06:18:22',0,NULL,3,1,1,1,NULL,'绿叶 CPL  77mm  1\r77mm canon 镜头盖   1'),(6281,686486367002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','nurdasanto2009','nurdasanto@yahoo.com','Nurdasanto','Wisma Bakrie<br>Jl. HR Rasuna Said Kav.B-1','Jakarta','DKI','INDONESIA','12920','08176617123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 06:49:13',0,NULL,3,1,2,1,NULL,NULL),(6282,737301447016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','gf24708','gfunina@rambler.ru','Galina Funina','Fakultetsky per. 3-54','Moscow','','RUSSIAN FEDERATION','125080','7-903-2562144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 07:47:04',0,NULL,3,1,2,1,NULL,NULL),(6283,686499544002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','ozbargain.king','bargain.king@yahoo.com','U L Seneviratne','5 Raby Place','Deer Park','Victoria','AUSTRALIA','3023','0433999980','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 08:13:48',0,NULL,3,1,4,1,NULL,'lighting kit  $30 \rozbargain.king\rYW864871316CN\r'),(6284,752624401015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','elfin-embroidery','bigfoot11@btinternet.com','Graham L Harvey','9 Ayr Street<br>Moorlands','Lancaster','Lancashire','UNITED KINGDOM','LA1 3Dt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 09:21:55',0,NULL,3,1,3,1,NULL,' \rRA022497145CN\r'),(6285,686520639002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ppnbuy','prpn@mail.ru','Pavel Prokopovich','ulitsa Mira 1/1  kvartira 22','Surgut','HMAO','RUSSIAN FEDERATION','628400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 09:42:42',0,NULL,8,1,17,0,NULL,' '),(6286,646275272001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ppnbuy','prpn@mail.ru','Pavel Prokopovich','ulitsa Mira 1/1  kvartira 22','Surgut','HMAO','RUSSIAN FEDERATION','628400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 09:55:12',0,NULL,3,1,3,1,NULL,'ppnbuy\r斜臂   1 \r反光板支架   1\r看看是否2kg以下\r小庄    \rRA022497131CN\r'),(6287,751951572015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','normsbm','lindnorm1@aol.com','NORMAN HARRISON','12 TRINITY CLOSE','DUKINFIELD','CHESHIRE','UNITED KINGDOM','SK16 5JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 10:06:52',0,NULL,3,1,2,1,NULL,NULL),(6288,646278860001,110529627255,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7º 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:08:01',0,NULL,3,1,2,1,NULL,NULL),(6289,646281868001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fboy9685','federico.boy448@gmail.com','federico boy','via garau 29','san sperate','CA','ITALY','09026','0709601716','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 10:22:37',0,NULL,3,1,3,1,NULL,' 小刘  \rfboy9685\rRA022497128CN\r'),(6290,646284987001,110414474017,'Remote Cord Shutter Release for Olympus E420 E410 E510',1,'AA3229',5.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:43',0,NULL,8,1,17,0,NULL,NULL),(6291,646284616001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:43',0,NULL,8,1,17,0,NULL,' '),(6292,646285481001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',4,'AD1402',55.96,'hermeshine','curlybren_68','andynbren@bigpond.com','BRENDA PARSONS','7 carlson street<br>bluestone estate','MOUNT BARKER','South Australia','AUSTRALIA','5251','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-03-14 10:34:56',0,NULL,3,1,3,1,NULL,'RA022497202CN\r '),(6293,752648740015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.95,'hutongstore','bowbelles','bowbelles2011@live.co.uk','Peter King','14 Grasmere Grove, Frindsbury','Rochester','Kent','UNITED KINGDOM','ME24PL','01634723775','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 10:41:29',0,NULL,3,1,2,1,NULL,NULL),(6294,686532575002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','marbella756','rafael-sat@hotmail.com','Lorena Romer','GTA<br>C/ Torrente Ballester. Edificio Albatros II, Local 1','Marbella','Andalucía Ceuta y Melilla','SPAIN','29660','609531102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 10:33:44',0,NULL,3,1,2,1,NULL,'爵影快门线 E2  1 \r爵影快门线C1   1\r爵影快门线C3  1'),(6295,686553577002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','teddy-baku23','ted.baku@mail.ru','bakuteddi jabrayilov','neftyanikov 145 flat 122','baku','baku','AZERBAIJAN','aze1000','009940502208013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 11:51:27',0,NULL,3,1,3,1,NULL,'RA022497180CN\r'),(6296,686554474002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bigzetek','bigzet@gmail.com','Zbyszek Panek  PHOTO','Gagarina 31','Warszawa','mazowieckie','POLAND','00753','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 11:59:59',0,NULL,8,0,17,0,NULL,''),(6297,646307170001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','bigzetek','bigzet@gmail.com','Zbyszek Panek  PHOTO','Gagarina 31','Warszawa','mazowieckie','POLAND','00753','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 12:03:36',0,NULL,3,1,3,1,NULL,'摄影背心 Canon  老款 XL   1\r气吹+ 布   1 \rRA022497397CN\r'),(6298,646321671001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',133.98,'hermeshine','lerych66','valeriyvn@gmail.com','Valeriy Nazarov','Aralskaya 212-21','Chelyabinsk','','RUSSIAN FEDERATION','454025','+73519096587','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 13:55:06',0,NULL,3,0,5,1,NULL,'2m 灯架  2\r反光板支架   2\r斜臂   2 \r小王    lerych66\rCP226334960CN\r'),(6299,646348849001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','mcsatama','mmatasic@gmail.com','Marko Matasić','Kralji 19, Sesvete','Zagreb','Croatia','CROATIA','10360','00385958024480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:29:37',0,NULL,3,1,2,1,NULL,NULL),(6300,686609064002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','77613076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 14:51:26',0,NULL,3,1,2,1,NULL,NULL),(6301,646365493001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:23:27',0,NULL,8,1,17,0,NULL,NULL),(6302,646366052001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:25:07',0,NULL,8,1,17,0,NULL,NULL),(6303,686621547002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','selbergswe','robertselberg@hotmail.com','Robert Selberg','Västibäcksvägen 12','Boden','','SWEDEN','96196','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:26:43',0,NULL,3,1,2,1,NULL,NULL),(6304,686621337002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:27:46',0,NULL,8,1,17,0,NULL,NULL),(6305,686622236002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','uciteljica_nina','ninuska18@hotmail.com','Nina Miler','Kralja Tomislava 46','Krk','','CROATIA','51500','0038551221957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:29:55',0,NULL,3,1,3,1,NULL,'lenspen   1\r气吹+ 布   1\r麂皮   1\rGGS 450D    1 \rRA022497176CN\r'),(6306,686622783002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','thegrandmatux','matu.posei@fastwebnet.it','Marco Polselli','Via Ergisto Bezzi 34','Roma','RM','ITALY','00153','065813327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 15:30:23',0,NULL,3,1,2,1,NULL,NULL),(6307,686625007002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','glazowski81','glaziz@interia.pl','lukasz glazowski','68 Abberley Apt<br>Hight Street','Dublin','Dublin','IRELAND','24','086 0323276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 15:37:02',0,NULL,3,1,3,1,NULL,' 小庄    glazowski81\rRA022497220CN\r'),(6308,737704073016,260661735101,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',20.8,'hutongstore','kevincho761129','dakeeus@hotmail.com','Kevin (KEE PIL) Cho','Hornsbergs Strand 43<br>1tr','Stockholm','Sweden','SWEDEN','112 16','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 16:22:07',0,NULL,3,1,3,1,NULL,'4镜片，其中+8 换成+4 \rRA022497879CN'),(6309,686643639002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','bourneid','bourneidentity@abv.bg','TEODOR TODOROV','Rue Vandenbroeck 2, app 4, ettage 3','Bruxelles','','BELGIUM','1050','0476057394','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 16:25:11',0,NULL,3,1,2,1,NULL,NULL),(6310,686642262002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','antiqueclockworks','antiqueclockworksgalicia@gmail.com','Iván Blanco Vilar','Av. Vilachán nº11, 1º izquierda','Negreira (A Coruña)','Galicia','SPAIN','15830','667757296','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 16:37:47',0,NULL,3,1,3,1,NULL,'欧标 \r小王  antiqueclockworks\rRA022497233CN\r\r'),(6311,752793589015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1604',16,'hutongstore','crook2205','ian-helen@sky.com','Ian Crook','400 Leyland Road, Lostock Hall','Preston','Lancashire','UNITED KINGDOM','PR55SA','01772316721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 16:57:36',0,NULL,3,0,3,1,NULL,'wf1003   1\r小庄    crook2205\rRA022497247CN\r'),(6312,646422025001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',7.25,'hermeshine','r7rocket','davbowman@yahoo.com','David Bowman','10273 Miner Place','Cupertino','CA','UNITED STATES','95014','(650) 438-4815','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-14 17:51:06',0,NULL,3,1,1,1,NULL,' '),(6313,646435381001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','aperturef2.8','t.dickeson@ntlworld.com','Tim Dickeson','6 Denison Way','St Fagans','Cardiff','UNITED KINGDOM','CF5 4SF','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 18:16:28',0,NULL,3,1,4,1,NULL,'light stand  $20 \r小王   aperturef2.8\rYW864871261CN\r'),(6314,646442719001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','6tuka','andrey.foto.brest@gmail.com','andrei shuka','Suvorova st., 114-19','Brest','','BELARUS','224000','375295739686','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 18:33:53',0,NULL,3,1,3,1,NULL,' 小刘   \r6tuka\rRA022497162CN\r'),(6315,686751219002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','volpone76','karsheimer@gmail.com','Fredrik Jarl','Dalgången 5','Stockholm','','SWEDEN','16841','(+46)0735070869','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 19:57:08',0,NULL,3,1,3,1,NULL,' 小王    \rvolpone76\rRA022497255CN\r'),(6316,646494519001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','ald182','l.david@9online.fr','Laurent david','74 BIS avenue Paul Doumer','Rueil-Malmaison','Île-de-France','FRANCE','92500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 20:01:44',0,NULL,3,1,4,1,NULL,'tripod $20 \r小庄      ald182\rYW864871272CN\r'),(6317,686764393002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','jskinner84t','js84t@yahoo.com','John Skinner','360 CARON<br>Suite #406','WINDSOR','ON','CANADA','N9A5B2','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 20:16:58',0,NULL,3,1,5,1,NULL,'小庄   \rjskinner84t\rCP226334956CN\r'),(6318,646505236001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','pousaul','saul7070@yahoo.com','SAUL POU','# 39 Rafaela Rivera Street Urb. Paseo de los Artesanos  ','LAS PIEDRAS','PR','UNITED STATES','00771','(787) 590-1556','NoPaymentFailure','CheckoutComplete','Other','2011-03-14 20:20:02',0,NULL,3,0,1,1,NULL,'pousaul\r刘'),(6319,751389866015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','lauren_jr1','lauren_jr1@hotmail.co.uk','Marcus Wiltshire','Arrowspeed, 5 Bonville Trading Estate<br>Brislington','Bristol','Bristol','UNITED KINGDOM','bs4 5qu','07983394127','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 21:10:00',0,NULL,3,1,3,1,NULL,' 小刘  \rlauren_jr1\rRA022497264CN\r'),(6320,686794601002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','deimossssss','darslanov@yahoo.com','Denis Arslanov','Vossendijk<br>159','Nijmegen','','NETHERLANDS','6534TN','31616922022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-14 21:12:11',0,NULL,3,1,4,1,NULL,'background support   $20 \r背景架2m  白\r小王    deimossssss\rYW864871283CN\r'),(6321,752975390015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','karada_uk','lord.james.of.lochaber@googlemail.com','Jim Findlay','21 Bramble Bank<br>Frimley Green','Camberley','Surrey','UNITED KINGDOM','GU16 6PN','01252836463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-14 21:37:52',0,NULL,3,1,3,1,NULL,' 小王   \rkarada_uk\rRA022497352CN\r'),(6322,646565037001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','manutxao6.0','manutxao5.0@gmail.com','Txema Serrano','FAUSTEBEKOA 3A 2C','DURANGO','País Vasco','SPAIN','48200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-14 22:26:10',0,NULL,3,1,2,1,NULL,' 庄'),(6323,753003159015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','kachok2001','kachok2001@gmail.com','GrigorI Zelenov','PALKKATILANKATU 1 D 80','Helsinki','FIN','FINLAND','00240','358407190206','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:34:54',0,NULL,3,1,2,1,NULL,' 庄'),(6324,737925904016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','travelyourlife','travelyourlife@gmail.com','tommaso iadicicco','Google Ireland<br>Barrow St','Dublin','Dublin','IRELAND','D4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:39:46',0,NULL,8,1,17,0,NULL,' 小王   \rtravelyourlife'),(6325,753008829015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','travelyourlife','travelyourlife@gmail.com','tommaso iadicicco','Google Ireland<br>Barrow St','Dublin','Dublin','IRELAND','D4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:44:29',0,NULL,3,1,4,1,NULL,' 小庄    \rtravelyourlife\r斜臂   1\r反光板支架   1\rYW864871294CN\r'),(6326,737931282016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','b_nikolov','bnnikolov@yahoo.com','Boyan Nikolov','dstr.\"Sveta Troica\", bl.366, vh.B ap.44','Sofia','','BULGARIA','1309','(+359889)834140','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-14 22:52:01',0,NULL,3,1,2,1,NULL,'庄 '),(6327,753038836015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mk2brian','brianandliz@sky.com','BRIAN HODGKINS','4 THROSTLENEST<br>FARCET','PETERBOROUGH','Cambridgeshire','UNITED KINGDOM','PE73BP','01733240509','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 00:02:15',0,NULL,3,1,3,1,NULL,' 小庄  \rmk2brian\rRA022497216CN\r'),(6328,686869351002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','garyohboy3rv8','garyohboy@aol.com','GARY J FERREIRA','192 Hayden Ave','TIVERTON','RI','UNITED STATES','02878-2122','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 00:23:42',0,NULL,3,1,1,1,NULL,'庄 '),(6329,686891328002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','edji_kiz','linedji@hotmail.fr','Jean-pierre Gilly','10 chemin pierre stajano','La penne sur huveaune','Provence-Alpes-Côte d\'Azur','FRANCE','13821','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 01:28:52',0,NULL,3,1,3,1,NULL,'小刘    \redji_kiz\rRA022497278CN\r'),(6330,686925322002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',4,'hermeshine','hips2220','hipcoral@hotmail.com','Hipolito Corral','1988 Goya','Laval','QC','CANADA','H7S 1T1','(514) 994-4843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 03:20:53',0,NULL,3,1,2,1,NULL,'hips2220 '),(6331,686926395002,120564178812,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','akarae','genchildren@hotmail.com','Teo   Hong Joo',' Block 426 Serangoon Avenue 1 #11-203','Singapore','Singapore','SINGAPORE','550426','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 03:26:13',0,NULL,3,1,11,1,NULL,'\rakarae\r接口环是77mm的 \r小王'),(6332,646652606001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 03:39:58',0,NULL,3,1,3,1,NULL,'leofotografias \rRA022497383CN\r庄'),(6333,646209985001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',16.56,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:03:49',0,NULL,3,1,3,1,NULL,'santimuya\r申报 ：  light reflector $10\rRA022497321CN\r庄\r'),(6334,646210333001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',22.6,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:06:54',0,NULL,3,1,3,1,NULL,'santimuya \r单灯头  欧标   2\rRS-C1    1\r申报： lamp holder accesory  $10\rRA022497318CN\r庄\r'),(6335,646209709001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',30.96,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','541147733629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 04:09:06',0,NULL,3,1,3,1,NULL,'santimuya\r申报：bulb holder accesory   $12\rRA022497406CN\r\r\r'),(6336,646657224001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','a.schoenberg','adrian_schoenberg@gmx.net','Adrian Schönberg','Burgwall 27','Vehlefanz','','GERMANY','16727','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 04:09:16',0,NULL,3,1,3,1,NULL,' RA022497335CN\r庄\r'),(6338,686954787002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','royrak','royrak@gmail.com','Rogelio Hernandez','3789 Diamond ct','Simi Valley','CA','UNITED STATES','93063','(805) 304-2594','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-15 05:56:12',0,NULL,3,1,1,1,NULL,'royrak\r刘'),(6339,646666143001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','santimuya','vamoloredondos@hotmail.com','Santiago D\'Addezio','Darregueyra 2438   3ero A','Capital Federal','Buenos Aires','ARGENTINA','C1425FLR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 06:07:18',0,NULL,8,1,17,0,NULL,'santimuya'),(6340,686960756002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','tricksecret','sathitporn@gmail.com','Sathitporn Jittramontri','32/337 Moo1 Jangwatthana RD.<br>Pakkret','Nonthaburi','','THAILAND','11120','(668)145-63049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 06:36:50',0,NULL,3,1,3,1,NULL,'tricksecret\rRA022497587CN'),(6341,686961764002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','hoonbk','bijolotte@naver.com','Kyoung-Hoon Bae','669-12 3F, Pungdeokcheon 1-dong<br>Suji-gu','Yongin-si','Gyeonggi-do, Korea','KOREA,REPUBLIC OF','448-552','82-10-8706-6853','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 06:46:40',0,NULL,3,1,3,1,NULL,'hoonbk\rRA022497595CN'),(6342,749288574015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','crag67','michaelcraig67@hotmail.com','M Craig','141 Ribbleton Avenue','Preston','Lancashire','UNITED KINGDOM','PR26YS','07876790728','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 08:19:26',0,NULL,7,0,18,0,NULL,'crag67'),(6343,753235578015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 12:24:43',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022497794CN\r庄\r'),(6344,752963108015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','exercise2006','jm2heffernan@eircom.net','j heffernan','24 Forgehill Crescent<br>Stamullen','Co. Meath','Meath','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 12:25:25',0,NULL,3,0,3,1,NULL,'exercise2006庄\rRA022497825CN\r黑色 灰色 1.6x2.1\r'),(6345,753239609015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 12:37:12',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022497689CN\r'),(6346,646758489001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',4.4,'hermeshine','harleysc91','bill-pope@sbcglobal.net','Billie  G  Pope','804 Spring Lake Cir','Enon','OH','UNITED STATES','45323','(937) 864-5418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 12:47:21',0,NULL,3,1,1,1,NULL,'harleysc91\r庄'),(6347,738176251016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','jpintom7204','zeamandio@gmail.com','José Mesquita','Avenida D. Dinis, 36-38','Vila Real','','PORTUGAL','5000-600','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 13:51:21',0,NULL,3,1,2,1,NULL,'jpintom7204'),(6348,646779518001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:04:20',0,NULL,3,1,3,1,NULL,'nixette_nixette\r庄RA022497692CN\r'),(6349,646789479001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.9,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:37:44',0,NULL,8,1,17,0,NULL,'vitorf2011'),(6350,738194652016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','zbynek.hromek','hromek@zzsoft.cz','Zbynek Hromek','Jaroslava Jezka 786','Trutnov','','CZECH REPUBLIC','54101','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 14:41:14',0,NULL,8,1,17,0,NULL,'zbynek.hromek'),(6351,753284484015,250599424460,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',2,'AA1308',3.76,'hutongstore','zbynek.hromek','hromek@zzsoft.cz','Zbynek Hromek','Jaroslava Jezka 786','Trutnov','','CZECH REPUBLIC','54101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 14:41:15',0,NULL,3,1,2,1,NULL,'zbynek.hromek\r大力夹   1\rNIKON 镜头盖 72mm   2\r'),(6352,646790567001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',4,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:41:32',0,NULL,8,1,17,0,NULL,'vitorf2011'),(6353,646775228001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','dkrm','randy@rwmyers.com','Randy Myers','Forensics Service, 150 East Main St.<br>Police Dept.','Lexington','KY','UNITED STATES','40507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 14:50:34',0,NULL,3,1,1,1,NULL,'dkrm'),(6354,646793894001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','vitorf2011','vmaf@netcabo.pt','Vitor Fernandes','Pta. Almeida Garrett, nº5, 3ºesq<br>Quinta do Rouxinol','Corroios','Corroios','PORTUGAL','2855-213','+351917220027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 14:52:38',0,NULL,3,1,2,1,NULL,'vitorf2011\r眼罩 450D/500D   1\r绿叶 ND8  77mm  1\r绿叶 UV  67mm   1'),(6355,753292770015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','joseluis.295','jlrsmartin@gmail.com','José Luís Martín (ServeisWeb)','C. Ponent, 13 -15 Pol. Ind. Mas Llado II','Fornells de la Selva','Cataluña','SPAIN','17458','644320882','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 15:04:21',0,NULL,3,1,2,1,NULL,'joseluis.295'),(6356,687097232002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','reverendo_ferryz','ferriz_manson@hotmail.com','Christian Ferriz Santos','c/ flor de nit 5-7 5 B','cornella','Cataluña','SPAIN','08940','933764548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 15:46:28',0,NULL,3,1,3,1,NULL,'reverendo_ferryz\r刘\rRA022497644CN\r'),(6357,646815747001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kanfar1','l2939@aceweb.com','Nelson Smith','98645 Camellia Dr','Brookings','OR','UNITED STATES','97415','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:03:02',0,NULL,3,1,1,1,NULL,'kanfar1'),(6358,687115389002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','calico.cat!','milo@grika.com','Milo Grika','5642 100th Ln N','Brooklyn Park','MN','UNITED STATES','55443-5700','(612) 730-6456','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 16:37:57',0,NULL,3,1,1,1,NULL,'calico.cat!'),(6359,753346593015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:08:40',0,NULL,3,1,17,0,NULL,'sparky01278'),(6360,753347332015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:10:13',0,NULL,3,1,17,0,NULL,'sparky01278'),(6361,753348287015,250599393197,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',4,'AA3314',15.28,'hutongstore','sparky01278','demis@rabbit-hutches.com','Samples','PO BOX 163<br>Dunstan Road','Burnham On Sea','Somerset','UNITED KINGDOM','TA8 1ER','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 17:12:06',0,NULL,3,1,3,1,NULL,'sparky01278\r绿叶 CPL  77mm    12\rRA022496122CN\r'),(6362,646849992001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.8,'hermeshine','grisoxxl1','grisoxxl@zoznam.sk','Peter Greňo','L. Svobodu 14','Lučenec','','SLOVAK REPUBLIC','98401','+421907657527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:35:18',0,NULL,3,1,17,0,NULL,'grisoxxl1\r庄'),(6363,687142307002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.8,'hermeshine','grisoxxl1','grisoxxl@zoznam.sk','Peter Greňo','L. Svobodu 14','Lučenec','','SLOVAK REPUBLIC','98401','+421907657527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 17:43:13',0,NULL,3,1,2,1,NULL,'grisoxxl1\r52-58mm 双阳环  1\r52-52mm 双阳环  1\r庄'),(6364,687151383002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dmitry-e-bay','dmwq@bk.ru','Dmitriy Golubev','Malaya Buharestskaya street dom 6 korp 1 kv 367','St. Petersburg','RU','RUSSIAN FEDERATION','192288','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:06:14',0,NULL,3,1,2,1,NULL,'dmitry-e-bay'),(6365,687153946002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thomasjavier','thomasjcastillo@gmail.com','Thomas Castillo','445 S 5th Ave','Tucson','AZ','UNITED STATES','85701-2446','(520) 403-1467','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-15 18:10:52',0,NULL,3,1,1,1,NULL,'thomasjavier\r庄'),(6366,687162673002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gal-gal','galm69@walla.com','gal mizrahi','haim laskov 7/5','jerusalem','israel','ISRAEL','1363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 18:30:21',0,NULL,3,1,3,1,NULL,'gal-gal\rRA022497613CN\r'),(6367,687187667002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','riso_lubi_kavu','richardslovakia@hotmail.com','Richard Medzihradsky','ATT Slovakia, Karadzicova 8/A,','Bratislava','','SLOVAK REPUBLIC','82108','421903814164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 19:17:17',0,NULL,3,1,2,1,NULL,'riso_lubi_kavu'),(6368,753405556015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',2,'AA3312',10.4,'hutongstore','luke.morgan.bmx.2009','luke.morgan.bmx@googlemail.com','luke morgan','38 the crescent<br>sea mills','bristol','Bristol','UNITED KINGDOM','bs9 2js','07785592930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 18:59:36',0,NULL,3,1,2,1,NULL,'luke.morgan.bmx.2009\r庄\r'),(6369,646939385001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','hakanberg1','ebay@hocke.se','Håkan Berg','Albogatan 16','Lund','Skane','SWEDEN','22241','+46709280709','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-15 20:35:57',0,NULL,3,1,3,1,NULL,'hakanberg1\r庄\rRA022497658CN\r\r'),(6370,687230818002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:37:27',0,NULL,3,1,2,1,NULL,'woopz86\r刘\r\r'),(6371,646941465001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','igoreksimbiker','ligasurskoe@rambler.ru','Makarov Aleksei','street Samarskaya d.17 kv.91','Ulyanovsk','','RUSSIAN FEDERATION','432073','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 20:38:09',0,NULL,3,1,2,1,NULL,'igoreksimbiker'),(6372,738391697016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','kimh139','kimhughes_uk@yahoo.co.uk','kim Hughes','1, Oaklands Drive','Bridgend','Bridgend','UNITED KINGDOM','CF31 4SH','07887931743','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-15 21:00:50',0,NULL,3,1,2,1,NULL,'kimh139\r庄\r'),(6373,682327235002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','correa*wellington','wttf_nunes@hotmail.com','Wellington Correa Nunes','Rua Bulcão Viana, n.198','Florianópolis','Santa Catarina','BRAZIL','88020-010','(48) 9635-5842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 22:12:21',0,NULL,3,1,2,1,NULL,'woopz86\r刘'),(6374,646989673001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','pedrofelipe-pedrolas','pedrolas25@hotmail.com','Pedro Felipe Iglesias Sánchez','Av. Portugal nº 195 -Bajo.(peluquería)','Salamanca','Castilla y León','SPAIN','37006','636577533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-15 22:27:15',0,NULL,3,1,2,1,NULL,'pedrofelipe-pedrolas\r欧标\r庄\r'),(6375,753541554015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','rtkzn','sm-video@inbox.ru','Радик Гаялиев','Ноксинский Спуск, 16, 42','Казань','Республика Татарстан','RUSSIAN FEDERATION','420140','89046666270','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-15 22:47:53',0,NULL,3,1,5,1,NULL,'rtkzn刘\r+一件摄影背心 冬夏 XL\rCP226630619CN'),(6376,753544322015,250662485736,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',21.5,'hutongstore','rtkzn','sm-video@inbox.ru','Радик Гаялиев','Ноксинский Спуск, 16, 42','Казань','Республика Татарстан','RUSSIAN FEDERATION','420140','89046666270','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-15 22:53:42',0,NULL,3,1,17,0,NULL,'rtkzn'),(6377,647021496001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','staversky','lgreenm@gmail.com','Dmitry Staversky','Architectors St., 24, kv.53','Kharkov','','UKRAINE','61174','(050)3255120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 00:08:48',0,NULL,3,0,3,1,NULL,'staversky\rXXXL\rRA022497560CN\r庄  \r'),(6378,647030299001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','plorenzo29','plorenzog@gmail.com','Paul Lorenzo','Jr. Tiahuanaco 889<br>urb. Zarate','Lima','Lima','PERU','Lima 36','511995570853','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 00:44:53',0,NULL,3,1,2,1,NULL,'plorenzo29庄\r'),(6379,647061352001,110534333294,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',9.69,'hermeshine','zeb86','theguy_911@hotmail.com','Miranda Bruckner','3/50 Pakington Street','Kew','Victoria','AUSTRALIA','3101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 02:42:12',0,NULL,3,1,2,1,NULL,'zeb86庄\r'),(6380,647062457001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','ardens','junkorama@comcast.net','Ms. Arden Shelton','1524 N Terry St','Portland','OR','UNITED STATES','97217','(503) 709-7252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 03:04:55',0,NULL,3,1,1,1,NULL,'ardens\r刘'),(6381,753647934015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','mr_geoff2','ihaveteeth@hotmail.com','Geoff Wols','35/147 Talavera Road','Marsfield','New South Wales','AUSTRALIA','2122','0298691285','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 04:20:47',0,NULL,3,1,2,1,NULL,'mr_geoff2\r庄'),(6382,687394513002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','beata_muszynski','wm@usprocom.com','Beata Muszynski','646 N Northwest Hwy<br>Apt B','Park Ridge','IL','UNITED STATES','60068','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 05:10:46',0,NULL,3,1,1,1,NULL,'bern047\r庄'),(6383,647096817001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','martinez1800','martinez1800@comcast.net','Miguel Martinez','1502 Peony Dr','Tracy','CA','UNITED STATES','95377-8815','(209) 832-5079','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 05:50:44',0,NULL,3,0,1,1,NULL,'martinez1800\rxxxl\r刘'),(6384,647096851001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.8,'hermeshine','yudi1103','maspaidy@yahoo.co.id','Yudi ardiyanto','PT TERUMO INDONESIA<br>Wisma Kyoei Prince 5th Floor Jl. Jenderal Sudirman Kav. 3','Jakarta','JK','INDONESIA','10220','62215724071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:51:16',0,NULL,3,1,2,1,NULL,'yudi1103\r庄'),(6385,642433815001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',5.4,'hermeshine','nio-999','sergei-r@yandex.ru','Sergei Rozhdestvenskiy','Tarkhanskaya street, 3/1<br>119','Moscow','','RUSSIAN FEDERATION','109156','(926) 886-31-99','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 05:51:42',0,NULL,3,1,2,1,NULL,'nio-999\r庄'),(6386,687409637002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dimgordeev','dim555@bk.ru','Dmitry Gordeev','Vostochniy poselok, 20-14','Cheboksary','Chuvashiya','RUSSIAN FEDERATION','428011','(905)345-57-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 07:25:49',0,NULL,3,1,2,1,NULL,'dimgordeev\r庄'),(6387,753709365015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','unusualigor','unusuallll@gmail.com','Igor Karpov','ylitsa 70 let Oktjabrja 5-220','Togliatti','Samarskaja','RUSSIAN FEDERATION','445030','79626127152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 09:15:12',0,NULL,3,1,2,1,NULL,'unusualigor\r庄'),(6388,753709784015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','igoris.g','garvida@takas.lt','Igoris Gargazinas','Zygio 93-44','Vilnius','Zirmunai','LITHUANIA','08234','37069955218','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 09:16:16',0,NULL,3,1,2,1,NULL,'igoris.g\r庄'),(6389,647137565001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.4,'hermeshine','mazeke777','mazeke@rambler.ru','Almas Kozygulov','K.Satpaev str. 4-65','Ust-Kamenogorsk','East Kazakhstan','KAZAKHSTAN','070020','87055000022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:43:17',0,NULL,3,1,17,0,NULL,'mazeke777'),(6390,687442788002,120568891207,'58mm Lens lenscap for Canon 450D 500D 550D 7D 5DII',1,'AA1301',2.6,'hermeshine','mazeke777','mazeke@rambler.ru','Almas Kozygulov','K.Satpaev str. 4-65','Ust-Kamenogorsk','East Kazakhstan','KAZAKHSTAN','070020','87055000022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 09:43:18',0,NULL,3,1,2,1,NULL,'mazeke777\r绿叶 UV  58mm   1\rCANON 镜头盖  58mm  1\r庄'),(6391,687451989002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','phoenix4027','mail@artfacade.com.au','Andrew Baird','21 Burton Street','Dromana','Victoria','AUSTRALIA','3936','0414263555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 10:23:23',0,NULL,3,1,2,1,NULL,'phoenix4027\r刘'),(6392,647158537001,110566020598,'New GGS Digital Camera 3.0\" LCD Screen Protector Glass ',1,'AB2208',5.6,'hermeshine','vvvova','vvvrost@mail.ru','VLADIMIR VAKULENKO','Chicherinsky 1A','Rostov-on-Don','Rostovskaya obl','RUSSIAN FEDERATION','344034','+79081816800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 11:15:27',0,NULL,5,0,18,0,NULL,'vvvova'),(6393,647170923001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xandhao','asc1407@ig.com.br','Alexandre da Silva Cruz','R. Piracicaba, 480 - Apt.131','Santo André','São Paulo','BRAZIL','09060-180','55-11-44256377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 12:02:42',0,NULL,3,1,3,1,NULL,'xandhao\r庄\rRA022496025CN\r'),(6394,647174883001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','harcangel','morehh@hotmail.es','Antonio Francisco Morenilla Díaz','Campanilleros, 26 K<br>Benjamin Lopez, 13 bajo A','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','647864915','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 12:17:29',0,NULL,3,1,3,1,NULL,'harcangel\r刘\rRA022496048CN\r'),(6395,753776925015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.38,'hutongstore','jokubas.lioge','joqbas@gmail.com','Jokubas Lioge','Bitininku 1a-10','Vilnius','','LITHUANIA','LT-08414','+37060383067','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-16 12:46:23',0,NULL,3,1,2,1,NULL,'jokubas.lioge\r庄'),(6396,687498490002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','lviana1968','luisviana_89@hotmail.com','Luis Viana','rua tomé de sousa n14 r/chão direito','Póvoa de Varzim','porto','PORTUGAL','4490-681','252100521','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 13:17:06',0,NULL,3,1,3,1,NULL,'lviana1968\rRA022496082CN\r'),(6397,753791642015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','xscrolls','triciro@hotmail.com','patricia whelan','2 cappagh green, finglas west','dublin','ireland','IRELAND','11','018645005','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-16 13:27:49',0,NULL,3,1,4,1,NULL,'xscrolls\r白色布\rlighting kit  $30\rYW864871246CN\r'),(6398,687510666002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','6topal','shestopal@gmail.com','Konstantin Shestopal','Gorodnya str., 13, app. 42','Kiev','','UKRAINE','03141','+38 068 9054985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 13:55:26',0,NULL,3,1,2,1,NULL,'6topal\r刘'),(6399,753830453015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',4.3,'hutongstore','dt090772','ght1942@googlemail.com','Graham Taylor','18 Normanhurst Close<br>Three Bridges','Crawley','West Sussex','UNITED KINGDOM','RH10 1YL','01293534513','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 15:08:20',0,NULL,3,1,2,1,NULL,'dt090772\r王'),(6400,687540725002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','carploos','roquetascity@gmail.com','carlos','c/Seneca Nº8 , Puebla de Vícar','ALMERIA','Andalucia','SPAIN','04738','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 15:27:12',0,NULL,3,1,4,1,NULL,'carploos\r庄\rYW864871235CN\r'),(6401,647245769001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',50.99,'hermeshine','wilfred951','skunker925@yahoo.com','Wilfred Briones','3600 Cashmere Cir','Perris','CA','UNITED STATES','92571','(951) 312-2165','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 16:03:10',0,NULL,3,1,3,1,NULL,'wilfred951\r刘\rRA022496119CN\r'),(6402,687552247002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','loufield_roadwin','loufield_@hotmail.com','Ivan Antunez','Urb brisas del aljarafe 40','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41907','696012201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 16:07:08',0,NULL,3,1,4,1,NULL,'loufield_roadwin\r庄\rYW864871224CN\r'),(6403,687572546002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 16:57:39',0,NULL,3,1,3,1,NULL,'arnorolf10\rRA022496034CN\r'),(6404,687582254002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ph4rm3r_3d','ed.piebiak@gmail.com','Ed Piebiak','Box 97','Eaglesham','AB','CANADA','T0H 1H0','(780) 359-2448','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 17:13:24',0,NULL,3,1,3,1,NULL,'    ph4rm3r_3d\rRA022496051CN\r'),(6405,687512073002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','stacey.reardon2010','gracesjack@yahoo.com','Stacey Reardon','445 Litchfield Rd','New Milford','CT','UNITED STATES','06776-2005','(860) 350-2087','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 17:43:45',0,NULL,3,1,4,1,NULL,'stacey.reardon2010\rlighting kit  $30\r灯泡 是110v 的\r庄\rYW864871202CN\r'),(6406,687595754002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','eldaral','aliyev.eldar@gmail.com','Ali Aliyev','Comfort Suites(TXA73)<br>631 I-45 South','Huntsville','TX','UNITED STATES','77340','','NoPaymentFailure','CheckoutComplete','Other','2011-03-16 17:50:27',0,NULL,3,1,3,1,NULL,'eldaral\rRA022496105CN\r'),(6407,687602446002,120568984583,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','baggedmitsu','illdragonyou@aol.com','Ernesto Macias','13895 Pheasant Knoll Ln','Moreno Valley','CA','UNITED STATES','92553','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 17:59:35',0,NULL,3,1,1,1,NULL,'baggedmitsu'),(6408,738827854016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','jtnewman2011','johnthomas.newman@btinternet.com','John Thomas Newman','5 Bindloss Cottages','Milnthorpe','Cumbria','UNITED KINGDOM','LA7 7QD','0153964843','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 18:44:34',0,NULL,3,1,2,1,NULL,'jtnewman2011庄'),(6409,687621596002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','robertmarino31','bmar223@aol.com','Robert Marino','2399 Lakeshore Dr','Mandeville','LA','UNITED STATES','70448-5736','(985) 674-7634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-16 18:51:11',0,NULL,3,1,1,1,NULL,'robertmarino31\r庄'),(6410,647320464001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rexregum','honkietong@hotmail.com','Cheng Shian Wen','Hougang Ave 2 BLK 705<br>#10-249','default','','SINGAPORE','530705','+6597110935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 18:57:06',0,NULL,3,1,11,1,NULL,'rexregum\r庄'),(6411,647364880001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.55,'hermeshine','kew78','kewang78@hotmail.com','Eric Wang','860 Centennial Ave<br>Genscript USA Inc','Piscataway','NJ','UNITED STATES','08854-3918','(812) 340-3923','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 20:17:09',0,NULL,3,1,1,1,NULL,'kew78\r庄'),(6412,687682272002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','airfxca','cmw9001@hotmail.com','ying chuan lin','2989 E 26AVE','Vancouver','BC','CANADA','V5R1L4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 20:33:05',0,NULL,3,1,3,1,NULL,'airfxca刘\rRA022496096CN\r'),(6413,738959574016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','zimoutlaw','ryanclivelaw@gmail.com','Ryan Law','38 Cliveden Road<br>Wimbledon','Wimbledon','London','UNITED KINGDOM','SW19 3RB','02085436535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 22:20:31',0,NULL,3,1,3,1,NULL,'zimoutlaw\r王\rRA022496017CN\r'),(6414,683159313002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','1hectornoel','estudio505@gmail.com','HECTOR RAMOS','VILLA GRANADA<br>ALAMEDA 937','SAN JUAN','PR','UNITED STATES','00924','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-16 22:29:41',0,NULL,5,0,18,0,NULL,'1hectornoel\r庄'),(6415,687744005002,120519553558,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',61.5,'hermeshine','c0starx','costarx@gmail.com','Joaquin costa subias','parroco eusebio cuenca 36 6A','Madrid','Madrid','SPAIN','28045','651199699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-16 22:44:01',0,NULL,3,1,4,1,NULL,'c0starx\r庄\rtripod  $15\rYW864871213CN\r\r'),(6416,687745038002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','georgecanitgy','graby0@hotmail.com','gabriel mestre sole','calle montserrat, 7, 1-1<br>calle sant pere, 12','calafell','Tarragona','SPAIN','43820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-16 22:47:15',0,NULL,3,1,17,0,NULL,'georgecanitgy\r'),(6417,738977098016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','lcor1768','lino.coria@gmail.com','Lino Coria','125 - 2875 Osoyoos Crescent','Vancouver','BC','CANADA','V6T 2G3','(604) 221-5929','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-16 23:00:34',0,NULL,3,1,5,1,NULL,'lcor1768\r灯泡是110v  的\r王\rCP226630622CN\r'),(6418,754094835015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',7.8,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:18',0,NULL,3,1,17,0,NULL,'allanb24'),(6419,754094258015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:19',0,NULL,3,1,17,0,NULL,'allanb24'),(6420,738978773016,260660053536,'New Pro Photo Vest for all DSLR fans Size: L',1,'AA1103',20.5,'hutongstore','allanb24','allan.brisbane@hotmail.co.uk','Allan Brisbane','1 Hawkwood<br>Whitehills','East Kilbride','South Lanarkshire','UNITED KINGDOM','G75 0SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-16 23:07:19',0,NULL,3,1,4,1,NULL,'allanb24\r反光伞  1\r摄影背心 冬夏  L    1\r灯架  2m   1\r闪光灯B座    1\r柔光伞    1\r2.056\r刘\rYW864871191CN  \r'),(6421,641126481001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','aaz38','saletorrent@gmail.com','Alexey Zyuzyun','Pervomayskiy d.8a kv.23','Irkutsk','','RUSSIAN FEDERATION','664058','3952613620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 00:54:43',0,NULL,3,1,2,1,NULL,'aaz38\r庄'),(6422,687789450002,120581555897,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 01:13:23',0,NULL,3,1,17,0,NULL,'aimeedesigns'),(6423,647470057001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-03-17 01:13:23',0,NULL,3,1,17,0,NULL,'aimeedesigns'),(6424,647470164001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','aimeedesigns','studioaimee@msn.com','Aimee Cooper','957 E Chelsea Dr','Queen Creek','AZ','UNITED STATES','85240','(480) 357-4239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 01:13:24',0,NULL,3,1,1,1,NULL,'aimeedesigns\r10片装套装 + 72mm 环架  1\r77mm 接口环  1\r82mm 接口环   1\r徐'),(6425,647475350001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','ljubisa-jagodina','ljubisa.jovanovic@hotmail.com','Ljubisa Jovanovic','Kneza Lazara B1 167/10','Jagodina','Serbia','SERBIA','35000','(381)600626466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 01:32:32',0,NULL,3,1,2,1,NULL,'ljubisa-jagodina\r新地址： \r Ljubisa Jovanovic \rKneza Lazara 173/3/10 35000 Jagodina Serbia +381600626466\r庄'),(6426,687803918002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','buyerul','manuel_agotici@hotmail.com','Manuel Agotici','134, Marl Meadow Dr.','Kitchener','ON','CANADA','N2R1L3','(519) 589-2336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 02:00:25',0,NULL,3,1,2,1,NULL,'buyerul\r庄'),(6427,647494357001,110523102293,'72mm Lens lenscap for Nikon Combined shipping discounts',1,'AA1308',2.6,'hermeshine','tyman1975','ty_miles@yahoo.com','Tyler Miles','694 Buoy Dr','Pensacola','FL','UNITED STATES','32507-8696','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 02:42:59',0,NULL,3,1,1,1,NULL,'tyman1975\r庄'),(6428,687931408002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:12:45',0,NULL,3,1,17,0,NULL,'jdoc6368'),(6429,687932386002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:15:59',0,NULL,3,1,17,0,NULL,'jdoc6368'),(6430,647619470001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','trubicboris','trubic.boris@gmail.com','Boris Trubic','Preradoviceva 7','Krizevci','','CROATIA','48260','385-98-9332-301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:10:00',0,NULL,3,1,2,1,NULL,'trubicboris\r欧标'),(6431,687927513002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','mrkenosuke','kkarta@graduate.uwa.edu.au','Kenneth Karta','2 Eden Close','perth','Western Australia','AUSTRALIA','6150','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-17 12:00:02',0,NULL,3,1,4,1,NULL,'mrkenosuke\rtripod   $16\rYW864871180CN\r'),(6432,647623138001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','anusov-2007','anusovbay@hotmail.com','Anusorn Vanasant','69 Soi Lardpround 110 Yak 3,  Lardpround Rd.<br>Wongthonglang','Bangkok','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:24:24',0,NULL,3,1,2,1,NULL,'anusov-2007'),(6433,647624910001,110566020611,'NEW GGS LCD Screen Protector for Canon EOS 450D 500D',1,'AB2209',7.2,'hermeshine','pi****','dpmzgz@gmail.com','Daniel  Pérez Mendoza','c/ Segundo de Chomon<br>nº12   6ºA','zaragoza','Aragón','SPAIN','50018','677313160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:29:49',0,NULL,5,1,18,0,NULL,'pi****'),(6434,684358304002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.2,'hermeshine','richardenbridge','edith.richard@enbridge.com','Edith Richard','289 Scout Street','Ottawa','ON','CANADA','K2C 4E7','(613) 792-4123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:49:55',0,NULL,5,0,18,0,NULL,'richardenbridge'),(6435,0,110662306866,'New 72mm Rubber 3in1 Collapsible Lens Hood',1,'AB1306',2.99,'hermeshine','hollym666','hollym666@aol.com','Holly Mergogey','83 Tower Rd','Cream Ridge','NJ','UNITED STATES','08514-2428','(732) 226-3320','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 14:13:04',0,NULL,3,1,1,1,NULL,'arthurlumen\r庄'),(6436,647636460001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:01',0,NULL,3,1,17,0,NULL,'alexsrf'),(6437,647636988001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:03',0,NULL,3,1,17,0,NULL,'alexsrf'),(6438,647636861001,110544744106,'Neoprene Protector Camera Cover for Canon 450D 550D M',1,'',6.24,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:02',0,NULL,3,1,17,0,NULL,'alexsrf'),(6439,687965971002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:02',0,NULL,3,1,17,0,NULL,'alexsrf'),(6440,647636768001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:03',0,NULL,3,1,17,0,NULL,'alexsrf'),(6441,647636585001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','alexsrf','sedov_as@yahoo.com','Sedov Alexander','Odesskaya 3-94','Penza','','RUSSIAN FEDERATION','440047','8-8412-448753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:14:04',0,NULL,3,1,3,1,NULL,'52-58mm 双阳环  1\r52-52mm 双阳环  1\r万用遮光罩  1\r肥皂盒 柔光罩   580EX  1\r中号内胆包 canon  1\r热靴保护盖  普通  1'),(6442,647613538001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',5,'AC2302',31.05,'hermeshine','alexandreuehara','uehara73@terra.com.br','Ana Maria Armelin Uehara','Rua Gema 141 Bloco 6 Apart 23<br>Jd São Judas','Diadema','Sao Paulo','BRAZIL','09930290','40913711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 12:50:41',0,NULL,3,1,3,1,NULL,'alexandreuehara\rRA022496428CN'),(6443,647645817001,110414371013,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',11,'hermeshine','rustyreliks','randb@san.rr.com','Betty Gehm','5023 Hilda Rd','San Diego','CA','UNITED STATES','92110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 14:40:47',0,NULL,3,1,1,1,NULL,'rustyreliks'),(6444,647651857001,110583278181,'TianYa 55mm CPL filter New 55 Circular Polarizing C-PL',1,'AA2302',5.7,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:59:34',0,NULL,3,1,17,0,NULL,'esiskandar'),(6445,647595381001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','kalina11111111','kalina._@rambler.ru','Elena Gaykova','per. Severnyi 9-19','Kaliningrad','Russia','RUSSIAN FEDERATION','236029','+79527938458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 11:40:43',0,NULL,3,1,2,1,NULL,'kalina11111111'),(6446,687923392002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 12:00:30',0,NULL,3,1,17,0,NULL,'jdoc6368'),(6447,687949123002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','felipefurtado','felipesfurtado@gmail.com','Felipe Furtado','SQN 308 Bloco J Apto 106<br>Asa Norte','Brasília','Distrito Federal','BRAZIL','70747100','556184577637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 13:16:42',0,NULL,3,1,3,1,NULL,'felipefurtado\rRA022496167CN'),(6448,647602136001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','jdoc6368','info@policlinicaareilza.com','Jorge Zamacona','Dr. Areilza 21 ','Bilbao','País Vasco','SPAIN','48011','652734131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 12:05:26',0,NULL,3,1,4,1,NULL,'jdoc6368\r反光板支架   1\r2m 灯架   1\rb座   2\r柔伞   1\r无字肩带   1\rlighting kit $25\r庄\rYW864871176CN\r\r\r'),(6449,754376688015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',51.9,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-17 15:33:12',0,NULL,3,1,17,0,NULL,'stewebster'),(6450,754383445015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 15:49:07',0,NULL,3,1,17,0,NULL,'stewebster\r徐'),(6451,753287089015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',8.99,'hutongstore','sarahjones522','sarahjones522@hotmail.com','sarah jones','152 kimberley road<br>Roath','Cardiff','Cardiff','UNITED KINGDOM','CF23 5AF','07828928535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 16:53:24',0,NULL,3,1,2,1,NULL,'sarahjones522'),(6452,647696507001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','candyfloss0215','candyfloss@cutey.com','Candace Henson','2239 Cromwell Cir<br>Apt 207','Austin','TX','UNITED STATES','78741-6058','(832) 444-5351','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 17:12:53',0,NULL,3,1,1,1,NULL,'candyfloss0215'),(6453,647709479001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','vincentrozenberg','vincent@voordebuis.com','Vincent Rozenberg','Hoofdlaan 18','ROTTERDAM','','NETHERLANDS','3051XG','0103400440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:45:19',0,NULL,3,1,17,0,NULL,'vincentrozenberg\r庄'),(6454,647682291001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','grotex','dmytropanchyshyn@yahoo.com','Western Bid company','3410 Winnetka Ave N<br>Ste 105','New Hope','MN','UNITED STATES','55427-2091','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 18:26:11',0,NULL,3,1,1,1,NULL,'grotex'),(6455,739398109016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','peterm1906','mccullow@msn.com','peter mccullow','21 austin avenue<br>hartburn','Stockton On Tees','Cleveland','UNITED KINGDOM','ts18 3qn','01642647550','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 20:17:36',0,NULL,3,1,2,1,NULL,'peterm1906'),(6456,687743548002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','shaulialek','alek11@walla.com','Shauli Alek','15','Moshav Sde Ya\'akov','ID','ISRAEL','36586','050-5667720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 14:44:36',0,NULL,3,1,3,1,NULL,'shaulialek\rRA022496269CN'),(6457,687979016002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','arthurlumen','arthurlumengevorgyan@gmail.com','Arthur Gevorgyan','4 Nar-Dos, apt. 44','Yerevan','Yerevan','ARMENIA','0018','0037491471989','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 14:56:12',0,NULL,3,1,3,1,NULL,'arthurlumen\rRA022496198CN\r'),(6458,647698710001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','vincentrozenberg','vincent@voordebuis.com','Vincent Rozenberg','Hoofdlaan 18','ROTTERDAM','','NETHERLANDS','3051XG','0103400440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:17:43',0,NULL,3,1,3,1,NULL,'vincentrozenberg\r单灯头   欧标 1\r一转四 灯头   1\r刘\rRA022496343CN\r'),(6459,647799227001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nilantha722','nilantha_daya@yahoo.com','Nilantha Dahanak','230<br>Ilam road','Chirstchurch','','NEW ZEALAND','8011','02102390080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 20:53:36',0,NULL,3,1,2,1,NULL,'nilantha722'),(6460,647662774001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','dalmatinoid','gasparjurica@gmail.com','Jurica Gašpar','Put Nina 17','Zadar','Dalmatia','CROATIA','23000','+385 98 582 264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 15:36:53',0,NULL,3,1,2,1,NULL,'hollym666\r庄'),(6461,684784692002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','albertgerrard','alberto2_sa@hotmail.com','Alberto Sanz Alegre','Lopez de Hoyos 133 7º 4','Madrid','Madrid','SPAIN','28002','914169314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 21:29:49',0,NULL,3,1,2,1,NULL,'albertgerrard\r刘'),(6462,647682445001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',56.97,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:38:10',0,NULL,3,1,3,1,NULL,'nilantha722\r刘\rRA022496286CN'),(6463,647677287001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','zuhalbizz','zuhalbiz@hotmail.com','Awang  Zuhal','No. 33, Taman Rakyat Mergong','Alor Setar','Kedah','MALAYSIA','43000','04-7337244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:44:23',0,NULL,3,1,2,1,NULL,'peterm1906\r刘\r新地址:\rMOHD LUTFI LOKMAN BAH. TEKNOLOGI MAKLUMAT, KEM. PERTANIAN & INDS. ASAS TANI, ARAS 3 PODIUM, LOT 4G1, WISMA TANI, NO.28 PRESINT 4, 62624 PUTRAJAYA,\r MALAYSIA '),(6464,647688025001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','stefdima-2007','stefdima@yandex.ru','Dima Stefanov','6 Demokraticheskaya street, apartment 56','Samara','Samara','RUSSIAN FEDERATION','443031','+79297000281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 16:52:38',0,NULL,3,1,3,1,NULL,'stefdima-2007\r庄\rRA022496391CN\r'),(6465,687859651002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','bogopolsky1','bog.vadim@gmail.com','vad bogopolsky','motzkin 21 ap 10','netanya','israel','ISRAEL','42460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 17:26:47',0,NULL,3,1,3,1,NULL,'richardenbridge\r徐\rRA022496175CN'),(6466,647799193001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','htnwassenaar','hermanwassenaar@gmail.com','Herman Wassenaar','Torenlaan 72','Blaricum','','NETHERLANDS','1261','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 20:52:33',0,NULL,3,1,3,1,NULL,'htnwassenaar\r刘\rRA022496357CN'),(6467,688194333002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:20:20',0,NULL,3,0,3,1,NULL,'rustyreliks\r庄\r3片装 滤镜袋   1\r50cm 棚   1\r摄影背心绿色 薄款 nikon XL  1\rRA022496431CN\r930\r'),(6468,688199604002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ivanrobe','ivancorreio@yahoo.com.br','Ivan Correa','Rua Rio Espera, 368<br>Carlos Prates','Belo Horizonte','Minas Gerais','BRAZIL','30710-260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:36:25',0,NULL,3,1,2,1,NULL,'sarahjones522\r刘'),(6469,688111893002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','themike38','themike38@shaw.ca','mike hughes','1408<br>17327 69 ave','edmonton','AB','CANADA','t5t3s9','(780) 721-4710','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 22:51:49',0,NULL,3,1,5,1,NULL,'shaulialek\r王\r2m 灯架   2\r斜臂  2\r反光板支架    1\rCP226334973CN\r'),(6471,647507679001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','guit_in_mos','alvogadro2000@gmail.com','Aleksandr Volkov','Kashirskoe shosse, 84-1-379','Moscow','','RUSSIAN FEDERATION','115569','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 04:01:44',0,NULL,3,1,17,0,NULL,'shenker123\r庄'),(6472,647549006001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','chudostepan','her_husband@inbox.lv','Sergejs Nescereckis','Darzu 60-31','Rezekne','Latvia','LATVIA','LV4601','26704742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:13:10',0,NULL,3,1,2,1,NULL,'skarp92\r刘'),(6473,647528638001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','guit_in_mos','alvogadro2000@gmail.com','Aleksandr Volkov','Kashirskoe shosse, 84-1-379','Moscow','','RUSSIAN FEDERATION','115569','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 08:04:15',0,NULL,3,1,5,1,NULL,'guit_in_mos\r2m 灯架    2\r柔光箱 50-70cm 单灯头  欧标  2\r包   1\r一转四 灯头  2\r王\rCP226334987CN\r\r'),(6474,687876767002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 08:16:31',0,NULL,3,1,3,1,NULL,'stefdima-2007\rRA022496312CN\r'),(6475,687886945002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tuah_reno_design','ben_@singapore.com','Tuah .','650C JURONG WEST ST 61<br>#03-244','default','','SINGAPORE','643650','65 91594849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 09:17:24',0,NULL,3,1,11,1,NULL,'tuah_reno_design\r刘'),(6476,647568089001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 09:42:39',0,NULL,3,1,3,1,NULL,'dominiquej999\rRA022496374CN'),(6477,644376224001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',4.4,'hermeshine','nikakvasi','nika.kosir@gmail.com','Nika Ko.ir','Bernekerjeva 22','ljubljana','ljubljana','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-17 09:45:43',0,NULL,3,1,2,1,NULL,'nikakvasi\r庄'),(6478,647433946001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','georgecanitgy','graby0@hotmail.com','gabriel mestre sole','calle montserrat, 7, 1-1<br>calle sant pere, 12','calafell','Tarragona','SPAIN','43820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:23:45',0,NULL,3,1,3,1,NULL,'trubicboris\r镜头筒 中号  1\r反光板 100*150 40*60 5合1  1\rRA022496445CN\r庄\r'),(6479,647562670001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Luda.','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 09:18:04',0,NULL,3,1,3,1,NULL,'fotoivideo\r刘\rRA022496207CN\r'),(6480,647577741001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','0045zetteangel','dj719@hotmail.com','Duzette Johannessen','Algade 72, 1','Vordingborg','','DENMARK','4760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:46:56',0,NULL,3,1,2,1,NULL,'alexandreuehara\r庄\r'),(6481,687907843002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','hun_jz','jugoslavijezeleznice@gmail.com','Balint G.tz','41. Acsadi Strasse','Monor','','HUNGARY','H-2200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 10:41:29',0,NULL,3,1,2,1,NULL,'albertgerrard\r庄'),(6482,647583577001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kajzik','ya_tut_ti_tam@mail.ru','Christina Popova','Rokossovskogo avenue, 115-3','Minsk','','BELARUS','220085','+3757007155','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 10:51:43',0,NULL,3,1,3,1,NULL,'kajzik\r庄\rRA022496330CN'),(6483,647866283001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','999jaby','jaby999@gmail.com','Javier Borja Molina','Tomas Breton 53','Madrid','Madrid','SPAIN','28045','651121336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 00:04:36',0,NULL,3,0,2,1,NULL,'999jaby\r徐'),(6484,739110926016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','sprollieandcollie','nikkicharlton@btinternet.com','nikki charlton','cae poeth<br>abergeirw','dolgellau','Gwynedd','UNITED KINGDOM','ll40 2pf','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-17 08:00:44',0,NULL,3,1,2,1,NULL,'sprollieandcollie\r庄'),(6485,688230000002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','dsincere1','david.l.redick@gmail.com','David Redick','464 jordan stuart circle<br>apt 234','Apopka','FL','UNITED STATES','32703','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 01:23:31',0,NULL,3,1,1,1,NULL,'dsincere1'),(6486,647650851001,110566018220,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',34.84,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 01:33:56',0,NULL,3,0,3,1,NULL,'esiskandar\r55mm 接口环  1\r托架  1\r小号内胆包   1\rlenspen   1\r3pcs 滤镜袋   1\rsony 红外遥控   1\r索尼热靴盖   1\r55mm 天涯cpl    1\rRS-S1   1\r\r刘\rRA022496290CN\r\r\r\r'),(6487,739249516016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','stewebster','stewebster@hotmail.com','Stephen Alan Webster','32 lovett drive','prescot','Merseyside','UNITED KINGDOM','l35 5hj','07891258294','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-17 15:29:20',0,NULL,3,1,4,1,NULL,'stewebster\r绿布  \r英标\rlighting kit  $30\r再加上\r115w220v   2\r2m 灯架  1\r斜臂   1\r50-70 棚 英标  1\r王\rYW864871154CN\r\r'),(6488,688251765002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','tdun824259','tdunagan@grandislandchiro.net','Timothy L. Dunagan','620 N Custer Ave','Grand Island','NE','UNITED STATES','68803-4375','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 02:43:03',0,NULL,3,1,1,1,NULL,'tdun824259\r庄'),(6489,647844441001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','icutu','icutu@aol.com','Drew Schnitt','1001 Avocado Isle','Fort Lauderdale','FL','UNITED STATES','33315-1337','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-17 22:47:18',0,NULL,3,1,1,1,NULL,'icutu\r庄\r中号内胆包  canon    1'),(6490,647772822001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','themike38','themike38@shaw.ca','mike hughes','1408<br>17327 69 ave','edmonton','AB','CANADA','t5t3s9','(780) 721-4710','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 22:51:50',0,NULL,3,0,17,0,NULL,'themike38'),(6491,688189195002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-17 23:20:21',0,NULL,3,1,17,0,NULL,'roquerosolitario'),(6492,647848182001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','roquerosolitario','monticolasolitarius@gmail.com','Isidoro Hidalgo Aguilera','C/ Cerrillo, 20','ALMEDINILLA','Andalucía Ceuta y Melilla','SPAIN','14812','609856643','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-17 23:20:20',0,NULL,3,1,17,0,NULL,'alexandreuehara\rRA022496388CN'),(6493,688270165002,120538959115,'NEW Flash Diffuser for Canon 580EX II',3,'AB3332',7.8,'hermeshine','donnajean0619','treasuredevents@carolina.rr.com','Donna jean Deshaies','710 Bellows Ln','Charlotte','NC','UNITED STATES','28270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 04:03:02',0,NULL,3,1,1,1,NULL,'donnajean0619\r徐'),(6494,688303803002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:40:13',0,NULL,3,1,17,0,NULL,'osmanshawkat'),(6495,647953370001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:44:43',0,NULL,3,1,17,0,NULL,'osmanshawkat'),(6496,647953765001,110566021441,'TianYa ND4 Filter for Cokin P Series Neutral Density',1,'AA2324',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:48:44',0,NULL,3,1,17,0,NULL,'osmanshawkat'),(6497,647953980001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 07:48:43',0,NULL,3,1,3,1,NULL,'osmanshawkat\r天涯方形滤镜  渐变蓝  1\r天涯方形滤镜  ND8  1\r天涯方形滤镜  ND4  1\r天涯方形滤镜  渐变橙   1\r大号内胆包canon   1\r庄\rRA022496961CN'),(6498,688310138002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:14:17',0,NULL,3,1,17,1,NULL,'osmanshawkat'),(6499,647962586001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','e_gedaminas','evaldas_ged@inbox.lt','Evaldas Gedaminas','H. Manto 5-3','Klaipėda','','LITHUANIA','92128','+37068165225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:35:38',0,NULL,3,1,2,1,NULL,'e_gedaminas\r庄'),(6500,645514132018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'',80,'photographyacc','pantis80','jensjohansen@gmail.com','Jens Anton Johansen','Ørneveien 38, 101','Tromsø','Troms','NORWAY','9015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 08:40:17',0,NULL,3,0,4,1,NULL,'pantis80\rbackground  support $25\r2m 背景架  （ 白  黑）  1\rYW864871132CN\r'),(6501,688308108002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','klysner200551','steen@faklysner.dk','steen klysner','laeskovvej 117','Bjaeverskov','sjaeland','DENMARK','4632','45+22687661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 08:05:48',0,NULL,3,0,3,1,NULL,'klysner200551\rRA022496975CN'),(6502,647450707001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','evanswindaching','stevenzilla151@sbcglobal.net','Steven Ching','6220 Calvine Rd','Sacramento','CA','UNITED STATES','95823-5794','(916) 422-0635','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 09:08:24',0,NULL,3,0,1,1,NULL,'evanswindaching\r美国客户帮忙发了，tracking number 是：\r03103200000021098645\r'),(6503,647984734001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 10:23:17',0,NULL,3,1,17,0,NULL,'bluesmansur'),(6504,647788912001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','toggasantiques','toggasbyggatervinning@hotmail.com','Torgny Samuelsson','Lummelundsväg 49','Visby','Visby','SWEDEN','62141','070-1750033','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 10:55:19',0,NULL,3,1,4,1,NULL,'toggasantiques\rbackground support  $20\r2m 背景架   （ 白  黑）   1\rYW864871390CN'),(6505,688349081002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','perteco','quvo@quvo.es','Alejandro Jesus Nieto Fernandez','Calle Ladera de los almendros, 18A, 2ºd','Madrid','Madrid','SPAIN','28032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 11:10:39',0,NULL,3,1,2,1,NULL,'perteco'),(6506,754803367015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',25,'hutongstore','kyodai_studio','krasz76@hotmail.com','Dave Kraszewski','St. Johns College Computer Department<br>St. Johns Street','Cambridge','Cambridgeshire','UNITED KINGDOM','CB21TP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 11:31:29',0,NULL,3,1,3,1,NULL,'kyodai_studio\r英标\rRA022495144CN'),(6507,648013363001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','kojak-with-a-kodak','danny_bowes@hotmail.com','danny bowes, room 523','riverside condo, 324/11 chiang mai lampun road<br>t.nonghoi, a.muang.','chiang mai','thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 12:29:15',0,NULL,3,1,2,1,NULL,'kojak-with-a-kodak\r接口环是67mm的'),(6508,754823738015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','andraz25','andraz_muljavec@t-2.net','Andraž Muljavec','Lojzeta Hrovata 9','Kranj','Slovenia','SLOVENIA','4000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 12:33:51',0,NULL,3,1,3,1,NULL,'andraz25\rRA022496958CN\r'),(6509,688337973002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 10:25:27',0,NULL,3,1,4,1,NULL,'bluesmansur\r2m 灯架   1\rb座   1\r柔光伞    1\r反光板支架   1\rlighting kit    $20\rYW864871386CN'),(6510,688396118002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','charles1713','chasespotshot@aol.com','charles wilkinson','393 Main St','paterson','NJ','UNITED STATES','07501','(201) 406-0589','NoPaymentFailure','CheckoutIncomplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'charles1713'),(6511,648043055001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','metlili','metlilimout@yahoo.fr','Raphael Caputo','16 Luis Vives','Fuenlabrada','Madrid','SPAIN','28946','695167369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 13:59:05',0,NULL,3,1,2,1,NULL,'metlili'),(6512,648029622001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 13:15:04',0,NULL,3,1,1,1,NULL,'xrobertojosuex'),(6513,688414466002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','boon_song_2502','boon_song_2502@hotmail.com','boonsong jiamjitvanicha','166/1 soi.Phachachun20 Phachachun Road, Bangsue,Bangsue','Bangkok','Bangkok','THAILAND','10800','02-5731687','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:55:09',0,NULL,3,1,2,1,NULL,'boon_song_2502'),(6514,648071475001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','halatchev1','halatchev@yahoo.com','peter halatchev','42 Victoria street','Box Hill','Victoria','AUSTRALIA','3128','0412032147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 15:27:54',0,NULL,3,1,2,1,NULL,'halatchev1'),(6515,739765990016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','omuliss','ugis.naglins@gmail.com','Ugis Naglins','Silverlawn 17','Navan','Meath','IRELAND','','0851204884','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 15:57:47',0,NULL,3,1,3,1,NULL,'omuliss\rRA022495175CN\r'),(6516,648081300001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','nomarsavir','ramon.rivas.bcn@gmail.com','Ramon Rivas Lloret','Calle Sant Ramon, 63 - 1º<br>08301 Mataró (Barcelona)','Mataró','Cataluña','SPAIN','08301','680884215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 16:00:11',0,NULL,3,1,4,1,NULL,'nomarsavir\r\rtripod   $20\rYW864871331CN'),(6517,688400598002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sergei_martin','kulverstuukas@gmail.com','Lasuy Sergei','8 Maslova st., арр.52','Monino','','RUSSIAN FEDERATION','141170','(926)2673303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 14:47:41',0,NULL,3,1,2,1,NULL,'sergei_martin'),(6518,688468088002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','karandaev.ea','karandaev@gmail.com','Evgeny Karandaev','Democratic st., 4-21','Samara','Samara obl','RUSSIAN FEDERATION','443031','+79272040151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:21:53',0,NULL,3,1,2,1,NULL,'karandaev.ea'),(6519,688487688002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nikp89','niklauspavlov@gmail.com','Nik Pavlov','8573 Southwestern Blvd<br>Apt 2236','Dallas','TX','UNITED STATES','75206-2350','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 18:11:34',0,NULL,3,1,1,1,NULL,'nikp89'),(6520,688428385002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','franksdirect','fschifano@gmail.com','Frank J. Schifano','112 E Euclid St','Valley Stream','NY','UNITED STATES','11580-4145','(516) 456-6219','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 15:37:20',0,NULL,3,1,1,1,NULL,'franksdirect'),(6521,648153889001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','hugoestevespereira','hugoesteves@gmail.com','HUGO ESTEVES','Av. Prof. Manoel de Abreu<br>n.851 apto.402','Rio de Janeiro','Rio de Janeiro','BRAZIL','20550170','5521 9386-3119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 19:03:46',0,NULL,3,1,2,1,NULL,'hugoestevespereira'),(6522,648084436001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','s4271504','s42715@gmail.com','WAI LAI YIP','FLT2010,BLOCK A,SHEK TO HSE,<br>SHEK WAI KOK EST,TSUEN WAN,NT','default','','HONG KONG','default','(852)63336753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 16:07:02',0,NULL,3,1,2,1,NULL,'s4271504'),(6523,0,130498063928,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',6.49,'hermeshine','rsr1080','rsteven66@gmail.com','Ronald Steven Ran','1080 Carpenters Trace','Villa Hills','KY','UNITED STATES','41017-4414','(859) 331-4837','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-18 19:24:17',0,NULL,3,1,1,1,NULL,'rsr1080'),(6524,648173312001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',2,'AB3321',39.98,'hermeshine','woodsroad','danz1745@comcast.net','Dan Johnson','1745 Walnut Ln','Quakertown','PA','UNITED STATES','18951-2046','(215) 529-4671','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-18 19:44:34',0,NULL,3,1,1,1,NULL,'woodsroad'),(6525,645741852018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','71204k','tru2kbee@sbcglobal.net','James Alexander','2267 E Kirkwood St','Springfield','MO','UNITED STATES','65804-2604','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-18 19:56:27',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871342CN'),(6526,648207233001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','kourepatos','orionas7@hotmail.com','aris kourepis','alexandroupoleos 17','patras','achaia','GREECE','26443','6997189222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:17:00',0,NULL,3,1,17,0,NULL,'kourepatos'),(6527,648215566001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','kourepatos','orionas7@hotmail.com','aris kourepis','alexandroupoleos 17','patras','achaia','GREECE','26443','6997189222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 21:23:12',0,NULL,3,1,2,1,NULL,'52-52mm 双阳环  1\r58-58mm 双阳环   1\r'),(6528,739965569016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','262.5','gregbevf@comcast.net','Gregory Foreman','6283 Dimitri Ct','Magalia','CA','UNITED STATES','95954','(530) 873-8155','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-18 22:40:57',0,NULL,3,1,1,1,NULL,'262.5'),(6529,688614042002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','deloner','kai.pihl.vatland@lyse.net','Kai Vatland','Utslaatten 27','Sandnes','','NORWAY','4332','99610397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 23:04:05',0,NULL,3,1,3,1,NULL,'deloner\rRA022495011CN\r'),(6530,754982878015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','petebest1','pete@fastjapcars.com','Peter Best','65 Ramsbury Avenue','Swindon','Wiltshire','UNITED KINGDOM','SN25NY','07979535123','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-18 18:40:52',0,NULL,3,1,2,1,NULL,'petebest1'),(6531,648269790001,110533631197,'67mm 3-Stage Rubber Lens Hood for D80 D90 18-70mm',1,'AB1305',3.79,'hermeshine','lthurmon','lthurmon@gmail.com','Lauren Thurmon','202 Appleby Rd','Port Wentworth','GA','UNITED STATES','31407-1108','(912) 966-1584','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 00:23:02',0,NULL,3,1,1,1,NULL,'lthurmon'),(6532,688481880002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sirbion','polustudio@yandex.ru','Alexander Pyatiletov','Moscow avenue, 94, 72','Voronezh','Voronezh','RUSSIAN FEDERATION','394068','74732755225','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 17:55:32',0,NULL,3,1,3,1,' ','sirbion\rRA022495025CN\r'),(6533,648217675001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','lucseguin','luc.seguin@videotron.ca','Luc Séguin','388 des Erables','Brownsburg-Chatham','QC','CANADA','J8G 2Y3','(450) 533-5830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 21:26:38',0,NULL,3,1,3,1,NULL,'lucseguin\rRA022496935CN\r'),(6534,688588808002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','har20','wh11630@att.net','William T Harwell','11630 White Cross','San Antonio','TX','UNITED STATES','78253-6019','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-18 21:53:10',0,NULL,3,1,3,1,NULL,'har20\rRA022495039CN\r'),(6535,648309237001,110409866856,'77mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1307',3.79,'hermeshine','jeff_mar','jeff30_ha@yahoo.com','Jefferson Edouasie','8381 Hurlbut St','San Diego','CA','UNITED STATES','92123-2011','(843) 441-2430','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 03:26:19',0,NULL,3,1,1,1,NULL,'jeff_mar'),(6536,688510373002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 19:00:52',0,NULL,3,1,3,1,NULL,'le_juki\rRA022497009CN\r'),(6537,648184827001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','9999196868','giorgos220@gmail.com','GIORGOS PANOYRGIAS','SAXTOYRI 37','ASPROPYRGOS','GREECE','GREECE','19300','6975959524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-18 20:09:59',0,NULL,3,1,2,1,NULL,'9999196868'),(6538,688669992002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','bousympatico','rogerio@videotron.ca','Rogerio Barbosa','4740 Lacombe','Montreal','QC','CANADA','h3w 1r3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 02:39:06',0,NULL,3,1,3,1,NULL,'bousympatico\rRA022495100CN\rxxxl  '),(6539,688587127002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','sincejan5163','sincejan63@gmail.com','Joe  Williams','62 Harnworth Drive','Toronto','ON','CANADA','M2h 3C2','(416) 318-1545','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-18 21:56:44',0,NULL,3,1,3,1,NULL,'sincejan5163\r王\rRA022494991CN'),(6540,688761517002,120601699344,'JueYing Lambency Flash Diffuser for 430EX F36AM P2',1,'AB3308',22,'hermeshine','javivi001','javivi.martinez@gmail.com','JAVIER MARTINEZ CADAVID','C/ Juan Duque 37, 7º 5','Madrid','Madrid','SPAIN','28005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 10:39:01',0,NULL,3,1,3,1,NULL,'javivi001\rRA022495158CN'),(6541,688761858002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','david.fms','david.fms.67@gmail.com','David Martinez Suarez','ROSALIA DE CASTRO 49 - 5A','SANTIAGO DE COMPOSTELA','Galicia','SPAIN','15706','619737362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 10:40:07',0,NULL,3,1,2,1,NULL,'david.fms'),(6542,648336816001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 06:34:53',0,NULL,3,1,3,1,NULL,'shenker123\r RA022495135CN'),(6543,740181199016,260660051361,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','pedroramon2007','mancini6@hotmail.com','pedro  r mancini','avda catalunya  41/43 bajos 1 derecha','badalona','Cataluña','SPAIN','08917','935333089','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 12:47:28',0,NULL,3,1,2,1,NULL,'pedroramon2007'),(6544,648430367001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','alik321','g.ales@seznam.cz','Ales Brenek','Veverkova 11','Ostrava','Hrabuvka','CZECH REPUBLIC','70030','+420737363232','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 13:17:28',0,NULL,3,0,17,0,NULL,'alik321\r'),(6545,648431547001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','alik321','g.ales@seznam.cz','Ales Brenek','Veverkova 11','Ostrava','Hrabuvka','CZECH REPUBLIC','70030','+420737363232','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 13:21:29',0,NULL,3,0,3,1,NULL,'52mm cpl  x  2\r52mm nd8  x  2\r52mm 渐变镜  x  2\r52mm +2 近摄镜  x2\r4片装 滤镜袋   x  2\ralik321\rRA022491071CN'),(6546,648442280001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','ana_pma','ddlua@uol.com.br','Ana Paula Martins de Araújo','Rua Aleixo Jorge, 172/116<br>Perdizes','Sao Paulo','SP','BRAZIL','01259050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 14:04:47',0,NULL,3,1,2,1,NULL,'ana_pma'),(6547,688830602002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:29:56',0,NULL,3,1,17,0,NULL,'pastrayer85022'),(6548,688830440002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:29:59',0,NULL,3,1,17,0,NULL,'pastrayer85022'),(6549,648451955001,110566018419,'72mm 3-Stage Rubber Lens Hood for 80-200mm 24-105mm',1,'AB1306',3.79,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:03',0,NULL,3,1,17,0,NULL,'pastrayer85022'),(6550,648452258001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:05',0,NULL,3,1,17,0,NULL,'pastrayer85022'),(6551,688828806002,120491626264,'58mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1303',3.34,'hermeshine','pastrayer85022','pastrayer@gmail.com','Patrick Strayer','401 E Paradise Ln','Phoenix','AZ','UNITED STATES','85022-2520','(602) 326-9400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 14:30:04',0,NULL,3,0,1,1,NULL,'pastrayer85022\r58mm 橡胶罩   1\r橡胶遮光罩 52mm  1\r橡胶遮光罩 72mm  1\r橡胶遮光罩 67mm   1\r橡胶遮光罩 77mm   1\r'),(6552,688856545002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tremontrods','jschatz@columbus.rr.com','Michael Schatz','3344 Mansion Way','columbus','OH','UNITED STATES','43221-1573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 15:39:20',0,NULL,3,1,1,1,NULL,'tremontrods'),(6553,648285709001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mikelatimer74','mlatimer74@yahoo.com','Mike Latimer','3737 Loretto Rd<br>Apt 208','jacksonville','FL','UNITED STATES','32223','','NoPaymentFailure','CheckoutComplete','Other','2011-03-19 01:31:51',0,NULL,3,1,3,1,NULL,'\rmikelatimer74\r RA022495127CN'),(6554,648523941001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','tmelda','mmichalx@seznam.cz','Michal Macák','miličova 267/4','Vysoké Mýto','CZ','CZECH REPUBLIC','56601','+420608346569','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-19 17:33:10',0,NULL,3,1,3,1,NULL,'tmelda\r62mm CPL 1\r62mm   ND8   1\r62mm   Macro+8    1\r62mm  渐变灰    1\r4片装滤镜袋     1  滤镜不要盒子了\rRA022496913CN'),(6555,688909525002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','marius.krivicius','mkrivicius@gmail.com','Solveiga Kriviciene','Mikalojaus 7-22','Vilnius','','LITHUANIA','01133','+37061519868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 17:45:13',0,NULL,3,1,2,1,NULL,'marius.krivicius'),(6556,688926076002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bank_4nb','bank_4nb@hotmail.com','Charath Petthongchai','23/190 Lumpini Condo Phahol-Sutthisarn<br>Intramara 2 Samsanenai','Phyathai','Bangkok','THAILAND','10400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 18:19:42',0,NULL,3,1,2,1,NULL,'bank_4nb'),(6557,688697701002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','kimballcorson','kimcorson@netzero.com','Kimball Corson','General Delivery','Pago Pago','AS','UNITED STATES','96799-9999','(684) 258-0590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 05:01:14',0,NULL,3,1,1,1,NULL,'kimballcorson'),(6558,689039661002,120571007222,'Neoprene Protector Camera Cover Case Nikon D5000 D80 M',1,'AC2304',6.24,'hermeshine','sdaepsa','ivanazp@gmail.com','ivan ong','6 colonial cir','east norriton','PA','UNITED STATES','19401','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-19 22:20:45',0,NULL,3,1,1,1,NULL,'sdaepsa'),(6559,740475667016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','dark_alucard230782','dave_hamilton66@hotmail.com','David Hamilton','2 Railway Bridge<br>Brackhill','Castlemaine','County Kerry','IRELAND','0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:37:45',0,NULL,3,0,2,1,NULL,'dark_alucard230782\r1.6x2.1 背景布 白色的'),(6560,740476895016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',43.8,'hutongstore','aard.fi','bernd.wachter@gmail.com','Bernd Wachter','Kivääritehtaankatu 1 A 16','Jyväskylä','','FINLAND','40100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:40:39',0,NULL,3,1,17,0,NULL,'aard.fi'),(6561,755635722015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','aard.fi','bernd.wachter@gmail.com','Bernd Wachter','Kivääritehtaankatu 1 A 16','Jyväskylä','','FINLAND','40100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-19 22:44:29',0,NULL,3,1,4,1,NULL,'2m 灯架   1\r反光板支架   1\r斜臂   1\rlight stand  $25\rYW864871351CN'),(6562,740529503016,260660050674,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','ashmills','imagework@btinternet.com','Ash Mills','Dean Cottage, Mulberry Court<br>Sixpenny Handley','Salisbury','Dorset','UNITED KINGDOM','SP5 5AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 01:12:19',0,NULL,3,1,3,1,NULL,'ashmills\rRA022495113CN'),(6563,689055407002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','guanwei6971','guanwei6971@gmail.com','wei guan','81 Empringham Cres.','Markham','ON','CANADA','L3R3E9','(905) 470-0947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-19 23:03:51',0,NULL,3,1,2,1,NULL,'guanwei6971'),(6564,689130445002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','eberles','mellisaeb@gmail.com','Mellisa Eberle','2315 Green Valley Ln','Moody','AL','UNITED STATES','35004-3214','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 03:36:37',0,NULL,3,1,1,1,NULL,'eberles'),(6565,689170633002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','gottikkus','rkoblev@gmail.com','Roman Koblev','Turmalinovskaya 85/12, flat 17','Rostov-on-Don','Rostovskaya oblast','RUSSIAN FEDERATION','344038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 07:29:24',0,NULL,3,1,2,1,NULL,'gottikkus'),(6566,689179559002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:10:10',0,NULL,3,1,2,1,NULL,'tomis.ales'),(6567,689184418002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','mafrin','martin.frolin@gmail.com','Martin Frolin','Malmögatan 23','Helsingborg','','SWEDEN','25252','+46736760050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:35:59',0,NULL,3,1,2,1,NULL,'mafrin'),(6568,648794598001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','888ronc','ronbc@ozemail.com.au','Ron Coker','9/2Fern st','Randwick','New South Wales','AUSTRALIA','2031','0296658863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 08:53:54',0,NULL,3,1,2,1,NULL,'888ronc'),(6569,689198771002,120601700875,'TianYa New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','drewspoon72','wopper@me.com','Drew Wotherspoon','280 Keira St','Wollongong','New South Wales','AUSTRALIA','2500','0467061939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 09:19:14',0,NULL,3,1,2,1,NULL,'drewspoon72'),(6570,648826319001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','happy-j','bragin72@gmail.com','Alexey Bragin','Krasnobogatyrskaya 11 - apt 195','Moscow','Moscow region','RUSSIAN FEDERATION','107564','(909)6299244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 10:25:37',0,NULL,3,1,2,1,NULL,'happy-j'),(6571,648818910001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','jarker28','jarker@hotmail.com','Jack Hu','37 Telfer Road','Castle Hill','New South Wales','AUSTRALIA','2154','61431695139','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-03-20 10:07:05',0,NULL,3,1,4,1,NULL,'jarker28\rreflector holder   $20\rYW864871364CN'),(6572,648857518001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','stuzzystyle','stuessir@gmail.com','Raphael Stüssi','Tannerstrasse 58','Aarau','','SWITZERLAND','5000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 11:45:25',0,NULL,3,1,2,1,NULL,'stuzzystyle'),(6573,648851232001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','suzana1','suzanahorvat@gmail.com','Suzana Ludaš','Šumska 14, Brdovec','Zaprešić, Prigorje brdovečko','Croatia','CROATIA','10291','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 11:29:24',0,NULL,3,1,3,1,NULL,'suzana1\rRA022496944CN\r'),(6574,648869644001,110451008449,'72mm 77 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1306',3.79,'hermeshine','d_man1990','ganelind@mail.tau.ac.il','Daniel Ganelin','8 HaRav Levi Street, Apartment 42','Bat-Yam','','ISRAEL','59647','97235514008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:17:59',0,NULL,3,1,2,1,NULL,'d_man1990'),(6575,648877126001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ronald14669','rjcoulombe@comcast.net','Ronald Coulombe','4 E Sheppard Ln','Chelmsford','MA','UNITED STATES','01824-2215','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 12:36:17',0,NULL,3,1,1,1,NULL,'ronald14669'),(6576,689240628002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','suhadajayamanne','djsuhada@gmail.com','suhada jayamanne','no 197/35A,Padri PioMavatha,Taladuwa ,Negombo,','Negombo','western','SRI LANKA','11500','+94 77 3 611 554','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 11:25:44',0,NULL,3,1,3,1,NULL,'suhadajayamanne\rRA022495056CN\r'),(6577,689279575002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','vincent3483471','vincent.laniel@videotron.ca','Vincent Laniel','222 rue Sainte-Marie','Sainte-Marthe-sur-le-Lac','QC','CANADA','J0N 1P0','(450) 735-4317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 12:49:54',0,NULL,3,1,2,1,NULL,'vincent3483471'),(6578,648885826001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','pbrav','tmptie-dcomp@yahoo.es','Alfonso Alfaro Pelayo','C/Montearagon, 3 pral.dcha.','Zaragoza','Aragón','SPAIN','50013','976591640','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 12:57:51',0,NULL,3,1,3,1,NULL,'pbrav\rRA022495095CN'),(6579,689336271002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','spyros_tav','tavspyros@hotmail.com','Spyros Tavladorakis','Daidalou 10 Ammoudara','Heraklion','Crete/Greece','GREECE','71414','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 14:58:49',0,NULL,3,1,2,1,NULL,'maciek173\r庄'),(6580,689307449002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','vetec_666','vetold@gmail.com','Witold Dondalski','ul. Konopna 34','Torun','kujawsko-pomorskie','POLAND','87-100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 13:56:02',0,NULL,3,1,4,1,NULL,'vetec_666\rtripod  $30\r先发脚架给他，\rYW864871423CN\r随后补袋子（+把手）给他：\rRA117713079CN'),(6581,648884019001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','mushkaboom','wishlist@rock.com','Ania Markowska','3339 Carillion Ave','Mississauga','ON','CANADA','L5C 2A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:04:00',0,NULL,3,1,2,1,NULL,'mushkaboom'),(6582,688393008002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','padua12','coutinho.padua@gmail.com','antonio de padua lima  coutinho','rua thome 120<br>bairro mury','nova friburgo','rio de janeiro','BRAZIL','28615240','55212225421852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 15:51:10',0,NULL,3,1,2,1,NULL,'padua12'),(6583,755983533015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.5,'hutongstore','krisi-b','k.boneva1@gmail.com','Kristina Boneva','1 Brazil House<br>2 Brazil Street','Manchester','Greater Manchester','UNITED KINGDOM','M1 3PW','07871658619','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 15:11:14',0,NULL,3,1,2,1,NULL,''),(6584,756000043015,250599918807,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','joesoap100','theblackburns4@btinternet.com','John Blackburn','10 Atholl,<br>Ouston,','Chester-le-Street,','Durham','UNITED KINGDOM','DH2 1RS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-20 15:35:43',0,NULL,3,1,2,1,NULL,'joesoap100'),(6585,646717446018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','gubat_hill','gubat_hill@yahoo.com','Virgil Rovensky','247 greenfield Cres.','Saskatoon','SK','CANADA','S7R0B6','(306) 717-3217','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-20 18:58:01',0,NULL,3,1,5,1,NULL,'gubat_hill\r8个45w的灯泡换成 4个115w 110v的\rCP226379440CN'),(6586,741041036016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','samgy1','sami.laine@hotmail.com','Sami Laine','orapihlajanpolku 1 b 32','vantaa','Finland','FINLAND','01360','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-20 19:28:11',0,NULL,3,1,2,1,NULL,'samgy1'),(6587,649164138001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','embassylimosine','utokhvre@yahoo.com','Urmas Tokhvre','723 A St NE<br># B','Auburn','WA','UNITED STATES','98002-4026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-20 19:51:55',0,NULL,3,1,1,1,NULL,'sincejan5163'),(6588,646832770018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','817zoealexis','klbeaub1@sbcglobal.net','Nicholas Novak','3065 33rd St NE','Paris','TX','UNITED STATES','75462-3312','(903) 249-9342','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-20 21:12:24',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871375CN'),(6589,741302520016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',2,'AC1301',11,'hutongstore','ffotografo','rui-gaio@hotmail.com','Rui Gaio','Rua de Cabo Verde Lt. 54, 3º esq.','Portimão','Portugal','PORTUGAL','8500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 01:52:35',0,NULL,3,1,2,1,NULL,'ffotografo'),(6590,0,120700660095,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',1.99,'hermeshine','98642john','johnkimball1020@msn.com','J Kimball','1819 NE 209th St','Ridgefield','WA','UNITED STATES','98642-8212','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 03:55:58',0,NULL,3,1,1,1,NULL,'98642john\rLK032882647CN'),(6591,756297969015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','multimati76','multimati@interia.pl','Maciej Janiczek','9 Warrenstown Lawn<br>Blanchardstown','Dublin','Dublin','IRELAND','15','0879707768','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-20 20:33:26',0,NULL,3,1,3,1,NULL,'multimati76\rRA022496927CN'),(6592,689615274002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','elidoskalovich','weedick@walla.co.il','Eli Doskalovich','Hatavor st 23/2','Gan Yavne','','ISRAEL','70800','+972 52 8948493','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 20:53:59',0,NULL,3,1,3,1,NULL,'elidoskalovich\rRA022496887CN'),(6593,689445580002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','compradorveloz','apodo360@aol.com','Matias Curtidor','7231 Boulder Ave<br># 269','highland','CA','UNITED STATES','92346-3313','(909) 831-6440','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-20 17:50:57',0,NULL,3,1,1,1,NULL,'compradorveloz'),(6594,649196077001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','schneidermato','martin.schneider@zoznam.sk','Martin Schneider','Muskatova 2','Pezinok','Slovakia','SLOVAK REPUBLIC','90201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-20 20:44:42',0,NULL,3,1,2,1,NULL,'schneidermato\r庄'),(6595,649368667001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','hammar12','alaiyed@gmail.com','saleh alaiyed','11104 Cavalier Ct','fairfax','VA','UNITED STATES','22030-4914','(571) 335-6742','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 03:27:52',0,NULL,3,1,1,1,NULL,'hammar12\rLK032879890CN'),(6596,649413682001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','majormfrf','shtuchkaz@yandex.ru','Andrey Shtuchka','Yangelya st., 6/74','Baykonur','KZ','KAZAKHSTAN','468320','73362270348','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:04:18',0,NULL,3,1,2,1,NULL,'majormfrf\r庄'),(6597,756362496015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','gioelegio1','giovannettifabio@tin.it','Fabio Giovannetti','via firenze 22','pavona st.','RM','ITALY','00040','348-4075074','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-20 21:52:23',0,NULL,3,0,3,1,NULL,'gioelegio1\r庄\rRA022495918CN\r'),(6598,689841211002,120570269661,'55mm 55 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1302',3.34,'hermeshine','nncnfrmst','syntaxfree+signup@gmail.com','Michelle Quah','16 Amber Gardens<br>#11-02','default','','SINGAPORE','439961','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:42:24',0,NULL,3,1,11,1,NULL,'nncnfrmst\r庄'),(6599,689841966002,120571007311,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','kojak-with-a-kodak','danny_bowes@hotmail.com','danny bowes, room 523','riverside condo, 324/11 chiang mai lampun road<br>t.nonghoi, a.muang.','chiang mai','thailand','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:49:08',0,NULL,3,1,2,1,NULL,'庄'),(6600,689844594002,120571007466,'New Umbrella in Silver 85cm / 33.5\" Photo Studio Light',1,'AD1401',9.9,'hermeshine','danilbokeh','element3200@hotmail.com','Daniil Golubtsov','Kivila 13-79','Tallinn','Harjumaa','ESTONIA','13917','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 08:59:51',0,NULL,3,1,2,1,NULL,'刘'),(6601,689853839002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','uramechii','uramechi@hotmail.com','piyawat chitjaiman','27/147 Rama2 soi 39 BangMod Jomthong','Bangkok','Bangkok','THAILAND','10150','+6694851668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 09:41:42',0,NULL,3,1,2,1,NULL,'uramechii\r庄'),(6602,649041493001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','logova','logova@teleline.es','LORENZO GONZALEZ VAZQUEZ','C/OCCITANIA, 7.','SANT QUIRZE DEL VALLES','Cataluña','SPAIN','08192','650395592','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-20 17:44:45',0,NULL,3,0,3,1,NULL,'logova\rL\r'),(6603,741464595016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','whoray1960','r.gibson874@btinternet.com','Ray Gibson','15 West Carr Road','Retford','Nottinghamshire','UNITED KINGDOM','DN22 7NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 12:21:51',0,NULL,3,1,2,1,NULL,'whoray1960\r庄'),(6604,649473343001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','mrtim63129','timrichards1@juno.com','Tim Richards','2707 Blackforest Dr','Saint Louis','MO','UNITED STATES','63129-4005','(314) 221-7146','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 12:23:01',0,NULL,3,1,1,1,NULL,'mrtim63129\r再加上 77mm 接口环  1\r72mm 接口环   1\r刘'),(6605,689903101002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','origrupo','origrupo@ono.com','Jose Fenoll Perez','Plaza Nueva, 8','orihuela','Comunidad Valenciana','SPAIN','03300','609674147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:49:20',0,NULL,3,1,2,1,NULL,'origrupo\r刘'),(6606,689898648002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:26',0,NULL,3,1,17,0,NULL,'greenzeen'),(6607,649479186001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:30',0,NULL,3,1,17,0,NULL,'greenzeen'),(6608,649478928001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:31',0,NULL,3,1,17,0,NULL,'ricardo-del-rio\r庄'),(6609,689728344002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','ricardo-del-rio','rdr-foto@hotmail.com','Ricardo Garcia Granados','José María Vigil 101-C2<br>Col. Escandón','México','Distrito Federal','MEXICO','11800','5515092737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 00:48:39',0,NULL,3,0,3,1,NULL,'ricardo-del-rio\rRA022495745CN'),(6610,649530760001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3302',5.9,'hermeshine','glenbren','glenbren@gmail.com','E. Brennan','PO Box 46','Fort Covington','NY','UNITED STATES','12937','(450) 371-4891','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 15:46:26',0,NULL,3,1,17,0,NULL,'origrupo\r庄'),(6611,689956104002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','glenbren','glenbren@gmail.com','E. Brennan','PO Box 46','Fort Covington','NY','UNITED STATES','12937','(450) 371-4891','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 15:46:25',0,NULL,3,1,1,1,NULL,'northandos\r刘'),(6612,0,120700927157,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:14',0,NULL,3,1,17,0,NULL,'brockman-woodworks'),(6613,0,110664158425,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:15',0,NULL,3,1,17,0,NULL,''),(6614,0,120700926039,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.55,'hermeshine','brockman-woodworks','brock.kokopelli@gmail.com','Brock  Stokes','298 Spencer Way','Farmington','UT','UNITED STATES','84025','(801) 451-7882','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:11:15',0,NULL,3,1,1,1,NULL,'brockman-woodworks\rLenspen   3\r庄'),(6615,0,110664162846,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','docwifford','docwifford@msn.com','Wayne Ford','2464 Kingfisher Lane','Lincoln','CA','UNITED STATES','95648','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 16:21:23',0,NULL,3,1,1,1,NULL,'docwifford\r庄'),(6616,0,130499736491,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',1.25,'hermeshine','gracious78','happyone78@msn.com','Pansy k Lim','815 E Lucille Ave','West Covina','CA','UNITED STATES','91790-5220','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:11:58',0,NULL,3,1,1,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r申报：Pad support  $15\r庄'),(6617,649570036001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','vasiliy9','vasiliy76@inbox.ru','Василий Нечаев','Алексея Томского 6/2, кв.1','Тверь','Россия','RUSSIAN FEDERATION','170019','+7-905-607-25-68','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 17:18:23',0,NULL,3,1,3,1,NULL,'vasiliy9\r刘\rRA022495590CN'),(6618,0,130499737443,'Genuine Lenspen lens cleaning CANON NIKON just ship USA',1,'AA1310',1.25,'hermeshine','bmooney33','brendan@emooney.com','Brendan Mooney','36 Pequot Ln','East Islip','NY','UNITED STATES','11730-2713','(860) 796-4679','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:34:03',0,NULL,3,1,1,1,NULL,'ke4clu\r刘'),(6619,0,130499738431,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.5,'hermeshine','junbug0024','junbug0024@aol.com','Demosthenes Lao','13930 Valley View Ln','Chino Hills','CA','UNITED STATES','91709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:39:33',0,NULL,3,1,17,0,NULL,'junbug0024'),(6620,0,110664155441,'Genuine Lenspen lens cleaning CANON NIKON just ship USA',1,'AA1310',0.55,'hermeshine','junbug0024','junbug0024@aol.com','Demosthenes Lao','13930 Valley View Ln','Chino Hills','CA','UNITED STATES','91709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 17:40:21',0,NULL,3,1,1,1,NULL,'刘\r'),(6621,649096837001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','maliena_175','maliena_1757@hotmail.com','Nurul Amalina Ahmad Tajudin','NO: 596 Spg 592 Kampong Kasat<br>Negara Brunei Darussalam','Bandar Seri Begawan','Negara Brunei Darussalam','BRUNEI DARUSSALAM','BJ1724','6738804995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 17:55:28',0,NULL,3,1,2,1,NULL,'maliena_175'),(6622,690020608002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ke4clu','gander@nc.rr.com','Richard Anderson','811 Bain St<br>Wayne County Schools','Goldsboro','NC','UNITED STATES','27530-2816','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 18:11:19',0,NULL,3,1,1,1,NULL,'jaynoda\r庄'),(6623,0,110664158071,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','jaynoda','jaynoda@msn.com','Joaquin  G Noda','7803 sw 88st<br>apt# F106','MIAMI','FL','UNITED STATES','33156','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:27:30',0,NULL,3,1,1,1,NULL,'jaynoda\r刘'),(6624,0,130499740752,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.01,'hermeshine','northandos','darrinmascarin@gmail.com','Norhtandos Evolution','9302 Cty Rd #1 RR #1','Palgrave','ON','CANADA','L0N 1P0','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-03-21 20:14:15',0,NULL,3,1,2,1,NULL,'northandos\r庄'),(6625,0,110664164931,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:25',0,NULL,3,1,17,0,NULL,'danbbbb'),(6626,0,110664164620,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:25',0,NULL,3,1,17,0,NULL,'hammar12\r刘'),(6627,0,130499747626,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:26',0,NULL,3,1,17,0,NULL,'danbbbb'),(6628,0,130499746353,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','hellovending','hellovending2002@yahoo.com','Phillip Gillis','827 S. Griffith Ave.','Aurora','MO','UNITED STATES','65605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:47:32',0,NULL,3,1,17,0,NULL,'hellovending'),(6629,649592457001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:30:22',0,NULL,3,1,2,1,NULL,'frankedisson\r欧标\r庄'),(6630,0,120700931159,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:24',0,NULL,3,1,17,0,NULL,'danbbbb\r'),(6631,0,130499748376,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 20:17:23',0,NULL,3,1,1,1,NULL,'danbbbb\rCANON 镜头盖  58mm    5\r庄'),(6632,649684156001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ambaaaaa','amber.hopkins@gmail.com','Amber Hopkins','C/- Harrex Group<br>24 Main Street','Gore','New Zealand','NEW ZEALAND','9710','+64 21 032 2623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 20:57:12',0,NULL,3,1,2,1,NULL,'ambaaaaa'),(6633,649695647001,110566018399,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 21:23:30',0,NULL,3,1,17,0,NULL,'docwifford\r刘'),(6634,649692155001,110566018220,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 21:23:31',0,NULL,3,1,17,0,NULL,'danilbokeh\r67mm 环架   1\r55mm 环架   1\r庄'),(6635,0,130499738735,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.06,'hermeshine','hellovending','hellovending2002@yahoo.com','Phillip Gillis','827 S. Griffith Ave.','Aurora','MO','UNITED STATES','65605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 19:47:11',0,NULL,3,1,1,1,NULL,'hellovending\rCANON 镜头盖  58mm   1\rlenspen    1\r刘'),(6636,649749857001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','shoxpro','shoxpro@mailcity.com','reynald barredo','13890 Sayre st<br>Apt. 218','Sylmar','CA','UNITED STATES','91342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-21 23:47:55',0,NULL,3,1,1,1,NULL,'shoxpro\r渐变灰   1\r72mm 环架   1'),(6637,649735714001,110544744587,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.9,'hermeshine','tiborita','tiborita@gmail.com','Igor Gottardi','Via Piani d\'Isarco, 12','Bolzano','BZ','ITALY','39100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 00:02:11',0,NULL,3,1,17,0,NULL,'tiborita'),(6638,690169246002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','tiborita','tiborita@gmail.com','Igor Gottardi','Via Piani d\'Isarco, 12','Bolzano','BZ','ITALY','39100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 00:02:16',0,NULL,3,1,3,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r申报：Pad support  $15\r庄\rRA022495833CN'),(6639,741824074016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','little.rabbit90','stephanee.huizhen@gmail.com','Stephanie Stephanie','2/18 Courtney Street','North Melbourne','Victoria','AUSTRALIA','3051','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-22 00:38:38',0,NULL,3,1,2,1,NULL,'little.rabbit90\r刘'),(6640,0,120701185557,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.51,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:39:59',0,NULL,3,1,17,0,NULL,'toyoza'),(6641,0,130499966565,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.66,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:01',0,NULL,3,1,17,0,NULL,'toyoza'),(6642,0,110664413594,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.41,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:07',0,NULL,3,1,17,0,NULL,'toyoza'),(6643,0,120701184785,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.31,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:09',0,NULL,3,1,17,0,NULL,'bmooney33\r刘'),(6644,0,120701183675,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.4,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:10',0,NULL,3,1,17,0,NULL,'toyoza'),(6645,0,110664417373,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',1.25,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:10',0,NULL,3,1,17,0,NULL,'toyoza'),(6646,0,110664414547,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.31,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,3,1,17,0,NULL,'toyoza\rttt'),(6647,0,130499965914,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.66,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,3,1,17,0,NULL,'ambaaaaa\r庄'),(6648,0,120701186747,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.81,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:40:16',0,NULL,3,1,17,0,NULL,'toyoza'),(6649,0,110664414937,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.56,'hermeshine','toyoza','bizkung@hotmail.com','Korakod Aphipanya','8810 N Union Blvd','Colorado Springs','CO','UNITED STATES','80920-7798','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 00:41:49',0,NULL,3,1,1,1,NULL,'98642john\r徐'),(6650,757021031015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','bern047','bernard.mannas@gmail.com','Bernard Mannas','244 Broadway','Yaxley','Cambs','UNITED KINGDOM','PE7 3NR','01733761722','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 00:57:08',0,NULL,3,1,2,1,NULL,'bern047\r庄'),(6651,0,110664163695,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 01:20:24',0,NULL,3,1,1,1,NULL,'gubat_hill\r8个45w的灯泡换成 4个115w 110v的\r刘'),(6654,649792100001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ericporto1977','swrswr2x10@hotmail.com','Eric Portelance','1375 des rouges gorges','Saint Jérome','QC','CANADA','J7Z6Z4','(450) 512-4398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 02:20:54',0,NULL,3,1,2,1,NULL,'toyoza\rLenspen  10\r徐'),(6652,689882483002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','peterkremzar','peter.kremzar@gmail.com','Peter Kremzar','Krekova 9','Komenda','','SLOVENIA','1218','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 11:43:28',0,NULL,3,1,3,1,NULL,'0peterkremzar\r庄\rRA022495643CN'),(6653,649464820001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','tampromise2010','tampromise@gmail.com','Kalygin Dmitriy','Kalygin Dmitriy<br>Karbysheva 20-30','Berezovskiy, Kemerovskaya oblast','','RUSSIAN FEDERATION','652427','+79626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:46:38',0,NULL,3,1,2,1,NULL,'tampromise2010\r庄'),(6655,649474987001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','greenzeen','lessz0rs@gmail.com','Zeen Dsouza','12/32 Meron Street','Southport','Queensland','AUSTRALIA','4215','0432677798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 12:54:30',0,NULL,3,1,3,1,NULL,'greenzeen\r机身盖/镜头后盖  Canon\r气吹 + 布\rNIKON 镜头盖 52mm\r小号内胆包 Nikon\r王\rRA022495802CN'),(6656,689906011002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','toxawww','anton.gvozdikov@gmail.com','Anton Gvozdikov','Leninskij prospekt 77-2-242','Moscow','Moscow','RUSSIAN FEDERATION','119261','+79262072089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 13:00:06',0,NULL,3,1,2,1,NULL,'tiborita\r肩架   1\r双灯头 欧标   1\r刘'),(6657,649802115001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','padisolodiver','solo.diver@sbcglobal.net','Jason Wessler','16947 Shea ave','Hazel Crest','IL','UNITED STATES','60429-1348','(708) 422-7300','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 03:06:26',0,NULL,3,1,1,1,NULL,'wienerdude26\r'),(6658,649806915001,110566018257,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',3.34,'hermeshine','deelist','dilysss@gmail.com','Dilys Woo','Blk 726 Woodlands Circle #07-138','default','','SINGAPORE','730726','91373202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 03:23:24',0,NULL,3,1,11,1,NULL,'deelist'),(6659,689916243002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','saponac17','matpor75@aol.com','Matthew Porter','1 Martingale Rd','Amherst','NH','UNITED STATES','03031-2625','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-21 13:32:05',0,NULL,3,1,1,1,NULL,'saponac17'),(6660,689939513002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','ziguitow','ziguitow2@gmail.com','Cauã Csik Lima','Estrada Sorima 222 Barra da Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22611030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:45:14',0,NULL,3,1,3,1,NULL,'ziguitow\rRA022495820CN'),(6661,741520049016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','lukas.hlavacka','lukas.hlavacka@gmail.com','Lukas Hlavacka','Osuskeho<br>3','Bratislava','Slovensko','SLOVAK REPUBLIC','85103','00421908574077','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-21 14:50:52',0,NULL,3,1,2,1,NULL,'lukas.hlavacka'),(6662,649823415001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','vshtern','vladimirshtern@walla.com','Vladimir Shtern','Hazionut 57/27','Ashdod','Non-US','ISRAEL','77456','972546327822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 05:05:05',0,NULL,3,1,2,1,NULL,'vshtern\r徐'),(6663,689864820002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','chad030708','richardpureza08@yahoo.com','Richard Robles Pureza','National Lead Smelting Co. Ltd<br>2nd Industrial Area, Sanaiya','P.O. Box 43169','Riyadh','SAUDI ARABIA','11561','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 10:27:36',0,NULL,3,1,3,1,NULL,'chad030708\rRA022495793CN\rRA022495847CN'),(6664,741552263016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','wondervlad','kovalev.vladimir1990@gmail.com','Vladimir Kovalev','194<br>King\'s College','Cambridge','Cambridgeshire','UNITED KINGDOM','CB2 1ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 16:11:14',0,NULL,3,1,2,1,NULL,'wondervlad'),(6665,740851831016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','fabriferratingtong','f.ferazzini@alice.it','fabrizio ferazzini','via leonardo da vinci 4/6','carobbio degli angeli','BG','ITALY','24060','+393334296872','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-21 10:58:57',0,NULL,3,1,4,1,NULL,'fabriferratingtong\r欧标\rlighting kit  $30\rYW864871434CN'),(6666,689876225002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','kepkeretezo','wasser01@freemail.hu','Vass Gergely','Bolgárkertész utca 13/F; III/12','Budapest','Budapest','HUNGARY','1148','+36304124582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 11:12:57',0,NULL,3,1,5,1,NULL,'kepkeretezo\rCP226379422CN'),(6667,690305511002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','alfarif','alfarif@alfarif.com','Warren Stallworth','3791 Mac Nicholas Ave','Cincinnati','OH','UNITED STATES','45236','(513) 375-2919','NoPaymentFailure','CheckoutComplete','Other','2011-03-22 08:59:26',0,NULL,3,1,3,1,NULL,'alfarif\rRA022494020CN'),(6668,649506961001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','richardrandik','rrandik@gmail.com','Richard Randik','Bohunova 32','Bratislava','','SLOVAK REPUBLIC','81104','+421 944 431 680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 14:15:43',0,NULL,3,1,2,1,NULL,'richardrandik'),(6669,649641906001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','dedamarijan','marijan.forgac1@zg.t-com.hr','Marijan Forgac','D.Domjanica 13','Dugo Selo','','CROATIA','10370','+38512759159','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 19:40:28',0,NULL,3,1,3,1,NULL,'dedamarijan\rRA022495688CN'),(6670,690328614002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gasparitos','fanakov@mail.ru','Artem Fanakov','Sedova str. 55-25','Tyumen','RU','RUSSIAN FEDERATION','625048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 10:45:14',0,NULL,3,1,2,1,NULL,'stevetanner\r刘'),(6671,649897060001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','dekanyz','dekaaa71@gmail.com','Zoltan Dekany','Hitel str. 5','Kecskemet','','HUNGARY','6000','+36209849183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:45:29',0,NULL,3,1,2,1,NULL,'dekanyz'),(6672,649909338001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',6,'AB1302',20.04,'hermeshine','bearmanolith','aloolmez@gmail.com','Alaattin Olmez','Hasan Ali Yucel sok. Senil apt. No:34/36 D.15','Ciftehavuzlar / Kadikoy / Istanbul','Yoksam kapiciya birakin','TURKEY','34728','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:34:23',0,NULL,3,1,3,1,NULL,'bearmanolith\r庄\rRA022494957CN\r'),(6673,690355536002,120581555372,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','kap_t','kapatost@in.gr','Anastasios Kapatos','Agion Anargyron<br>P.O. Box 4310','Epanomi','Thessaloniki','GREECE','57500','0302392041331','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:35:27',0,NULL,3,1,2,1,NULL,'snoz2\r刘'),(6674,756902829015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','snoz2','snoz_2@hotmail.co.uk','Sophie Day','2 mill farm ave','sunbury on thames','London','UNITED KINGDOM','tw167dg','07507130847','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-21 20:42:01',0,NULL,3,0,3,1,NULL,'aliaksei_kaniuka\r徐\rRA022495855CN'),(6675,690109411002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 20:49:29',0,NULL,3,0,3,1,NULL,'arnorolf10\rRA022495816CN'),(6676,649913901001,110566018317,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','scomaroo1','aubin.ma@videotron.ca','MARC AUBIN','342 DU CANTONNIER','ST-AUGUSTIN','QC','CANADA','G3A1N4','(418) 878-4905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:51:33',0,NULL,3,1,2,1,NULL,'ronbj1\r刘'),(6677,757215306015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',25.98,'hutongstore','deuce460','deuce460@aol.com','dave turley','30 keswick road','bexleyheath','kent','UNITED KINGDOM','da7 5du','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 13:26:45',0,NULL,3,1,3,1,NULL,'arnorolf10\r刘\rRA022494869CN'),(6678,690370367002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','elosodelamariola','monteverdi1643@gmail.com','Luis Calvente-Romero','avd/ Blasco Ibanez 27-3','Mislata','Comunidad Valenciana','SPAIN','46920','600697155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:28:42',0,NULL,3,1,2,1,NULL,'elosodelamariola'),(6679,649585249001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','aliaksei_kaniuka','bloodypooh@mail.ru','Shevcov S. V.','Djukovskogo str., 6-1-169','Minsk','','BELARUS','220007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 13:29:53',0,NULL,3,1,2,1,NULL,'aliaksei_kaniuka'),(6680,690381376002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','fdel3335','monteventas@hotmail.com','Felix de la Calle Pastor','C/monasterio Sanmillan Cogolla, 18, AticoB<br>Valladolid','Valladolid','Castilla y León','SPAIN','47015','606042783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 14:05:44',0,NULL,3,1,2,1,NULL,'fdel3335\r庄'),(6681,647588588018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','exousia247','moovman@sbcglobal.net','Armand Buford','1218 Roxton Dr','Saint Louis','MO','UNITED STATES','63137-2139','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-03-22 14:32:52',0,NULL,3,1,4,1,NULL,'灯泡是110v的\rYW864871493CN\rexousia247   '),(6682,0,110664683101,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','stevetanner','stanner@pinpointgroup.com','Steve Tanner','424 Kendall Rd','Churchville','NY','UNITED STATES','14428-9326','(585) 293-2320','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 14:47:48',0,NULL,3,1,1,1,NULL,'elosodelamariola\r徐'),(6683,0,110664682430,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.37,'hermeshine','ken71951','mtnmankrs@yahoo.com','Ken Smith','PO Box 2051<br>2650 Washington Blvd.','Crescent City','CA','UNITED STATES','95531-6051','(707) 218-0719','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:01:52',0,NULL,3,1,1,1,NULL,'ken71951\r58mm 佳能镜头盖   3'),(6684,0,110664688066,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','allgooddeals4u','leonvaf@yahoo.com','Leontios Vafeiadis','3920 Mystic Valley Pkwy','Medford','MA','UNITED STATES','02155-6912','(857) 919-4601','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:07:51',0,NULL,3,1,1,1,NULL,'allgooddeals4u'),(6685,0,120701517236,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.26,'hermeshine','fotojohnyoc','foto_johnyoc@yahoo.com','John O\'Connor','2416 Sheelah Ct','Kettering','OH','UNITED STATES','45420-1127','(937) 479-6700','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:12:11',0,NULL,3,1,1,1,NULL,'fotojohnyoc\r徐'),(6686,690405129002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','akyros360','ikodolemos@yahoo.com','IOANNIS47 KONTOLAIMOS','RAGAVI 25    N FALIRO','ATHENS','eu','GREECE','185 47','2104813053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:24:13',0,NULL,3,1,2,1,NULL,'akyros360'),(6687,0,130500249185,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.06,'hermeshine','udnllc','signsvdc@aol.com','John Temple','2253 E Fairfield St','Mesa','AZ','UNITED STATES','85213-5210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:31:56',0,NULL,3,1,17,0,NULL,'udnllc'),(6688,0,130500248982,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.06,'hermeshine','udnllc','signsvdc@aol.com','John Temple','2253 E Fairfield St','Mesa','AZ','UNITED STATES','85213-5210','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 15:31:57',0,NULL,3,1,1,1,NULL,'udnllc\r橡胶遮光罩 58mm  2'),(6689,0,130500248156,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','ronbj1','ronbj99@yahoo.com','Ronald Johnstone','251 Rodonovan Dr','Santa Clara','CA','UNITED STATES','95051-6605','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 16:20:52',0,NULL,3,1,1,1,NULL,'ronbj1'),(6690,0,120701510787,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','ekkotrading','ebayshop@trading.ekkosolutions.com','Carson Porter','662 W 150 N','Hurricane','UT','UNITED STATES','84737-3408','(435) 229-9331','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 17:08:30',0,NULL,3,1,1,1,NULL,'ekkotrading'),(6691,690179074002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',4,'AKT055',250,'hermeshine','polamsky','vlad.barreto@gmail.com','Vlad da Cunha','Locked Bag 15','Rozelle','New South Wales','AUSTRALIA','2039','0293511051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 23:27:10',0,NULL,3,1,4,1,NULL,'polamsky\rYW864871445CN\r'),(6692,649612105001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','joachimottow','joachim.ottow@gmail.com','Joachim Ottow','Cromhoffsbleekweg 82','Enschede','','NETHERLANDS','7513EW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-21 19:00:17',0,NULL,3,0,2,1,NULL,'joachimottow'),(6693,690472714002,120568072824,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',6.8,'hermeshine','cleg6298','clegnion@yahoo.com','cacy legnion','1701 old omen rd','tyler','TX','UNITED STATES','75701-5130','(903) 330-9350','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:21:34',0,NULL,3,1,1,1,NULL,'cleg6298'),(6694,0,120701515745,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','po box 953','getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:33:48',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6695,650050675001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','alexrubiom','alejandrorubiom@terra.es','Alejandro Rubio Martinez','Narvaez, 60','Madrid','Madrid','SPAIN','28009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:21:37',0,NULL,3,1,3,1,NULL,'alexrubiom\r庄\rRA022494815CN\r'),(6696,756848269015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','zanemangale','zonkis@gmail.com','ZANE MANGALE','LĪDUMA 8-109','RĪGA','','LATVIA','LV-1079','+37129822898','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-21 19:46:50',0,NULL,3,0,5,1,NULL,'zanemangale\r背景架 2m 白  黑  1\rCP226335007CN'),(6697,650063820001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','andrey_rayskiy','andrey.rayskiy@gmail.com','Andrii Raiskyi','vyl. Kudryashova, dom 7-b, kv. 133','Kyiv','','UKRAINE','03035','+380992799787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:51:55',0,NULL,3,1,2,1,NULL,'andrey_rayskiy'),(6698,742227530016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',4,'AA1310',15.12,'hutongstore','ralphm64','ralph.mills@vodamail.co.za','Ralph Mills','PO Box 53657<br>Wierda Park','Centurion','','SOUTH AFRICA','0149','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-22 20:41:48',0,NULL,3,1,2,1,NULL,'joachimottow\r庄'),(6699,0,120701511545,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:12',0,NULL,3,1,17,0,NULL,'basara1013\r徐'),(6700,0,110664683503,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:13',0,NULL,3,1,17,0,NULL,'basara1013\r徐'),(6701,0,130500245633,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:13',0,NULL,3,1,17,0,NULL,'basara1013\r庄'),(6702,0,110664683727,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 21:08:44',0,NULL,3,1,17,0,NULL,'basara1013'),(6703,690130550002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','anderurkiza','hadpersonal@gmail.com','Eugenio Alonso Garcia','Avda. Antigua, 5, 4º C','Zumarraga','País Vasco','SPAIN','20700','655700046','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-21 21:25:37',0,NULL,3,1,4,1,NULL,'anderurkiza\rYW864871412CN\r6662a   1\r67mm 环架   1\r55mm 环架   1\r\r'),(6704,690568435002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','mikeysmom45','bballgirlmikey@aol.com','Micahlyn Allen','SUNDEF<br>UCO','Angers','Pays de la Loire','FRANCE','49100','(336) 482-1028 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:32:04',0,NULL,3,1,2,1,NULL,'mikeysmom45'),(6705,0,130500245972,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','basara1013','eeriepa@gmail.com','Joel Rickenbach','1558 Tanglewood Dr','West Chester','PA','UNITED STATES','19380-5855','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 23:33:11',0,NULL,3,1,1,1,NULL,'basara1013\rCANON 镜头盖  58mm   5'),(6706,0,130500250879,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:10:24',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6707,690628276002,120540612178,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:20',0,NULL,3,1,17,0,NULL,'remiaus'),(6708,650168176001,110566020229,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.19,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:22',0,NULL,3,1,17,0,NULL,'remiaus'),(6709,649812453001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',60.3,'hermeshine','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 00:13:21',0,NULL,3,1,3,1,NULL,'remiaus\r气吹 + 布    1\r麂皮   2\r115w 220v   1\r反光板支架   1\r单灯头 欧标    1\r庄\rRA022494988CN'),(6710,0,120701513489,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:12',0,NULL,3,1,17,0,NULL,'wienerdude26\r庄'),(6711,0,110664685948,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:12',0,NULL,3,1,17,0,NULL,'wienerdude26\r刘'),(6712,0,110664687204,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,3,1,17,0,NULL,'wienerdude26\r庄'),(6713,0,130500249295,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,3,1,17,0,NULL,'wienerdude26\r庄'),(6714,0,110664686965,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:13',0,NULL,3,1,17,0,NULL,'wienerdude26\r庄'),(6715,0,130500248313,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:51:14',0,NULL,3,1,1,1,NULL,'wienerdude26\r58rubber   7   \r\\'),(6716,0,110664685214,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','wienerdude26','cjw26@earthlink.net','Cary Wiener','7100 Shadow Ridge Court','West Hills','CA','UNITED STATES','91307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 00:53:15',0,NULL,3,1,17,0,NULL,'wienerdude26\r庄\r'),(6717,757110095015,250607841646,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',20,'hutongstore','ricardofrajuca','ricardo2509@hotmail.co.uk','Ricardo Silva','27 A Brett Road','LONDON','London','UNITED KINGDOM','E81JP','07706926691','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 07:23:36',0,NULL,3,1,3,1,NULL,'ricardofrajuca\rRA022495317CN'),(6718,649858957001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','alfarif','alfarif@alfarif.com','Warren Stallworth','3791 Mac Nicholas Ave','Cincinnati','OH','UNITED STATES','45236','(513) 375-2919','NoPaymentFailure','CheckoutComplete','Other','2011-03-22 08:52:16',0,NULL,3,1,3,1,NULL,'alfarif\rRA022494033CN'),(6719,690277432002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','niteskie','jweedop@gmail.com','Jade Weedop','756 E 60 S','American Fork','UT','UNITED STATES','84003-2247','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-22 06:13:52',0,NULL,3,1,1,1,NULL,'niteskie\rLK032928295CN'),(6720,649962290001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',9.58,'hermeshine','dollyredshoes','strangekatts@hotmail.com','Audrey Leong','Blk 100, Commonwealth Crescent<br>#07-78','Singapore','','SINGAPORE','140100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 03:09:01',0,NULL,3,1,11,1,NULL,'dollyredshoes\r52mm 橡胶罩   1\r中号内胆包  无字   1\r庄\r'),(6721,649888687001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tony_c77','tony_c@mail.ru','Cheremukhin Anton','Moravsky side str.  3-1-395','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','192289','+79216446366','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 11:16:41',0,NULL,3,1,3,1,NULL,'tony_c77\r刘\rRA022494965CN'),(6722,647600468018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',98,'photographyacc','woojiebear','info@sarahbeebe.com','Sarah Beebe','101B 1477 Glenmore Rd.','Kelowna','BC','CANADA','V1V 2H6','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 03:43:29',0,NULL,3,1,5,1,NULL,'woojiebear\r2m 背景架  （白　黑　灰　蓝）　　１\r１.６ｘ２.１ｍ   \rCP226379467CN'),(6723,757188784015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',2,'AO0001',236,'hutongstore','pastortunde2011','pastortunde@kingdomarena.org.uk','Pastor Tunde Ogedengbe','39 Sunderland Place<br>Shortstown','Bedford','Bedfordshire','UNITED KINGDOM','MK42 0FE','01582405757','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'colossus2011\r庄'),(6724,649843122001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','photoblacktony','antonio99159@hotmail.com','ANTONIO A. RODRIGUEZ MARTINEZ','Rbla. Anselmo Clavé, 49, entlo. 3ª','CORNELLÁ DE LLOBREGAT, BARCELONA','Cataluña','SPAIN','08940','933774268','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 07:33:47',0,NULL,3,0,3,1,NULL,'photoblacktony\rRA022495586CN'),(6725,649902621001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','im.simply.me','naturallymorbid@gmail.com','Matan Eshel','Antot 12A','Tel Aviv','','ISRAEL','69080','0545806362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:28:25',0,NULL,3,0,2,1,NULL,'im.simply.me'),(6726,690701572002,120581555418,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.5,'hermeshine','ike_emi','emhakim@gmail.com','Emil Yagudin','74 Main St','Framingham','MA','UNITED STATES','01702-2952','(508) 270-8844','NoPaymentFailure','CheckoutComplete','Other','2011-03-23 05:02:24',0,NULL,3,1,3,1,NULL,'zaferdefnezafer\r庄\rRA022494492CN'),(6727,690317514002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','sturamironova1','sturamironova@yandex.ru','Yalovegin Andrey','Stalingradskaya,11-120','Volzhsky','Volgograd region','RUSSIAN FEDERATION','404111','+79876484629','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 09:55:18',0,NULL,3,0,3,1,NULL,'sturamironova1\rRA022494930CN'),(6728,690335578002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','garseklis','garseklis@gmail.com','Andrius Paulavicius','Suduviu 50, Gineitiskiu km','Vilniaus raj, Buivydiskiu pst','','LITHUANIA','14166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 11:14:46',0,NULL,3,0,3,1,NULL,'imanolguirado\r徐   \rRA022494886CN\r'),(6729,690410817002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 15:43:20',0,NULL,3,0,3,1,NULL,'shenker123\rRA022494872CN'),(6730,647307652001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','miriamomland','miriam_sk@hotmail.com','Miriam Skår Omland','Opplandsveien 187b','Grimstad','','NORWAY','4885','+47 97176674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 12:34:20',0,NULL,3,0,2,1,NULL,'miriamomland'),(6731,649886392001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','chilla1142','kahuna@bigpond.net.au','P PEACOCK','42 LAKE BREEZE DRIVE','WINDAROO','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 11:00:23',0,NULL,3,0,2,1,NULL,'chilla1142'),(6734,690456013002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','theonewearingbluesocks','tomy_gyeresy@yahoo.com','Tamas Gyeresi','Suseni/130','Sintana de Mures','Mures','ROMANIA','547565','+40740847652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 17:42:04',0,NULL,3,1,2,1,NULL,'theonewearingbluesocks'),(6732,757224275015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','david_garvey_1987','davidgarvey1987@googlemail.com','David Garvey','TRaC, Unit E, South Orbital Trading Park<br>Hedon Rd','Hull','East Riding of Yorkshire','UNITED KINGDOM','HU91NJ','07875236580','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-22 13:52:11',0,NULL,3,0,2,1,NULL,'david_garvey_1987\r刘'),(6733,690718053002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','imanolguirado','imanolguirado@hotmail.com','Imanol Guirado Perez','Avda. Isabel II Nº4, esc. Izq, 1-D','Donostia - San Sebastian','País Vasco','SPAIN','20011','605725709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 06:55:57',0,NULL,3,1,2,1,NULL,'waynehe51\r徐'),(6735,757240502015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','4myclothesuk','myclothesuk@live.com','David Lingard','71 Canada Road','Deal','Kent','UNITED KINGDOM','CT14 7EJ','01304362303','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-22 14:35:46',0,NULL,3,0,4,1,NULL,'4myclothesuk\r燕文   lighting kit  $30\rYW864871482CN'),(6736,757669187015,250692240567,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','micky2009b','m_pbarrett@yahoo.co.uk','Michael Barrett','Turlough','Castlebar','Mayo','IRELAND','000','0877604479','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 09:42:57',0,NULL,3,1,2,1,NULL,'micky2009b\r58mm 接口环  1\r托架   1\r渐变灰   1'),(6737,649451409001,110533631550,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','sokolc','sokol_cekrezi@hotmail.com','sokol cekrezi','Lagja. 4 Rruga  \"skenderbe\"<br>Pallati i Papajve, cel - 0692152285','DURRES','DURRES','ALBANIA','2001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 10:38:56',0,NULL,3,1,2,1,NULL,'欧标'),(6738,650290471001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','7481858','studia5@yahoo.com','Vladimir Kuleshov','Andrianova str. 12-70','Orel','','RUSSIAN FEDERATION','302040','+7-910-748-1858','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 10:55:57',0,NULL,3,1,3,1,NULL,'7481858\rzhuang\rRA022494475CN\r'),(6739,650300004001,110566020814,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',67,'hermeshine','explorer200hiking','shillsborough@aol.com','James Smith','6001 Guess Rd','Durham','NC','UNITED STATES','27712-9279','(919) 471-1198','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 11:16:21',0,NULL,3,1,3,1,NULL,'explorer200hiking\rzhuang\rRA022494461CN'),(6740,647943144018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',90,'photographyacc','justformichelle2008','justformichelle@ymail.com','Thi Bich Tram Pham','8 Belfort Street<br>St Albans','Melbourne','Victoria','AUSTRALIA','3021','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-23 11:22:50',0,NULL,3,1,4,1,NULL,'justformichelle2008\r背景架 2m （ 白 黑 灰  ）   1\r1.6mx2.1m布\r庄\rYW864871471CN\r'),(6741,0,120701919087,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:43:34',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6742,0,120701918812,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:55:01',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6743,0,120701919233,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:56:45',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6744,0,120701919503,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:57:52',0,NULL,3,0,17,0,NULL,'i3izkit311\r'),(6745,0,110665060923,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 13:59:15',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6746,0,130500586320,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:00:43',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6747,0,110665060659,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:02:49',0,NULL,3,1,17,0,NULL,'i3izkit311\r'),(6748,0,110665054116,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:04:05',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6749,0,130500598261,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',1.04,'hermeshine','dcalbrecht','dave@dcdadvancedtech.com','Dave Albrecht','14 Hudson Dr','New Windsor','NY','UNITED STATES','12553-7427','(914) 455-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:31:14',0,NULL,3,1,1,1,NULL,'dcalbrecht'),(6750,0,130500598718,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',0.16,'hermeshine','hayhay1968','colleenball@att.net','Haley Ball','5805 Spring Hollow Dr','Toledo','OH','UNITED STATES','43615-7905','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:37:40',0,NULL,3,1,1,1,NULL,'\r庄'),(6751,0,110665075004,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',0.57,'hermeshine','bonniec9090','bonnie@buildingsolution.net','Bonnie Carroll','1111 Butterworth Ct','Stevensville','MD','UNITED STATES','21666-2580','(443) 223-4696','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:38:56',0,NULL,3,1,1,1,NULL,''),(6752,0,120701930419,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','g_enterprises','bgentle@centurytel.net','Bruce G. Gentle','6909 Buck Jackson Rd','Vernon','AL','UNITED STATES','35592-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 14:44:57',0,NULL,3,1,1,1,NULL,'g_enterprises'),(6753,742560223016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','sav0801','saravanan.anandathiyagar@googlemail.com','Mr Saravanan Anandathiyagar','180 Arrowsmith Road','Chigwell','Essex','UNITED KINGDOM','IG7 4NZ','07525990204','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 14:58:00',0,NULL,3,1,3,1,NULL,'sav0801\r庄\rRA022494444CN'),(6754,0,130500597884,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',0.16,'hermeshine','schee','sdchee@yahoo.com','Sonny D Chee','12629 Centurion Ln','Fairfax','VA','UNITED STATES','22033-1708','(571) 643-9975','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:02:03',0,NULL,3,1,1,1,NULL,'oceoke\r刘'),(6755,0,110665076467,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',0.06,'hermeshine','jshen.1','jshen.1@netzero.net','Jun Shen','1017 Thistle Ct','Sunnyvale','CA','UNITED STATES','94086-9079','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:08:41',0,NULL,3,1,1,1,NULL,'jshen.1'),(6756,690841486002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','speedmadness','richard.l.jongsma@jci.com','Richard Jongsma','7310 Indigo Ridge Dr SW','Byron Center','MI','UNITED STATES','49315-8453','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:17:29',0,NULL,3,1,17,0,NULL,'speedmadness'),(6757,0,130500599988,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.94,'hermeshine','speedmadness','richard.l.jongsma@jci.com','Richard Jongsma','7310 Indigo Ridge Dr SW','Byron Center','MI','UNITED STATES','49315-8453','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:17:30',0,NULL,3,1,1,1,NULL,'speedmadness\rNIKON 镜头盖 77mm   1\r绿叶 UV  77mm   1\rZHN'),(6758,650161988001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','maciek173','mskireco@3web.net','maciek sierminski','33 Fulton Cres.','Whitby','ON','CANADA','L1R2C9','(905) 665-7263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 23:50:16',0,NULL,3,1,2,1,NULL,'maciek173'),(6759,0,110664688516,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.07,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 15:42:34',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6760,650025693001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jammieshopper','ccbonessa@sbcglobal.net','Lisa Newenhouse','122 W Glengate Ave','Chicago Heights','IL','UNITED STATES','60411-1730','(219) 923-1846','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 18:31:04',0,NULL,3,1,1,1,NULL,'jammieshopper'),(6761,650379020001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','324click','hajnrihar.robert@siol.net','Robert Hajnrihar','Kidriceva 19A','Skofja Loka','','SLOVENIA','4220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 15:56:36',0,NULL,3,1,2,1,NULL,'jamesikf\r徐'),(6762,0,110665505012,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.69,'hermeshine','mwunsch1031','mihawunsch@hotmail.com','MiHa Wunsch','10 Bostin Ln','McCleary','WA','UNITED STATES','98557-9433','(360) 878-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:05:32',0,NULL,3,1,17,0,NULL,'mwunsch1031\r\r'),(6763,0,110665076546,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',2.26,'hermeshine','mwunsch1031','mihawunsch@hotmail.com','MiHa Wunsch','10 Bostin Ln','McCleary','WA','UNITED STATES','98557-9433','(360) 878-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:05:33',0,NULL,3,1,1,1,NULL,'gorrionsudaca\r绿叶 UV  77mm    1\r绿叶 UV  72mm    1\rZHN'),(6764,0,120701911230,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','nmphoto22','nmariet@gmail.com','Nicole T','8513 Red Wing Ln','Lanham','MD','UNITED STATES','20706-3858','(240) 678-5545','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 16:17:30',0,NULL,3,1,1,1,NULL,'nmphoto22'),(6765,690543498002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mon_jark','mistamoocow@hotmail.com','Jon-Mark Wiltshire','#303-331 Burnside Road East','Victoria','BC','CANADA','V9A1A6','(250) 858-5930','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 20:36:58',0,NULL,3,1,3,1,NULL,'mon_jark\r庄\rRA022494909CN'),(6766,757811955015,250692241086,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB900',1,'AB3311',32.99,'hutongstore','reapapke25','reapapke@web.de','Rea Papke','Mühlenbrook 9','Kiel','','GERMANY','24106','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 16:34:36',0,NULL,3,1,3,1,NULL,'reapapke25\rRA022494458CN'),(6767,690885711002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','photolady2011','nggphotography@gmail.com','nadeene  gholston','5802 Northwoods Dr','hixson','TN','UNITED STATES','37343-3627','(423) 870-2117','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:13:28',0,NULL,3,1,1,1,NULL,'photolady2011'),(6768,0,110665074671,'New 52mm Rubber 3in1 Collapsible Lens Hood',1,'AB1301',0.16,'hermeshine','2009bikeman','legoskibike@gmail.com','Matthew Richey','19830 SE 328th PL','Auburn','WA','UNITED STATES','98092','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:20:03',0,NULL,3,1,1,1,NULL,'2009bikeman'),(6769,690501330002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','colossus2011','colossus86@gmail.com','dima spivak','Haoren st.  , P.O. box: 5039.<br>Apartment: 7 , building: 11 .','Akko','','ISRAEL','24406','972545303373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 19:19:45',0,NULL,3,1,2,1,NULL,'colossus2011'),(6770,0,120701930739,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',0.84,'hermeshine','waynehe51','heyang51@gmail.com','Yang He','365 S Atlantic Blvd<br>Apt A','Monterey Park','CA','UNITED STATES','91754-3248','(626) 688-2518','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 17:28:05',0,NULL,3,1,1,1,NULL,'waynehe51'),(6771,650121503001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sageata_de_aur','sageata_de_aur@yahoo.com','ionel stanciu','via de gasperi nr 9','ponte di piave','TV','ITALY','31047','0422759544','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 21:46:01',0,NULL,3,1,3,1,NULL,'sageata_de_aur\rRA022494912CN\r申报：  support pad  camera\r $15'),(6772,690525064002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',4,'AC2303',24.84,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 20:05:02',0,NULL,3,1,2,1,NULL,'gorrionsudaca'),(6773,0,130500597993,'Canon 58mm Reverse Adapter Combined shipping discounts',1,'AA1208',1.5,'hermeshine','phoenixsoaring','phoenixsoaring2008@gmail.com','Glen Chin','8778 24th Ave','Brooklyn','NY','UNITED STATES','11214','(646) 807-8182','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 18:52:30',0,NULL,3,1,1,1,NULL,'phoenixsoaring'),(6774,0,110665074742,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.06,'hermeshine','xxxgmoney','theeternal_1@yahoo.com','Daniel Garman','423 Sanford St<br>Apt D','Radford','VA','UNITED STATES','24141-3140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 19:22:43',0,NULL,3,1,1,1,NULL,'xxxgmoney'),(6775,690953390002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 19:37:08',0,NULL,3,1,3,1,NULL,'gulbrandtang\r庄\rRA022494501CN'),(6776,650139915001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','black_hack_magik','archangel23@gmail.com','Robert Coffey','6770 Scott St','Allendale','MI','UNITED STATES','49401','(616) 895-4118','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-22 22:35:55',0,NULL,3,1,1,1,NULL,'i3izkit311'),(6777,690962640002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','nibor626','robinehs@gmail.com','Ilse Taylor','50 Victoria road<br>Bakoven','Cape Town','Western Cape','SOUTH AFRICA','8001','(021)438-8941','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 19:55:46',0,NULL,3,0,3,1,NULL,'nibor626\r欧标\r3个包:\r灯架+棚RA022494210CN\r灯架+棚RA022494237CN\r灯泡+包RA022494223CN\r'),(6778,650208132001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','paulopqdt','prtfoto@yahoo.com.br','Paulo Rosa Teixeira','BRAS DE PINA 617 APT 202<br>VILA DA PENHA','RIO DE JANEIRO','rio de janeiro','BRAZIL','21210673','021 25735432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-23 02:45:15',0,NULL,3,1,3,1,NULL,'paulopqdt\r-liu-\rRA022494489CN'),(6779,0,120701931759,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.17,'hermeshine','marinehacker','djtkatchjr@yahoo.com','duane tkatch jr','PO Box 352','fontana','CA','UNITED STATES','92334-0352','(909) 331-5144','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 20:08:57',0,NULL,3,1,1,1,NULL,'marinehacker'),(6780,690993046002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','jamesikf','jamesipkf@yahoo.com.hk','Ka Fai Ip','Flat A 20/F Fu Bon Court Fortress Garden<br>32 Fortress Hill Road North Point','default','','HONG KONG','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:50:11',0,NULL,3,1,2,1,NULL,'jamesikf'),(6781,690615987002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jotamadrid','jose.tachu@gmail.com','Jose Elías Rodríguez','Calle Plomo, 3A, 1º C','Madrid','Madrid','SPAIN','28045','606696053','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-22 23:33:20',0,NULL,3,1,4,1,NULL,'jotamadrid\r燕文   tripod  $15\rYW864871504CN   '),(6782,690566298002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','vmoreno_es','vtemz03@gmail.com','Vicente Moreno Zafra','C/ Churruca, 4 atico izda.','ALICANTE','Alicante','SPAIN','03003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:26:12',0,NULL,3,0,17,0,NULL,'vmoreno_es\r庄（包含另外一票80cm 5in1）'),(6783,650111773001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vmoreno_es','vtemz03@gmail.com','Vicente Moreno Zafra','C/ Churruca, 4 atico izda.','ALICANTE','Alicante','SPAIN','03003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-22 21:26:13',0,NULL,3,1,2,1,NULL,'vmoreno_es\r80 5in1  1  \r广角托架   1'),(6784,0,120701930813,'Nikon 52mm Reverse Adapter',1,'AA1210',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:23:14',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6785,0,110665075226,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:23:51',0,NULL,3,1,17,0,NULL,'i3izkit311\r'),(6786,0,110665075091,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:24:49',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6787,0,110665075157,'New 77mm Rubber 3in1 Collapsible Lens Hood',1,'AB1307',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:25:19',0,NULL,3,1,17,0,NULL,''),(6788,0,110665075037,'New 72mm Rubber 3in1 Collapsible Lens Hood',1,'AB1306',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:25:57',0,NULL,3,1,17,0,NULL,'i3izkit311\r'),(6789,0,110665074961,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:26:48',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6790,0,130500580318,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:27:44',0,NULL,3,1,17,0,NULL,'trikerexcalibur\rXXL\r'),(6791,0,120701930359,'New 58mm Rubber 3in1 Collapsible Lens Hood',1,'AB1303',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:27:44',0,NULL,3,1,17,0,NULL,'i3izkit311\r'),(6792,0,110665053639,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:28:28',0,NULL,3,1,17,0,NULL,'4myclothesuk\r刘+庄+王'),(6793,0,110665074932,'New 67mm Rubber 3in1 Collapsible Lens Hood',1,'AB1305',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:30:15',0,NULL,3,1,17,0,NULL,'i3izkit311\r'),(6794,0,130500579768,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.11,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:30:21',0,NULL,3,1,17,0,NULL,'xxxgmoney\r庄'),(6795,0,110665053899,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.12,'hermeshine','amishelvis1','amishelvis1@aol.com','Will Shilts','4055 Flatley Rd','Richmond','IN','UNITED STATES','47374-9204','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 22:27:52',0,NULL,3,0,1,1,NULL,'nibor626\r刘'),(6796,691045054002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','proshkin','proxorov@gmail.com','Katerina Adyseva','pr. Shevchenko 33-B, app. 203','Odessa','','UKRAINE','65058','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:49:00',0,NULL,3,1,2,1,NULL,'proshkin'),(6797,650557596001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',3,'AA1210',10.74,'hermeshine','zaferdefnezafer','zaferdefne@hotmail.com','ahmet zafer tunc','569 sk. no. 14. k.1 d.2 osmangazi mah.<br>bayrakli','izmir','','TURKEY','35030','5079464074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 22:50:42',0,NULL,3,1,2,1,NULL,'zaferdefnezafer'),(6798,645213229001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','alati61252','alati61@hotmail.com','ioannis kokologiannis','45 ipsilantou','loutraki','korinthos','GREECE','20300','+302744023333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 00:11:21',0,NULL,3,1,2,1,NULL,'alati61252'),(6799,0,120701930074,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',0.11,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 00:42:48',0,NULL,3,1,17,0,NULL,'danbbbb'),(6800,0,120701912632,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.06,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 00:42:49',0,NULL,3,1,1,1,NULL,'\r'),(6801,690973161002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','oceoke','oceoke01@gmail.com','Miguel Angel Ruiz Santaella','Avda. del Mediterraneo nº 7 2º I<br>Salobreña (Granada)','Salobreña   (Granada)','Andalucía Ceuta y Melilla','SPAIN','18680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:13:44',0,NULL,3,1,2,1,NULL,'oceoke'),(6802,690341645002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','erinjohn','erinjohnreho@yahoo.com','john reho','11 grand port rd','Ocean Pines','MD','UNITED STATES','21811-1520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:27:54',0,NULL,3,1,1,1,NULL,'erinjohn\rLIU'),(6808,0,130500597958,'Canon 52mm Reverse Adapter Combined shipping discounts',1,'AA1207',0.11,'hermeshine','sunniey924','edwardsunnie@gmail.com','Edward Yang','450 S Los Robles Ave<br>Apt 1','Pasadena','CA','UNITED STATES','91101-3256','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:05:02',0,NULL,3,1,1,1,NULL,'sunniey924\r庄\r肩带 pentax 1\r橡胶遮光罩 58mm 1'),(6803,0,120702387044,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:47:44',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6804,0,120702387175,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.12,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:48:06',0,NULL,3,1,17,0,NULL,'i3izkit311'),(6805,0,120701930688,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 01:50:00',0,NULL,3,1,1,1,NULL,'i3izkit311\rCANON 镜头盖  58mm  4\rCANON 镜头盖  67mm  1\rCANON 镜头盖  72mm   5\rNIKON 镜头盖 72mm 1\rNIKON 镜头盖 77mm   1\rNikon  52mm 反接环  1\r橡胶遮光罩 58mm   1\r橡胶遮光罩 67mm   1\r72mm 橡胶罩    4\r橡胶遮光罩 77mm   1\r绿叶 UV  67mm   1\r绿叶 UV  58mm   1\r王'),(6806,742719575016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','rellydasal1976','rellydasal@yahoo.com','Vanessa Buendia','Ceann-Lios, The Twenties','Drogheda','Louth','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-23 20:12:12',0,NULL,3,1,2,1,NULL,'rellydasal1976\r庄'),(6807,650502011001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','hp67210','henripascal@hotmail.fr','Henri PASCAL','3c rue poincaré','OBERNAI','Alsace','FRANCE','67210','0685129515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-23 20:36:55',0,NULL,3,1,2,1,NULL,'hp67210\r庄'),(6809,0,110665058376,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:16',0,NULL,5,0,18,0,NULL,'segalu'),(6810,0,120701912299,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:17',0,NULL,5,0,18,0,NULL,'segalu'),(6811,0,110665054291,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:17',0,NULL,3,0,4,0,'test456','segalu'),(6812,0,120701915368,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:18',0,NULL,5,0,18,0,NULL,'segalu'),(6813,0,120701915892,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:18',0,NULL,3,0,1,1,NULL,'segalu\r发个镜头布给他就行了'),(6814,0,110665054739,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:19',0,NULL,3,0,7,0,' 09980','segaluttsfsfs'),(6815,0,130500582332,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:19',0,NULL,3,0,3,1,'ijk ','fdfsdsegalusssss'),(6816,0,130500581991,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:20',0,NULL,3,0,12,1,'r5 ','sdfsegalu'),(6817,0,110665055914,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 02:59:20',0,NULL,5,0,18,0,' ','segalu'),(6818,0,110665074705,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.93,'hermeshine','richardctchang','richardctchang@yahoo.com','Richard Chang','93 Monterey Road','South Pasadena','CA','UNITED STATES','91030','(626) 285-8578','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 03:22:49',0,NULL,3,1,1,1,NULL,'richardctchang'),(6819,0,130500251284,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.07,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 04:57:31',0,NULL,3,1,1,1,NULL,'usa_global_trader'),(6820,650645592001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','hpsiu1','bensiu_87@hotmail.com','Hou Pan Siu','30 Campden Place','Markham','ON','CANADA','L6C2J8','(905) 887-5351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 05:13:21',0,NULL,3,1,2,1,NULL,'hpsiu1'),(6821,650535801001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','prtycrys26','prtycrystal26@att.net','Crystal Lopez','2188 Coastland Ave<br># 3','San Jose','CA','UNITED STATES','95125-2609','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-23 21:50:31',0,NULL,3,1,1,1,NULL,'prtycrys26'),(6822,758029884015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','newparts11','newpartsebay@gmail.com','auguste banyte','31 hartingdon street','manchester','Lancashire','UNITED KINGDOM','M14 4RW','07963124666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-23 22:58:26',0,NULL,3,1,2,1,NULL,'newparts11'),(6823,650673235001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','msocin','m.socin@virgilio.it','MASSIMO SOCIN','via Premuda, 19','Mestre','VE','ITALY','30171','328/4185377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 08:14:30',0,NULL,3,1,2,1,NULL,'msocin\r\\'),(6824,691176921002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','flaviopetrini','info@flaviopetrini.it','PETRINI, FLAVIO','VIA ZUCCARI 24','ANCONA','AN','ITALY','60129','331-4540741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 08:44:06',0,NULL,3,1,2,1,NULL,'flaviopetrini'),(6825,650688044001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','pazzo_66','plamen66@gmail.com','Plamen Petrov','Luln, bl.427, ap.78','Sofia','Sofia','BULGARIA','1359','359899261269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 09:29:11',0,NULL,3,0,2,1,NULL,'pazzo_66\r方形滤镜接口环 52mm  1\r方形滤镜接口环 49mm   1\r广角托架   1'),(6826,650594079001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bobb77777','bobb77777@hotmail.com','paul camp','23 hillview dr','Drayton','ON','CANADA','n0g1p0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 01:04:43',0,NULL,3,0,3,1,NULL,'bobb77777\rRA022494183CN'),(6827,650650529001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','volka78','v0lka@list.ru','Vladimir Popov','Bebelya<br>110-55','Ekaterinburg','','RUSSIAN FEDERATION','620034','9022534273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 10:45:38',0,NULL,3,1,2,1,NULL,'volka78\r\\'),(6828,0,110665060430,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.59,'hermeshine','highbidderlady02','stephanie@powertranstechinc.com','Stephanie Sedlacek','PO Box 573<br>170236 Co Rd 37','Bayard','NE','UNITED STATES','69334-0573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 13:14:27',0,NULL,3,1,1,1,NULL,'highbidderlady02\r52mm uv   1\r55mm  uv   1\r67mm uv    1\r52-52 双阳环  1\r52-58 双阳环   1\r58-58 双阳环   1\r佳能肩带   1\r72mm 镜头盖  canon   1\r72mm 橡胶罩   1\r\\\r'),(6829,0,130500251466,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 13:55:09',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6830,0,120702380413,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:33',0,NULL,3,1,17,0,NULL,'norabla'),(6831,0,130500953499,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.11,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:34',0,NULL,3,1,17,0,NULL,'volka78\rLIU'),(6832,0,110665495356,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.25,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:34',0,NULL,3,1,17,0,NULL,'norabla'),(6833,0,130500953300,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.26,'hermeshine','norabla','norabla@aol.com','Alan Baron','78 Cherry Ln','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:25:35',0,NULL,3,1,1,1,NULL,'norabla\rNIKON 镜头盖 52mm  4\r'),(6834,0,130500953920,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','2009bikeman','legoskibike@gmail.com','Matthew Richey','19830 SE 328th PL','Auburn','WA','UNITED STATES','98092','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:40:00',0,NULL,3,1,1,1,NULL,'2009bikeman\r\r'),(6835,0,120702383009,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:12',0,NULL,3,1,17,0,NULL,'danbbbb'),(6836,0,120702381381,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:12',0,NULL,3,1,17,0,NULL,'danbbbb'),(6837,0,120702382885,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.01,'hermeshine','danbbbb','khdb0000@hotmail.com','Dan Basgall','2568 Poplar Xing','York','SC','UNITED STATES','29745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 14:48:13',0,NULL,3,1,1,1,NULL,'danbbbb\r62mm 橡胶罩   2\r55mm 橡胶罩   1\r\\\r\r'),(6838,743067466016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','leepfp','lee4pfp@btinternet.com','Mr L Howell','Lake Cottage, Church Lane<br>Saul','Gloucester','Glos','UNITED KINGDOM','GL2 7JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 14:51:41',0,NULL,3,1,17,0,NULL,'leepfp\r'),(6839,743066963016,260660051651,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D S',1,'AC2305',5.5,'hutongstore','leepfp','lee4pfp@btinternet.com','Mr L Howell','Lake Cottage, Church Lane<br>Saul','Gloucester','Glos','UNITED KINGDOM','GL2 7JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 14:51:41',0,NULL,3,1,2,1,NULL,'leepfp\rlenspen   1\r中号内胆包 canon    1\r\\'),(6840,650775994001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','skotsomitis','spikots@hotmail.com','kotsomitis spiros','ISIODOU 7','KOROPI','GREECE','GREECE','19400','+306936968226','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 15:17:49',0,NULL,3,0,3,1,NULL,'skotsomitis\rRA022494387CN'),(6841,758109058015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','moet16','rnewbery@optusnet.com.au','Robyn Newbery','9 Boyce Street','Ryde','New South Wales','AUSTRALIA','2112','0298781103','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 03:01:06',0,NULL,3,1,2,1,NULL,'moet16\rLIU'),(6842,0,120700932244,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.02,'hermeshine','maliysem','vdsem@aol.com','vadim  semenov','3409 northrop ave','sacramento','CA','UNITED STATES','95864-5026','(916) 320-2790','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:22:09',0,NULL,3,0,1,1,NULL,'maliysem\rCANON 镜头盖  58mm  2'),(6843,0,120701910155,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','goodstoyou','kenofsimi@yahoo.com','Kenneth DeNunez','2373 Morley St','Simi Valley','CA','UNITED STATES','93065-3630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 16:53:16',0,NULL,3,1,1,1,NULL,'goodstoyou'),(6844,650803096001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','electro5555','ilkka.rutanen@kymp.net','Ilkka Rutanen','Juustenintie 3 H 96','Helsinki','Pirkanmaa','FINLAND','00410','3583730773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 16:35:29',0,NULL,3,1,2,1,NULL,'electro5555\r\\'),(6845,691317848002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 17:17:13',0,NULL,3,1,3,1,NULL,'arnorolf10\rRA022495997CN'),(6846,0,130500953029,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.2,'hermeshine','molle444','molle4444@gmail.com','Anders Moldén','528 Hale Hall','Storrs','CT','UNITED STATES','06269','617 416 5952','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 19:29:01',0,NULL,3,1,1,1,NULL,'2009bikeman\rZHUANG'),(6847,650885406001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','synthesis','propq@hotmail.com','Quintin Erasmus','35 River Drive Mews,<br>The Circus ave, Three Rivers','Vereeniging','Gauteng','SOUTH AFRICA','1935','+27839557246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:47:04',0,NULL,3,1,2,1,NULL,'synthesis\r\\'),(6848,650842510001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','andreatoth22','andrea.toth@st.t-com.hr','Andrea Toth','Kroz Smrdečac 11','Split','AZ','CROATIA','21000','+385993000309','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 18:19:17',0,NULL,3,1,3,1,NULL,'andreatoth22\rRA022496003CN'),(6849,650937662001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',2,'AC1204',15.8,'hermeshine','travelindaze','islands_11@earthlink.net','Lata Lightsey','1606 Phelps Rd','Courtland','MS','UNITED STATES','38620','(662) 934-0765','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:22:32',0,NULL,3,1,1,1,NULL,'travelindaze\r\\'),(6850,0,110665503034,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:36',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6851,0,130500956771,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:37',0,NULL,3,1,17,0,NULL,''),(6852,0,110665498129,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:38',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6853,0,130500956952,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:38',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6854,0,130500957195,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:39',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6855,0,110665498884,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:40',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6856,0,130500955020,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:40',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6857,0,130500957362,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:41',0,NULL,3,1,17,0,NULL,'ragginghoe'),(6858,0,120702381909,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','ragginghoe','daddythebig@hotmail.com','kevin shook','19845 n harrah rd','luther','OK','UNITED STATES','73054-9831','(405) 664-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-24 22:23:41',0,NULL,3,1,1,1,NULL,'ragginghoe\rCANON 镜头盖  58mm  4\r绿叶 UV  58mm   5\r\\'),(6859,691386255002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','magugwana','gugulakhe@hotmail.com','Gugulethu Sibiya','P O Box 30540','Richards Bay','KwaZulu Natal','SOUTH AFRICA','3900','0839810238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 19:46:58',0,NULL,3,1,3,1,NULL,'magugwana\r潘\rRA022492386CN\r\\'),(6860,650964630001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','onlineshop*2009','ivantocao@live.com.ph','ivan tocao','unionbank of the philippines<br>quibod complex, rizal street','davao city','davao del sur','PHILIPPINES','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 22:47:39',0,NULL,3,1,17,0,NULL,''),(6861,648670230018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','dmalhaz','rn3qc@mail.ru','Sergey Chernykh','Vokzalnaya 53','Voronezh','','RUSSIAN FEDERATION','394024','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-24 22:48:27',0,NULL,3,1,5,1,NULL,'dmalhaz\rCP226379475CN\r'),(6862,650974731001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','onlineshop*2009','ivantocao@live.com.ph','ivan tocao','unionbank of the philippines<br>quibod complex, rizal street','davao city','davao del sur','PHILIPPINES','8000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 23:20:56',0,NULL,3,1,2,1,NULL,'onlineshop*2009\r52-52mm 双阳环  1\rnikon 反接环  52mm   1\r\\'),(6863,691396679002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','trikerexcalibur','guenther@chello.at','Günther Moro','Hillerstrasse 6/7','Wien','','AUSTRIA','A-1020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 20:06:02',0,NULL,3,0,3,1,NULL,'trikerexcalibur\rXXL\rRA022494373CN'),(6864,0,130500955593,'New 62mm Rubber 3in1 Collapsible Lens Hood',1,'AB1304',0.3,'hermeshine','fsgor','fainasamg@gmail.com','Semen Gorelov','6627 N Mozart St','Chicago','IL','UNITED STATES','60645-4307','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 00:28:13',0,NULL,3,1,1,1,NULL,'fsgor'),(6865,0,120702380945,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','arrielle78','homeyertx@yahoo.com','Arrielle Homeyer','532 17th st','niagara falls','NY','UNITED STATES','14301-2216','(716) 345-0814','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 00:42:44',0,NULL,3,1,1,1,NULL,'arrielle78'),(6866,650895096001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','aok_antti','antti.kansala@gmail.com','Antti Känsälä','Louhentie 13 a 3','Espoo','Espoo','FINLAND','02130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 20:05:18',0,NULL,3,1,3,1,NULL,'aok_antti\rRA022491916CN\r'),(6867,0,130500956587,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.3,'hermeshine','myhustle09','vietcrimeboss@yahoo.com','James Vu','1556 Spruce st','Placentia','CA','UNITED STATES','92870','(626) 533-6391','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:11:13',0,NULL,3,1,1,1,NULL,'myhustle09'),(6875,691439867002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,17,0,NULL,'datoow78'),(6868,758499071015,250621659362,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','farhangroosta','farhang_roosta@yahoo.com','farhang roosta','Friskväderstorget 4 läg 421','Göteborg','Göteborg','SWEDEN','41838','0046-31-3307327','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-24 21:24:05',0,NULL,3,1,2,1,NULL,'farhangroosta\r\\'),(6869,0,110665497444,'New 55mm Rubber 3in1 Collapsible Lens Hood',1,'AB1302',0.01,'hermeshine','arx808','weondaair808@aol.com','Lorelie Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:31:16',0,NULL,3,1,1,1,NULL,'arx808\r\\'),(6874,650762587001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',56.03,'hermeshine','nightdesigner1981','nightdesigners@gmail.com','Liubou Kazakova','Денисовская, 41-2-5','Минск','','BELARUS','220006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 02:06:51',0,NULL,3,1,3,1,' ','nightdesigner1981\rRA022494395CN\r\\\r'),(6870,650935282001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','AU_SmallParcels','0000-00-00 00:00:00',0,NULL,3,1,4,1,NULL,'datoow78\r大力夹   1\r80cm 2in1 反光板   1\r反光板支架   1\r斜臂    1\rboom arm $25\rYW864871526CN\r\r'),(6871,0,120700660253,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',1.99,'hermeshine','tapdure','mondzeu_v@yahoo.com','Francis Seftel','87 Fairway Drive','Daly City','CA','UNITED STATES','94015','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 01:44:27',0,NULL,3,1,1,1,NULL,'tapdure\r\\'),(6872,650937525001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,3,1,17,0,NULL,'datoow78'),(6873,691439996002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,17,0,NULL,'datoow78'),(6876,0,130500958384,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.01,'hermeshine','jayceew','jcwumail@gmail.com','Jinchong Wu','123 Golden Meadow Ln','Franklin','TN','UNITED STATES','37067','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 04:17:25',0,NULL,3,1,1,1,NULL,'jayceew'),(6877,691477665002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','denybarboza','denyzinho@gmail.com','Paulo Cesar Neves Barboza','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-24 23:15:51',0,NULL,3,1,3,1,NULL,'denybarboza\r\\\rRA022492134CN\r'),(6878,0,130500251599,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','107 Springville Ave','Buffalo','NY','UNITED STATES','14226-3117','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 04:39:34',0,NULL,3,0,1,1,NULL,'usa_global_trader'),(6879,650966613001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','gfcodo','gianfrancocod@tiscali.it','Gianfranco Codognotto - PROTEAM Srl','Via 25 Aprile, n° 51','BARLASSINA','MI','ITALY','20825','3289646230','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-24 22:56:37',0,NULL,3,1,3,1,NULL,'gfcodo\rreflector holder  $15\rRA022492103CN\r\\'),(6880,650992852001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','phan2om','sudden@gmail.com','Stephan Witane','106 Lindvest Crescent','Maple','ON','CANADA','L6A 4N2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 00:29:58',0,NULL,3,1,2,1,NULL,'phan2om\r\\'),(6881,758581583015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 00:42:20',0,NULL,3,1,4,1,NULL,'bob9038\r柔光箱 60-60cm  四灯头  2\rlight  $22\rYW864871515CN\r'),(6882,758396232015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','rafal6767','kkkwiatuszek@poczta.fm','Rafal Kwiatkowski','36 Burlington Road','Coventry','West Midlands','UNITED KINGDOM','CV2 4QH','07727249258','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 05:57:50',0,NULL,3,1,2,1,NULL,'rafal6767\r\\'),(6883,758519159015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','james670_0','jamescombe@supanet.com','James Combe','7 Spey Road Craigellachie  Aberlour','Elgin','Moray','UNITED KINGDOM','ab389ta','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:47:49',0,NULL,3,1,2,1,NULL,'james670_0\r\\'),(6884,758563088015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-24 23:48:19',0,NULL,3,1,17,0,NULL,'bob9038'),(6885,651067838001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','vlinder301','sgsub@earthlink.net','Suzanne Gedance','232 Wakeman Ave','Wheaton','IL','UNITED STATES','60187-3664','(630) 588-8533','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 07:15:01',0,NULL,3,1,1,1,NULL,'vlinder301'),(6886,651072247001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','markobaric','marko_baric@yahoo.com','Marko Baric','Hektoroviceva 11B','Solin','Splitsko-dalmatinska','CROATIA','21210','021-244-346','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 07:40:58',0,NULL,3,1,3,1,NULL,'markobaric\r\\\rRA022491981CN\r'),(6887,743449611016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',3,'AA2217',20.85,'hutongstore','futureshop.fi','smartbuy.fi@gmail.com','Vladimir Novikov','Karstulantie 10 A 5','Helsinki','Uusimaa','FINLAND','00550','0451224100','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 08:09:22',0,NULL,3,1,3,1,NULL,'futureshop.fi\rRA022492001CN\r\\'),(6889,651050591001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','migggo','m.junttila@ovi.com','Mikko junttila','Kurkihirrentie 3C22','Oulu','','FINLAND','90540','358451271086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 05:10:04',0,NULL,3,1,2,1,NULL,'migggo'),(6888,651087801001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','godzila-zk','godzilazk@seznam.cz','Zdeněk Krňanský','Tloskovská 248','Neveklov','','CZECH REPUBLIC','25756','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 08:58:53',0,NULL,3,0,3,1,NULL,'godzila-zk\r发 52mm CPL+ND8+Macro+2 +Gradual grey+filter case \r潘\r刘\rRA022492284CN\r'),(6890,691604433002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','mamaneos','majikm@azet.sk','Ing. Marian Majik','3 Allee des Charmes','Luxembourg','','LUXEMBOURG','L-1372','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:15:54',0,NULL,3,1,2,1,NULL,'mamaneos\r、'),(6891,651054801001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 05:43:49',0,NULL,3,1,3,1,NULL,'shenker123\rRA022492094CN'),(6892,691609318002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','2011*annak','farciara84@wp.pl','anna kramek','40 woodview','castlebridge','Wexford','IRELAND','1','0871466066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:29:31',0,NULL,3,1,2,1,NULL,'2011*annak\r、'),(6893,651059113001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',18.99,'hermeshine','nabelrock','marcusbabao@yahoo.com','Marcus Babao','Blk 627 Yishun Street 61, #09-79, Singapore','default','','SINGAPORE','560627','(65)92311107','NoPaymentFailure','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'nabelrock\rRA022492085CN\r、加到这行了'),(6894,651060041001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','susu361','suhairie@gmail.com','suhairi suhadah','Hong Leong Investment Bank Berhad<br>Level 8, Menara HLA, No. 3 Jalan Kia Peng','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50450','0123992524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 06:22:38',0,NULL,3,1,2,1,NULL,'susu361'),(6895,651097640001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','arteemusica','mirbus@libero.it','Mirko Buschiazzo','C.so Sebastopoli 240','Torino','TO','ITALY','10100','3476826031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 09:46:07',0,NULL,3,1,2,1,NULL,'arteemusica\r、'),(6896,651113689001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',19.8,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 10:55:38',0,NULL,3,1,11,1,NULL,'gulbrandtang'),(6897,691263151002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','lenagon','lena.goncharov@gmail.com','Elena Goncharov','Ben Zvi Izhak12/41','K.Mozkin','','ISRAEL','26230','972544475325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 04:59:51',0,NULL,3,1,3,1,NULL,'\rRA022492117CN\rlenagon'),(6898,648847294018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','xavifrias','xfriasahs@yahoo.es','Xavier Frias Garrido','Iris 15<br>Martí Julià 11-17','BADALONA','Cataluña','SPAIN','08911','934642711','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-25 12:24:12',0,NULL,3,1,4,1,NULL,'xavifrias\r2m 背景架   1\r1.6x2.1  背景布 （ 白 黑）\rYW864488384CN\r'),(6899,691651268002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','raqmaci2010','raqmaci@hotmail.com','Raquel Macías Cabrera','Tirso de Molina, 18, 2ºD','Valladolid','Castilla y León','SPAIN','47010','983258813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 12:35:03',0,NULL,3,1,2,1,NULL,'raqmaci2010'),(6900,758795212015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',4.68,'hutongstore','iwanoff81','iwanfokin@yahoo.com','Iwan Fokin','van alkemadelaan 359','Den Haag','','NETHERLANDS','2597BA','0619552505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-25 14:04:37',0,NULL,3,1,2,1,NULL,'iwanoff81'),(6901,691671753002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:51:07',0,NULL,3,1,3,1,NULL,'a.buragohain\rRA022491690CN、'),(6902,651159960001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:51:06',0,NULL,3,1,3,1,NULL,'a.buragohain\rRA022491743CN、'),(6903,651161778001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','glenviewpark','panola.carter@gmail.com','Panola Carter III','2462 Zanone Ave','Memphis','TN','UNITED STATES','38114-2463','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 13:55:14',0,NULL,3,1,3,1,NULL,'glenviewpark\rRA022491726CN、'),(6904,651170994001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','regon7','jotafoto@yahoo.es','Francisco Javier Replinger Gonzalez','C/ Opera Carmen 65- 3ºB<br>Eurohogar II','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41007','687790888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 14:25:49',0,NULL,3,1,2,1,NULL,'regon7'),(6905,691661726002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','diavoletto1985','diavoletto85@yahoo.it','Stefano Messerville','Viale Madrid cond. ITALCO 4C','Frosinone','FR','ITALY','03100','3807972732','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 13:20:41',0,NULL,3,1,3,1,NULL,'diavoletto1985\rRA022491788CN、'),(6906,0,120702823957,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:15',0,NULL,3,1,17,0,NULL,'elmster1st'),(6907,0,110665938748,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:19',0,NULL,3,1,17,0,NULL,'elmster1st'),(6908,0,130501322310,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.16,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:22',0,NULL,3,1,17,0,NULL,'elmster1st'),(6909,0,110665932682,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:22',0,NULL,3,1,17,0,NULL,'elmster1st'),(6910,0,130501318196,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:26',0,NULL,3,1,17,0,NULL,'elmster1st'),(6911,0,120702819181,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:26',0,NULL,3,1,17,0,NULL,'elmster1st'),(6912,0,110665933257,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.06,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 14:41:30',0,NULL,3,1,17,0,NULL,'elmster1st'),(6913,0,120702823792,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.01,'hermeshine','elmster1st','elmster@charter.net','Jeff Anderson','813 W Rainbow St','Roseburg','OR','UNITED STATES','97471-2659','(541) 733-7457','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-25 14:41:31',0,NULL,3,1,1,1,NULL,'elmster1st\rNIKON 镜头盖 52mm   4\rNIKON 镜头盖 62mm   4'),(6914,691690666002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','sousamlis','sousamli@hol.gr','Petros Sousamlis','Mirogianni 2A','Mitilini','','GREECE','81100','302251023728','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 14:36:36',0,NULL,3,1,4,1,NULL,'sousamlis\r欧标\rYW864488373CN\r'),(6915,758712509015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','neilukd','neildharris@sky.com','Neil Harris','23 Jardine Close','Stourbridge','West Midlands','UNITED KINGDOM','DY8 4AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 09:55:52',0,NULL,3,0,3,1,NULL,'neilukd\rRA022491933CN'),(6916,691698314002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','antoshka8877','a.n.t.o.s.h.k.a@mail.ru','Антон Джавадян','ул. Набережная, д.59','Пятигорск','Ставропольский край','RUSSIAN FEDERATION','357500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 15:01:15',0,NULL,3,1,3,1,NULL,'antoshka8877\rRA022491448CN、'),(6917,651209540001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','gil540','gillesdemenois@wanadoo.fr','GILLES   DEMENOIS','540 RUE DE DONNERY','MARDIE','Centre','FRANCE','45430','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 16:22:32',0,NULL,3,1,3,1,NULL,'gil540\r、\rRA022491902CN'),(6918,648928361018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','erminbeg1','erminbeg@gmail.com','Begovic Ermin','Porodice Foht 82','Sarajevo','Sarajevo','BOSNIA AND HERZEGOVINA','71000','+38762105157','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-25 16:23:04',0,NULL,3,1,5,1,NULL,'erminbeg1\r1.6m 背景架  1\r白 黑  1.6x2.1\r申报 gift  $10\rCP226379484CN\r'),(6919,0,130500954588,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.06,'hermeshine','mrscat70','kats1964@yahoo.com','Kimberly Hazzard','155 E Monroe St','Auburn','IL','UNITED STATES','62615-1523','(217) 960-3517','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 17:00:23',0,NULL,3,1,1,1,NULL,'mrscat70'),(6920,0,120702820986,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.11,'hermeshine','carlosvincenzo','carlosdv@microsoft.com','Carlos De Vincenzo','9012 229th PL NE','Redmond','WA','UNITED STATES','98053-2067','(425) 836-9309','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 17:03:12',0,NULL,3,1,1,1,NULL,'carlosvincenzo'),(6921,691803124002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','bglytle','blytle@ups.com','Brooke Lytle','15 Ogden Ter','Butler','NJ','UNITED STATES','07405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-25 19:25:34',0,NULL,3,1,1,1,NULL,'bglytle'),(6922,651011602001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',68.3,'hermeshine','konischev','paraidey@yandex.ru','Maxim Konischev','N. Ostrovskogo St.<br>162/1, 104','Astrakhan','','RUSSIAN FEDERATION','414022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-25 15:25:35',0,NULL,3,1,3,1,NULL,'konischev\r反光板支架  1   \r肩架   1 \r发两个小包给他\rRA022491880CN\rRA022492205CN'),(6923,651309327001,110618902967,'Pro Photo Vest Blue for Canon 500D 550D 7D 60D  user',1,'AA2116',32,'hermeshine','btf5a','bradfoster@comcast.net','Bradley Foster','501 Enola Rd.','Pikesville','MD','UNITED STATES','21208','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 20:17:01',0,NULL,3,1,1,1,NULL,'btf5a\rxxl'),(6924,758988437015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','optiker72','waznyadres@gmail.com','Peter Kanka, Bush Opticians Laboratory','337 Holderness Road','Hull','North Yorkshire','UNITED KINGDOM','HU8 8RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 20:34:05',0,NULL,3,1,3,1,NULL,'optiker72\rRA022491862CN\r、'),(6925,651231864001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3301',27.5,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 20:35:37',0,NULL,3,1,3,1,NULL,'elpeladoedu\rRA022491261CN、'),(6926,651337295001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','ishkabibble','john_stephenson@bellsouth.net','John W. Stephenson','340 Swan Dr','Brandon','MS','UNITED STATES','39047-6729','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 21:24:04',0,NULL,3,0,1,1,NULL,'ishkabibble\rXXXL'),(6927,691822340002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','donkafkas','akin@balcab.ch','Enrico Akin','Postfach','Basel','','SWITZERLAND','4005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 21:26:55',0,NULL,3,1,2,1,NULL,'donkafkas'),(6928,650831301001,110664971677,'GGS Glass LCD Screen Protector for Canon 50D 5DII',2,'AB2211',100.2,'hermeshine','expertsourcing','cvaleriu@gmail.com','Valeriu Crangus','P.O.Box 41-6<br>Sector 1','Bucharest','Bucharest','ROMANIA','011252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-25 19:21:19',0,NULL,3,1,4,1,' ','expertsourcing\r2m 灯架  2\r双灯头   欧标  2\r反光伞   2\r包   1\rggs 50d   保护屏   2\rYW864488362CN\r'),(6929,0,130501320084,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','arx808','weondaair808@aol.com','Jared Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','(808) 383-8412','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 00:56:09',0,NULL,3,1,17,0,NULL,'arx808'),(6930,0,110665936369,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','arx808','weondaair808@aol.com','Jared Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','(808) 383-8412','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 00:56:09',0,NULL,3,1,1,1,NULL,'arx808\r绿叶 UV  58mm   2'),(6931,759000693015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.56,'hutongstore','satin-silk','mygarnette@netscape.net','Michael Garnette','490 Watford Way<br>Mill Hill','London','London','UNITED KINGDOM','NW7 2PX','07956375805','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-25 20:56:42',0,NULL,3,1,2,1,NULL,'satin-silk'),(6932,691900407002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jimhanseng','jim@hansenlan.com','James Hansen','3 Sardania CT','Sacramento','CA','UNITED STATES','95831','','NoPaymentFailure','CheckoutComplete','Other','2011-03-25 23:26:06',0,NULL,3,1,3,1,NULL,'jimhanseng\rRA022491791CN、'),(6933,0,120701916002,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:03',0,NULL,5,0,18,0,NULL,'segalu'),(6934,0,110665054987,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:04',0,NULL,5,0,18,0,'1234','segalu'),(6935,0,120701913339,'58mm 3-Stage Rubber Lens Hood for 18-55mm 450D 500D',1,'AB1303',0.01,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:33:04',0,NULL,5,0,18,0,'fangbo','segalu'),(6936,651435723001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:40:59',0,NULL,3,1,1,1,NULL,'robert5525'),(6937,0,110664689678,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','Thu thi Le','PO Box 953','Getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 03:56:24',0,NULL,3,0,1,1,NULL,'usa_global_trader\r发ggs的麂皮'),(6938,0,130501317800,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',0.55,'hermeshine','linda4490','linda4490@hotmail.com','Linda Ordonio-Dixon','572 Rose Dr','Benicia','CA','UNITED STATES','94510','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 04:30:41',0,NULL,3,1,1,1,NULL,'linda4490'),(6939,691971331002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','carlos4970','carlitus@three.com.au','Carlos Velasco','P.O. Box 7719<br>Bondi Beach','Sydney','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 04:34:15',0,NULL,3,1,3,1,NULL,'carlos4970\rRA022491522CN、'),(6940,0,120702819816,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.01,'hermeshine','highbiddergent','richard@powertranstechinc.com','Stephanie Sedlacek','PO Box 573<br>170236 Co Rd 37','Bayard','NE','UNITED STATES','69334-0573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 06:01:12',0,NULL,3,1,1,1,NULL,'highbiddergent'),(6941,651459198001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',70,'hermeshine','dlikane','dlikane@tpg.com.au','Dmitry Likane C/O Anatoli Likane','8a Yendon Rd','CARNEGIE','Victoria','AUSTRALIA','3163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 06:27:48',0,NULL,3,1,3,1,NULL,'dlikane\r注意一共10个220v的（XU:220V？）\rRA022491814CN、'),(6942,651467201001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','spikingsdj','djspikings@gmail.com','David Spikings','14376 Pinnacle Ct.','Canyon Country','CA','UNITED STATES','91387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 07:18:58',0,NULL,3,1,1,1,NULL,'spikingsdj'),(6943,743744679016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','pultik','marat@ru66.ru','Marat Saitov','Sinyaeva st - 8/103','Yekaterinburg','RU','RUSSIAN FEDERATION','620028','+7 905 801 38 71','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 07:25:49',0,NULL,3,1,2,1,NULL,'pultik'),(6944,651476404001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','greensokol','anpoch@mail.ru','Anna Mambetova','pr. Slavy 52-1 1392','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','192241','+7-911-245-70-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 08:18:42',0,NULL,3,1,2,1,NULL,'greensokol'),(6945,0,110665936162,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.01,'hermeshine','naturalseagifts','daydreamingthatsme@yahoo.com','keri dapron','2896 Biscaya Dr','Laughlin','NV','UNITED STATES','89029','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 08:52:16',0,NULL,3,1,1,1,NULL,'naturalseagifts'),(6946,759230299015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','menimm','marcin@mackowiak.name','Marcin Mackowiak','6 Wild Green South','Langley, Slough','Berkshire','UNITED KINGDOM','SL38NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 10:16:10',0,NULL,3,1,2,1,NULL,'menimm'),(6947,692045814002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','iceman183','steve.c.reid@gmail.com','Stephen Reid','Unit 7<br>96 Edgecumbe Street','Como','Western Australia','AUSTRALIA','6152','0468957498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 10:46:57',0,NULL,3,1,4,1,NULL,'iceman183\rlight set   $22\rYW864488351CN\r'),(6948,759264501015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','grubydzordz','krzysztof-dobrzynski@wp.pl','Krzysztof Dobrzynski','2 West Farm Cottage<br>Bincombe','Weymouth','Dorset','UNITED KINGDOM','DT35PS','07955020734','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 11:55:14',0,NULL,3,0,2,1,NULL,'grubydzordz\r黑色'),(6949,744036046016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dandins04','evija_2@inbox.lv','Ingus Stepans','31 adnitt road','Northampton','Northamptonshire','UNITED KINGDOM','nn14ll','07556126436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 12:47:26',0,NULL,3,1,2,1,NULL,'dandins04'),(6950,692087949002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','soontornta4918','soontornta@gmail.com','Mr. Soontorn Tachasakulnapaporn','64/11 M.2  Vibhawadee rd.,<br>Thungsonghong, Laksi','Bangkok','Thai','THAILAND','10210','(66)089-7628989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 13:05:54',0,NULL,3,1,2,1,NULL,'soontornta4918'),(6951,691584174002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','hrenokop','hrenocop@gmail.com','Pavel Tsarev','2 Viktora Gakuna, Appartment 19','Kaliningrad','','RUSSIAN FEDERATION','236000','7-905-249-07-68','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 15:48:48',0,NULL,3,1,2,1,NULL,'hrenokop'),(6952,692158023002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'viong'),(6953,692069602002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','cichlasoma79','faceyourfear@web.de','Schneider Christian','kohlerstr. 17','Ravensburg','','GERMANY','88214','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 16:22:08',0,NULL,3,1,4,1,NULL,'cichlasoma79\r1.6m的背景架 + 1.6x2.1 白色\rYW864488340CN\r'),(6954,692174173002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','lacalafoto','nornoreste@msn.com','  ventalles balfegó','C/. garbí  nº 9, barcelona','Canet de Mar - Barcelona','Cataluña','SPAIN','08360','937941552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 16:41:56',0,NULL,3,1,3,1,NULL,'lacalafoto\rRA022491607CN、'),(6955,651653183001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','lacie64','normagetsmail@mchsi.com','Norma Williams','211 Mossie Rd','Wewahitchka','FL','UNITED STATES','32465-7329','(850) 532-4626','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 17:09:36',0,NULL,3,1,1,1,NULL,'lacie64\r黄色logo的'),(6956,651661182001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','coldlocoman','anderson_harlen@yahoo.com.br','Fernanda Mota','rua dos cravos,426<br>inacio barbosa','Aracaju','Sergipe','BRAZIL','49040-140','055 21 79 8139 7614','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 17:33:07',0,NULL,3,1,3,1,NULL,'coldlocoman\rRA022491598CN、'),(6957,651672297001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','sergey_gorkiy_city','zykov.sergey87@gmail.com','Sergey Zykov','Lenina st.  45/161','Nizhniy Novgorod','RU','RUSSIAN FEDERATION','603135','+7-930-701-70-01','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 17:50:50',0,NULL,3,1,2,1,NULL,'sergey_gorkiy_city'),(6958,649415820018,280556434923,'Background Support & 10x20ft Green Screen LightKit 3x6m',1,'AKT065',124,'photographyacc','sunandheir','elliechenderson@googlemail.com','Heloise Henderson','210 Peckham Rye','East Dulwich','London','UNITED KINGDOM','SE22 0LU','02086930511','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-26 18:22:40',0,NULL,3,1,4,1,NULL,'sunandheir\r英标\rYW864488336CN\r'),(6959,759520933015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','omplantning','aatonder@gmail.com','Alexander Tønder','Vorrevej 19','Skødstrup','Østjylland','DENMARK','8541','25154416','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 19:49:57',0,NULL,3,1,2,1,NULL,'omplantning'),(6960,759538546015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','lauriha56','han2lau@gmail.com','Hannu Rytky','Mieluskylantie 182','Haapavesi','','FINLAND','86600','+358503516049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 20:15:58',0,NULL,3,1,3,1,NULL,'lauriha56\rRA022491805CN\r、'),(6961,651769793001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',56.97,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','+79214501223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 20:53:12',0,NULL,3,1,3,1,NULL,'dm-pal\r注意是6个灯泡\rRA022491482CN、'),(6962,651769725001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','stermix22','makrigar@hotmail.com','Maurizio  K. Gargiulo','Rua Alice nr 278 / ap 301<br>Laranjeiras','Rio de Janeiro','Rio de Janeiro','BRAZIL','22241-020','(21) 2556-7547','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 20:55:05',0,NULL,3,1,5,1,NULL,'stermix22\rCP226379498CN\r'),(6963,692309899002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','jagacek','zbyszek@bieleniewicz.com','Zbigniew Bieleniewicz','ul. Gdanska 5a/5','Elk','warmińsko-mazurskie','POLAND','19-300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 21:03:40',0,NULL,3,1,5,1,NULL,'jagacek\rCP226379515CN\r'),(6964,692309171002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','tamkam','tamkamvideo@gmail.com','Tamara McQuade','12007 Old Salem Church Rd','Locust Grove','VA','UNITED STATES','22407','(540) 419-8228','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 21:07:06',0,NULL,3,1,1,1,NULL,'tamkam'),(6965,651788540001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jonathanlewald','jonathanlewald@hotmail.com','Jonathan Lewald','Hallebergsvägen 11 (3tr)','Bromma','Stockholm','SWEDEN','SE-16737','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 21:34:48',0,NULL,3,1,3,1,NULL,'jonathanlewald\r橡胶遮光罩 58mm   1\r肩架    1\rRA022491615CN、'),(6966,651791193001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jonathanlewald','jonathanlewald@hotmail.com','Jonathan Lewald','Hallebergsvägen 11 (3tr)','Bromma','Stockholm','SWEDEN','SE-16737','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-26 21:40:53',0,NULL,3,1,17,0,NULL,'jonathanlewald'),(6967,744336019016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',120,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 21:52:26',0,NULL,3,1,4,1,NULL,'leifs123\r欧标 lighting kit $30\rYW864488421CN\r'),(6968,692194697002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','kalapachito','monte.cuco@hotmail.com','JOSE ANTONIO RODRIGO ESPADA','C/SAN ANTON 11, BLQ.1-BAJO','PLASENCIA','Extremadura','SPAIN','10600','676959917','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 22:16:00',0,NULL,3,1,4,1,NULL,'kalapachito\rtripod  $16\rYW864488410CN\r'),(6969,744354391016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','bmscdk','bcll@dbmail.dk','Brian Christensen','Frederikssundsvej 410,2tv','Brønshøj','Denmark','DENMARK','2700','(045)60116735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-26 22:30:29',0,NULL,3,1,2,1,NULL,'bmscdk'),(6970,759625740015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.55,'hutongstore','beserker0','timmaidens@bulldoghome.com','Timothy Maidens','11 Sherwood Place','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP26PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-26 22:59:19',0,NULL,3,1,2,1,NULL,'beserker0'),(6971,651787693001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','olga_j','t_janicki@live.co.uk','tomasz janicki','30 poppy close','london','London','UNITED KINGDOM','ub55tp','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-26 23:01:42',0,NULL,3,1,3,1,NULL,'olga_j\rRA022491709CN、'),(6972,692371232002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','bearw00d','eddyrademaker@gmail.com','Edward M Rademaker','9 Cocus Crescent','Palm Cove','Queensland','AUSTRALIA','4879','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-26 23:41:16',0,NULL,3,0,3,1,NULL,'bearw00d\r1.6x2.1  背景布  2 （ 白 黑）\rRA022491425CN、'),(6973,0,130500252054,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','usa_global_trader','globaltraderusa@gmail.com','T Le','po box 953','getzville','NY','UNITED STATES','14068-0953','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-26 23:54:03',0,NULL,3,0,1,1,NULL,'usa_global_trader\r发ggs的麂皮'),(6974,651853623001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:12',0,NULL,3,1,17,0,NULL,'sze_ling'),(6975,692392557002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:12',0,NULL,3,1,17,0,NULL,'sze_ling'),(6976,692393005002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:13',0,NULL,3,1,17,0,NULL,'sze_ling'),(6977,692396497002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:13',0,NULL,3,1,17,0,NULL,'sze_ling'),(6978,651856236001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:14',0,NULL,3,1,17,0,NULL,'sze_ling\r'),(6979,651852965001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sze_ling','szelingwong@gmail.com','Sze Ling Wong','Apt 204<br>124 Terra Nova Road','St. John\'s','NL','CANADA','A1B 1G2','(709) 351-4268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 01:17:15',0,NULL,3,1,3,1,NULL,'sze_ling\r橡胶遮光罩 52mm   1\r橡胶遮光罩 62mm  1\rNIKON 镜头盖 52mm   1\rNIKON 镜头盖 77mm  1\r中号内胆包 nikon   1\r大号内胆包 nikon   1\rRA022491893CN、'),(6980,651890204001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',5,'AKT007',94.95,'hermeshine','gj95600','gj_95600@hotmail.com','Guillaume Depestèle','14 rue Suzanne','Eaubonne','Île-de-France','FRANCE','95600','01.39.59.95.27','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,NULL,'gj95600\r注意是10个\rRA022491774CN、'),(6981,692472207002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',40,'AA1310',219.6,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 07:29:43',0,NULL,3,1,3,1,NULL,'blinker-182\rRA022491434CN、'),(6982,651953301001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','marcusfluvius','kadoelen141@hotmail.com','Marc van Beek','Roostenlaan 150','Eindhoven','','NETHERLANDS','5644GJ','31402437291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 09:03:36',0,NULL,3,1,2,1,NULL,'marcusfluvius'),(6983,759804318015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','sundberglarsson','thomas.sundberg@hotmail.com','Thomas Sundberg','Tjärn 120','Arnäsvall','Västernorrland','SWEDEN','89195','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 09:26:57',0,NULL,3,0,4,1,NULL,'sundberglarsson\r背景架 （ 白 黑 绿)   1\r2m的没有了，就发1.6m的给他\r庄+王\rYW864488465CN\r\r'),(6984,744543701016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','sundberglarsson','thomas.sundberg@hotmail.com','Thomas Sundberg','Tjärn 120','Arnäsvall','Västernorrland','SWEDEN','89195','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 09:41:01',0,NULL,3,0,17,0,NULL,'sundberglarsson'),(6985,759820029015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','tomek2009rafal','nowy84nrlondyn@interia.pl','rafal nowotnik','2 dundonald close','beckton','London','UNITED KINGDOM','e6 5ru','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 09:54:12',0,NULL,3,1,2,1,NULL,'tomek2009rafal\r英标'),(6986,744574178016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','magica_hada','h_metal16@hotmail.com','Claudia Hurtado Hurtado','Avd. Sants De La Pedra 22','Sagunto','Comunidad Valenciana','SPAIN','46500','607241479','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 10:58:50',0,NULL,3,1,4,1,NULL,'magica_hada\rYW864488406CN\r'),(6987,652002558001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 11:16:00',0,NULL,3,1,2,1,NULL,'loboau_au\r\\'),(6988,652015443001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','edu139','eduardo.arranz@hotmail.com','eduardo arranz','cl las monjas, 10 3ºC','palencia','Castilla y León','SPAIN','34005','626363403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:54:09',0,NULL,3,1,17,0,NULL,'edu139'),(6989,692562785002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','edu139','eduardo.arranz@hotmail.com','eduardo arranz','cl las monjas, 10 3ºC','palencia','Castilla y León','SPAIN','34005','626363403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 11:54:10',0,NULL,3,1,11,1,NULL,'edu139\r反光伞    1\r柔光伞    1'),(6990,652075840001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','buchhauser','buchhauser1@freenet.de','Christian Buchhauser','Schönstraße 22a','Hallbergmoos','','GERMANY','85399','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:09:13',0,NULL,3,1,2,1,NULL,'buchhauser'),(6991,652030442001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','trava-if','trava_if@ukr.net','Taras Travinskyy','Volunska 34','Ivano-Frankivsk','','UKRAINE','76010','00380503731120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:15:58',0,NULL,3,1,2,1,NULL,'trava-if'),(6992,692627223002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',18,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:16:51',0,NULL,3,1,2,1,NULL,'rdvru'),(6993,0,120702819656,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',0.24,'hermeshine','blond-n-blue','grethelindemann@aol.com','Grethe Lindemann','1021 W 6th St','Erie','PA','UNITED STATES','16507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 14:26:10',0,NULL,3,0,1,1,NULL,'blond-n-blue\rCANON 镜头盖  58mm   3'),(6994,652084842001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 14:27:27',0,NULL,3,1,2,1,NULL,'viong'),(6995,651321295001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',23.6,'hermeshine','nikolayxxx','platovnikolay@gmail.com','Nikolay Platov','Zagorodniy per. 21/28','Vyazma','Smolenskaya obl','RUSSIAN FEDERATION','215110','+79057605564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:06:52',0,NULL,3,1,3,1,NULL,'nikolayxxx\r欧标\rRA022491417CN、'),(6996,652107208001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sziga6','szi_ga@vipmail.hu','Gábor Szijártó','Rohonci 48','Szombathely','Vas','HUNGARY','9700','(36)305430541','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 15:14:07',0,NULL,3,1,3,1,NULL,'sziga6\rRA022491496CN、'),(6997,692672159002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','uuchip','uuchip@aliceposta.it','Daniele Simone','Via Manfredi, nr. 83/a','Monte Sant\'Angelo','Foggia','ITALY','71037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 15:41:39',0,NULL,3,1,2,1,NULL,'uuchip'),(6998,760042130015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','86948','johnward35a@hotmail.co.uk','john ward','35a aranmore avenue','londonderry','Londonderry','UNITED KINGDOM','BT489TS','02871288940','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 16:15:46',0,NULL,3,1,2,1,NULL,'86948'),(6999,652152023001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','gmiethig','gerhard.m@sympatico.ca','Gerhard Miethig','50 Lombard St<br>Suite 2102','Toronto','ON','CANADA','M5C2X4','(416) 363-9086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 16:23:35',0,NULL,3,1,2,1,NULL,'gmiethig'),(7000,760070478015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','esty2002','jana_parker1@yahoo.co.uk','Jana Parker','Urb Jardin Botanico Fase 3<br>Bloque 5, apt 5B','Cala de Mijas','Andalucía Ceuta y Melilla','SPAIN','29649','608658197','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-27 16:47:55',0,NULL,3,1,4,1,NULL,'esty2002\r欧标\rlighting kit  $30\rYW864488395CN\r'),(7001,692723234002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shaharstroh','shaharstroh@gmail.com','Shahar Stroh','4546 Winnetka Cir','Woodland Hills','CA','UNITED STATES','91364-4614','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-27 16:57:07',0,NULL,3,1,1,1,NULL,'shaharstroh'),(7002,692741253002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','ag_presentz','barathaanushka@yahoo.com','Anushka Gunasinghe','21-6 New Hospital Rd, Pamunuwa<br>Maharagama','Colombo','Western','SRI LANKA','0094','+94-719331387','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 17:19:30',0,NULL,3,1,17,0,NULL,'ag_presentz'),(7003,652200078001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','ag_presentz','barathaanushka@yahoo.com','Anushka Gunasinghe','21-6 New Hospital Rd, Pamunuwa<br>Maharagama','Colombo','Western','SRI LANKA','0094','+94-719331387','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 17:27:34',0,NULL,3,0,3,1,NULL,'ag_presentz\r摄影背心 绿色薄 nikon XXL  1\r摄影背心 夏  XL   1\rRA022491730CN、'),(7004,744835441016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.39,'hutongstore','timksophie','timispractising@googlemail.com','tim kitchen','6 glebelands road','tiverton','devon','UNITED KINGDOM','ex16 4eb','07890626014','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-27 17:33:27',0,NULL,3,1,2,1,NULL,'timksophie'),(7005,692819254002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','draghestar2006','dragonzord61@tiscali.it','Gabriele Sopranzi','Via filottrano N.7','Ancona','AN','ITALY','60126','3771581267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:42:07',0,NULL,3,1,2,1,NULL,'draghestar2006'),(7006,652263748001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','fatimah.abdullah','fatimah.dollah@gmail.com','Fatimah Abdullah','Hankyu Hanshin Express Sdn Bhd, Lot D-8, Block D,<br>MAS Cargo Complex, KLIA Cargo Complex','KLIA','Selangor','MALAYSIA','64000','0163113265','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 18:44:07',0,NULL,3,1,2,1,NULL,'fatimah.abdullah'),(7007,652277850001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jannehapponen','janne.happonen@gmail.com','Janne Happonen','Döbelninkatu 1 A 20','Helsinki','Uusimaa','FINLAND','00260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 18:47:16',0,NULL,3,1,2,1,NULL,'jannehapponen'),(7008,692912492002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','don604','don.middleton@dccnet.com','Don Middleton','889 Bayview Drive','Delta','BC','CANADA','V4M2R5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 20:10:40',0,NULL,3,1,2,1,NULL,'don604'),(7009,760338838015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','littlelambfound','jtpornstar@yahoo.com','Krajcsi Pal','Zrinyi ut 80/B','Batonyterenye','Nograd','HUNGARY','H-3078','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:30:45',0,NULL,3,1,3,1,NULL,'littlelambfound\rRA022491519CN、'),(7010,745061092016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',24,'hutongstore','purpleserpentgirl','purplesnakegirl@yahoo.com','Anne Duffy','14 Phoenix Pl Giralang','Canberra','Australian Capital Territory','AUSTRALIA','2617','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:33:24',0,NULL,3,0,3,1,NULL,'purpleserpentgirl\r1.6m x 3m 背景布   红色 + 粉色\rRA022491505CN、'),(7011,760348701015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',16,'hutongstore','schiller_dk','ms@definitivt.dk','Mark Schiller','Vosborgvej 30','Kastrup','','DENMARK','2770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-27 20:44:56',0,NULL,3,1,3,1,NULL,'schiller_dk\r、RA022491712CN'),(7012,692963104002,120448640631,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',4.87,'hermeshine','kim_hoerning','kim@benn.dk','Kim Benn','Brunhøj 37','Hørning','Jylland','DENMARK','8362','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 21:16:51',0,NULL,3,1,2,1,NULL,'kim_hoerning'),(7013,693008563002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','boriska_gr','boriska_gn@yahoo.com','Boris Gorshtein','Avraam Shtern str. 42/12','Jerusalem','','ISRAEL','96750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:38:04',0,NULL,3,1,2,1,NULL,'boriska_gr'),(7014,693011990002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','*stockweb*','taini.alberto@gmail.com','alberto taini','via del giglio n°60b','cattolica','RN','ITALY','47841','3335811023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-27 22:49:48',0,NULL,3,1,2,1,NULL,'*stockweb*'),(7015,650624562001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',290,'hermeshine','fellygish','j.zheng@kneelerdesign.com.au','Jina Zheng','135 Campbell St','Collingwood','Victoria','AUSTRALIA','3066','0433124982','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-27 22:54:08',0,NULL,3,1,4,1,NULL,'fellygish\rnikon 老款 摄影背心  M   1\r双灯头   澳标   1\r反光伞   1\r反光板支架   1\r2mx3m 背景架   1\r2m灯架   2\r50-70 单灯头棚  澳标   2\r115w 220v   2\r包    1\rYW864488432CN\r\r\r\r\r'),(7016,652481401001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','francisco_bs','franciscobs@gmail.com','Francisco Batalla Sánchez','C/ Villardondiego 23, 2º-B','Madrid','Madrid','SPAIN','28032','687993669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 00:01:09',0,NULL,3,1,2,1,NULL,'francisco_bs'),(7017,652502436001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 01:01:04',0,NULL,3,1,1,1,NULL,'bbaker8282'),(7018,652520561001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','thebadplayer','deekaysk@gmail.com','Daniel Krnac','Devinska 7','Nove Zamky','','SLOVAK REPUBLIC','94063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 01:50:42',0,NULL,3,1,3,1,NULL,'thebadplayer\rRA022491876CN、'),(7019,693096578002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','livan-2006','licantenino@gmail.com','ivan muñoz','A. Rojas 28','Licanten','Septima Region','CHILE','3410000','75400711','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 02:34:09',0,NULL,3,0,5,1,NULL,'livan-2006\r发1.6m的背景架给他吧\rCP226379507CN\r'),(7020,0,130500585835,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.16,'hermeshine','noblewood57','noblewood57@yahoo.com','E.J. McCollum','3928 Haleys Way','Round Rock','TX','UNITED STATES','78665-1166','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 03:56:40',0,NULL,3,1,1,1,NULL,'noblewood57'),(7021,652556132001,110618892690,'Pro Photo Vest for Nikon D60 D80 D90 D7000 D300s  user',1,'AA2119',32,'hermeshine','shenker123','shenkerbay@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:01:57',0,NULL,3,0,3,1,NULL,'shenker123\rxxl\r申报 vest  $12\rRA022491828CN、'),(7022,693123048002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','5_star_shop','boangoc@optusnet.com.au','lee xuan loi','24 skipton street','st albans','Victoria','AUSTRALIA','3020','03968974110411467893','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:12:52',0,NULL,3,0,4,1,NULL,'5_star_shop\rball head $15\rYW864488443CN\r'),(7023,693129009002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mycowcow','bagel99@rogers.com','William Ng','1345 Willowvale Gardens','Mississauga','ON','CANADA','L5V 1V1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 04:45:39',0,NULL,3,1,3,1,NULL,'mycowcow\rRA022491765CN、'),(7024,760612267015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','francisco_pico','franciscopico@hotmail.com','Francisco Pico','1 H Springwell avenue','London','London','UNITED KINGDOM','nw10 4hn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 08:12:14',0,NULL,3,1,2,1,NULL,'francisco_pico\r刘\r\\'),(7025,652598995001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',87,'hermeshine','ramboroven','stenssons@telia.com','Tomas Stensson','Pl 467','Svenstavik','none','SWEDEN','84040','0687-10585','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 08:14:11',0,NULL,3,1,4,1,NULL,'ramboroven\rYW864488454CN\r\r'),(7026,652603839001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','sergio.raf','sergio.paolo@alice.it','Paolo Sergio','C.so Garibaldi n.201','Canosa di Puglia','BA','ITALY','70053','0883-664109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 08:37:40',0,NULL,3,1,2,1,NULL,'sergio.raf\r徐\r、'),(7027,760625342015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','autoosta','dedpixto@hotmail.com','Vitalijs Labors','6.linija 58B','Jelgava','','LATVIA','LV-3003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 08:59:43',0,NULL,3,0,2,1,NULL,'autoosta\r1.6x2.1 黑色   1\r徐\r、'),(7028,652610071001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',62,'hermeshine','adelisle14','adelisle14@hotmail.com','VERDE-DELISLE ANTOINE','6 rue RAFFET','Paris','other','FRANCE','75016','0146477173','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 09:06:22',0,NULL,3,1,4,1,NULL,'adelisle14\rreflector holder  $20\r王\rYW864488476CN\r'),(7029,652611473001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',3,'AA2205',10.5,'hermeshine','thanasis117','thanasisxask@yahoo.gr','thanasis xaskos','BK50 arithmos 15','PATRA','N AXAIAS','GREECE','26333','6983503026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 09:13:01',0,NULL,3,1,2,1,NULL,'thanasis117\r\\'),(7030,693192818002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','taz_ufrj','kiwi2free@yahoo.com','JULIO CORAL','9228 Lamont Ave<br>Fl 3','ELMHURST','NY','UNITED STATES','11373-2866','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 10:08:34',0,NULL,3,1,1,1,NULL,'taz_ufrj\r庄'),(7031,652634846001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','militaryjudge','koshild@gmail.com','DMITRIY KOSHIL','LENINA ST. 169 KV. 36','ANAPA','','RUSSIAN FEDERATION','353454','+78613360523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:48:25',0,NULL,3,1,2,1,NULL,'militaryjudge\r庄\r\\'),(7032,693205176002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','rama1981','burnxout@libero.it','Andrea Raimondi','Corso del popolo,15','San Michele al Tagliamento','VE','ITALY','30028','+393401709428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 10:59:17',0,NULL,3,1,2,1,NULL,'rama1981\r徐\r\\'),(7033,693208466002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','dangfilms210','dangfilms@yahoo.com','freddy dang','5126 Village Crst','san antonio','TX','UNITED STATES','78218','(210) 843-3537','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 11:09:41',0,NULL,3,1,1,1,NULL,'dangfilms210\r注意是5个\r庄'),(7034,652648382001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','jpf_106684','johnpatrick84@btinternet.com','John Patrick Fletcher','22 Ash Grove<br>Yiewsley','London','Middlesex','UNITED KINGDOM','UB7 8BL','01895430530','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 11:40:33',0,NULL,3,0,3,1,NULL,'jpf_106684\rXXL\r王\rRA022492412CN\r\\'),(7035,693222216002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','andyc134','andyt.cobb@gmail.com','Andy Cobb','4426 Greenbriar Rd','Louisville','KY','UNITED STATES','40207-2304','(502) 386-6797','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 12:01:41',0,NULL,3,1,1,1,NULL,'andyc134\r徐'),(7036,651204059001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotodjuls','djuls@gmx.net','Julien Bataillet C/o ADD','Eppendorfer weg 95a','Hamburg','','GERMANY','20259','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 13:01:08',0,NULL,3,1,3,1,NULL,'fotodjuls\r王\r\\\rRA022492307CN\r'),(7037,693140049002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 15:03:25',0,NULL,3,0,3,1,NULL,'saud-p\r发两个小包挂号\rRA117710245CN\rRA117710231CN\r\\'),(7038,760769217015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.99,'hutongstore','g.loxton','g.loxton@virgin.net','Giles Loxton','14 minerva road','kingston','Surrey','UNITED KINGDOM','kt1 2qa','02082871411','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 15:40:09',0,NULL,3,1,2,1,NULL,'g.loxton\r徐\r\\'),(7039,652725304001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','manuj28','fueratarget@hotmail.com','MANUEL JIMENEZ','C/ LUCENA DEL PUERTO 20 - 4ºA','HUELVA','Andalucía Ceuta y Melilla','SPAIN','21002','627022006','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 15:47:17',0,NULL,3,0,4,1,NULL,'manuj28\r发1.6的背景架  （ 白  黑）   1\r115w 220v  1\rbackground support  \r$20\r王\rYW864488480CN\r'),(7040,652729016001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','jamboleo2010','jamboleo@list.ru','Bogdanov Mikhail','Tolstikova 49-7','Kalininigrad','','RUSSIAN FEDERATION','236011','+79114524743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:59:21',0,NULL,3,1,2,1,NULL,'jamboleo2010\r徐'),(7041,693299878002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','woopz86','woopz@hot.ee','Eduard Jashin','Sopruse 250-8','Tallinn','Estonia / Harjumaa','ESTONIA','13412','(+372)55604952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 15:59:35',0,NULL,3,1,5,1,NULL,'woopz86\r注意是2套\r庄\rCP226379524CN\r'),(7042,652752469001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','manuj28','fueratarget@hotmail.com','MANUEL JIMENEZ','C/ LUCENA DEL PUERTO 20 - 4ºA','HUELVA','Andalucía Ceuta y Melilla','SPAIN','21002','627022006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 16:56:23',0,NULL,3,1,17,0,NULL,'manuj28'),(7043,693326964002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','magmasowulo','gustavolugao@gmail.com','Gustavo Lugão','Rua Vicente Satriani 308- 06<br>Vila Suconasa','Araraquara','São Paulo','BRAZIL','14807-070','+55 16 88129917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:04:03',0,NULL,3,1,2,1,NULL,'magmasowulo\r徐'),(7044,652765325001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','dragonic99','kay_dragonic99@yahoo.com','Michael Ian Lee Tin Wah','6D, Robinson St','Rose Hill','','MAURITIUS','0000','(230) 492 0505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 17:27:12',0,NULL,3,1,2,1,NULL,'dragonic99\r徐\r\\'),(7045,693339539002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','denybarboza','denyzinho@gmail.com','Jordana Brizolara','Rua Ver. Severo Ribeiro, 912<br>Três Vendas','Pelotas','Rio Grande do Sul','BRAZIL','96020-620','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 17:32:07',0,NULL,3,1,3,1,NULL,'denybarboza\r王\rRA022492298CN\r\\'),(7046,652776456001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 17:49:56',0,NULL,3,1,3,1,NULL,'bluesmansur\r王\rRA022492236CN\r\\'),(7047,760841628015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',3,'AA1314',6.6,'hutongstore','cdelabbeer','cdelabbeer@aol.com','Charles de la Bertauche','\"Westleigh\"<br>Fore Street,','Beer','Devon','UNITED KINGDOM','EX12 3EQ','0129721016','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 17:57:03',0,NULL,3,1,2,1,NULL,'cdelabbeer\r徐'),(7048,652782760001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','armenak*84','armenak84@mail.ru','Armenak Baghdasaryan','David Beki str. 90','Yerevan','Erebuni','ARMENIA','0008','(374)91010024','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 18:02:13',0,NULL,3,1,3,1,NULL,'armenak*84\r王\rRA022492219CN\r\\'),(7049,652796373001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','andrea_bo57','fabio010790@hotmail.it','Andrea Ferrari','via 2 agosto 1980 n° 19','Monte San Pietro','BO','ITALY','40050','+390516761781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 18:28:23',0,NULL,3,1,2,1,NULL,'andrea_bo57\r徐'),(7050,745565756016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',19.5,'hutongstore','peterw4963','peterw579@aol.com','Peter White','4 Cuppleditch Way','Louth','Lincolnshire','UNITED KINGDOM','LN11 0UF','01507606579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 18:28:30',0,NULL,3,1,3,1,NULL,'peterw4963\r王\rRA022492240CN\r\\'),(7051,652814771001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',2,'AO0015',15.8,'hermeshine','jyrgenro','ykomar@yandex.ru','Iurii Ruzhytskyi','Pryrichna 17V <br>app. 47','Kyiv','','UKRAINE','04213','067-112-15-14','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 19:00:30',0,NULL,3,1,2,1,NULL,'jyrgenro\r刘'),(7052,693346833002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','bboykorrus','expl0@yandex.ru','POLOZOV EVGENIY','ULITSA LENINA DOM 31 KVARTIRA 6','KIROV','KALUZHSKAYA OBLAST\'','RUSSIAN FEDERATION','249440','+79208888626','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 19:31:39',0,NULL,3,1,3,1,NULL,'bboykorrus\r王\rRA022492222CN\r\\'),(7053,650641830018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','timc3986','proexc1@yahoo.com','tim carr','4320 Wilcor Dr','Akron','OH','UNITED STATES','44319-2644','(330) 618-5251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-28 19:48:09',0,NULL,3,1,4,1,NULL,'timc3986\r刘（灯换成110V)\rYW864488491CN\r\r'),(7054,760968201015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','lynfm1948','lyn@netconnect.com.au','Lyn MacKenzie','7 Newton St','Stawell','Victoria','AUSTRALIA','3380','0353581878','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-28 20:55:06',0,NULL,3,1,2,1,NULL,'lynfm1948\r徐'),(7055,760982059015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.5,'hutongstore','heljay','jason.pallett@sky.com','JASON P PALLETT','18 JOHN STREET','SWADLINCOTE','DERBYSHIRE','UNITED KINGDOM','DE11 0AZ','01283221426','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-28 21:28:12',0,NULL,3,1,2,1,NULL,'heljay\r徐\r\\'),(7056,693476187002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','c_r_croker','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 21:48:46',0,NULL,3,0,3,1,NULL,'c_r_croker\rRA117710055CN\r\\'),(7057,693486672002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','9228jay','liquid10@telus.net','JAY FERNANDEZ','502 - 5189 GASTON STREET','VANCOUVER','BC','CANADA','V5R6C7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-28 22:08:25',0,NULL,3,1,2,1,NULL,'9228jay\r庄'),(7058,652938827001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','chongzhili','terry_lee2003@hotmail.com','chongzhi li','325 S Chapel Ave<br>Apt B','alhambra','CA','UNITED STATES','91801-4296','(626) 935-9493','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-28 23:47:07',0,NULL,3,1,1,1,NULL,'chongzhili\r庄\r\\'),(7059,693519300002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','anar4k3l','anasoares13@gmail.com','Paulo Jorge Gonçalves Lacerda','Rua 25 de Abril Edificio Viana 6 4.º esq<br>3850 - Albegaria-a-Velha','Albergaria-a-Velha','Portugal','PORTUGAL','3850-004','+351935237838','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-28 23:59:45',0,NULL,3,1,4,1,NULL,'anar4k3l\r庄\r欧标\rYW864488502CN\r'),(7060,652949540001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','brocky05rip','tenille.muscat@sa.gov.au','Tenille Muscat','Level 10, Roma Mitchell House<br>136 North Terrace','ADELAIDE','South Australia','AUSTRALIA','5000','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-03-29 00:29:22',0,NULL,3,0,4,1,NULL,'brocky05rip\r发1.6m 背景架  （ 白 黑）   1\r庄\rYW864488513CN\r'),(7061,652952320001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','gran748','granote@gmail.com','Eran Granot','1 Israel Ishayahoo<br>p.o.box 2704','Petach TIqva','','ISRAEL','49127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 00:40:31',0,NULL,3,1,2,1,NULL,'gran748\r庄\r\\'),(7062,652983063001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 02:35:55',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r徐\r\\'),(7063,652995440001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','yakou-moua','yakoumoua@hotmail.com','Yakou Moua','1400 Monks Ave<br>Apt 480','Mankato','MN','UNITED STATES','56001-5113','(651) 354-1092','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 03:39:23',0,NULL,3,1,1,1,NULL,'yakou-moua\r\\'),(7064,653006804001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','thepraetorianone','sergey@smolyaninov.ru','Sergey Smolyaninov','Krasnomoskovskaya 25-55','Krasnoyarsk','','RUSSIAN FEDERATION','660018','8(983)2690489','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 04:37:28',0,NULL,3,1,5,1,NULL,'thepraetorianone\rCP226379538CN\r'),(7065,653011242001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','crawdog00','rick_crawford@hotmail.com','Richard J Crawford','5901 Pinewood Rd','Oakland','CA','UNITED STATES','94611-1859','(510) 338-0332','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 05:04:28',0,NULL,3,1,1,1,NULL,'crawdog00'),(7066,653012710001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','joakim.k','joakim_k@yahoo.com','Joakim Karlsson','Nobelvagen 11a','Malmo','','SWEDEN','214 29','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 05:14:26',0,NULL,3,1,3,1,NULL,'joakim.k\rRA022492275CN\r\\'),(7067,650849188018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','fouadandfatema','fowady2000@gmail.com','Fouad Bou-Khamsin','PO Box: 11791<br>Dhahran','Dhahran','Eastren Province','SAUDI ARABIA','31311','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-29 07:40:08',0,NULL,3,1,3,1,NULL,'fouadandfatema\r王\rRA117710355CN\r'),(7068,693625213002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','plumeriaheaven','judokix@yahoo.com','J Soeda','PO Box 4999','Kaneohe','HI','UNITED STATES','96744-8999','(808) 463-1331','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-29 07:51:59',0,NULL,3,1,1,1,NULL,'plumeriaheaven\r\\'),(7069,745867952016,260660053068,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','probadge999','jc@probadge.com','Jeff Crisp','3 The Walk','Winslow','Buckinghamshire','UNITED KINGDOM','MK18 3AJ','01296715746','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 08:04:04',0,NULL,3,1,3,1,NULL,'probadge999\r刘\rRA117710191CN'),(7070,691755931002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','december196930','i-shubina@mail.ru','Irina Shubina','Krotevicha St., 47','Lipetsk','Russia','RUSSIAN FEDERATION','398020','74742 230165','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 08:19:08',0,NULL,3,0,3,1,NULL,'december196930\r徐\rRA117710452CN\r'),(7071,757188784015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',2,'AO0001',236,'hutongstore','pastortunde2011','pastortunde@kingdomarena.org.uk','Pastor Tunde Ogedengbe','39 Sunderland Place<br>Shortstown','Bedford','Bedfordshire','UNITED KINGDOM','MK42 0FE','01582405757','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-29 08:27:55',0,NULL,3,1,4,1,NULL,'pastortunde2011\r王\rYW864488535CN\r'),(7072,693638277002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',5.99,'hermeshine','sypige','sylvain.geyer@arcelormittal.com','Geyer Sylvain','avenue d\'Oberkorn, 118','Differdange','','LUXEMBOURG','L-4640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:56:55',0,NULL,3,1,17,0,NULL,'sypige'),(7073,693638119002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','sypige','sylvain.geyer@arcelormittal.com','Geyer Sylvain','avenue d\'Oberkorn, 118','Differdange','','LUXEMBOURG','L-4640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 08:56:56',0,NULL,3,1,2,1,NULL,'sypige\r580ex  肥皂盒  1\r带水平仪 热靴保护盖   1\r刘\r\\'),(7074,653058169001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Ludaš','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 09:21:42',0,NULL,3,1,3,1,NULL,'fotoivideo\r王\rRA117710205CN'),(7075,652587184001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','shomaman','exprezident@yandex.ru','Shamil Suleimanov','Nejinskaya 1<br>16','Ufa','Bashkiria','RUSSIAN FEDERATION','450064','8-347-2644325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 09:48:23',0,NULL,3,1,3,1,NULL,'shomaman\r王\rRA117710435CN\r'),(7076,693680055002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','hinrich19','hinrichbehrens@neofit.de','Magix Print - Hinrich Behrens','Dingstätte 7','Pinneberg','','GERMANY','25421','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 11:52:15',0,NULL,3,1,2,1,NULL,'hinrich19\r徐\r\\'),(7077,653137662001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',5,'AC3301',72.8,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:22:51',0,NULL,3,1,5,1,NULL,'nixette_nixette\r反光板  80cm 5合1     5\r圆形柔光棚 40cm       1\r庄\rRA117710112CN\r换号了： CP226342759CN\r'),(7078,653138999001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 14:28:04',0,NULL,3,1,17,0,NULL,'nixette_nixette\r'),(7079,653156828001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','timon_ru','timon.chel@gmail.com','Alimov Dmitry','apt. 39<br>214-A Aralskaya street','Chelyabinsk','Chelyabinskaya obl','RUSSIAN FEDERATION','454025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 15:24:14',0,NULL,3,1,5,1,NULL,'timon_ru\r王\rCP226344794CN\r'),(7080,761333937015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',4,'AKT056',155.96,'hutongstore','hpan2010','shabir@hpan.org.uk','H-PAN H-PAN','`117 Fairfield Street<br>Manchester','Manchester','Lancashire','UNITED KINGDOM','M12 6EL','01612252307','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-03-29 15:44:25',0,NULL,3,1,4,1,NULL,'hpan2010\r刘\rYW864488546CN\r'),(7081,693778906002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','rdvru','r-dimka@mail.ru','Dima Rebrov','Simonovskiy val 7-1-86','Moscow','Russia','RUSSIAN FEDERATION','109044','+79266298181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 16:54:08',0,NULL,3,1,2,1,NULL,'rdvru\r徐\r\\\r'),(7082,693780324002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','lindows-by','joshhhab@gmail.com','Andrey Burkov','boulevard Komsomolskiy 59-2','Kamensk-Uralskiy','Sverdlovskaya oblast','RUSSIAN FEDERATION','623430','+7-915-290-14-59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:08:47',0,NULL,3,1,2,1,NULL,'lindows-by\r庄\r\\'),(7083,693794108002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','michi1312','migum13@gmx.ch','Michael Hägele','Holligenstrasse 101','Bern','','SWITZERLAND','3008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:29:49',0,NULL,3,1,2,1,NULL,'michi1312\r徐\r\\'),(7084,693800400002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','leteatbee_cyril','cyril.g@mail.ru','Kirill Golikov','Gagarina, 83-16','Sovetsky','Khanty-Mansiysky autonomous region','RUSSIAN FEDERATION','628240','+7(34675)38370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:47:24',0,NULL,3,1,3,1,NULL,'leteatbee_cyril\r庄\rRA117710126CN\r'),(7085,693803816002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',55.99,'hermeshine','kazus_arthur','kazus1@yandex.ru','Pavel','Ryzhenkov<br>17-17 Stahanovskaya str.','Minsk','','BELARUS','220009','+375296454836','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 17:56:44',0,NULL,3,1,3,1,NULL,'kazus_arthur\r王\rRA117710041CN'),(7086,693847960002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','primorsk1971','primorsk@012.net.il','Vitaliy Berkovych','shmuel hanatsiv 14/9','netanya','hasharon','ISRAEL','42281','+972526686852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 19:17:20',0,NULL,3,1,2,1,NULL,'primorsk1971\r徐\r\\'),(7087,746174425016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','adam.wol','adam.wolynszczak@gmail.com','Adam Wolynszczak','127 The Crescent<br>Park West Pointe','Dublin','Dublin','IRELAND','D12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 20:09:44',0,NULL,3,1,3,1,NULL,'adam.wol\r庄\rRA117710109CN'),(7088,693908469002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','marcio8493','aishaveras@hotmail.com','marcio veras','101 Norfolk St','Dorchester Center','MA','UNITED STATES','02124-3343','','NoPaymentFailure','CheckoutComplete','Other','2011-03-29 21:07:28',0,NULL,3,1,1,1,NULL,'marcio8493\r徐'),(7089,653324057001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','poonny06','lionel.prados@gmail.com','lionel prados','706 chemin du Suy Blanc','La Gaude','Provence-Alpes-Côte d\'Azur','FRANCE','06610','06.28.26.66.83','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 21:22:34',0,NULL,3,1,4,1,' ','poonny06\r庄（欧标）\rYW864488550CN\r'),(7090,761442196015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',30,'hutongstore','worldgems2010','wgworldgems7@gmail.com','rahmatullah asmari','93 Oxford Avenue','southampton','Hampshire','UNITED KINGDOM','SO14 0DP','07544853253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:43:56',0,NULL,3,1,3,1,NULL,'worldgems2010\r王\rRA117710090CN\r'),(7091,746234220016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.62,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:54:13',0,NULL,3,1,17,0,NULL,'roryalderson'),(7092,746235812016,260660053738,'New Wireless Flash Sync Trigger Receiver D700 D90 5D II',1,'AB3322',13.19,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:55:59',0,NULL,3,1,17,0,NULL,'roryalderson'),(7093,746236771016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 21:58:13',0,NULL,3,1,17,0,NULL,'roryalderson'),(7094,761560436015,250599928359,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','roryalderson','roryald@aol.com','Rory Alderson','22 James street','Rochester','Kent','UNITED KINGDOM','ME46JS','07970922726','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:00:07',0,NULL,3,1,3,1,NULL,'roryalderson\r方形滤镜接口环 58mm  1\r方形滤镜 镜片卡座   1\r永诺 YN-04 引闪器一套  1\r反光板 60cm 2合1    1\r天涯方形滤镜  渐变灰   1\r刘\rRA117710157CN\r'),(7095,693932350002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jairoperezv','chaca_24@hotmail.com','Jairo Perez Vecino','Bulevar Juan Carlos I,nº21, 1ºi<br>C/Severo Ochoa nº9,1ºA','Ponferrada','Leon','SPAIN','24400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 22:06:08',0,NULL,3,1,4,1,NULL,'jairoperezv\rtripod  $16\r刘\rYW864488561CN\r'),(7096,761570637015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',24.95,'hutongstore','redbill80','redbill1980@yahoo.gr','Vasilis Lolos','Chrysaugi','Paramythia','Thesprotia','GREECE','46200','6944961595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-29 22:24:27',0,NULL,3,1,3,1,NULL,'redbill80\r王\rRA117710072CN'),(7097,761577672015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','agalad','phancock@hotmail.co.uk','Paul Hancock','14 Bloomsbury Lane, Timperley','Altrincham','Cheshire','UNITED KINGDOM','WA156LX','07867824762','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:42:25',0,NULL,3,1,3,1,'','agalad\r王\rRA117710086CN\r'),(7098,761579119015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','geraldinetenten','gmcgarrigle@gmail.com','geraldine mc garrigle','31 meadowvale park','omagh','Tyrone','UNITED KINGDOM','bt79 7rb','02882251122','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 22:47:38',0,NULL,3,1,3,1,NULL,'geraldinetenten\r王\rRA117710069CN'),(7099,693953995002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','rodolfoperez','rodolfoperez79@gmail.com','Rodolfo Perez','8627 NW 54th St','Doral','FL','UNITED STATES','33166-3347','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-29 23:13:23',0,NULL,3,1,1,1,NULL,'rodolfoperez\r刘'),(7100,761596147015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','michaelmassaro','mike@mikemike.co.uk','michael massaro','38 Kirton Gardens','London','London','UNITED KINGDOM','E2 7LS','07985943981','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-29 23:36:39',0,NULL,3,1,3,1,NULL,'michaelmassaro\r刘\rRA117710130CN\r'),(7101,650935282001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-03-29 23:43:38',0,NULL,7,0,18,0,NULL,'datoow78'),(7102,691439996002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-29 23:43:52',0,NULL,7,0,18,0,NULL,'datoow78'),(7103,650937525001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 23:43:54',0,NULL,7,0,18,0,NULL,'datoow78'),(7104,691439867002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','datoow78','tanyadickenson@bigpond.com.au','robbie dickenson','17 alligator crk rd<br>alligator crk','townsville','QUEENSLAND','AUSTRALIA','4816','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-29 23:44:22',0,NULL,7,0,18,0,NULL,'datoow78'),(7105,693970763002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','fluidsuper','juancamilovenegas@yahoo.com','Juan Venegas','8481 avenue des belges','Montreal','QC','CANADA','h2p2b3','(514) 241-3273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 00:12:00',0,NULL,3,1,3,1,NULL,'fluidsuper\r王\rRA117710143CN\r'),(7106,653401868001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','assafmajdy','hazar_k@yahoo.com','majdy assaf','non<br>non','mi\'ilya village','mi\'ilya village po box 128','ISRAEL','25140','972547559297','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 01:50:44',0,NULL,3,1,3,1,NULL,'assafmajdy\r刘\rRA117710038CN\r'),(7107,650623943001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',13.99,'hermeshine','fellygish','j.zheng@kneelerdesign.com.au','Jina Zheng','135 Campbell St','Collingwood','Victoria','AUSTRALIA','3066','0433124982','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-03-30 02:11:40',0,NULL,7,0,18,0,NULL,'fellygish'),(7108,0,120701930117,'Adjustable Neoprene Padded Neck shoulder Strap for Sony',1,'AB1406',0.11,'hermeshine','riya_in_pink','brgrl01@gmail.com','Gillian Lansang','5655 Silver Creek Valley Rd<br># 543','San Jose','CA','UNITED STATES','95138-2473','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 02:29:20',0,NULL,3,1,1,1,NULL,'riya_in_pink\r徐'),(7109,694017143002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','alexander_sanchez','alexanderjsanchez@gmail.com','ALEXANDER SANCHEZ','URB LAS FUENTES CALLE 1 EDIF LOS ANDES PB APTO 2A EL PARAISO','CARACAS','DTTO FEDERAL/CARACAS','VENEZUELA','1020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 02:58:39',0,NULL,3,1,3,1,NULL,'alexander_sanchez\r庄\rRA022491200CN\r\\'),(7110,694020686002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','deebarajpal','vindee@airtelmail.in','Deeba Rajpal','#654, Sector 23<br>Urban Estate','Gurgaon','HR','INDIA','122017','9810208298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:13:01',0,NULL,3,1,2,1,NULL,'deebarajpal\r刘\r\\'),(7111,653428664001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','ezipman','yapls2002@yahoo.com.sg','William Yap','Blk 662 Choa Chu Kang Crescent<br>#16-271','default','','SINGAPORE','680662','91808647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 03:53:47',0,NULL,3,1,11,1,NULL,'ezipman\r庄'),(7112,694031585002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','spetsnazth','birdcomloso@gmail.com','Teerakiat Vuttima','6 moo 7,Tambon Chiang Dao<br>Chotana Road','Chiang Dao','Chiang Mai','THAILAND','50170','+6681937769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 04:05:43',0,NULL,3,1,2,1,NULL,'spetsnazth\r刘\r\\'),(7113,653439661001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','vwchacer','hham@usa.com','Hugo Ham','440/10816 Macleod trail SE<br>Suite 129','Calgary','AB','CANADA','T2J5N8','(403) 404-7960','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 04:57:18',0,NULL,3,1,3,1,NULL,'vwchacer\r\\\rRA022491173CN'),(7114,694044397002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','japa984','japa984@gmail.com','Jagraj Pattar','14969 69th Ave','Surrey','BC','CANADA','V3S0Y8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 05:18:40',0,NULL,3,1,2,1,NULL,'japa984\r\\'),(7115,694049358002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','neobanthamia','catlleya1@bigpond.com','Grace Bryant','59 Gostwyck Street','Uralla','New South Wales','AUSTRALIA','2358','0267784169','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 05:47:45',0,NULL,3,0,3,1,NULL,'neobanthamia\rXL\rRA117710259CN\r\\'),(7116,653425652001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','hunternmack','kellykiwi@yahoo.com','Kelly Vary','8 Somerset Street<br>Stanhope Gardens','Sydney','New South Wales','AUSTRALIA','2768','0414846563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:48:59',0,NULL,3,0,3,1,NULL,'hunternmack\r1.6x2.1 背景布  2\r黑色 浅蓝\rRA117710262CN'),(7117,653460355001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','sergeykobah','kobahs@mail.ru','Sergey Nikolov','yl. Tihonova 12, korp:2, kv:21','Mirny, Respublika Saha(Yakutya)','RU','RUSSIAN FEDERATION','678175','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 06:59:25',0,NULL,3,1,3,1,NULL,'sergeykobah\r欧标\rRA117710280CN\r\\'),(7118,653489676001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','giddygaga','lornac@hotmail.com','Heri Natal','41- 43 Erskine Street','Sydney','New South Wales','AUSTRALIA','2001','0292903680','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 09:19:51',0,NULL,3,1,3,1,NULL,'giddygaga\r庄\rRA117713051CN'),(7119,653510120001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','alentement90','tement.alen@gmail.com','Alen Tement','Videm pri Ptuju 37','Videm pri Ptuju','','SLOVENIA','2284 ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 10:44:18',0,NULL,3,1,2,1,NULL,'alentement90\r庄'),(7120,653539322001,110526978476,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','emarjac','red.door@bigpond.com','Chris B Harrison','PO BOX 24','Durham Ox','Victoria','AUSTRALIA','3576','0354551251','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:34:59',0,NULL,3,1,2,1,NULL,'emarjac\r庄'),(7121,694144017002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:41',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7122,694143081002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:41',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7123,694144718002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 12:56:42',0,NULL,3,1,4,1,NULL,'andrewespuni1979\r欧标\r套装 + 下面的产品：\r柔光伞   1\r绿叶 ND8  52mm   1\rlenspen     1\r绿叶 渐变镜 52mm    1\r绿叶 渐变镜 58mm    1\r绿叶 渐变镜 72mm    1\r绿叶 ND4  52mm    1\r绿叶 ND4  58mm   1\r绿叶 ND8  58mm   1\rLighting kit  $30\r王\rYW864488583CN\r'),(7124,694143548002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:45',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7125,653539355001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:56:51',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7126,694143229002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:02',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7127,694142939002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:10',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7128,694142976002,120454219152,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',5.8,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:10',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7129,694143047002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',6.2,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:17',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7130,694142881002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 12:57:58',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(7131,694159447002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','geekool','geek00l@gmail.com','CS Lee','SL-127 Jalan Besar','Kuala Kurau','Perak','MALAYSIA','34350','016-4159873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:33:32',0,NULL,3,1,2,1,NULL,'geekool\r徐'),(7132,653559099001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','busuioaca792010','busuioaca79@yahoo.com','Busuioc Adrian','Mihai Viteazu Nr.1 Sc. B Ap. 35','Bacau','Bacau','ROMANIA','600055','+40752300215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 13:40:18',0,NULL,3,1,2,1,NULL,'busuioaca792010\r徐'),(7133,653578429001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','pakornkitjaikla','jaikla@gmail.com','Pakornkit Jaikla','585/76 CITY HOME Ratchada-Pinklao Condominium<br>Charansanitwong 95/1 Rd. Bang Ao, Bangplat','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:43:52',0,NULL,3,1,17,0,NULL,'pakornkitjaikla\r'),(7134,653583996001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','pakornkitjaikla','jaikla@gmail.com','Pakornkit Jaikla','585/76 CITY HOME Ratchada-Pinklao Condominium<br>Charansanitwong 95/1 Rd. Bang Ao, Bangplat','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 14:59:03',0,NULL,3,1,3,1,NULL,'pakornkitjaikla\r徐\r反光板  80cm 5合1    1\r圆形柔光棚 40cm       1\rRA117713153CN'),(7135,653593625001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 15:26:18',0,NULL,3,1,17,0,NULL,'loboau_au\r王'),(7136,761558274015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.28,'hutongstore','gergo*','gery03@mailbox.hu','Gergő Szotkó','Menyhárt József tér 2 fszt. 1','Debrecen','Hajdú-Bihar','HUNGARY','4032','+36306021014','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 15:35:25',0,NULL,3,1,2,1,NULL,'gergo*\r徐'),(7137,653597058001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 15:37:18',0,NULL,3,1,17,0,NULL,'loboau_au\r庄'),(7138,653600001001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','loboau_au','flovibagar@yahoo.es','Florian Vicente Bazataqui Garcia','virgen de lourdes nº 7 bajo derecha','puerto sagunto','Comunidad Valenciana','SPAIN','46520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 15:40:23',0,NULL,3,1,4,1,NULL,'loboau_au\r反光板支架   1\r斜臂   1\r小号灰卡    1\rphotography acc  $20\r庄\rYW864488572CN'),(7139,653609228001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','alwaystubed','bwolfe@pacbell.net','Brad Wolfe','2317 Auto Park Way','Escondido','CA','UNITED STATES','92029','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 16:04:06',0,NULL,3,1,1,1,NULL,'alwaystubed\r庄'),(7140,651450633018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','diixiirkazan','diixiir@gmail.com','Dmitri Kochnev','Yamasheva street, dom (house) 51, kvartira(flat) 169','Kazan','Tatarstan','RUSSIAN FEDERATION','420126','89625603803','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-30 16:08:32',0,NULL,3,1,5,1,NULL,'diixiirkazan\r刘\r欧标\r申报：lighting kit　\r$165\rCP226344750CN\r'),(7141,689646403002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','deamidated1911rush','julien14orbt@yahoo.com','Panama Netbuy','8424 NW 56th St<br>Ste PTY-1779','Doral','FL','UNITED STATES','33166-3327','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-03-30 16:54:15',0,NULL,3,1,1,1,NULL,'deamidated1911rush\r徐'),(7142,694229488002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',12,'AB1407',65.88,'hermeshine','masterclnprdllc','masterclnprd@gmail.com','Sal Muscarella','745 Valley St<br>Unit B','Colorado springs','CO','UNITED STATES','80915-3745','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 16:48:06',0,NULL,3,1,1,1,NULL,'masterclnprdllc\r、'),(7143,653626394001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 17:11:57',0,NULL,3,1,5,1,NULL,'anato01\r庄\rCP226344777CN'),(7144,693946299002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','scuba.carlos','escuba.carlos@gmail.com','Carlos Otero Navarro','avda. Pintor Felo Monzón<br>nº2, portal 3 - 3º puerta 2','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 17:45:34',0,NULL,3,1,2,1,NULL,'scuba.carlos\r徐'),(7145,653663500001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','srclaudinei','srclaudinei@yahoo.com.br','Claudinei Rodrigues dos Santos','Av:  Souza Lima, 557 - Universitária II','Campo Grande','Mato Grosso do Sul','BRAZIL','79071340','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 18:22:10',0,NULL,3,1,5,1,NULL,'srclaudinei\r申报 backgound  support  $35\r王  \rCP226344715CN'),(7146,694282796002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','capnjack818','laurengposs@hotmail.com','Lauren G. Poss','492 N Lake Dr','Sandersville','GA','UNITED STATES','31082-7504','','NoPaymentFailure','CheckoutComplete','Other','2011-03-30 18:38:04',0,NULL,3,0,3,1,NULL,'capnjack818\r王\rRA117713034CN'),(7147,653683977001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','whitelion_85','emilia_m@netti.fi','Marianna Purhonen','Niinitie 38 B 13','Nastola','','FINLAND','15560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 18:45:38',0,NULL,3,1,2,1,NULL,'whitelion_85\r徐'),(7148,653687331001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','emiber63','eniber_63@yahoo.com','Emil Berman','Mishol shedema 23','Karmiel','','ISRAEL','21981','+972545233990','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 18:52:23',0,NULL,3,1,3,1,NULL,'emiber63\r背景架2m（ 白 黑） 1\r发两个小包\r王+庄\rRA117713082CN\rRA117713065CN'),(7149,694280790002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ultrasmaga','magapsix@meta.ua','Yuri Maga','Kievskaya naberezhna 20 kv 31','Uzhgorod','Zakarpatskaya obl','UKRAINE','88018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 19:56:05',0,NULL,3,1,5,1,NULL,'ultrasmaga\r白色背景布  2m架子\r庄\rCP226344732CN'),(7150,653736656001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','bigsandro17465','info@media-sound.it','Sandro Gentile','Via San Sisto,6','Trescore Balneario','Bergamo','ITALY','24069','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 20:17:20',0,NULL,3,1,3,1,NULL,'bigsandro17465\r刘\rRA117710302CN'),(7151,653746124001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','o_maggie','kellyrowe@xplornet.ca','Kelly Fraleigh','P.O.Box 212','Nestleton Station','ON','CANADA','L0B1L0','(905) 259-2552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 20:35:41',0,NULL,3,1,2,1,NULL,'o_maggie\r刘'),(7152,694354992002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1307',11.37,'hermeshine','pa4credit','willpa4credit@gmail.com','Rob Rhodes','203 Harbor Lndg','Braidwood','IL','UNITED STATES','60408-1763','(630) 935-7945','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-30 20:46:04',0,NULL,3,1,1,1,NULL,'pa4credit\r刘'),(7153,762083662015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','prof._b','timn33@gmail.com','Tim Nightinale','3 Butterfields','Camberley','Surrey','UNITED KINGDOM','GU15 3EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 20:51:56',0,NULL,3,1,2,1,NULL,'prof._b\r徐'),(7154,762106081015,250692242373,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',2.4,'hutongstore','mzalmy2','mohd_zalmy@yahoo.com','Mohd Zalmy Zakaria','Stipendiegränd 4A Lgh 1201','Umeå','Vasterbotten','SWEDEN','90735','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-30 21:30:52',0,NULL,3,1,2,1,NULL,'mzalmy2\r徐'),(7155,746783678016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','secretwishclothinguk','secretwishuk@googlemail.com','Pawel Cwajna','70 Silbury Avenue','Mitcham','Surrey','UNITED KINGDOM','CR4 3SQ','07756910125','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 21:59:34',0,NULL,3,1,17,0,NULL,'secretwishclothinguk'),(7156,746783670016,260660051871,'New 3 pcs filters for Cokin System P Series',1,'AKT062',13.8,'hutongstore','secretwishclothinguk','secretwishuk@googlemail.com','Pawel Cwajna','70 Silbury Avenue','Mitcham','Surrey','UNITED KINGDOM','CR4 3SQ','07756910125','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-30 21:59:35',0,NULL,3,1,3,1,NULL,'secretwishclothinguk\rＮＤ２／４／８　　　１\r渐变灰    1\r77mm  1\r环架    1\r刘\rRA117711890CN\r\\'),(7157,694388132002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 22:03:50',0,NULL,3,1,3,1,NULL,'saud-p\r分成两个小包发\r王\rRA117713096CN\rRA117710214CN'),(7158,694382624002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-30 22:04:01',0,NULL,3,1,3,1,NULL,'saud-p\r分成2个小包发\r王\rRA117713105CN\rRA117710228CN'),(7159,653791369001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','regon7','jotafoto@yahoo.es','Francisco Javier Replinger Gonzalez','C/ Opera Carmen 65- 3ºB<br>Eurohogar II','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41007','687790888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 22:27:16',0,NULL,3,1,2,1,NULL,'regon7\r徐'),(7160,694413042002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','pablocaugusto','ebay@pabloaugusto.com','Pablo  da Cunha Augusto Pinto','Av Nossa Senhora de Fatima 33 / 705 - Centro','Rio de Janeiro','RJ','BRAZIL','20240-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-30 23:31:05',0,NULL,3,1,2,1,NULL,'pablocaugusto\r刘'),(7161,653825193001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 00:38:09',0,NULL,3,1,5,1,NULL,'kosowar7\r套装＋一个单灯头欧标　１\r欧标\r庄\rCP226344729CN'),(7162,694435710002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 00:44:28',0,NULL,3,1,17,0,NULL,'kosowar7'),(7163,653831092001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','bubbleforshoping','bubbleforshop@gmail.com','Sirichi Srimahattarchi','21/13 Moo 7 Soi Rattanasakha<br>T.Maehei','A.Muang','Chiangmai','THAILAND','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 01:01:37',0,NULL,3,1,11,1,NULL,'bubbleforshoping\r刘'),(7164,653323471001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','pappy7209','geevolution@hotmail.com','ERICK PAVEL GUTIERREZ','ING. F. ESPINOSA G. #85-102<br>COL. ATLANTA','CUAUTITLAN IZCALLI','MEXICO','MEXICO','54740','55 5881 7599','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 01:26:33',0,NULL,3,1,3,1,NULL,'pappy7209\r庄\rRA117713025CN'),(7165,653490179001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','chertany2010','chertany@hotmail.com','Tatyana Chernyak','Krasnochechelevska str. 30,<br>Apt.16','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49009','+380958484133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 04:31:33',0,NULL,3,0,2,1,NULL,'chertany2010\r深蓝色\r刘'),(7166,746423049016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','apr0604','alliekidd@hotmail.co.uk','allison kidd','183 bulkington rd','bedworth','warks','UNITED KINGDOM','cv12 9ee','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 05:51:40',0,NULL,3,0,2,1,NULL,'apr0604\r黑色'),(7167,651746663018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',248,'photographyacc','andrijm','andrij_m@inbox.ru','Andriy Matskiv','2 Pokutska str.','Sopiv','Ivano-Frankivsk reg','UKRAINE','78217','380673420266','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-03-31 06:19:10',0,NULL,3,1,5,1,NULL,'andrijm\r2m 灯架   2\r4灯头 棚  欧标   2\r45w 8\r包    1\r2m 灯架   1\r斜臂   1\r50-70 棚 欧标   1\r115w 220v   1\r刘\rCP226344701CN\r'),(7169,653907642001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 07:36:38',0,NULL,3,0,3,1,NULL,'beguin5651\rRA117713122CN\r\\'),(7168,653901091001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','gran748','granote@gmail.com','Eran Granot','1 Israel Ishayahoo<br>p.o.box 2704','Petach TIqva','','ISRAEL','49127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 07:02:20',0,NULL,3,1,11,1,NULL,'gran748\r\\'),(7170,694527812002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 08:10:01',0,NULL,3,0,17,0,NULL,'beguin5651'),(7171,762294790015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','xeno85','clintonmagro@gmail.com','Clinton Magro','4B, Stardust<br>Luqa Briffa Street','Naxxar','MT','MALTA','NXR 2460','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 08:37:07',0,NULL,3,1,3,1,NULL,'xeno85\rRA117713241CN\r\\'),(7172,0,110667377938,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','skibby650','staral4@wi.rr.com','Michael Staral','4212 S 57th St','Milwaukee','WI','UNITED STATES','53220-3123','(414) 546-1747','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 08:43:42',0,NULL,3,1,1,1,NULL,'skibby650\r徐'),(7173,0,120704314361,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jdn4525','jd4525@yahoo.com','Jim Nong','4525 S 17th St','Omaha','NE','UNITED STATES','68107-2154','(402) 932-6664','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 09:13:12',0,NULL,3,1,1,1,NULL,'jdn4525\r庄\r、'),(7174,0,120704307665,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','biigmoe','biigmoe@yahoo.com','Jessica Moeller','830 S Webster Ave<br>Apt 23','Anaheim','CA','UNITED STATES','92804-4156','(949) 235-7078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 09:14:35',0,NULL,3,1,1,1,NULL,'biigmoe\r徐'),(7175,653929869001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','chanjaime','chanjaime@terra.es','Sebastian Molano Robledo','c/ Isaac Albeniz, 24','Cáceres','Extremadura','SPAIN','10005','609861719','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 09:23:31',0,NULL,3,1,2,1,NULL,'chanjaime\r\\'),(7176,653939962001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:25',0,NULL,3,1,17,0,NULL,'borichka'),(7177,653940189001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:26',0,NULL,3,1,17,0,NULL,'borichka'),(7178,694553422002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','borichka','boris@ceva-dsp.com','Boris Shpitser','CEVA DSP<br>2(D) Maskit St.','Herzelia','','ISRAEL','46120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 10:13:27',0,NULL,3,1,3,1,NULL,'borichka\r77mm 接口环   1（缺货）\r广角托架   1\r渐变灰   1\r渐变橙    1\r渐变蓝   1\rRA117713927CN'),(7179,653978542001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 12:50:33',0,NULL,3,1,4,1,NULL,'ffmal\r6663a   1\r绿叶 CPL  77mm    1\r绿叶 CPL  67mm   1\rtripod $20\r庄\rYW864488594CN\r'),(7180,653978847001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:50:34',0,NULL,3,1,17,0,NULL,'ffmal'),(7181,694592878002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','ffmal','florent.marchal@gmail.com','Florent Marchal','1 bis rue de rocheclos','St Germain sur Ille','Bretagne','FRANCE','35250','06 71 61 66 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 12:50:34',0,NULL,3,1,17,0,NULL,'ffmal'),(7182,653467781001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',113.97,'hermeshine','lovercyndi','klmc88@hotmail.com','kenneth lam man chung','90,Jalan Midah Besar, Taman Midah, Cheras','Kuala Lumpur','wilayah persekutuan','MALAYSIA','56000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 12:57:15',0,NULL,3,1,6,1,NULL,'lovercyndi\r王3.43\rEE442466390CN'),(7183,694616080002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gokugohanyeah83','stanebaynow@yahoo.com','stan moua','45012 Tanglewood ct','shelby township','MI','UNITED STATES','48317','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-03-31 13:58:31',0,NULL,5,1,18,0,NULL,'gokugohanyeah83\r庄'),(7184,654004388001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','loutocky','tomasloutocky@seznam.cz','Tomas Loutocky','SALTO spol. s r.o.<br>Kastanova 129a','Brno','','CZECH REPUBLIC','62000','+420 603 837 432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 14:05:13',0,NULL,3,1,3,1,NULL,'loutocky\r王\rRA117713238CN\r\\'),(7185,0,120704307966,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:04',0,NULL,3,1,17,0,NULL,'beadspluss'),(7186,0,110667379386,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:05',0,NULL,3,1,17,0,NULL,'beadspluss'),(7187,0,120704307990,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:06',0,NULL,3,1,17,0,NULL,'beadspluss'),(7188,0,120704307671,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:06',0,NULL,3,1,17,0,NULL,'beadspluss'),(7189,0,110667378970,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:08',0,NULL,3,1,17,0,NULL,'beadspluss'),(7190,0,120704307713,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 14:24:08',0,NULL,3,1,1,1,NULL,'beadspluss\r麂皮   11\r徐\r、'),(7191,654011099001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','mozzaldinho','morcm006@students.unisa.edu.au','Christopher Morrison','24 Albert St<br>Prospect','Adelaide','South Australia','AUSTRALIA','5082','0882692440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 14:26:15',0,NULL,3,1,3,1,NULL,'mozzaldinho\r刘\rRA117713224CN\r、'),(7192,654014907001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','pribilinskiy','steven.pribilinskiy@gmail.com','Steven Pribilinskij','Generala Petrova str., 10/56','Mukachevo','Zakarpatye','UKRAINE','89600','380509667377','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 14:45:53',0,NULL,3,1,3,1,NULL,'pribilinskiy\r庄\rRA117713215CN\r\\'),(7193,694635582002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:03:41',0,NULL,3,1,17,0,NULL,'canadianinternational'),(7194,654019216001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 15:03:42',0,NULL,3,1,3,1,NULL,'canadianinternational\r肩架    1   \r双灯头   1\r大力夹   2   \rRA117713272CN\r\\\r\r'),(7195,694635001002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','canadianinternational','canadadoux@yahoo.ca','marwan issa','319 rue emile','laval','QC','CANADA','H7N 4M3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 15:03:42',0,NULL,3,1,17,0,NULL,'canadianinternational'),(7196,0,110667377495,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.85,'hermeshine','navimomma','katrinasoper@live.com','Katrina Ayala','10109 186th St E<br>Unit 250','Puyallup','WA','UNITED STATES','98375-1810','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 15:59:51',0,NULL,3,1,1,1,NULL,'navimomma\r麂皮  2\r徐'),(7197,0,110667386036,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jkjdawg1','kerney_inc@hotmail.com','Michelle Kerney','310 7th Ave W','Kalispell','MT','UNITED STATES','59901-4762','(406) 212-5734','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'jkjdawg1\r庄'),(7198,654051807001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','666demos666','choteau.frederic@free.fr','frederic choteau','101 rue kuhlmann','lomme','Nord-Pas-de-Calais','FRANCE','59160','0320094695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 16:22:11',0,NULL,3,1,2,1,NULL,'666demos666\r刘\r\\'),(7199,0,110667385136,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','russumselectronics','russumelectronics@yahoo.com','Cole Russum','1730 Homestead CT','Fulton','MO','UNITED STATES','65251-3077','(573) 529-2924','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 16:42:27',0,NULL,3,1,1,1,NULL,'russumselectronics\r刘'),(7200,0,120704305916,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','byrdtrucks11','byrdtrucks@gmail.com','Justin Byrd','2090 Corson St','Pasadena','CA','UNITED STATES','91107-3270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 16:52:40',0,NULL,3,0,1,1,NULL,'byrdtrucks11\r徐\r、'),(7201,694684395002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:09:50',0,NULL,3,1,17,0,NULL,'teatrodemarionetaslaestrella'),(7202,694684309002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 17:09:51',0,NULL,3,1,17,0,NULL,'teatrodemarionetaslaestrella'),(7203,694684044002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 17:09:50',0,NULL,3,1,4,1,NULL,'teatrodemarionetaslaestrella\r2m 灯架   1\r反光板支架   1\r反光板 100*150 40*60 5合1  1\r反光板 80cm 2合1    1\r燕文 一票两件\rreflector holder  $25\r刘\rYW864488605CN\r从这里开始查询    小王\r'),(7204,694698467002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','curagash11','ghiweras@yahoo.com','Vadim Sadykov','1934 E 28th St<br>Bsmt Floor','Brooklyn','NY','UNITED STATES','11229-2533','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 17:38:48',0,NULL,3,1,1,1,NULL,'curagash11\r徐'),(7205,762542034015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','casualbuyer_7','morrisseeee_7@yahoo.ie','martin nolan','boherash<br>glanworth','cork','Cork','IRELAND','default','0872042774','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 18:50:23',0,NULL,3,1,2,1,NULL,'casualbuyer_7\r徐\r\\'),(7206,694737949002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','csmfnl89','astrofilo2007@libero.it','Cosimo Fanuli','via Giacomo Leopardi 11','Oria','BR','ITALY','72024','0831849031','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 19:00:23',0,NULL,3,0,3,1,NULL,'csmfnl89\rL\r庄\rRA117713184CN\r、'),(7207,747207660016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','hamburg-chill','ebay@feustel.com','Andreas Feustel','Lindenallee 5d','Reinbek','','GERMANY','21465','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 19:08:54',0,NULL,3,1,3,1,NULL,'hamburg-chill\r庄\rRA117713198CN\r、'),(7208,747208227016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','trampower','ctram01@gmail.com','Cuong Tram','35 Moon Shadow Dr','Milpitas','CA','UNITED STATES','95035-8711','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 19:10:20',0,NULL,3,1,1,1,NULL,'trampower\r庄\r、'),(7209,747209043016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','benmachulk','ben.kelly@tiscali.co.uk','Ben Kelly','80 Daylesford Drive<br>Castle Dene','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE3 1TW','07896827685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-03-31 19:11:04',0,NULL,3,1,2,1,NULL,'benmachulk\r庄\r\\'),(7210,653774707001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','guajejorge','guaje53@hotmail.com','JORGE VAZQUEZ MARTINEZ','AV CANARIAS, 20-6ª A<br>LAS PALMAS DE GC','LAS PALMAS DE G.C.','Canarias','SPAIN','35002','928256130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-03-31 19:21:03',0,NULL,3,1,4,1,NULL,'guajejorge\r刘\rtripod $20\r6663a  1\r6663a 的快装板   1\rYW864488616CN'),(7211,0,110667387962,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:17',0,NULL,3,1,17,0,NULL,'alemed277'),(7212,0,110667387859,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:17',0,NULL,3,1,17,0,NULL,'alemed277'),(7213,0,110667386752,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:18',0,NULL,3,1,17,0,NULL,'alemed277'),(7214,0,120704314932,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:19',0,NULL,3,1,17,0,NULL,'alemed277'),(7215,0,120704315250,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:19',0,NULL,3,1,17,0,NULL,'alemed277'),(7216,0,110667387387,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:20',0,NULL,3,1,17,0,NULL,'alemed277'),(7217,0,120704315279,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:20',0,NULL,3,1,17,0,NULL,'alemed277'),(7218,0,120704315269,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:21',0,NULL,3,1,17,0,NULL,'alemed277'),(7219,0,110667387823,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:25:21',0,NULL,3,1,17,0,NULL,'alemed277'),(7220,0,120704314876,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:28:36',0,NULL,3,1,17,0,NULL,'alemed277'),(7221,0,110667387872,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:28:58',0,NULL,3,1,17,0,NULL,'alemed277'),(7222,0,110667387442,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:00',0,NULL,3,1,17,0,NULL,'alemed277'),(7223,0,120704314938,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:02',0,NULL,3,1,17,0,NULL,'alemed277'),(7224,0,110667387373,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:10',0,NULL,3,1,17,0,NULL,'alemed277'),(7225,0,110667387842,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:11',0,NULL,3,1,17,0,NULL,'alemed277'),(7226,654137243001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','guajejorge','guaje53@hotmail.com','JORGE VAZQUEZ MARTINEZ','AV CANARIAS, 20-6ª A<br>LAS PALMAS DE GC','LAS PALMAS DE G.C.','Canarias','SPAIN','35002','928256130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 19:29:16',0,NULL,3,1,17,0,NULL,'guajejorge'),(7227,0,110667387396,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:20',0,NULL,3,1,17,0,NULL,'alemed277'),(7228,0,120704314928,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:24',0,NULL,3,1,17,0,NULL,'alemed277'),(7229,0,120704315244,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:29:24',0,NULL,3,1,17,0,NULL,'alemed277'),(7230,0,110667387418,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:30:36',0,NULL,3,1,17,0,NULL,'alemed277'),(7231,0,110667387800,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','alemed277','alemed27@gmail.com','Alex Medeiros','22 Troy Rd','Belmont','MA','UNITED STATES','02478-4156','(617) 484-9634','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:30:36',0,NULL,3,1,1,1,NULL,'alemed277\r麂皮  20'),(7232,0,110667385102,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','greybeard48','greybeardsebay@yahoo.com','Austin Bradley','PO Box 1291','Buffalo','MO','UNITED STATES','65622-1291','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 19:57:34',0,NULL,3,0,1,1,NULL,'greybeard48\r徐'),(7233,654169928001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mpchaney8','newkid521@web.de','Michael P. Chaney','Eppelheimer Str. 69','Heidelberg','','GERMANY','69123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:33:34',0,NULL,3,1,2,1,NULL,'mpchaney8\r刘\r\\'),(7234,654178086001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','ibuyyousell2010','a_d_guzman@shaw.ca','alexander de guzman','2820-66 st ne','calgary','AB','CANADA','t1y4m9','(403) 383-4227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 20:51:16',0,NULL,3,1,3,1,NULL,'ibuyyousell2010\r刘\r1 X 77mm ring adapter（缺）\r1 X filter adapter\r3 X Filters (ND2 + ND4 + ND8)\rRA117713913CN\r'),(7235,762634140015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:39',0,NULL,3,1,17,0,NULL,'turisam'),(7236,762634237015,250623448641,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:39',0,NULL,3,1,17,0,NULL,'turisam'),(7237,762633862015,250599911589,'New Air Dust Blower Cleaner Pump and Cloth ',1,'AA1311',3.5,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:40',0,NULL,3,1,17,0,NULL,'turisam'),(7238,762634054015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-03-31 21:17:40',0,NULL,3,1,3,1,NULL,'turisam\r大号灰卡   1\r气吹 + 布   1\rlenspen   2\r45w 5500k 灯泡   2\r庄\rRA117713286CN\r、\r'),(7239,0,110667378590,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1,'hermeshine','makarachan','makararath@gmail.com','Makara Rath','10057 CYPRESS AVE','RIVERSIDE','CA','UNITED STATES','92503-1657','(951) 688-8636','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:19:14',0,NULL,3,0,1,1,NULL,'makarachan\r庄'),(7240,654190557001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','r53115','mrrudyv@yahoo.com','Rudy Villarreal','1335 Racine St','Delavan','WI','UNITED STATES','53115-1462','(262) 949-7917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:20:46',0,NULL,3,1,17,0,NULL,'r53115'),(7241,694810024002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','r53115','mrrudyv@yahoo.com','Rudy Villarreal','1335 Racine St','Delavan','WI','UNITED STATES','53115-1462','(262) 949-7917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 21:23:06',0,NULL,3,1,1,1,NULL,'r53115\rcanon 反接环  52mm  1\r绿叶 ND8  52mm   1\r庄'),(7242,747293616016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','sale9900','u_nek_reality@yahoo.com','sandy alexander','6300 Milgen Rd<br>Apt 1270','Columbus','GA','UNITED STATES','31907','(918) 277-2322','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-03-31 21:32:12',0,NULL,3,1,4,1,NULL,'sale9900\r美标头+110v灯泡\r王\rYW864488620CN'),(7243,654206444001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','raiminati','fernandezj57@gmail.com','Jose Fernandez','578 Academy St<br>Apt 4B','New York','NY','UNITED STATES','10034-5230','','NoPaymentFailure','CheckoutComplete','Other','2011-03-31 22:04:38',0,NULL,3,1,3,1,NULL,'raiminati\r王\rRA117713167CN\r\\'),(7244,653956201001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','hannahkatehm','hannahamills@yahoo.com.au','Janine Rossi','5 Hodgson Terrace','Richmond','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 22:21:49',0,NULL,3,1,2,1,NULL,'hannahkatehm\r徐\r\\');
INSERT INTO `hmsh_ebay_transaction` VALUES (7245,0,110667377301,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',2.5,'hermeshine','tonymorales2','tony.morales2@comcast.net','Ramon A. Morales','6 Steeplechase Ct','Cherry Hill','NJ','UNITED STATES','08003-5165','(856) 354-8715','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 22:31:13',0,NULL,3,0,1,1,NULL,'tonymorales2\r庄\r麂皮   2\r、'),(7246,0,120704307109,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:39',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7247,0,110667377483,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.52,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:32',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7248,0,110667387294,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:39',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7249,0,120704307155,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.16,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:40',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7250,0,120704308012,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:41',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7251,0,120704304752,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:41',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7252,0,120704312505,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:42',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7253,0,120704308508,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:42',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7254,0,120704306614,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-03-31 23:04:43',0,NULL,3,0,1,1,NULL,'qiqi77zz\r就发1x（黑粗）麂皮给他就行了'),(7255,654229716001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','coorykoray','korayturkay@gmail.com','Koray Turkay','kurucesme mah. sakarya cad no:46<br>Osmangazi','bursa','','TURKEY','16050','902242236064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-03-31 23:41:31',0,NULL,3,1,2,1,NULL,'coorykoray\r徐\r\\'),(7256,694859686002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','julesoille','julesoille@hotmail.com','Jules Oille','189 Bullock Dr','Markham','ON','CANADA','L3P 1W4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 00:04:51',0,NULL,3,1,3,1,NULL,'julesoille\r王\rRA117713255CN\r\\'),(7257,0,110667377505,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.18,'hermeshine','utahskimom','michelle@milburn.cc','Michelle L Milburn','100 Ottermont Ct','Cary','NC','UNITED STATES','27513','(919) 469-5822','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 00:29:25',0,NULL,3,0,1,1,NULL,'utahskimom\r庄\r麂皮 3'),(7258,654256405001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','jhune9','jhunesalenga@gmail.com','Napoleon Salenga','#29 Vivians Crescent','Brampton','ON','CANADA','L6Y 4V1','(905) 454-6711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 01:21:25',0,NULL,3,1,3,1,NULL,'jhune9\r72mm 接口环  1\r托架  1\rND4, ND8 and 渐变灰   1\r庄\rRA117713175CN\r\\'),(7259,654257971001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','salqa','newvisionmedia@snet.net','Jose Martinez','40 Timothy Ter<br>New Vision Media, Llc','Windsor','CT','UNITED STATES','06095-1652','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'salqa\rLK035429603CN'),(7260,0,120704307194,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','i3izkit311','jbawholesaleresale@gmail.com','Joey Abrin','4025 Pinella Cir<br>Apt 654','Palm Beach Gardens','FL','UNITED STATES','33410-6730','(248) 542-2746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 01:38:27',0,NULL,3,1,1,1,NULL,'i3izkit311\r庄\r、'),(7261,654279042001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','maryanne8516','manne4@mac.com','Mary Anne lapenna','134 D\'Ostende','vimont, Laval','QC','CANADA','H7K3L1','(514) 802-6284','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 03:04:03',0,NULL,3,1,3,1,NULL,'maryanne8516\r庄\rRA117713357CN\r、'),(7262,0,120704314038,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.12,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 03:40:56',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7263,0,110667386780,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.72,'hermeshine','qiqi77zz','steven8philly@gmail.com','qi zhao, Panphil Realty,','1025 S 8th St','Philadelphia','PA','UNITED STATES','19147-4718','(267) 582-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 03:40:59',0,NULL,5,0,18,0,NULL,'qiqi77zz'),(7264,694926076002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mikeythetiregod','t_ateah@yahoo.ca','mike alexander','B 45658 lewis ave','CHILLIWACK','BC','CANADA','V2P3C6','(604) 418-1502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 04:50:52',0,NULL,3,1,3,1,NULL,'mikeythetiregod\rRA117716013CN'),(7265,654302131001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','tomburke7','burke.thomas.s@edumail.vic.gov.au','Tom Burke','7 Farrer Crt','Warranwood','Victoria','AUSTRALIA','3134','0398763047','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 05:09:36',0,NULL,3,1,2,1,NULL,'tomburke7\r徐'),(7266,654306164001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 05:35:04',0,NULL,3,1,3,1,NULL,'dmitriyla\r欧标\rRA117713330CN\r、'),(7267,694940637002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ikarus_65','ebay@solbach.org','Ludger Solbach','440 Clyde Ave<br>Audience Inc.','Mountain View','CA','UNITED STATES','94043-2232','(650) 440-0602','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 06:18:53',0,NULL,3,1,1,1,NULL,'ikarus_65'),(7279,654347988001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','robertogrilloph','phrgrillo@gmail.com','Roberto Grillo','via duca degli abruzzi 16','san giovanni la punta','CT','ITALY','95037','3477471241','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 09:32:13',0,NULL,3,1,3,1,NULL,'robertogrilloph\r刘\rRA117713958CN\r'),(7268,654327382001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','88boub','nicolas_grienenberger@hotmail.fr','nicolas grienenberger','25 rue frédéric mistral','matzenheim','Alsace','FRANCE','67150','0620965418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 07:38:59',0,NULL,3,0,2,1,NULL,'88boub\r、'),(7269,0,120704307690,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:38',0,NULL,3,0,17,0,NULL,'beadspluss'),(7270,0,110667379460,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:39',0,NULL,3,0,17,0,NULL,'beadspluss'),(7271,0,120704307620,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:40',0,NULL,3,0,17,0,NULL,'beadspluss'),(7272,0,110667379746,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:41',0,NULL,3,0,17,0,NULL,'beadspluss'),(7273,0,110667379000,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:08:42',0,NULL,3,0,17,0,NULL,'beadspluss'),(7274,654336973001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mohamed_remember','the_remember_@hotmail.com','Mohamed Ratoun','C/General Prim<br>39 - 3 - 3','Sant Fruitós de Bages','Cataluña','SPAIN','08272','634853283','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 08:27:58',0,NULL,3,0,3,1,NULL,'mohamed_remember\rRA117713391CN\r\\'),(7275,694964137002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','kirian7','kirian3@lycos.com','Gunnar Gercke','Achtern Barg 9a','Barsbüttel','','GERMANY','22885','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 08:28:21',0,NULL,3,0,2,1,NULL,'kirian7\r\\'),(7276,654339585001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','fotoivideo','vlado.ludas@gmail.com','Vladimir Ludaš','Argentinska <br>2','Zagreb','','CROATIA','10000','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 08:40:31',0,NULL,3,1,3,1,NULL,'fotoivideo\r庄\rRA117713374CN\r\\'),(7277,0,110667379376,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','beadspluss','newplr123@yahoo.com','joseph simonelli','1607 Azalea Cir<br>apt b','springdale','AR','UNITED STATES','72764-7626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 08:52:54',0,NULL,3,1,1,1,NULL,'beadspluss\r刘'),(7278,654344212001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','uszkomatonta','don@tricon.hu','Szilard Pasztor','Kaposvár u. 14-18.','Budapest','Hungary','HUNGARY','1117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 09:02:49',0,NULL,3,1,2,1,NULL,'uszkomatonta\\'),(7280,747490196016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','graeme-maria','graemeh@o2.ie','Graeme Haughton','24 Ryecroft<br>Church road','Bray','Wicklow','IRELAND','00','35312763294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-01 09:43:16',0,NULL,3,1,2,1,NULL,'graeme-maria\\'),(7281,654362370001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kata141kata','katahorvat14@gmail.com','Kata Horvat','Šumska 14<br>Brdovec','Prigorje Brdovečko','','CROATIA','10291','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 10:24:51',0,NULL,3,1,3,1,NULL,'kata141kata\r刘\rRA117713428CN\r'),(7282,747502641016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','dedoso','d.batacchi@gmail.com','David Batacchi','via di castello 37','firenze','FI','ITALY','50141','055-4590810','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-01 10:29:36',0,NULL,3,0,4,1,NULL,'dedoso\r欧标\rlighting kit  $30\r庄\rYW864488723CN'),(7283,694996013002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',5,'AC2402',114.95,'hermeshine','dermafrance','domdeb0@yahoo.com.br','Dominique Debusschere Dermafrance','rua São Paulo 409 Centro','Belo Horizonte','MG','BRAZIL','30170130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 11:32:25',0,NULL,3,1,5,1,NULL,'dermafrance\rCP226344692CN\r王   \r从这里开始查的  小王'),(7284,654378605001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','fgr91','frederic.grosso@free.fr','GROSSO Frédéric','2 rue Pierre Picard','Massy','91','FRANCE','91300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 11:34:38',0,NULL,3,1,3,1,NULL,'fgr91\rRA117713873CN\r'),(7285,694084740002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','ashisusu11','ashisusu@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','3332205045','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 11:57:56',0,NULL,3,1,3,1,NULL,'ashisusu11\r刘\rRA117713414CN\r'),(7286,747551013016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','mike-elvis','info@elvisonline.dk','Mike Andersen','Slotsgade 12, 3Th.','Hillerød','standard','DENMARK','3400','24243808','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-01 13:10:26',0,NULL,3,1,4,1,NULL,'mike-elvis\r欧标\r刘   \rYW864488712CN'),(7287,654414823001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','igorshljivo','sljivo1981@gmail.com','Igor Sljivancanin','Stari aerodrom, Lamela 4','PODGORICA','MONTENEGRO','MONTENEGRO','81000','+38267816326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 13:44:29',0,NULL,3,1,2,1,NULL,'igorshljivo\r刘\r\\'),(7288,654427990001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','cosplaycasuals','cosplaycasuals@gmail.com','zet barrett','531 bennett ave','american falls','ID','UNITED STATES','83211','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 14:38:59',0,NULL,3,0,1,1,NULL,'cosplaycasuals\r刘'),(7289,654406335001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',36.92,'hermeshine','leon12blau','wolfgang.gfrerer@arcor.de','Wolfgang Gfrerer','Gewuerzmuehlstr. 3','Muenchen','','GERMANY','80538','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 14:41:45',0,NULL,3,0,3,1,'RA117727988CN\r ','leon12blau\r刘\rRA117713445CN\r当时漏发了：\r大号内胆包无字   1\r中号内胆包 nikon   1\r绿叶72mm cpl   1\r无字肩带   1\rlenspen    1\r\r\r\r'),(7290,694690414002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AKT039',26.99,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrei Aksenov','str. Vologodskaya 25-74','Arhangelsk','Arhangelsk region','RUSSIAN FEDERATION','163001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:08:37',0,NULL,3,0,3,1,NULL,'andreiphotografy\r新的那个4灯头 有伞孔的  1\rRA117713887CN\r'),(7291,695078922002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','28666466','vadim.ka@inbox.lv','Vadims Blazevics','Rigas 72-15','Daugavpils','','LATVIA','LV-5401','37129895549','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:40:22',0,NULL,3,1,3,1,NULL,'28666466\r徐\rRA117713493CN\r'),(7292,654456565001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',3,'AC1201',14.7,'hermeshine','mauriciomartins','mmartins98@yahoo.com','Mauricio Silva','Rua Espumas 200 / 205<br>Ilha do Governador','Rio de Janeiro','Rio de Janeiro','BRAZIL','21941170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 15:54:52',0,NULL,3,1,2,1,NULL,'mauriciomartins\r刘\r\\'),(7293,654502549001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','erikaryanngtar','erikaryann@hotmail.com','Erika Sedmak','1961 S Josephine St<br>Apt 103','Denver','CO','UNITED STATES','80210-4235','(303) 885-9151','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-01 17:55:39',0,NULL,3,1,1,1,NULL,'erikaryanngtar\r刘'),(7294,695135558002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','armaram','aramkostanyan@gmail.com','Armen Gharibyan','1 Jivani str. (lane)','Yerevan','','ARMENIA','0032','37410534976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:03:18',0,NULL,3,1,17,0,NULL,'armaram'),(7295,654510926001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','armaram','aramkostanyan@gmail.com','Armen Gharibyan','1 Jivani str. (lane)','Yerevan','','ARMENIA','0032','37410534976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 18:15:36',0,NULL,3,1,2,1,NULL,'armaram\r反光板 60cm 2合1   1\r倒影板（白黑）   1\r\\'),(7296,695144880002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','drummer5829','drummer5829@comcast.net','Matt Quock','129 Lathrop St','Madison','WI','UNITED STATES','53726-4079','(630) 485-8152','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 18:35:41',0,NULL,3,1,1,1,NULL,'drummer5829\r刘'),(7297,695179417002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','sweetone4ever','sweet_one_at_heart11683@yahoo.com','Karri  Allen','1514 Colorado St','Midland','MI','UNITED STATES','48642-5726','(989) 600-6358','NoPaymentFailure','CheckoutComplete','Other','2011-04-01 19:41:04',0,NULL,3,1,4,1,NULL,'sweetone4ever\rlighting kit $25\r庄\rYW864488701CN'),(7298,695187988002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','hawkkwah','giperhawk@mail.ru','Aleksey Zagirniy','Delegatskaya str., 10-25','Donetsk','UA','UKRAINE','83036','+380503550412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 19:55:53',0,NULL,3,1,2,1,NULL,'hawkkwah\r徐\r\\'),(7299,695198619002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','kados_de','dornbusch@gmx.de','Sascha Dornbusch','Sinnersdorfer Str. 45','Dormagen','','GERMANY','41540','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 20:19:43',0,NULL,3,1,3,1,NULL,'kados_de\r庄\rRA117713900CN\r'),(7300,654569443001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','matthieuwmc13','matthieu.melquiond@voila.fr','matthieu melquiond','93 rue horace bertin','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13005','06.25.07.33.28','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 20:32:11',0,NULL,3,1,3,1,NULL,'matthieuwmc13\r刘\rRA117713502CN\r'),(7301,747772655016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','markem808','markem@inbox.lv','Marks Maksimovs','Yewfield<br>Hawkshead Hill','Ambleside','Cumbria','UNITED KINGDOM','la22 0pr','07532425149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 21:00:14',0,NULL,3,1,2,1,NULL,'markem808\r王\r\\'),(7302,693638601002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','dezlentin','leneyt@live.no','Lene Tindlund','Randulveien 6c','Sellebakk','Østfold','NORWAY','1654','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 21:13:14',0,NULL,3,1,3,1,NULL,'dezlentin\r庄\rRA117713431CN\r'),(7303,654603405001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','embassylimosine','utokhvre@yahoo.com','Urmas Tokhvre','723 A St NE<br># B','Auburn','WA','UNITED STATES','98002-4026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 21:57:43',0,NULL,3,1,1,1,NULL,'embassylimosine\r徐'),(7304,654608691001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','17tma','t.avis@sky.com','teresa avis','the basement flat<br>17 the esplanade','seaford','East Sussex','UNITED KINGDOM','bn25 1jl','01323872027','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 22:16:41',0,NULL,3,0,3,1,NULL,'17tma\rXXXL\rRA117714009CN'),(7305,652501330018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','stefangraur2010','stefangraur@yahoo.com','Stefan Graur','str. Olanesti, nr. 6, bl38, sc.2, ap72<br>sector 6','Bucuresti','','ROMANIA','060401','+407 43827523','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-01 22:24:23',0,NULL,3,1,5,1,NULL,'stefangraur2010\r欧标\r王\rCP226344675CN'),(7306,747815144016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','mazhitova*2007','forever_after@mail.ru','Assel Mazhitova','Basement Front Flat<br>37 Great Cumberland Place','London','London','UNITED KINGDOM','W1H7TD','07500444807','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 22:51:33',0,NULL,3,1,2,1,NULL,'mazhitova*2007\r庄\r\\'),(7307,695251679002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:14',0,NULL,3,1,17,0,NULL,'nono-ey'),(7308,695252595002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:15',0,NULL,3,1,17,0,NULL,'nono-ey'),(7309,654617628001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:15',0,NULL,3,1,17,0,NULL,'nono-ey'),(7310,695252002002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-01 23:19:16',0,NULL,3,1,4,1,NULL,'nono-ey\r2m 灯架   2\r双灯头  2 欧标\r反光伞  2\r包    1\r反光板 100*150 40*60 5合1     1\r反光板支架    1\r115w 5500k 灯泡  220v   4\rlighting kit  $30\rYW864488690CN\r庄\r反光板单包， 一票两件\r'),(7311,747832622016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','75relax','joyful7979@yahoo.co.uk','David Whitaker','79 France Furlong,<br>Gt.Linford,','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK14 5EJ','01908674932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-01 23:47:06',0,NULL,3,0,3,1,NULL,'75relax\rRA117713520CN\r\\'),(7312,695268966002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','trapero34','saamba2@hotmail.com','SALVADOR GONZALEZ FERRER','C/PERE MARTEL Nº 40,BAJOS,T.B.C','PALMA DE MALLORCA','Baleares','SPAIN','07003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-01 23:56:26',0,NULL,3,1,2,1,NULL,'trapero34\r徐\r\\'),(7313,695273879002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ussn36','brunosicotte@gmail.com','Bruno Sicotte','2680 rue de Beausejour<br>app.4','Longueuil','QC','CANADA','J4M 1M5','(514) 942-2022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 00:18:00',0,NULL,3,1,3,1,NULL,'ussn36\r庄\rRA117713860CN\r'),(7314,695273792002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:22:01',0,NULL,3,1,17,0,NULL,'paparina-x'),(7315,654637394001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:22:01',0,NULL,3,1,17,0,NULL,'paparina-x'),(7316,654636721001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','paparina-x','fjvila@ono.com','Fco Javier Vila Fernandez','Muntaner 83-C 3º 1ª','Barcelona','Cataluña','SPAIN','08011','666842198','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 00:22:02',0,NULL,3,1,3,1,NULL,'paparina-x\r摄影背心 Nikon 老款  L   1\r大号内胆包 nikon    1\r防寒罩     1 （老款那种防寒罩，应该是最后一个）\r徐\rRA117713944CN\r\r\r'),(7317,654645746001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pocharatka83','magdakoziel83@yahoo.ie','Thomas Kucharczyk','\"PFIZER\" Watermarque Building Ringsend Road<br>Dublin 4','Dublin','Dublin','IRELAND','D4','857320556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 00:56:54',0,NULL,3,1,2,1,NULL,'pocharatka83\r徐\r\\'),(7318,654671909001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','7302edward','yachtvigia@hotmail.com','Edward Atkinson','115/15 Ploenchan 3, Moo 2,<br>Paklok','Thalang','Phuket','THAILAND','83110','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 03:02:16',0,NULL,3,1,6,1,NULL,'7302edward\r庄\rEE442466430CN'),(7319,695295791002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','dcravendavid','crvndcraven@aol.com','David craven','24 chase ln','Cambridge','NY','UNITED STATES','12816-1726','(917) 376-5790','NoPaymentFailure','CheckoutComplete','Other','2011-04-02 03:25:23',0,NULL,3,1,3,1,NULL,'dcravendavid\r庄\r放转美标头\rRA117713459CN'),(7320,654677784001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','your-sweet-home','sweethome.ebay@gmail.com','Maria Belous A.','P.O. Box 1511','Barnaul','Altayregion','RUSSIAN FEDERATION','656066','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 03:35:09',0,NULL,3,1,2,1,NULL,'your-sweet-home\r庄\r、'),(7321,654697392001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','alejandro.arcardini','alejandro.arcardini@hotmail.com','Alejandro Arcardini','osorio 11-75 apto 004','Montevideo','Montevideo','URUGUAY','11300','099280545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 05:42:42',0,NULL,3,1,2,1,NULL,'alejandro.arcardini\r欧标\r、'),(7322,654701924001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','photography_4kids','annette123000@yahoo.com','Marilyn Jackson','203 Water Tank Rd<br>Lot 5','Ruston','LA','UNITED STATES','71270-8568','','NoPaymentFailure','CheckoutComplete','Other','2011-04-02 06:13:55',0,NULL,3,1,1,1,NULL,'photography_4kids\rXL'),(7323,654024345001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',10,'AA3302',73.52,'hermeshine','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 06:57:01',0,NULL,3,1,3,1,NULL,'nord975\r绿叶 UV  52mm   5\r绿叶 UV  55mm   10\r绿叶 UV  67mm   5\r绿叶 UV  72mm   3\rRA117713975CN\r、\r'),(7324,654738297001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','inna22088','ofizer22088@rambler.ru','Ilya Ustinov','Naberegnaya reki Ufy 71-134','Ufa','Bashkortostan','RUSSIAN FEDERATION','450105','+79177621450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 09:15:06',0,NULL,3,0,3,1,NULL,'inna22088\r蓝 色   白色 \r王\rRA117711055CN\r\\'),(7325,747995177016,260660050217,'Aluminium Ultra Lightweight 71\" Camera Monopod 3wayhead',1,'AE1603',21.99,'hutongstore','shep803256','daviddodge04@aol.com','david sheppard','23 the ridgeway','south shields','Tyne and Wear','UNITED KINGDOM','ne34 8bb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 11:07:22',0,NULL,3,1,3,1,NULL,'shep803256\r刘\rRA117711679CN\r\\'),(7326,763383276015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.89,'hutongstore','altea-tdi-sport','andy-wills@hotmail.co.uk','ANDY WILLS','C/O RAWLE GAMMON & BAKER<br>FORDTON','CREDITON','DEVON','UNITED KINGDOM','EX17 3BZ','01363772246','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 11:40:57',0,NULL,3,1,2,1,NULL,'altea-tdi-sport\r徐'),(7327,695436123002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','viktor4i4ek','christopher-grand@ya.ru','Viktor Prymachenko','avenue Obolonskiy, 16-e, ap. 350','Kiev','','UKRAINE','04205','+380662726672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:13:30',0,NULL,3,1,2,1,NULL,'viktor4i4ek\r徐'),(7328,654803914001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','origionalgp','jameson.wheeler@sympatico.ca','jameson wheeler','77 balmoral dr.','brampton','ON','CANADA','l6t1v2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 13:31:06',0,NULL,3,1,3,1,NULL,'origionalgp\r庄\rRA117711815CN\r\\'),(7329,654815495001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','pedritto_kite','pedritto_mo@hotmail.com','pedro morales dominguez','c/prokofiev nº9 1-c','torremolinos (málaga)','Andalucía Ceuta y Melilla','SPAIN','29620','667438651','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 14:12:07',0,NULL,3,1,3,1,NULL,'pedritto_kite\rRA117711872CN\r\\'),(7330,695461141002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','terry.hizon','terry.hizon0608@hotmail.com','Terry Hizon','#249 Lauro st. Villacatalina subd.<br>Dasmarinas, Cavite','Dasmariñas','Cavite','PHILIPPINES','4114','9178800439','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 14:28:33',0,NULL,3,1,3,1,NULL,'terry.hizon\rRA117711943CN\r\\'),(7331,654853459001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','mavesariaxym','mavesari@yahoo.es','manoli rizo san segundo','urb. huerta las pilas c/ thomas edison, 31','algeciras (cadiz)','andalucia cadiz','SPAIN','11204','607190459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 16:01:14',0,NULL,3,1,2,1,NULL,'mavesariaxym\r徐'),(7332,695500383002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 16:18:16',0,NULL,3,1,17,0,NULL,'robert5525'),(7333,763496965015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','the-normad03','normad03@hotmail.com','Dean Brindle','12 Maes Famau','Rhyl','Denbighshire , North Wales','UNITED KINGDOM','LL18 4SJ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-02 16:27:01',0,NULL,3,1,4,1,NULL,'the-normad03\rlighting kit $25\r庄\rYW864488841CN'),(7334,652771830018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','osetia1','art-osetia@mail.ru','Mihnevsky Vladislav Valerevich','13 Street Vorovskogo<br>Apartment 59','Kazan','','RUSSIAN FEDERATION','420057','+79375228723','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-02 16:46:21',0,NULL,3,1,5,1,NULL,'osetia1\r2m 背景架   （ 白色布）  1\r刘\rCP226344573CN'),(7335,654890337001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','maxwellpenney','maxpenney@hotmail.com','MAXWELL PENNEY','43.BRIGUS ROAD, APT 112<br>P.O. BOX 535','WHITBOURNE','NL','CANADA','A0B3K0','(709) 759-3397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 17:38:54',0,NULL,3,1,2,1,NULL,'maxwellpenney\r徐'),(7336,763588660015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cellavee','rg@raygilbert.plus.com','Raymond Gilbert','65 Main Street<br>Stoneyburn','Bathgate','West Lothian','UNITED KINGDOM','EH47 8BY','01501762538','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 19:08:50',0,NULL,3,1,3,1,NULL,'cellavee\rRA117711930CN\r\\'),(7337,695597708002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','pietro-82ct','pietro82ct@hotmail.it','Pietro Zappalà','Via. C. Marchesi, 4','Misterbianco','CT','ITALY','95045','3494551005','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 19:51:48',0,NULL,3,1,4,1,NULL,'pietro-82ct\rlight stand $20\r2m 灯架  1\r斜臂  1\r50-70柔光棚 通用塑料卡口  1\r刘\rYW864488830CN\r\r'),(7338,763622890015,250615144668,'YongNuo Flash Battery Pack 8*AA Canon Flash 580EXII 550',1,'AB3307',32.99,'hutongstore','nilmattos31','nilmattos31@yahoo.co.uk','Nilton Mattos','Flat 4,  81 Burnley Road','Dollis Hill','London','UNITED KINGDOM','NW10 1EE','02088305469','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-02 20:04:26',0,NULL,3,1,3,1,NULL,'nilmattos31\r王\rRA117711033CN\r\\'),(7339,654962832001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 20:08:12',0,NULL,3,1,17,0,NULL,'robert5525'),(7340,695609104002,120448646606,'New ND4 Filter for Cokin P Series Neutral Density ND 4',1,'AA2324',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:24:53',0,NULL,3,1,17,0,NULL,'lobi2318'),(7341,654967367001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:24:57',0,NULL,3,1,17,0,NULL,'lobi2318'),(7342,654966783001,110414378578,'New ND2 Filter for Cokin P Series Neutral Density ND 2',1,'AA2323',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:01',0,NULL,3,1,17,0,NULL,'lobi2318'),(7343,654964796001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:04',0,NULL,3,1,17,0,NULL,'lobi2318'),(7344,695608024002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:25:24',0,NULL,3,1,3,1,NULL,'lobi2318\r72mm 接口环  1\r77mm 接口环  1\r托架   1\r渐变灰  1\rND2      1\rND4      1\rND8      1\r徐\rRA117711047CN\r\\'),(7345,695608452002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','lobi2318','aitorarenaza@hotmail.com','Mº Angeles Echarren Garcia','C/ Sancho Ramirez  Nº 5  -  2º','ESTELLA','Navarra','SPAIN','31200','665724252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 20:26:02',0,NULL,3,1,17,0,NULL,'lobi2318'),(7346,695633060002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','pietro-82ct','pietro82ct@hotmail.it','Pietro Zappalà','Via. C. Marchesi, 4','Misterbianco','CT','ITALY','95045','3494551005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 21:12:52',0,NULL,3,1,17,0,NULL,'pietro-82ct'),(7347,695649241002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','vicentesagredo','vicentesagredo@gmail.com','fernando sagredo stevens','La Marina 7310 dept 1306','Talcahuano','Bio-Bio','CHILE','4260000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-02 21:57:13',0,NULL,3,1,3,1,NULL,'vicentesagredo\rRA117711767CN\r\\'),(7348,655030526001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-02 23:19:08',0,NULL,3,1,17,0,NULL,'robert5525'),(7349,655038223001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','the_fanatic_2','fanatic2@hotmail.com','Jonathan Lauzon','750 Pageau','St-Jerome','QC','CANADA','J7Z6E6','(450) 438-2975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-02 23:49:05',0,NULL,3,1,2,1,NULL,'the_fanatic_2\r徐'),(7350,655040146001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 00:02:10',0,NULL,3,1,2,1,NULL,'jaimeluanco\r徐'),(7351,695728952002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','lubrician10','lubrician@gmail.com','Larry Luber','5228 Tresham ct','Charlotte','NC','UNITED STATES','28215-5056','(704) 507-9751','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 03:00:31',0,NULL,3,1,1,1,NULL,'lubrician10\r徐'),(7352,0,110667379443,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.06,'hermeshine','trevormotors11','trevormotors@gmail.com','Trevor Davis','2090 Corson St','Pasadena','CA','UNITED STATES','91107-3270','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 03:35:45',0,NULL,3,1,1,1,NULL,'trevormotors11\r徐'),(7353,695751838002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','huyddd','darrendao@gmail.com','Darren Dao','3476 Marathon Dr','San Diego','CA','UNITED STATES','92123-2622','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 04:51:37',0,NULL,3,1,1,1,NULL,'huyddd\r徐'),(7354,695780192002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','djezz91','dhochart@club-internet.fr','didier hochart','2 clos du village','écharcon','Ile-de-France','FRANCE','91540','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 07:26:37',0,NULL,3,0,3,1,NULL,'djezz91\rXXXL\r王\rRA117711965CN\r\\'),(7355,695786937002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','izhak801izhak','izhak801@hotmail.com','izhak haime','aharoov 212/8','atlit','','ISRAEL','30300','00972506829988','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 07:51:44',0,NULL,3,1,3,1,NULL,'izhak801izhak\rRA117711719CN\r\\'),(7356,655139525001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','wan_*6','baitrahmah@yahoo.com','Wan Saifuldin W Hassan','Fakulti Pengajian Kontemporari Islam<br>Universiti Sultan Zainal Abidin (UNiSZA)','Kuala Terengganu','Terengganu','MALAYSIA','21300','0199200963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:06:40',0,NULL,3,1,17,0,NULL,'wan_*6'),(7357,655139028001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','wan_*6','baitrahmah@yahoo.com','Wan Saifuldin W Hassan','Fakulti Pengajian Kontemporari Islam<br>Universiti Sultan Zainal Abidin (UNiSZA)','Kuala Terengganu','Terengganu','MALAYSIA','21300','0199200963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:06:43',0,NULL,3,1,2,1,NULL,'wan_*6\r52-58 双阳环   1\rcanon-58mm 反接环   1\r庄'),(7358,654721895001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','varisornd','varisornd@gmail.com','varisorn ditsaranont','54 Soi Taksin 14, Taksin Rd.,<br>Bukkalo','Thonburi','Bangkok','THAILAND','10600','66891105449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 08:14:24',0,NULL,3,1,2,1,NULL,'varisornd\r徐'),(7359,655147064001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','iain8368','iainlamond@dodo.com.au','iain lamond','280 westernport rd','lang lang','Victoria','AUSTRALIA','3984','0359975927','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 08:29:10',0,NULL,3,0,3,1,NULL,'iain8368\rXXXL\r刘\rRA117711020CN\r\\'),(7360,695791154002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','blondiini','virpi.niskanen@bosis.fi','Virpi Niskanen','Reunatie 8','Lempaala','','FINLAND','37550','35833751492','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 09:00:43',0,NULL,3,0,3,1,NULL,'blondiini\r摄影背心 canon 老款 xxl   1\r摄影背心 夏季  xl    1\r庄\rRA117713547CN\r\\'),(7361,695787250002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','blondiini','virpi.niskanen@bosis.fi','Virpi Niskanen','Reunatie 8','Lempaala','','FINLAND','37550','35833751492','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 09:00:44',0,NULL,3,0,17,0,NULL,'blondiini'),(7362,763881975015,250627432317,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','tony12340','tonykaye2004@orangehome.co.uk','Colin Grellis','96 Crock Lane','Bridport','Dorset','UNITED KINGDOM','DT64DQ','01308427882','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 09:31:57',0,NULL,3,1,2,1,NULL,'tony12340\r庄'),(7363,695879947002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bb6800','bab1985@aussiebroadband.com.au','B Blake','5/30 Gordon Street','Traralgon','Victoria','AUSTRALIA','3844','0351745713','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 12:22:29',0,NULL,3,1,3,1,NULL,'bb6800\rRA117711798CN\r\\'),(7364,655235420001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','jorisfriat','friat.joris@gmail.com','joris friat','rue de la Jaqua 122','Attalens','Fribourg','SWITZERLAND','1616','0793598983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 12:37:31',0,NULL,3,1,2,1,NULL,'jorisfriat\r王'),(7365,748626226016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','andyl.33','andy@rc31.co.uk','Andy Long','33 Chestnut Close<br>Kings Hill','West Malling','Kent','UNITED KINGDOM','ME19 4FP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 14:30:04',0,NULL,3,1,2,1,NULL,'andyl.33\r庄'),(7366,695974336002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',87.8,'hermeshine','toyz_joe','jaffyjaf99@hotmail.com','Joe Fleury','356, av. Fiset','Donnacona','QC','CANADA','G3M 2P5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 15:50:02',0,NULL,3,1,17,0,NULL,'toyz_joe'),(7367,695974067002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','toyz_joe','jaffyjaf99@hotmail.com','Joe Fleury','356, av. Fiset','Donnacona','QC','CANADA','G3M 2P5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-03 15:50:04',0,NULL,3,1,5,1,NULL,'toyz_joe\r2m 灯架   2\r云台   2\r柔光伞   2\r301p 1托二    1\r庄\rCP226344587CN'),(7368,696026788002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','kleiberfragoso','kfvideo@gmail.com','Kleiber Sequeira','Rua República do Peru, 193/ 41<br>Copacabana','Rio de Janeiro','Rio de Janeiro','BRAZIL','22021040','55-21- 254858598','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 17:01:42',0,NULL,3,1,5,1,NULL,'kleiberfragoso\r王\r改发1.55m高的，再加一个717的快装板给他\rCP226344595CN'),(7369,696105527002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 18:23:22',0,NULL,3,1,17,0,NULL,'robert5525\r'),(7370,696132630002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','subotai-2009','mcarb2008@gmail.com','Miguel Carmena Bermudez','C/ Santa María de Gracia, 34 - esc. A - 1º izq.','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14002','619613683','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 18:51:46',0,NULL,3,1,4,1,NULL,'subotai-2009\rtripod  $16\r王\rYW864488782CN'),(7371,655504605001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','neronmusico','jmdele@hotmail.com','JOSE MARIANO GIL DELEGIDO','C/ CAMI VELL DE L\'ESTACIO<br>Nº6 3er P.9','ONTINYENT','Comunidad Valenciana','SPAIN','46870','678422245','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 19:22:28',0,NULL,3,1,3,1,NULL,'neronmusico\r王\rRA117711016CN\r\\'),(7372,764333095015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.58,'hutongstore','archivlad','spirov.vladimir@gmail.com','Vladimir Spirov','6 Cleveland Road','Ealing','London','UNITED KINGDOM','W13 8AU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 19:42:28',0,NULL,3,1,2,1,NULL,'archivlad\r王'),(7373,655542722001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','mikeis1212','mikesbenjamin@gmail.com','Michael Benjamin','151 South Bernardo Ave<br>Apt 14','Sunnyvale','CA','UNITED STATES','94086-5657','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 20:11:42',0,NULL,3,1,1,1,NULL,'mikeis1212\r徐'),(7374,696203336002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','juro168','juraj168@gmail.com','Juraj Belica','Jeskova ves 168<br>958 45 Velky Kliz','okres Partizanske','','SLOVAK REPUBLIC','958 45','+421 944 115 812','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-03 20:13:58',0,NULL,3,1,3,1,NULL,'juro168\rRA117711682CN\r\\'),(7375,764391834015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 20:49:08',0,NULL,3,1,17,0,NULL,'electronicparts321'),(7376,764030984015,250599405329,'Green.L 58mm 58 Neutral Density ND4 Filter ND 4 New',1,'AE2303',4.1,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 20:49:08',0,NULL,3,1,2,1,NULL,'electronicparts321\r热靴保护盖  普通   1\r绿叶 ND4  58mm   1\r庄'),(7377,749006607016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 21:40:22',0,NULL,3,1,2,1,NULL,'ogg78\r他买了2只lenspen 但不合并，分开发\r徐'),(7378,749008710016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-03 21:43:25',0,NULL,3,1,2,1,NULL,'ogg78\r他买了2只lenspen 但不合并，分开发\r庄'),(7379,749013699016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','rynektbg','compac@wp.pl','Damian Rys','2 Napier Road<br>54 Merlin House','London','London','UNITED KINGDOM','EN3 4QJ','02082110616','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-03 21:53:02',0,NULL,3,1,2,1,NULL,'rynektbg\r徐'),(7380,696273802002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-03 22:33:11',0,NULL,3,1,17,0,NULL,'robert5525'),(7381,696309802002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 00:17:36',0,NULL,3,1,3,1,NULL,'arnorolf10\r王\rRA117711988CN\r\\'),(7382,655649135001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','cockney52','wcpooh26@hotmail.com','bill chandler','po box 359','harrah','OK','UNITED STATES','73045-0359','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 00:26:58',0,NULL,3,1,1,1,NULL,'cockney52\r徐'),(7383,696317799002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',5,'AE3102',39.45,'hermeshine','kluzz','kluzz@radical.org','Jan Fredrik Leversund','Alvsvåg 115','BREMNES','','NORWAY','5430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 00:37:52',0,NULL,3,1,3,1,NULL,'kluzz\r注意是5个\r刘\rRA117711991CN\r\\'),(7384,764537717015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','rallynitros','rally27@poczta.fm','Lukas Rabczynski','106 ard alainn<br>Merlin Park','Galway','Galway','IRELAND','1','091471071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 02:03:54',0,NULL,3,1,3,1,NULL,'rallynitros\rRA117711912CN\r\\'),(7385,655697214001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5,'hermeshine','taraztiger','barryquiet@yahoo.com','Barry Ackerson','12818 Sunnymeadows Dr','Moreno Valley','CA','UNITED STATES','92553-5961','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 02:50:30',0,NULL,3,1,1,1,NULL,'taraztiger\r徐'),(7386,653427387001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','yenna709','jenna@okito.net','Jenna Jolley','4388 El Camino Real #378','Los Altos','CA','UNITED STATES','94086','(650) 391-4094','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 03:17:28',0,NULL,3,1,1,1,NULL,'yenna709\r徐'),(7387,655713421001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','puntella','juanpuntella@yahoo.com.ar','Juan Sebastián Puntella','Cnel Lynch 1765','Villa Luzuriaga','Buenos Aires','ARGENTINA','B1753BUW','54-11 4461-2907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 04:02:50',0,NULL,3,1,2,1,NULL,'puntella\r庄'),(7388,655728868001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','grif_5','grif_5@yahoo.com','Benjamin C Griffith','209 N Hayes St','Bellefontaine','OH','UNITED STATES','43311-2405','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 05:38:57',0,NULL,3,1,1,1,NULL,'grif_5\r徐'),(7389,696403933002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','iceparrot','signups@iceparrot.com','Josh and Erika Thornes','15579 Walton Heath Row','San Diego','CA','UNITED STATES','92128-4477','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 05:44:25',0,NULL,3,1,1,1,NULL,'iceparrot\r徐'),(7390,696419241002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','blackdesirepg','blackdesire@live.cn','Qi Gu','Unit 32/57-63 Belmore Rd','Randwick','New South Wales','AUSTRALIA','2031','0421960787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 07:10:05',0,NULL,3,1,2,1,NULL,'blackdesirepg\r徐'),(7391,655760827001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:23:25',0,NULL,3,1,17,0,NULL,'moklanarpa'),(7392,696433172002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','moklanarpa','moklanarpa@yahoo.es','Miguel Ángel Moclán Arpa','Avenida Carlos I, 9, 9º A','San Sebastián','Guipuzcoa','SPAIN','20011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 08:23:26',0,NULL,3,1,4,1,NULL,'moklanarpa\r2m 灯架  1\rb座   1\r柔光伞   1\r80cm 5in1 反光板   1\r一票两件  lighting kit  $20\rYW864488771CN'),(7393,655761243001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jirasak2007_123','jirasak_pollamai@yahoo.com','Mr.Kasipat Phonlamai','138 samorai mokamontree Rd.','Muang Nakornratchsima','Nakornratchsima','THAILAND','30000','0858566099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 08:26:09',0,NULL,3,1,3,1,NULL,'jirasak2007_123\r小号灰卡   1\r45w灯泡   2\r庄\rRA117711974CN\r\\'),(7394,655767137001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','algete2','viciao_ps2@yahoo.es','mayte collado rodriguez','c/ rio tajo nº2 2º pta 4','san sebastian de los reyes','madrid','SPAIN','28701','916510138','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 08:54:35',0,NULL,3,1,4,1,NULL,'algete2\rtripod  $16\rYW864488760CN\r'),(7395,764647132015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','2006lapin','misteraliyah@hotmail.fr','GANGAT Salim Ahmed','65, rue des Poissonniers<br>Interphone: 201, Bat: A, 1er étage, Gauche','Paris','Ile-de-France','FRANCE','75018','06.26.77.03.29','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 08:58:58',0,NULL,3,1,2,1,NULL,'2006lapin\r庄'),(7396,696451946002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','hirviana','ssanchezdelgado@gmail.com','Silvia SÁNCHEZ DELGADO','Plaza Virgen del Rosario Nº3','Huelva','Andalucía Ceuta y Melilla','SPAIN','21007','636958575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 09:36:44',0,NULL,3,1,2,1,NULL,'hirviana\r徐\r\\'),(7397,749256917016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',54.6,'hutongstore','sebasgini','sginardnicolau@gmail.com','sebastia ginard nicolau','ses parres nº63 2d','manacor','Baleares','SPAIN','07500','654789875','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-04 10:45:02',0,NULL,3,1,4,1,NULL,'sebasgini\rbackground support  $25\r王\rYW864488756CN'),(7398,655863571001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','merkur_71','gerhard.bruckner1@chello.at','Gerhard Bruckner','Etrichstr. 19/3/5','Wien','','AUSTRIA','1110','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 14:31:29',0,NULL,3,1,3,1,NULL,'merkur_71\r刘\rRA117711665CN\r\\'),(7399,655866475001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','mariochristou1','mariochristou@bigpond.com','mario christou','64 monash rd','newborough','Victoria','AUSTRALIA','3825','04383291910438329191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 14:40:34',0,NULL,3,1,3,1,NULL,'mariochristou1\r徐\rRA117712008CN\r\\'),(7400,696558717002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','candee19','flysxygsxr@yahoo.com','Crystal Skolnik','131 N Parkside Dr','Bardstown','KY','UNITED STATES','40004-9443','(352) 217-7577','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 15:28:29',0,NULL,3,1,1,1,NULL,'candee19\r徐'),(7401,696520668002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','oneownercar','oneownercar@clara.co.uk','Roy Lawrence','10 Turnberry Drive,Bricket Wood','St.Albans','Hertfordshire','UNITED KINGDOM','AL23UF','01923671573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 15:38:34',0,NULL,3,1,3,1,NULL,'oneownercar\rRA117711855CN\r\\'),(7402,696562072002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','leondcx','allan_hudson@hotmail.com','Allan Hudson','Av. General Rondon, 3542<br>Vila Leopodina','Duque de Caxias','Rio de Janeiro','BRAZIL','25050-230','552126528640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 15:41:01',0,NULL,3,1,3,1,NULL,'leondcx\r\\\rRA117711926CN\r'),(7403,655895092001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','robin372','tramptnv@mail.ru','Andrey Bannov','11-4-34','Zarafshan','','UZBEKISTAN','210300','+998795729372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 16:03:47',0,NULL,3,1,2,1,NULL,'robin372\r庄'),(7404,695102243002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',107.28,'hermeshine','countrydreams','dianne.humble@yahoo.com','Dianne G. Humble','8135 Rustin Rd','Middleton','ID','UNITED STATES','83644-5330','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 16:09:24',0,NULL,3,1,4,1,NULL,'countrydreams\r2m 灯架  1\rB座   1\r柔光伞   1\r斜臂   1\rlenspen   1\rNikon 老款 黑色 背心  xl   1\r庄\rYW864488745CN\r'),(7405,696577309002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','art_buyer_123','transaction@fsmail.net','H N E Bayley','9 Holly Terrace','York','North Yorkshire','UNITED KINGDOM','YO10 4DS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 16:14:55',0,NULL,3,1,2,1,NULL,'art_buyer_123\r徐'),(7406,696665685002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','bepestar','becseypeter@freemail.hu','peter becsey','28. Petnehazy Str. 7f/7d','budapest','budapest','HUNGARY','1139','+36308202663','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-04 19:07:31',0,NULL,3,0,3,1,NULL,'bepestar\rXL\r王\rRA117711722CN\r\\'),(7407,764945774015,250601901408,'Wireless Remote Control Cord for Canon 500D/1000D/450D',1,'AA3210',11.47,'hutongstore','geavir','kr@elvis.dk','Kristian Rosengren','Monradsvej 16a','Viby j','','DENMARK','8260','26237779','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-04 19:30:40',0,NULL,3,1,2,1,' ','geavir\r庄'),(7408,656006506001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 19:35:33',0,NULL,3,1,2,1,NULL,'junglistic_maxim\r徐'),(7409,656029727001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','vaizdostudija','uab@vaizdostudija.com','Arunas Eimulis','Tulpiu 13-3','Klaipeda','','LITHUANIA','91210','+370 673 92399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 20:17:30',0,NULL,3,1,2,1,NULL,'vaizdostudija\r'),(7410,653990414018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','andresurma','asurma@yahoo.com','Andre Surma','5814 E Pinyon Pine Dr','Orange','CA','UNITED STATES','92869-6006','(714) 633-4783','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-04 20:32:19',0,NULL,3,1,4,1,NULL,'andresurma\r灯泡是110v\r刘\rYW864488734CN'),(7411,765003804015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','terciopellojosh','dzordz@poczta.onet.pl','Josh Rostkowski','5 Windsor Close','Leyland','Lancashire','UNITED KINGDOM','PR25 1JU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-04 20:58:01',0,NULL,3,1,2,1,NULL,'terciopellojosh\r刘'),(7412,656049339001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','poovey33','x_sveta_x@hotmail.com','Sveta Poovey','1 Easy St','Winfield','KS','UNITED STATES','67156','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-04 20:58:37',0,NULL,3,0,1,1,NULL,'poovey33\r1.6X2.1 背景布  黑色   1\r徐'),(7413,656063070001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','femto_e','femtoe@earthlink.net','Lei Zhang','111 Parker St.','Acton','MA','UNITED STATES','01720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-04 21:32:31',0,NULL,3,1,1,1,NULL,'femto_e\r徐'),(7414,655405241001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','perova','furtuke@bk.ru','Natalia Furtuke','st. Smorodina house 12, apartment 17','Lipetsk','Russian Federation','RUSSIAN FEDERATION','398046','+79202448833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-04 22:06:34',0,NULL,3,1,2,1,NULL,'perova\r庄\r\\'),(7415,656119277001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 00:50:39',0,NULL,3,1,17,0,NULL,'caduviterbo'),(7416,696800803002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','caduviterbo','caduprado@gmail.com','Carlos Eduardo Viterbo Prado','Rua Soares Couto 201/03','Belo Horizonte','Minas Gerais','BRAZIL','30380760','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 00:50:42',0,NULL,3,1,3,1,NULL,'caduviterbo\r圆形柔光棚 60cm   1\r爵影碗罩P1    1\r刘\rRA117711740CN\r\\'),(7417,696811020002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 01:22:01',0,NULL,3,1,4,1,'YW864488653CN ','ryrvikryrvik\rlighting kit  $25\r庄\r'),(7418,696810914002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','fookdeck','fookdeck@pacbell.net','Douglas Lee','870 Regulus St','Foster City','CA','UNITED STATES','94404','(650) 522-8942','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 01:22:26',0,NULL,3,1,1,1,NULL,'fookdeck\r徐'),(7419,696846729002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','jirasak2007_123','jirasak_pollamai@yahoo.com','Mr.Kasipat Phonlamai','138 samorai mokamontree Rd.','Muang Nakornratchsima','Nakornratchsima','THAILAND','30000','0858566099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 03:37:49',0,NULL,3,1,17,0,NULL,'jirasak2007_123'),(7420,653850237001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','srfrancisco69','srfrancisco69@yahoo.com.au','simon Francis','3<br>Findon Avenue','Caufield North','Victoria','AUSTRALIA','3161','0418178884','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 04:19:24',0,NULL,3,1,4,1,NULL,'srfrancisco69\r澳标头 \rlighting kit  $30  \r刘\rYW864488664CN'),(7421,696875635002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','sadak3d','sadak@hqcreative.ae','sadak kalathil','hqcreative, 103,liberty building, garhoodh, dubai,uae','garhodh','dubai','UNITED ARAB EMIRATES','61886','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 06:25:35',0,NULL,3,1,3,1,NULL,'sadak3d\rRA117711838CN\r\\'),(7422,656195326001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','kirill602','kir602@mail.ru','kiriLL Grebenev','st.Unih Lenincev 79 building 6 , apartment 48','Moscow','','RUSSIAN FEDERATION','109443','+79261493021','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 06:55:43',0,NULL,3,1,3,1,NULL,'kirill602\rRA117711824CN\r\\'),(7423,656207089001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','flank3r','flanker@rt.sk','Ondrej Morháč','M. R. Štefánika 14','Zvolen','','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 07:55:55',0,NULL,3,1,2,1,NULL,'flank3r\r徐'),(7424,749765539016,260661403446,'TianYa 77mm CPL filter New 77 Circular Polarizing C-PL',1,'AA2307',5.3,'hutongstore','symonmark07','mark-brookman@live.com','Mr S M Brookman','20 York road','Littlehampton','West Sussex','UNITED KINGDOM','BN17 6EN','01903715584','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 07:58:39',0,NULL,5,0,18,0,NULL,'symonmark07\r'),(7425,656208109001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','digitium','digitium@gmail.com','Darrell Lye','38 Loyang View','default','','SINGAPORE','507232','+6590669612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 08:55:10',0,NULL,3,1,11,1,NULL,'digitium\r徐\r\\'),(7426,749789403016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','astralgr','astralgr@mycosmos.gr','Mparmperoglou Marios','Papanastasiou 66','Heraklion','Crete','GREECE','71306','00306977461733','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-05 09:38:23',0,NULL,3,1,4,1,NULL,'astralgr\rlighting kit  $30\r欧标\r庄\rYW864488675CN'),(7427,656234125001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','adamoscz','red.dog@email.cz','Adam Strojsa','Pruchova 3169','Kladno','','CZECH REPUBLIC','27201','+420721102097','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:07:46',0,NULL,3,1,5,1,'CP227125305CN ','adamoscz\r刘\rCP226344600CN  捷克去了智利?\r----\r第一次发货错发到智利\r'),(7428,696921701002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','hell122010','hell12@mail.ru','Aleksander Golovin','Gurteva, 5, 13','Orel','','RUSSIAN FEDERATION','302028','+7(903)8810081','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:16:39',0,NULL,3,1,5,1,NULL,'hell122010\r三脚架 伟峰 EI-717  135   1\r肩架   1\r庄\rCP226344613CN'),(7429,696930037002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','le_juki','jukkatallinen@gmail.com','Jukka Tallinen','Toppilansaarentie 3 B 19','Oulu','-','FINLAND','90510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:49:39',0,NULL,3,1,3,1,NULL,'le_juki\r庄\rRA117711736CN\r\\'),(7430,656244507001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','hell122010','hell12@mail.ru','Aleksander Golovin','Gurteva, 5, 13','Orel','','RUSSIAN FEDERATION','302028','+7(903)8810081','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 10:51:30',0,NULL,3,1,17,0,NULL,'hell122010'),(7431,656247378001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','fireweed72','yukonbee@gmail.com','Elizabeth Beard','409-130 Jameson Ave','Toronto','ON','CANADA','M6K 2Y2','(416) 912-9691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 11:02:52',0,NULL,3,1,3,1,NULL,'fireweed72\rRA117711886CN\r\\'),(7432,656254683001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','valnabi','valentinas.nabijevas@gmail.com','Valentinas Nabijevas','Zemaiciu g 88-3','Kaunas','','LITHUANIA','44182','37061420015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 11:34:03',0,NULL,3,1,2,1,NULL,'valnabi\r刘'),(7433,696943851002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dant_riga','dant.riga@gmail.com','dmitry antipov','Anninmuizas bulvars 64-42','Riga','','LATVIA','LV-1029','+371 29129028','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 12:04:14',0,NULL,3,1,3,1,NULL,'dant_riga\r申报： reflector  $10\r王\rRA117711529CN\r\\'),(7434,765297321015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3203',2.98,'hutongstore','amanda.2969','amanda.laughton@hotmail.co.uk','amanda laughton','6 ST GILES HOUSE<br>RHOSNESNI LANE','WREXHAM','Wrexham','UNITED KINGDOM','LL12 7NJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 13:04:07',0,NULL,3,1,2,1,NULL,'amanda.2969\r庄'),(7435,696969456002,120461614281,'JJC Hand Strap Grip  HS-1 Nikon D40 D60 Canon 450D',1,'AB1408',6.99,'hermeshine','editor9','abc9@hot.ee','altor-san OÜ','Jaama 29','Võru','','ESTONIA','65604','37253451682','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:22:42',0,NULL,5,1,18,0,NULL,'editor9\r刘'),(7436,696971949002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','barbosha_max','barbosha@rambler.ru','Maxim Chuprina','Korchagina str., 4','Nezhin','Chernigov','UKRAINE','16600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:23:27',0,NULL,3,1,2,1,NULL,'barbosha_max\r庄'),(7437,656286263001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','igbkmrf','08vev00@gmail.com','Alexandr Kapaev','Trudovaya St., 66, apt.169.','Irkutsk','Irkutskaya Oblast','RUSSIAN FEDERATION','664047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:30:12',0,NULL,3,1,2,1,NULL,'igbkmrf\r徐'),(7438,696576877002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',10.47,'hermeshine','boonheng84','hin_wsc@hotmail.com','Mak Boon Heng','KAMPONG SUNGAI LIANG, TUNGGU LIAN<br>SIMPANG 1307, NO32','Kuala Belait','','BRUNEI DARUSSALAM','KC2735','6738607072','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 13:48:19',0,NULL,3,1,3,1,NULL,'boonheng84\r刘\rRA117711617CN\r\\'),(7439,697013543002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','cyclophonie','reader422002@yahoo.fr','jean-pierre benaroya','101 bd voltaire','asnieres','Ile-de-France','FRANCE','92600','0147930912','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:30:45',0,NULL,3,1,2,1,NULL,'cyclophonie\r庄'),(7440,697023140002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yazhun','a.somos@gmail.com','András Somos','33 Tarkö Street','Budapest','','HUNGARY','1182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 15:55:08',0,NULL,3,1,2,1,NULL,'yazhun\r徐'),(7441,0,110667386036,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.01,'hermeshine','jkjdawg1','kerney_inc@hotmail.com','Michelle Kerney','310 7th Ave W','Kalispell','MT','UNITED STATES','59901-4762','(406) 212-5734','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-01 09:30:41',0,NULL,7,0,18,0,NULL,'jkjdawg1'),(7442,697040467002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sevamobile','komkovv@gmail.com','Valeriy Komkov','Novogireevskaya Str. 14, korpus 2, kv.8. Domofon 88.','Moscow','','RUSSIAN FEDERATION','111401','+7(926)250-0200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:43:31',0,NULL,3,1,17,0,NULL,'sevamobile'),(7443,697042411002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sevamobile','komkovv@gmail.com','Valeriy Komkov','Novogireevskaya Str. 14, korpus 2, kv.8. Domofon 88.','Moscow','','RUSSIAN FEDERATION','111401','+7(926)250-0200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:44:21',0,NULL,3,1,5,1,NULL,'sevamobile\r2m 灯架   2\rb座     2\r柔光伞   2\r王\rCP226344627CN\r'),(7444,656358356001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','carlos1980e','carlos.mail@terra.es','Carlos Escanlar','C/ Ternera, 6 1ºC','Madrid','Madrid','SPAIN','28013','678303671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 16:56:31',0,NULL,3,1,2,1,NULL,'carlos1980e\r庄'),(7445,697072048002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','alozoven','lozovenko.anatoliy@gmail.com','Anatoliy Lozovenko','13-y Voennyy Gorodok d.15 kv.16','Almaty','Almaty oblast','KAZAKHSTAN','050030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 17:51:37',0,NULL,3,1,3,1,NULL,'alozoven\r王\rRA117711841CN\r\\'),(7446,697083456002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3306',19.95,'hermeshine','elpeladoedu','enocetti@adinet.com.uy','EDUARDO NOCETTI','AVDA  RONDEAU  1470','MONTEVIDEO','','URUGUAY','11100','59829029106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 18:13:12',0,NULL,3,1,3,1,NULL,'elpeladoedu\r庄\rRA117711784CN\r\\'),(7447,656411871001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','johannesnicolaspalm','johannespalm77@gmail.com','Johannes Palm','Hornsgatan 6g','Höganäs','','SWEDEN','26339','0733858633','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 18:48:36',0,NULL,3,1,3,1,NULL,'johannesnicolaspalm\r刘\rRA117711957CN\r\\'),(7448,765494507015,250692240862,'Wireless Remote Shutter Release for Nikon D200/D300​/D3',1,'AA3207',11.47,'hutongstore','alanslotus','alan.paterson5@ntlworld.com','Alan   Paterson','13 Littlefield Close, Ash','Aldershot','Hampshire','UNITED KINGDOM','GU12 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-05 19:30:40',0,NULL,3,1,3,1,NULL,'alanslotus\r徐\r第一次发错了，重发 爵影无线 N1  1 庄\rRA117728572CN'),(7449,765521349015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','baifa69','deniz_sergio@yahoo.es','Sergio Déniz Rivero','C/ Sancho Panza, 2, 3ºD','Las Palmas De Gran Canaria','Canarias','SPAIN','35009','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-05 20:13:48',0,NULL,3,1,3,1,NULL,'baifa69\r徐\rRA117711807CN\r\\'),(7450,697165203002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','iz5165','ilanziv@bezeqint.net','49223ilan ziv','14 Moshe Sneh St.','Petach Tikva','','ISRAEL','49223','0545337325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 20:51:30',0,NULL,3,1,3,1,NULL,'iz5165\rRA117711909CN\r\\'),(7451,656478373001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','thank.you.come.again','akifergin@live.com','ANH TRAN','3200 Race St<br>Rm E513C','PHILADELPHIA','PA','UNITED STATES','19104-2753','(215) 866-6067','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-05 21:03:17',0,NULL,3,1,1,1,NULL,'thank.you.come.again\r徐'),(7452,656218202001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',178,'hermeshine','biller6969','vasilispliatsikas@hotmail.com','VASILEIOS PLIATSIKAS','TRION IERARXON 6 & ASKLIPIOU<br>HRISOPIGI NEROKOUROU','CHANIA','CHANION','GREECE','73100','00302821302106','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 22:02:19',0,NULL,3,1,4,1,' ','biller6969\r王\rYW864488686CN\r'),(7453,656508104001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-05 22:59:31',0,NULL,3,1,3,1,NULL,'salmon404\r庄\rRA117711775CN\r\\'),(7454,697215539002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:20:51',0,NULL,3,1,17,0,NULL,'jlbs2009'),(7455,656523688001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-05 23:24:53',0,NULL,3,1,2,1,NULL,'jlbs2009\r单灯头 欧标   1\r小号内胆包  canon   1\r徐'),(7456,697257938002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','abraaojr','abraao.junior@yahoo.com.br','Abraão Gomes Soares Jr','R. Conselheiro Lafaiete, 1977<br>apto: 1202, Sagrada Família','Belo Horizonte','Minas Gerais','BRAZIL','31035-560','+55 31 3327-8275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 01:52:37',0,NULL,3,1,2,1,NULL,'abraaojr\r徐'),(7457,697261838002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','robert5525','bobgrein@gmail.com','Bob Greiner','1629 Phillips Ave','Las vegas','NV','UNITED STATES','89104-3545','(702) 732-6932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 02:03:57',0,NULL,3,1,1,1,NULL,'robert5525\r中号内胆包 nikon  1\rNIKON 镜头盖 67mm   1\r麂皮    1\r绿叶 CPL  67mm   1\r3片装的滤镜袋   1\r橡胶遮光罩 67mm  1'),(7458,697268474002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',145.6,'hermeshine','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','(923)289-2744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 02:29:38',0,NULL,3,1,5,1,NULL,'zenitar16\r王\rCP226344635CN'),(7459,656585290001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','billybob2th','billybob2th@msn.com','diego correal','498 dexter st','central falls','RI','UNITED STATES','02863-2646','(401) 855-3800','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 03:41:26',0,NULL,3,0,1,1,NULL,'billyb\r庄'),(7460,697271728002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','mlkt2308','mariathompson23@gmail.com','Maria Thompson','17 Ormiston Gardens, Clarkson','Perth','Western Australia','AUSTRALIA','6030','0893044609','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-06 03:52:27',0,NULL,3,0,3,1,NULL,'mlkt2308\r1.6mx2.1m 白  黑  \r庄'),(7461,765700934015,250601900955,'Wireless Remote Control Cord for Canon 50D/40D/30D/20D',1,'AA3210',11.47,'hutongstore','koubikm','jakubmachu@seznam.cz','Jakub Machu','Ceská 4758','Zlín','Czech Republic','CZECH REPUBLIC','76005','00420 777 863 995','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 04:57:01',0,NULL,5,0,18,0,NULL,'koubikm\r庄\r爵影无线 C3   1'),(7462,656599054001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','genodis','dr.steen@gmail.com','Marius H Steen','Nubbebakken 7B','Bergen','-','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 04:59:29',0,NULL,3,1,2,1,NULL,'genodis\r庄'),(7463,0,120700925692,'Genuine Lenspen lens cleaning CANON NIKON ship to USA',1,'AA1310',0.55,'hermeshine','yaroslav_lviv','yaroslavyatskiv@yahoo.com','Yaroslav Yatskiv','6016 Sunrise Vista Dr<br>Apt C Apt 6','Citrus Heights','CA','UNITED STATES','95610-7060','(916) 420-7678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 05:17:44',0,NULL,3,1,1,1,NULL,'yaroslav_lviv\r庄\rYaroslav Yatskiv\r2633\rCalifornia Ave\rCarmichael CA 95608\rUnited States\r\r'),(7464,697303141002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',2,'AC2303',12.42,'hermeshine','funku28','mustafasakizci@ttnet.net.tr','MUSTAFA SAKIZCI','KORESEHITLERI CD. KAYA ALDOGAN SOK. NO :16 ZINCIRLIKUYU','ISTANBUL','TURKEY','TURKEY','34394','00905318650028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 05:19:11',0,NULL,3,1,2,1,NULL,'funku28\r庄'),(7465,765739016015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','tgon4895','tom.villa@gmail.com','Tomas Gonzalez Villa','Department of Microbiology. Faculty of Pharmacy<br>University of Santiago de Compostela','Santiago de Compostela','Galicia','SPAIN','15706','647344039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 07:49:02',0,NULL,3,1,3,1,NULL,'tgon4895\rRA117711170CN'),(7466,696479816002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',5,'AA2217',44.95,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 07:58:01',0,NULL,3,1,3,1,NULL,'pinchukov\rRA117711254CN'),(7467,750286903016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','zoki03','cvijanovic.zoran@gmail.com','Zoran Cvijanovic','Cankarjeva ulica 26','Nova Gorica','','SLOVENIA','5000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 09:05:12',0,NULL,3,1,2,1,NULL,'zoki03\r刘'),(7468,765770928015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','manninej1979','manninej@gmail.com','Jarno Manninen','Arkkitehdinkatu 38 A 12','Tampere','Pirkanmaa','FINLAND','33720','+358447552901','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 09:45:51',0,NULL,3,1,4,1,NULL,'manninej1979\r刘\r欧标  \rlighting kit  $28\r4.3\rYW864488815CN'),(7469,696914007002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','scat_ap','scat-ap@yandex.ru','Артем Павлов','Алма-Атинская улица, дом 5, кв. 180','москва','','RUSSIAN FEDERATION','115408','+7(916)3138301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:08:51',0,NULL,3,1,3,1,NULL,'scat_ap\r王\rRA117711095CN\r\\'),(7470,697364737002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','339514884','kamikazi@inbox.ru','Andrey Pirinov','yl. Nekrasova d.11','Voronezh','Voronezh','RUSSIAN FEDERATION','394071','8 4732 774840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 10:30:23',0,NULL,3,1,3,1,NULL,'339514884\r庄\rRA117713476CN\r\\'),(7471,697366364002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','juha191','jupak@elisanet.fi','Juha Pakanen','Koivuahonkuja 7','Oulu','Finland','FINLAND','90630','+35850467013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:37:31',0,NULL,3,1,2,1,NULL,'juha191\r刘'),(7472,656667601001,110414378578,'New ND2 Filter for Cokin P Series Neutral Density ND 2',1,'AA2323',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:49:04',0,NULL,3,1,17,0,NULL,'phylax57\r'),(7473,697368342002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:49:03',0,NULL,3,1,17,0,NULL,'phylax57\r'),(7474,697368224002,120448646606,'New ND4 Filter for Cokin P Series Neutral Density ND 4',1,'AA2324',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 10:51:59',0,NULL,3,1,17,0,NULL,'phylax57'),(7475,656667484001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 11:11:50',0,NULL,3,1,3,1,NULL,'phylax57\r77mm 接口环  1\r托架   1\rND2   1\rND4   1\r渐变灰   1\rRA117711104CN'),(7476,656675686001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','raitis-v','rvalainis@gmail.com','Raitis Valainis','Krisjana Barona 125-75','Riga','Latvia','LATVIA','LV-1012','+37122006160','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 11:20:11',0,NULL,3,1,3,1,NULL,'raitis-v\r徐\rRA117713604CN\r\\'),(7477,750336062016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','kati_mbj','woref_cts@hotmail.com','Catalina Maria Bibiloni joan','c/menorca nº12','Alcudia','Baleares','SPAIN','07400','697194978','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 11:58:01',0,NULL,3,0,4,1,NULL,'kati_mbj\r庄\r套装中的布是黑色的， 欧标\r80cm 2in1   反光板   1\r58mm 橡胶罩      1\r52mm 橡胶罩      1\r天涯 58mm cpl     1\r9.68\r申报： lighting kit  \r$40\rYW864488826CN'),(7478,697422128002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','inxlee','inxlee@hotmail.com','Christopher Euw','Block 371 Hougang Street 31 #02-35<br>Singapore 530371','Singapore','Singapore','SINGAPORE','530371','62823227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:04:03',0,NULL,3,1,11,1,NULL,'inxlee\r刘\r\\'),(7479,697424058002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 14:10:35',0,NULL,3,1,5,1,NULL,'zonagrib\r王\rCP226344542CN\r'),(7480,656725395001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','norestani','mk@nurestan.com','mushtaba norestani','Birkhøjterrasserne 424 E','Farum','sealand','DENMARK','3520','004522956401','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 14:13:01',0,NULL,3,0,4,1,NULL,'norestani\r刘\r欧标\r申报lighting kit  $40\r9.13\rYW864489165CN'),(7481,750284532016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',28,'hutongstore','luci.moldovan','nicolas122@hotmail.com','Moldovan Nicolae Lucian','Primaverii nr.2','Tirgu Mures','Jud Mures','ROMANIA','540174','+40744237490','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-06 15:14:25',0,NULL,3,0,3,1,NULL,'luci.moldovan\r1.6x4m 背景布  2\r绿色   黑色\rRA117713578CN\r\\'),(7482,0,120705977458,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',0.99,'hermeshine','sabbath999','metropolis1928@mac.com','Ken Mitchell','108 N 5th','Edina','MO','UNITED STATES','63537','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-06 15:42:50',0,NULL,3,1,1,1,NULL,'sabbath999\r王'),(7483,0,110669242210,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','chulincylycos','rhkpf@live.com','Bryan Chu','3870 Maybelle Ave','Oakland','CA','UNITED STATES','94619-2116','(510) 213-3682','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 15:57:33',0,NULL,3,1,1,1,NULL,'chulincylycos\r庄'),(7484,656767322001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','anispamami','isabeljd@hotmail.com','ANGEL BELLO LEON','C/ COCHERAS 4, PORTAL C, 2º -PTA. 3','MADRID','Madrid','SPAIN','28007','915017627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 16:20:41',0,NULL,3,1,2,1,NULL,'anispamami\r王'),(7485,0,110669239679,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',0.99,'hermeshine','mamasledge','jimorcathy@suddenlink.net','Cathy McCarty','6205 Edgeware Place','Amarillo','TX','UNITED STATES','79109','(806) 354-8689','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 16:35:00',0,NULL,3,1,1,1,NULL,'mamasledge\r刘'),(7486,0,120705977409,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',0.99,'hermeshine','hms1405','hms1405@gmail.com','hussain mohammad alsailm','3225 old 63 s','columbia','MO','UNITED STATES','65201-5369','(573) 529-6382','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 17:28:42',0,NULL,3,1,1,1,NULL,'hms1405\r庄\r、'),(7487,765961307015,250600525175,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'AA3205',2.98,'hutongstore','arkadiush77','arkadiusz.sobol@interia.eu','Arkadiusz Sobol','19 Marlborough Way','Uttoxeter','Staffordshire','UNITED KINGDOM','ST14 7HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 17:49:35',0,NULL,3,1,2,1,NULL,'arkadiush77\r刘'),(7488,656803621001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Alvaro López Rivera','Avenida manolete 11- 1  2º 3','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 17:51:05',0,NULL,3,1,17,0,NULL,'bluesmansur\r'),(7489,656804865001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Alvaro López Rivera','Avenida manolete 11- 1  2º 3','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 17:53:09',0,NULL,3,1,2,1,NULL,'bluesmansur\r刘\r橡胶遮光罩 52mm   1\r橡胶遮光罩 58mm   1'),(7490,0,120705979181,'55mm 55 mm Macro +4 Close-Up Close Up Filter',1,'AE3216',0.99,'hermeshine','kohelet_son_of_david','kullyev@yandex.ru','Andrey Kullyev','2930 N Pine Grove Ave<br>Apt 403','Chicago','IL','UNITED STATES','60657-5742','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 17:57:53',0,NULL,3,1,1,1,NULL,'kohelet_son_of_david\r庄'),(7491,765975123015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',39.99,'hutongstore','alcintas','alcintas@gmail.com','Antonio Luis Cintas García','Tomás Romero de Castilla nº4 1ºA','Badajoz','Badajoz','SPAIN','06011','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-06 18:13:40',0,NULL,3,1,4,1,NULL,'alcintas\r王\rtripod $16\rYW864489154CN'),(7492,697518092002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','spikingsdj','djspikings@gmail.com','David Spikings','14376 Pinnacle Ct.','Canyon Country','CA','UNITED STATES','91387','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 18:14:28',0,NULL,3,1,1,1,NULL,'spikingsdj\r刘'),(7493,656835802001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','milkyway_2011','m1lkyway_2011@yahoo.com','Franco Pogi Infante','3350 Griffith Park Blvd<br>Apt 37','Los Angeles','CA','UNITED STATES','90027-2268','(323) 440-1029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 18:56:04',0,NULL,3,1,1,1,NULL,'milkyway_2011\r庄'),(7494,656837489001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',46.8,'hermeshine','cdat2003','dtull8@yahoo.com','Denelle Tull','1808 N 34th St','Decatur','IL','UNITED STATES','62526-5620','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 18:59:34',0,NULL,3,1,3,1,NULL,'cdat2003\r王  \r1.1\rRA117712025CN\r、'),(7495,697553459002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','bass20311','bass2031@hotmail.com','Sébastien Corriveau','86 D\'Argenson','Québec','QC','CANADA','g1k1r5','(418) 317-0776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 19:24:54',0,NULL,3,1,3,1,NULL,'bass20311\r刘\r注意是5个\rRA117713555CN'),(7496,656876639001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:21:32',0,NULL,3,1,17,0,NULL,'jlbs2009\r庄'),(7497,697580280002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jlbs2009','telltojlbs@hotmail.com','jose luis bravo','francesc frontera 1 bajos b','palma de mallorca','Baleares','SPAIN','07007','971911822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 20:21:31',0,NULL,3,1,4,1,NULL,'jlbs2009\r刘\r2m 灯架  1\rb座    1\r柔光伞   1\r50-70 棚  欧标   1\rlight stand $25\r2.1\rYW864489143CN'),(7498,656887584001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','jenspettrus','kklemet@yahoo.no','Knut Klemetsen','Tomtegt 25','Skien','Telemark','NORWAY','3714','(+47) 90913991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 20:50:06',0,NULL,3,1,3,1,NULL,'jenspettrus\r庄\r注意是红盒的\rRA117713595CN\r\\'),(7499,656901048001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',3,'AA1213',10.2,'hermeshine','zsmadar','mad-r@freemail.hu','Madar Zsolt','11. Leiningen str.','Debrecen','Hajdú-Bihar megye','HUNGARY','H-4030','+36204390542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:17:45',0,NULL,3,1,17,0,NULL,'zsmadar\r'),(7500,656900279001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',3,'AA1212',10.2,'hermeshine','zsmadar','mad-r@freemail.hu','Madar Zsolt','11. Leiningen str.','Debrecen','Hajdú-Bihar megye','HUNGARY','H-4030','+36204390542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:17:46',0,NULL,3,1,3,1,NULL,'zsmadar\r58-58mm 双阳环   3\r52-58mm 双阳环   3\rRA117713533CN\r\\'),(7501,697607671002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','dulepg','bimmerpg@gmail.com','Dusko Tasic','II crnogorskog bataljona 14/2','Podgorica','Podgorica','MONTENEGRO','382','+38267255637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 21:20:52',0,NULL,3,1,2,1,NULL,'dulepg\r刘\r检查一下，是发的那个黄盒的吧\r这个很少发'),(7502,0,110669239111,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',2.61,'hermeshine','circleheartx','foreverpureart@yahoo.com','rene miramontes','4667 Challen ave','Riverside','CA','UNITED STATES','92503-3034','(951) 823-9293','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 21:48:39',0,NULL,3,1,1,1,NULL,'circleheartx\r庄'),(7503,656913511001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','orba_80','orba1@yandex.ru','DMITRY SHIROKOV','AKADEMIKA KOMAROVA str., 18-A, 53','MOSCOW','','RUSSIAN FEDERATION','127276','+7 916 6702890','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 21:49:21',0,NULL,3,1,3,1,NULL,'orba_80\r刘\r注意是红盒的\rRA117713581CN\r\\'),(7504,656922251001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','kiki6666kiki','kiki6666@gmail.com','Kristijan Katarincek','J.J. Strossmayera 51','Nasice','Osjecko-baranjska','CROATIA','31500','00385989471848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-06 22:17:56',0,NULL,3,1,2,1,NULL,'kiki6666kiki\r庄'),(7505,697621527002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','vimmern','stianvimme@gmail.com','Stian Vimme','Bjerkåsveien 52B','Vollen','Akershus','NORWAY','1391','91644483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 22:22:06',0,NULL,3,1,4,1,NULL,'vimmern\r刘\rlight stand  $20\rYW864489132CN'),(7506,766130133015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','tehwiidhed','i_own_you_all@hotmail.com','Jack Silve','46 Cleveland road','Worthing','West Sussex','UNITED KINGDOM','BN13 2ES','07938157387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-06 23:03:00',0,NULL,3,1,3,1,NULL,'tehwiidhed\r庄\r英标\r0.568\rRA117712039CN\r、\r'),(7507,0,110669242398,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',0.99,'hermeshine','efuji','efuji@comcast.net','Edwin S. Fujinaka','8402 N. Yellowstone Ave','Tucson','AZ','UNITED STATES','85704','(520) 297-1271','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-06 23:21:02',0,NULL,3,1,1,1,NULL,'efuji\r刘'),(7508,654936448018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','voiceoveip','i@ztup.com','AI Trade SARL - Ingmar Putz','Chateau de Bimare<br>1, rue de Bimare','Saint Germain des Essourts','Haute-Normandie','FRANCE','76750','0951381378','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-06 23:23:04',0,NULL,3,1,4,1,NULL,'voiceoveip\r王\r欧标     \r5.63\rlighting kit  $35\rYW864489121CN\r'),(7509,656938890001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','cascaderon','rrivera@cascorp.com','Ron Rivera','2201 NE 201st Ave','Fairview','OR','UNITED STATES','97024-9799','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-06 23:23:57',0,NULL,3,1,1,1,NULL,'cascaderon\r庄'),(7510,656296131001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-06 23:38:38',0,NULL,3,1,5,1,NULL,'elizeucine\r刘\rCP226344560CN'),(7511,0,120705977362,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',1.29,'hermeshine','arrielle78','homeyertx@yahoo.com','Arrielle Homeyer','532 17th st','niagara falls','NY','UNITED STATES','14301-2216','(716) 345-0814','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 00:01:30',0,NULL,3,1,1,1,NULL,'arrielle78\r庄'),(7512,656953831001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','lisu9789','li_su@hotmail.com','Li Su','3209 Twinfalls Drive','Plano','TX','UNITED STATES','75093','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 00:29:38',0,NULL,3,1,1,1,NULL,'lisu9789\r庄'),(7513,656954906001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.98,'hermeshine','geco1968','videos@gecoproducciones.cl','Gerardo Campos Pelayo','San Eugenio #1085 depto. 11-A','santiago','santiago','CHILE','7750000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 00:32:01',0,NULL,3,1,5,1,NULL,'geco1968\r庄\rCP226344556CN\r'),(7514,656961786001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','divertimento_88','musique88@hotmail.com','Alison Shipley','9-179 MacNab Street South','Hamilton','ON','CANADA','L8P 3C7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 01:01:10',0,NULL,3,1,2,1,NULL,'divertimen\r庄'),(7515,654257971001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','salqa','newvisionmedia@snet.net','Jose Martinez','40 Timothy Ter<br>New Vision Media, Llc','Windsor','CT','UNITED STATES','06095-1652','','NoPaymentFailure','CheckoutComplete','Other','2011-04-07 01:13:56',0,NULL,7,0,18,0,NULL,'salqa'),(7516,656970382001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 01:34:42',0,NULL,3,1,17,0,NULL,'bbaker8282'),(7517,656970130001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','bbaker8282','blb8282@gmail.com','brandon baker','24 w pine st','fremont','MI','UNITED STATES','49412','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 01:34:43',0,NULL,3,1,1,1,NULL,'bbaker8282\rcanon 反接环  58mm    1\r方形滤镜接口环 58mm   1\r方形滤镜 镜片卡座   1'),(7518,656973890001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 01:48:26',0,NULL,3,1,3,1,NULL,'hathuyminhana\rRA117713480CN\r\\'),(7519,0,110669239527,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',1.3,'hermeshine','curtissp6e','jimaroc@cox.net','Jim Cady','2671 Nye Street','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 03:28:37',0,NULL,3,0,1,1,NULL,'curtissp6e\r'),(7520,657000631001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','jap_magister','jeffrey_pabroquez@yahoo.com','Jeffrey Pabroquez','Al Ain, Abu Dhabi, UAE','Abu Dhabi','Al Ain','UNITED ARAB EMIRATES','7659','00971508384768','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 03:57:56',0,NULL,3,1,3,1,NULL,'jap_magister\r77mm 接口环\rRA117712042CN\r、'),(7521,697711004002,120704792152,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',5.49,'hermeshine','squirmishermish','philip@ermish.com','LeTourneau University','2100 S Mobberly Ave<br>Philip Ermish Cpo #868','Longview','TX','UNITED STATES','75602-3564','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 04:01:00',0,NULL,3,1,1,1,NULL,'squirmishermish\r徐'),(7522,697733154002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','nikki355','nikkihaskell355@msn.com','Nicole Haskell','21 Bunker Ave','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 06:12:26',0,NULL,3,0,3,1,NULL,'nikki355\r1.6mx3m 背景布 白色\rRA117713825CN\r\\'),(7523,766254540015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','emulsion120','exposure.120@hotmail.co.uk','Colin Rogers','63 Yealmpstone Drive<br>Plympton','Plymouth','Devon','UNITED KINGDOM','PL7 1HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 07:01:53',0,NULL,3,1,2,1,NULL,'emulsion120\r英标\r\\'),(7524,697044808002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','hayberdkadir','hayberd@hotmail.com','Kadir Altan','Ereğli<br>Konya','Türkey','Rasim Erel CadÖnder Color','TURKEY','42320','3327128185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 07:58:59',0,NULL,3,1,2,1,NULL,'hayberdkadir\r\\'),(7525,697769030002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 09:19:49',0,NULL,3,1,3,1,NULL,'hathuyminhan\r王\r斜臂    1\r大力夹   1\rRA117713723CN\r\\'),(7526,744035431016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dandins04','evija_2@inbox.lv','Ingus Stepans','31 adnitt road','Northampton','Northamptonshire','UNITED KINGDOM','nn14ll','07556126436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 09:23:01',0,NULL,3,1,2,1,NULL,'dandins04'),(7527,657063010001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','hathuyminhan','ha.ho@bigpond.com','Ha Ho','2/16 Kwinana Street<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0386493002','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-07 09:26:07',0,NULL,3,1,17,0,NULL,'hathuyminhan\r徐'),(7528,657068295001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','brynjolfur-dk','martin@fam-jessen.dk','Martin Jessen','Bostedet 23','Vaerloese','','DENMARK','3500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 09:50:26',0,NULL,3,1,2,1,NULL,'brynjolfur-dk\r庄'),(7529,750800931016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',7.5,'hutongstore','tullesfar','jens.nielsen45@gmail.com','Jens Peter Nielsen','Emdrupvej 137 st. th.','2400 København NV','Denmark','DENMARK','0045','(0045) 50805538','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 09:58:55',0,NULL,3,1,2,1,NULL,'tullesfar\r徐'),(7530,697777560002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thongthong','teezackwhy@gmail.com','Thong Zhen Yang','45, Jalan Kenanga SD9/8<br>Bandar Sri Damansara','Kuala Lumpur','','MALAYSIA','52200','03-62762149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:00:15',0,NULL,3,1,2,1,NULL,'thongthong\r庄'),(7531,655074270018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','assimons62','anne-sofie.simonsen@vkbb.no','Anne Sofie Simonsen','Øyjord','Straumsjøen','','NORWAY','8475','+4797002381','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-07 10:06:56',0,NULL,3,1,4,1,NULL,'assimons62\r刘\rtripod  $20\rYW864489051CN'),(7532,697765001002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 10:28:47',0,NULL,3,1,17,0,NULL,'nono-ey'),(7533,697779071002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:48',0,NULL,3,1,17,0,NULL,'nono-ey'),(7534,657062594001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:48',0,NULL,3,1,17,0,NULL,'nono-ey'),(7535,697769705002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 10:28:49',0,NULL,3,1,17,0,NULL,'nono-ey'),(7536,766322162015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 11:17:00',0,NULL,3,1,4,1,NULL,'sundsdal\rYW864489036CN\r'),(7537,697796241002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','almoghalili','gizbart@gmail.com','Almog Halili','Harkabi 19','Tel aviv','Israel','ISRAEL','67329','+972544936353','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 11:19:51',0,NULL,3,1,3,1,NULL,'almoghalili\r庄\rRA117713754CN\r\\'),(7538,766326043015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 11:25:39',0,NULL,3,1,17,0,NULL,'sundsdal\r徐'),(7539,657096012001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','erwha','yellowbeepbeep@hotmail.com','David Munden','2446 Bank St. Unit 636','Ottawa','ON','CANADA','K1V1A8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 11:51:30',0,NULL,3,1,2,1,NULL,'erwha\r庄'),(7540,750867937016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','robbiestail','brian.campbell4@ntlworld.com','Brian Campbell','2 The Moorings<br>Colwich','Stafford','Staffordshire','UNITED KINGDOM','ST17 0XT','07718601163','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 13:30:42',0,NULL,3,0,3,1,NULL,'robbiestail\r刘\r黑色  3m长\rRA117713839CN\r、'),(7541,657125064001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','zhouweiyi1988','dare_5onic_d3@hotmail.com','kelvin','A1006  / 339 sussex street','sydney','New South Wales','AUSTRALIA','2000','0430065788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 13:36:26',0,NULL,3,1,3,1,NULL,'zhouweiyi1988\r庄\rRA117713737CN\r\\'),(7542,697834747002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','davidbonet','davidboon@hotmail.com','david garcia','patricio borant n-43','lalcudia','Comunidad Valenciana','SPAIN','46250','606837182','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 13:42:30',0,NULL,3,1,2,1,NULL,'davidbonet\r徐'),(7543,655888690001,110471764872,'E-TTL Flash Unit for Canon 450D 500D XSi XS T1i 40D 50D',1,'AB3303',245.98,'hermeshine','senkler','azaro@home.nl','A.Azaro','G.Flinclstraat 46','Meppel','','NETHERLANDS','7944 HB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:02:54',0,NULL,3,0,5,1,' ','senkler\rSergei Gazarov\rStr. Lisunova kvartal 1\rH.22 app.18\rHamzinskij rajon\r700204 Tashkent\rUzbekistan\rCP226268829CN\r王   \r\rNew Camera shoulder bag a1 for Nikon D80 D90 D3000 	Nikon a1 单肩包	1\rNew Camera bag topload D3 for Canon 550D 500D\r	Canon 三角包	1\r24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm\r	60cm 2in1  反光板	1\rNEW Flash Diffuser for Canon 580EX II\r	肥皂盒 580ex	2\rNEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap\r	72mm canon 镜头盖	2\r67mm 67 mm Macro +8 Close-Up Close Up Filter\r	67mm +8 近摄镜	1\rNew Diffuser for external flash sb800 sb700 580ex metz\r	万用柔光罩	1\r3ft Universal TTL Off camera Cord Canon/Nikon/Pentax\r	爵影的ttl线	1\r24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box\r	60cm 园棚 	1\rNEW Flash Diffuser for Canon 430EX / 430EXII\r	肥皂盒 430ex	2\ri-TTL Flash for Nikon D60 D90 D5000 D3000 D300s D700 D3\r	Yn465 Nikon	1\rE-TTL Flash Unit for Canon 450D 500D XSi XS T1i 40D 50D\r 	Yn465 canon	1\r\r王\r'),(7544,0,110669239265,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',1.04,'hermeshine','venadoub','hikingwithdog@yahoo.com','Jim Hunter','3231 Old Salisbury Concord Rd','Concord','NC','UNITED STATES','28025-1546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:08:09',0,NULL,3,1,1,1,NULL,'venadoub\r庄'),(7545,655148562018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','leilanistouch','leilanistouch@yahoo.com','Leilani Mitchell','14808 Cartagena Dr','Gainesville','VA','UNITED STATES','20155-1978','(571) 222-7686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 14:38:29',0,NULL,3,1,4,1,NULL,'leilanistouch\r王\r灯泡110v\rYW864489073CN'),(7546,697851250002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nono-ey','fred.fred@voila.fr','Frédéric Bertrand','6 rue Bernardin de Saint-Pierre','Eragny','Île-de-France','FRANCE','95610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 14:42:53',0,NULL,3,1,4,1,NULL,'nono-ey\r2m 灯架   1\r单灯头  欧标   1\r反光伞   1\r大力夹   2\rc型大力夹   1\r45w    2\r庄  \r2.847\rYW864489040CN\r'),(7547,697850609002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','smala68','videozom@gmail.com','Arunas Zilius','Pavasario 31-6','Mazeikiai','','LITHUANIA','89162','(370) 61293372','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:44:21',0,NULL,3,1,5,1,' ','smala68\r王  2.19\rCP226344525CN\r需邮件'),(7548,697850443002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',2,'AO0023',547,'hermeshine','boutiquetele','service.client@boutique-tele.fr','Ocelys Sarl, Dembele Benedicte','48 Rue la Cigogne Bat C','Angoulême','Poitou-Charentes','FRANCE','16000','0667700704','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:45:41',0,NULL,3,1,4,1,NULL,'boutiquetele\r1.8m 717    2\r肩架   2\rtripod $50\r王\rYW864941902CN\r'),(7549,657147125001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.98,'hermeshine','boutiquetele','service.client@boutique-tele.fr','Ocelys Sarl, Dembele Benedicte','48 Rue la Cigogne Bat C','Angoulême','Poitou-Charentes','FRANCE','16000','0667700704','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 14:49:56',0,NULL,3,1,17,0,NULL,'boutiquetele\r刘'),(7550,750929659016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','v00rtex','david.micallef@gmail.com','David Micallef','34, \'Colin Flats\', No.1<br>Bishop F.S. Caruana Street','Msida','Malta','MALTA','MSD1410','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:13:14',0,NULL,3,1,17,0,NULL,'v00rtex\r'),(7551,766435055015,250692237083,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'AE2314',4.8,'hutongstore','v00rtex','david.micallef@gmail.com','David Micallef','34, \'Colin Flats\', No.1<br>Bishop F.S. Caruana Street','Msida','Malta','MALTA','MSD1410','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 16:13:14',0,NULL,3,1,2,1,NULL,'v00rtex\r绿叶 渐变镜 77mm   1\r绿叶 ND8  77mm   1\r徐'),(7552,766443251015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'AC1302',6.1,'hutongstore','zenziv','zouyi@live.com','Y Zou','25 Dartmouth Street','Stafford','Staffordshire','UNITED KINGDOM','ST16 3TU','07894352017','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:29:22',0,NULL,3,1,2,1,NULL,'zenziv\r徐'),(7553,697898009002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','zaferbakmaz2010','zaferbakmaz@hotmail.com','ZAFER BAKMAZ','baykan ilçe emniyet amirliği inönü polis merkezi<br>siirt baykan','siirt','siirt','TURKEY','56000','+905055466344','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 16:52:25',0,NULL,3,0,3,1,NULL,'zaferbakmaz2010\r庄\rL\rRA117713785CN\r\\'),(7554,766453628015,250599929225,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',8.99,'hutongstore','keetociber','kdotc@hotmail.co.uk','Charles Mills','59 yardley close<br>oldbury','birmingham','West Midlands','UNITED KINGDOM','b68 9dd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 16:54:08',0,NULL,3,1,2,1,NULL,'keetociber\r徐\r62mm 接口环   1\r渐变灰    1(缺)\r托架    1\r\\'),(7555,657194622001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','twsh35','t4wish@gmail.com','Balint Kiss','58','Stary Hradok','Nitra','SLOVAK REPUBLIC','93556','0918823299','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 17:05:32',0,NULL,3,1,3,1,NULL,'twsh35\r庄\rRA117713842CN\r\\'),(7556,697902877002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 17:11:39',0,NULL,3,1,3,1,NULL,'a.buragohain\r王\rRA117713771CN\r\\'),(7557,766458552015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 17:16:13',0,NULL,3,1,4,1,NULL,'pissdrunkdu69\r刘\r2m 灯架  3\r50-70 棚  欧标  2\r115w 220v   4\r包   1\r80cn 2in1 反光板   1\rlighting kit  $32\rYW864489084CN\r'),(7558,750952924016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 17:16:13',0,NULL,3,1,17,0,NULL,'pissdrunkdu69\r徐'),(7559,766459094015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',28,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 17:16:14',0,NULL,3,1,17,0,NULL,'pissdrunkdu69\r王'),(7560,766459018015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','pissdrunkdu69','pissdrunkdu694@msn.com','Jeff Loch','4 rue jean moulin','meyzieu','Rhône-Alpes','FRANCE','69330','0663936579','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 17:16:14',0,NULL,3,1,17,0,NULL,'pissdrunkdu69\r刘'),(7561,657200366001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','wateringer1','g.d.dekleijn@kabelfoon.nl','Guido de Kleijn','van Lottomstraat 25','Kwintsheul','','NETHERLANDS','2295HB','0624502686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 17:19:24',0,NULL,3,1,2,1,NULL,'wateringer1\r徐'),(7562,750974811016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','la**ka','borsos.laci@gmail.com','Laszlo Borsos','35a High Street','Hampton Hill','Middlesex','UNITED KINGDOM','tw12 1nb','07850383806','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-07 17:47:08',0,NULL,3,0,4,1,NULL,'la**ka\r庄\r看一下英标放了吗\rlighting  kit  $40\r放了\rYW864489095CN'),(7563,750989171016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','marsyanya','nickson2000@mail.ru','Vladimir Nikulenko','28 Kalarasha Street, Appartment 29','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 18:11:59',0,NULL,3,1,2,1,NULL,'marsyanya\r徐'),(7564,766514379015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','thik_thi_feed','v.nguyen@lancaster.ac.uk','Nguyen Van Linh','D221 Bowland Ash, Bowland college<br>Lancaster University','Lancaster','Lancashire','UNITED KINGDOM','LA1 4YW','07407254832','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 18:43:26',0,NULL,3,1,2,1,NULL,'thik_thi_feed\r徐'),(7565,0,110669239743,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',1.79,'hermeshine','nob1','nob110@q.com','Norbert R Heimlich','12325 w Larkspur RD','El Mirage','AZ','UNITED STATES','85335-5286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 18:50:49',0,NULL,3,1,1,1,NULL,'nob1\r庄'),(7566,657243749001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','norilsk6867','vikki6867@yandex.ru','4Victoria Yurchenko','Shumilova 77, 6','Volgograd','','RUSSIAN FEDERATION','400021','79876496867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 18:54:46',0,NULL,3,1,2,1,NULL,'norilsk6867\r徐'),(7567,0,110669239189,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',2.75,'hermeshine','mntmansales','robertkellywv@gmail.com','robert kelly','125 rogers st','oak hill','WV','UNITED STATES','25901-2552','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-07 19:06:04',0,NULL,3,1,1,1,NULL,'mntmansales\r庄'),(7568,751021344016,260660053762,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.16,'hutongstore','maxkozin77','max_1977@mail.ru','Maksim Kozin','Frunze street, 10A-75','Togliatti','Samara Region','RUSSIAN FEDERATION','445037','+79023737372','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 19:17:34',0,NULL,3,1,2,1,NULL,'maxkozin77\r徐'),(7569,751074579016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zsoltgyapay','zsolt.gyapay@gmail.com','Zsolt Gyapay','Attila u. 34.','Hévíz','Zala','HUNGARY','8380','0036304007688','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 20:33:49',0,NULL,3,1,2,1,NULL,'zsoltgyapay\r庄'),(7570,698011325002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lunadrift','lunadrift@gmail.com','Bu Wang','1920 Powell Campus Ctr','Alfred','NY','UNITED STATES','14802','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-07 21:00:59',0,NULL,3,1,1,1,NULL,'lunadrift\r刘'),(7571,761000492015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','andrejsplavins','andrejs.plavins@gmail.com','Andrejs Plavins','2 Castle Park','Buncrana','Donegal','IRELAND','','0879178759','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-07 21:10:30',0,NULL,3,1,3,1,NULL,'andrejsplavins\r庄\rRA117713808CN\r\\'),(7572,766609785015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','dazhop-irl','kathybhopkins@yahoo.ie','Kathy Hopkins','Carrickmoyragh','Newtownforbes','Longford','IRELAND','default','0861629151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-07 21:22:33',0,NULL,3,0,3,1,NULL,'dazhop-irl\r庄\r白色  3m 长\rRA117713799CN\r\\'),(7573,698024986002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','pinya70','pinya70@hotmail.com','Javier López Raja','CFilet de Fora nº63<br>3ª planta, puerta A','Elche','Comunidad Valenciana','SPAIN','03203','699870303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 21:34:53',0,NULL,3,1,2,1,NULL,'pinya70\r徐'),(7574,766621276015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cammy3005','lynncameron@gmail.com','Lynn Cameron','Acorn B&B<br>16 Priestden Road','St.Andrews','Fife','UNITED KINGDOM','KY16 8DJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-07 21:47:17',0,NULL,3,1,3,1,NULL,'cammy3005\r王\rRA117713745CN\r\\'),(7575,518411999003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','zorton7','besantes@hotmail.com','francisco jose besantes fernandez','josep serra carsi 2-19','catarroja','Comunidad Valenciana','SPAIN','46470','622190322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 21:53:57',0,NULL,3,1,2,1,NULL,'zorton7\r徐'),(7576,698037438002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','77613076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 22:13:59',0,NULL,3,1,2,1,NULL,'jfossb\r徐\r'),(7577,657341438001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','jessjason_lives','jessicca.pratt@gmail.com','Jess Pratt','7 Joan Avenue ','Dromana','Victoria','AUSTRALIA','3936','0407830797','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-07 23:00:32',0,NULL,3,1,4,1,NULL,'jessjason_lives\r刘澳标\rYW864489106CN'),(7578,697987818002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gio757','gio757@simail.it','Giorgio Calore','v. Risorgimento 34','Selvazzano Dentro','Padova','ITALY','35030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-07 23:24:52',0,NULL,3,1,3,1,NULL,'gio757\r王\r申报：light stand $15\rRA117713710CN\r\\'),(7579,657373864001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','egun_314','e.gunderson@utoronto.ca','Erik Gunderson','116B Barton Ave','Toronto','ON','CANADA','M6G 1P9','(416) 532-5255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 01:19:37',0,NULL,3,1,2,1,NULL,'egun_314\r徐'),(7580,698113940002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','sngchile','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 03:15:30',0,NULL,3,1,2,1,NULL,'sngchile\r徐'),(7581,657425437001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','funku28','mustafasakizci@ttnet.net.tr','MUSTAFA SAKIZCI','KORESEHITLERI CD. KAYA ALDOGAN SOK. NO :16 ZINCIRLIKUYU','ISTANBUL','TURKEY','TURKEY','34394','00905318650028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 05:31:30',0,NULL,3,1,2,1,NULL,'funku28\r徐'),(7582,698151228002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ilgar_i','ilgarilyasov@gmail.com','Ilgar Ilyasov','Rashid Behbudov 71','Baku','Baku','AZERBAIJAN','AZ1022','+994556596004','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 06:47:22',0,NULL,3,1,3,1,NULL,'ilgar_i\r徐\rRA117712073CN\r、'),(7583,698153909002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','sean_foulkes','seanfoulkes@gmail.com','SPC Foulkes, Sean','C Co  TF 1-163<br>COS KALSU','APO','AE','AA','09312','(406) 219-4262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-08 07:09:26',0,NULL,3,1,1,1,NULL,'sean_foulkes\r徐'),(7584,657443246001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','ilgar_i','ilgarilyasov@gmail.com','Ilgar Ilyasov','Rashid Behbudov 71','Baku','Baku','AZERBAIJAN','AZ1022','+994556596004','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 07:26:46',0,NULL,3,1,3,1,NULL,'ilgar_i\rRA117712087CN\r、'),(7585,698162657002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kaiwan2010','kaiwan.b.h@hotmail.com','Kaiwan Bahroz','Oscarsgate 35A','0258 Oslo','Oslo','NORWAY','0258','004795002606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 07:45:21',0,NULL,3,1,17,0,NULL,'kaiwan2010'),(7586,698163069002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kaiwan2010','kaiwan.b.h@hotmail.com','Kaiwan Bahroz','Oscarsgate 35A','0258 Oslo','Oslo','NORWAY','0258','004795002606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 07:47:17',0,NULL,3,1,3,1,NULL,'kaiwan2010\r100*150  5合1 反光板    1\rlenspen   1\r徐\rRA117716849CN'),(7587,657461865001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','jaikoo','jaikoo@gmail.com','Jonathan Conway','3 Parker Way<br>Little Canfield (Priors Green near Takeley)','Dunmow','Essex','UNITED KINGDOM','CM6 1GT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 08:49:04',0,NULL,3,0,3,1,NULL,'jaikoo\rRA117712379CN\r\\'),(7588,698189947002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','asturcop','asturcop@gmail.com','Pelayo Palacio Arce','Avda Portugal 94    5 b','Gijon','Asturias','SPAIN','33207','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 09:55:22',0,NULL,3,1,4,1,NULL,'asturcop\rtripod $16\rYW864941036CN'),(7589,657479916001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','lev_gromov','lgromov@yandex.ru','Лев Громов','Мичуринский пр-кт <br>11-3- 80','Москва','','RUSSIAN FEDERATION','119191','+7(903)7241849','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 10:07:58',0,NULL,3,1,3,1,NULL,'lev_gromov\rRA117712201CN\r\\'),(7590,698198163002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yaro-t','yaro-t@ukr.net','Andriy Ivanenko','prospekt Peremogi 89a kv 205','Kiev','','UKRAINE','03115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 10:33:03',0,NULL,3,1,2,1,NULL,'yaro-t\r刘\r\\'),(7591,751320031016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','dsiefa','dsiefa@aol.com','Victoria Andrews','7 Sawkins Close<br>The Poplars, Langenhoe','Colchester','Essex','UNITED KINGDOM','CO5 7LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 10:57:37',0,NULL,3,1,2,1,NULL,'dsiefa\r庄\r\\'),(7592,657500878001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','suhaimuzi','suhaim@012.net.il','uzi haim hacohen','aerez 34a/4','binyamina','','ISRAEL','30500','+972528890644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 11:34:23',0,NULL,3,1,2,1,NULL,'suhaimuzi\r王\r\\'),(7593,766851230015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','radioactive50149','steves.jones@ge.com','STEPHEN JONES','282<br>MEADOWCROFT','AYLESBURY','Buckinghamshire','UNITED KINGDOM','HP19 9HZ','01494543787','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-08 11:48:19',0,NULL,3,1,2,1,NULL,'radioactive50149\r刘\r\\'),(7594,698226143002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gescon77','alvaro.delallaverodriguez@t-gestiona.com','ALVARO RODRIGUEZ','CONDESA DE VENADITO 7 4ªPLANTA','MADRID','Madrid','SPAIN','28027','918478995','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 12:24:47',0,NULL,3,1,4,1,NULL,'gescon77\rtripod $16\rYW864941040CN'),(7595,657551893001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','monra1962','monchodax@hotmail.com','ramon luis alvarado','juan rodriguez nº 221 Bº san salvador','ushuaia','Tierra del fuego','ARGENTINA','9410','02901-431046','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 14:38:33',0,NULL,3,1,2,1,NULL,'monra1962\r庄\r\\'),(7596,657558907001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','ragota','ragoka@enternet.hu','Agota Reti','Szarazhegy u. 29.','Budapest','','HUNGARY','1171','+36 306 808 305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 14:59:14',0,NULL,3,1,2,1,NULL,'ragota\r刘\r\\'),(7597,698306950002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','d_ranade','d_ranade@hotmail.com','Dilip Ranade','GM (Vigilance) RCF Ltd, Room No 942B,<br>9th Floor, Priyadarshini, Eastern Express Highway, Sion','Mumbai','Maharashtra','INDIA','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 16:37:42',0,NULL,3,1,2,1,NULL,'d_ranade\r庄\r\\'),(7598,657598045001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','jmscheller','marilyn.scheller@gmail.com','Marilyn Scheller','c/o RM of Glen Bain<br>Box 39  Main Street','Glen Bain','SK','CANADA','S0N 0X0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 16:49:07',0,NULL,3,1,2,1,NULL,'jmscheller\r刘\r\\'),(7599,766974652015,250606686795,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2202',2.75,'hutongstore','marta0872','martamyebay@gmail.com','marta chelli','via fucini 37','grosseto','GR','ITALY','58100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-08 17:02:54',0,NULL,3,1,2,1,NULL,'marta0872\r庄\r\\'),(7600,657620245001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','lexx016','lexx015@gmail.com','Aleksey Petukhov','Pushkarskaya<br>79-52','Perm\'','Permsky Kray','RUSSIAN FEDERATION','614077','89082652737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-08 17:56:08',0,NULL,3,1,2,1,NULL,'lexx016\r刘\r\\'),(7601,657601900001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','jmta123','hamcomm@comcast.net','Hamilton Communications','1442 Essex Rd','Westbrook','CT','UNITED STATES','06498-1585','','NoPaymentFailure','CheckoutComplete','Other','2011-04-08 18:02:20',0,NULL,3,1,4,1,NULL,'jmta123\r庄\rYW864941051CN'),(7602,657632627001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-08 18:14:14',0,NULL,3,1,3,1,NULL,'willyodd\rRA117712175CN\r\\'),(7603,655755154018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','rtelly837ronald','xax371@yahoo.com','RONALD HOWARD','177-50 106 AV','JAMAICA','NY','UNITED STATES','11433','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-08 22:14:42',0,NULL,3,1,4,1,NULL,'rtelly837ronald\r灯泡是110v\rlighting kit $28\rYW864941062CN\r王'),(7604,698472441002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','bask2727','alohakid2727@yahoo.com','Toni Sullivan','1129 Bloomdale St','Duarte','CA','UNITED STATES','91010-2442','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 00:12:56',0,NULL,3,1,1,1,NULL,'bask2727\r徐\r、'),(7605,698479394002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','richard218','rgryziak@yahoo.com','Richard Gryziak','1401 Madison St NW','Washington','DC','UNITED STATES','20011','(202) 882-0046','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 00:43:53',0,NULL,3,1,1,1,NULL,'richard218\r庄\r、'),(7606,657764225001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','paulo_alfonso','paulo.alfonso.n@gmail.com','Paulo Alfonso Nuñez Utreras','Artemio Gutierrez 1635<br>Santiago','Santiago','Metropolitana','CHILE','8360658','5625511639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 00:48:38',0,NULL,3,1,3,1,NULL,'paulo_alfonso\r王\r1.418\rRA117712507CN\r、'),(7607,698484097002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','beguin5651','juanperva@ya.com','juan antonio perez d las vacas bueno','plza cartaya 1','madrid','Madrid','SPAIN','28024','915184109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 01:05:43',0,NULL,3,0,3,1,NULL,'beguin5651\r1.6x3m 黑色背景布   1\rRA117712215CN\r\\'),(7608,698497669002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','beverly35533553','terryandbeverly@yahoo.com','BEVERLY KILLIAN','2525 POINT ST<br>FRONT PORCH','CLAREMONT','NC','UNITED STATES','28610-8622','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 02:07:12',0,NULL,3,1,1,1,NULL,'beverly35533553\r徐\r、'),(7609,655842030018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','kd21h','karynhelton@yahoo.com','Karyn Helton','2890 Carl Stuart St','Conway','AR','UNITED STATES','72034-7527','(501) 328-8555','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-09 03:44:17',0,NULL,3,1,4,1,NULL,'kd21h\r灯泡是110v  \rlighting kit $35\r庄\rYW864941073CN'),(7610,657820369001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','osmanshawkat','sam_shawkat@yahoo.com','Osman Shawkat Ali','Blk 739,#02-01,Pasir Ris Dr 10','default','','SINGAPORE','510739','97505559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 05:50:11',0,NULL,3,1,3,1,NULL,'osmanshawkat\rRA117712161CN\r\\'),(7611,657824915001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ruc.catala','oriol.corbella@gmail.com','Oriol Corbella Cervelló','Gran Via de les Corts Catalanes, 490, 7è 2a','Barcelona','Cataluña','SPAIN','08015','934537038','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 06:19:52',0,NULL,3,1,3,1,NULL,'ruc.catala\rRA117729480CN\r\\'),(7612,698547508002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mcguffincemoli','ddemmaa@hotmail.com','Cemal Samli','INONU CAD. NO:386 K:7 D:28 HAKIMEVLERI','IZMIR','KONAK','TURKEY','35290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 06:41:02',0,NULL,3,1,3,1,NULL,'mcguffincemoli\r刘\rRA117712158CN\r\\'),(7613,698561691002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',74.8,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo str, 64/1-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 07:55:03',0,NULL,3,1,5,1,NULL,'najort-perm\rCP226268801CN\r需邮件'),(7614,698568021002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','insaned79','tolstenkoiv@gmail.com','Ilya Tolstenko','Glavpochtampt<br>box 3778','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350000','+7-918-376-17-89','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 08:42:47',0,NULL,3,1,3,1,NULL,'insaned79\rRA117712189CN\r\\'),(7615,698170401002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 08:56:20',0,NULL,3,1,3,1,NULL,'saud-p\r2m 背景架  白色背景布\r发两个小包\rRA117712135CN\rRA117729414CN\r\\\r\r王'),(7616,698579138002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 09:09:54',0,NULL,3,1,17,0,NULL,'imparcial'),(7617,657862238001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:13:58',0,NULL,3,1,17,0,NULL,'imparcial'),(7618,698580959002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','imparcial','lundi@wanadoo.es','José Ríos López','C/Los Devis,5','Alcázar de San Juan','Ciudad Real','SPAIN','13600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 09:17:19',0,NULL,3,1,3,1,NULL,'imparcial\r爵影碗罩P4   1\r万用遮光罩    1\r肥皂盒 柔光罩   580EX  1\r徐\rRA117712232CN\r、\r'),(7619,767299963015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','123kellock','big_boy_willy@hotmail.com','Will Kellock','O2<br>1a, SIlver Street','Wellignborough','Northamptonshire','UNITED KINGDOM','NN81BQ','01933278902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 09:18:34',0,NULL,3,1,2,1,NULL,'123kellock\r庄\r\\'),(7620,639206861018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','solidagoart','solidagoart2010@hotmail.it','marco scarparo','via pertini,21(ex via torino)','gessate','MI','ITALY','20060','3478109706','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-09 09:21:58',0,NULL,3,1,4,1,NULL,'solidagoart\rlighting kit  $26\r欧标\r王\rYW864941084CN'),(7621,698592161002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','h-smulders-2007','h.smulders@hccnet.nl','Harry Smulders','Henk vd Broeklaan 4','Eindhoven','','NETHERLANDS','5626 HA','0402621675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:07:47',0,NULL,3,1,2,1,NULL,'h-smulders-2007\r徐\r\\'),(7622,698594088002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','zcetrt','ziga.cetrtic@gmail.com','Ziga Cetrtic','Podgora pri Dolskem 6','Dol pri Ljubljani','Dol pri Ljubljani','SLOVENIA','1262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:13:30',0,NULL,3,1,2,1,NULL,'zcetrt\r庄'),(7623,698600488002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','allaboutsculpting','dansgarbage@yahoo.com','Daniel Moy','127 Wexford Road','Wellington','Miramar','NEW ZEALAND','6022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 10:41:26',0,NULL,3,1,11,1,NULL,'allaboutsculpting\r刘\r\\'),(7624,698607051002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','indiana107','kyliev@kanet.com.au','Kylie Valencius','12 The Avenue','GLENMORE PARK','New South Wales','AUSTRALIA','2745','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 11:08:02',0,NULL,3,0,3,1,NULL,'indiana107\rL\r庄\rRA117729051CN\r、'),(7625,657900082001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','altermann7878','altermann78@yandex.ru','Anton Mironov','Vilnyusskaya street, 4-163','Moscow','Moscow','RUSSIAN FEDERATION','117574','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 11:48:40',0,NULL,3,1,5,1,NULL,'altermann7878\r2m 背景架 （ 白  黑）  1\r王\rCP226268815CN'),(7626,657898787001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',5,'AA2217',44.95,'hermeshine','fabiobravin','fpbravin@yahoo.com.br','Fabio Bravin','QSA 17 Casa 25<br>Taguatinga','Brasília','Distrito Federal','BRAZIL','72015-170','55-61-92119138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 12:07:20',0,NULL,3,1,3,1,NULL,'fabiobravin\r庄\rRA117729048CN\r、'),(7627,698635883002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','jenigoci','jenigoci@gmail.com','Jenny Goicochea C/O Clinilabs','423 W 55th St<br>4th Floor','New York','NY','UNITED STATES','10019','','NoPaymentFailure','CheckoutComplete','Other','2011-04-09 12:57:09',0,NULL,3,1,3,1,NULL,'jenigoci\r庄\r1.545\rRA117712498CN\r\\'),(7628,698637075002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','garnik1008kg','gk1008kg@yahoo.com','Garnik Karapetyan','A. Serob 10. 26','Erevan','','ARMENIA','0019','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 13:07:23',0,NULL,3,1,3,1,NULL,'garnik1008kg\r欧标\r分两个小包发\r2个灯架 +伞\r双灯头  2 欧标\rRA117712285CN\rRA117729428CN\r\\\r'),(7629,518876031003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:00:32',0,NULL,3,0,5,1,NULL,'mellogabriel\r申报 tripod  $40\r庄\rCP226268792CN\r需邮件'),(7630,657960747001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mkostas','bladimhros@yahoo.com','Konstantinos Kargas','Eteokleous 4','Thessaloniki','Greece','GREECE','54250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 15:02:50',0,NULL,3,1,2,1,NULL,'mkostas\r徐\r\\'),(7631,657961391001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','d_spider541','arha80@msn.com','Rosemarie Arbur','6342 Katie Ln','Klamath Falls','OR','UNITED STATES','97603-7151','(541) 273-6787','NoPaymentFailure','CheckoutComplete','Other','2011-04-09 15:05:54',0,NULL,3,1,1,1,NULL,'d_spider541\r庄\r、'),(7632,751888974016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jkegholm','kalle@jkegholm.dk','Kalle Egholm','Bellisallé 14','Horsens','','DENMARK','DK8700','004561304107','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-09 15:14:18',0,NULL,3,1,4,1,NULL,'jkegholm\r欧标   \rlighting kit  $40\r刘\rYW864941095CN'),(7633,656015101018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','jenigoci','jenigoci@gmail.com','Jennifer Goicochea','41-36 51Street<br>Apt. C-2','Woodside','NY','UNITED STATES','11377','(718) 779-8442','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-04-09 15:25:44',0,NULL,3,1,4,1,NULL,'jenigoci\r灯泡 是110v\r庄\rYW864941106CN'),(7634,767485494015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','embeclan','alanh44@hotmail.com','Alan Hewitt','4 Moorgate Park','Retford','Nottinghamshire','UNITED KINGDOM','DN22 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-09 17:22:50',0,NULL,3,1,2,1,NULL,'embeclan\r徐\r\\'),(7635,658093215001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','lisemiron','normandmiron@hotmail.com','Lise Miron','7064 Marie G.-Lajoie','Montreal','QC','CANADA','H1J 2R9','(514) 353-8098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:04:21',0,NULL,3,1,2,1,NULL,'lisemiron\r庄\r\\'),(7636,767579275015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','raztomesko','raztomesco@yahoo.com','razvan tomescu','Bruria 2/7','Ramat Gan','center','ISRAEL','52526','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-09 20:05:36',0,NULL,3,1,3,1,NULL,'raztomesko\r分三个挂号小包发    欧标    王\rRA117712762CN\rRA117712855CN\rRA117712833CN\r'),(7637,658096126001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','swjeweler','a86music@gmail.com','Milan Kiss','Kereknad 9','Gyor','Gyor Moson Sopron','HUNGARY','9030','+36205308688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:11:02',0,NULL,3,1,3,1,NULL,'swjeweler\r刘\rRA117712229CN\r、'),(7638,698819623002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','janosik1209','marcinpawlik@hotmail.com','marcin pawlik','293 1/2 Pavonia Ave','jersey city','NJ','UNITED STATES','07302-1577','(201) 704-6095','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-09 20:39:36',0,NULL,3,1,1,1,NULL,'janosik1209\r庄\r、'),(7639,658112091001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','massimox76','massimox@gmail.com','Massimo Iacarelli','baveno 58','roma','RM','ITALY','00166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-09 20:49:25',0,NULL,3,1,2,1,NULL,'massimox76\r徐\r\\'),(7640,658154869001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','khaled3210','the.kbk@gmail.com','Khaled Khadra','94 Spring Farm Rd','Aurora','ON','CANADA','L4G7W7','(647) 867-3210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-09 23:14:26',0,NULL,3,1,3,1,NULL,'khaled3210\rRA117712113CN\r\\'),(7641,752154492016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','alechandro78','alechandro@mail.ru','alexey demenschin','5 city west mews','ballincollig','Cork','IRELAND','319','0861091762','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 01:00:21',0,NULL,3,0,3,1,NULL,'alechandro78\r1.6x3m 白色\r刘\rRA117712303CN\r、'),(7642,658271087001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','studio_store','studio43300@gmail.com','Tomasz Zając','ul. Pięciu Stawów 11/60','Bielsko-Biała','śląskie','POLAND','43300','33 4865299','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 08:05:07',0,NULL,3,0,3,1,NULL,'studio_store\rXXL\r庄\rRA117729476CN\r、'),(7643,767810888015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','jara_1960','giralda_1960@yahoo.com','jose aragones aragones','c/ real, 35','viator','Almeria','SPAIN','04240','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-10 08:33:12',0,NULL,3,1,4,1,NULL,'jara_1960\r庄\rYW864941110CN'),(7644,699003764002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','palvolgyifoto','palvolgyi@palvolgyi.hu','Palvolgyi-Foto Kft','Baross u 261','Budapest','Budapest','HUNGARY','1162','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 08:53:03',0,NULL,3,1,3,1,NULL,'palvolgyifoto\r徐\rRA117712192CN\r、'),(7645,767907000015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','9997barry','bgibson@bgibson.karoo.co.uk','BARRY GIBSON','87 EASTFIELD ROAD','HULL','East Riding of Yorkshire','UNITED KINGDOM','HU4 6DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 12:11:01',0,NULL,3,1,2,1,NULL,'9997barry\r庄\r\\'),(7646,658400188001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','macokaz','martind_maco@hotmail.com','Martin Darnadi','Tupolevova 8','Bratislava','','SLOVAK REPUBLIC','85101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 13:56:44',0,NULL,3,1,2,1,NULL,'macokaz\r徐\r\\'),(7647,0,120708876423,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',2.25,'hermeshine','malim269','malim8888@yahoo.com','Gifts Crafts & Beyond','11291 Senda Luna Llena','San Diego','CA','UNITED STATES','92130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 14:54:14',0,NULL,3,1,1,1,NULL,'malim269\r庄\r、'),(7648,768004014015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','jaguar200000','extrados@neuf.fr','PASCAL DARNANVILLE','42 RUE FELIX FAURE','DUNKERQUE','Nord-Pas-de-Calais','FRANCE','59240','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 15:17:54',0,NULL,3,1,3,1,NULL,'jaguar200000\rRA117729065CN\r\\'),(7649,752465265016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.5,'hutongstore','bardelas1','habelyan@ntlworld.com','Jan Habelman','28 Rosedale Waltham','Grimsby','Lincolnshire','UNITED KINGDOM','DN37 0UJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:33:37',0,NULL,3,1,2,1,NULL,'bardelas1\r徐\r\\'),(7650,768015238015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','r*g*b','robertgburke@hotmail.com','Robert Burke','46 Ashtofts Mount<br>Guiseley','Leeds','West Yorkshire','UNITED KINGDOM','LS20 9DB','07871882896','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:34:37',0,NULL,3,1,2,1,NULL,'r*g*b\r庄\r\\'),(7651,699161616002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','011 48657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 15:44:02',0,NULL,3,1,3,1,NULL,'2010bousosheila\rRA117729025CN\r\\'),(7652,752133119016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',2,'AB3307',65.98,'hutongstore','michaelhele','michael@hele.co.uk','Michael Hele','23 Norbiton Road<br>Kingstanding','Birmingham','West Midlands','UNITED KINGDOM','B44 0EE','01216801366','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 15:45:28',0,NULL,3,1,3,1,NULL,'michaelhele\r王\rRA117729975CN'),(7653,699170239002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 15:50:14',0,NULL,3,1,3,1,NULL,'zandermatt\r加77ND8   1   \r王\rRA117712609CN\r、'),(7654,658458534001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 15:59:59',0,NULL,3,1,17,0,NULL,'zandermatt\r徐'),(7655,699003069002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','arx808','weondaair808@aol.com','Lorelie Arcalas','94-693 Kupuna Loop','Waipahu','HI','UNITED STATES','96797-1120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 16:06:22',0,NULL,3,1,1,1,NULL,'arx808\r庄\r、'),(7656,752503787016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','dolon2424','dolon24@hol.gr','Ioannis Athanasiadis','Aristotelous 35<br>Stavroupoli','Thessaloniki','Thessaloniki','GREECE','56431','2310665482','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 16:28:03',0,NULL,3,1,3,1,NULL,'dolon2424\r庄\rRA117729079CN\r、'),(7657,658478885001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dennis.781','dennwise@gmail.com','Dennis S.  Wise','2 Ponkapoag Way','Canton','MA','UNITED STATES','02021-1117','(781) 608-0548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 16:28:59',0,NULL,3,1,1,1,NULL,'dennis.781\r要“灰色”背景布。\r刘\r、'),(7658,656557207018,280541368434,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','artanis1986','artanis@artanis.hu','Gergely Cziva','Radnoti 15.','Martonvásár','','HUNGARY','2462','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-10 16:51:43',0,NULL,3,1,5,1,NULL,'artanis1986\r刘\r欧标   \rCP226268775CN\r'),(7659,658516695001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','schinder1956','skrunda.lv@gmail.com','Indulis Gutmanis','Jubilejas 7-16','Rudbarzu pagasts','Skrundas novads','LATVIA','LV-3324','26271330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 17:20:51',0,NULL,3,1,3,1,NULL,'schinder1956\r庄\rRA117729493CN\r、'),(7660,658526298001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','karloslk','karloska@mail.ru','Karen Lazaryan','Varshavskoe shosse 37A','Moscow','','RUSSIAN FEDERATION','117105','+79265934053','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 17:31:30',0,NULL,3,1,3,1,NULL,'karloslk\rRA117729082CN\r\\'),(7661,768131160015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','sakura54t','lobster876@hotmail.com','Richard Taylor','88 Hamilton Road, Summertown','Oxford','Oxfordshire','UNITED KINGDOM','OX2 7QA','01865559694','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 17:46:19',0,NULL,3,1,2,1,NULL,'sakura54t\r刘\r\\'),(7662,768135708015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','bodyboarder1979','lisajones_1982@hotmail.co.uk','lisa jones','78 priory court','neath','Neath Port Talbot','UNITED KINGDOM','sa10 7rz','01639698561','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 17:49:52',0,NULL,3,1,2,1,NULL,'bodyboarder1979\r庄\r\\'),(7663,658549073001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','fred_star101','fred_star@intnet.mu','Frederic Foo Shin','8 cook street','Port Louis','','MAURITIUS','000000','+230 212 6660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:07:12',0,NULL,3,1,2,1,NULL,'fred_star101\r刘\r\\'),(7664,658567478001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','magician20','kaprifolvagen@bredband.net','Thomas Andersson','Kaprifolvägen 46','Hässelby','Stockholm','SWEDEN','S-165 59','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 18:12:15',0,NULL,3,1,3,1,NULL,'magician20\r刘\r注意是2个\r1.7\rRA117712475CN\r\\'),(7665,699299679002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tomuresa','almagra@telefonica.net','Tomas Ureña Saez','C/ Santo Tomas 22','Mazarron','Murcia','SPAIN','30870','609589176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 18:28:06',0,NULL,3,1,2,1,NULL,'tomuresa\r庄\r\\'),(7666,752629477016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','espirelojuan','espirelott@hotmail.es','david bestard','calle plataner 12 4b','Palma de Mallorca','Baleares','SPAIN','07008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 18:28:43',0,NULL,3,1,2,1,NULL,'espirelojuan\r刘\r\\'),(7667,699335546002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','tg60','ebay@tg60.de','Thomas Gänsdorfer','Im Winterrot 95','Karlsruhe','','GERMANY','76228','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 19:08:24',0,NULL,3,1,3,1,NULL,'tg60\r庄\rXL\rRA117729034CN\r、'),(7668,699416472002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','pavelsib','tigerx@ngs.ru','Pavel Sibirtsev','ul. Vybornaya 110-11<br>ул. Выборная 110-11','Novosibirsk','Novosibirskaya Oblast','RUSSIAN FEDERATION','630126','7(903)9976336','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-10 21:10:36',0,NULL,3,1,3,1,NULL,'pavelsib\r刘\rRA117712127CN\r\\'),(7669,658714681001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','walbo007','ej.wallet@telfort.nl','Edith-José Wallet-Boers','Berkelstroom 117','Zoetermeer','','NETHERLANDS','2721 AG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:42:01',0,NULL,3,1,2,1,NULL,'walbo007\r徐\r\\'),(7670,658715523001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',15,'AA3309',74.25,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:44:22',0,NULL,5,0,18,0,NULL,'1imagen'),(7671,658712327001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',15,'AA3308',74.25,'hermeshine','1imagen','imaklos@hotmail.com','Manuel','Avenida Derechos Humanos 28 - Rdcia.Los sauces 10','Laredo','Cantabria','SPAIN','39770','942611010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:44:22',0,NULL,5,0,18,0,NULL,'1imagen'),(7672,658129784001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','manolovian','mvianh@hotmail.com','Manuel Vian Hernando','C/ San juan 11-13 1ºB<br>Medina de Rioseco','Valladolid','Castilla y León','SPAIN','47800','650478444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 21:51:08',0,NULL,3,0,3,1,NULL,'manolovian\r1.6x2.1  背景布  2\r灰色  +  绿色\rRA117712294CN\r、'),(7673,658723586001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','shoxpro','shoxpro@mailcity.com','reynald barredo','13890 Sayre st<br>Apt. 218','Sylmar','CA','UNITED STATES','91342','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-10 22:05:01',0,NULL,3,1,1,1,NULL,'shoxpro\r徐\r、'),(7674,752814664016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','bobhllihp','phillybob67@aol.com','PHIL LOCKHART','6 BIRCH CROFT','DEESIDE','Flintshire','UNITED KINGDOM','CH52BN','01244536485','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-10 22:32:49',0,NULL,3,1,3,1,NULL,'bobhllihp\r王\rRA117729961CN'),(7675,768373260015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',2,'AA3310',7,'hutongstore','sookonn','indrek.polakes@mail.ee','Indrek Polakes','Kärberi 52-11','Tallinn','Harjumaa','ESTONIA','13919','56453066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-10 22:35:59',0,NULL,3,1,2,1,NULL,'sookonn\r徐\r\\'),(7676,656810862018,280522560367,'Tripod Fancier FT-6662A with 6160H Ball head 550D D90',1,'AE1503',69.9,'photographyacc','kulyllo','kulyllo@hotmail.com','ENCARNA MARIA GIMENEZ SANCES','C/PICASSO Nº4<br>BALERMA','ALMERIA','Andalucía Ceuta y Melilla','SPAIN','04712','658974588','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-10 22:52:07',0,NULL,3,1,4,1,NULL,'kulyllo\r庄\rtripod  $20\rYW864941121CN'),(7677,699455332002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','revenk0','rda9@ya.ru','Денис Ревенко','11-я улица дом 56','Ростов-на-Дону','','RUSSIAN FEDERATION','344013','89034620514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-10 22:55:12',0,NULL,3,1,3,1,NULL,'revenk0\rRA117729017CN\r\\'),(7678,699481373002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','mlmho','mlmho@yahoo.com','Ming Ho','274 Pantego Terr NW','Calgary','AB','CANADA','T3K0k3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 00:00:24',0,NULL,3,1,5,1,NULL,'mlmho\r庄\r2m 背景架    白色\rCP226268761CN'),(7679,768414750015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mikeparsons1974','mcpuk1@btinternet.com','Mike Parsons - Capture Moments Photography','No 5 Green Lawns<br>14 Bay View Road','Colwyn Bay','Conwy','UNITED KINGDOM','LL298DW','01492531032','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:26:51',0,NULL,3,1,3,1,NULL,'mikeparsons1974\rRA117729105CN\r\\'),(7680,768420676015,250599922899,'New 67mm 67 Ring adapter and Holder for Cokin P Series ',1,'AKT022',3.62,'hutongstore','sprinter_90','andy_millen@hotmail.co.uk','Andy Millen','7 Phineas Pett Road','Eltham','London','UNITED KINGDOM','SE9 6RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:41:11',0,NULL,3,1,17,0,NULL,'sprinter_90'),(7681,768420678015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',1.88,'hutongstore','sprinter_90','andy_millen@hotmail.co.uk','Andy Millen','7 Phineas Pett Road','Eltham','London','UNITED KINGDOM','SE9 6RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 00:41:13',0,NULL,3,1,2,1,NULL,'sprinter_90\rNIKON 镜头盖 67mm   1\r接口环 67mm   1\r卡座   1\r徐\r\\'),(7682,752892289016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','matzu855','matzu85@yahoo.com','badea nicolae sebastian','7 The Cottage<br>Lewis Street','st helier','Channel Islands','UNITED KINGDOM','JE2 3PB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 01:55:35',0,NULL,3,1,3,1,NULL,'matzu855\rRA117729502CN\r\\'),(7683,658803415001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','plab6987','labedzki@live.ca','Piotr Labedzki','22 Gloucester CRT','Kitchener','ON','CANADA','N2B3W1','(519) 894-2869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 02:04:22',0,NULL,3,1,2,1,NULL,'plab6987\r\\'),(7684,658819132001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:43',0,NULL,3,1,17,0,NULL,'greencatmerlin'),(7685,699544436002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:47',0,NULL,3,1,17,0,NULL,'greencatmerlin'),(7686,658818214001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:48',0,NULL,3,1,17,0,NULL,'greencatmerlin'),(7687,658818738001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','greencatmerlin','richl@unimelb.edu.au','Linda Richmond','Campus Operations Group<br>215 Grattan Street','The University of Melbourne','Victoria','AUSTRALIA','3010','0383446105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 03:01:48',0,NULL,3,1,3,1,NULL,'greencatmerlin\r麂皮   1\r气吹 + 布    1\r橡胶遮光罩 58mm   1\r眼罩 450D/500D   1\rRA117712246CN\r\\'),(7688,0,120708876461,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.99,'hermeshine','rydabomb','ryan4luck@sbcglobal.net','Ryan Wills','7705 Devon Ct','Atascadero','CA','UNITED STATES','93422','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 03:27:12',0,NULL,3,1,1,1,NULL,'rydabomb\r、'),(7689,656904433018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','4697timothy','lexball68@hotmail.com','Timothy Williams','3145 S Prairie Ave','Chicago','IL','UNITED STATES','60616-3903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 04:20:13',0,NULL,3,1,4,1,NULL,'4697timothy\r刘  \rYW864941983CN'),(7690,657793944001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',71.88,'hermeshine','heart.beth.ann','bskabar@gmail.com','beth skabar','618 N St<br>Apt 2','anchorage','AK','UNITED STATES','99501-6084','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,3,0,3,1,NULL,'heart.beth.ann\r反光板支架   1\r100-150 5in1 反光板  1\r发两个小包  王\rRA117712467CN\rRA117712419CN\r、\r'),(7691,658863584001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','graf131313','m.prishep@gmail.com','Pryshep Zinaida','Rokossovskogo 48-4','Bobryisk','Belarys','BELARUS','213811','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 07:03:28',0,NULL,3,0,3,1,NULL,'graf131313\rRA117712555CN\r\\'),(7692,658627325001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',75.07,'hermeshine','michaelkozhin','kozhin@mail.ru','MIKHAIL KOZHIN','GRINA 30 - 65','MOSCOW','Russian Federation','RUSSIAN FEDERATION','117628','+79857634708','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 07:26:08',0,NULL,3,1,3,1,NULL,'michaelkozhin\r肩架   1\rB座   1\r大号内胆包  canon   1\rlenspen   2\rNG128    1\rRA117729431CN\r\\\r\r'),(7693,658874614001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','bryan2105','info@artover.com','Janvier Bryan','EDC<br>Riambel','Surinam','','MAURITIUS','0001','(230) 494-2793','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 07:58:51',0,NULL,3,0,2,1,NULL,'bryan2105\r\\'),(7694,768561188015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','agreis81','agreis@agreis.hu','Bela Forgo','Fóti út 122','Budapest','Budapest','HUNGARY','H-1046','36704584638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 08:56:02',0,NULL,3,0,3,1,NULL,'agreis81\rRA117729462CN\r\\'),(7695,658122636001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','makkirill','mak2do@ukr.net','Kirill Mysak','Vorovskogo st. 11A, ap.76','KIEV','','UKRAINE','04053','+380443603613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 09:09:16',0,NULL,3,1,2,1,NULL,'makkirill\r、'),(7696,658905410001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','frank8490','frank@roland.sk','Frantisek Nagel','Brezova 5','Nove Zamky','','SLOVAK REPUBLIC','94001','00421905601328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 10:17:33',0,NULL,3,1,2,1,NULL,'frank8490\r\\王'),(7697,768598276015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.62,'hutongstore','nutboy83','japarsons2@gmail.com','James Parsons-Day','47 Talavera Close<br>Old Market','Bristol','Bristol','UNITED KINGDOM','BS2 0EF','07795553030','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 11:14:20',0,NULL,3,1,2,1,NULL,'nutboy83\r庄\\'),(7698,698552458002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','istokka','admoccia@alice.it','pasquale saviano','via GRAMSCI 55','Frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 11:56:50',0,NULL,3,1,4,1,NULL,'istokka\r4灯头棚   2\r2.1\rphoto light  $22\r王\rYW864941891CN'),(7699,658935181001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','costinha50','augustoradacosta@hotmail.com','augusto ra da costa','73, Raeburn road<br>Roleystone','Perth','Western Australia','AUSTRALIA','6111','0893976725','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-11 12:10:50',0,NULL,3,1,2,1,NULL,'costinha50\r王\\'),(7700,699665912002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','karolusko1980','hogo.fogo@azet.sk','Karol Brull','Popolna 32','Bratislava','','SLOVAK REPUBLIC','83106','+421903211474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 12:19:42',0,NULL,3,1,3,1,NULL,'karolusko1980\r王\rRA117712780CN\r、'),(7701,768638283015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','capekfilip','email@capekfilip.cz','Filip Čapek','U Tesly 7','Havířov','Moravskoslezký kraj','CZECH REPUBLIC','73601','+420736272866','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-11 12:51:37',0,NULL,3,1,5,1,'CP226269170CN ','capekfilip\r庄\r'),(7702,699431351002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','hlwhitson','hlwhitson@charter.net','HAROLD WHITSON','1908 Fairway Dr','JOHNSON CITY','TN','UNITED STATES','37601-2207','(423) 929-2096','NoPaymentFailure','CheckoutComplete','Other','2011-04-11 13:10:21',0,NULL,3,1,1,1,NULL,'hlwhitson\rXL\r庄\r、'),(7703,753100149016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','david-brookes','david-brookes@supanet.com','David Brookes','24 Oakfield Close','Bolton','Lancashire','UNITED KINGDOM','BL66JR','01204690262','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 14:04:20',0,NULL,3,1,3,1,NULL,'david-brookes\r庄\rRA117712878CN\r、'),(7704,658967898001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','irenep23','ipidal@teleline.es','Irene Pidal Miranda','Martí Costa, 1, 5ºA','Palma de Mallorca','Baleares','SPAIN','07013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 14:20:25',0,NULL,3,1,2,1,NULL,'irenep23\r庄\r、'),(7705,753114420016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','harcab02','harcab02@yahoo.com','Harris Cabatingan','63 Glenhugh Park, Ahoghill','Ballymena','Antrim','UNITED KINGDOM','BT42 1LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 14:41:45',0,NULL,3,1,2,1,NULL,'harcab02\r庄\\'),(7706,658979889001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','pulleirofernando','tricolordelsur@hotmail.com','Fernando Pulleiro','6718 NW 72nd Ave<br>Miami Fl, 33166 Ste A-6702','Miami','FL','UNITED STATES','33166-3045','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 14:42:25',0,NULL,3,1,1,1,NULL,'pulleirofernando\r庄\r、'),(7707,658981808001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','arrandi001','arrandi@gmail.com','Ander Arriandiaga Laresgoiti','Zunzunegi 6<br>10º ezk.','Bilbo','País Vasco','SPAIN','48013','665723749','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 14:49:06',0,NULL,3,1,4,1,NULL,'arrandi001\rtripod  $16\rYW864941935CN\r王'),(7708,0,110671627185,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',2.25,'hermeshine','sigmadelta','busnau@hotmail.com','Stanley Pau','1630 East University Blvd.<br>University Of Arizona','Tucson','AZ','UNITED STATES','85721-0001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:05:07',0,NULL,3,1,1,1,NULL,'sigmadelta\r庄\r、'),(7709,658989308001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','alvaro19561','aneira65@yahoo.com','Alvaro Neira','340 NW 19th St<br>Apt 200','boca raton','FL','UNITED STATES','33432','(561) 929-2877','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-11 15:06:54',0,NULL,3,1,1,1,NULL,'alvaro19561'),(7710,753119148016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','gronqvist9690','gronqvist@nrdc.dk','Mogens Grønqvist','Valmuemarken 18','Fjerritslev','standard','DENMARK','9690','98213585','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 15:14:02',0,NULL,3,1,2,1,NULL,'gronqvist9690\r庄\r、'),(7711,0,110671627085,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',2.8,'hermeshine','aries_dreamer','guardgurl86@yahoo.com','Ellie Alikhani','8108 bright meadows ln','Dunn Loring','VA','UNITED STATES','22027','(703) 217-4739','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 15:20:03',0,NULL,3,1,1,1,NULL,'aries_dreamer\r庄\r、'),(7712,657055112018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',88,'photographyacc','a.vyatkin','avyatkin@mail.ru','Anton Vyatkin','Baikal\'skaya 291/2 - 21','Irkutsk','Irkutskaya obl','RUSSIAN FEDERATION','664050','+79149335500','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-11 15:52:21',0,NULL,3,1,5,1,NULL,'a.vyatkin\r2m背景架    1\r3块背景布  白  黑   灰    \r王\rCP226269197CN'),(7713,659014693001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:19:06',0,NULL,3,1,17,0,NULL,'kosowar7'),(7714,768725424015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.62,'hutongstore','mike2005walking','driving@supanet.com','Mike Hesp','1 Buttermere Close<br>Little Lever','Bolton','Lancashire','UNITED KINGDOM','BL3 1UF','01204577077','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:21:56',0,NULL,3,1,2,1,NULL,'mike2005walking\r庄、'),(7715,659016322001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','parts-auto','info@autopartsbiz.com','Lima Nuno','Av. Antero de Quental nº 86<br>monaco','Braga','Braga','PORTUGAL','4710-377','939840517','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:23:19',0,NULL,3,1,2,1,NULL,'parts-auto\r庄\r、'),(7716,699748683002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 16:23:49',0,NULL,3,1,3,1,NULL,'kosowar7\r一转四 灯头   1\r4灯头 灯头 孔     2  欧标\r申报 $40\r庄\r1.77\rRA117729842CN\r、'),(7717,768727143015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','colincooks','colin_cook@talktalk.net','colin cook','16 coltishall close','Plymouth','Devon','UNITED KINGDOM','pl5 2pa','01752362916','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 16:24:59',0,NULL,3,1,2,1,NULL,'colincooks\r刘\r、'),(7718,699757310002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','gundamseed84','ahcang@gmail.com','ang wei cang','Blk 286D Toh Guan Road #13-10','singapore','singapore','SINGAPORE','604286','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 16:44:59',0,NULL,3,1,3,1,NULL,'gundamseed84\r刘\rRA117712895CN\r、'),(7719,699766415002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rcf_1989','rcf33@hotmail.com','Rebeca Castillo','Ramón Sáez de Adana nº 7 2º izq','Santander','Cantabria','SPAIN','39006','660817133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:07:41',0,NULL,3,1,2,1,NULL,'rcf_1989\r庄、'),(7720,659035445001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:36',0,NULL,3,0,17,0,NULL,'marcelinopozo'),(7721,659033536001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:37',0,NULL,3,1,17,0,NULL,'marcelinopozo'),(7722,659033977001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:15:37',0,NULL,3,0,4,1,NULL,'marcelinopozo\r摄影背心 nikon 原厂  XL\r摄影背心 Nikon 老款   M\r摄影背心 Nikon 老款   XL\r刘\rphoto vest  $25\r2.134\rYW864941946CN'),(7723,659025474001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','isabellaisibal','isabella.allegrini@live.it','Isabella Allegrini','via Cascinetto 9 D','Cureggio','NO','ITALY','28060','348 4032674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 17:16:20',0,NULL,3,1,2,1,NULL,'isabellaisibal\r庄、'),(7724,659048325001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','mangokillers','artem.yumashev@gmail.com','Artem Yumashev','Dimitrova street 12-2-64','St. Petersburg','','RUSSIAN FEDERATION','192239','981-862-68-18','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:37:57',0,NULL,3,1,17,0,NULL,'mangokillers'),(7725,699788562002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','mangokillers','artem.yumashev@gmail.com','Artem Yumashev','Dimitrova street 12-2-64','St. Petersburg','','RUSSIAN FEDERATION','192239','981-862-68-18','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 17:58:03',0,NULL,3,1,17,0,NULL,'mangokillers\r'),(7726,699814288002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','orlando_xxx','roland.sax@hispeed.ch','Roland Sax','Sägenstrasse 107','Chur','','SWITZERLAND','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 18:40:53',0,NULL,3,1,2,1,NULL,'orlando_xxx\r庄、'),(7727,659083252001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','voodoohill','dario.m@tin.it','Dario Mollo','Via Alba, 30','BORDIGHERA','IM','ITALY','18012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 18:43:56',0,NULL,3,1,3,1,NULL,'voodoohill\r刘\r8个灯泡   1.35\rRA117712816CN'),(7728,659101075001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','wooqe','wooqe75@hotmail.com','Qi Wu','399 Bathurst St<br>Toronto Western Hospital, Room 14MP301','Toronto','ON','CANADA','M5T 2S8','(647) 863-6957','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 19:18:45',0,NULL,3,1,3,1,NULL,'wooqe\r庄\rRA117712881CN\r、'),(7729,768839860015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','markarnold74','maa13101974@yahoo.co.uk','mark arnold','27 Randolph Drive<br>Southwood','Farnborough','Hampshire','UNITED KINGDOM','GU14 0QQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 19:24:31',0,NULL,3,1,2,1,NULL,'markarnold74\r庄\\'),(7730,699845191002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','mangokillers','artem.yumashev@gmail.com','Dmitriy Rumiancev','Alpiiskii pereulok 15-1-49','St Petersburg','','RUSSIAN FEDERATION','192239','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-11 19:38:27',0,NULL,3,1,5,1,NULL,'mangokillers\r庄\r肩架    3\rCP226268832CN'),(7731,659111494001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','marioknor','mario.knor@gmail.com','Mario Knor','Vukovarska 2','Varaždin','Varaždin','CROATIA','42000','0915017137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 19:40:31',0,NULL,3,1,2,1,NULL,'marioknor\r庄\r、'),(7732,768867351015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','zenelb','zenelb@gmail.com','Zenel Batagelj','Tavcarjeva 4','Ljubljana','','SLOVENIA','SI-1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 20:05:19',0,NULL,3,1,2,1,NULL,'zenelb\r庄、'),(7733,659130167001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','matan-sabag','matansbg@gmail.com','matan sabag','chochit 12','beer sheva','south','ISRAEL','84828','054-6564-572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:12:35',0,NULL,3,1,11,1,NULL,'matan-sabag\r庄\r、'),(7734,0,120708477651,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',1.25,'hermeshine','eightball777','eightball777@sbcglobal.net','STACEY LYNN BLEVINS','4445 MCNIEL AVE','WICHITA FALLS','TX','UNITED STATES','76308-3530','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 20:24:06',0,NULL,3,1,1,1,NULL,'eightball777\r庄\r、'),(7735,753307285016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.68,'hutongstore','tallauders','msh@ms-h.demon.co.uk','Audrey Scott-Hopkins','Crows Oak<br>Crow Hill','Ringwood','Hampshire','UNITED KINGDOM','BH24 3DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 20:28:55',0,NULL,3,1,2,1,NULL,'tallauders\r庄\\'),(7736,699876742002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','apoel1977','george1977@gmail.com','George Georgiou','P.O.Box 23588','Nicosia','','CYPRUS','1685','99617323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:40:39',0,NULL,3,1,3,1,NULL,'apoel1977\r刘\rRA117712793CN\r、'),(7737,659147335001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','gildmai*210','gildmai@gmail.com','Sergey Guzev','October st. 11-23','Magnitogorsk','Chelyabinsk region','RUSSIAN FEDERATION','455023','+79068727983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-11 20:49:32',0,NULL,3,1,2,1,NULL,'gildmai*210\r庄\\'),(7738,768912594015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','our-friends-electric','andre.govia@london.com','Mr a govia','50 perrycroft<br>windsor','berkshire','Berkshire','UNITED KINGDOM','sl44he','01753683253','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-11 21:27:50',0,NULL,3,1,2,1,NULL,'our-friends-electric\r刘\\'),(7739,768929328015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',3.59,'hutongstore','ramonpastormarco','rpastor@iberdrola.es','Ramón Pastor Marco','C/ Jorge Juan, nº 37','San Vicente del Raspeig','Alicante','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-11 22:08:59',0,NULL,3,1,2,1,NULL,'ramonpastormarco\r庄\r\\'),(7740,659190598001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','jengelsmeier','blackcat1957@netscape.com','Jeanne Engelsmeier','16681 Garnet St NW','Ramsey','MN','UNITED STATES','55303','(763) 258-9093','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 23:02:31',0,NULL,3,1,1,1,NULL,'jengelsmeier\r庄\r、'),(7741,0,120708477477,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',0.99,'hermeshine','lewisville','ebay@texaspowells.org','Jeff Powell','1705 Ash ln','Corinth','Tx','UNITED STATES','76210-3106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-11 23:33:17',0,NULL,3,1,1,1,NULL,'lewisville\r庄\r、'),(7742,699948901002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','rainlook','reinlook@hotmail.com','Vladimir Luchianiuc','1816 Woodlands Dr SE','Smyrna','GA','UNITED STATES','30080-8405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 00:34:13',0,NULL,3,1,1,1,NULL,'rainlook\r刘、'),(7743,659221192001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','jlking52','jking@hhbc.com','Jenny King','500 Pepperdine Ave','Edmond','OK','UNITED STATES','73013-5456','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 01:09:29',0,NULL,3,1,1,1,NULL,'jlking52\r刘\r、'),(7744,659225593001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','receedo69','mmargeson@krrc.ns.ca','Mike Margeson','170 South Street','Berwick','NS','CANADA','B0P1E0','(902) 538-0763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:20:42',0,NULL,3,1,2,1,NULL,'receedo69\r刘\r\\'),(7745,659232941001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','gregz2008','gregor.zelle@gmail.com','Gregor Zelle','4 Jobson Avenue','Mount Ousley','New South Wales','AUSTRALIA','2519','0406780709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 01:47:18',0,NULL,3,1,3,1,NULL,'gregz2008\r是金属卡口的在白盒子里\r庄\rRA117712864CN\r、'),(7746,699994825002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','noisegenerator23','zns.photography@live.it','marco pugliese','via libero grassi, 9','palermo','PA','ITALY','90135','3881011166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 03:33:53',0,NULL,3,1,4,1,NULL,'noisegenerator23\r王\rYW864941950CN'),(7747,698893993002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','jezreex','jezreex@gmail.com','Jezreel Bago','1826 Carolann St','Pomona','CA','UNITED STATES','91766','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 04:52:58',0,NULL,3,1,1,1,NULL,'jezreex\r庄、'),(7748,700008048002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',3,'AA1103',80.4,'hermeshine','udotaty','udotati@globo.com','tatiana teixeira','av luiz aranha 890 apt 508<br>barra da tijuca cond pedra de itauna','rio de janeiro','rio de janeiro','BRAZIL','22793810','55 21 8113 1499','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 05:08:59',0,NULL,3,1,3,1,NULL,'udotaty\r庄\rRA117712776CN\r、'),(7749,700019952002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','n.c.m.2002','nmaiers@mac.com','Neil Maiers','4927 La Calandria Dr','Los Angeles','CA','UNITED STATES','90032-3329','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 05:54:55',0,NULL,3,1,1,1,NULL,'n.c.m.2002\r、'),(7750,700022987002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','valuter.ru','valuter@gmail.com','Владимир Паршин','Zvodskaya 71','c.Mayma','Respublika Altay','RUSSIAN FEDERATION','649100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 06:11:29',0,NULL,3,1,3,1,NULL,'valuter.ru\r王\rRA117712904CN\r\\'),(7751,659302276001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','barry9019','barryslade@tpg.com.au','Barry Slade','61 Mulyan st, Como','Sydney','New South Wales','AUSTRALIA','2226','0295286617','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 07:44:28',0,NULL,3,1,4,1,NULL,'barry9019\rphoto boom arm $20\r刘\rYW864941961CN'),(7752,700051969002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:18',0,NULL,3,1,3,1,NULL,'elle-ch\r庄\rRA117729992CN\r、'),(7753,700050806002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:19',0,NULL,3,1,3,1,NULL,'elle-ch\r刘 \rRA117729913CN\r、'),(7754,700051860002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','elle-ch','auktion@swisselle.ch','Michelle Brügger','Stationsstrasse 57','Embrach','','SWITZERLAND','8424','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 08:42:19',0,NULL,3,1,3,1,NULL,'elle-ch\r庄\rRA117729958CN\r、'),(7755,659319805001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','dja-u','dja-u@nm.ru','Ilia Chungurov','60 let Oktyabya d. 5, kv. 59','Simferopol','Crimea','UKRAINE','95044','380676527619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:09:03',0,NULL,3,1,3,1,NULL,'dja-u\r刘\rRA117729935CN\r、'),(7756,659321225001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','v0xff','voxtobox@gmail.com','Vova Antonyuk','Filatova 4','Lutsk','Volyn region','UKRAINE','43018','380631788440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:14:41',0,NULL,3,1,2,1,NULL,'v0xff\r庄'),(7757,697244640002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','abraaojr','abraao.junior@yahoo.com.br','Abraão Gomes Soares Jr','R. Conselheiro Lafaiete, 1977<br>apto: 1202, Sagrada Família','Belo Horizonte','Minas Gerais','BRAZIL','31035-560','+55 31 3327-8275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 09:23:55',0,NULL,3,1,2,1,NULL,'abraaojr\r刘'),(7758,769127135015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','kennyipcu','kmclellon@aol.com','Kenneth   McLennan','58 Ness Circle','Ellon','Aberdeenshire','UNITED KINGDOM','AB419BR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 10:09:22',0,NULL,3,1,2,1,NULL,'kennyipcu\r庄'),(7759,700094084002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','aleksei5425','aleksei.lang@mail.ee','Aleksei Lang','Oismae tee 109-54','Tallinn','Harjumaa','ESTONIA','13515','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 11:35:50',0,NULL,3,1,3,1,NULL,'aleksei5425\r刘\rRA117729944CN\r、'),(7760,659366396001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','crenatoycar','smelly_texta@hotmail.com','corinna conforti','57 rugby crescent<br>chipping norton','sydney','New South Wales','AUSTRALIA','2170','0297552558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 12:13:01',0,NULL,3,1,2,1,NULL,'crenatoycar\r庄'),(7761,753589900016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','rossii_91','rossii_g@abv.bg','Rossi Gencheva','6 Layosh Koshut str., ap. 5','Shumen','','BULGARIA','9700','+357-896-515-272','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 12:23:10',0,NULL,3,1,2,1,NULL,'rossii_91\r刘'),(7762,700127622002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','woodloretech','leo@woodlore.ca','Leo Fleury','160 Delta Park Blvd.','Brampton','ON','CANADA','L6T 5T6','(905) 791-9555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 13:30:56',0,NULL,3,1,3,1,NULL,'woodloretech\r庄\rRA117729927CN\r\\'),(7763,659403578001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','pas2par','paskay@bezeqint.net','GIDEON PASKAY','SHMARIAHU LEVIN 23/16','RISHON LE ZION','','ISRAEL','75278','972548110224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:14:53',0,NULL,3,1,2,1,NULL,'pas2par\r刘'),(7764,659408194001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','lau009','laurent3@gmail.com','Laurent Nangniot','rue Louis Titeca 42','Woluwe Saint Pierre','','BELGIUM','1150','0477917909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 14:29:48',0,NULL,3,1,2,1,NULL,'lau009\r庄'),(7765,769218076015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',13.64,'hutongstore','thaleinfo','t.aleziardo@gmail.com','THIBAUD ALEZIARDO','22 RUE DU GENERAL BERTRAND','PARIS','Ile-de-France','FRANCE','75007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 14:35:14',0,NULL,3,1,3,1,NULL,'thaleinfo\r王\r小号镜头筒   1\r优永佳 快门线  RE-A  1\rcanon-58mm 反接环   1\rRA117729839CN\r、\r'),(7766,659411675001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','brainquinn','quinn.b@comcast.net','Brian Quinn','3306 Charles St','Rockford','IL','UNITED STATES','61108-3746','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 14:42:07',0,NULL,3,1,1,1,NULL,'brainquinn\r庄'),(7767,659437039001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','danr1234','danr1234@comcast.net','Daniel Reynolds','1426 Orkney Dr','Leesburg','FL','UNITED STATES','34788-7642','(352) 343-1446','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 15:54:11',0,NULL,3,1,1,1,NULL,'danr1234\r刘'),(7768,700175546002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','youst75','youst@ukr.net','Yuriy Druzhinets','Lenina str., 27A-38','Tokmak','Zaporozhye region','UKRAINE','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 16:23:59',0,NULL,3,1,2,1,NULL,'youst75\r注意是2只    庄'),(7769,659461730001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','diablocds1','diablocds1@yahoo.com','christopher sisti','620 Peachtree St NE<br>Apt 1904','Atlanta','GA','UNITED STATES','30308-2381','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-12 16:58:04',0,NULL,3,1,1,1,NULL,'diablocds1\r刘'),(7770,700252415002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','user-maat-ra-63','felix-arranz-martin@hotmail.com','FÉLIX ARRANZ MARTÍN','CARRETERA DE LA GRANJA, 4<br>CONSEJERÍA DE EDUCACIÓN','COLLADO VILLALBA','Madrid','SPAIN','28400','656560066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 18:49:21',0,NULL,3,1,2,1,NULL,'user-maat-ra-63\r庄'),(7771,659498384001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','dudziakw','wdudziak@wp.pl','Wojciech Dudziak','Telimeny<br>17/32','Kraków','','POLAND','30638','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:02:19',0,NULL,3,1,17,0,NULL,'dudziakw'),(7772,700237017002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','dudziakw','wdudziak@wp.pl','Wojciech Dudziak','Telimeny<br>17/32','Kraków','','POLAND','30638','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:02:18',0,NULL,3,0,3,1,NULL,'dudziakw\r摄影背心 黑色厚 无字   XXL  1\r伟峰 717 快装板   1\r王   RA117729895CN\r、'),(7773,700271900002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:26:36',0,NULL,3,1,4,1,'YW864941876CN\r','ryrvikryrvik\r白色 1.6x2.1\r2m 架子    王\r'),(7774,700273599002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',2,'AE2308',11.6,'hermeshine','fodi64','fojola@digikabel.hu','Fodor Jozsef','Tulipan u. 1. II/8.','Bekescsaba','','HUNGARY','5600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 19:30:04',0,NULL,3,1,2,1,NULL,'fodi64\r2个    庄'),(7775,700278105002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','manakayak40','manmeryal@telefonica.net','Manuel Navarro Ballester','Calle Huelva nº 36','San Cristobal de La Laguna','Canarias','SPAIN','38205','922641123','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 19:40:33',0,NULL,3,1,3,1,NULL,'manakayak40\r刘\rRA117730001CN\r、'),(7776,700281417002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','Other','2011-04-12 19:45:18',0,NULL,3,1,17,0,NULL,'s0324\r庄'),(7777,0,110671627420,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',3.75,'hermeshine','jayredbraveman','redbraveman27@hotmail.com','Jay Reise','436 Canal Lake Rd','Blairsville','GA','UNITED STATES','30512-0249','(678) 936-7121','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 19:53:07',0,NULL,3,1,1,1,NULL,'jayredbraveman\r刘'),(7778,769402721015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','derekoo','dereko@btinternet.com','Derek Oosthuizen','DST House<br>St Marks Hill','Surbiton','Surrey','UNITED KINGDOM','KT64QD','02083995395','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-12 20:05:00',0,NULL,3,1,2,1,NULL,'derekoo\r庄'),(7779,700289636002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 20:21:12',0,NULL,3,1,17,0,NULL,'s0324\r刘'),(7780,659545039001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','Other','2011-04-12 20:21:12',0,NULL,3,0,17,0,NULL,'s0324\r庄'),(7781,700287708002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','s0324','ssykes1@hot.rr.com','Stanley Sykes','2707 Huckleberry Dr','Killeen','TX','UNITED STATES','76549','(254) 634-9468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-12 20:21:13',0,NULL,3,1,4,1,NULL,'s0324\r2m 灯架   1\r云台   1\r柔光伞   1\r防雨罩   1\r80cm 2in1 反光板   1\r摄影背心 Nikon 老款 XXL\r一票两件吧 \r lighting kit  $30    \r     刘\rYW864941865CN'),(7782,700299791002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','loro_swett','lswettn@hotmail.com','Lorenzo Swett','Duble Almeyda 1617 dpto 406-C<br>Nunoa','Santiago','Region Metropolitana, Nunoa','CHILE',' 7750097','56-998026337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 20:31:56',0,NULL,3,1,3,1,NULL,'loro_swett\r庄\rRA117729887CN\r、'),(7783,659572222001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','daredeviljohn','daredeviljohn@hotmail.com','John Gauci','10, Triq Censu Busuttil','Iklin','MLT','MALTA','BZN11','(+356) 21435755','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 20:55:37',0,NULL,3,1,3,1,NULL,'daredeviljohn\r刘\rRA117729825CN\r、'),(7784,659573280001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',3,'AA2205',10.5,'hermeshine','vildandy','daaal81@hotmail.com','Andreas Dalevik','Ällingavägen 9B<br>1317','Lund','S','SWEDEN','22734','0730821179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:01:17',0,NULL,3,1,2,1,NULL,'vildandy\r庄\r注意是3个'),(7785,659578754001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','yesse87','jesse.juhani@netti.fi','Aku Kainulainen','Myllykyläntie 99','SIUNTIO KK','','FINLAND','02570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:11:03',0,NULL,3,1,2,1,NULL,'yesse87\r刘'),(7786,659585097001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','zhalfrin85','alpayaktan@hotmail.com','Alpay Aktan','Atatürk Sitesi,Hilmi Çayıroglu Sokak 4.Blok No:2','Ankara','OranÇankaya','TURKEY','06312','+905395700108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 21:27:06',0,NULL,3,1,3,1,NULL,'zhalfrin85\r庄    RA117729811CN\r、'),(7787,769447079015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',24.2,'hutongstore','fidel.cornelis','fidel.cornelis@gmail.com','Fidel Paul Cornelis Gimenez','Calle 1º de Mayo Nº 35 , Puerta 12','Alfara del Patriarca','Comunidad Valenciana','SPAIN','46115','655829242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-12 21:29:06',0,NULL,3,1,3,1,NULL,'fidel.cornelis\r刘    注意是两个 \rRA117729900CN\r、'),(7788,700346675002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jctoletum','toletum@gmail.com','Jose Carlos Sanchez','Calle de Aragoneses, 2A<br>SELF BANK','Alcobendas','Madrid','SPAIN','28108','676325593','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-12 22:26:03',0,NULL,3,1,4,1,NULL,'jctoletum\r王\rtripod  $16\rYW864941854CN'),(7789,700351743002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','miha90','miha.horvat@gmail.com','Miha Horvat','Bevkova ulica 43','Radovljica','','SLOVENIA','4240','0038631506375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 22:43:29',0,NULL,3,1,2,1,NULL,'miha90\r刘'),(7790,659614249001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','alxg3','alxgag3@gmail.com','Alexander Vedeler','Fjellveien<br>123','Bergen','Hordaland','NORWAY','5019','+4797514080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-12 23:12:10',0,NULL,3,1,2,1,NULL,'alxg3\r庄'),(7791,700390904002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bobsgrobert','bobsg@videotron.ca','Robert Sgouromitis','5833 Crevier','Montreal','QC','CANADA','H1G 2C9','(514) 326-0949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 01:15:32',0,NULL,3,1,2,1,NULL,'bobsgrobert\r刘'),(7792,700394588002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','wenfasiluy','wenfasiluy@yahoo.com','SILVANA  DOS SANTOS','11 Pillot Pl','WEST ORANGE','NJ','UNITED STATES','07052-5205','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 01:29:47',0,NULL,3,1,1,1,NULL,'wenfasiluy\r庄'),(7793,0,110671627256,'72mm 72 mm Macro +8 Close-Up Close Up Filter',1,'AE3227',0.99,'hermeshine','1marcuss','m1569@hotmail.com','Marcus gantt','5444 Peterson Ln<br>Apt 2013','dallas','TX','UNITED STATES','75240-5129','(214) 306-4970','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 02:45:07',0,NULL,3,1,1,1,NULL,'1marcuss\r庄'),(7794,659675923001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','az626rca','77295654@tigo.com.sv','Arnoldo Zetino','Urb. San Juan Bosco, calle circunvalación, polig. C, # 20, Santa Ana<br>contiguo a piscina de Apanteos.','Santa Ana','El Salvador','EL SALVADOR','00106-8000','(503)7729-5654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 03:28:27',0,NULL,3,1,2,1,NULL,'az626rca\r刘'),(7795,657803512018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','1ronryan2','rbshav@telusplanet.net','Ron Shavchook','4412 29 Street','Edmonton','AB','CANADA','T6T1G9','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 03:54:53',0,NULL,3,1,5,1,NULL,'1ronryan2\r灯泡是110v 的\r刘\rCP226269166CN'),(7796,0,120708477611,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',1.98,'hermeshine','huaguosan','shop94556@gmail.com','K C Hua','109 Alta Mesa Court','Moraga','CA','UNITED STATES','94556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 04:36:42',0,NULL,3,1,1,1,NULL,'huaguosan\r庄'),(7797,659688522001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','green61dog','maggie_07108@yahoo.com','margaret adams','39 mead st','newark','NJ','UNITED STATES','07106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 04:41:01',0,NULL,3,1,1,1,NULL,'green61dog\r庄\r、'),(7798,0,110671627393,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',2.75,'hermeshine','camexico','partscameras@hotmail.com','juan carlos velazquez','105 E San Antonio Ave','El paso','TX','UNITED STATES','79901-1111','(915) 542-4553','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 05:02:34',0,NULL,3,1,1,1,NULL,'camexic\r庄'),(7799,769126954015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','deadline2030','kameraverleih@gmail.com','Peter A. Egger','Schuetzengasse 1','Wien','','AUSTRIA','1030','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 07:11:56',0,NULL,3,1,2,1,NULL,'deadline2030\r庄\r、'),(7800,700476495002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','pheter01','lp25@freemail.hu','Peter Lindi','Halle 7/E 2/5','Veszprem','Veszprem','HUNGARY','8200','3670-3133416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:13:27',0,NULL,3,1,2,1,NULL,'pheter01\r庄'),(7801,659732726001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','sprestoy','prestoy@yahoo.no','Ståle Prestøy','Egganvegen 33','Sjetnemarka','','NORWAY','N-7081','+47 48054144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:42:44',0,NULL,3,1,17,0,NULL,'sprestoy'),(7802,700481935002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','sprestoy','prestoy@yahoo.no','Ståle Prestøy','Egganvegen 33','Sjetnemarka','','NORWAY','N-7081','+47 48054144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 08:42:44',0,NULL,3,1,2,1,NULL,'sprestoy\r天涯方形滤镜  ND8   1\r天涯方形滤镜系列  CPL   1\r'),(7803,659739409001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','5axian','baksaj@gmail.com','János Baksa','DDRFU Maria st. 3','Pécs','Baranya','HUNGARY','7621','+36 30 496 20 32','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:12:27',0,NULL,3,1,17,0,NULL,'5axian'),(7804,700488962002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','5axian','baksaj@gmail.com','János Baksa','DDRFU Maria st. 3','Pécs','Baranya','HUNGARY','7621','+36 30 496 20 32','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:12:28',0,NULL,3,1,3,1,NULL,'5axian\r2m灯架  1\r云台    1\r柔光伞  1\r反光伞   1\rRA117729723CN\r'),(7805,700466109002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:31:16',0,NULL,3,1,17,0,NULL,'camera2171'),(7806,659715677001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:31:17',0,NULL,3,1,17,0,NULL,'camera2171'),(7807,659715022001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','camera2171','camera.sales@optusnet.com.au','Wayne Rogers','56 Easey street<br>Collingwood','Melbourne','Victoria','AUSTRALIA','3066','61394195247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 09:31:17',0,NULL,3,0,4,1,NULL,'camera2171\r十个橡胶罩 :\r62mm X4, 77mm X1, 72mm X1, 67mm X1, 58mm X1, 55 mm X1, 52mm X1\r115w 220v   2\r60cm 棚   1\rYW864941795CN\r'),(7808,754050347016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','davecrosby_uk','davecrosby@gmail.com','David Crosby','Flat 1 (Above Pizza Express)<br>1 High Street, St Martins','Stamford','Lincolnshire','UNITED KINGDOM','PE9 2LE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 09:41:41',0,NULL,3,1,17,0,NULL,'davecrosby_uk'),(7809,700496339002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','joselu_hg','jose.jhg@gmail.com','Jose Luis Hernandez','C/Marinel·lo Bosch, 39 Atc. 2ª','Terrassa','Cataluña','SPAIN','08222','937831835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 09:42:53',0,NULL,3,1,4,1,NULL,'joselu_hg\rtripod  $16\r刘\rYW864941821CN'),(7810,769652305015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','davecrosby_uk','davecrosby@gmail.com','David Crosby','Flat 1 (Above Pizza Express)<br>1 High Street, St Martins','Stamford','Lincolnshire','UNITED KINGDOM','PE9 2LE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 09:52:22',0,NULL,3,1,2,1,NULL,'davecrosby_uk\r橡胶遮光罩 52mm   2\r橡胶遮光罩 58mm  1'),(7811,700502646002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nedman29','pedro.castanheira@biocant.pt','Pedro Castanheira','Biocant - Parque Tecnologico Cantanhede<br>Nucleo 4 Lote 3','Cantanhede','Cantanhede','PORTUGAL','3060-197','(351)933303619','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 10:08:36',0,NULL,3,1,3,1,NULL,'nedman29\rRA117729785CN\r'),(7812,700518575002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','pink_rose146','k.melrose@hotmail.com','Kathleen Johns','38 Maliwa Rd','Narara','New South Wales','AUSTRALIA','2250','0422427660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 11:18:35',0,NULL,3,1,4,1,NULL,'pink_rose146\r刘\rYW864941832CN'),(7813,700540974002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','okradarko','darko.buzdon@gmail.com','Darko Buzdon','Jeretova 48','Pula','Istra','CROATIA','52100','385916121966','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:33:02',0,NULL,3,1,2,1,NULL,'okradarko\r'),(7814,659795184001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','soundofdesdoe','mathiasraulin@free.fr','mathias  raulin','94 J rue moliere','montreuil','Île-de-France','FRANCE','93100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 12:49:42',0,NULL,3,1,2,1,NULL,'soundofdesdoe\r刘'),(7815,700547581002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','roger299507','rlab@bigpond.net.au','Roger La Brooy','2, St. Johns Wood Rd','Mt. Waverley','Victoria','AUSTRALIA','3149','61438269196','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 12:56:15',0,NULL,3,1,3,1,NULL,'roger299507\rRA117729771CN\r'),(7816,659803380001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','zlobniq','p.karapetkov@gmail.com','Plamen Karapetkov','25 Tzar Asen Str.','Plovdiv','Plovdiv','BULGARIA','4000','+359885786740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 13:15:56',0,NULL,3,1,2,1,NULL,'zlobniq'),(7817,696437187002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dimauzhakov','udima@inbox.ru','Dmitriy Uzhakov','Krasnodoncev<br>49a-19','Petrozavodk','Karelia','RUSSIAN FEDERATION','185001','921-018-0800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 13:32:39',0,NULL,3,1,3,1,NULL,'dimauzhakov\r刘\rRA117729768CN\r'),(7818,769741915015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.39,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 14:02:57',0,NULL,3,1,17,0,NULL,'gordonc8193'),(7819,754131041016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','gordonc8193','gordoncooper2@sky.com','GORDON COOPER','24 WHITEBIRK ROAD','BLACKBURN','Lancashire','UNITED KINGDOM','BB13JD','01254601915','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 14:02:58',0,NULL,3,1,2,1,NULL,'gordonc8193\r接口环 55mm   1\r接口环 49mm   1\r刘'),(7820,700564963002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','andras.harman','endi22@yahoo.com','Andras Harman','Egressy tér4','Debrecen','','HUNGARY','4031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 14:03:40',0,NULL,3,1,2,1,NULL,'andras.harman'),(7821,0,110671627321,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.5,'hermeshine','swedchef13','swedchef13@hotmail.com','Cassandra Merolla','1584 Treetop Trl<br>Apt B','Akron','OH','UNITED STATES','44313-8641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:31:07',0,NULL,3,1,1,1,NULL,'swedchef13'),(7822,0,120708476589,'67mm 67 mm Macro +8 Close-Up Close Up Filter',1,'AE3226',1.25,'hermeshine','sassygirlstyles','pmd92886@gmail.com','Patrice Dwyer','18091 Debi Lane','Yorba Linda','CA','UNITED STATES','92886','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:39:06',0,NULL,3,1,1,1,NULL,'sassygirlstyles\r刘'),(7823,0,120708476177,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',2.01,'hermeshine','dabu1104','shrib2@yahoo.com','Shrichand Bathija','32512 Jean Dr','Union City','CA','UNITED STATES','94587','(510) 471-2861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:51:01',0,NULL,3,1,17,0,NULL,'dabu1104'),(7824,0,110671625537,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',2.01,'hermeshine','dabu1104','shrib2@yahoo.com','Shrichand Bathija','32512 Jean Dr','Union City','CA','UNITED STATES','94587','(510) 471-2861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 14:51:02',0,NULL,3,1,1,1,NULL,'dabu1104\r绿叶 UV             58mm   1\r绿叶近摄镜 +4  58mm    1'),(7825,659834205001,110587046983,'New Camera shoulder bag N2 for Canon with raincover',1,'AD1104',25.99,'hermeshine','amentoi54','albper@sunrise.ch','Albert Perritaz','Buchilles 46','Boudry','','SWITZERLAND','2017','0041328414860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 14:52:42',0,NULL,3,1,3,1,NULL,'amentoi54\rRA117729745CN\r\r'),(7826,754166554016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','sadegh_sh61','sadegh_sh61@yahoo.com','Mohammad Sadegh Shahrokhi-Dehkordi','34 Newmarket road,<br>Lewes Road,','Brighton','East Sussex','UNITED KINGDOM','BN2 3QF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 15:02:30',0,NULL,3,1,2,1,NULL,'sadegh_sh61'),(7827,0,110671625686,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',0.99,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 15:18:17',0,NULL,3,1,1,1,NULL,'green_dream_sky'),(7828,659847374001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1305',7.4,'hermeshine','bztina','bztina@yahoo.com','Tina Gonsman','5167 1st Rd','Lake Worth','FL','UNITED STATES','33467','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 15:29:45',0,NULL,3,1,1,1,NULL,'bztina'),(7829,659856934001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','kairimantas','mantaskairys@gmail.com','Mantas Kairys','Vandentiekio 32-16','Vilnius','Lithuania','LITHUANIA','03151','+37062577639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 15:58:52',0,NULL,3,1,2,1,NULL,'kairimantas'),(7830,520286111003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','almazkabal','bokertovstar@gmail.com','Alexandr Almazov','Shabolovka str. 65-1-35','Moscow','','RUSSIAN FEDERATION','115419','7(495)633-0038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 16:55:52',0,NULL,3,1,5,1,NULL,'almazkabal\rCP226269149CN'),(7831,659891115001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','jasperimpala','steve.harwood@tdinsurance.com','Stephen Harwood- TD Meloche Monnex','2161 Yonge Street 8th Floor','Toronto','ON','CANADA','M4S 3A6','(416) 545-6119','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 17:24:15',0,NULL,3,0,3,1,NULL,'jasperimpala\rXXXL\rRA117729710CN\r'),(7832,700649039002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','cyrilcanada','cyrilcanada@yahoo.com','Eugene Kirillov','405 Lauderdale Drive','Maple','ON','CANADA','L6A 4K9','(416) 419-7792','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 17:32:36',0,NULL,3,1,3,1,NULL,'cyrilcanada\r刘\rRA117729808CN\r'),(7833,0,120708476358,'62mm 62 mm Macro +4 Close-Up Close Up Filter',1,'AE3218',0.99,'hermeshine','austinator92','aes1992@gmail.com','Austin Smith','1708 Murray Ave','Rockdale','TX','UNITED STATES','76567-2500','(425) 953-3326','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 18:15:41',0,NULL,3,1,1,1,NULL,'austinator92'),(7834,700675045002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','rbytes1','rbytes@gmail.com','Alexander Marchukov','Koltsova str. 22','Volgograd','n/a','RUSSIAN FEDERATION','400111','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 18:27:16',0,NULL,3,1,3,1,NULL,'rbytes1\rRA117729856CN\r\r'),(7835,769886696015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',127,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 18:46:23',0,NULL,3,1,4,1,NULL,'leifs123\r（欧标）\r2mx1.6m 背景架   1\r背景布  2.1x1.6m   1白\r背景布  3x1.6m       2黑+1白\r2m灯架    2\r反光伞   2\r双头灯   2  欧标\r115w   220v  灯泡  6\r灯架包   1\rYW864941810CN\r'),(7836,754278569016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',36,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 18:46:24',0,NULL,3,1,17,0,NULL,'leifs123'),(7837,754280670016,260619309261,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 18:46:23',0,NULL,3,1,17,0,NULL,'leifs123'),(7838,700700874002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','gianfranco4222','salacius@inwind.it','Gianfranco Pistidda','via G. Deledda 167','Sassari','SS','ITALY','07100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 19:17:34',0,NULL,3,0,3,1,NULL,'gianfranco4222\rL\r刘\rRA117729666CN\r'),(7839,659943065001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','rufillo','rufillo@telefonica.net','Jose Vazquez Lopez','ACE Europe - C/ Francisco Gervas 13','Madrid','Madrid','SPAIN','28020','659347399','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 19:01:57',0,NULL,3,1,4,1,NULL,'rufillo\rYW864941843CN'),(7840,655445781018,280559946878,'Professional Photo Studio Continuous Lighting Kit boom',5,'AKT066',1000,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 21:00:23',0,NULL,3,1,12,1,' ','saud-p\r申报 lighting kit  $1000\r368752975570\rDHL: 5741518226\r'),(7841,769976994015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:40',0,NULL,3,1,17,0,NULL,'123andrewbarry'),(7842,754366486016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:41',0,NULL,3,1,17,0,NULL,'123andrewbarry'),(7843,700755690002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','lady_gris','4natasha_88@mail.ru','Головская Наталия','Набережная Авиастроителей, дом 24, кв. 139','Воронеж','','RUSSIAN FEDERATION','394004','(908)1379288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 21:12:41',0,NULL,3,1,17,0,NULL,'lady_gris'),(7844,769973807015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:41',0,NULL,3,1,17,0,NULL,'123andrewbarry'),(7845,660001171001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','lady_gris','4natasha_88@mail.ru','Головская Наталия','Набережная Авиастроителей, дом 24, кв. 139','Воронеж','','RUSSIAN FEDERATION','394004','(908)1379288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-13 21:12:41',0,NULL,3,1,2,1,NULL,'lady_gris\r绿叶 UV  52mm  1\r绿叶 UV  58mm  1\r刘'),(7846,754366703016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.39,'hutongstore','123andrewbarry','a.b.j@hotmail.co.uk','andrew barry johnson','131 southleigh road beeston','leeds','West Yorkshire','UNITED KINGDOM','ls11 5xg','01132718477','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-13 21:12:42',0,NULL,3,1,3,1,NULL,'123andrewbarry\r接口环 55mm  1\r接口环 52mm   1\r接口环 77mm   1\rcanon 大胆        1\rRA117729670CN\r'),(7847,658150466018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','jean_cf','nategrey_x@hotmail.com','Jean Carlos Farias','Domingo Lucio Farias','Sao Joao Batista','Santa Catarina','BRAZIL','88240000','(48) 3265-0722','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-13 21:17:18',0,NULL,3,1,5,1,NULL,'jean_cf\rCP226269152CN\r2m架子 白+黑  1.6x2.1'),(7848,0,110671625953,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.99,'hermeshine','chitownswifey05','want_frogs@yahoo.com','RACHEL TURNER','18811 n vemto st','MARICOPA','AZ','UNITED STATES','85138-5693','(520) 510-3072','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 21:37:58',0,NULL,3,1,1,1,NULL,'chitownswifey05'),(7849,660008645001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','loosercruiser1','eaglefilms@gmail.com','Christopher Read','15 Pointe Ln<br>Apt 1A','Cullowhee','NC','UNITED STATES','28723-5868','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-13 21:38:51',0,NULL,3,1,1,1,NULL,'loosercruiser1'),(7850,658165789018,280556434923,'Background Support & 10x20ft Green Screen LightKit 3x6m',1,'AKT065',124,'photographyacc','aatuska91','monkeyaatu@gmail.com','Aatu Keränen','Viitostie 308','Suomussalmi','','FINLAND','89600','+358405400364','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-13 21:57:27',0,NULL,3,1,4,1,NULL,'aatuska91\r欧标\rlighting kit  $38\r刘\rYW864941806CN'),(7851,0,110671625839,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',2.25,'hermeshine','mystic-ibis','saba.razvi@gmail.com','Saba Razvi','2376 Portland St<br>Apt 6','Los Angeles','CA','UNITED STATES','90007-1980','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:12:54',0,NULL,3,1,1,1,NULL,'mystic-ibis'),(7852,754396504016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 22:16:33',0,NULL,3,1,17,0,NULL,'moeras1980'),(7853,754395546016,260660054263,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','moeras1980','moeras1@hotmail.com','anton moerland','crooswijck 2','St-Annaland','','NETHERLANDS','4697 CM','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 22:16:33',0,NULL,3,1,2,1,NULL,'moeras1980\r小号灰卡   1\r爵影快门线C3    1'),(7854,700783610002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','jukkahast','jukka.hast@gmail.com','Jukka Hast','Ladamnesgatan 28','Goteborg','','SWEDEN','41679','+46707884444','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-13 22:35:23',0,NULL,3,1,3,1,NULL,'jukkahast\r刘\rRA117729754CN\r'),(7855,0,110671625921,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',1.82,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:36:06',0,NULL,3,1,17,0,NULL,'us.prolensshop'),(7856,0,120708476328,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',2.02,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-13 22:36:06',0,NULL,3,1,1,1,NULL,'us.prolensshop\r绿叶 UV  62mm   1\r绿叶 CPL  62mm   1\r庄'),(7857,754417838016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','n30filou','ath.triantafyllou@gmail.com','ATHANASIOS TRIANTAFYLLOU','21, FALIROU STREET','ATHENS','ATTIKI','GREECE','11742','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-13 23:23:40',0,NULL,3,1,2,1,NULL,'n30filou\r庄'),(7858,0,120708476210,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',1.82,'hermeshine','arbolito','virginitagarcia@hotmail.com','Virginia Pena','6730 Longmeade Ln','Orlando','FL','UNITED STATES','32822','(407) 658-0418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 00:07:37',0,NULL,3,1,1,1,NULL,'arbolito\r庄'),(7859,660068165001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Francisco alves, 222<br>Vl. dos Remédios','Osasco ','Sao paulo','BRAZIL','06296160','55-11-93530450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 01:22:11',0,NULL,3,1,3,1,NULL,'davidcinegra\r刘\rRA117729799CN\r'),(7860,700825716002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','beokiwi','churchcoaching@gmail.com','Berthold E. Olbrich','8 Gordon Craig Place<br>Algies Bay','Walkworth','','NEW ZEALAND','0920','094255996','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 01:24:43',0,NULL,3,1,6,1,NULL,'beokiwi\r刘\rEE442466372CN'),(7861,0,110671625663,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',2.52,'hermeshine','backitup','schnepfer@chartermi.net','Chris Schnepf','6317 Santa Anita dr','Saginaw','MI','UNITED STATES','48603-6176','(989) 497-0743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 01:54:46',0,NULL,3,1,1,1,NULL,'backitup\r刘'),(7862,0,120705979344,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',2.76,'hermeshine','bigb.koop','bently.kooper@hotmail.com','Bently Joiner','10013 S Maplewood Ave','tulsa','OK','UNITED STATES','74137-5541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 02:43:48',0,NULL,3,1,1,1,NULL,'bigb.koop\r刘'),(7863,660087708001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','pictureperf','photopro@aol.com','Ronald M. Witherspoon','151 Kay St','Buffalo','NY','UNITED STATES','14215','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 02:45:35',0,NULL,3,1,1,1,NULL,'pictureperf\r刘'),(7864,660104671001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',61,'hermeshine','fotofilia','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 04:26:47',0,NULL,3,1,3,1,NULL,'fotofilia\rRA117729683CN'),(7865,770113003015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','bob9038','b_alam9038@msn.com','bobby alam','44 gooseley lane','east ham','London','UNITED KINGDOM','e66ap','02085489038','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 04:53:03',0,NULL,3,1,3,1,NULL,'bob9038\r英标\rRA117729697CN'),(7866,660109819001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','kot_rrr','kotolom@gmail.com','Denis Ovchinnikov','Titova street 46','Almaty','','KAZAKHSTAN','050019','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 04:53:49',0,NULL,3,1,2,1,NULL,'kot_rrr'),(7867,660116188001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','willtipp','willtipp@hotmail.com','willie Tipp','7742 Redlands St<br>Unit D3038','playa del rey','CA','UNITED STATES','90293','(310) 488-3011','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 05:36:15',0,NULL,3,1,1,1,NULL,'willtipp'),(7868,660116514001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','shelbyappp','shelbyapp@bigpond.com','steven wright','21 Furner Ave','Camden','New South Wales','AUSTRALIA','2570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 05:47:52',0,NULL,3,1,2,1,NULL,'shelbyappp'),(7869,700883684002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kiznito','jmanuelmorante@gmail.com','jose manuel nuñez morante','pl/ jazmin nº5 6ºd','alcala de henares','Madrid','SPAIN','28803','679786781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 06:27:38',0,NULL,3,1,3,1,NULL,'kiznito\rRA117729635CN\r'),(7870,700891889002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:09:03',0,NULL,3,1,3,1,NULL,'willyodd\rRA117729533CN'),(7871,660134489001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:32',0,NULL,3,1,17,0,NULL,'dimonio08'),(7872,660133087001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:37',0,NULL,3,1,17,0,NULL,'dimonio08'),(7873,700892849002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:37',0,NULL,3,1,17,0,NULL,'dimonio08'),(7874,660133143001,110417009860,'58mm 58 mm Macro +4 Close-Up Close Up Filter',1,'AE3217',5.9,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:39',0,NULL,3,1,4,1,NULL,'dimonio08\r橡胶遮光罩 58mm   1\r绿叶 UV  58mm   1\r爵影红外 canon    1\r绿叶 CPL  58mm\r绿叶  58mm  ND8 1\r三脚架 伟峰 wf-6662A+ 6160H 球台   1\r刘\rYW864941784CN'),(7875,660132301001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 07:25:40',0,NULL,3,1,17,0,NULL,'dimonio08'),(7876,660133112001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','dimonio08','dimonio8@hotmail.com','Francisco Javier Lorca Suarez','C/. Bernat Metge 29, 1º-1ª','Inca','Baleares','SPAIN','07300','616371949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 07:25:41',0,NULL,3,1,17,0,NULL,'dimonio08'),(7877,754547180016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','tania0122','taniabanyard@rocketmail.com','tania banyard','90<br>western avenue','HERNE BAY','Kent','UNITED KINGDOM','CT6 8UF','01227370908','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 08:13:08',0,NULL,3,1,2,1,NULL,'tania0122\r'),(7878,700904892002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','maxiki1330813','homy@rambler.ru','Ryashintsev Maksim','30 let Pobedy<br>d.4, kv.40','Volgodonsk','Rostov Region','RUSSIAN FEDERATION','347381','7-928-133-08-13','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 08:28:51',0,NULL,3,1,3,1,NULL,'maxiki1330813\rRA117729290CN'),(7879,770170902015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mododorico','info@mododorico.com','Andrea Ghigliazza','Via santa caterina 26','Varazze','SV','ITALY','17019','3487333113','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 09:19:32',0,NULL,3,1,2,1,NULL,'mododorico\r申报：20$， Light Cube Box\r庄'),(7880,770207600015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','deore_g','george_karydas@yahoo.com','George Karydas','Filippou 27','Serres','Serres','GREECE','62122','+306972530977','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 11:12:42',0,NULL,3,1,3,1,NULL,'deore_g\r庄\rRA117728144CN\r'),(7881,660190317001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','kulkuri82','pasi_hartikka@yahoo.com','Pasi Hartikka','Viikinkitie 2 C 14','Vantaa','','FINLAND','01200','+358 40 534 2802','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 11:39:14',0,NULL,3,1,3,1,NULL,'kulkuri82\r接口环是52mm的\r庄\rRA117728484CN\r'),(7882,770224075015,250600475807,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','lucaseata679','lucaseata679@libero.it','melody cafè','via ruffo augusto 20','arcole','VR','ITALY','37041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 12:08:54',0,NULL,3,1,17,0,NULL,'lucaseata679'),(7883,770223914015,250600475807,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','lucaseata679','lucaseata679@libero.it','melody cafè','via ruffo augusto 20','arcole','VR','ITALY','37041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 12:08:54',0,NULL,3,1,3,1,NULL,'lucaseata679\r防寒罩   2\r申报：15$, Camera rain cover\rRA117729003CN'),(7884,660201667001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',3,'AA1214',23.94,'hermeshine','foveal','funglammd@aol.com','Fung Lam','3838 California St<br>Rm 812','San Francisco','CA','UNITED STATES','94118-1510','','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 12:19:47',0,NULL,3,1,1,1,NULL,'foveal\r徐'),(7885,754640193016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','hallbrant','markus.hallbrant@gmail.com','Dag Hällbrant','Tranbärsvägen 112','Floda','','SWEDEN','44837','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 13:25:35',0,NULL,3,1,2,1,NULL,'hallbrant\r徐'),(7886,770254570015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','chriswallace0007','jennhodges40@hotmail.com','chris wallace','20 coningsby drive','winsford','Cheshire','UNITED KINGDOM','cw74bx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 13:29:45',0,NULL,3,1,2,1,NULL,'chriswallace0007\r徐'),(7887,660222255001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','gtrsleeper','mrkissyfur@hotmail.com','chris roberts','1/10 green glen rd','ashmore','Queensland','AUSTRALIA','4214','0417411317','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-14 13:36:45',0,NULL,3,1,4,1,NULL,'gtrsleeper\r2m宽背景架   白 + 黑  1.6x2.1\r庄\rYW864941736CN'),(7888,700985240002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:41',0,NULL,3,1,17,0,NULL,'sergioaraujo2006'),(7889,660224137001,110426880442,'JJC JN-24 Neoprene Lens Case 100x240mm for 100-300 Lens',1,'AC2204',13.9,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:42',0,NULL,3,1,17,0,NULL,'sergioaraujo2006'),(7890,660223858001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','sergioaraujo2006','saraujo10@gmail.com','SERGIO ARAUJO PEREIRA','RUA TIMOTEO DA COSTA, 297 APTO. 201<br>LEBLON','RIO DE JANEIRO','RJ','BRAZIL','22450-130','552181828446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 13:47:42',0,NULL,3,1,3,1,NULL,'sergioaraujo2006\r镜头筒 小号   2\rJJC 镜头筒 JN24   1\r防雨罩     1\r庄\rRA117728475CN\r'),(7891,770271618015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','jonjg_spareparts','amazonman67@hotmail.com','Cheryl Terry','26 mallory road<br>Bishops tachbrook','Leamington spa','Warwickshire','UNITED KINGDOM','Cv339qx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 14:20:05',0,NULL,3,1,2,1,NULL,'jonjg_spareparts\r庄'),(7892,657793944001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',71.88,'hermeshine','heart.beth.ann','bskabar@gmail.com','Ed O\'Connor','PO Box 861','Talkeetna','AK','UNITED STATES','99676-0861','','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 14:33:36',0,NULL,7,0,18,0,NULL,'heart.beth.ann\r反光板 100cm x150cm   1\r反光板支架   1\r'),(7893,0,110672018345,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',2.2,'hermeshine','pramodrukshan','pramod@kandynet.net','rukshan nugaliyadda','19930 Poinciana','Redford','MI','UNITED STATES','48240-1654','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:38:28',0,NULL,3,1,1,1,NULL,'pramodrukshan\r庄'),(7894,0,120708872461,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',9.6,'hermeshine','usgrantwon','baroda1@gmail.com','Baroda Ra','12685 Germane Ave<br>Apt 12','Apple Valley','MN','UNITED STATES','55124-4375','(612) 850-2029','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:38:37',0,NULL,3,1,1,1,NULL,'usgrantwon\r庄'),(7895,0,110672018749,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',2.81,'hermeshine','cmon1988','cmon198888@yahoo.com','CRAIG ON','1638 Bayhill Drive','Oldsmar','FL','UNITED STATES','34677','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:39:57',0,NULL,3,1,17,0,NULL,'cmon1988'),(7896,660242179001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','cmon1988','cmon198888@yahoo.com','CRAIG ON','1638 Bayhill Drive','Oldsmar','FL','UNITED STATES','34677','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:46:50',0,NULL,3,1,1,1,NULL,'cmon1988\r绿叶 渐变镜 72mm\r绿叶 渐变镜 77mm   1\r庄'),(7897,0,110672018642,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',2.02,'hermeshine','fxstchip','chipwarren@sbcglobal.net','Chip T Warren','3238 Cottonwood Dr','Saint Charles','MO','UNITED STATES','63301-0108','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 14:58:06',0,NULL,3,1,1,1,NULL,'fxstchip\r庄'),(7898,701006788002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:42',0,NULL,3,1,1,1,NULL,'binhndoan\rNikon 52mm   2 \rNikon 72mm    1\rCanon 58mm   1\rCanon 72mm   1\r肩带 nikon    1\r肩带 canon    1\r肩带 pentax    1庄\r'),(7899,0,120708871976,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',1.04,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:43',0,NULL,3,1,17,0,NULL,'binhndoan'),(7900,0,110672017862,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',3.25,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:43',0,NULL,3,1,17,0,NULL,'binhndoan'),(7901,0,120708871881,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',1.25,'hermeshine','binhndoan','binh_n_doan@yahoo.com','binh doan','540 Bonita Ave<br>Spc 111','San Jose','CA','UNITED STATES','95116-3310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 14:58:44',0,NULL,3,1,17,0,NULL,'binhndoan\r'),(7902,658428687018,280522564774,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','zhychologic','zheett@hotmail.com','zhychologic Shop','P.O.Box 301<br>Pattaya Post Office','Pattaya City','Chon Buri','THAILAND','20260','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-14 15:47:17',0,NULL,5,0,18,0,NULL,'zhychologic'),(7903,660266916001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','kvpoppe','kpopplewell@gmail.com','Ken Popplewell','14007 FM 346 W','Bullard','TX','UNITED STATES','75757','(903) 258-1852','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 15:58:31',0,NULL,3,1,3,1,NULL,'kvpoppe\r刘\rRA117728467CN\r'),(7904,0,120708872033,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',1.8,'hermeshine','joyblueyes','cjperkins@att.net','Chris Perkins','1512 W Mesa Ave','Fresno','CA','UNITED STATES','93711-1942','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 16:04:05',0,NULL,3,1,1,1,NULL,'joyblueyes\r庄'),(7905,701029303002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','mauri.2010','maurizio.pellizer@gmail.com','maurizio pellizer','levja 5','Koper','slovenia','SLOVENIA','6000','0038641948989','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 16:04:27',0,NULL,3,1,3,1,NULL,'mauri.2010\r欧标\r庄\rRA117728158CN\r'),(7906,754716689016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mandygalaxy','mandywilby21@googlemail.com','Darren Law','4 ASH STREET<br>WOMBWELL','BARNSLEY','South Yorkshire','UNITED KINGDOM','S73 8EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-14 16:37:23',0,NULL,3,1,2,1,NULL,'mandygalaxy\r庄'),(7907,660281474001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','sledge99.1','carl@full-sail.com','Carl Perry','2506 Gravel Dr','Fort Worth','TX','UNITED STATES','76118-6903','(817) 975-8878','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 16:38:24',0,NULL,3,1,1,1,NULL,'sledge99.1\r庄'),(7908,660347114001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','djcowboy50','micvester@hotmail.com','Michel Sylvestre','396 Audouart','Québec','QC','CANADA','G1C 6M2','(418) 666-6548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:06:36',0,NULL,3,1,2,1,NULL,'djcowboy50\r庄'),(7909,660352803001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','ardiani2009','keni25_ch@hotmail.com','muharrem gashi','verger-rond 8','neuchatel','','SWITZERLAND','2000','0041762885785','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:18:19',0,NULL,3,1,4,1,'YW864941740CN\r','ardiani2009\r庄\r'),(7910,0,110672017824,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',3.45,'hermeshine','dherndon72','dtherndon@comcast.net','Diane Herndon','2705 Wildwood Dr','Brunswick','GA','UNITED STATES','31520-4346','(912) 230-4167','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-14 19:30:27',0,NULL,3,1,1,1,NULL,'dherndon72\r庄'),(7911,701122481002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','torpedoruso','antonio23666@hotmail.com','Antonio López','C/Ravel nº1 portal 4º 5ºA','Almeria','Andalucía Ceuta y Melilla','SPAIN','04007','679170103','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:35:48',0,NULL,3,1,3,1,NULL,'torpedoruso\r刘\rRA117728060CN\r'),(7912,701122726002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','pulleirofernando','tricolordelsur@hotmail.com','Fernando Pulleiro','25 de Mayo 635<br>Piso 6','Montevideo','','URUGUAY','11000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:36:51',0,NULL,3,1,3,1,NULL,'pulleirofernando\r庄\rRA117728073CN\r'),(7913,701123311002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gacero','gerardoacero@gmail.com','Gerardo Acero','cl81 110-34 int 8 apto 504','Bogotá D.C.','Bogotá Distrito Capital','COLOMBIA','111011','(571) 4359899','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 19:44:15',0,NULL,3,1,3,1,NULL,'gacero\r刘\rRA117728087CN\r'),(7914,769880340015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','balvess','bgalvess@gmail.com','Bruno Alves','Travessa Helena Vieira da Silva, N.º 259 – 1.6<br>4450-573','Leça da Palmeira','Matosinhos','PORTUGAL','4450-573','229982310','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:19:05',0,NULL,3,1,2,1,NULL,'balvess\r刘'),(7915,769589934015,250692242373,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',134.4,'hutongstore','lorenzofinanziere','caravellolorenzo@libero.it','gruppo cineamatori delle apuane','via pascoli 17','carrara','MS','ITALY','54033','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:27:43',0,NULL,3,1,17,0,NULL,'lorenzofinanziere\r刘'),(7916,0,110672018581,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',2.25,'hermeshine','us.prolensshop','usprolensshop@threee.com','Ann Marie Peter Schenk','3895 Clairemont Dr<br>Ste B-218','San Diego','CA','UNITED STATES','92117-5833','(858) 483-1909','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-14 20:39:27',0,NULL,3,1,1,1,NULL,'us.prolensshop\r庄'),(7917,754851672016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',3.58,'hutongstore','davidclimb85','david.toncic@gmail.com','David Tončič','Tomšičeva 17/B','Idrija','Slovenia','SLOVENIA','0386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-14 20:41:17',0,NULL,3,1,2,1,NULL,'davidclimb85\r(包装前仔细检查一下货)\r刘'),(7918,770470116015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0001',150,'hutongstore','lorenzofinanziere','caravellolorenzo@libero.it','gruppo cineamatori delle apuane','via pascoli 17','carrara','MS','ITALY','54033','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-14 20:43:09',0,NULL,3,1,4,1,'YW864941751CN ','lorenzofinanziere\rNIKON 镜头盖 67mm    1\r三脚架 伟峰 EI-717    1\r2mX3m背景架   1\r2m 灯架   2\r2mX3m 背景布（绿）   1\r115w 220v 灯泡   2\r50x70  棚 欧标   2\r灯架包   1\r刘\rtripod $25\r'),(7919,701155382002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','heleenab','heleenrink@wanadoo.nl','Rink Post Tanktransporten B.V.','Vaart zz 124','Appelscha','','NETHERLANDS','8426 AL','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 20:48:36',0,NULL,3,0,3,1,NULL,'heleenab\rXL\r庄\rRA117728135CN\r\r'),(7920,660396690001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','esmemou','esmemou@hotmail.com','E Pugh c/o M Traverzo','2114 Farrington Street','Dallas','TX','UNITED STATES','75207','2812366895','NoPaymentFailure','CheckoutComplete','Other','2011-04-14 20:56:52',0,NULL,3,1,1,1,NULL,'esmemou\r庄'),(7921,660397071001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','janka90125','90125@chello.sk','Marek Smatrala','Soltesovej 32','Bratislava','Bratislava','SLOVAK REPUBLIC','81108','+00421905923198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-14 20:58:09',0,NULL,3,1,2,1,NULL,'janka90125\r刘'),(7922,660399966001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','scream2525','christianvall6@hotmail.com','FCO. JAVIER MARTINEZ FARALDO','c/ RODODENDRO, 82-84','RIVAS-VACIAMADRID','Madrid','SPAIN','28522','665649056','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 21:07:44',0,NULL,3,1,4,1,NULL,'scream2525\r刘\rYW864941762CN\r'),(7923,660403938001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-14 21:26:02',0,NULL,3,1,3,1,NULL,'leofotografias\r刘\rRA117728127CN\r'),(7924,660461895001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:03:02',0,NULL,3,1,17,0,NULL,'dvdguychatter2\r刘'),(7925,660464907001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:15:01',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r刘\r爵影红外 5 in 1   1\rGGS 550D    1'),(7926,660465843001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','10marinkangel','marinkangel@yahoo.com','marishka karamyan','35 esterbrooke ave apt 809','north york','ON','CANADA','m2j 2c5','(416) 826-4184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 01:19:10',0,NULL,3,1,2,1,NULL,'10marinkangel\r庄'),(7927,659605855001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',22.99,'hermeshine','olinghouse','scott@minerslunchbox.com','Miner\'s Lunchbox','5655 Riggins Ct<br>Ste 15','Reno','NV','UNITED STATES','89502-6565','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 01:46:42',0,NULL,3,1,1,1,NULL,'olinghouse\r庄'),(7928,660475747001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','diggindiogi','joebrenckman@comcast.net','Joseph Brenckman','300 W Price St','Linden','NJ','UNITED STATES','07036','(908) 590-4512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 01:57:28',0,NULL,3,1,1,1,NULL,'diggindiogi\r庄'),(7929,660485603001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','mtgravy','garvinweb+ebay@gmail.com','Lisa Sung','222 Rainbow Pl','Milpitas','CA','UNITED STATES','95035-8751','(613) 366-8882','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:42:42',0,NULL,3,1,1,1,NULL,'mtgravy\r刘'),(7930,660486518001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','curtissp6e','jimaroc@cox.net','Jim Cady','2671 Nye Street','Henderson','NV','UNITED STATES','89074','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 02:44:05',0,NULL,3,1,1,1,NULL,'curtissp6e\r刘'),(7931,701257019002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','topgumf16','topgum@gmail.com','Raymond M Klein','400 Morgan St','Suisun City','CA','UNITED STATES','94585-2841','707 399 9318','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 02:55:42',0,NULL,3,1,3,1,NULL,'topgumf16\r50-70柔光棚 通用塑料卡口  1\r1.6x2.1m 背景布 黑色   1\rRA117728113CN\r'),(7932,660487843001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','topgumf16','topgum@gmail.com','Raymond M Klein','400 Morgan St','Suisun City','CA','UNITED STATES','94585-2841','707 399 9318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 02:55:42',0,NULL,3,0,17,0,NULL,'topgumf16'),(7933,0,110672017789,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT054',2.55,'hermeshine','ungvs','ung88@yahoo.com','victor Ung','10041 bismark dr','Huntington beach','CA','UNITED STATES','92646-3701','(714) 372-2766','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 03:05:59',0,NULL,3,1,1,1,NULL,'ungvs'),(7934,701267095002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','gil*riodejaneiro','gilmardamasio1@hotmail.com','gilmar damasio','Av. José Mendonça de Campos 101<br>Bairro Mutondo','São Gonçalo','Rio de Janeiro','BRAZIL','24450265','(021)2601-2578','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 03:40:48',0,NULL,3,1,3,1,NULL,'gil*riodejaneiro\rRA117728498CN\r'),(7935,0,120708477793,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',2.26,'hermeshine','chadwick9.9','gemini9.9@netzero.com','chad coots','3088 Wadsworth Rd<br># 4','norton','OH','UNITED STATES','44203-5265','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 04:00:18',0,NULL,3,1,1,1,NULL,'chadwick9.9\r刘'),(7936,770444853015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sakaedor','danitower@hotmail.com','Juan Daniel Bello Cano','c/Escota, 1<br>Cádiz','Rio San Pedro (Puerto Real)','Andalucía Ceuta y Melilla','SPAIN','11519','607957933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 04:27:54',0,NULL,3,1,2,1,NULL,'sakaedor\r刘'),(7937,660512561001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','jpvillaverde','jpablo@omnisciens.com','Juan Pablo Villaverde','Riobamba 1914 Dto 1','Rosario','Santa Fe','ARGENTINA','2000','(0341) 155209165','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 05:09:07',0,NULL,3,1,2,1,NULL,'jpvillaverde\r刘'),(7938,770650506015,250692241383,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','nagydarab10','nagydarab2@gmail.com','Róbert Vancsura','Közvágóhíd utca 7','Budapest','','HUNGARY','1151','0036303117788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 07:08:52',0,NULL,3,1,3,1,NULL,'nagydarab10\rRA117728095CN\r'),(7939,701306131002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','bigdavemc08','barwickdavid96@yahoo.com','david barwick','11517 Windcrest Ln','san diego','CA','UNITED STATES','92128-6409','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-15 07:26:26',0,NULL,3,1,1,1,NULL,'bigdavemc08'),(7940,701318275002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','nikki355','nikkihaskell355@msn.com','Nicole Haskell','21 Bunker Ave','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 08:33:30',0,NULL,3,0,3,1,NULL,'nikki355\r绿色\rRA117728507CN'),(7941,701326271002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:08:49',0,NULL,3,1,17,0,NULL,'thealmightybenwa'),(7942,660554299001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',5,'AA1304',12.2,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:08:53',0,NULL,3,1,17,0,NULL,'thealmightybenwa'),(7943,660552885001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 09:08:55',0,NULL,3,1,17,0,NULL,'thealmightybenwa'),(7944,701324893002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:09:06',0,NULL,3,1,17,0,NULL,'thealmightybenwa'),(7945,660554514001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',8.9,'hermeshine','thealmightybenwa','february_6th@hotmail.com','Benny Southall','6 Spowers Cicruit','Holder','Australian Capital Territory','AUSTRALIA','2611','0262888391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:09:16',0,NULL,3,1,3,1,NULL,'thealmightybenwa\rlenspen   2\rCANON 镜头盖  77mm   5\r摄影背心 黑色薄 canon  XL  1\r防寒罩   1\r肩带 canon   1\rRA117728419CN\r'),(7946,770685082015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','dubby66','dubstemp@hotmail.co.uk','Jonathan Stemp','17 Muirfield Road','Woking','Surrey','UNITED KINGDOM','GU213PW','01483828267','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 09:16:45',0,NULL,3,1,2,1,NULL,'dubby66'),(7947,660556921001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bluesmansur','ramrif@hotmail.com','Ramón Rivera Freire','San Antonio,6 1º C','ALGECIRAS','Cadiz','SPAIN','11201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 09:21:28',0,NULL,3,1,2,1,NULL,'bluesmansur'),(7948,770702502015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lajos.andrejkovics','lajos@grandiflorum.net','IBM ISC - Lajos Andrejkovics','Apollo Business Centre II<br>Mlynske nivy 49','Bratislava','','SLOVAK REPUBLIC','82109','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 10:15:55',0,NULL,3,1,2,1,NULL,'lajos.andrejkovics\r刘'),(7949,701345824002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','chickiecyk','cynthia.y.kam@gmail.com','Cynthia Kam','po box 11','east Kew','Victoria','AUSTRALIA','3102','0403082365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 10:37:11',0,NULL,3,1,2,1,NULL,'chickiecyk\r庄'),(7950,701352825002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','zamirram55','zamirram@gmail.com','Rami zamir','Yasur 25','arad','IL','ISRAEL','89078','0546703723','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 11:04:31',0,NULL,3,1,3,1,NULL,'zamirram55\r欧标\r庄\rRA117728780CN\r'),(7951,660592763001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','b_usher','busher04@aim.com','Brandon Usher','2092 S Potter Rd','Lancaster','SC','UNITED STATES','29720-7664','(803) 804-7834','NoPaymentFailure','CheckoutComplete','Other','2011-04-15 11:53:09',0,NULL,3,1,1,1,NULL,'b_usher\rM\r庄'),(7952,701365629002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','rcares','rodolfo.cares@gmail.com','Rodolfo Cares Moreno','Pasaje Dos 2862','Independencia','Metropolitana','CHILE','8380730','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 11:58:24',0,NULL,3,1,3,1,NULL,'rcares\r刘\rRA117728745CN\r'),(7953,755151502016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',6.1,'hutongstore','scotty.robson','scotty@clanrobson.co.uk','Scott Robson','Orange (PB-G-080)<br>The Point, 37 North Wharf Road','Paddington','London','UNITED KINGDOM','W2 1AG','07896567106','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-15 14:10:19',0,NULL,3,1,2,1,NULL,'scotty.robson\r庄'),(7954,0,110672018282,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',3.54,'hermeshine','dandwjones','debrakay2006@aol.com','Debra Jones','7620 Opal Rd','Warrenton','VA','UNITED STATES','20186-8679','(540) 347-5714','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-15 14:17:08',0,NULL,3,1,1,1,NULL,'dandwjones\r庄'),(7955,660638371001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','gambitsworld65','microshitcankissmyhairywhitebutt@hotmail.com','ian MacDonald','#102 10505 70ave','Edmonton','AB','CANADA','t6h2g1','(780) 436-7512','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 14:32:18',0,NULL,3,1,3,1,NULL,'gambitsworld65\r刘\rRA117728569CN'),(7956,770778738015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:43',0,NULL,3,1,17,0,NULL,'akim_s'),(7957,770777690015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:43',0,NULL,3,1,17,0,NULL,'akim_s'),(7958,755144747016,260660055262,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',8,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:45',0,NULL,3,1,17,0,NULL,'akim_s'),(7959,770771126015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',12.2,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 14:35:44',0,NULL,3,1,3,1,NULL,'akim_s\r倒影板（白黑）   1\r45w 5500k 灯泡  2\r80cm  2in1   1\r双灯头   欧标  1  庄\rRA117728541CN\r\r'),(7960,770428541015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','akim_s','akimaso@googlemail.com','Tomas Mika','Mlynska 1179/8','Cesky Tesin','','CZECH REPUBLIC','73701','00420723266304','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-15 14:35:44',0,NULL,3,1,3,1,NULL,'akim_s\r柔光伞——换成——银光伞\r庄\rRA117728714CN\r'),(7961,701417035002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','jaroslawkurek','jaroslaw.kurek@poczta.neostrada.pl','Jarosław Kurek','Kalinowa 1<br>skr.poczt. 84','Nadarzyn','mazowieckie','POLAND','05-830','22 7398568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:53:07',0,NULL,3,1,2,1,NULL,'jaroslawkurek\r庄'),(7962,660641265001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 14:53:22',0,NULL,3,1,2,1,NULL,'salmon404\r刘'),(7963,753670649016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','jmtriky','fuentesjm2002@yahoo.es','Jose Manuel Fuentes Canalejo','Marcenado, 20  3-D','Madrid','Madrid','SPAIN','28002','669170417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 15:21:17',0,NULL,3,1,3,1,NULL,'jmtriky\r庄\rRA117728538CN'),(7964,660655225001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','denjigunoff','jigunoff@tut.by','Denis Jigunoff','ul. Prushinskih<br>dom 12 kv. 2','Minsk','Minsk','BELARUS','220112','375298624942','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 15:24:59',0,NULL,3,1,3,1,NULL,'denjigunoff\r庄\rRA117728609CN'),(7965,660658966001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dherrymar','herrymar@hotmail.com','DAVID HERRAIZ MARTINEZ','CALLE RAMON Y CAJAL 28, LA CAIXA, CUARTE DE HUERVA','ZARAGOZA','Aragón','SPAIN','50410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 15:38:15',0,NULL,3,1,2,1,NULL,'dherrymar\r庄'),(7966,660575408001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 16:03:39',0,NULL,3,1,2,1,NULL,'frankedisson\r欧标\r刘'),(7967,755226718016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vicaraucaria','vitorutad@gmail.com','Vítor da Cunha','Avenida Padre António Carneiro, nº200','Areosa-','Viana do Castelo','PORTUGAL','4900-590','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 17:12:46',0,NULL,3,1,2,1,NULL,'vicaraucaria\r庄'),(7968,701470306002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','alimov2007','naalimov@yahoo.com','Alimov Oleg','Berliner str.27 B','Wittenberg','','GERMANY','06886','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 17:25:46',0,NULL,3,1,3,1,NULL,'alimov2007\r庄\r、'),(7969,701477251002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','russian727','amalykhin@earthlink.net','Subhon Khodjaev','Saharov 11/2 kv 10','Kishinev','','MOLDOVA, REPUBLIC OF','2024','(373) 692-5278 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 17:43:33',0,NULL,3,1,3,1,NULL,'russian727\r刘\rRA117728515CN'),(7970,701490872002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','peteart','peteart2@yahoo.com','Peter Kober','138 Rose Haven Rd','Somers','CT','UNITED STATES','06071-1215','(860) 698-6746','NoPaymentFailure','CheckoutComplete','Other','2011-04-15 18:15:32',0,NULL,3,1,1,1,NULL,'peteart\r庄'),(7971,660737367001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','severinkaradzhov12','cccp0887@gmail.com','severin karadzhov','61A block, floor 5, apt.511 Studentski grad distr.','Sofia','Bulgaria/Sofia/Sofia','BULGARIA','1700','0897811819','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 18:57:47',0,NULL,3,1,2,1,NULL,'severinkaradzhov12\r.庄'),(7972,701511091002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','viktorpro','alouds@yandex.ru','Viktor Prokopishen','ul. Lenina, dom 8, kv. 115','Komsomolsk','Poltavskaya oblast','UKRAINE','39800','380676014720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 19:00:40',0,NULL,3,1,2,1,NULL,'viktorpro\r庄'),(7973,660770717001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','m.petrosyan','valyagharibyan@rambler.ru','Valentina Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','055101565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 20:18:25',0,NULL,3,1,2,1,NULL,'m.petrosyan\r刘'),(7974,701571018002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','faustm01','faustm@uol.com.br','Marcelo Faustino','Rua Duque Costa, 495 apto 52 Bloco 4<br>Jd Marajoara','São Paulo','São Paulo','BRAZIL','04671-160','55 11 81798694','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 21:29:03',0,NULL,3,1,5,1,NULL,'faustm01\r欧标\r刘\rCP226269121CN\r需邮件'),(7975,770996801015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','daminimandan','dan_bird2003@hotmail.com','Dan bird','251 scartho road<br>scartho','grimsby','Lincolnshire','UNITED KINGDOM','dn332ea','01472328749','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-15 21:34:10',0,NULL,3,1,4,1,NULL,'daminimandan\r庄\rYW864941655CN'),(7976,701575634002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','mannavis','manavisk@hotmail.com','Mannavis Kostas','136 Papanikolaoy st.','Thessaloniki','Thessaloniki','GREECE','57010','+306978102100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-15 21:41:59',0,NULL,3,1,2,1,NULL,'mannavis\r庄'),(7977,771009334015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','vencaxxx','v.vesely@centrum.cz','Václav Veselý','Blatenská 4020','Chomutov','','CZECH REPUBLIC','43003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-15 22:03:02',0,NULL,3,1,2,1,NULL,'vencaxxx\r刘'),(7978,701599633002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sabnton','tlavin1@telus.net','Tony Lavin','859 165a st','Surrey','BC','CANADA','V4A9C4','(778) 686-9520','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-15 23:12:42',0,NULL,3,1,3,1,NULL,'sabnton\r庄\rRA117728524CN'),(7979,755418477016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','hayder_123','rizjani@hotmail.com','rizwan sheikh','1 cowell way','blackburn','Lancashire','UNITED KINGDOM','bb2 1qz','01254581577','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 00:50:49',0,NULL,3,1,2,1,NULL,'hayder_123\r庄'),(7980,701623556002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','hwanggoh','hwanggoh79@yahoo.com','chen hwang goh','G190, Lrg33, Tmn Sejati Indah<br>Sungai Petani,','sungai petani','Kedah','MALAYSIA','08000','012-4933020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 00:56:03',0,NULL,3,1,2,1,NULL,'hwanggoh\r庄'),(7981,701624366002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','francisco_bs','franciscobs@gmail.com','Francisco Batalla Sánchez','C/ Villardondiego 23, 2º-B','Madrid','Madrid','SPAIN','28032','687993669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 00:59:39',0,NULL,3,1,4,1,NULL,'francisco_bs\r2套 \rlighting kit  $20\r庄\rYW864941666CN'),(7982,660887351001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','carmellino','carmel_mallia196@hotmail.com','Carmel Mallia','35 st anthony street','Zebbug','europe','MALTA','Zbg 2233','+35621467464','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 04:30:32',0,NULL,3,0,17,0,NULL,'carmellino'),(7983,701668210002,120439964418,'MACRO CLOSE UP Filter Lens kit +2 +3 +4 +8 40d d80 d90',1,'AKT012',23.6,'hermeshine','carmellino','carmel_mallia196@hotmail.com','Carmel Mallia','35 st anthony street','Zebbug','europe','MALTA','Zbg 2233','+35621467464','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 04:33:12',0,NULL,3,1,3,1,NULL,'carmellino\r67mm +2 +3 +4 +8    1\r+4如果没有了，发67mm cpl\r摄影背心 Nikon 老款  XL  1\r庄\rRA117728590CN\r'),(7984,771144167015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','niksahdus','nv.partanen@gmail.com','Niko Partanen','Kauppakatu 15 B 30','Jyväskylä','Keski-Suomi','FINLAND','40100','0408391457','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-16 07:08:22',0,NULL,3,1,2,1,NULL,'niksahdus\r刘'),(7985,660921008001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fahimul277','fahimul27@gmail.com','Fahimul Hoque','10 Tuxedo Court<br>Apt 314','Scarborough','ON','CANADA','M1G3S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 07:45:08',0,NULL,3,1,2,1,NULL,'fahimul277\r庄'),(7986,771178246015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sakaedor','danitower@hotmail.com','Juan Daniel Bello Cano','c/Escota, 1<br>Cádiz','Rio San Pedro (Puerto Real)','Andalucía Ceuta y Melilla','SPAIN','11519','607957933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-16 09:20:45',0,NULL,3,1,2,1,NULL,'sakaedor\r刘'),(7987,701722306002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','absancakli16','absancakli@msn.com','Abdüsselam Sancaklı','Dr. İsmail Niyazi Kurtulmuş Ögrenci Yurdu Topkapı Mah.<br>Kahılbağı sokak. No:3','Istanbul','Fatih','TURKEY','34093','905068499460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 09:24:29',0,NULL,3,1,2,1,NULL,'absancakli16\r刘'),(7988,660950589001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','olimax60','oliveh@scarlet.be','Olivier Hennebert','20 Place de la gare','Bruxelles','','BELGIUM','1150','0486463907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 09:54:15',0,NULL,3,1,3,1,NULL,'olimax60\r申报：  microphone  $15\r庄\rRA117728612CN\r'),(7989,660960860001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','kasem001','kasemc@gmail.com','Kasem Chaisukpirom','205/125 Pattanakarn Road<br>Prawet','Bangkok','','THAILAND','10250','66-81-423-2847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 10:41:10',0,NULL,3,1,11,1,NULL,'kasem001\r72mm接口环  1\r托架  1\rND8   1'),(7990,701757202002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','eyalwaiss1','eyalwaiss@gmail.com','eyal waiss','Mordehai Elkahi 532/5','jerusalem','israel','ISRAEL','93807','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 11:44:10',0,NULL,3,1,3,1,NULL,'eyalwaiss1\rRA117728728CN\r'),(7991,660974769001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','denfilyukov','lokystaff@mfilm.ru','Denis Filyukov','Eniseyskaya str.17-1-77','Moscow','','RUSSIAN FEDERATION','129327','+79255026348','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 11:31:00',0,NULL,3,1,3,1,NULL,'denfilyukov\r庄\rRA117728688CN\r'),(7992,660998656001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','mecklaowd87','mecklaowd@gmail.com','Hassan Maklada','mail box - 5625','Daliat El Carmel','','ISRAEL','30056','0578165062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 12:55:01',0,NULL,3,1,11,1,NULL,'mecklaowd87\r'),(7993,701782058002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','photoshopix','photoshopix@hotmail.com','yves cambier','terkammenstraat 1','bogaarden','','BELGIUM','1670','023803424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:14:25',0,NULL,3,1,2,1,NULL,'photoshopix\r庄'),(7994,661017732001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','keonigmann','kodzo@list.ru','Anton Negonov','Artilleriyskaya 56-119','Kaliningrad','','RUSSIAN FEDERATION','236016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 13:55:44',0,NULL,3,1,2,1,NULL,'keonigmann\r庄'),(7995,661027539001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.55,'hermeshine','pepsi_cola747','carol_mcallister_@hotmail.com','Carol McAllister','36 Alex Avenue','Wheelers Hill','Victoria','AUSTRALIA','3150','0395748271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:26:17',0,NULL,3,1,17,0,NULL,'pepsi_cola747'),(7996,661029303001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.87,'hermeshine','pepsi_cola747','carol_mcallister_@hotmail.com','Carol McAllister','36 Alex Avenue','Wheelers Hill','Victoria','AUSTRALIA','3150','0395748271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:31:29',0,NULL,3,1,2,1,NULL,'pepsi_cola747\r52mm 接口环  1\r55mm 接口环  1\r托架   1\r刘'),(7997,701813798002,120642963815,'Photography Telescopic Background  Cross Bar 10ft 3m',1,'AO0012',45,'hermeshine','willyodd','willy.kommedal@gmail.com','Willy Odd Kommedal','Tomasbakken 8','Hundvaag','Rogaland','NORWAY','4085','+4790980860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 14:46:56',0,NULL,3,1,3,1,NULL,'willyodd\r刘\rRA117728759CN\r'),(7998,661066396001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','brada113','zlatko.srbeli@ka.htnet.hr','Zlatko Srbelj','Zagrebacka 35','Velika Gorica','','CROATIA','10410','+385916225795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:11:34',0,NULL,3,0,2,1,NULL,'brada113\r渐变红   1\r庄'),(7999,701850243002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','hantolic','hrvoje.antolic@gmail.com','Hrvoje Antolic','Hrvoja Macanovica 11','Zagreb','','CROATIA','10000','+(385)91-2410642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 16:30:41',0,NULL,3,1,2,1,NULL,'hantolic\r庄'),(8000,771349233015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','shahrouz.z','shahrouz_shz@yahoo.com','Mr Shahrouz Zanganeh','57 Rozel Square','Manchester','Lancashire','UNITED KINGDOM','M3 4FQ','01612798681','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 16:38:02',0,NULL,3,1,2,1,NULL,'shahrouz.z\r庄'),(8001,0,110672018144,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',1.98,'hermeshine','simoncifer','simonhfu@netscape.net','Simon Fu','5120 Kauffman Ave','Temple City','CA','UNITED STATES','91780-3945','(626) 287-6274','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 18:21:01',0,NULL,3,1,1,1,NULL,'simoncifer\rsony 肩带   1\r52-canon 反接环   1\r庄'),(8002,771409544015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','decethymnus','pekimworthy@btinternet.com','Peter Kenworthy-Browne','The Old Vicarage','Staverton','Northamptonshire','UNITED KINGDOM','NN11 6JJ','01327704667','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 18:25:03',0,NULL,3,1,2,1,NULL,'decethymnus\r庄'),(8003,661147306001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','alberbond','alberbond@eresmas.com','Alberto Fernandez Gonzalez','paseo de la Florida 40-5A','Oviedo','Asturias','SPAIN','33012','984189588','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 19:14:35',0,NULL,3,1,4,1,NULL,'alberbond\rtripod  $20\r庄\rYW864941670CN'),(8004,701960202002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','rentavet1','rentavet@zoominternet.net','John M Jones','PO Box 488<br>Baker Animal Hospital','Clark','PA','UNITED STATES','16113-0488','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-16 20:29:03',0,NULL,3,1,1,1,NULL,'rentavet1\r庄'),(8005,661190680001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','senaystar','vanovanya@bigmir.net','Semen Starzhinskiy','Gogolya street<br>dom 78 kvartira 57','boyarka','Kiyvska oblast','UKRAINE','08150','(063)310-0686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 20:58:00',0,NULL,3,1,3,1,NULL,'senaystar\r庄\rRA117728691CN\r'),(8006,755859949016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','sorry-to-see-it-go','coldcurry@hotmail.co.uk','Dominic Kerridge','76 Lower Oldfield PARK','Bath','Somerset','UNITED KINGDOM','ba2 3hp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-16 21:36:56',0,NULL,3,1,2,1,NULL,'sorry-to-see-it-go\r庄'),(8007,701985933002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','1619bison','siso_2000@yahoo.com','Peter Chen','TH15 - 6063 Iona Drive','Vancouver','BC','CANADA','V6T 0B1','(604) 210-0185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 21:38:38',0,NULL,3,1,2,1,NULL,'1619bison\r庄'),(8008,521266708003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','soloilfatolivinse011','soloilfatolivinse@hotmail.it','massimo stefanelli','strada camporelle 19','nole','TO','ITALY','10076','011 9297991','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:03:16',0,NULL,3,1,2,1,NULL,'soloilfatolivinse011\r庄'),(8009,701995040002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','pavelpervushin','pspervushin@gmail.com','Pavel Pervushin','Voznesenskaya 80a-27','Sergiev Posad','','RUSSIAN FEDERATION','141300','8-926-5548066','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-16 22:06:20',0,NULL,3,1,5,1,NULL,'pavelpervushin\r欧标\r刘\rCP226269118CN'),(8010,661223973001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','oddjohan2004','odd.lundberg@odont.uib.no','Odd Johan Lundberg','Erdalsveien 41','Erdal','','NORWAY','5306','+4790192671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-16 22:28:00',0,NULL,3,1,2,1,NULL,'oddjohan2004\r庄'),(8011,702045912002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','jazz_papa','uflathm@cpcus.jnj.com','Ullrich Flathmann','310 Tyler Court','New Hope','PA','UNITED STATES','18938','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 01:18:27',0,NULL,3,1,1,1,NULL,'jazz_papa\r庄'),(8012,661312823001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','chevelleboy_67','chevelleboy_67@yahoo.com','Breck Byington','PO Box 335<br>6935 N 2500 W','Honeyville','UT','UNITED STATES','84314-0335','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 05:16:52',0,NULL,3,1,1,1,NULL,'chevelleboy_67\r庄'),(8013,702097374002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','clkuv','valpaso@fastwebnet.it','Valle Luca','VIA Maestro Martino  7','VERONA','VR','ITALY','37131','+393495574380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 05:50:55',0,NULL,3,1,2,1,NULL,'clkuv\r庄'),(8014,661350590001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','polarfoxi','polarfox@polarfox.net','Mikko Ruohola','Kulmalantie 1 A 3','Vanha-Ulvila','','FINLAND','28450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:15:38',0,NULL,3,1,2,1,NULL,'polarfoxi\r刘'),(8015,771694362015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lilutchm','lilutch@hotmail.com','Lillo Mendola','Rue des liégeois 11','Bruxelles','','BELGIUM','1050','02-6475218','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 08:26:44',0,NULL,3,1,2,1,NULL,'lilutchm\r庄'),(8016,702139786002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:44:44',0,NULL,3,1,17,1,NULL,'phylax57\r庄'),(8017,702141201002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:48:08',0,NULL,3,1,17,0,NULL,'phylax57'),(8018,702142179002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','phylax57','amann.fr@libertysurf.fr','françois amann','1,rue des vignobles','BLIESBRUCK','Lorraine','FRANCE','57200','03.87.02.34.47','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 08:52:08',0,NULL,3,1,3,1,NULL,'phylax57\r72mm 接口环   1\r托架  1\r渐变蓝   1\rCPL   1\r刘\rRA117728436CN\r'),(8019,702171771002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','sandro1w','sandro1w67@hotmail.it','Giusy Grasso','via catania 18','floridia','SR','ITALY','96014','3358266652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:17:36',0,NULL,3,1,2,1,NULL,'sandro1w\r庄'),(8020,702172688002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','hockey_guy99','galway.brendan@gmail.com','Brendan Galway','15 Atlantic Place','Beaumont Hills','New South Wales','AUSTRALIA','2155','61437856783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 10:18:51',0,NULL,3,1,2,1,NULL,'hockey_guy99\r刘'),(8021,659641590018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','usk1877','ukhan@orangemodels.ca','Usman Khan','111 Peter Street, Suite 107','Toronto','ON','CANADA','M5V2H1','(416) 830-9039','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-17 11:09:53',0,NULL,3,1,5,1,NULL,'usk1877\r灯泡是110v的\r刘\rCP226269135CN\r需邮件\r'),(8022,771769013015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',18.5,'hutongstore','rok_pop','rok.popovic@gmail.com','Rok Popovič','Pot k cuvajnici 9','Vnanje Gorice','','SLOVENIA','1351','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 11:17:18',0,NULL,3,1,3,1,NULL,'rok_pop\r庄\rRA117728731CN\r'),(8023,661427396001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','micmoo2005','mic.moo.2005@gmail.com','Michinori Mouri','Hamanomiya 171-1','Nachikatuurachou  Higashimurogun','Wakayama','JAPAN','6495314','09076890011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 11:59:25',0,NULL,3,1,2,1,NULL,'micmoo2005\r庄'),(8024,756112570016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lele_elena','zbrskx@yahoo.com','Elena Zaborskikh','60 fontwell Close Harrow Weald','London','London','UNITED KINGDOM','HA3 6DE','4477209188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 12:00:11',0,NULL,3,1,2,1,NULL,'lele_elena\r庄'),(8025,702222312002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','imellado','iker.mellado@gmail.com','Iker Mellado Blanco','Buztintxulo nº 3 3 izda','San Sebastian','GUIPUZCOA','SPAIN','20015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 12:46:12',0,NULL,3,1,2,1,NULL,'imellado\r庄'),(8026,702231555002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.99,'hermeshine','sisco_5','sisco_5@abv.bg','Svilen Titov','Okolovraste Pat No 253, Mladost 4<br>Business Park Sofia, INA Trading','Sofia','Sofia','BULGARIA','1766','00359885332445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 13:04:02',0,NULL,3,1,2,1,NULL,'sisco_5\r庄'),(8027,756160871016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','alanthompson5','judiththompson5@gmail.com','Alan Thompson','5 Tynedale Crescent','Lisburn','Antrim','UNITED KINGDOM','BT28 3JY','02892665083','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 13:13:44',0,NULL,3,1,2,1,NULL,'alanthompson5\r庄'),(8028,702243637002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','junjunpang','jun-pang@hotmail.com','jun pang','1 Rosedale Ave Wattlepark','Adelaide','South Australia','AUSTRALIA','5066','0883317443','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 13:35:33',0,NULL,3,1,3,1,NULL,'junjunpang\r刘\rRA117728626CN\r'),(8029,661465238001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','10mikhail10','mikbasov@gmail.com','Mikhail Basov','Varshavskoe shosse<br>108-1-239','Moscow','Moscow','RUSSIAN FEDERATION','117639','903-773-97-69','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 13:38:23',0,NULL,3,1,3,1,NULL,'10mikhail10\r庄\rRA117728630CN\r'),(8030,702245354002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','filmstudio2010','zurafilm@yahoo.com','Zurab Katamadze','6909 6th Ave<br>Apt 1R','Brooklyn','NY','UNITED STATES','11209','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'filmstudio2010\r庄\r、'),(8031,702291002002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','takisgreekman67','panagiotisbp@gmail.com','THEODORA VUDICLARI','PROMITHEOS 4a','ATHENS','GREECE','GREECE','17674','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 15:24:27',0,NULL,3,1,2,1,NULL,'takisgreekman67\r刘'),(8032,756239211016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','vitpict','alfakapital@navigator.lv','Vitalijs Nevidomskis','Dzelzavas 76/2-61','Riga','','LATVIA','LV-1082','(371)25971410','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 15:40:04',0,NULL,3,1,2,1,NULL,'vitpict\r庄'),(8033,661522640001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','erdavis1','erdavis1@bellsouth.net','Everett R Davis','129 Creekside Dr','Dallas','GA','UNITED STATES','30157-7373','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 15:43:48',0,NULL,3,1,1,1,NULL,'erdavis1\r注意数量\r庄'),(8034,661526280001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','v65magnasales','v65magnaebayer@hotmail.com','Charles Smith','1516 Clermont Rd','Durham','NC','UNITED STATES','27713','(919) 423-0834','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 15:58:33',0,NULL,3,1,1,1,NULL,'v65magnasales\r庄'),(8035,771938173015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',2.48,'hutongstore','wwsong79','wwsong@gmail.com','SONG WEI WEN','1B, LORONG 1,<br>JALAN GAMBIR','SIBU','SARAWAK','MALAYSIA','96000','6084349772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 16:23:47',0,NULL,3,1,2,1,NULL,'wwsong79\r刘'),(8036,0,120711003203,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',3.99,'hermeshine','lbw65red','lisa65red@gmail.com','Lisa Weiner','35 Jean Pl','Syosset','NY','UNITED STATES','11791','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-17 16:48:37',0,NULL,3,1,1,1,NULL,'lbw65red\r庄'),(8037,756323206016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','lomaf123','lomafulton@talktalk.net','loma fulton','30 mitchell avenue','workington','Cumbria','UNITED KINGDOM','ca141ab','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-17 17:27:07',0,NULL,3,1,4,1,NULL,'lomaf123\r（英标）\r刘\r英国物流手里有一票，已经直接安排从英国转了，单号YW864870922CN'),(8038,661621350001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','stanleyfamily2011','stanleyfamily96@hotmail.com','Vanessa Stanley','96 Alfredo Duarte House Edinburgh Estate','Gibraltar','Gibraltar','GIBRALTAR','GX11A','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 17:59:21',0,NULL,3,1,2,1,NULL,'stanleyfamily2011\r刘'),(8039,772050010015,250599412421,'Green.L 67mm 67 Neutral Density ND8 Filter ND 8 New',2,'AE2312',8.6,'hutongstore','electronicparts321','ivotsolov@yahoo.com','Ivailo  Tsolov','Kr.Pishurka 1','Vratsa','Vratsa','BULGARIA','3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 18:21:46',0,NULL,3,1,2,1,NULL,'electronicparts321\r注意数量\r刘'),(8040,661664113001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','davidcinegra','davidcamera@msn.com','david faria','Rua Minas Gerais, 328<br>Vila Santana','Valinhos','Sao paulo','BRAZIL','13274080','55 19 3849-7661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 18:46:43',0,NULL,3,1,3,1,NULL,'davidcinegra\r庄\rRA117728643CN'),(8041,756426448016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','thegoo0_0','dermotdu@eircom.net','dermot dunne','44 balally park, dundrum','dublin','Dublin','IRELAND','d16','0879566595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 18:55:45',0,NULL,3,1,2,1,NULL,'thegoo0_0\r刘'),(8042,661693553001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','silverbrp','audi80silver@rambler.ru','Pavel Bakhteev','15-1-72 Musy Jalilia','Moscow','','RUSSIAN FEDERATION','115580','+7-926-294-43-17','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-17 19:25:28',0,NULL,3,1,2,1,NULL,'silverbrp\r刘'),(8043,772137997015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','tubenutdave','tubenutdave.smith@virgin.net','Dave Smith','33 Mauldeth Road<br>heaton Mersey','Stockport','Cheshire','UNITED KINGDOM','SK4 3ND','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 19:33:49',0,NULL,3,1,2,1,NULL,'tubenutdave\r刘'),(8044,772132685015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','f-nielsen','inkognito65@gmail.com','Frank Nielsen','Løkkenvej 428','Brønderslev','','DENMARK','9700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-17 19:44:07',0,NULL,3,1,2,1,NULL,'f-nielsen\r刘'),(8045,661746963001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','rlip6245','rdlonnie@gmail.com','Ronald Lipman','5800 Nicholson Ln<br>Apt 808','Rockville','MD','UNITED STATES','20852-2964','','NoPaymentFailure','CheckoutComplete','Other','2011-04-17 21:00:51',0,NULL,3,1,1,1,NULL,'rlip6245\r尺寸：2XL\r庄'),(8046,772215862015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',63.99,'hutongstore','muntazer10','garcinia03@yahoo.com','Muntaz Abu Bakar','55 Trinity Square<br>Lombard Street1','Dublin ','Dublin','IRELAND','2','0852707282','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-17 21:15:35',0,NULL,3,1,4,1,NULL,'muntazer10\r庄\rYW864941692CN\r'),(8047,702546033002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','adrianleys2010','adrianleys@hotmail.com','Perez, Vanesa','Sullivan 1200 Edif. 51 Dep. F<br>Barrio Policial','San Antonio de Padua','Buenos Aires','ARGENTINA','1718','0220-4835898','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 21:22:39',0,NULL,3,1,3,1,NULL,'adrianleys2010\r庄\rRA117728657CN'),(8048,661771592001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','howerdal','anders.howerdal@telia.com','Anders Howerdal','Solhemsgatan 20','Gislaved','none','SWEDEN','33234','037114400','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-17 21:38:50',0,NULL,3,1,3,1,NULL,'howerdal\r庄\rRA117728705CN\r'),(8049,772235507015,250692237341,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'AA2201',2.75,'hutongstore','anowarul2006','pritha_moni@hotmail.com','Anowarul Kamal','K  F  C<br>East Gate Shoping Centre.  (Food Court)','Inverness.','Highland','UNITED KINGDOM','IV1  1LQ','07985281231','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 21:54:00',0,NULL,3,1,2,1,NULL,'anowarul2006\r刘\r\\\r'),(8050,772273450015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','chamling_keta','sherockedme@yahoo.com','samir rai','17 albany street','middlesbrough','Cleveland','UNITED KINGDOM','ts1 4db','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-17 23:28:04',0,NULL,3,1,2,1,NULL,'chamling_keta\r刘'),(8051,702618490002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','stormdelrosario','mannydelrosario@yahoo.com','Maani Del Rosario','5495 Coolbrook Avenue','Montreal','QC','CANADA','H3X2L3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 00:54:59',0,NULL,3,1,2,1,NULL,'stormdelrosario\r刘'),(8052,661845697001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',6.8,'hermeshine','hilltopper23','beaman_rg@yahoo.com','RANDALL BEAMAN','2332 Ridgeway Rd','MEMPHIS','TN','UNITED STATES','38119-7414','(901) 820-0544','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 01:33:23',0,NULL,3,1,1,1,NULL,'hilltopper23\r庄'),(8053,702638201002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','inness207','innessphoto@securespeed.net','Inness  Photo Service','25 Plaza Dr<br>Ste 6','Scarborough','ME','UNITED STATES','04074-6900','(207) 883-7860','NoPaymentFailure','CheckoutComplete','Other','2011-04-18 01:49:59',0,NULL,3,1,1,1,NULL,'inness207\rxl\r庄'),(8054,756659177016,260660054946,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB800',1,'AB3309',32.99,'hutongstore','scooter2462','willys@shermanlaws.com','Wilfredo Santiago','61 Town Center Court # 1401','Scarborough','ON','CANADA','M1P 5C5','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 02:15:26',0,NULL,3,1,3,1,NULL,'scooter2462\r庄\rRA117728665CN\r'),(8055,661863593001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','5144ryan','migramcrae@yahoo.com','Ryan McRae','1544 E Irene Dr','Casa Grande','AZ','UNITED STATES','85122-8697','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 02:30:21',0,NULL,3,1,1,1,NULL,'5144ryan\r庄'),(8056,660116309018,280522563067,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-18 02:35:06',0,NULL,3,1,5,1,NULL,'ppnc12\r2m背景架 +2块 绿色的\r  背景布 1.6x2.1 庄\rCP226344661CN\r需邮件'),(8057,0,110672017749,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',0.99,'hermeshine','huaguosan','shop94556@gmail.com','K C Hua','109 Alta Mesa Court','Moraga','CA','UNITED STATES','94556','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:18:54',0,NULL,3,1,1,1,NULL,'huaguosan\r庄'),(8058,702666013002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','lw463','boguo@aol.com','Bo Guo','6705 185th St','Fresh Meadows','NY','UNITED STATES','11365-3511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:22:33',0,NULL,3,1,1,1,NULL,'lw463\r庄'),(8059,702668293002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','beowulf_cam','shauncoleman@rogers.com','Shaun Coleman','60 Haddington Street','Cambridge','ON','CANADA','N1R3P9','(519) 240-1212','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 03:30:37',0,NULL,3,1,3,1,NULL,'beowulf_cam\r刘\rRA117728674CN\r'),(8060,702670122002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nathalee10','yo.nat_buh@hotmail.com','nathalee hernandez','carr.853 k.m 5.1 bo. barrazas, carolina , PR<br>p.o box 1110 00986 carolina','carolina','PR','UNITED STATES','00986','(787) 548-9586','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:40:09',0,NULL,3,1,1,1,NULL,'nathalee10\r庄'),(8061,661882283001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','failure.online','x.deadlyfishy.x@gmail.com','Brady Lee','N10275 171st St','Boyceville','WI','UNITED STATES','54725-9527','(715) 225-9061','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 03:49:39',0,NULL,3,1,1,1,NULL,'failure.online\r1.6x2.1 黑色\r刘'),(8062,702675257002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','jantine57','hofman.tina@yahoo.com','jantine hofman','209 racecourse rd','leongatha','Victoria','AUSTRALIA','3953','0356624512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:14:16',0,NULL,3,1,2,1,NULL,'jantine57\r庄'),(8063,702681424002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','marzum01','mario@marzuki.co.nz','Mario Marzuki','Lvl 4 CallPlus Business Centre<br>110 Symonds Street, Auckland Central','Auckland','Auckland','NEW ZEALAND','1010','099196236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 04:36:31',0,NULL,3,1,2,1,NULL,'marzum01\r庄'),(8064,661900339001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','genadyd','genadyd@gmail.com','Genady Dubnik','Mivtza Harel 20 Str.','Rishon Lezion','','ISRAEL','75443','(972)506235314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 05:38:46',0,NULL,3,1,2,1,NULL,'genadyd\r庄'),(8065,702698944002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 06:21:50',0,NULL,3,1,5,1,NULL,'ppnc12\r刘\rCP226269104CN\r需邮件'),(8066,661915381001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','yowonn','yotang@time.net.my','Mr. Tang Yow Onn','19,Jalan Bunga Melur 14<br>Taman Muda, Cheras','Kuala Lumpur','WP','MALAYSIA','56100','0122975572','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 07:03:59',0,NULL,3,1,3,1,NULL,'yowonn\r庄\rRA117728440CN\r'),(8067,702713960002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:33:56',0,NULL,3,1,17,0,NULL,'emiltan79'),(8068,702714818002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:04',0,NULL,3,1,17,0,NULL,'emiltan79'),(8069,661925569001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:05',0,NULL,3,1,17,0,NULL,'emiltan79'),(8070,702717050002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','emiltan79','emiltndn@yahoo.com','Emil Tandian','Blk 5004, #03-12 Ang Mo Kio Ave 5<br>TECHplace II','default','','SINGAPORE','569872','+6598561576','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 08:34:05',0,NULL,3,1,3,1,NULL,'emiltan79\r77mm ring  1\rstar6 星光镜   1\r广角托架  1\r渐变灰   1\rRA117728422CN'),(8071,702730758002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oldman-garage','oldmangarage@gmail.com','Donny Tong','35 jalan pp 4/13<br>taman putra prima','puchong','selangor','MALAYSIA','47130','012-2966223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:16:25',0,NULL,3,1,2,1,NULL,'oldman-garage\r徐'),(8072,702735099002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 09:31:42',0,NULL,3,1,17,0,NULL,'eddyhuang'),(8073,661946799001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 09:36:40',0,NULL,3,1,9,1,NULL,'eddyhuang\rwt600   1\r6662a 快装板  1\r104231201104180107'),(8074,661959763001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mauri.2010','maurizio.pellizer@gmail.com','maurizio pellizer','levja 5','Koper','slovenia','SLOVENIA','6000','0038641948989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 10:32:42',0,NULL,3,1,2,1,NULL,'mauri.2010'),(8075,772496803015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','iheartsunshine01','sunshine_ying92@yahoo.com.au','Ying Lim','Ramsay Hall<br>20 Maple St','London','London','UNITED KINGDOM','W1T 5HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 12:08:38',0,NULL,3,1,2,1,NULL,'iheartsunshine01\r庄'),(8076,661985077001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','juraaa','juraaa@mail.ru','Yury Gich','Österlånggatan 15B','Trollhättan','Centrum','SWEDEN','46131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:13:34',0,NULL,3,1,3,1,NULL,'juraaa\r刘\rRA022493418CN'),(8077,661209794001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',231.05,'hermeshine','teatrodemarionetaslaestrella','iberians@hotmail.com','Alberto Gomez Sanchis','Av./Pais Valenciano nº32  Esc.2ª  1ºA','Villajoyosa','ALICANTE','SPAIN','03570','677072979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 12:43:56',0,NULL,3,1,4,1,NULL,'teatrodemarionetaslaestrella\r4灯头 伞孔  1 欧标\r佳能红外   1\r50-70 通用卡口棚  1\r115w 220v   4\r肩架   1\r渐变灰  1\r77mm canon 镜头盖  1\r斜臂  1\r2m 灯架  1\r77mm 接口环  1\r托架   1\r刘\rYW864941176CN\r'),(8078,702800476002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','m_r_t','buyuknacarmurat@mynet.com','Murat Buyuknacar','Yucel Buro Mob.San. ve Tic.AS.<br>3. O.S.B. Celal Dogan Blv. No=38 - Baspinar','Gaziantep','TURKEY','TURKEY','27600','3423379550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:41:00',0,NULL,3,1,2,1,NULL,'m_r_t\r庄'),(8079,662009441001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','selma110011','selma.hodz@gmail.com','selma hodzic','bilica 5<br>donja mahala','mostar','','BOSNIA AND HERZEGOVINA','88000','+38763428212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 13:43:07',0,NULL,3,1,2,1,NULL,'selma110011\r庄'),(8080,702820540002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','ribesella','carlosrosal@gmail.com','Marta Rodriguez Moro','C/ Modesto Lafuente, Nº 15, 4º - 3','Madrid','Madrid','SPAIN','28003','637522177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 14:47:10',0,NULL,3,1,2,1,NULL,'ribesella\r庄'),(8081,662032411001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:00:24',0,NULL,3,1,2,1,NULL,'vio\r庄'),(8082,662042237001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','marco_dian','dian.marco@gmail.com','Marco Dian','Via P. Picasso 41','Peseggia','VE','ITALY','30030','339 8593761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 15:28:47',0,NULL,3,1,2,1,NULL,'marco_dian\r申报：Lens hood，5$\r刘'),(8083,662056856001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','cybertonio666','cybertonio@terra.es','José Antonio Peñas Lázaro','Pedro Saputo 14, 1ºA','Zaragoza','Aragón','SPAIN','50018','616467953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:15:06',0,NULL,3,1,2,1,NULL,'cybertonio666\r刘'),(8084,702853172002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','banditbikerchick333','bandit3364@yahoo.com','Dawn Berndt','2047 W Farwell Ave','Chicago','IL','UNITED STATES','60645-4982','(773) 592-1243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 16:21:36',0,NULL,3,1,1,1,NULL,'banditbikerchick333\r庄'),(8085,702853093002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','rmsoares','rafael.msoares@terra.com.br','Rafael Mello','Avenida Nilo Peçanha<br>50 33º ANDAR 3301','Rio de Janeiro','Rio de Janeiro','BRAZIL','20020100','55 21 3824-2208','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:21:39',0,NULL,3,1,3,1,NULL,'rmsoares\r王\rRA022493404CN\r、'),(8086,702858208002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:55',0,NULL,3,1,17,0,NULL,'stiu1983'),(8087,702855263002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:56',0,NULL,3,1,17,0,NULL,'stiu1983'),(8088,702850075002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:56',0,NULL,3,1,17,0,NULL,'stiu1983'),(8089,662059568001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',59,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:57',0,NULL,3,1,17,0,NULL,'stiu1983'),(8090,662065063001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',2,'AB3328',101.98,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 16:43:57',0,NULL,3,1,4,1,NULL,'stiu1983\r滤镜套装：10片镜+卡座+58mm环\r柔光伞   2\r3片装的滤镜袋   3\rCanon  老款背心（M）    1\r灯架  2m    2\r闪光的柔光箱   50cm   2\r申报：Lighting kit，25$\r庄\rYW864941180CN'),(8091,662062542001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','stiu1983','steve.83@live.it','Stefano','C.so torino 85/d','buttigliera alta','TO','ITALY','10090','+393389919552','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 16:43:58',0,NULL,3,1,17,0,NULL,'stiu1983'),(8092,772623238015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','mm5pb','mmooreqc@tiscali.co.uk','M.Moore','5,Paper Buildings<br>Temple','London','London','UNITED KINGDOM','EC4Y 7HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 17:18:53',0,NULL,3,1,2,1,NULL,'mm5pb\r刘'),(8093,662094376001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','el_supahfly','flydelivery@gmail.com','Alexander Nazarov','11-Mitskevich str., Ap.9','Rivne','Rivne region','UKRAINE','33013','+380503753590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 17:42:58',0,NULL,3,1,2,1,NULL,'el_supahfly\r刘'),(8094,772645646015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','bydemofilo2010','bydemofilo@gmail.com','jose demofilo camacho carrasco','galdames nº92<br>ayamonte','huelva','Andalucía Ceuta y Melilla','SPAIN','21400','671084038','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-18 17:58:21',0,NULL,3,1,3,1,NULL,'bydemofilo2010\r王\rRA022493395CN\r、'),(8095,772678792015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','521pebe','patblackledge@msn.com','Pat Blackledge','181 Liverpool Road South, Burscough','Ormskirk','Lancashire','UNITED KINGDOM','L40 7RE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-18 18:48:05',0,NULL,3,1,2,1,NULL,'521pebe\r数量！！\r刘'),(8096,702927565002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','momomo25','momomo25@hotmail.com','Monique Schaefer','183a putnam pike','dayville','CT','UNITED STATES','06241-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 19:04:54',0,NULL,3,1,17,0,NULL,'momomo25'),(8097,772690885015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',12.4,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 19:07:18',0,NULL,3,1,17,0,NULL,'leifs123'),(8098,772688104015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-18 19:07:19',0,NULL,3,1,17,0,NULL,'leifs123'),(8099,772686395015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-18 19:07:19',0,NULL,3,1,4,1,NULL,'leifs123（欧标）\r反光伞    2\r2m灯架   2\r双灯头   2\r反光伞   2\r背景架2mx2m    1\r背景布 1.6    2（黑白各一块）\r灯架包  1\r申报：20￡，\rlighting kit？\r刘\rYW864941143CN'),(8100,662147971001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','momomo25','momomo25@hotmail.com','Monique Schaefer','183a putnam pike','dayville','CT','UNITED STATES','06241-1626','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 19:27:33',0,NULL,3,1,1,1,NULL,'momomo25\rEW-73B   1\r62mm  橡胶遮光罩    1\r庄'),(8101,662180576001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','robert2348','robertgibsonb@hotmail.com','Robert Gibson','Casilla 10-03-45','Ibarra','Imbabura','ECUADOR','EC-100140','(593) 062-6520 ext.: 73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-18 20:38:58',0,NULL,3,1,2,1,NULL,'robert2348\r庄'),(8102,702976359002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','vaidulencijus3706','vaidulencijus@gmail.com','Vaidas Azubalis','Amatu g. 3','Moletai','Utena region','LITHUANIA','LT-33102','+37065679130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 20:44:18',0,NULL,3,1,3,1,NULL,'vaidulencijus3706\r庄\rRA022493191CN'),(8103,662177441001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','xtrimal','xtrimal@gmail.com','Leonid Shmigun','Pionerskaya st.3 - 37','Vuktil','Respublika Komi','RUSSIAN FEDERATION','169570','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-18 21:03:37',0,NULL,3,1,3,1,NULL,'xtrimal\r刘\rRA022494002CN'),(8104,660472332018,280522565557,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','goyngreen','carlottapoole@hotmail.com','Mark A. Poole','1588 Los Angeles Ave','ventura','CA','UNITED STATES','93004-3216','(805) 649-5285','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-18 21:19:03',0,NULL,3,1,4,1,NULL,'goyngreen\r灯泡是110v\r庄\rYW864941154CN'),(8105,0,120711002739,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.25,'hermeshine','ministerfortson','admin@ministerfortson.com','Minister Fortson','2321 Juanita Cir','North Las Vegas','NV','UNITED STATES','89032-3519','(702) 762-3185','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:37:38',0,NULL,3,1,1,1,NULL,'ministerfortson\r庄\r、'),(8106,662204969001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',21.94,'hermeshine','carlotta611','avonwoman1@gmail.com','Carlotta Roberts','381 Meadow Lark Ln','Banning','CA','UNITED STATES','92220','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:40:06',0,NULL,3,1,1,1,NULL,'carlotta611\r庄\r、'),(8107,662209369001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','thank.you.come.again','akifergin@live.com','Akif Ergin','115B N 34th St<br>Apt 7-B','PHILADELPHIA','PA','UNITED STATES','19104-4904','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 21:53:58',0,NULL,3,1,1,1,NULL,'thank.you.come.again\r庄\r、'),(8108,703012217002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','keithpyt','keithpyt@yahoo.com','Keith A. Pytlinski','2343 Corlson Pl','Simi Valley','CA','UNITED STATES','93063-2717','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 22:21:18',0,NULL,3,1,1,1,NULL,'keithpyt\r庄\r、'),(8109,703023300002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lunadrift','lunadrift@gmail.com','Bu Wang','1920 Powell Campus Ctr','Alfred','NY','UNITED STATES','14802','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-18 23:00:39',0,NULL,3,1,1,1,NULL,'lunadrift\r庄\r、'),(8110,660549215018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','namadnats','rocketlabz@gmail.com','Ruben Alvarez','5100 boul de Maisonneuve Ouest 5th Floor','Montreal','QC','CANADA','H4A3T2','(514) 451-6922','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-19 01:54:23',0,NULL,3,1,6,1,NULL,'namadnats\r灯泡是110v\r申报 lighting kit  $20\r王\rEE442466412CN'),(8111,703068744002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mogly73','etienneducharme@videotron.ca','Etienne Ducharme','1027, Rue Ronsard','Deux-Montagnes','QC','CANADA','j7r6n2','(450) 974-2526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 01:55:16',0,NULL,3,1,2,1,NULL,'mogly73\r刘'),(8112,662281371001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','whl36512','weihan_lin@yahoo.com','Weihan Lin','2916 Colton Ct','Lisle','IL','UNITED STATES','60532-4411','(630) 579-1825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 02:35:55',0,NULL,3,1,1,1,NULL,'whl36512\r庄'),(8113,660577577018,280522567137,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','george.ym.siu','george.ym.siu@gmail.com','Yuet SIU','28/2 Wattle Cres','Pyrmont','New South Wales','AUSTRALIA','2009','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-19 03:55:01',0,NULL,3,1,4,1,NULL,'george.ym.siu\r澳标    王\rYW864941165CN'),(8114,757207699016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','ksorweide25','ksorweide@gmail.com','kara sorweide','427 W 13th Ave','spokane','WA','UNITED STATES','99204-3758','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 04:17:38',0,NULL,3,1,1,1,NULL,'ksorweide25\r、'),(8115,703102822002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lucablight32','rahal_roog@hotmail.com','Christian Erwanda','212/547 Flinders Lane','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:29:16',0,NULL,3,1,2,1,NULL,'lucablight32\r'),(8116,662303654001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','rwir7405','richard@a3logistics.net','Richard Wirski','PO BOX 2208','Seaford','Victoria','AUSTRALIA','3198','0397867007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 04:31:50',0,NULL,3,1,3,1,NULL,'rwir7405\r注意是铁接口那个         王\rRA022493364CN\r'),(8117,0,110671625976,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',51.93,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 05:19:55',0,NULL,3,0,3,1,NULL,'traderseamer\r52mm 渐变灰  1\r72mm +4 近摄镜   1\r58mm 渐变灰  1\r67mm uv   1\r52mm uv  10\r58mm uv  10\r1.264\r'),(8118,772920332015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','bisseryo','bisser_yordanov@mail.bg','Bisser Yordanov','Lyulin 10, bl 133, ent1, fl 5, apt 18','Sofia','Sofia','BULGARIA','1335','359898776059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 06:05:14',0,NULL,3,1,2,1,NULL,'bisseryo'),(8119,662320497001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','luliag','xemenia@hotmail.com','Juliah Sharron','6 Bolgers Lane','St. John\'s','NL','CANADA','a1c1k8','(709) 691-9451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 06:18:21',0,NULL,3,1,2,1,NULL,'luliag'),(8120,757237267016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0005',23.97,'hutongstore','2006walvin','christinewalvin@btinternet.com','christine walvin','brairwood<br>the common','hucknall','Nottinghamshire','UNITED KINGDOM','ng15 6qb','01159638606','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 06:41:30',0,NULL,3,0,3,1,NULL,'2006walvin\r2.1x1.6m   3（黑+红+粉）\rRA022493165CN'),(8121,703125936002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rlbrett','bobbylbrett@yahoo.com','Robert Brett','15960 Doublegrove St','La Puente','CA','UNITED STATES','91744','(626) 536-0433','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 06:43:54',0,NULL,3,1,1,1,NULL,'rlbrett'),(8122,662340565001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','danielephoto','danieleomma@hotmail.com','Daniele Omma / FRAEN','Via Pordoi, 5','Settimo Milanese','MI','ITALY','20019','3487249558','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 08:06:40',0,NULL,3,1,3,1,NULL,'danielephoto\rreflector holder $15\rRA022493214CN'),(8123,660286486001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','japoneva','eva.aurio@gmail.com','EVA MARIA TORRECILLA ALLO','AURIO PRINTER C/ MARCELINO ALVAREZ, 18 - LOCAL POSTERIOR','MADRID','Madrid','SPAIN','28017','637454949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 08:18:06',0,NULL,3,1,2,1,NULL,'japoneva\r\\'),(8124,703139578002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','znegg1','zneg1@verizon.net','Arnold Gallardo','9015 205th St','Hollis','NY','UNITED STATES','11423-2730','','NoPaymentFailure','CheckoutComplete','Other','2011-04-19 08:00:58',0,NULL,3,1,1,1,NULL,'znegg1'),(8125,772957233015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','derrinal','kenm.harrison@gmail.com','Ken Harrison','Avenue de Burbure 124a','Wezembeek-Oppem','','BELGIUM','1970','027850088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 08:42:36',0,NULL,3,1,2,1,NULL,'derrinal\r注意是2个\r庄'),(8126,703150407002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','muhd2005','amir@mdamirpp.net','Muhammad Amir H Umarali','No. 898<br>Kampung Kiudang','Tutong','','BRUNEI DARUSSALAM','TE1543','(673) 8866648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 08:55:24',0,NULL,3,0,3,1,NULL,'muhd2005\rXL\r庄\rRA022493245CN\r、'),(8127,757275273016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','swordyg','gajdoscsabi@gmail.com','Csaba Gajdos','Hóvirág u. 3/a','Kárász','Hungary','HUNGARY','7333','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 09:19:06',0,NULL,3,1,3,1,NULL,'swordyg\r庄\rRA022493982CN\r、'),(8128,662359257001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','suzana1','suzanahorvat@gmail.com','Suzana Ludaš','Šumska 14, Brdovec','Zaprešić, Prigorje brdovečko','Croatia','CROATIA','10291','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 09:39:40',0,NULL,3,1,3,1,NULL,'suzana1\r庄\rRA022493965CN\r、'),(8129,662361033001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:07:37',0,NULL,3,1,3,1,NULL,'saud-p\r刘   、\rRA022493863CN\rRA022493877CN\r'),(8130,703140483002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',2,'AO0009',141.8,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:07:38',0,NULL,3,1,3,1,NULL,'saud-p\r和下面的反光板支架一起，看看能发几个小包出去\r刘   、\rRA022493885CN\rRA022493894CN'),(8131,703175013002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','saltiks','akifsaltik@hotmail.com','akif saltik','yilmaz iletisim topraklik mh. no  26-1<br>gun market karsisi garaj mevki','denizli','merkez','TURKEY','20100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 10:52:01',0,NULL,3,1,3,1,NULL,'saltiks\rL\r庄\rRA022493948CN\r、'),(8132,703181218002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','123.clem1','clementsylvain500@yahoo.ca','Clement Sylvain','49 Wilson St','Wallaceburg','ON','CANADA','n8a 5a5','(519) 627-6985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 11:18:47',0,NULL,3,1,2,1,NULL,'123.clem1\r庄'),(8133,703183501002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','cyavasoglu','yavasoglu@gmail.com','Caglar YAVASOGLU','Erdem Sokak 6/2<br>Kurtulus / Cebeci','Ankara','','TURKEY','06600','+905326789817','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 11:28:37',0,NULL,3,1,6,1,' EE520583295CN','cyavasoglu\r庄'),(8134,662393176001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','junctionflyer','finnan@wwy.org','Dennis Finnan','1754 Bell Ridge Ct','Grand Junction','CO','UNITED STATES','81506-4011','(970) 242-3900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 12:07:51',0,NULL,3,1,17,0,NULL,'junctionflyer'),(8135,772964331015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',59,'hutongstore','kalletappinen','timo.flinkkila@kolumbus.fi','Timo Flinkkilä','Hyökkäläntie 10 A 6','Tuusula','','FINLAND','04300','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-19 12:17:58',0,NULL,3,1,4,1,NULL,'kalletappinen\r庄\r2x2m         背景架   1\r1.6x2.1m   背景布 \r  3（黑+白+灰）\rYW864941202CN'),(8136,703204259002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',106,'hermeshine','tulnikov','tulneek@gmail.com','Aleksandr Tulnikov','Savushkina, 24, app 32','Astrakhan','','RUSSIAN FEDERATION','414056','+79270799195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 12:55:03',0,NULL,3,1,5,1,NULL,'tulnikov\r刘\rCP226269095CN'),(8137,0,120710988343,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',2.52,'hermeshine','surffishjim','jim.kehler@reddrum.net','Jim Kehler','2500 Caprice Ln','Amelia Island','FL','UNITED STATES','32034-8980','(904) 491-1678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:18:01',0,NULL,3,1,17,0,NULL,'surffishjim'),(8138,0,110674134245,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',2.52,'hermeshine','surffishjim','jim.kehler@reddrum.net','Jim Kehler','2500 Caprice Ln','Amelia Island','FL','UNITED STATES','32034-8980','(904) 491-1678','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:18:01',0,NULL,3,1,1,1,NULL,'surffishjim\r绿叶 ND8  67mm    1\r绿叶 ND8  52mm    1\r庄\r、'),(8139,0,120710988419,'Green.L 72mm Neutral Density ND8 Filter ND 8 72',1,'AE2313',3.52,'hermeshine','madacheng','hbj8@cdc.gov','Hongwei Jia','455 Villa Place Ct','Tucker','GA','UNITED STATES','30084-1958','(678) 380-5318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:38:37',0,NULL,3,1,17,0,NULL,'madacheng'),(8140,0,110674134514,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',3.6,'hermeshine','madacheng','hbj8@cdc.gov','Hongwei Jia','455 Villa Place Ct','Tucker','GA','UNITED STATES','30084-1958','(678) 380-5318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:38:38',0,NULL,3,1,1,1,NULL,'madacheng\r绿叶 ND8 72mm    1\r绿叶 ND4 72mm    1\r庄\r、'),(8141,0,120710988587,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',0.99,'hermeshine','mosquitoebites24','lhyme_lopez@yahoo.com','Lhyme Lopez','2105 Spence Cir<br>Apt 10','Jonesboro','AR','UNITED STATES','72401-7235','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 13:45:58',0,NULL,3,1,1,1,NULL,'mosquitoebites24\r庄\r、'),(8142,0,120710988669,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',1.25,'hermeshine','beanbridge','rbrmaliniak@hotmail.com','Brigitte Maliniak','7940 State Rd','Port Hope','MI','UNITED STATES','48468','(989) 428-5065','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 14:01:59',0,NULL,3,1,1,1,NULL,'beanbridge\r庄\r、'),(8143,662416431001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','kata141kata','katahorvat14@gmail.com','Kata Horvat','Šumska 14<br>Brdovec','Prigorje Brdovečko','','CROATIA','10291','00385989601830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 14:35:24',0,NULL,3,1,3,1,NULL,'kata14\r庄\rRA022493925CN\r、'),(8144,773066065015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','kirstmonty','kirstmonty@hotmail.com','K.Greenhalgh','31 farndon Way','Birmingham','West Midlands','UNITED KINGDOM','B235XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 14:41:31',0,NULL,3,1,17,0,NULL,'kirstmonty'),(8145,772996337015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','kirstmonty','kirstmonty@hotmail.com','K.Greenhalgh','31 farndon Way','Birmingham','West Midlands','UNITED KINGDOM','B235XU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 14:41:31',0,NULL,3,1,2,1,NULL,'kirstmonty\r中号内胆包 canon   2\r庄'),(8146,662438820001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','davekui','singkuiwong@yahoo.co.uk','Wong Sing Kui','Block119, bukit merah view #16-89','default','','SINGAPORE','152119','91666242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 14:55:23',0,NULL,3,1,11,1,NULL,'davekui\r庄\r、'),(8147,0,110674134573,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','junctionflyer','finnan@wwy.org','Dennis Finnan','1754 Bell Ridge Ct','Grand Junction','CO','UNITED STATES','81506-4011','(970) 242-3900','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 15:39:11',0,NULL,3,1,1,1,NULL,'junctionflyer\r绿叶 渐变镜 77mm   1\r绿叶 ND4  77mm    1\r庄\r、'),(8148,0,120710988643,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',1.75,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 15:41:44',0,NULL,3,1,1,1,NULL,'george35209\r庄\r、'),(8149,703265621002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dnportero','dnportero@retemail.es','Daniel Nevado Portero','Avda. San Francisco Javier nº 24 (Edf. Sevilla 1) - 10ª Plta. (última puerta)','Sevilla','Sevilla','SPAIN','41018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 16:17:08',0,NULL,3,1,2,1,NULL,'dnportero\r庄'),(8150,0,110674145643,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.59,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 17:02:18',0,NULL,3,1,1,1,NULL,'zeroone12345\r58-58mm  双阳环    1\r52-58mm  双阳环    1\r52mm  接口环    1\r庄\r、'),(8151,662485772001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','bart1628','btw_lee@hotmail.com','Bert Lee','5577 Argyle Street','Vancouver','BC','CANADA','V5P3J5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:13:23',0,NULL,3,1,2,1,NULL,'bart1628\r庄'),(8152,0,120710988481,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',3.82,'hermeshine','frojas','ab4qc@yahoo.com','Felipe Rojas','2020 Woods River Ln','Duluth','GA','UNITED STATES','30097-7963','(678) 499-2720','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 17:16:32',0,NULL,3,1,1,1,NULL,'frojas\r庄\r、'),(8153,757448545016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','tzepuly','case@lesfauves.net','Mr Davide Caselli','91 Kenworthy Road','London','London','UNITED KINGDOM','E9 5RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 17:40:08',0,NULL,3,1,2,1,NULL,'tzepuly\r庄'),(8154,700878622002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','javiermendoza2010','mendoza6313@att.net','Miguel A Mendoza','134 kennedy dr<br>trlr 44','medway','OH','UNITED STATES','45341-1279','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-19 17:46:18',0,NULL,3,1,4,1,NULL,'javiermendoza2010\rreflector holder $20\r王  \rYW864941235CN'),(8155,703301659002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','bayteo','teo_s@inwind.it','Matteo Schiavo','Via Giorgio La Pira, 3','MELENDUGNO','LE','ITALY','73026','3208908782','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 17:51:10',0,NULL,3,1,3,1,NULL,'bayteo\r申报 light stand  $15\r王\rRA022493934CN\r、'),(8156,662502161001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','jacoboo28','jjmarsa@hotmail.com','luis','camino viejo puerto lajas n.78A','spain','Canarias','SPAIN','35600','637392694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:54:25',0,NULL,3,1,3,1,NULL,'jacoboo28\r4个灯泡      庄\rRA022493951CN\r、'),(8157,703305297002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','toors22','n_kozulins@inbox.lv','Nauris Kozulins','Maskavas 309 - dz.94','Riga','Latvia','LATVIA','LV-1063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 17:59:41',0,NULL,3,1,2,1,NULL,'toors22\r庄'),(8158,662514107001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','photocat67','jaclancy@msn.com','Ann Clancy','865 Regal Path Ln','Decatur','GA','UNITED STATES','30030','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-19 18:19:05',0,NULL,3,1,1,1,NULL,'photocat67\r庄\r、'),(8159,662500502001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','myvnev','matyunin_yv@mail.ru','YURIY VITALIEVICH MATYUNIN','PODGORNOGO 28-3','NEVINNOMISSK','STAVROPOLSKIY','RUSSIAN FEDERATION','357112','78655477839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:31:13',0,NULL,3,1,2,1,NULL,'myvnev\r庄'),(8160,662523999001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',45.8,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 18:40:57',0,NULL,3,1,3,1,NULL,'salmon404\r欧标\r庄\rRA022493917CN\r、'),(8161,773193763015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','rosalie_1701','rosalie1701@gmail.com','Rosalie Micallef','42 Caros<br>Triq l-Ghasel','Mosta','','MALTA','MST 2522','0035621437337','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-19 19:03:54',0,NULL,3,1,2,1,NULL,'rosalie_1701\r庄'),(8162,773210782015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48,'hutongstore','chainsawpete2010peter','jackiestewart555@btinternet.com','peter bratley','1 mason street','workington','Cumbria','UNITED KINGDOM','ca143eq','0190063570','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-19 19:31:05',0,NULL,3,1,4,1,NULL,'chainsawpete2010peter\rlighting kit $20\r刘\rYW864941261CN'),(8163,703354885002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','bebelumin','jpmichael@free.fr','Jean-Pierre Michael','21 Grande rue de Chandelles','Coulombs','Centre','FRANCE','28210','0660761523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 19:43:41',0,NULL,3,1,17,0,NULL,'bebelumin'),(8164,662553496001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','bebelumin','jpmichael@free.fr','Jean-Pierre Michael','21 Grande rue de Chandelles','Coulombs','Centre','FRANCE','28210','0660761523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-19 19:43:42',0,NULL,3,1,4,1,' ','bebelumin\r717 155cm    1\r717手柄一个\rtripod $28\r王\rYW864941272CN\r'),(8165,773242593015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','art_udaya','sayhi_udaya@hotmail.com','Udaya','94 Roxeth Green Avenue','Harrow','Middlesex','UNITED KINGDOM','HA2 8AQ','02088648098','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-19 20:25:50',0,NULL,3,1,3,1,NULL,'art_udaya\r王\rRA022493259CN\r、'),(8166,662573042001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mikhail.kuperman','kuperman.mikhail@gmail.com','Mikhail Kuperman','Syezzhinskaya 37 21','Saint-Petersburg','','RUSSIAN FEDERATION','197198','+7 911 1527861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-19 20:26:04',0,NULL,3,1,2,1,NULL,'mikhail.kuperman\r刘'),(8167,0,110674134738,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',0.99,'hermeshine','atlantic_xpress','9.99@comcast.net','Alexander Eychis','1075 Fawn Dr','Southampton','PA','UNITED STATES','18966-4310','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 23:27:10',0,NULL,3,1,1,1,NULL,'atlantic_xpress\r庄\r、'),(8168,773322233015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','davielilley','david@love4leisure.com','David Lilley','40 Heritgae Drive','Clowne','Derbyshire','UNITED KINGDOM','S434ST','01246819480','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-19 23:48:16',0,NULL,3,1,4,1,NULL,'davielilley\r（英标）\r庄\rlightingkit  $35\rYW864941283CN\r'),(8169,757623356016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','torbjorn.fjellestad','xrtno@hotmail.com','Torbjørn Fjellestad','Gamle Nøstegaten 13b','Bergen','','NORWAY','5010','+4748020062','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-19 23:49:08',0,NULL,3,1,4,1,NULL,'torbjorn.fjellestad\r（欧标）\rYW864941434CN\r'),(8170,703449047002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','mgrande','jbrhoward@aol.com','Jerry Howard','3302 N. Salida del Sol','chandler','AZ','UNITED STATES','85224','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-20 00:22:53',0,NULL,3,1,1,1,NULL,'mgrande\r庄\r、'),(8171,703454668002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','eokhan','okhanh@hotmail.com','okhan HORASANLI','yeni belediye is mrk. Mudanya<br>Kat 6 D:126','Bursa','Turkey','TURKEY','16000','00905445440411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 00:53:28',0,NULL,3,1,2,1,NULL,'eokhan\r庄\r、'),(8172,662658463001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bonchoo','morekrit@hotmail.com','CHOONIAH LAO','59/72 NAKANIWAS48, Moo4,<br>NAKANIWAS STREET,','LADPROW','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 01:25:00',0,NULL,3,1,3,1,NULL,'bonchoo\r庄\rRA022493996CN\r、'),(8173,773378464015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','bulapom','ebay@bulapom.com','Rajiv   Kumar','18 Dowland House<br>4 Holbrook Close','Enfield','Middlesex','UNITED KINGDOM','EN14UJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-20 02:56:18',0,NULL,3,1,2,1,NULL,'bulapom\r庄'),(8174,662690881001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',19.8,'hermeshine','maximk1985','viciouskms@mail.ru','Maxim Kurmanov','Свердлова 30-35','Новкузнецк','Кемеровская обл','RUSSIAN FEDERATION','654080','89133117362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 03:49:12',0,NULL,3,1,11,1,NULL,'maximk1985\r庄'),(8175,662710043001,110498795544,'New soft box photography studio lighting Set',2,'AKT016',194,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'crocopk1\r欧标\r115w 220v 灯泡  4个\r灯架  2m   4\r柔光箱 50-70cm 单灯头  4 欧标\r包  2'),(8176,662712922001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','+380634690949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 06:14:24',0,NULL,3,1,3,1,NULL,'axonalex\r庄\rRA117739990CN'),(8177,662714655001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'crocopk1\r'),(8178,662719624001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 06:47:03',0,NULL,3,0,3,1,NULL,'eddyhuang\r58mm 3-stage Rubber lens hood (2 pieces)\r62mm 3-stage Rubber lens hood (2 pieces)\r67mm 3-stage Rubber lens hood (2 pieces)\r72mm 3-stage Rubber lens hood (2 pieces)\r77mm 3-stage Rubber lens hood (2 pieces)\rRA117739986CN\r\r'),(8179,757730798016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','sweetycatone','piocam@maltanet.net','pio camilleri','nid d\'amour<br>triq Francis Attard','naxxar','malta europe','MALTA','nxr1170','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 07:05:36',0,NULL,3,1,2,1,NULL,'sweetycatone\r\\'),(8180,703561252002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ribolov','tigr_2002@ukr.net','Andrii Oliinyk','Politehnichna 31b<br>apartment 9','Kiev','','UKRAINE','03055','+380675086636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 09:33:14',0,NULL,3,1,2,1,NULL,'ribolov\r刘\\'),(8181,754613997016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','magic_yogie_bear','elmos_home@hotmail.com','Murray Orr','4/74 Pohlman Street','Southport','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-20 09:37:02',0,NULL,3,1,4,1,NULL,'magic_yogie_bear\r澳标  \r布换成白色的   刘\rYW864941305CN\r'),(8182,703565290002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vmyr','vladymyrshcherbina@gmail.com','Volodymyr Shcherbina','Kryvoriz\'ka 33-21','Zaporizhzhya','UA','UKRAINE','69039','80612659217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 09:58:23',0,NULL,3,1,3,1,NULL,'vmyr\r庄\rRA117728396CN\r\\'),(8183,662757639001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xanthulina','maria_gounari@hotmail.com','Maria Gounari','Solokfleous 5','Nicosia','Palluriotissa','CYPRUS','1046','0035799828975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 10:03:53',0,NULL,3,1,2,1,NULL,'xanthulina\r刘\\'),(8184,658103543001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','slimyfishy','frazierphotography@gmail.com','Ian S Frazier','765 Agate St<br>Apt 7','San Diego','CA','UNITED STATES','92109-1046','(858) 926-8299','NoPaymentFailure','CheckoutComplete','Other','2011-04-20 10:14:07',0,NULL,3,1,1,1,NULL,'slimyfishy\r庄\r、'),(8185,662770869001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','bedstefarbil','abe.bremer@mail.dk','Benthe Sørensen','Præstevænget 2A<br>Guderup','6430 Nordborg','Sønderjylland','DENMARK','6430','74459322','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 11:05:44',0,NULL,3,0,3,1,NULL,'bedstefarbil\r背心 Nikon 老款 - L\r刘\rRA117728379CN\r\\'),(8186,703587805002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','tjhunni','tj_thinktomorrowsok@yahoo.com','Trudy Scarborough','54 Morris Drive','Billingshurst','West Sussex','UNITED KINGDOM','RH14 9SF','07799741034','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 11:33:01',0,NULL,3,0,3,1,NULL,'tjhunni\r庄XL\rRA117728382CN\r\\'),(8187,662784844001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','iamlado','vorobyevvladimir@mail.ru','Vladimir Vorobyev','Mira 34/1 kv.11<br>tel +7 (701) 747-69-20','Astana','Aqmola obl','KAZAKHSTAN','010000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 12:04:18',0,NULL,3,1,3,1,NULL,'iamlado\r刘\rRA117728334CN\r\\'),(8188,757824259016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',2,'AA1301',3.74,'hutongstore','craigibear','paddygahan@yahoo.co.uk','Pat Gahan','184 Seven Oaks','Sarsfield Road','Dublin','IRELAND','10','0857290252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:34:24',0,NULL,3,1,17,0,NULL,'craigibear'),(8189,773526776015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','craigibear','paddygahan@yahoo.co.uk','Pat Gahan','184 Seven Oaks','Sarsfield Road','Dublin','IRELAND','10','0857290252','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:34:24',0,NULL,3,1,2,1,NULL,'craigibear\r58mm Canon 镜头盖    2\r58mm 橡胶遮光罩   1\r庄\\'),(8190,773545700015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','ale23bee','blue_notorius@yahoo.it','Alessandra Bettin','Via Loredan, 43','Stra\'','VE','ITALY','30039','049-502819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:58:26',0,NULL,3,1,17,0,NULL,'ale23bee'),(8191,773546070015,250599986868,'Large size Neoprene Lens Pouch Case 90mm x 220mm',1,'AC1203',3.28,'hutongstore','ale23bee','blue_notorius@yahoo.it','Alessandra Bettin','Via Loredan, 43','Stra\'','VE','ITALY','30039','049-502819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 13:58:26',0,NULL,3,1,2,1,NULL,'ale23bee\rCanon 小号胆包   1\r大号镜头筒    1\r刘\\'),(8192,662817883001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','webixe','webmaster@webixe.com','Pierre-Olivier Beaudry','1842 préfontaine','montreal','QC','CANADA','h1w2p1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 14:09:54',0,NULL,3,1,3,1,NULL,'webixe\r庄\rRA117728405CN\r\\'),(8193,773596546015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','nbrimmer','neilbrimmer@gmail.com','Neil Brimmer','1/2, Paradise Flats,<br>Triq L-Ahwa Zammit,','Qormi','-','MALTA','QRM05','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-20 16:06:29',0,NULL,3,1,2,1,NULL,'nbrimmer\r数量： 2\r刘\\'),(8194,661603036001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','abnsariel','danbakov@globalnet.hr','Daniel Bakovic','Antuna Stipancica 24','Zagreb','','CROATIA','10000','3831697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:36:55',0,NULL,3,1,2,1,NULL,'abnsariel\r庄、'),(8195,662862732001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','microlab629648','witazzew@yandex.ru','Natalia Ulanova','ul. Nikulinskaya-23 korp-2 kv.547','Moscow','','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:42:42',0,NULL,3,1,2,1,NULL,'microlab629648\r刘\r绿叶 CPL  58mm   1\r绿叶 CPL  52mm   1\r、'),(8196,662862050001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','microlab629648','witazzew@yandex.ru','Natalia Ulanova','ul. Nikulinskaya-23 korp-2 kv.547','Moscow','','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 16:42:42',0,NULL,3,1,17,0,NULL,'microlab629648\r'),(8197,773625362015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','deano1793','beadleboy@hotmail.com','Dean Scource','30 Bridges View<br>Bensham','Gateshead','Tyne and Wear','UNITED KINGDOM','NE8 1NZ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-20 17:11:43',0,NULL,3,1,4,1,NULL,'deano1793\rlighting kit $26\r庄\r英标\rYW864941342CN'),(8198,703680806002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','wisky_studio','wisky@wisky.ru','Andrey Guryanov','Komsomolskaya st. 37, ap 147','Kirov','','RUSSIAN FEDERATION','610001','+7(922)995-7575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:30:18',0,NULL,3,1,2,1,NULL,'wisky_studio\r庄、'),(8199,661196487018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','zhychologic','zheett@hotmail.com','zhychologic Shop','P.O.Box 301<br>Pattaya Post Office','Pattaya City','Chon Buri','THAILAND','20260','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-20 17:30:37',0,NULL,3,1,6,1,NULL,'zhychologic\r！！！顺道给他加黑白背景布的边角料各一块——客户要样品。  刘\rEE442466514CN\r'),(8200,703701960002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','yanivnadav19722','yanivnadav1@gmail.com','yaniv nadav','ha\'ela 48<br>06','maale adumim','maale adumim','ISRAEL','98534','97225903987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:57:18',0,NULL,3,1,3,1,NULL,'yanivnadav19722\r刘\rRA117728317CN\r\\'),(8201,662894897001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','panssari','panzerwag@gmail.com','Jukka-Pekka Berg','Perkiönkatu 85 A 15','Tampere','','FINLAND','33900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 17:57:30',0,NULL,3,1,2,1,NULL,'panssari\r庄、'),(8202,703715649002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','sl2007i','shlomi-levi@usa.net','SHLOMI LEVI','P.O BOX 624','HOLON','','ISRAEL','58105','050-7773987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:21:52',0,NULL,3,1,2,1,NULL,'sl2007i\r刘、'),(8203,662923012001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',5,'AC3301',72.8,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 18:59:35',0,NULL,3,1,5,1,NULL,'nixette_nixette\r庄\rCP226344406CN\r需邮件'),(8204,701119968002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','shafraleks','ka_za@walla.co.il','Aleksei Shafranov','Rosmarin 39 apt. 21','Jerusalem','','ISRAEL','93743','+972547977996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 19:43:37',0,NULL,3,1,2,1,NULL,'shafraleks\r刘、'),(8205,702245354002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','filmstudio2010','zurafilm@yahoo.com','Zurab Katamadze','6909 6th Ave<br>Apt 1R','Brooklyn','NY','UNITED STATES','11209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-19 09:19:35',0,NULL,7,0,18,0,NULL,'filmstudio2010'),(8206,662997972001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','subaruoleg','olegsubaru@yahoo.com','Oleg Pereverzy','Yarden 25/15','Nazareth illit','','ISRAEL','17850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:13:34',0,NULL,3,1,2,1,NULL,'subaruoleg\r庄、'),(8207,703815761002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-20 22:37:36',0,NULL,3,1,4,1,NULL,'leifs123\r（欧标）\r申报：30$，Lighting kit\r1.6×2.1m 背景布   3  （一块白的，两块黑色）\r2mx 1.6m背景架    1\r2m灯架    2\r反光伞      2\r双灯头      2\r115w 220v  灯泡    4\r灯架包     1\r庄\rYW864941390CN\r'),(8208,663004617001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:40:26',0,NULL,3,1,17,0,NULL,'leifs123\r'),(8209,663005162001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','lagaffe2008','fabiomcfonseca@yahoo.com.br','Fabio Fonseca','Rua Sylvio da Rocha Pollis<br>201 bloco04 apt.908','Rio de Janeiro','RJ - Barra da Tijuca','BRAZIL','22793-395','55-21-91915953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:41:30',0,NULL,3,1,17,0,NULL,'lagaffe2008\r'),(8210,703817381002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','lagaffe2008','fabiomcfonseca@yahoo.com.br','Fabio Fonseca','Rua Sylvio da Rocha Pollis<br>201 bloco04 apt.908','Rio de Janeiro','RJ - Barra da Tijuca','BRAZIL','22793-395','55-21-91915953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-20 22:41:31',0,NULL,3,1,5,1,NULL,'lagaffe2008\r庄\r2m灯架   2\rB座    2\r柔光伞   2\r反光伞   1\r庄\rCP226344410CN\r'),(8211,663019245001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','horse_trailer','lmckay1@cogeco.ca','Lawrence H McKay','679 Vanier St.','Windsor','ON','CANADA','N8X3E4','(519) 250-8226','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 00:19:55',0,NULL,3,1,3,1,NULL,'horse_trailer\r刘\rXL\rRA117728365CN\r\\'),(8213,773850882015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','nunomls','cabacita@gmail.com','NUNO SANTOS','DOMUS PACIS<br>RUA SAO VICENTE DE PAULO, 32','FÁTIMA','PORTUGAL','PORTUGAL','2495-438','00351916309872','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 02:27:08',0,NULL,3,1,2,1,NULL,'nunomls\r庄、'),(8212,703870002002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','katchlightphotog','prwebster@comcast.net','patrick webster','2865 Minuet Ave.','West Valley City','UT','UNITED STATES','84119','','NoPaymentFailure','CheckoutComplete','Other','2011-04-21 02:15:00',0,NULL,3,1,3,1,NULL,'katchlightphotog\r庄\rRA117728325CN\r\\'),(8214,663059739001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','vincevincevincevincevince','vince.dyer@gmail.com','Vincent Dyer','30 Jackson st<br>Coorparoo','Brisbane','Queensland','AUSTRALIA','4151','0738436911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 02:36:21',0,NULL,3,1,2,1,NULL,'vincevincevincevincevince\r刘、'),(8215,663086135001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','cleosantana2009','cleosantana2@yahoo.com.br','CLEÓMENES SOARES SANTANA','AV: JOÃO DE BARROS ,201 APTº 901<br>BOA VISTA','RECIFE','PERNAMBUCO','BRAZIL','50050-180','81 3088.3027','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 05:01:37',0,NULL,3,1,2,1,NULL,'cleosantana2009'),(8216,703902531002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 05:26:50',0,NULL,3,1,3,1,' RA117739646CN\r','bmonye\r摄影背心 冬夏  L    1\r灯架 84cm   1\r王'),(8217,663090242001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','korcule-kolieska.sk','alain.roger@gmail.com','alain roger','Helsinska 17','kosice','','SLOVAK REPUBLIC','04013','0904880544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 05:31:24',0,NULL,3,1,2,1,NULL,'korcule-kolieska.sk'),(8218,663090999001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','planetshop','planetshop@rcn.com','Peter Miller','52 W 91st St','New York','NY','UNITED STATES','10024-1418','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 05:52:14',0,NULL,3,1,1,1,NULL,'planetshop'),(8219,663096317001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','mitokondrium0621','koszegi89@gmail.com','Tamás Kőszegi','Vajda János utca 25','Velence','Fejér megye','HUNGARY','2481','36307180472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 06:10:00',0,NULL,3,1,3,1,NULL,'mitokondrium0621\rRA022493735CN'),(8220,703947669002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dvdcollector2008','ajshih@gmail.com','Andrew Shih','138 White Branch Ct','Buffalo Grove','IL','UNITED STATES','60089-1595','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 09:22:38',0,NULL,3,1,1,1,NULL,'dvdcollector2008\r刘\\'),(8221,703951735002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wolvf','wolvf@aol.com','A l Jefferson','128 Hazelton St','Ridgefield Park','NJ','UNITED STATES','07660-1141','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 09:42:51',0,NULL,3,1,1,1,NULL,'wolvf\r庄\\'),(8222,703952460002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','dannir2010','dannir10@gmail.com','Daniel Israel','6 Moran St.','Kiryat Tivon','Israel','ISRAEL','36530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 09:50:02',0,NULL,3,1,11,1,NULL,'dannir2010\r刘\r\\'),(8223,663145169001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','donalex24','mamont24@gmail.com','Alexander Donin','Hasukah, 12b, 1','Rishon Lecion','','ISRAEL','75491','(054) 4548338','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 10:29:30',0,NULL,3,0,3,1,NULL,'donalex24\r庄\rRA117739147CN\r\\'),(8224,663158993001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','spets1980','bindasne@mail.ru','Andrey Spetsialnyy','Odesskaya, 48, \"B\"<br>of. 206, Rusfinance','Krasnodar','Krasnodar region','RUSSIAN FEDERATION','350020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 11:40:45',0,NULL,3,1,3,1,NULL,'spets1980\r刘\rRA117739155CN\r\\'),(8225,663160046001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','galser71','galser2@mail.ru','Siarhei Halkin','Karatkevich street, 18/1/97','Vitebsk','Belarus','BELARUS','210038','+375-29-5151763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 11:56:37',0,NULL,3,1,3,1,NULL,'galser71\r庄\rRA117739062CN\r\\'),(8226,758284231016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','fenwick2362','shfenwick@talktalk.net','STEPHEN FENWICK','29 St John Street','Retford','Nottinghamshire','UNITED KINGDOM','DN22 6JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 12:08:48',0,NULL,3,1,2,1,NULL,'fenwick2362\r刘\\'),(8227,663171445001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:13',0,NULL,3,1,17,0,NULL,'budda001'),(8228,703987245002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:13',0,NULL,3,1,17,0,NULL,'budda001'),(8229,703986966002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',5,'AA2203',17.5,'hermeshine','budda001','isaev.foto@gmail.com','Isaeva Tatyana Timofeevna','Leni Golikova d.28 kv.15','St-Petersburg.','','RUSSIAN FEDERATION','198262','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 12:39:14',0,NULL,3,1,3,1,NULL,'budda001\rlenspen               6\r爵影红外 sony    5\r橡胶遮光罩          10（尺寸如下）\r------\r55mm - 2 \r62mm - 2\r67mm - 2 \r72mm - 2 \r77mm - 2\r刘     790\rRA117739076CN\r\\'),(8230,758305353016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ephovid','info@ephos.gr','ΓΙΩΡΓΟΣ ΣΕΪΡΛΗΣ','ΒΟΥΛΗΣ 16','ΑΘΗΝΑ','προεπιλογή','GREECE','11563','+302103237508','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-21 13:20:59',0,NULL,3,1,4,1,'YW864941386CN ','ephovid\r刘(欧标）\rGeorge Seirlis\r16 Voulis str \r10563 Athens Greece\rtel +30 210 3237508\r\r'),(8231,704007712002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 14:00:34',0,NULL,3,1,17,0,NULL,'bmonye'),(8232,704015164002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','erictran911','erictran911@yahoo.com','eric tran','2548 McLaughlin Ave','San Jose','CA','UNITED STATES','95121-2749','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 14:18:27',0,NULL,3,1,1,1,NULL,'erictran911\r庄\\'),(8233,758325475016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','joruba75','joruba@freemail.hu','Zsolt Biczó','Gárdonyi G. 60.','Kozármisleny','Baranya','HUNGARY','7761','+36/30-520-0338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 14:20:19',0,NULL,3,1,2,1,NULL,'joruba75\r刘\\'),(8234,704016546002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','eladher81','eladher@gmail.com','elad herskovici','yafe nof 39/7<br>22208','nahariyya','nahariyya','ISRAEL','22208','0523413111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 14:29:42',0,NULL,3,1,2,1,NULL,'eladher81\r庄\\'),(8235,774042176015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','albas1591','alan@baseley.name','Alan Baseley','46 Woodburn Avenue, Earlsheaton','Dewsbury','West Yorkshire','UNITED KINGDOM','WF12 8LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-21 14:43:23',0,NULL,3,1,2,1,NULL,'albas1591\r刘\\'),(8236,663213296001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','dariopenadario','dariopena@hotmail.com','Dario Duraes Ferreira Pena','Rua Emilio Pinheiro Barros, 239<br>Apt. 301','Belo Horizonte','Minas Gerais','BRAZIL','30360130','(31) 3297-5188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 15:05:35',0,NULL,3,1,2,1,NULL,'dariopenadario\r庄\\'),(8237,0,120711872733,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',0.99,'hermeshine','impal864','impal864@aol.com','Tim Stacey','935 Lotz Way','Suisun City','CA','UNITED STATES','94585','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 15:14:48',0,NULL,3,1,1,1,NULL,'impal864\r刘\\'),(8238,773768395015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:16',0,NULL,3,1,17,0,NULL,'turisam'),(8239,758064684016,260660053713,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',7.8,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:17',0,NULL,3,1,17,0,NULL,'turisam'),(8240,773768212015,250692237477,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:17',0,NULL,3,1,17,0,NULL,'turisam'),(8241,773767986015,250692240278,'Remote Control Cord Shutter Nikon D80 D70s​ MC-DC1',1,'AA3208',2.98,'hutongstore','turisam','samperisdsl@alice.it','Salvatore Samperi','Viale C. Colombo n. 42','Biancavilla','CT','ITALY','95033','095687868','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 15:23:18',0,NULL,3,1,3,1,'RA117739907CN\r ','turisam\r反光伞  1\r单灯头 欧标  1\r爵影快门线 RS-N2   1\r倒影板（白黑）    1\r刘\r'),(8242,663225498001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','falkone2001','tfalkovskyy@yahoo.co.uk','Taras Falkovskyy','8 Brodivska St.','Zolochiv','Lviv','UKRAINE','80700','+380973149336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 16:00:56',0,NULL,3,1,3,1,NULL,'falkone2001\r注意是铁接口那个\rRA117739938CN\r、'),(8243,0,110674973270,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',3.1,'hermeshine','el-supremo','peter.haas@gmail.com','Peter Haas','144 S 3rd St<br>Unit 401','San Jose','CA','UNITED STATES','95112','(408) 230-8703','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:11:37',0,NULL,3,1,1,1,NULL,'el-supremo\r刘\\'),(8244,0,120711872764,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',0.99,'hermeshine','naturesorigin','katkat@gmail.com','Joseph Kyo','9 Bienvenu Dr','Foothill Ranch','CA','UNITED STATES','92610','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-21 16:28:07',0,NULL,3,1,1,1,NULL,'naturesorigin\r庄\\'),(8245,0,110674973243,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',1.04,'hermeshine','mtdiablo1','steve.sorgatz@gmail.com','Stephen Sorgatz','26 Millbrook Ct','Danville','CA','UNITED STATES','94526','','NoPaymentFailure','CheckoutComplete','Other','2011-04-21 16:39:14',0,NULL,3,1,1,1,NULL,'mtdiablo1\r王\r\\'),(8246,0,120711872399,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',1.04,'hermeshine','cutiger99','kaktug@triad.rr.com','Kurt B. Aktug','7755 Fording Bridge Rd.','Kernersville','NC','UNITED STATES','27284','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:50:28',0,NULL,3,1,1,1,NULL,'cutiger99\r庄\\'),(8247,0,120711872623,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',0.99,'hermeshine','fxstchip','chipwarren@sbcglobal.net','Chip T Warren','3238 Cottonwood Dr','Saint Charles','MO','UNITED STATES','63301-0108','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 16:54:17',0,NULL,3,1,1,1,NULL,'fxstchip\r刘\\'),(8248,663256140001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','sjon7050','gaudydivinephotography@yahoo.com','Simone Jones','P.O. Box 2898','Sanford','FL','UNITED STATES','32772-2898','(407) 233-9147','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 17:21:01',0,NULL,3,1,1,1,NULL,'sjon7050\r庄\\58mm'),(8249,0,110674972659,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',1.29,'hermeshine','davichinanyc','davichina@gmail.com','FEN CHEN','8870 62nd DR','REGO PARK','NY','UNITED STATES','11374','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 17:22:11',0,NULL,3,1,1,1,NULL,'davichinanyc\r刘\\'),(8250,701640536002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:35:24',0,NULL,3,1,2,1,NULL,'princessvideo\r庄、'),(8251,704080854002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','alex-lifan','alexl61@walla.co.il','Alex Liflyandchik','Liber Ze\'ev 1/21','Netanya','','ISRAEL','42524','+(972)524453838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 17:49:25',0,NULL,3,1,2,1,NULL,'alex-lifan\r刘\\'),(8252,704100404002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','karnag9','blade-master2008@yandex.ru','Sergey Druzhin','M. Zhukova 16-3, 41','Tula','Tul\'skaya obl','RUSSIAN FEDERATION','300036','89038414422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 18:40:46',0,NULL,3,1,2,1,NULL,'karnag9\r庄、'),(8253,0,120711872457,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',1.05,'hermeshine','2903jmp3','mkauf@charter.net','Matthew Kaufman','2903 S 9th St','Sheboygan','WI','UNITED STATES','53081-6843','(920) 452-1404','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 19:02:06',0,NULL,3,1,1,1,NULL,'2903jmp3\r刘\\'),(8254,704086006002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',61.99,'hermeshine','restudiorml','rpedrito@hotmail.com','RAUL MARTORELL LURBE','C/ PURISIMA, 12 BAJO','L\'ELIANA','Comunidad Valenciana','SPAIN','46183','647094821','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 19:16:16',0,NULL,3,1,4,1,' ','restudiorml\r庄\rYW864941423CN\r、'),(8255,663313134001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','vivekiny2k','vivek.cinci@gmail.com','vivek yadav','7781 clearwater ct','mason','OH','UNITED STATES','45040-9593','(513) 237-1947','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-21 19:48:26',0,NULL,3,1,1,1,NULL,'vivekiny2k\r刘\r58mm cpl   1\r58mm ND8   1\r58mm 渐变灰   1\r4片装的滤镜袋   1\r（不发近摄镜了）'),(8256,704145128002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','oletangen','fjern_kontrollen@hotmail.com','Marianne Borg','Paasche Aasensvei 9','default','Hønefoss','NORWAY','3514','99042651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:31:15',0,NULL,3,1,3,1,NULL,'oletangen\r庄\rRA022493758CN\r\\'),(8257,704141581002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','themetalgod400','firebird.formula.400@gmail.com','Runar Hanssen','Skog','Hamnvik','','NORWAY','9450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 20:33:46',0,NULL,3,1,3,1,NULL,'themetalgod400\r刘\rRA117739915CN\r、'),(8258,663337229001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','onlinephotostuff','onlinepstuff@gmail.com','ONLINE PHOTO STUFF','525 EAST OHIO ST','PITTSBURGH','PA','UNITED STATES','15212','(412) 231-1717','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 20:55:26',0,NULL,3,1,1,1,NULL,'onlinephotostuff\r庄\\'),(8259,663344411001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','sergport13','portyannikoff@mail.ru','Sergei Portyannikov','Dubovskogo 46<br>102','Novocherkassk','Rostov Region','RUSSIAN FEDERATION','346400','+79198780414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-21 21:19:02',0,NULL,3,1,3,1,NULL,'sergport13\r王\rRA117728277CN\r\\'),(8260,663351545001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 21:40:56',0,NULL,3,1,2,1,NULL,'solsuny\r庄\\'),(8261,758524225016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','nicola.nordin','nicolanordin@hotmail.com','Nicola Nordin','Bergdalen 8','Stockholm','Sundbyberg','SWEDEN','17279','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-21 22:07:57',0,NULL,3,1,3,1,NULL,'nicola.nordin\r申报：GIFT\r刘\rRA117739120CN\r\\'),(8262,704182920002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','taras9889','ragip.candan@gmail.com','Ragip Candan','6445 sok.18/14 Yali mah.Karsiyaka','IZMIR','NA','TURKEY','35550','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 22:24:40',0,NULL,3,1,2,1,NULL,'taras9889\r庄\\'),(8263,774250776015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','nathsuell2002','nathaliasuellen.com@gmail.com','nathalia suellen','Rua 756, nº 81 - Casa de Pedra','Volta Redonda','Rio de Janeiro','BRAZIL','27257220','99642555','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-21 22:48:22',0,NULL,3,1,5,1,NULL,'nathsuell2002\r布为：灰+黑\r王\rCP226344468CN'),(8264,0,120711872890,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.25,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'george35209\r王\\'),(8265,663377522001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','c_beach2','cbeach2@embarqmail.com','Clarence Beach','1239 Maple View Dr','Charlottesville','VA','UNITED STATES','22902','(434) 979-3236','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-21 23:18:33',0,NULL,3,1,1,1,NULL,'c_beach2\r庄\\'),(8266,663384798001,110419742275,'Green.L 62mm Neutral Density ND8 Filter ND 8 62',1,'AE2311',6.2,'hermeshine','studiovirtus','comercial@studiovirtus.com.br','Marcelo Ramon','Rua Alfredo Mendes da Silva, 327-apto 61','São paulo','SP','BRAZIL','05525000','551128672365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-21 23:53:43',0,NULL,3,1,2,1,NULL,'studiovirtus\r王、'),(8267,704218248002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','dmcd6897','solidsoul19@hotmail.com','Daniel McDonald','229-108 Elliott st.','Whitehorse','YT','CANADA','Y1A 6C4','(867) 334-9107','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 00:47:00',0,NULL,3,0,3,1,NULL,'dmcd6897\r庄2XL\rRA117728263CN\r\\'),(8268,704232821002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 01:43:35',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r王\r、'),(8269,663411895001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','raulteofilo','pr.rauljesus@gmail.com','Raul Jesus','rua fernando pessoa nº59 rc','Forte da Casa','Vila franca de xira','PORTUGAL','2625-416','0351 934483917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 01:49:27',0,NULL,3,1,2,1,NULL,'raulteofilo\r王、'),(8270,0,120711872607,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',0.99,'hermeshine','arclu88','lupeng0515@gmail.com','Peng  Lu','3101 Beau Jardin Dr<br>Apt 302','Lansing','MI','UNITED STATES','48910-8537','(517) 643-6779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 02:01:16',0,NULL,3,1,1,1,NULL,'arclu88\r王\\'),(8271,774314252015,250692239955,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',23,'hutongstore','gazihysa','ghysa@yahoo.com','Gus Hysa','299 Adams Ave','Staten Island','NY','UNITED STATES','10306','(917) 567-1200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 02:28:28',0,NULL,3,1,3,1,NULL,'gazihysa\r王\rRA117739133CN\r\\'),(8272,0,110674972593,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',1.25,'hermeshine','richgian','richgian@frii.com','Richard Giansiracusa','891 Eagle Ridge Ct','Loveland','CO','UNITED STATES','80537','(970) 663-0316','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 03:13:48',0,NULL,3,1,1,1,NULL,'richgian\r王\\'),(8273,663439636001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',20,'hermeshine','5076andrew','ajmoylan2@optusnet.com.au','Andrew Moylan','PO Box 632<br>Forestville','sydney','New South Wales','AUSTRALIA','2087','0294511097','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-04-22 04:03:26',0,NULL,3,1,2,1,NULL,'5076andrew\r\\'),(8274,704264502002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','tc123micthis','randomgarland@hotmail.com','Tim Cofield','8503 Hilltop Dr','Ooltewah','TN','UNITED STATES','37363-6841','(423) 715-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 04:04:35',0,NULL,3,1,1,1,NULL,'tc123micthis\r\\'),(8275,663448719001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','mirosajnic77','miro@grafika-grafoprint.hr','miroslav sajnic','gacka 12','zagreb','bestovje','CROATIA','10437','00385912019822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 05:12:26',0,NULL,3,1,3,1,NULL,'mirosajnic77\r庄\rRA117740009CN\r、'),(8276,704293374002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','cks_f','cks_f@yahoo.com.my','Fazdly Kamal','No 383 Jalan KS6<br>Kulim Square','Lunas','Kedah','MALAYSIA','09600','0193314930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 07:11:52',0,NULL,3,1,2,1,NULL,'cks_f\r、'),(8277,663305212001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',6.98,'hermeshine','agastyaalfath','agastya.alfath@gmail.com','Agastya Fauzan Alfath','Perumahan Reni Jaya Blok A5 No 5<br>Pondok Petir, Sawangan','Depok','Jawa Barat','INDONESIA','16517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 08:04:38',0,NULL,3,1,2,1,NULL,'agastyaalfath\rnikon-52反接环   1\r52-52 双阳环   1\r、'),(8278,758671419016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','camilleri4','lar_eri@hotmail.com','Natalie Camilleri','29, Luigi Billion Street','Pembroke','Malta','MALTA','PBK1372','0035621372804','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 08:06:10',0,NULL,3,1,2,1,NULL,'camilleri4\r\\'),(8279,704307317002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','chappo59','karl.genser@aon.at','Karl Genser','ORF Studio Steiermark<br>Marburgerstrasse 20','Graz','','AUSTRIA','8042','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 08:19:07',0,NULL,3,0,3,1,'RA117739924CN ','chappo59\rL  \r'),(8280,663495009001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','carlosss18','carlosss18ro@yahoo.com','Marius Florin Stan','str. Prieteniei 8, bl. N, sc. A, ap. 7<br>Constanta','Constanta','','ROMANIA','900303','0040726365260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:13:19',0,NULL,3,1,3,1,' RA117739796CN\r','carlosss18\r刘'),(8281,663505336001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','redback5112','bridgewater5112@optusnet.com.au','John Bridgewater','17 Halsey Road, Elizabeth East','Adelaide','South Australia','AUSTRALIA','5112','0882871797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 09:52:38',0,NULL,3,1,2,1,NULL,'redback5112\r刘'),(8282,704331617002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','ashisusu11','ashisusu@yahoo.it','Paolo Zuddas','Corso Repubblica, 71','Domusnovas','CA','ITALY','09015','3332205045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 10:02:06',0,NULL,3,1,3,1,' RA117739717CN\r','ashisusu11\r欧标\rlight $15\r刘'),(8283,758738928016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',2,'AA2209',4.5,'hutongstore','8877thomasb','tb.1@blueyonder.co.uk','Thomas Boyle','59 Byron Street<br>G/R','Dundee','Angus','UNITED KINGDOM','DD3 6QU','01382804286','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 12:01:30',0,NULL,3,1,2,1,NULL,'8877thomasb\r刘'),(8284,704366237002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alkulovefoto','almudenafotografia@gmail.com','Almudena Lara','Azorin,10,4A<br>18003','Granada','Andalucía Ceuta y Melilla','SPAIN','18003','653308005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 12:28:59',0,NULL,3,1,3,1,'RA117739629CN\r ','alkulovefoto\r刘'),(8285,774468000015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','photographer1506','edwarddullard@gmail.com','EDWARD DULLARD','13 DE LA SALLE PLACE','KILKENNY CITY','COUNTY KILKENNY','IRELAND','056','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-22 12:29:51',0,NULL,3,1,2,1,NULL,'photographer1506\r王'),(8286,663454773001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','talmerli','talmerli@yahoo.com','Todd Almerli','570 E Slifer St','Portage','WI','UNITED STATES','53901-1257','(608) 408-7659','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 12:53:44',0,NULL,3,1,1,1,NULL,'talmerli\r王'),(8287,663552806001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','foxfordshrimp','desp27@wanadoo.fr','Pascal Despeaux','6 route neuve<br>Le Bourg','Asnières par Cormeilles','Haute-Normandie','FRANCE','27260','06 08 76 54 30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 13:07:03',0,NULL,3,1,2,1,NULL,'foxfordshrimp\r王'),(8288,704381706002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','kmar69888','keith.martinet@gmail.com','Keith Martinet','13 Ahwahnee Street<br>P.O. Box 708','San Juan Bautista','CA','UNITED STATES','95045','(408) 710-2339','NoPaymentFailure','CheckoutComplete','Other','2011-04-22 13:23:52',0,NULL,3,0,1,1,NULL,'kmar69888\rXXL\r王'),(8289,704388497002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','denskiter','4elogram@mail.ru','Denis Skiter','Leningradskiy 3-64','New Urengoy','Tumenskaya obl','RUSSIAN FEDERATION','629305','951-992-9200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 13:57:58',0,NULL,3,1,3,1,'RA117739632CN\r ','denskiter\r王'),(8290,663568012001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:02:10',0,NULL,3,1,17,0,NULL,'crni1985'),(8291,663569373001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 14:07:09',0,NULL,3,1,17,0,NULL,'crni1985\r'),(8292,0,110674973177,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',5.94,'hermeshine','eloquentimages','larrya.harrison@gmail.com','Larry Harrison','197 Pinelli Dr','Piscataway','NJ','UNITED STATES','08854','(732) 858-1699','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 15:07:34',0,NULL,3,1,1,1,NULL,'eloquentimages\r49mm 接口环  1\r52mm 接口环  1\r62mm 接口环  1\r72mm 接口环  1\r77mm 接口环  1\r82mm 接口环  1\r刘\r'),(8293,704429142002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','b3tho','herberth007@gmail.com','Herberth Bezerra','S.Q.N 411 Bloco F apto. 303','Brasília','Distrito Federal','BRAZIL','70.866-060','06181751965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:04:09',0,NULL,3,1,17,0,NULL,'b3tho'),(8294,663603681001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','b3tho','herberth007@gmail.com','Herberth Bezerra','S.Q.N 411 Bloco F apto. 303','Brasília','Distrito Federal','BRAZIL','70.866-060','06181751965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:04:09',0,NULL,3,1,2,1,NULL,'b3tho\r橡胶遮光罩 67mm  1\r橡胶遮光罩 52mm  1\r王'),(8295,663606765001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','susanhaynes','susan@haynesaudio.com','Susan Haynes','532 N K St','Livermore','CA','UNITED STATES','94551-6821','(925) 606-1086','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 16:08:04',0,NULL,3,1,1,1,NULL,'susanhaynes\r王'),(8296,704432389002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','aaydagul','aydagul@gmail.com','Aysan Aydagul','Yesilbahce Mah. 1480 Sokak<br>2. Erenkus Apt. No:42/3','Antalya','','TURKEY','07160','+902423129520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:08:39',0,NULL,3,1,2,1,NULL,'aaydagul\r王'),(8297,663614614001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','khikays','cate_tolosa@yahoo.com','Catherine Tolosa','4057 Jason Place','Victoria','BC','CANADA','v8n4t5','(250) 891-5521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:39:14',0,NULL,3,1,2,1,NULL,'khikays\r刘'),(8298,704446621002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','lan-mas-ter','vacaciones@rambler.ru','Gennadiy Zuev','st. Kolcevay 159/1 - 57','Ufa','Bashkortostan','RUSSIAN FEDERATION','450038','917-345-2848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 16:49:43',0,NULL,3,1,2,1,NULL,'lan-mas-ter'),(8299,663632405001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 17:20:23',0,NULL,3,1,3,1,' RA117739685CN\r','igrom78\r肩架   1\rlenspen   2\r刘'),(8300,704463243002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',2,'AKT051',23,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 17:34:44',0,NULL,3,1,3,1,'RA117722420CN\r ','igrom78\rlenspen   2\r上次少发了2只，我合并订单的时候少写了'),(8301,663640094001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','eugeneyeo92','oblivion247@hotmail.com','Eugene Yeo','Blk 345 Hougang Avenue 7<br>#02-555','default','','SINGAPORE','530345','98527557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 17:40:35',0,NULL,3,1,11,1,NULL,'eugeneyeo92\r王'),(8302,663685383001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','djbi','jibeliste@hotmail.com','Jean-Baptiste Lévy','44 allée de Bassac','Colomiers','Midi-Pyrénées','FRANCE','31770','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 19:32:29',0,NULL,3,1,4,1,' YW864941460CN\r','djbi\rtripod $20\r'),(8303,704517485002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 19:48:10',0,NULL,3,1,3,1,' RA117739819CN\r','zandermatt\r王'),(8304,0,120711872815,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',0.99,'hermeshine','busub01210','sub9902@yahoo.com','TRUMAN P','5710 KNOLLWELL WAY','San Jose','CA','UNITED STATES','95138-1652','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 20:18:15',0,NULL,3,1,1,1,NULL,'busub01210\r庄'),(8305,663703901001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','dewalt962','cvacca01@comcast.net','Carl Vaccarino','460 Capri J','Delray Beach','FL','UNITED STATES','33484','(561) 499-8499','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 20:20:16',0,NULL,3,1,1,1,NULL,'dewalt962\r庄'),(8306,0,120710988058,'Green.L 55mm Neutral Density ND4 Filter ND 4 55',1,'AE2302',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:42',0,NULL,3,1,17,0,NULL,'traderseamer'),(8307,0,110674134400,'Green.L 62mm Neutral Density ND4 Filter ND 4 62',1,'AE2304',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:42',0,NULL,3,1,17,0,NULL,'traderseamer'),(8308,0,110674134377,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',1.75,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:43',0,NULL,3,1,17,0,NULL,'traderseamer'),(8309,0,120710987989,'Green.L 52mm Neutral Density ND4 Filter ND 4 52',1,'AE2301',1.04,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:44',0,NULL,3,1,17,0,NULL,'traderseamer'),(8310,0,120710988317,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',0.99,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:44',0,NULL,3,1,17,0,NULL,'traderseamer'),(8311,0,110674134346,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',1.8,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:45',0,NULL,3,1,17,0,NULL,'traderseamer'),(8312,0,120710988103,'Green.L 55mm Neutral Density ND8 Filter ND 8 55',1,'AE2309',0.99,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:45',0,NULL,3,1,17,0,NULL,'traderseamer\r'),(8313,0,110674134420,'Green.L 62mm Neutral Density ND8 Filter ND 8 62',1,'AE2311',2.25,'hermeshine','traderseamer','stuff2cash@gmail.com','Tony Muller','1664 Wildrose Dr','Rockwall','TX','UNITED STATES','75032','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 21:02:46',0,NULL,3,1,1,1,' ','traderseamer\r绿叶 ND4  52mm  1\r绿叶 ND4  55mm  1\r绿叶 ND4  58mm  1\r绿叶 ND4  62mm  1\r绿叶 ND4  67mm  1\r绿叶 ND8  55mm  1\r绿叶 ND8  58mm  1\r绿叶 ND8  62mm  1\r徐\r405g'),(8314,704566774002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bpoalm','olimpiada@gmail.com','Brandon P Olimpiada','2600 Woody Creek Ct','Cameron Park','CA','UNITED STATES','95682-9231','(916) 588-6301','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-22 22:08:26',0,NULL,3,1,1,1,NULL,'bpoalm\r庄'),(8315,663754004001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-22 23:14:25',0,NULL,3,1,3,1,' RA117739544CN\r','luizfernandoborgesnomura\r刘'),(8316,663755953001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-22 23:20:53',0,NULL,3,1,3,1,' RA117739677CN\r','luizfernandoborgesnomura\r刘'),(8317,774581419015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','sandyjardine1979','sandy.jardine1979@hotmail.co.uk','mark jardine','11 moorefield','banbridge','Down','UNITED KINGDOM','bt324de','07725099073','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-22 23:22:18',0,NULL,3,1,2,1,NULL,'sandyjardine1979\r王'),(8318,663789601001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','otakubrasil','peter@yamatocorp.com.br','carlos afonso','av almirante cochrane nr 194 cj 44','Santos -SP','São Paulo','BRAZIL','11040002','+551391012604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 02:02:53',0,NULL,3,1,2,1,NULL,'otakubrasil\r王'),(8319,704636227002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',5.5,'hermeshine','sbabaq','sbaback@netcabo.pt','Nelson Nunes','Rua General Humberto Delgado,<br>Edificio Lameiros, Bloco 4, 3ºEsq','Vila Franca de Xira','Vila Franca de Xira','PORTUGAL','2600-154','+351962749779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:32:36',0,NULL,3,1,2,1,NULL,'sbabaq\r王'),(8320,663809760001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','dimage2004','yuejian@yahoo.com','Bryan Wu','61 Insmill Cres.','Ottawa','ON','CANADA','K2T1G4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:54:00',0,NULL,3,1,2,1,NULL,'dimage2004\r刘'),(8321,663810477001,110658446785,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',5,'AA2205',17.5,'hermeshine','neburlopez','ru.lopez.a@gmail.com','Rube Lopez','Lord Cochrane 209, Dpto 510, Torre Sur','Santiago','Stgo/ Stgo/ Region Metropolitana','CHILE','8330414','56990461920','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 03:58:40',0,NULL,3,1,3,1,' RA117739725CN\r','neburlopez\r5个\r王'),(8322,663826331001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 05:43:37',0,NULL,3,1,3,1,' RA117739734CN\r','ppnc12\r王'),(8323,704660882002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','doniks','sby6ek@gmail.com','Daniyar Kenebayev','Abay 16-54<br>7017551926','Almaty','','KAZAKHSTAN','050013','007-7017551926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 06:03:51',0,NULL,3,1,2,1,NULL,'doniks\r刘'),(8324,704668192002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','usacat1978','savtchuk@rambler.ru','YURIY SAVCHUK','4825 FORSTER AVE','SCHILLER PARK','IL','UNITED STATES','60176','(773) 225-0738','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 06:47:11',0,NULL,3,1,1,1,NULL,'usacat1978\r庄'),(8325,774842914015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','johndorney','johnrobertdorney@hotmail.com','John Dorney','Loughane','Vicarstown','Cork','IRELAND','default','0214385815','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 07:09:40',0,NULL,3,1,2,1,NULL,'johndorney\r王'),(8326,662209669018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','mutleq','mato-2008@hotmail.com','Mutleq Alotaibi','2 Nobleman place<br>Hamilton East','Hamilton','Waikato','NEW ZEALAND','3216','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-23 07:20:23',0,NULL,3,1,6,1,NULL,'mutleq\r澳标\r再加2mx2m 背景架  一套 白 + 黑\r刘+庄\rEE442466488CN\r'),(8327,704667821002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','k1tahaei','k1_tahaei@yahoo.com','Kayvan Tahaei','CMiC<br>4850 Keele Street','Toronto','ON','CANADA','M3J 3K1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 07:23:16',0,NULL,3,1,3,1,'RA117739561CN\r ','k1tahaei\r王'),(8328,662210294018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','mutleq','mato-2008@hotmail.com','Mutleq Alotaibi','2 Nobleman place<br>Hamilton East','Hamilton','Waikato','NEW ZEALAND','3216','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-23 07:23:17',0,NULL,3,1,17,0,NULL,'mutleq'),(8329,774846849015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','vasko9','vasko.chobanov@gmail.com','Vasil Chobanov','ul. Koliu Ficheto 3, et. 4','Plovdiv','Plovdiv','BULGARIA','4003','+359897059886','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 07:26:17',0,NULL,3,1,2,1,NULL,'vasko9\r王'),(8330,759132456016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','butchielad','mark@butcher92.freeserve.co.uk','Mark Butcher','31 Napier Street','Dalton-in-Furness','Cumbria','UNITED KINGDOM','LA158HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 08:27:07',0,NULL,3,1,2,1,NULL,'butchielad\r2套    刘'),(8331,663855237001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',74.1,'hermeshine','ardiani2009','keni25_ch@hotmail.com','muharrem gashi','verger-rond 8','neuchatel','','SWITZERLAND','2000','0041762885785','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 08:27:23',0,NULL,3,1,4,1,'YW864941456CN\r ','ardiani2009\rDV support $20\r还需要放一个肩架的配件一起发\r王'),(8332,704691136002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',151.6,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 08:50:04',0,NULL,3,1,4,1,' YW864941445CN\r','juanfernandez2007\r刘'),(8333,774872357015,250599364923,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon New',2,'AA3303',4.6,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:57',0,NULL,3,1,17,0,NULL,'octavian_p'),(8334,774872214015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:58',0,NULL,3,1,17,0,NULL,'octavian_p'),(8335,774872297015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',2,'AA3317',9.6,'hutongstore','octavian_p','octavian1406@yahoo.com','Paul Octavian Anca','str. Romancierilor nr. 5, bl. C14, sc.B, ap. 77','Bucharest','Sector 6','ROMANIA','061791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:07:58',0,NULL,3,1,3,1,' RA117714057CN','octavian_p\r绿叶 UV  58mm  2\r绿叶 CPL  58mm  1\r刘\r绿叶 渐变镜 58mm   2\r'),(8336,774872729015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','don.lund','jacoblund89@gmail.com','Jacob Lund','Vintervej 15, 2. sal nr 24','Aarhus V','','DENMARK','8210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 09:12:58',0,NULL,3,1,3,1,' RA117739748CN\r','don.lund\r王'),(8337,704718498002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 11:00:14',0,NULL,3,1,17,0,NULL,'pastandpresentphoto'),(8338,663887349001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-23 11:00:15',0,NULL,3,1,17,0,NULL,'pastandpresentphoto'),(8339,663886483001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','pastandpresentphoto','jillhatcher@msn.com','Jill Hatcher','4622-109th ave se','Snohomish','WA','UNITED STATES','98290','(206) 778-3001','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-23 11:00:15',0,NULL,3,1,1,1,NULL,'pastandpresentphoto\rlenspen   1\r绿叶 ND4  67mm  1\r绿叶 渐变镜 67mm  1\r庄'),(8340,704726254002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','370deivux','dnutautas@yahoo.com','deivis nutautas','architektu 88 57','vilnius','','LITHUANIA','lt-04107','+37068616569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 11:36:31',0,NULL,3,1,5,1,' CP226344454CN\r','370deivux\r王\r需邮件'),(8341,699462959002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','rgbeme','meisrg82@yahoo.com','gary ryan','4709 roosevelt ave','middletown','OH','UNITED STATES','45044-6235','(513) 265-1884','NoPaymentFailure','CheckoutComplete','Other','2011-04-23 12:12:35',0,NULL,3,1,4,1,' YW864941493CN\r','rgbeme\rlighting kit  $25\r刘'),(8342,759217618016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','judazuk','peter.lennartsson@gmail.com','Peter J Lennartsson','Ronnebergavagen 8A','Eslov','Skane','SWEDEN','24134','+46763191343','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-23 13:32:37',0,NULL,3,1,4,1,' YW864941482CN\r','judazuk\rlighting kit  $40\r欧标\r庄'),(8343,774959137015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','reitermaniac1','sebastian.lessner@unitybox.de','Sebastian Lessner','Calvinstraße 13','Düsseldorf','','GERMANY','40597','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 13:55:46',0,NULL,3,1,17,0,'fangbo ','reitermaniac1'),(8344,759228279016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','reitermaniac1','sebastian.lessner@unitybox.de','Sebastian Lessner','Calvinstraße 13','Düsseldorf','','GERMANY','40597','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 14:08:43',0,NULL,3,1,2,1,'test ','reitermaniac1\r镜头筒 小号  1\r镜头筒 中号   1\r刘'),(8345,704767297002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:13:13',0,NULL,3,1,4,1,' YW864941541CN','ryrvikryrvik\rlight stand  $25\r刘\r\r'),(8346,774971222015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','froistedt76','johan@superspecial.se','Johan Fröistedt','Mimergatan 1A','Västerås','','SWEDEN','72214','+46706775876','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 14:29:36',0,NULL,3,1,2,1,NULL,'froistedt76\r王'),(8347,704779626002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1306',7.58,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:17',0,NULL,3,1,17,0,NULL,'fernand5233'),(8348,663947371001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:18',0,NULL,3,1,17,0,NULL,'fernand5233'),(8349,704778388002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','fernand5233','fernr@videotron.ca','Fernand Roy','468 Zephyr','Laval','QC','CANADA','H7X2P8','(450) 689-6266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 14:55:19',0,NULL,3,1,3,1,' RA117739782CN\r','fernand5233\r橡胶遮光罩 72mm   2\r橡胶遮光罩 58mm  1\r橡胶遮光罩 77mm 2 \r庄\r\r'),(8350,759264418016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','el.der','helder.hjf@gmail.com','Helder Fernandes','PRACETA COLÉGIO DE GAIA Nº 240 - 3C','Vila Nova de Gaia','Vila Nova de Gaia','PORTUGAL','4400-090','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 15:38:44',0,NULL,3,1,2,1,NULL,'el.der\r王'),(8351,775002574015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','smarston2610','stuart.marston@ntlworld.com','stuart marston','10<br>Malton Road','North Hykeham, Lincoln','Lincolnshire','UNITED KINGDOM','LN6 8HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-23 15:54:16',0,NULL,3,1,2,1,NULL,'smarston2610\r王'),(8352,775048948015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','postondemand','huwjenkins@uk2.net','huw jenkins','Avenida Marques De L\'Argentera 5, 1b','barcelona','Cataluña','SPAIN','08003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 17:32:39',0,NULL,3,1,3,1,' RA117739751CN\r','postondemand\r庄'),(8353,704731186002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','julianapelucio','julianapelluccio@yahoo.com.br','Juliana Pelucio','Rua Tenente Ulisses, 25<br>Centro','Itaguara','Minas Gerais','BRAZIL','35514000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 17:53:14',0,NULL,3,1,5,1,'CP226344445CN\r','julianapelucio\r欧标'),(8354,664015796001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','heckcare_der','heckcare.der@gmail.com','Heng Derrick','Blk 641 Rowell Road #11-50','Singapore','','SINGAPORE','200641','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:11:43',0,NULL,3,1,11,1,' ','heckcare_der\r庄'),(8355,664024740001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',4,'AE3601',72,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 18:30:14',0,NULL,3,1,4,1,'YW864941563CN\r ','leifs123\r申报：bulbs   $18\r刘'),(8356,759345062016,260660052183,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',2.25,'hutongstore','woody0872','hotwoody72@yahoo.co.uk','GARY WOODS','5 MORRISON HOUSE<br>DERWENT CRESENT','ARNOLD','Nottinghamshire','UNITED KINGDOM','NG5 6TE','01159261180','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'woody0872\r刘'),(8357,664027336001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vissyboy','vissysdg@yahoo.co.uk','Sedlan George','58 Birch Court,<br>Sherman gardens','Chadwell heath, Romford','Essex','UNITED KINGDOM','RM6 4AP','02085864045','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 18:37:48',0,NULL,3,1,3,1,' RA117739663CN\r','vissyboy\r刘'),(8358,775108638015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','killrabbit','david_jfcarvalho@hotmail.com','David Carvalho','Praca Lourenco de Carvalho<br>n28 3 Direito','Almeirim','Almeirim','PORTUGAL','2080-043','00351916397746','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 19:34:28',0,NULL,3,1,2,1,NULL,'killrabbit\r刘'),(8359,664058093001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','leenick','kayorinite3@hotmail.com','Nick Dussault','23 Weymond Crescent','Riverview','NB','CANADA','e1b 5h7','(506) 852-1592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 19:54:55',0,NULL,3,1,17,0,' ','leenick'),(8360,704889387002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','leenick','kayorinite3@hotmail.com','Nick Dussault','23 Weymond Crescent','Riverview','NB','CANADA','e1b 5h7','(506) 852-1592','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 19:57:44',0,NULL,3,0,3,1,' RA117739853CN\r','leenick\r摄影背心 Canon  老款 L    1\r永诺 Canon ttl线  3m       1\r\r庄'),(8361,759387351016,260660051264,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',4.3,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:22',0,NULL,3,1,17,0,NULL,'gdiggerru'),(8362,775124288015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:23',0,NULL,3,1,17,0,NULL,'gdiggerru'),(8363,759386999016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','gdiggerru','gdigger@gmail.com','Anton Labunsky','Molostovykh, 16-4-126','Moscow','','RUSSIAN FEDERATION','111558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 20:05:23',0,NULL,3,1,3,1,' RA117739840CN\r','gdiggerru\r大号内胆包canon     1\r带水平仪 热靴保护盖  1\r永诺 SF18- CANON   1\r王'),(8364,664065084001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','rusty92310','ruslan923@rambler.ru','Ruslan Losaev','Rothschild 12. entrance 2. apartament 3.<br>רוטשילד 12. כניסה ב\'. דירה 3','Bat-yam','','ISRAEL','59326','0527363975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:14:28',0,NULL,3,1,2,1,NULL,'rusty92310\r刘'),(8365,704893297002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','miguel7cardoso','miguelmscardoso@gmail.com','Miguel Cardoso','Avenida João Corte Real, 232, 2ºdt','Barra - Ílhavo - Aveiro','Portugal','PORTUGAL','3830-751','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 20:14:28',0,NULL,3,1,2,1,NULL,'miguel7cardoso\r刘'),(8366,704906492002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','arte3512','pet_son@hotmail.com','Peter Scheuer','Furuslätten 60','Gothenburg','Billdal','SWEDEN','42735','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 20:46:30',0,NULL,3,1,3,1,' RA117739805CN\r','arte3512\rXL\r庄'),(8367,664092325001,110583709836,'NEW 62mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT045',28,'hermeshine','melemele94','mlpm@hotmail.fr','Marie-Line Périllat-Mercerot','11 rue Gabrielle','Charenton-le-pont','Île-de-France','FRANCE','94220','0143684889','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:32:28',0,NULL,3,1,17,0,NULL,'melemele94'),(8368,664071657001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:37:29',0,NULL,3,1,17,0,NULL,'saud-p'),(8369,664073382001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-23 21:37:31',0,NULL,3,1,3,1,'RA117739822CN\r RA17739181CN','saud-p\r反光板支架  1\r背景架2m x 3m  \r分两个小包发  \r庄'),(8370,664095472001,110566018317,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','melemele94','mlpm@hotmail.fr','Marie-Line Périllat-Mercerot','11 rue Gabrielle','Charenton-le-pont','Île-de-France','FRANCE','94220','0143684889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 21:44:06',0,NULL,3,1,3,1,' RA117739765CN\r','melemele94\r62mm 橡胶遮光罩   1\r绿叶 CPL  62mm   1\r绿叶 ND8  62mm   1\r绿叶 近摄+8  62mm   1\r绿叶 渐变灰  62mm   1\r4片装滤镜袋    1\r庄'),(8371,759430105016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','mount_productions','mount@gibraltar.gi','Mark Montovio','502/503 Watergardens','Waterport Wharf','Gibraltar','GIBRALTAR','gibb','00 350 40338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-23 21:48:31',0,NULL,3,1,3,1,' RA117739592CN\r','mount_productions\r王'),(8372,704932501002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jevanamstel','evamstel@gmail.com','Amstel van Eduard','Buizerdweg 42','Alkmaar','','NETHERLANDS','1826GH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 22:05:10',0,NULL,3,1,2,1,' ','jevanamstel\r王'),(8373,664121936001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','crni1985','ivan_crnjak@net.hr','Ivan Crnjak','Karlovacka 8','Sesvete','ZG','CROATIA','10360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:32:13',0,NULL,3,1,2,1,NULL,'crni1985\r绿叶 UV  58mm  1\r绿叶 UV  77mm   2\r刘'),(8374,704960282002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','cleosantana2009','cleosantana2@yahoo.com.br','CLEÓMENES SOARES SANTANA','AV: JOÃO DE BARROS ,201 APTº 901<br>BOA VISTA','RECIFE','PERNAMBUCO','BRAZIL','50050-180','81 3088.3027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-23 23:57:47',0,NULL,3,1,3,1,' RA117739779CN\r','cleosantana2009\r王'),(8375,664136647001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:06',0,NULL,3,1,17,0,NULL,'agagarin'),(8376,704968158002,120458030272,'Marco O Flash o-flash Ring Light For SB900 580EXII F175',1,'AO0026',38.49,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 00:44:06',0,NULL,3,1,17,0,NULL,'agagarin'),(8377,664130924001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:07',0,NULL,3,1,17,0,NULL,'agagarin'),(8378,664135048001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','Other','2011-04-24 00:44:08',0,NULL,3,1,17,0,NULL,'agagarin'),(8379,704965097002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','agagarin','gagarin239@yahoo.com','andrey gagarin','54 maplewood ave','newton','MA','UNITED STATES','02459-2526','(617) 965-7138','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 00:44:08',0,NULL,3,1,3,1,' RA117739575CN\r','agagarin\r绿叶 CPL  67mm   1\rcanon 电子触点      1\r绿叶 ND4  67mm   1\r绿叶 UV  67mm      1\ro-flash f175             1\r徐\r895g'),(8380,705003231002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','drjyeo12','drjyeo@gmail.com','John Yeo','850, Piasau Park','Miri','Sarawak','MALAYSIA','98000','013-8367001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 03:14:06',0,NULL,3,1,2,1,' ','drjyeo12\r庄'),(8381,705015512002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','tachezza','chesworthta@bigpond.com','terry chesworth','328 cabbage tree rd','williamtown','New South Wales','AUSTRALIA','2318','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 04:22:57',0,NULL,3,1,4,1,' YW864941526CN\r','tachezza\r王'),(8382,664180302001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','reginacinegra','regina_fotos@hotmail.com','Regina Yansen Faria','Francisco alves, 222<br>Remédios','Osasco','São Paulo','BRAZIL','06296160','55 11 3696-1882','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 04:26:32',0,NULL,3,1,3,1,' RA117739589CN\r','reginacinegra\r王'),(8383,663554832001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','alex_r_54','alexxxey_45r@mail.ru','Алексей Полохин','космическая 211, кв. 3192','Новосибирск','Новосибирская область','RUSSIAN FEDERATION','630092','8 913 754 1343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 05:03:55',0,NULL,3,1,2,1,NULL,'alex_r_54\r庄'),(8384,664190337001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','beyond_id','dina_anggraeni@hotmail.com','Yozandra','Jl. irigasi danita timur dalam 1 blok C1/11 RT10/14<br>Telp : 08129665829','Bekasi Timur','Jawa Barat','INDONESIA','17112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 05:39:44',0,NULL,3,1,2,1,NULL,'beyond_id\r庄'),(8385,759554404016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',3,'AA1301',5.61,'hutongstore','newthebeaut','stevenewton55@hotmail.com','Stephen Newton','10 Hazel Drive<br>Ripley','Woking','Surrey','UNITED KINGDOM','GU23 6LQ','01483224154','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 06:19:31',0,NULL,3,1,2,1,NULL,'newthebeaut\r庄'),(8386,705048947002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','smokebigbird70','barton54@bigpond.com','Jill Barton','9 James Cook AV','Singleton','New South Wales','AUSTRALIA','2330','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-04-24 07:41:36',0,NULL,3,0,2,1,' ','smokebigbird70\r白色\r庄'),(8387,664212919001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 07:42:28',0,NULL,3,1,17,0,NULL,'steeeevie'),(8388,705048730002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 07:42:30',0,NULL,3,1,4,1,' YW864941515CN\r','steeeevie\r背景布 1.6  x3m    1（粉色）\r100*150 5合1 反光板   1\r反光板支架    1\r燕文 一票两件  反光板和布一票， 反光板支架一票\r申报： reflector holder  $25\r刘'),(8389,705048919002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','steeeevie','steeevie@gmx.at','Stefan Renner','Anton-Haidinger-Siedlung 8/8/2','Rotheau an der Traisen','','AUSTRIA','3153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 07:42:33',0,NULL,3,0,17,0,NULL,'steeeevie'),(8390,704379472002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','cypher779','drobyshev.ev@gmail.com','Evgeniy Drobyshev','Perervinskiy bl. 21-1-275','Moscow','Moscow','RUSSIAN FEDERATION','109469','+79099418736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 08:05:03',0,NULL,3,1,3,1,' RA117739615CN\r','cypher779\r看看是否2kg以下\r刘\r'),(8391,664220889001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','blueheron2002','ronswords@comcast.net','Ronald J Swords','6123 N Lidgerwood St<br>Apt 305','Spokane','WA','UNITED STATES','99208-1056','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-24 08:15:43',0,NULL,3,1,1,1,NULL,'blueheron2002\r庄'),(8392,705074992002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ital-nyah','sold18@hotmail.com','Dan Sjölund','Loftagatan 1B','Gamleby','Kalmar','SWEDEN','59432','0046733867735','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 09:23:46',0,NULL,3,1,3,1,'RA117739898CN\r ','ital-nyah\r庄'),(8393,775401858015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','uguraci80','uguraci@gmail.com','UGUR ERBASOL','mehmetcik bulvari no:55/14 uckuyular karabaglar','IZMIR','','TURKEY','35350','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 11:53:25',0,NULL,3,1,2,1,NULL,'uguraci80\r申报：GIFT/\r庄\r\r'),(8394,775418629015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','edwardnapthine','enapthin@gmail.com','Edward Napthine','14 Gardner Ln','Kensington Banks','Victoria','AUSTRALIA','3031','0433997887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 12:36:10',0,NULL,3,1,2,1,NULL,'edwardnapthine\r庄'),(8395,705146451002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','irishpjeongco2010','irishpjeongco@yahoo.com.ph','Irish Jeongco','Ta-al Street Phase 5, Alta Tierra Village, Jaro','Iloilo City','','PHILIPPINES','5000','0333206210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 13:34:20',0,NULL,3,1,2,1,NULL,'irishpjeongco2010\r庄'),(8396,0,110677756384,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',0.99,'hermeshine','shanoobilly','azeemdadream27@yahoo.com','Azeem qureshi','8 Saint Andrews Ln','Annandale','NJ','UNITED STATES','08801-1620','(908) 400-7342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:34:23',0,NULL,3,1,1,1,NULL,'shanoobilly\r庄'),(8397,0,110677756305,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','johnhz','jjjjjjjjjjjjohn@yahoo.com','John Harasimowicz','7701 Hemlock Ave','Gary','IN','UNITED STATES','46403-2162','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:34:44',0,NULL,3,1,1,1,NULL,'johnhz\r庄'),(8398,0,110677756646,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.99,'hermeshine','professorc_123','professor_frog@hotmail.com','Thomas Campbell','30500 Bermont Rd','Punta Gorda','FL','UNITED STATES','33982-9711','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:36:46',0,NULL,3,1,1,1,NULL,'professorc_123\r庄'),(8399,0,110677757103,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',0.99,'hermeshine','normancha','alanzh@comcast.net','Alan Zhang','2125 Bucolic Ct<br>Xech Information Systems','Nolensville','TN','UNITED STATES','37135-9541','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 14:36:54',0,NULL,3,1,1,1,' ','normancha\r庄'),(8400,0,110677756134,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',0.99,'hermeshine','fishing26508','fishing26508@yahoo.com','Clayton  Eakin','1460 Smithtown Rd','Morgantown','WV','UNITED STATES','26508','(304) 276-7866','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 15:06:14',0,NULL,3,1,1,1,NULL,'fishing26508\r庄'),(8401,775495168015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','solowing0220','godgundam0220@live.com','Lim wee yang','choa chu kang street 52 block 545 #12-12','default','','SINGAPORE','680545','+6597886807','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 15:35:39',0,NULL,3,1,11,1,NULL,'solowing0220\r庄'),(8402,663629802001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','districtland','sia.annie89@gmail.com','Annie Sia Kin Toh','No 15, Jalan Wangsa Budi 4<br>Jalan Wangsa Melawati','Kuala Lumpur','wilayah persekutuan','MALAYSIA','53300','0178507755','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 15:50:57',0,NULL,3,1,3,1,' RA117739650CN\r','districtland\r庄'),(8403,705197224002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','zoomer_vn','dzungtranvn@gmail.com','TRAN Tiendung','Unit 5/52<br>McKillop','GEELONG','Victoria','AUSTRALIA','3220','0413638811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 15:57:35',0,NULL,3,1,2,1,NULL,'zoomer_vn\r庄'),(8404,664358760001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','floydtherappa','awknoflicek@ole.augie.edu','Andrew Knoflicek','2505 S Jefferson Ave','Sioux Falls','SD','UNITED STATES','57105-3413','(605) 339-3088','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 16:06:12',0,NULL,3,1,1,1,NULL,'floydtherappa\r庄'),(8405,664375991001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','clw1','ag668@lafn.org','Calvin Weisberger','538 11th St','Santa Monica','CA','UNITED STATES','90402','(310) 393-2932','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 16:20:16',0,NULL,3,1,1,1,' ','clw1\r庄'),(8406,664383722001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 16:37:08',0,NULL,3,1,2,1,' ','nowell63\r庄'),(8407,664417725001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','nathanael2003','ramonaandsunil@rogers.com','Ramona Ramjit','26 Meandering Trail','Scarborough','ON','CANADA','M1B6E8','(416) 284-5856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 17:39:41',0,NULL,3,1,2,1,NULL,'nathanael2003\r庄'),(8408,775585686015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','bigyingyang','mikegistrong@hotmail.co.uk','Mike Coughlan','19 Kings Ave','Corsham','Wiltshire','UNITED KINGDOM','SN13 0EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 17:59:37',0,NULL,3,1,2,1,NULL,'bigyingyang\r庄'),(8409,664446752001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','2639717','hcard@stny.rr.com','Harold F Card','22 Lake street<br>po 334','morris','NY','UNITED STATES','13808','(607) 263-9717','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 18:24:38',0,NULL,3,1,1,1,NULL,'2639717\r庄'),(8410,705282246002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','shourov007','shourov007@hotmail.com','Toufiq Hasan','Unit 13/53 King George street','Victoria Park','Western Australia','AUSTRALIA','6100','0434435219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 18:26:46',0,NULL,3,1,2,1,NULL,'shourov007\r庄'),(8411,775622716015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','mogeykmelllor','kevin.dmellor@yahoo.co.uk','Kevin Mellor','6 Glencoe Close<br>Holmes Chapel','Crewe','Cheshire','UNITED KINGDOM','CW47HX','01477535087','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-24 18:45:22',0,NULL,3,1,2,1,NULL,'mogeykmelllor\r庄'),(8412,705294400002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','advmuscle','marvin@medical-massage.net','Advanced Muscle Care','11231 Richmond Ave.<br>Ste D110','Houston','TX','UNITED STATES','77082','','NoPaymentFailure','CheckoutComplete','Other','2011-04-24 18:47:26',0,NULL,3,1,3,1,' RA117739884CN\r','advmuscle\r刘'),(8413,0,110677756709,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',2.25,'hermeshine','palermo22','palermo22@aol.com','Gerald K Kandel','924 Bea Court','Nipomo','CA','UNITED STATES','93444-6622','(805) 343-0848','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 18:48:27',0,NULL,3,1,1,1,' ','palermo22\r庄'),(8414,759882912016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sonfr123','sonelius@hotmail.com','Fredrik Sonelius','Torpagatan 14','Jönköping','','SWEDEN','55333','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-24 19:00:44',0,NULL,3,1,2,1,NULL,'sonfr123\r庄\r'),(8415,664484851001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','gerena4jc787','gerena4jc@gmail.com','Angel Gerena','5351 Hillock Way','Orlando','FL','UNITED STATES','32810','(407) 731-3437','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 19:32:41',0,NULL,3,1,1,1,NULL,'gerena4jc787\r庄'),(8416,0,110677756571,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',0.99,'hermeshine','gmoratz','gamoratz@gmail.com','gary moratz','5936 Jellico Ave','encino','CA','UNITED STATES','91316','(818) 983-3248','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:29:51',0,NULL,3,1,1,1,NULL,'gmoratz\r庄'),(8417,0,110677757008,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',1.51,'hermeshine','tradertodd2','million2one@netzero.net','Todd Tinsley','13320 Bar C','San Antonio','TX','UNITED STATES','78253-5203','(210) 679-5562','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:32:08',0,NULL,3,1,1,1,NULL,'tradertodd2\r庄'),(8418,664519954001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','vinfinite','vtn86@hotmail.com','vinh nguyen','1781 Chatfield Cir','stockton','CA','UNITED STATES','95209-4240','(209) 598-0915','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 20:42:50',0,NULL,3,1,1,1,NULL,'vinfinite\r庄'),(8419,664530293001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','ricabras','photobrasil@gmail.com','Ricardo Brasil','Rua Mucu nº 10 apto 102, Alto da Boa Vista','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531-180','5521-2570-4633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-24 21:07:53',0,NULL,3,1,2,1,' ','ricabras\r庄'),(8420,705374022002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','mkwb3','mkwb@sbcglobal.net','Katherine Boruch','105 Grace Ln','Fox River Grove','IL','UNITED STATES','60021','(847) 516-1190','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 21:24:37',0,NULL,3,1,1,1,' ','mkwb3\r庄'),(8421,705394950002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','michalw84','michalwallentinsen@hotmail.com','Michal Wallentinsen','Marmorveien 4','Nedenes','Aust-Agder','NORWAY','4823','92677669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:45:42',0,NULL,3,1,2,1,NULL,'michalw84\r庄'),(8422,664566510001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','artemyevvitaly','applemarkt@mail.com','Artemyev Vitaly','str. Fadeeva 65-127','Samara','','RUSSIAN FEDERATION','443081','9277058003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-24 22:59:06',0,NULL,3,1,2,1,NULL,'artemyevvitaly\r庄'),(8423,664565660001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','texurastar','texurastar@verizon.net','W.A. Mason','2547 Bent Oaks Dr','Colonial Heights','VA','UNITED STATES','23834-1700','(804) 640-4116','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-24 23:01:38',0,NULL,3,1,1,1,NULL,'texurastar\r庄'),(8424,664585914001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','boricua11411','lortiz2@wi.rr.com','Laureano Ortiz','N1615 Bluebird dr.','Lake Geneva','WI','UNITED STATES','53147','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 00:08:04',0,NULL,3,1,1,1,NULL,'boricua11411\r庄'),(8425,0,110677756622,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',1.98,'hermeshine','silver-quest','c2farr@yahoo.com','Charles Farrier','1548 Glenmore Ave','Baton Rouge','LA','UNITED STATES','70808','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 01:07:12',0,NULL,3,1,1,1,NULL,'silver-quest\r庄\r72mm nikon  镜头盖   1\r72mm uv    1\r'),(8426,705459471002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','jazz_papa','uflathm@cpcus.jnj.com','Ullrich Flathmann','310 Tyler Court','New Hope','PA','UNITED STATES','18938','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 01:51:17',0,NULL,3,1,1,1,' ','jazz_papa\r刘'),(8427,705461039002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lewsh','lewsinhoe8@yahoo.com','SIN HOE LEW','BLK 134 TECK WHYE LANE, #07-377','default','','SINGAPORE','680134','67602209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 01:55:14',0,NULL,3,1,11,1,NULL,'lewsh\r刘'),(8428,0,110677756242,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',2.25,'hermeshine','mlou5288','manwlouie@netzero.com','Man Louie','1926 Clove Rd','Staten Island','NY','UNITED STATES','10304-1633','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 02:57:59',0,NULL,3,1,1,1,NULL,'mlou5288\r庄'),(8429,705479630002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','abx1982','robert_bonilla@hotmail.com','Robert E. Bonilla','A7 Urb Santa Marta','San German','PR','UNITED STATES','00683-4402','(787) 717-3269','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-25 03:01:41',0,NULL,3,1,3,1,'RA117739836CN\r ','abx1982\r庄'),(8430,705481325002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','wilfredjohn2009','wilfredpaulse@gmail.com','Wilfred Paulse','Rua Cel. Bernadino d Melo 4705/c 79<br>Bairro da Luz,','Nova Iguaçu','Rio de Janeiro','BRAZIL','26262-070','55-21-26697051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 03:07:46',0,NULL,3,1,2,1,NULL,'wilfredjohn2009\r庄'),(8431,0,120714815130,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',0.99,'hermeshine','thrifty_crystal','puppawuppa@yahoo.com','crystal herrera','14811 West Rd<br>Apt 4107','houston','TX','UNITED STATES','77095-3188','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:20:24',0,NULL,3,1,1,1,' ','thrifty_crystal\r庄'),(8432,0,110677756442,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',1.11,'hermeshine','n555wp','pilot4hire@mac.com','Woor Pardo','6514 Farthing Dr','Colorado Springs','CO','UNITED STATES','80906-8651','(703) 626-6917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:39:27',0,NULL,3,1,1,1,NULL,'n555wp\r'),(8433,0,120714815736,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',1.98,'hermeshine','charlestonsasha','charlestonsasha@hotmail.com','Alexander Pozyuban','8221 Pleasant Ridge Dr','North Charleston','SC','UNITED STATES','29420-8326','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 03:53:49',0,NULL,3,1,1,1,' ','charlestonsasha\r67mm  Canon 镜头盖   1\r58mm  Canon 镜头盖   1\r庄'),(8434,664645142001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','fashionchic543','kuanalex@hotmail.com','Jessica Kuan','1105-8288 SABA Road','Richmond','BC','CANADA','V6Y 4C8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 04:29:31',0,NULL,3,1,3,1,'RA117739955CN\r','fashionchic543\r庄'),(8435,664654034001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','qadsha','qadsha@yahoo.com','qadeer shams','90545-629 markahm rd','scarborough','ON','CANADA','m1h 3g7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 04:39:18',0,NULL,3,1,2,1,' ','qadsha\r庄'),(8436,0,110677756540,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',0.99,'hermeshine','dennis.urgo','dsurgo@hotmail.com','Dennis Urgo','705 Summit St','Eveleth','MN','UNITED STATES','55734-1441','(218) 780-9123','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 05:07:26',0,NULL,3,1,1,1,NULL,'dennis.urgo\r庄'),(8437,0,120714815533,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',0.99,'hermeshine','rockster888','marvinchoi2003@yahoo.com','marvin choi','1922 Shoreline Dr','missouri city','TX','UNITED STATES','77459-1680','(832) 283-8444','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 05:35:39',0,NULL,3,1,1,1,' ','rockster888\r庄'),(8438,705497026002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','tarasovd','wardogs@mail.ru','Tarasov Dmitry','Trofimova, 36-1','Kemerovo','Kemerovskaya obl','RUSSIAN FEDERATION','650004','7-908-944-83-69','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 05:57:15',0,NULL,3,1,3,1,' RA117739941CN\r','tarasovd\r刘'),(8439,664666648001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','chriswwg','chriswwg2@gmail.com','Chris Wong','52A, Jalan Perdana 6/3,<br>Pandan Perdana,','Kuala Lumpur','WP','MALAYSIA','55300','0123782832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:04:10',0,NULL,3,1,2,1,' ','chriswwg\r庄'),(8440,775026914015,250621659362,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',188.95,'hutongstore','morkemyndy','centaur2002@libero.it','gabriele tosti','V.le Roma 80','Predappio','FO','ITALY','47016','0543922584','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 06:37:07',0,NULL,3,1,4,1,'YW864941552CN\r ','morkemyndy\r庄\r欧标\r80cm 5合1  反光板   1\r反光板支架     1\r100x150cm 5in1 反光板   1\r4灯头柔光箱×2\r灯架×3\r45w灯泡×8\r灯架包   1\r----\r燕文 1票2件\r申报：Lighing kit / 40$'),(8441,705496329002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','puttanon2010','n_puttanon@hotmail.com','supeyamas puttanon','68/75 moo.10 thambon bangmaenang ','bang yai','nonthaburi','THAILAND','11140','081636453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 06:49:01',0,NULL,3,1,2,1,NULL,'puttanon2010'),(8442,760169735016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','sergiosl','sergiosl.pt@gmail.com','Sergio S Lopes','Estrada de Vilar, 55 1º dir','Aveiro','Aveiro','PORTUGAL','3810-195','(351) 234345422','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 08:49:08',0,NULL,3,1,2,1,' ','sergiosl'),(8443,705544908002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','bergythebergfull','davidbowers@optushome.com.au','David Bowers','32 Grandview Road<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0403803856','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 08:53:43',0,NULL,3,1,3,1,' RA117739535CN\r','bergythebergfull'),(8444,0,110677756500,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',0.99,'hermeshine','lezst3','lzheng95@yahoo.com','Lei Zheng','1617 Queen Charlotte Dr<br>Apt 2','Sunnyvale','CA','UNITED STATES','94087','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 09:36:28',0,NULL,3,1,1,1,' ','lezst3\r庄'),(8445,664717675001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','torero_loco','torero0@gmail.com','Daniel GIMENEZ ALBA','avda cordoba 25','Yecla','Murcia','SPAIN','30510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 09:55:18',0,NULL,3,1,4,1,' YW864488981CN','torero_loco\rreflector holder  $20\r刘'),(8446,775968065015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','561934','mukundbhai@ntlworld.com','Mukundbhai Patel','56, Bardolph Street','Leicester','Leicestershire','UNITED KINGDOM','LE4 6EF','01162332172','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-25 10:46:02',0,NULL,3,1,4,1,' YW864489003CN','561934\rtripod  $25\r王'),(8447,705574770002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sharikas1976','sharikh.abdulaziz@gmail.com','abdulaziz alsharikh','P. O. Box 8171','Dhahran','East','SAUDI ARABIA','31311','00966504825572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 10:52:34',0,NULL,3,1,3,1,'RA117739235CN ','sharikas1976\r刘\r'),(8448,760224418016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','sms2info','holowaty@gmail.com','Bartlomiej Holowaty','32 The Moorings<br>Bailick Road','Midleton','Cork','IRELAND','default','214630311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 11:40:31',0,NULL,3,0,2,1,NULL,'sms2info\r庄'),(8449,705586695002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','g_stman','guysht123@gmail.com','guy shtibelman','haarava 98','Nesher','','ISRAEL','36863','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 11:44:12',0,NULL,3,1,3,1,'RA17739266CN RA117739408CN\r','g_stman\r分2个挂号小包发\r刘\r'),(8450,664750161001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','bibd0531','hubymaera@hotmail.com','Pg Omarali Saifuddin Pg Tengah','No.22 Spg.105 Jln Kuala Lurah<br>Kg.Limau Manis','Bandar Seri Begawan','Pengkalan Batu','BRUNEI DARUSSALAM','BH2323','+6738246319','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 11:58:06',0,NULL,3,1,3,1,'RA117739221CN ','bibd0531\r庄\r'),(8451,663160353018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'',200,'photographyacc','glumazojd','sansei.foto@gmail.com','Alexander Chizhov','Street pestelya house 2 apartment 25','Moscow','','RUSSIAN FEDERATION','127490','+7-926-597-34-01','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-25 12:09:07',0,NULL,3,1,17,0,NULL,'glumazojd'),(8452,663160728018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','glumazojd','sansei.foto@gmail.com','Alexander Chizhov','Street pestelya house 2 apartment 25','Moscow','','RUSSIAN FEDERATION','127490','+7-926-597-34-01','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-25 12:10:19',0,NULL,3,1,5,1,' CP226269064CN\r','glumazojd\r（欧标）\r2mx2m 背景架   1\r1.6mx2m 背景布   1（白）\r2m 灯架  3\r斜臂    1\r50x70cm 单灯头 棚   3\r115w 220v 灯泡   3\r灯架包    1\r庄\r需邮件'),(8453,760234791016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','j_ruiz','jordi_ruiz@hotmail.com','Jordi Ruiz Baeza','Studio Cocina<br>Avd/ Casalduch nº47','Castellon','Comunidad Valenciana','SPAIN','12005','669941866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 12:11:00',0,NULL,3,1,3,1,NULL,'j_ruiz\r庄\rRA117739218CN\r'),(8454,705607005002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 12:55:17',0,NULL,3,1,2,1,NULL,'andrewespuni1979\r庄'),(8455,705612289002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','lup1ne','lup1ne@hotmail.com','Tom Wheeler','19 Boyce Av<br>Briar Hill','Melbourne','Victoria','AUSTRALIA','3088','0403300076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 13:15:59',0,NULL,3,1,2,1,' ','lup1ne\r庄'),(8456,776024500015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','inoxcrompekka','pekka.nikander@netti.fi','pekka nikander','nerdrumintie<br>31','pyhtää','Oletus','FINLAND','49270','0405519235','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 13:29:40',0,NULL,3,1,2,1,NULL,'inoxcrompekka\r庄'),(8457,664782030001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',2,'AA1208',7.16,'hermeshine','biotrufas','dmelchordiaz@yahoo.com','DAVID MELCHOR DIAZ','C/ Rozabella 4, Ed. Bruselas, PYRO<br>Complejo Europa Empresarial','Las Rozas','Madrid','SPAIN','28290','654227693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 13:54:52',0,NULL,3,1,2,1,NULL,'biotrufas\r庄'),(8458,664794817001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','2011.rober','bennett.ok@gmail.com','Roberto Bennett','Medrano 1950, 12° A','Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1425','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-25 14:50:39',0,NULL,3,1,2,1,' ','2011.rober\r庄'),(8459,705641661002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','dc251978','dtm225@gmail.com','Dennis Chen','14296 brant ct','corona','CA','UNITED STATES','92880','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 14:53:22',0,NULL,3,1,1,1,' ','dc251978'),(8460,705648044002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','celesao55','celesao5@hotmail.com','john moraitis','nikolaou moutou 11','itea','fokida','GREECE','33200','+306937292448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 15:12:01',0,NULL,3,1,2,1,' ','celesao55\r庄'),(8461,705649271002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','fernt2003','ftortora@gmail.com','Fernando Tortora','Alsina 875 Piso 2','Buenos Aires','Buenos Aires','ARGENTINA','1087','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 15:19:20',0,NULL,3,1,2,1,NULL,'fernt2003\r庄'),(8462,776068367015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','Betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 15:19:37',0,NULL,3,1,2,1,NULL,'remiaus\r庄'),(8463,776087552015,250692238930,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','singersax','drury.lizzie@gmail.com','Elizabeth Drury','41 The Strand<br>Topsham','Exeter','Devon','UNITED KINGDOM','EX3 0AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 16:01:34',0,NULL,3,1,2,1,NULL,'singersax'),(8464,0,120714815256,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.99,'hermeshine','lyla3','creegeller@yahoo.com','Tracy Cree','PO Box 915','Storrs Mansfield','CT','UNITED STATES','06268-0915','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 16:17:47',0,NULL,3,0,1,1,NULL,'lyla3\r庄'),(8465,760337089016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','vidicigor21','vidicigor@gmail.com','Igor Vidic','Mlakarjeva ulica 11','4208 Šenčur','Slovenija','SLOVENIA','+386','0038640419360','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 16:35:09',0,NULL,3,1,2,1,NULL,'vidicigor21\r庄'),(8466,664851357001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','paula9156','garyk9156@hotmail.com','Gary Kirkpatrick','11311 Bertrand Ave','Granada Hills','CA','UNITED STATES','91344','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 17:05:51',0,NULL,3,0,1,1,NULL,'paula9156\r52mm (2)\r55mm (2)\r58mm (1)\r62mm (1)\r67mm (2)\r72mm (1)\r77mm (1)\r庄'),(8467,760355788016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','panos_pc2246','panios_ast@yahoo.gr','Panagiotis   Hatzipananis','Campos    Iou','Ios     Cyclades','Greece','GREECE','84001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 17:10:34',0,NULL,3,1,2,1,NULL,'panos_pc2246\r庄'),(8468,705695364002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','victorarandagarcia','victorarandagarcia@yahoo.es','Víctor Aranda García','Av. Blasco Ibañez, 64. Esc: B. Pta: 5','Valencia','Comunidad Valenciana','SPAIN','46021','600336126','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 17:13:24',0,NULL,3,1,3,1,'RA117739178CN\r ','victorarandagarcia\r庄\r'),(8469,705691850002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','vcha8330','vince@vincechanblog.ca','Vincent Chan','91 Durie St.','Toronto','ON','CANADA','M6S 3E7','(416) 762-1255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:00:15',0,NULL,3,1,17,0,NULL,'vcha8330'),(8470,664855782001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','vcha8330','vince@vincechanblog.ca','Vincent Chan','91 Durie St.','Toronto','ON','CANADA','M6S 3E7','(416) 762-1255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:00:16',0,NULL,3,1,3,1,'RA117739164CN ','vcha8330\r单灯头    2\r反光伞    1\r庄\r'),(8471,705702263002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','david_chapple','melanie_chapple@yahoo.co.uk','David Chapple','Venn Hayes<br>Higher Metcombe','Ottery St Mary','Devon','UNITED KINGDOM','EX11 1SR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-25 18:13:06',0,NULL,3,1,2,1,NULL,'david_chapple.\r庄'),(8472,664332416001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','amasya05','kuntayebay@gmail.com','Kuntay Aktaş','Libya caddesi<br>96 lar sitesi 6/6','Ankara','Kolej','TURKEY','06420','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 18:15:26',0,NULL,3,1,3,1,'RA117739252CN\r','amasya05\r刘\r\r'),(8473,664920698001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','jmaphotographic','jmasoccer@aol.com','Jamie Antonioli','3142 Oakwood Ln','Alamo','CA','UNITED STATES','94507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 19:19:19',0,NULL,3,1,1,1,' ','jmaphotographic\r庄'),(8474,705788748002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','stanislaw999*123','rude@tesco.net','Andrew Rudolf','70 Canterbury Drive<br>Washinborough','Lincoln','Lincolnshire','UNITED KINGDOM','ln4 1sx','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 20:12:58',0,NULL,3,1,3,1,'RA117739249CN\r','stanislaw999*123\r刘\r'),(8475,664962021001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','oshri3','yaniv.oshri@gmail.com','Oshri Yaniv','alumim 28<br>47','Kiryat-Netafim','','ISRAEL','44815','972-052-6330258','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 21:28:36',0,NULL,3,1,3,1,'RA17739354CN \rRA117739337CN\r','oshri3\r分2个挂号小包发\r刘'),(8476,760513027016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','jeeg.1975','biagio.pelligra@gmail.com','Biagio Pelligra','via Toselli 136','Palermo','PA','ITALY','90143','3931111376','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 21:45:18',0,NULL,3,1,2,1,NULL,'jeeg.1975\r庄'),(8477,776290299015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','saabze','zebaas@me.com','Laurens Wilming','5 Pinhoe Drive','Haverhill','Suffolk','UNITED KINGDOM','CB9 7WF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 21:49:29',0,NULL,3,1,3,1,NULL,'saabze\r庄\rRA17739270CN'),(8478,760517974016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','norad100','mj12templar@gmail.com','Oliver Galea','Blk 1, Flat 7, Appt. 21-09-1964,<br>Triq tal-Fieres,','Kirkop','','MALTA','KKP 1541','(356) 99062891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 21:53:29',0,NULL,3,1,2,1,' ','norad100\r庄'),(8479,776300826015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','mattakadeimos','matt.wagg@ntlworld.com','Matt Wagg','63 Hart Avenue','Sandiacre','Nottinghamshire','UNITED KINGDOM','NG105FY','01159398955','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 22:16:26',0,NULL,3,1,3,1,NULL,'mattakadeimos\r庄\rRA17739306CN'),(8480,760527751016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','tomonners','onners@hotmail.com','Thomas ONLEY','1 St Peter\'s Road<br>Newchurch','Rossendale','Lancashire','UNITED KINGDOM','BB4 9EZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-25 22:22:01',0,NULL,3,1,2,1,NULL,'tomonners\r庄'),(8481,705844254002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','aimee-2605','ayjones@bigpond.net.au','Aimee Jones','6 Doveleys Rd','Como West','New South Wales','AUSTRALIA','2226','0400768428','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-25 22:50:09',0,NULL,3,0,3,1,NULL,'aimee-2605（已入库）\r3XL\r庄\rRA17739297CN'),(8482,705848358002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',14.4,'hermeshine','mgrande','jbrhoward@aol.com','Jerry Howard','3302 N. Salida del Sol','chandler','AZ','UNITED STATES','85224','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-25 23:03:31',0,NULL,3,1,1,1,NULL,'mgrande\r庄'),(8483,776325487015,250801607283,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',35,'hutongstore','dfbugeja','david@artandconservation.net','david bugeja','22, Our Saviour Street,','Qrendi','','MALTA','QRD 1700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-25 23:31:29',0,NULL,3,1,3,1,'RA17739345CN \rRA117739310CN\r','dfbugeja\r注意数量！\r分两个小包发\r刘'),(8484,665025496001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','2000hero','viviwallart@gmail.com','SHI HUA CHEN','4842 S KENYON ST','SEATTLE','WA','UNITED STATES','98118-4133','(206) 227-6096','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 00:32:52',0,NULL,3,0,1,1,NULL,'2000hero\r白色\r庄\r'),(8485,665026852001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','vcrazy111','zenvcrazy111@gmail.com','Vi Tran','303 Pennyhill Dr','San Jose','CA','UNITED STATES','95127-1829','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 00:34:15',0,NULL,3,1,1,1,NULL,'vcrazy111\r庄'),(8486,705875309002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','ricabras','photobrasil@gmail.com','Ricardo Brasil','Rua Mucu nº 10 apto 102, Alto da Boa Vista','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531-180','5521-2570-4633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 00:46:29',0,NULL,3,1,3,1,'RA17739283CN ','ricabras\r2XL\r庄\r'),(8487,665068516001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','saavpiz','daniel_piz@hotmail.com','Daniel Saavedra','Carrera 20 # 51 - 46 apto 301','Bogota','Cundinamarca','COLOMBIA','11001000','3005642135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 03:25:14',0,NULL,3,1,2,1,NULL,'saavpiz\r庄'),(8488,665070064001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','dbuker','djbecommerce@gmail.com','Daniel J. Buker','1111 E Tennessee St<br>Fla Dental Association','Tallahassee','FL','UNITED STATES','32308-6937','(850) 345-9922','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 03:29:34',0,NULL,3,1,1,1,' ','dbuker\r庄'),(8489,760625056016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',120,'hutongstore','jkegholm','kalle@jkegholm.dk','Kalle Egholm','Bellisallé 14','Horsens','','DENMARK','DK8700','004561304107','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 03:47:45',0,NULL,3,1,4,1,' YW864488992CN','jkegholm\r欧标\rlighting kit $26\r王'),(8490,760627156016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','bigtors70','bigtors@gmail.com','Aleksejs Jegorovs','26 Montfort','Monaghan','Monaghan','IRELAND','default','3534762856','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 03:54:09',0,NULL,3,1,2,1,NULL,'bigtors70\r庄'),(8491,665084522001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sergejstrelchenko2010','sergej.strelchenko@mail.ru','Сергей Стрельченко','Фрунзе 14<br>Фрунзе 14','станица Платнировская','Краснодарский край Кореновский район','RUSSIAN FEDERATION','353177','89284162835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 04:57:18',0,NULL,3,1,17,0,NULL,'sergejstrelchenko2010'),(8492,665085218001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sergejstrelchenko2010','sergej.strelchenko@mail.ru','Сергей Стрельченко','Фрунзе 14<br>Фрунзе 14','станица Платнировская','Краснодарский край Кореновский район','RUSSIAN FEDERATION','353177','89284162835','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 04:59:48',0,NULL,3,1,5,1,' CP226269055CN','sergejstrelchenko2010\r肩架   2\r需邮件'),(8493,705932898002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','delatapu88','felipe_molinad@yahoo.com','felipe molina','5/162 old south head road<br>bellevue hill','sydney','New South Wales','AUSTRALIA','2023','0447976759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 05:02:11',0,NULL,3,1,2,1,NULL,'delatapu88\r庄'),(8494,665092922001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',65.96,'hermeshine','almearaj','aalmiraj5@gmail.com','Abdullah Jaffar Makki AlMearaj','P.O. Box 20028','Qateef','','SAUDI ARABIA','31911','00966503893668','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 05:55:20',0,NULL,3,1,3,1,NULL,'almearaj\r看看两个斜臂有没有可能在2kg以下， 如果不行，就发两个小包\rRA117739385CN'),(8495,665099326001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 06:31:49',0,NULL,3,1,17,0,NULL,'phreak_cz'),(8496,705949232002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:33:52',0,NULL,3,1,17,0,' ','phreak_cz'),(8497,665100069001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','phreak_cz','krizjakub@yahoo.com','Mr. Jakub Kriz','Rooseveltova 2129','Litvinov','','CZECH REPUBLIC','436 01','00420724044447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 06:34:54',0,NULL,3,1,3,1,'RA117739399CN ','phreak_cz\r2m 灯架   1\r双灯头 欧标  1\r反光伞    1\r庄\r'),(8498,665102497001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 06:48:45',0,NULL,3,1,3,1,'RA117739371CN ','molchanov_r\r庄\r'),(8499,665119312001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','biker1011985','biker@email.ua','Evgen Stadnik','164a Chapaeva Street, Apt.29','Alchevsk','Luganskaya oblast','UKRAINE','94207','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-04-26 08:42:30',0,NULL,3,1,3,1,' RA117739500CN','biker1011985\r庄'),(8500,760691231016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','becs308','becsgoodrum@yahoo.co.uk','Miss R Goodrum','7 The Glebe<br>Thorverton','Exeter','Devon','UNITED KINGDOM','EX5 5LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 09:01:00',0,NULL,3,1,2,1,NULL,'becs308'),(8501,705940882002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','kikrisda','kasadit@yahoo.com','Krisda Indrasthitya','Faculty of Architecture<br>KMITL.','Lardkabang','Bangkok','THAILAND','10520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 09:11:16',0,NULL,3,1,2,1,NULL,'kikrisda'),(8502,705980465002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','2010darkcloud1985','s.dark123@gmail.com','Spiriadis Alexandros','Panormou 6','Xanthi','προεπιλογή','GREECE','67100','2541100998','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 09:27:31',0,NULL,3,1,3,1,' RA117739439CN','2010darkcloud1985\r庄'),(8503,704681607002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',78.9,'hermeshine','houser1974','torralb@gmail.com','Carlos Torralba Ruiz','Avda. Condesa de Chinchon 17 , Ch 11','Boadilla del Monte','Madrid','SPAIN','28660','656359068','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 09:36:43',0,NULL,3,1,4,1,' YW864488863CN','houser1974\r2m背景架（ 白 黑）\rbackground support $25\r庄'),(8504,705993704002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','dnshall','dnshall@yahoo.com','Dennis Hall','2716 Cedar Street','Berkeley','CA','UNITED STATES','94708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 10:26:04',0,NULL,3,1,1,1,' ','dnshall\r庄'),(8505,665140384001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','liliborisova','liligb@abv.bg','Lili Borisova','Aleksandar Stamboliyski 25','Golyama Brestnitsa','Lovech/Yablanitsa','BULGARIA','5753','0899911134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 10:33:00',0,NULL,3,1,2,1,NULL,'liliborisova'),(8506,665150247001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','visistudio','visi_photographer@hotmail.com','ERVIS BOSTANXHI','Ave Gjergj Kastrioti no.12<br>Lagja no 12','KORCA','AL','ALBANIA','7000','+355672065800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 10:43:35',0,NULL,3,1,3,1,'RA117739425CN ','visistudio\rxl\r庄'),(8507,776504277015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','jaronyka','jaroslava.krajcova@gmail.com','Jaroslava Oprendek Krajčová','P. Jilemnického 838/37','Svit','','SLOVAK REPUBLIC','05921','00421 911 952 634','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 10:56:40',0,NULL,3,1,2,1,NULL,'jaronyka\r庄'),(8508,706027052002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','lgianoni82','lgianoni@hotmail.com','Lorena Gianoni','Luis B. Cavia 2888','Montevideo','Montevideo','URUGUAY','11300','598 98 842 086','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 12:40:52',0,NULL,3,1,3,1,' RA117739487CN','lgianoni82\rXL\r庄'),(8509,776539841015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','baklan4ikof','saveleva.da@gmail.com','Дарья Савельева','3-я Владимирская д.8/1 кв. 8','Москва','','RUSSIAN FEDERATION','111123','(926)3455526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 13:05:56',0,NULL,3,1,2,1,' ','baklan4ikof\r庄'),(8510,706034424002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','vokoda','vokoda@gmail.com','Dániel János Vokó','Vörösmarty utca 55 3/9','Budapest','','HUNGARY','1064','+36204943627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:07:34',0,NULL,3,1,3,1,'RA117739495CN ','vokoda\r庄'),(8511,663270116001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','pavelpi88','pi88@yandex.ru','Pavel A Groisman','D.Rishkanu 11-a apt.6','Kishinev','-','MOLDOVA, REPUBLIC OF','2024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 13:08:14',0,NULL,3,1,2,1,NULL,'pavelpi88\r庄'),(8512,0,120711872890,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.25,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 13:46:34',0,NULL,7,1,17,0,' ','george35209\r庄'),(8513,776562813015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:31',0,NULL,3,1,17,0,NULL,'jonesnet57'),(8514,760778775016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:32',0,NULL,3,1,17,0,NULL,'jonesnet57'),(8515,776562814015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jonesnet57','jonesnet57@yahoo.co.uk','Martin Jones','167 College Road','Deal','Kent','UNITED KINGDOM','CT146BX','01304367434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 13:50:33',0,NULL,3,1,3,1,' RA117739473CN','jonesnet57\r反光板  80cm 5合1   1\r橡胶遮光罩 52mm    1\r橡胶遮光罩 72mm    1\r庄\r'),(8516,760786545016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','abonentas00','ajarasius@yahoo.com','Arturas Jarasius','Vyduno al. 25a-1','Kaunas','Kaunas','LITHUANIA','50289','+37067535735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 14:12:39',0,NULL,3,1,2,1,NULL,'abonentas00\r庄'),(8517,665220142001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','mkarpienia','marcin.karpienia@gmail.com','Marcin Karpienia','5B<br>Jamaica Street','Inverness','Highland','UNITED KINGDOM','IV3 8DP','01463240148','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-04-26 15:03:54',0,NULL,3,1,2,1,NULL,'mkarpienia\r庄'),(8518,665221061001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 15:06:44',0,NULL,3,1,2,1,NULL,'cmontechi\r刘'),(8519,760817265016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','tomfromiceland','beele899@planet.nl','Geert van der Beele','van Eyckstraat  38','Maasbree','','NETHERLANDS','5993CV','077-4652641','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 15:31:37',0,NULL,3,1,2,1,NULL,'tomfromiceland\r王'),(8520,665236092001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','legna.nabetse','gelesteban@gmail.com','Angel Esteban Rubio Fernandez','Iglesia 26','Olmeda del Rey - Cuenca','Castilla-La Mancha','SPAIN','16216','696726409','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-26 15:52:27',0,NULL,3,0,3,1,' RA117739411CN','legna.nabetse\rXL\r庄'),(8521,776613639015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','tykelock','richwilliams2001uk@yahoo.co.uk','RICHARD WILLIAMS','18A RECTORY VIEW','LOCKINGTON','East Riding of Yorkshire','UNITED KINGDOM','YO259SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 15:57:14',0,NULL,3,1,2,1,NULL,'tykelock\r王'),(8522,706102407002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','olenka253','olgausa@yandex.ru','Olga Ilinykh','821 Livania Ln','Lexington','ky','UNITED STATES','40509-1758','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-04-26 16:41:49',0,NULL,3,1,3,1,'RA117739442CN ','olenka253\r刘'),(8523,760897918016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','promethius7','promethius747@hotmail.com','Ivan Hocking','38 Nodder Road','Sheffield','South Yorkshire','UNITED KINGDOM','S138DD','01142391224','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 18:18:19',0,NULL,3,1,2,1,NULL,'promethius7\r刘'),(8524,760913924016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','hemligamalin','brand.malin@gmail.com','Malin Brand','Södra Ravingatan 8','Forshaga','','SWEDEN','66730','+4654181909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-26 18:55:44',0,NULL,3,1,2,1,NULL,'hemligamalin\r转接环   52mm   1\r渐变灰  1\r卡座      1\r刘'),(8525,706147951002,120553897299,'Wireless Flash Sync Trigger Receiver NEW pt-04tm ',1,'AB3322',19.99,'hermeshine','lemuag','ergamu@gmail.com','David Lozano Abad','C/ Lagos de Coronas 34,  3ºC','Zaragoza','Aragón','SPAIN','50011','655429392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 18:32:22',0,NULL,3,1,2,1,NULL,'lemuag\r王'),(8526,705118028002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','krisino2009','krisino@inbox.lv','Kristaps Hohs','Baldones str.6','Ogre','','LATVIA','LV-5001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:21:06',0,NULL,3,1,2,1,NULL,'krisino2009\r刘'),(8527,706177845002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','910bradfordlane','xtremeist9@gmail.com','Laure Connelly','662 Trackside Dr','Aberdeen','NC','UNITED STATES','28315-5004','(910) 281-4535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-26 19:32:59',0,NULL,3,1,1,1,' ','910bradfordlane\r庄'),(8528,0,120714815883,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',0.99,'hermeshine','2009jrbsr','jimbettesr@gmail.com','James Bette','145 Biscayne Dr','Athens','GA','UNITED STATES','30606-1801','(706) 353-2742','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 19:35:49',0,NULL,3,1,1,1,NULL,'2009jrbsr\r庄'),(8529,706186151002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dwuw12','dwuw12@hotmail.com','Andrew Fredrickson','2422 S Gray Dr','Lakewood','CO','UNITED STATES','80227-3958','(720) 936-4126','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 19:49:50',0,NULL,3,1,1,1,' ','dwuw12\r庄'),(8530,706189000002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','foh83','freddy_thort@hotmail.com','freddy onaja hirano','pasaje los jaspes 184 balconcillo - la victoria','lima','lima','PERU','lima 13','005112661393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 19:55:55',0,NULL,3,1,2,1,NULL,'foh83\r王'),(8531,760955525016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','cupplesey','andy.cupples@gmail.com','Andrew Cupples','Flat 9, Roscoe House<br>7 Wood End Rd, Erdington','Birmingham','West Midlands','UNITED KINGDOM','B24 8AA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-26 20:00:39',0,NULL,3,1,2,1,NULL,'cupplesey\r王'),(8532,706196428002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','2011oleb','ole-b@hotmail.com','Ole B Hella','Radoeyvegen 2135','Manger','','NORWAY','5936','+47 41233689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:12:07',0,NULL,3,1,3,1,'RA117739368CN ','2011oleb\r王'),(8533,665352555001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','tostegroo_001','tostegroo@yahoo.com.br','Fabio Toste','Rua Almerina Rebuci, 283','São Bernardo do Campo','São Paulo','BRAZIL','09690-040','551143611228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:21:38',0,NULL,3,1,2,1,NULL,'tostegroo_001\r刘'),(8534,665358510001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','nnkp','pham_kim@hotmail.com','Pham Kim','Gueta 2','Savigny','','SWITZERLAND','1073','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:34:38',0,NULL,3,1,2,1,NULL,'nnkp\r刘'),(8535,706208158002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','chudo_alex','chudo1978@yandex.ru','ALEXEY CHUDINOVSKIKH','MAKLINA str., 63а-49','KIROV','KIROVSKAYA OBLAST','RUSSIAN FEDERATION','610035','+79536810128','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 20:39:01',0,NULL,3,0,2,1,NULL,'chudo_alex\r粉\r1.6x3m'),(8536,706245915002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',60,'AA1310',329.4,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-26 22:21:24',0,NULL,3,1,5,1,' CP226269047CN','blinker-182\r庄\r'),(8537,706264839002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','stillenma','mikestill@5615.com','Mike Still','14 Indian Ridge Dr<br>Mike Still And Associates','leominster','MA','UNITED STATES','01453-5233','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-26 23:34:07',0,NULL,3,1,1,1,NULL,'stillenma\r庄\r'),(8538,663861070018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'',280,'photographyacc','neuf-occas31','jjalmero@asiaindustrie.com','Sophie BARBE','9 chemin d\'auzeville, Bat E12','TOULOUSE','Midi-Pyrénées','FRANCE','31400','06.11.08.05.05','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-26 23:46:37',0,NULL,3,1,4,1,'YW864488852CN ','neuf-occas31\r欧标\r2m 灯架   3\r斜臂   1\r50x70cm 单灯头  3\r115W 220V 灯泡  3\r2x2m 背景架  1\r1.6x2.1m 背景布  2（黑+白）\r灯架包  1\r申报：40$ / Lighting Kit\r刘  \r需邮件'),(8539,761052673016,260660053068,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','crazy.ted','crazy_ted55@hotmail.com','Teddy Serriere','59 rue de la libération','bruyeres le chatel','idf','FRANCE','91680','06.75.90.71.06','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-26 23:54:11',0,NULL,3,1,3,1,' RA117739456CN','crazy.ted\r刘'),(8540,706291561002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','axoi1138','aksoy@thisisforyou.com.au','Onur Aksoy','21 Finisterre Drive Keysborough','Melbourne','Victoria','AUSTRALIA','3173','610402834825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 01:23:33',0,NULL,3,1,2,1,NULL,'axoi1138\r刘'),(8541,0,110677756796,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',2.5,'hermeshine','roccooneout1','rtwater1@earthlink.net','Roman  Tkach','1722 Village Dr','Lynden','WA','UNITED STATES','98264-1283','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 03:28:28',0,NULL,3,1,1,1,NULL,'roccooneout1\rcanon和nikon肩带各一条'),(8542,665486362001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','mauricegubiani','mauricegubiani@yahoo.co.uk','Maurice Gubiani c/o OTEK','Level 1, 222 St Kilda Rd<br>St Kilda','Melbourne','Victoria','AUSTRALIA','3182','0409707982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 05:19:35',0,NULL,3,1,3,1,'RA117714105CN\r\\ ','mauricegubiani\r王'),(8543,706354887002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dekalos','sdekalo@gmail.com','shahar dekalo','hamelaacha 2','ramat hasharon','israel','ISRAEL','47445','0544578957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 06:38:46',0,NULL,3,1,2,1,NULL,'dekalos\r王'),(8544,706358058002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mroy3824','nanie3@globetrotter.net','mario roy','60, boul. notre-dame','pont-rouge','QC','CANADA','g3h 3k6','(418) 873-2975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:02:42',0,NULL,3,1,3,1,'RA117714026CN\r ','mroy3824\r王'),(8545,665504955001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','doraditoalvarado','tavobuenaonda@hotmail.com','octavio garcia','7 Gurney Pl, page','Canberra','Australian Capital Territory','AUSTRALIA','2614','0423865333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:11:35',0,NULL,3,1,2,1,NULL,'doraditoalvarado\r王'),(8546,706366154002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',3.55,'hermeshine','stopframe','andrey@yarigin.com','Andrey Yarigin','Pushkinskaya street<br>6-88','Scherbinka','Moscow region','RUSSIAN FEDERATION','142172','+7(926)495-0860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:42:08',0,NULL,3,1,17,0,NULL,'stopframe'),(8547,706365917002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT018',9.74,'hermeshine','stopframe','andrey@yarigin.com','Andrey Yarigin','Pushkinskaya street<br>6-88','Scherbinka','Moscow region','RUSSIAN FEDERATION','142172','+7(926)495-0860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 07:42:10',0,NULL,3,1,3,1,'RA117722359CN\r','stopframe\r52mm 环架   2\r49mm 接口环    2\rRA17714012CN\r\\ \r王\r上次少发了2个普通卡座，用挂号小包补发.'),(8548,776551493015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','andreccarvalho','andrecostacarvalho@gmail.com','Andre Carvalho','Praceta Mario de Sa Carneiro<br>n-5 10-Esq','Odivelas','','PORTUGAL','2675-235','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:24:42',0,NULL,3,1,3,1,' RA117714193CN','andreccarvalho\r欧标\r申报 light $20\r王'),(8549,776975185015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','tziras','info@theodoreziras.com','Theodoros Ziras','Egosthenon 42-44<br>Galatsi','Athens','Athens','GREECE','11146','(+30)6936743993','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-27 08:33:15',0,NULL,3,1,4,1,' YW866010531CN','tziras\r欧标\rlighting kit $40\r王'),(8550,776973458015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','pbrito55','pedro.j.n.brito@gmail.com','Pedro Brito','Ericsson T.<br>Ed. Infante D. Henrique','Quinta da Fonte','Paço de Arcos','PORTUGAL','2770192','00351934466350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:33:27',0,NULL,3,1,17,0,NULL,'pbrito55'),(8551,761175140016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',40,'hutongstore','pbrito55','pedro.j.n.brito@gmail.com','Pedro Brito','Ericsson T.<br>Ed. Infante D. Henrique','Quinta da Fonte','Paço de Arcos','PORTUGAL','2770192','00351934466350','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 08:33:28',0,NULL,3,1,3,1,'RA117714202CN','pbrito55\r58mm 环架   1\r10片状套装\r\r52mm 接口环  1\r王'),(8552,761179567016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','playteam1234','vonnie@ryder1241.fsnet.co.uk','Yvonne Ryder','7 Greenway<br>Coppenhall','Crewe','Cheshire','UNITED KINGDOM','CW1 4JN','01270583593','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 08:43:47',0,NULL,3,1,2,1,NULL,'playteam1234'),(8553,761180619016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','andiermann','aw012e3054@blueyonder.co.uk','andrew watts','15 malcolm road<br>shirley','solihull','West Midlands','UNITED KINGDOM','b90 2ah','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 08:47:05',0,NULL,3,1,2,1,NULL,'andiermann'),(8554,761184723016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','andrew_fish','andrew@thefishtank.info','Andrew Fish','59 Fourth Avenue','Edwinstowe','Nottinghamshire','UNITED KINGDOM','NG21 9PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 09:04:17',0,NULL,3,1,2,1,' ','andrew_fish\r庄'),(8555,665531827001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','silygrl56','llgeorge6@comcast.net','Linda L. George','17524 114th St E','Bonney Lake','wa','UNITED STATES','98391','(253) 297-1831','NoPaymentFailure','CheckoutComplete','Other','2011-04-27 09:25:31',0,NULL,3,1,4,1,' YW866010494CN','silygrl56\r灯泡是110v的\r庄'),(8556,706390726002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 09:55:33',0,NULL,3,1,4,1,' YW866010483CN','sundsdal\r小号镜头筒   1\r717AH   1\rballhead  $22\r王'),(8557,665536028001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','sundsdal','csundsdal@gmail.com','Christian Sundsdal','Vestre Kvartergade 7d, st','Hvidovre','Denmark','DENMARK','2650','0045 31198080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 09:55:34',0,NULL,3,1,17,0,NULL,'sundsdal'),(8558,665541249001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',26,'AE3103',254.8,'hermeshine','vladimirzeonmaster','zeonmaster@yandex.ru','vladimir morgunov','kiev-32<br>post office box  №278','Kiev','ua','UKRAINE','01032','(050) 387  0299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 10:07:46',0,NULL,3,1,5,1,'     CP227020208CN','vladimirzeonmaster\r庄'),(8559,665540386001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',68.95,'hermeshine','prg8303','foruse@inbox.ru','Roman Podvysotskiy','kurchatov st., 3-18','Obninsk','Kaluga','RUSSIAN FEDERATION','249037','+79056433839','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 10:32:54',0,NULL,3,1,5,1,' \r\rCP227020199CN\r','prg8303\r2m 弹簧灯架 红盒  1\r反光板支架    1\r庄\r'),(8560,665554991001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','yevgeniy9','euzar@hotmail.com','Lyubov Litvin','Levit Medical Arts Pavilion<br>1220 Avenue P','Brooklyn','NY','UNITED STATES','11229','(718) 376-1004','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 11:06:01',0,NULL,3,1,1,1,NULL,'yevgeniy9\r庄'),(8561,665555706001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','attesom','lamiscusi@libero.it','Federico Gilberto Cambielli','viale Trento e Trieste , 39','Tradate','VA','ITALY','21049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:09:36',0,NULL,3,1,2,1,NULL,'attesom\r庄'),(8562,706418900002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','johnnycipika','cipry_kungfu_06@yahoo.com','Ciprian Baltag','9 rue general vouillemont','Bar sur aube','Champagne-Ardenne','FRANCE','10200','0601380815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 11:42:20',0,NULL,3,1,2,1,NULL,'johnnycipika\r王'),(8563,665563854001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 11:49:30',0,NULL,3,1,3,1,' RA117714065CN\rRA117714159CN\r','saud-p\r分成2个挂号小包发\r王'),(8564,664014446018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','missty66','aagadi.steph@live.fr','AAGADI STEPHANIE','130 ANCIENNE ROUTE DE LABRUGUIERE<br>RESIDENCE LES PASTELS APT C02','CASTRES','Midi-Pyrénées','FRANCE','81100','0629135308','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-27 11:51:03',0,NULL,3,1,4,1,'YW866010520CN ','missty66\r王\rlighting kit $26\r欧标'),(8565,777035135015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'AKT038',134,'hutongstore','skabet589','carie_16_2003@hotmail.com','carie clack','49 st anslems road','hayes','Middlesex','UNITED KINGDOM','ub3 4sd','07719824063','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-04-27 11:53:42',0,NULL,3,1,4,1,' YW866010516CN','skabet589\r2x3m 背景架    1\r3x6m 背景布    1（白）\r2m 灯架   2\r双灯头     2 英标\r柔光伞    2（！）\r\r45w  灯泡   4\r灯架包    1\r庄\r'),(8566,706429183002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','jphotographyb','jamesbianchi88@gmail.com','James Bianchi','13, Olive Street<br>The Gardens','St Julains','Malta','MALTA','stj 1953','0035621359413','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 12:20:41',0,NULL,3,1,2,1,NULL,'jphotographyb\r王'),(8567,777068005015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','traygleeson17','traygleeson@yahoo.co.uk','Tracey Gleeson','16 Killucan Manor Green<br>Rathwire','Mullingar','Westmeath','IRELAND','default','0449376544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 13:34:45',0,NULL,3,0,2,1,' ','traygleeson17\r1.6x2.1m      背景布   2（蓝+粉）'),(8568,777083656015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',2,'AA3314',8.56,'hutongstore','stefan588','stefan11schulz@gmx.de','Stefan Schulz','Von der Heydt 31','Ibbenbüren','','GERMANY','49477','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 14:12:56',0,NULL,3,1,2,1,' ','stefan588\r庄'),(8569,665622305001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','luizweb','luizantoniogsimoes@gmail.com','Luiz Simoes','Rua Olavo de Paula Borges, 83<br>ap. 23-B','Santos','São Paulo','BRAZIL','11035-130','13-3236-8826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:10:36',0,NULL,3,1,2,1,NULL,'luizweb'),(8570,706485645002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','danieltamir2009','danitamir@walla.co.il','daniel tamir','sivtey israel 41','haifa','israel','ISRAEL','26277','+97248400678','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:30:49',0,NULL,3,1,2,1,NULL,'danieltamir2009\r庄'),(8571,0,110677409268,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',0.99,'hermeshine','wolfguy2010','cwhr2010@yahoo.com','Kevin Smith','52509 Railroad St','La Pine','OR','UNITED STATES','97739-9511','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 15:34:27',0,NULL,3,1,1,1,NULL,'wolfguy2010\r庄'),(8572,665637241001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','sunny_logic2','jswarner2001@hotmail.com','Jack Warner','9a Eastlake Road<br>Camberwell','London','London','UNITED KINGDOM','SE5 9QJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 15:54:06',0,NULL,3,1,2,1,' ','sunny_logic2'),(8573,0,120714452027,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.49,'hermeshine','yurila71','yuri_lausberg@hotmail.com','Yuri Lausberg','916 129th PL NE','Bellevue','WA','UNITED STATES','98005-2610','(425) 681-5041','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 16:00:07',0,NULL,3,1,1,1,NULL,'yurila71\r庄'),(8574,665646737001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','tuzik_nnov','tuzikebay@gmail.com','Oleg Zozulya','pr. Gagarina, d. 103, kv. 45','Nizhniy Novgorod','','RUSSIAN FEDERATION','603137','(910) 870 4210','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 16:19:38',0,NULL,3,1,3,1,' RA117714145CN','tuzik_nnov\r庄'),(8575,664122742018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,17,0,NULL,'liandiex'),(8576,664125275018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117714220CN ','liandiex\r45w 5500k 灯泡    4\rNikon 三角包  D3   1\r庄   0.902'),(8577,665196863001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','aspire1640z','diman1640z@mail.ru','Дмитрий Алымов','14 Декабря, 4, 10','Узловая','Тульская обл','RUSSIAN FEDERATION','301602','+79207530720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 17:24:28',0,NULL,3,1,2,1,NULL,'aspire1640z\r王'),(8578,777174141015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',1,'AA3309',3.38,'hutongstore','dan_e_bernt','danerlend@hotmail.com','Dan Erlend Berntsen','Manglerudvn 22','Oslo','','NORWAY','0678','92648228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 17:42:40',0,NULL,3,1,17,0,NULL,'dan_e_bernt'),(8579,777182653015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','dan_e_bernt','danerlend@hotmail.com','Dan Erlend Berntsen','Manglerudvn 22','Oslo','','NORWAY','0678','92648228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 17:54:13',0,NULL,3,1,2,1,NULL,'dan_e_bernt\r绿叶 CPL  55mm   1\r绿叶 CPL  58mm    1\r庄'),(8580,706543499002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',35,'hermeshine','captainfuture','michael@rauch.com','Michael Rauch','Wingender Strasse 35','Neuss','GERMANY','GERMANY','41462','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 18:05:33',0,NULL,3,0,17,0,NULL,'captainfuture'),(8581,665687269001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','captainfuture','michael@rauch.com','Michael Rauch','Wingender Strasse 35','Neuss','GERMANY','GERMANY','41462','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 18:08:42',0,NULL,3,0,3,1,' RA117714114CN','captainfuture\r摄影背心 黑色薄 canon  XXL  1\r摄影背心 \rCanon  老款 \rXXL      1\r庄'),(8582,0,120714451938,'100% Genuine Lenspen lens cleaning tools NIB free S&H',1,'AA1310',3.25,'hermeshine','ankvn2000','ankvn@hotmail.com','W. P. L. (Kevin)','1614 251st St','Harbor City','CA','UNITED STATES','90710-2602','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 18:44:25',0,NULL,3,1,1,1,' ','ankvn2000\r庄'),(8583,0,110677409295,'55mm 55 mm Macro +4 Close-Up Close Up Filter',1,'AE3216',1.29,'hermeshine','dmsoho','dmetzpa@aim.com','Don Metz','149 Countryview Dr','Mc Kees Rocks','PA','UNITED STATES','15136-1252','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 19:15:42',0,NULL,3,1,1,1,NULL,'dmsoho\r庄'),(8584,777240002015,250634492762,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','angelo.2003','angelo2003@infinito.it','angelo de luca','Antonio Labriola, 6','grosseto','GR','ITALY','58100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 19:30:09',0,NULL,3,1,3,1,' RA117714176CN','angelo.2003\r庄\rbulbs  $10'),(8585,0,110677409667,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.99,'hermeshine','gmoratz','gamoratz@gmail.com','gary moratz','5936 Jellico Ave','encino','CA','UNITED STATES','91316','(818) 983-3248','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 19:57:21',0,NULL,3,1,1,1,NULL,'gmoratz\r庄'),(8586,0,110677409517,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',0.99,'hermeshine','rajan52s','rajan52s@gmail.com','SUNIL RAJAN','12 Rockland Dr','Jericho','NY','UNITED STATES','11753-1409','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 20:53:00',0,NULL,3,1,1,1,NULL,'rajan52s\r庄'),(8587,761476596016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','shorty.jude','shorty.jude@btopenworld.com','Judith Lipp','16 Ashton Gardens<br>Gartcosh','Glasgow','North Lanarkshire','UNITED KINGDOM','G698EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-27 20:53:15',0,NULL,3,0,2,1,NULL,'shorty.jude\r换成“Canon 小号内胆包    1”\r庄'),(8588,665767243001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','taraa76','hdenizli@gmail.com','HAKAN DENİZLİ','TUNUS CADDESİ<br>No:95 Kavaklıdere','ANKARA','','TURKEY','06680','5325251986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:01:14',0,NULL,3,1,2,1,NULL,'taraa76\r王'),(8589,665770711001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','komishukov','komishuko@gmail.com','Konstantin Mishukov','PILKONTIE 11','JOENSUU','','FINLAND','80130','358-505670104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:10:41',0,NULL,3,1,2,1,NULL,'komishukov\r王'),(8590,706629677002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','zoran1961','zoran.valencic@gmail.com','Zoran Valenčič','Cesta na Markovec 27','Koper','','SLOVENIA','6000','05 0562753','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-27 21:14:43',0,NULL,3,0,3,1,' RA117714128CN','zoran1961\rXXXL\r庄'),(8591,0,110677409599,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',0.99,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:25',0,NULL,3,1,17,0,NULL,'rainy2sunny'),(8592,0,110677409356,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',0.99,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:25',0,NULL,3,1,17,0,NULL,'rainy2sunny'),(8593,0,120714451996,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',2.21,'hermeshine','rainy2sunny','rstump@rochester.rr.com','Robert  L Stump','40A Whitney Ridge Road<br>Apt 8','Fairport','NY','UNITED STATES','14450','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 21:27:27',0,NULL,3,1,1,1,NULL,'rainy2sunny\r橡胶遮光罩 52mm    1\r橡胶遮光罩 58mm    1\r橡胶遮光罩 72mm    1\r庄'),(8594,706635802002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:31:38',0,NULL,3,1,17,0,NULL,'bobi1330'),(8595,665779334001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 21:34:10',0,NULL,3,1,2,1,NULL,'bobi1330\rCANON 镜头盖  67mm   1\rNIKON 镜头盖 67mm     1\r王'),(8596,0,120714452530,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',0.99,'hermeshine','add0987','druhzin@yahoo.com','Terry Pitman','807 Kings Mill Rd<br>Apt 138','Greenwood','IN','UNITED STATES','46142-1795','(765) 343-2150','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:09:11',0,NULL,3,1,1,1,NULL,'add0987\r庄'),(8597,761515785016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','kazysk','kazys.simutis@gmail.com','Mr Kazys Simutis','3rd Floor, Block B, Ulster Bank Group Centre, George\'s Quay<br>Dublin 2','Dublin','Dublin','IRELAND','2','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 22:25:18',0,NULL,3,1,2,1,NULL,'kazysk\r庄'),(8598,777330114015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','johanfolkesson','johan.folkesson@gmail.com','Johan Folkesson','Erik Tegels väg 19','Spånga','','SWEDEN','16340','0706484484','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-27 22:32:09',0,NULL,3,1,2,1,NULL,'johanfolkesson\r庄'),(8599,706655950002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',2,'AB1305',7.58,'hermeshine','shellcottage','fcrover@gmail.com','John Allaman','1205 S Orange Ave','Sarasota','FL','UNITED STATES','34239','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 22:37:17',0,NULL,3,1,1,1,NULL,'shellcottage\r庄'),(8600,0,110677409442,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',0.99,'hermeshine','thegaryharris','thegaryharris@msn.com','Gary Harris, Jr.','6651 Falling Branch Rd','Fairlawn','VA','UNITED STATES','24141-8449','(540) 998-9086','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 23:15:53',0,NULL,3,1,1,1,NULL,'thegaryharris\r庄'),(8601,665809552001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','kirum28','thanaratep@yahoo.com','THANARA  TEP','30 Carmody Parade','North Lakes','Queensland','AUSTRALIA','4509','0353343368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 23:24:23',0,NULL,3,1,2,1,NULL,'kirum28'),(8602,0,110677409237,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',1.36,'hermeshine','arbolito','virginitagarcia@hotmail.com','Virginia Pena','6730 Longmeade Ln','Orlando','FL','UNITED STATES','32822','(407) 658-0418','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-27 23:37:44',0,NULL,3,1,1,1,NULL,'arbolito\r庄'),(8603,665815687001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','babel1*miles777','lbcurado@gmail.com','Luís Barros Curado','Estrada dos Bernardos, Lote 60<br>Manique de Baixo','Alcabideche','Cascais','PORTUGAL','2645-456','919191074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-27 23:51:16',0,NULL,3,1,2,1,NULL,'babel1*miles777'),(8604,665823886001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',35,'hermeshine','olafbonsai','abg@bedinialejandro.com','Alejandro Bedini','Nexus<br>ENRIQUE MAC IVER - 440 piso 15','Santiago','RM','CHILE','8320123','0057-2-4208504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 00:30:22',0,NULL,3,0,17,0,NULL,'olafbonsai'),(8605,706683025002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','olafbonsai','abg@bedinialejandro.com','Alejandro Bedini','Nexus<br>ENRIQUE MAC IVER - 440 piso 15','Santiago','RM','CHILE','8320123','0057-2-4208504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 00:30:23',0,NULL,3,1,3,1,' RA117714131CN','olafbonsai\r摄影背心 黑色厚 sony  XL\r摄影背心 Nikon 老款  XXL\r庄'),(8606,665825480001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','13766899433','woshidaixiao@gmail.com','Xiao Dai','216 Verano PL','Irvine','CA','UNITED STATES','92617','(408) 896-8778','NoPaymentFailure','CheckoutComplete','Other','2011-04-28 00:34:45',0,NULL,3,1,1,1,NULL,'13766899433\r王'),(8607,706715119002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ahennell','andrew@hennell.com.au','Andrew Hennell','PO Box 8016<br>(21 Woollum Crescent)','Rivett','Australian Capital Territory','AUSTRALIA','2611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 02:35:56',0,NULL,3,1,2,1,NULL,'ahennell\r庄'),(8608,665857317001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nj_muttonchop','nj_mutton@hotmail.com','Nick  Mutton','30 Eucalyptus drive','Sydney','New South Wales','AUSTRALIA','2120','0199806751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 02:59:41',0,NULL,3,1,2,1,' ','nj_muttonchop\r庄\r'),(8609,665859649001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','gbm417','brian.marchman@gmail.com','Brian Marchman','217 Border Rd','Goose Creek','SC','UNITED STATES','29445-9643','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 03:08:02',0,NULL,3,1,1,1,NULL,'gbm417\r庄'),(8610,706716464002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','theplayersamigo','theplayersamigo@earthlink.net','Todd Jackson','8224 Wooden Windmill Ct','Las Vegas','NV','UNITED STATES','89131-1443','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 03:50:02',0,NULL,3,1,1,1,NULL,'theplayersamigo\r庄'),(8611,664122742018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-28 04:06:25',0,NULL,7,0,18,0,NULL,'liandiex'),(8612,664125275018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','liandiex','gpkokkinos@gmail.com','Giannis Kokkinos','5 Trapezountos str','Thessaloniki','','GREECE','55236','+306944315310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-28 04:06:36',0,NULL,7,0,18,0,NULL,'liandiex'),(8613,665878761001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:04',0,NULL,3,1,17,0,NULL,'gbgraphics_1'),(8614,706743606002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:03',0,NULL,3,1,17,0,NULL,'gbgraphics_1'),(8615,665878825001,110419738494,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',7.3,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:02:05',0,NULL,3,1,17,0,NULL,'gbgraphics_1'),(8616,665878703001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','gbgraphics_1','gbaron@zahav.net.il','guy baron','rozanski 17/6','rehovot','','ISRAEL','76453','972-8-9463207','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:02:09',0,NULL,3,1,3,1,' RA117714247CN\rRA117714162CN\rRA117714255CN','gbgraphics_1\r2m 灯架  2\r50-70 棚  2 欧标\r包    1\r72mm ND4    1\r72mm 渐变灰   1\r1转4灯头    1\r分两个小包发\r王'),(8617,706743798002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 05:03:19',0,NULL,3,1,17,0,NULL,'molchanov_r'),(8618,705964939002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','molchanov_r','molchanov_roman@mail.ru','Роман Молчанов','ул.Бирюзова д.31 корп. 1 кв. 252','г. Рязань','','RUSSIAN FEDERATION','390039','89206346666','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:03:19',0,NULL,3,1,3,1,'RA117714445CN ','molchanov_r\r反光板 100*150 40*60 5合1  1\r爵影红外 canon    1\r'),(8619,706744393002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','leomir2','dcedl@dalunet.cz','Jan Pidrman','Dvorakova 34','Zatec','','CZECH REPUBLIC','43801','+420602785437','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:13:28',0,NULL,3,0,3,1,'RA117714233CN ','leomir2\rXXXL (已减库）\r王'),(8620,777439593015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','kalinindmitriy','dkphoto@yandex.ru','Dmitriy Kalinin','Nevelskogo 4-197','Vladivostok','Primorskij','RUSSIAN FEDERATION','690013','+7-904-627-0183','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 05:20:28',0,NULL,3,1,2,1,NULL,'kalinindmitriy\r王'),(8621,665884261001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','cepn85','serious.pet@gmail.com','Sergey Peterman','Nastavnikov st. 42 - 70','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195279','+7-911-977-1-977','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 05:51:00',0,NULL,3,1,5,1,'CP227020239CN\r ','cepn85\r王'),(8622,665889562001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','dodoberecz214','berecz@atknet.sk','Dodo Berecz','Rožňavská 3','Košice','','SLOVAK REPUBLIC','04011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 06:11:16',0,NULL,3,1,2,1,NULL,'dodoberecz214\r王'),(8623,777463160015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','johnecache','johnpplant@gmail.com','John Plant','4 Osprey Close<br>Beechwood','Runcorn','Cheshire','UNITED KINGDOM','WA7 3JH','01928797001','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 07:11:10',0,NULL,3,1,2,1,NULL,'johnecache\r王'),(8624,664377967018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','rouche2011','hattinghrachel@vodamail.co.za','Rouche Du Toit','Bloekom street 4','secunda','Mpumalanga','SOUTH AFRICA','2302','+27825903125','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-28 07:37:17',0,NULL,3,1,3,1,'RA117714397CN \rRA117714383CN\rRA117714370CN','rouche2011\r分别记录一下3个小包多重  \r王\r1.89     1.994   0.656'),(8625,706769467002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','rouche2011','hattinghrachel@vodamail.co.za','Rouche Du Toit','Bloekom street 4','secunda','Mpumalanga','SOUTH AFRICA','2302','+27825903125','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 07:37:18',0,NULL,3,0,17,0,NULL,'rouche2011'),(8626,777471611015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','joan-rompe5066','joan-rompe@telefonica.net','joan bagur garrido','calle gelosos, 1','ciutadella de menorca','Baleares','SPAIN','07760','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 07:47:14',0,NULL,3,1,2,1,NULL,'joan-rompe5066\r欧标'),(8627,706769537002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','perryrimanda2010','perry.rimanda@gmail.com','perry rimanda','Aplikanusa Lintasarta<br>Menara Thamrin Lt.19 Jl. MH Thamrin Kav.3','Jakarta','DKI Jakarta','INDONESIA','10250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:09:30',0,NULL,3,1,2,1,NULL,'perryrimanda2010'),(8628,665912701001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','algirdasj','alibuchas@gmail.com','Algirdas Jankauskas','Gedvydžių 29-71','Vilnius','','LITHUANIA','06310','867651243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:15:07',0,NULL,3,1,2,1,NULL,'algirdasj'),(8629,706715983002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nameohname','psychonoetic@gmail.com','Fotios Vrionis','70 LYNDEN STREET, CAMBERWELL 3124','MELBOURNE','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 08:24:52',0,NULL,3,1,2,1,NULL,'nameohname'),(8630,706778386002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vigakuguitarist','vigakuguitarist@yahoo.com','Glenn Rodriguez','48552 Morgan Ln','Newberry Springs','CA','UNITED STATES','92365-9298','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 08:50:17',0,NULL,3,1,1,1,' ','vigakuguitarist\r庄'),(8631,665922498001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:05:15',0,NULL,3,1,2,1,NULL,'bobi1330\r庄'),(8632,706789800002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','rikif_123','spamy@fotoreport.eu','Richard Frydl - HBC REALITY','Nadrazni 535/15','Ostrava','CZECH REPUBLIC','CZECH REPUBLIC','70200','+420737005500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:24:37',0,NULL,3,1,3,1,'RA117714335CN ','rikif_123\r王'),(8633,706796630002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vatchravee_t','vatchravee@hotmail.com','Vatchravee Tasnavijitvong','297/29, Chaiwiwat3 Village, Soi Wat Bua Kwan<br>Ngamwongwan Road, Bangkrasau, Muang','Nonthaburi','Nonthaburi','THAILAND','11000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 09:57:32',0,NULL,3,1,2,1,NULL,'vatchravee_t\r庄'),(8634,706794566002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kristijanorlic','info@arijanova.hr','Kristijan Orlić','Put Pudarice 1','ZADAR','ZADAR','CROATIA','23000','+385 23 31 60 60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:04:18',0,NULL,3,1,3,1,' RA117714349CN','kristijanorlic\r刘 '),(8635,777503792015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',1.85,'hutongstore','freakingweird','markmurphywexford@gmail.com','Mark Murphy','Tomfarney<br>Clonroche','Enniscorthy, T-087-6771820','Wexford','IRELAND','N30','0876771820','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 10:20:42',0,NULL,3,1,2,1,NULL,'freakingweird\r庄'),(8636,706802968002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','djpetabyte','goda@gmx.at','Peter Goda','Am Dechantriegel 22','Voitsberg','','AUSTRIA','8570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 10:32:22',0,NULL,3,1,2,1,NULL,'djpetabyte\r庄\r'),(8637,706814543002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','potpot03','jayemcar@yahoo.co.uk','jay carag','8 Maudlin Vale<br>Trim, Co. Meath','Trim','comeath','IRELAND','default','0469483601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 11:16:52',0,NULL,3,1,2,1,NULL,'potpot03\r庄'),(8638,706816952002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sergeybaykal','guran38@yandex.ru','Sergey Tumolskiy','ul. Lenina dom 40, kv. 42','Irkutsk','RU','RUSSIAN FEDERATION','664003','+79025109440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:25:40',0,NULL,3,1,3,1,'RA117714264CN ','sergeybaykal\rL     王'),(8639,706817258002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','+2306971479','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:27:35',0,NULL,3,1,8,1,' CP26269033CN','demonod\r注意是河北的那个\r有1.6x2.1 白色背景布 一块\r王'),(8640,665955914001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','ivicabrujo','bodul@bodul.com','Ivica Brusic','Brusici 24','Malinska','Croatia','CROATIA','51511','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 11:36:07',0,NULL,3,1,3,1,'RA117714278CN ','ivicabrujo\r王'),(8641,761718992016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','057noel','nbernes1@eircom.net','noel bernes','mendips cottage<br>windsor','coolrain','Laois','IRELAND','default','0578735892','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 11:53:12',0,NULL,3,1,2,1,NULL,'057noel\r庄'),(8642,0,110677409488,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',0.99,'hermeshine','george35209','gbrowder@gmail.com','George Browder','2041 S Moonlit Pt','Homosassa','FL','UNITED STATES','34448-2164','(352) 621-9108','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-28 12:06:06',0,NULL,3,1,1,1,NULL,'george35209\r庄\r'),(8643,665963579001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','sophiec23','sophie230986@gmail.com','Sophie Constant','Bk A1 Emile Basset Saint Croix','Port Louis','Port Louis','MAURITIUS','742CU001','+2307719962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 12:07:19',0,NULL,3,1,2,1,' ','sophiec23\r庄'),(8644,706839634002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','jkup3146','mit@jankupec.net','Jan Kupec','Hoenggerstrasse 136','Zuerich','','SWITZERLAND','8037','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 12:54:57',0,NULL,3,1,4,1,' YW866010575CN','jkup3146\r欧标\rlighting kit $27\r庄'),(8645,665978023001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','turboatom','mmx310@gmail.com','Oleksandr Mazuryak','Chervonoarmiska 101 77','Chernivtsi','Chernivetska','UKRAINE','58013','+380509511122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:01:58',0,NULL,3,1,2,1,NULL,'turboatom\r庄'),(8646,665983785001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ezrati','ezrati_david@walla.com','david ezrati','tiltan<br>8','oranit','','ISRAEL','44813','9720502677337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 13:22:33',0,NULL,3,1,2,1,' ','ezrati\r庄'),(8647,706847183002,120619188583,'NEW 72mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT047',32,'hermeshine','ivrgoc','ivrgoc@yahoo.com','Sanja Majcan','Ljubijska 8','Zagreb, Dubrava','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 13:23:42',0,NULL,3,1,3,1,'RA117714318CN ','ivrgoc\r庄'),(8648,706871465002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','montfort48','jc.parmantier@free.fr','PARMANTIER  Jean Claude','34 Bd Saint Aignan','NANTES','Pays de la Loire','FRANCE','44100','0614836008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 14:49:42',0,NULL,3,1,2,1,NULL,'montfort48\r庄'),(8649,666011411001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','lucasalvadore','luca@salvadore.ch','Luca Salvadore','Av. des Alpes 64','Montreux','','SWITZERLAND','1820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 15:00:54',0,NULL,3,1,4,1,' YW866010564CN','lucasalvadore\rtripod $16\r庄'),(8650,706876972002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','pm.romero','d.mente@hotmail.com','Pablo Martin Romero','Rep. Argentina 221','Santa Lucía','Canelones','URUGUAY','90700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 15:06:28',0,NULL,3,1,3,1,'RA117714304CN','pm.romero\r刘'),(8651,706882801002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','elainor','adrian7386@gmail.com','Adrian Ong','11A, Forsyth Street','Kingsford','New South Wales','AUSTRALIA','2032','0433977939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:25:47',0,NULL,3,1,2,1,NULL,'elainor\r庄'),(8652,706891120002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','zerokhan','karotmarin@hotmail.com','Carlos Marín Aguilar','c/ del rey    Nº 62     piso 2º D','Aranjuez','Madrid','SPAIN','28300','918918736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 15:51:13',0,NULL,3,1,2,1,NULL,'zerokhan\r庄'),(8653,706896693002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','casaluca2004','casaluca@hotmail.com','LUCA CASAGRANDE','VIALE S.MARCO 70 MESTRE','VENEZIA','VE','ITALY','30173','041-976292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 16:09:13',0,NULL,3,1,4,1,'YW866010553CN ','casaluca2004\r800w红头灯     1\r800w  220v 灯泡     1\r灯本身就是欧标吧\r王'),(8654,761825344016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',6.1,'hutongstore','debauchery72','debsiporter@googlemail.com','Debi Porter - Children\'s Finance','Room 316, Oldway Mansion<br>Torquay Road','Paignton','Devon','UNITED KINGDOM','TQ3 2TE','01803206259','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 16:47:02',0,NULL,3,1,2,1,NULL,'debauchery72\r庄'),(8655,665973028001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 17:37:52',0,NULL,3,1,3,1,'RA117714352CN ','anato01\r刘'),(8656,706936647002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','raymonddelonpoh','raymonddelon@msn.com','Raymond Delon Poh','101 Telok Ayer Street #03-03<br>Singapore','default','','SINGAPORE','068574','+6597699996','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 17:56:22',0,NULL,3,1,3,1,'RA117714406CN ','raymonddelonpoh\r王'),(8657,777734947015,250665909845,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','alanslotus','alan.paterson5@ntlworld.com','Alan   Paterson','13 Littlefield Close, Ash','Aldershot','Hampshire','UNITED KINGDOM','GU12 6TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 19:22:52',0,NULL,3,0,2,1,NULL,'alanslotus\r白色\r庄\r'),(8658,706998847002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','micro1973','ebay@niechcial.de','Thorsten Niechcial','Buddenbergstraße 23','Selm','','GERMANY','59379','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 20:13:55',0,NULL,3,1,17,0,NULL,'micro1973'),(8659,706999523002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','micro1973','ebay@niechcial.de','Thorsten Niechcial','Buddenbergstraße 23','Selm','','GERMANY','59379','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:15:19',0,NULL,3,1,3,1,'RA117714295CN ','micro1973\rsony 单肩包  A1    1\r爵影红外 sony       1\r刘'),(8660,664625235018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','solidagoart','solidagoart2010@hotmail.it','marco scarparo','via pertini,21(ex via torino)','gessate','MI','ITALY','20060','3478109706','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-28 20:22:46',0,NULL,3,1,4,1,'YW866010542CN ','solidagoart\r欧标\r庄'),(8661,777779639015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','boldon.lad','normanharvey@btinternet.com','Norman Harvey','AP 1030<br>Urb. Camposol','Mazarron','Murcia','SPAIN','30875','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-28 20:41:12',0,NULL,3,1,2,1,NULL,'boldon.lad\r庄'),(8662,666148603001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','david19731','chauvin85@aol.com','chauvin david','31 rue jean jaures','saint maixent','deux sevres','FRANCE','79400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 20:52:16',0,NULL,3,1,2,1,NULL,'david19731\r庄'),(8663,666162920001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jmcv','jmvazquez@cusbro.com','Jose Maria VAZQUEZ','Balcarce 353 6to. \'14\'','Buenos Aires','South America','ARGENTINA','1064','(54-1)4446-5623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:34:04',0,NULL,3,1,2,1,NULL,'jmcv\r庄'),(8664,666166175001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 21:43:28',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r庄'),(8665,707047230002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','rudolfflachs','rudolf.flachs@centrum.cz','Rudolf Flachs','Na hrade 1118','Ricany','Praha-vychod','CZECH REPUBLIC','25101','602341972','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-28 22:26:16',0,NULL,3,1,3,1,'RA117714321CN ','rudolfflachs\r2XL\r王'),(8666,777824135015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','fwacsmum','agbofamily@agbofamily.plus.com','Stephanie Agbo','21 Hallett Road','Ansford','Somerset','UNITED KINGDOM','BA77LG','01963350261','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-28 22:32:15',0,NULL,3,1,2,1,' ','fwacsmum\r庄'),(8667,707045747002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','r.fonseca','ricardo_fonseca@live.com.pt','Ricardo Fonseca','Rua do Mercado nº28 3860-126','Avanca','default8','PORTUGAL','3860-126','(351) 926157786','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 22:32:31',0,NULL,3,1,2,1,NULL,'r.fonseca\r庄'),(8668,707055881002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','jamballa13','jaycool1320@yahoo.com','Jared Fullerton','1320 Fulton Ave<br>Apt C2','Bronx','NY','UNITED STATES','10456','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-28 22:58:47',0,NULL,3,1,1,1,' ','jamballa13\r刘'),(8669,666192206001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jumiroc','jumiroc@gmail.com','Juan M.  Roca Ripoll','Av. Argentina, 8, 1º, A','Palma de Mallorca','Baleares','SPAIN','07011','971288891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-28 23:23:14',0,NULL,3,1,2,1,NULL,'jumiroc\r庄'),(8670,707092629002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','svafar2005','svafarr@hotmail.com','Svafar Ragnarsson','Esjugrund 16','Reykjavik','','ICELAND','116','+354 8609727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 01:21:08',0,NULL,3,1,2,1,' ','svafar2005\r庄'),(8671,664715669018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',57,'photographyacc','johnmac6969','john.macmaster@anz.com','john macmaster','8 Addison Avenue','Tarneit','Victoria','AUSTRALIA','3029','0424171334','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-29 01:23:54',0,NULL,3,1,3,1,'RA117714281CN ','johnmac6969\r45w 5500k 灯泡    2\r2B柔    1套    \r刘'),(8672,707101463002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zuma_r6','cryhar@yahoo.com','Crystal  Harris','3009 3rd Ave W','Hibbing','MN','UNITED STATES','55746-2434','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 02:02:06',0,NULL,3,0,1,1,NULL,'zuma_r6\r庄'),(8673,762062986016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',3,'AA1310',11.34,'hutongstore','brandon_cro','brandonccronin@hotmail.com','Brandon Cronin','22 Liosdara<br>Oakpark','Tralee','Kerry','IRELAND','default','0667120952','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 02:41:37',0,NULL,3,1,2,1,NULL,'brandon_cro\r庄'),(8674,666251541001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','mli94','qiuranke@mac.com','Na Li','14317 Outpost Way','North Potomac','MD','UNITED STATES','20878','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 03:42:12',0,NULL,3,1,1,1,NULL,'mli94'),(8675,666264150001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','monchr366','viennasv@yahoo.com','Vienna Vogelezang','49 Berkshire Dr','Howell','NJ','UNITED STATES','07731-2355','(732) 814-4436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-29 05:15:44',0,NULL,3,1,1,1,NULL,'monchr366'),(8676,666290121001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','ivrgoc','ivrgoc@yahoo.com','Jelena Alpeza (kod Grgec)','Liganjska 6','Zagreb, Dubrava','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 07:32:54',0,NULL,3,1,3,1,'RA117714785CN\r ','ivrgoc\r'),(8677,777977137015,250692241184,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',4,'AE3601',51.96,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-29 08:27:00',0,NULL,3,1,17,0,NULL,'leifs123'),(8678,777977867015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',49.98,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-04-29 08:29:34',0,NULL,3,1,4,1,' YW866010586CN\r','leifs123\r115w 220v  8'),(8679,666231833001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',40,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 09:33:10',0,NULL,3,1,17,0,NULL,'braderbob'),(8680,707186783002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.87,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:09',0,NULL,3,1,17,0,NULL,'braderbob'),(8681,666312593001,110417014177,'72mm 72 mm Macro +8 Close-Up Close Up Filter',1,'AE3227',8.5,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:09',0,NULL,3,1,17,0,NULL,'braderbob'),(8682,666313081001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','braderbob','bob_azrul@yahoo.com','AZRUL NIZAM ABD. RAHIM','1007<br>SCHOEMAN STREET','ARCADIA','PRETORIA','SOUTH AFRICA','0083','27123425990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 09:33:08',0,NULL,3,1,3,1,'RA117714834CN\r ','braderbob\r6片装 （ 渐变灰， 渐变橙，渐变蓝，ND2, ND4， ND8) +滤镜袋\r72mm 环架   1\r72mm +8   1\rnikon 52mm 反接环   1'),(8683,664819617018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','chloehayden2011','sallyanneharp@hotmail.com','anne harpley','80<br>Laver Road','Mount Brown','New South Wales','AUSTRALIA','2530','0242623665','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-29 10:12:38',0,NULL,3,1,2,1,NULL,'chloehayden2011'),(8684,707206186002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ecosieteeu','ecosiete@yahoo.es','Jose Romera Puga','Crevillente 2 bis','Santa Maria Del Aguila','Almeria','SPAIN','04710','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 11:08:43',0,NULL,3,1,17,0,NULL,'ecosieteeu'),(8685,707205883002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ecosieteeu','ecosiete@yahoo.es','Jose Romera Puga','Crevillente 2 bis','Santa Maria Del Aguila','Almeria','SPAIN','04710','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:08:44',0,NULL,3,1,4,1,' YW866010612CN\r','ecosieteeu\r6662A 快装板   1\r三脚架  伟峰 WF-6662A    1\rtripod $16\r王'),(8686,762180855016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','charly151008','bubbling_beauty@hotmail.com','Charlotte Foster','21 Woodhill Gardens','Leeds','West Yorkshire','UNITED KINGDOM','LS16 7DD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 11:20:08',0,NULL,3,1,2,1,NULL,'charly151008\r庄'),(8687,666337547001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','kupodivu','dzzeri@seznam.cz','Martin Rejsa','103','Vidlata Sec','Czech Republic','CZECH REPUBLIC','57001','777327520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 11:35:02',0,NULL,3,1,2,1,NULL,'kupodivu\r庄'),(8688,762193284016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','wardystephen','wardstephen@gmail.com','Stephen Ward','Gaybrook','Mullingar','Westmeath','IRELAND','','0879863293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 12:11:42',0,NULL,3,1,2,1,NULL,'wardystephen\r庄'),(8689,666357870001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','suzzuka','capatcha@gmail.com','Vilen Shushenachev','Sakhalinskaya st.<br>38 - 81','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690080','+7 914 7060447','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 13:44:40',0,NULL,3,1,5,1,'CP227020361CN\r ','suzzuka\r欧标\r再加一个50cm的棚   \r王'),(8690,707251702002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','fela81fela','feladales@gmail.com','Fela Waddy','154 Hampshire Grove NW','Calgary','AB','CANADA','T3A5B3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:06:53',0,NULL,3,1,5,1,'CP227020358CN\r ','fela81fela\r庄'),(8691,666382033001,110544584989,'16chan Wireless  Control Cord for Canon 40D 50D 5D 5DII',1,'AA3204',18.5,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:28:02',0,NULL,3,1,17,0,' ','montresor_123'),(8692,666381884001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',87,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:28:03',0,NULL,3,1,4,1,'YW866010925CN ','montresor_123\r三脚架 伟峰 WF-6663A     1\ryn159- C3     1   \r'),(8693,666391097001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:57:57',0,NULL,3,1,17,0,NULL,'alfkro2010'),(8694,666390673001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 14:57:58',0,NULL,3,1,17,0,NULL,'alfkro2010'),(8695,707266685002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','alfkro2010','amkpart@gmail.com','Alfred Kroese','level 1<br>55 Hume Street','Crows Nest','New South Wales','AUSTRALIA','2065','0412888951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 14:57:58',0,NULL,3,1,4,1,' YW866010590CN\r','alfkro2010\r反光板支架    2\r灯架  2m    2\r斜臂   1\rreflector holder  $30\r王\r'),(8696,666393966001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','soundstarstudios','soundstarstudios@gmail.com','SOUNDSTARSTUDIOS Nico Larisch','Neumarkter Str. 17<br>2. Stock 089-78796600','München','','GERMANY','81673','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:05:18',0,NULL,3,1,3,1,' RA117714627CN\r','soundstarstudios'),(8697,707274354002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','gforce3d','hmanshar@g.risd.edu','Haim Mansharoff','P.O.Box 17395','Tel Aviv','','ISRAEL','61172','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:21:28',0,NULL,3,1,3,1,' RA117714600CN\r','gforce3d\r欧标'),(8698,666401764001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 15:30:50',0,NULL,3,0,3,1,'RA117731191CN ','ibico1974\r1.6x2.1m 灰+黑'),(8699,707279387002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','lentiayus','sudadoidet@yandex.ru','Aleksei Ratnikov','Lipetskaya 14K1, 304','Moscow','RU','RUSSIAN FEDERATION','115404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 15:38:02',0,NULL,3,1,2,1,NULL,'lentiayus\r庄'),(8700,666410370001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',44.99,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 15:56:50',0,NULL,3,1,3,1,'RA117714967CN\r ','cmontechi'),(8701,707294781002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','fadzbiz','fadzfaiz@yahoo.com','FADZILAH A. FAIZ','55, JALAN SS21/46,<br>DAMANSARA UTAMA,','PETALING JAYA','SELANGOR','MALAYSIA','47400','012-6408814','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 16:23:01',0,NULL,3,1,9,1,NULL,'fadzbiz\r英标\r王'),(8702,762313979016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','leftshoeleftshoe1','leftshoeleftshoe@hotmail.com','bothwell dube','32 The Lawn<br>Westgrove Estate, Donnybrookhill,','Douglas','Cork','IRELAND','default','0863128579','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 17:35:18',0,NULL,3,1,2,1,NULL,'leftshoeleftshoe1\r白色\r庄'),(8703,762314098016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','marcel77sk','marcel@totojeventure.sk','Marcel Gejdos','Pruzinskeho 3','Zlate Moravce','','SLOVAK REPUBLIC','953 01','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 17:35:44',0,NULL,3,1,3,1,'RA117714511CN\r ','marcel77sk'),(8704,666465601001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','jaakkorajala','killer_jax@yahoo.com','Jaakko Rajala','Eerikinkatu 29 B 28','Turku','','FINLAND','20100','+358400641108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:37:54',0,NULL,3,1,17,0,NULL,'jaakkorajala'),(8705,666463966001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jaakkorajala','killer_jax@yahoo.com','Jaakko Rajala','Eerikinkatu 29 B 28','Turku','','FINLAND','20100','+358400641108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:37:56',0,NULL,3,1,3,1,'RA117714595CN\r ','jaakkorajala\r欧标\r45w 5500k 灯泡  2\r柔光箱 50-70cm 单灯头   1'),(8706,666475668001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','dai_fabio_dai','fabioborra@alice.it','Fabio Borra','via sabin<br>24','Cattolica','RN','ITALY','47841','3334772527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 18:55:30',0,NULL,3,1,2,1,NULL,'dai_fabio_dai\r庄'),(8707,707270427002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','vangia7','vanessa288@live.it','giacomo romandini','via dei laghi, 15','martinsicuro','TE','ITALY','64014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:13:30',0,NULL,3,0,3,1,'RA117714763CN','vangia7\r1.6x3m 白色'),(8708,707364134002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ignakismo','ignakismo@hotmail.com','Iñaki González Cuesta','Avenida Cardenal Herrera Oria 121 3º C','Santander','Cantabria','SPAIN','39011','605496329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:24:01',0,NULL,3,1,2,1,' ','ignakismo\r庄'),(8709,666492941001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','amachu','mcruzmata@ptvtelecom.com','Maria Cruz Mata','C/ Murcia nº 6 1º B','Cordoba','Andalucía Ceuta y Melilla','SPAIN','14010','957252662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 19:41:15',0,NULL,3,1,2,1,NULL,'amachu\r庄'),(8710,665018295018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',400,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-04-29 20:30:43',0,NULL,3,1,8,1,'CP227020335CN\r ','saud-p\r灯架  2m   6\r斜臂   2\r50x70 单灯头 棚   6\r115w 220v    6\r灯架包   2\r王   13.87'),(8711,666503489001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 20:30:44',0,NULL,3,1,3,1,'RA117714865CN\rRA117714879CN\r','saud-p\r分2个小包'),(8712,707392397002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','hcigelo','olegich@apollo.lv','Oleg Vovchenko','Gipsa 2 -1','Riga','','LATVIA','LV-1048','+37129940911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 20:37:38',0,NULL,3,1,2,1,NULL,'hcigelo\r庄'),(8713,778261932015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38.99,'hutongstore','ivars55555','ivarslusis@gmail.com','Ivars Lusis','42 Spruce Court<br>Ashleigh Downs','Tralee','Kerry','IRELAND','default','0862116497','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-29 21:06:13',0,NULL,3,1,4,1,'YW866010645CN\r ','ivars55555\rreflector holder  $20\r刘'),(8714,662710043001,110498795544,'New soft box photography studio lighting Set',2,'AKT016',194,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-29 22:12:43',0,NULL,3,1,4,1,'YW866010634CN\r ','crocopk1\r欧标\r2m 灯架    4\r50x70单灯头   4\r115w 220v      4\r灯架包    2\rlighting kit $26\r庄\r'),(8715,762437461016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','c.aroon','aroon2702@hotmail.com','Aroon Chanpimpab','Victoria Hall Block F<br>Flat 12 room 2','Newcastle','Tyne and Wear','UNITED KINGDOM','NE2 1XH','077 83977537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 22:20:27',0,NULL,3,1,2,1,NULL,'c.aroon\r庄'),(8716,778290134015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','tomgee3','tiptoptom@talktalk.net','Thomas George','418 Field of Dreams<br>Findhorn','Forres','Moray','UNITED KINGDOM','IV36 3TA','07952549539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-29 22:25:46',0,NULL,3,1,2,1,NULL,'tomgee3\r庄'),(8717,666558636001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-29 23:19:42',0,NULL,3,1,2,1,NULL,'boyadjy\r庄'),(8718,718375541017,270741930246,'QR Quick Release Plate Video Tripod Head 717 EI-717AH',1,'AB1204',7.8,'photographyacc','chilla1142','kahuna@bigpond.net.au','P PEACOCK','42 LAKE BREEZE DRIVE','WINDAROO','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-30 01:06:31',0,NULL,3,1,2,1,NULL,'chilla1142\r庄'),(8719,666590961001,110618902967,'Pro Photo Vest Blue for Canon 500D 550D 7D 60D  user',1,'AA2116',32,'hermeshine','naprakarn','naprakarn@hotmail.com','Nopparat Klaewklong','TPC Plc.<br>8 I-1 road mabtaphud','Muang','Rayong','THAILAND','21150','081-437-8714','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 01:59:16',0,NULL,3,1,3,1,'RA117714998CN\r ','naprakarn\rXL-已入库'),(8720,666599576001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','1adamsheehy','exfriendofsigmaxigrantwinner@hotmail.com','Adam Sheehy','21 Linden St<br>Apt 205','Quincy','MA','UNITED STATES','02170-1825','','NoPaymentFailure','CheckoutComplete','Other','2011-04-30 02:42:59',0,NULL,3,1,1,1,NULL,'1adamsheehy\r庄'),(8721,0,120714452362,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',0.99,'hermeshine','eloquentimages','larrya.harrison@gmail.com','Larry Harrison','197 Pinelli Dr','Piscataway','NJ','UNITED STATES','08854','(732) 858-1699','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 02:51:25',0,NULL,3,1,1,1,NULL,'eloquentimages\r庄'),(8722,707489062002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','raysan12','raymond@valeo-mtl.com','Raymond Lafontaine','425 Greeley Rd','Springfield','VT','UNITED STATES','05156-8808','(819) 847-4756','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 03:17:08',0,NULL,3,1,1,1,NULL,'raysan12\r庄'),(8723,706475841002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','ss321ss321','crazzypics@gmail.com','Sameer Salloum','218 Wadsworth St','Syracuse','NY','UNITED STATES','13203-1048','(315) 254-6501','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-04-30 04:02:34',0,NULL,3,1,1,1,NULL,'ss321ss321\r庄'),(8724,707523415002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rash10','ran.shalom@gmail.com','Ran Shalom','31 Ashkenazi st.','Tel-Aviv','Tel-Aviv','ISRAEL','69864','+972 54 5429589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 07:09:57',0,NULL,3,1,2,1,NULL,'rash10\r庄'),(8725,666645229001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','homiricardo','homiricardo@yahoo.com','Ricardo Jurado Sendra','Passeig de la Riera 168 4 3','rubi','Barcelona','SPAIN','08191','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 07:29:52',0,NULL,3,1,4,1,'YW866010623CN\r ','homiricardo\rtripod $16'),(8726,707533006002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','PayPalPaymentInProcess','CheckoutComplete','AU_Other','0000-00-00 00:00:00',0,NULL,3,0,3,1,'RA117714984CN\r ','aligator_smile\r\r1.6x2.1  白色+黑色'),(8727,707551539002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','loffy_thriller','margeta@gmail.com','Marin Margeta','cim<br>crkvena','Mostar','Mostar','BOSNIA AND HERZEGOVINA','88000','0038763408551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:13:27',0,NULL,3,1,3,1,'RA117714635CN\r ','loffy_thriller'),(8728,707552465002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gabor1960','vocsok@yahoo.com','Gabor Marsal','Segesvar u. 43.','Budapest','','HUNGARY','1194','+3612826915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 09:18:02',0,NULL,3,1,2,1,NULL,'gabor1960\r庄'),(8729,665210718018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','shaz01','rochmckenzie@hotmail.com','lachlan mckenzie','Lot 5 Tregarthen Rd','Summertown','South Australia','AUSTRALIA','5141','0421282264','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-04-30 10:40:53',0,NULL,3,1,2,1,NULL,'shaz01\r再发一个黄色logo的给他 5月26号'),(8730,666692982001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','stinesmiseth','stinesm@yahoo.com','Stine Smiseth','Erling Skjalgssons gt 1C','Oslo','','NORWAY','0267','0047 41 51 10 15','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 11:06:15',0,NULL,3,1,2,1,NULL,'stinesmiseth\r庄'),(8731,665235108018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','PayPalPaymentInProcess','CheckoutComplete','AU_RegisteredParcelPost','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'sez87'),(8732,707595032002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','roadspider51','jddz1@netscape.net','Joseph D. Zunich','2221 Yale Ave','Maplewood','MO','UNITED STATES','63143-1420','(314) 781-4646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 12:17:15',0,NULL,3,1,1,1,' ','roadspider51\r庄'),(8733,665236872018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','PayPalPaymentInProcess','CheckoutComplete','ExpeditedInternational','0000-00-00 00:00:00',0,NULL,7,1,18,1,NULL,'sez87\r澳标\r另外再加一套 河北的背景架 （1.6x2.1 白色背景布）\rlighting kit  $35'),(8734,778504934015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','emregologlu','info@emregologlu.com','Ali Emre Göloğlu','Kızılelma Cad. Münifpaşa Sk.<br>Dilek Saray Ap. No:44 D:8 Fındıkzade','Fatih / İstanbul','','TURKEY','34093','+90 533 929 35 90','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-04-30 13:03:22',0,NULL,3,1,3,1,'RA117714922CN\r ','emregologlu'),(8735,666737748001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','00xander00','ottino02@tin.it','Lorenzo Ottino','corso adda, 62','Vercelli','VC','ITALY','13100','+393478825573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 13:50:45',0,NULL,3,1,2,1,NULL,'00xander00\r庄'),(8736,707638802002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','bessonov1987','bessonov87@gmail.com','Elena Bessonova','Kutuzova 189-35','Tiraspol','','MOLDOVA, REPUBLIC OF','3300','(373) 777 - 56745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 14:50:26',0,NULL,3,1,2,1,NULL,'bessonov1987\r庄'),(8737,707638752002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','azmyl10790','azmil_ferrari@hotmail.com','Azmil Yusman Josni','Flat 654, A1, Jalan Sungai Pandan, Kampung Mumong','Kuala Belait','Belait','BRUNEI DARUSSALAM','KA1931','6738165480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:11:37',0,NULL,3,1,2,1,NULL,'azmyl10790\r庄'),(8738,707650989002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','thayakorn','thayakornv@yahoo.com','Mr.Thayakorn Vhongthamsathit','164 Summakorn Villege,<br>Sukhaphiban 3 Road,','Khet Saphansoung','Bangkok','THAILAND','10240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 15:27:17',0,NULL,3,1,2,1,NULL,'thayakorn\r庄'),(8739,778574615015,250692240862,'Wireless Remote Shutter Release for Nikon D200/D300​/D3',1,'AA3201',11.47,'hutongstore','itru7159','ian.trudgian@sky.com','Ian Trudgian','Flat 2<br>23 Trenance Road','St Austell','Cornwall','UNITED KINGDOM','PL255AJ','01726400164','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 15:44:10',0,NULL,3,1,2,1,NULL,'itru7159\r庄'),(8740,778605720015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','mark-p-white','markphilipwhite@yahoo.com','Mark White','3 Lamb Hill Close','Sheffield','South Yorkshire','UNITED KINGDOM','S13 8FT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 16:52:44',0,NULL,3,1,2,1,NULL,'mark-p-white\r庄'),(8741,762744074016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','salad7016','andrew.gough@blueyonder.co.uk','A GOUGH','30 MARSTON ROAD<br>RUSSELLS HALL','DUDLEY','WEST MIDLANDS','UNITED KINGDOM','DY1 2PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 16:53:55',0,NULL,3,1,2,1,NULL,'salad7016\r庄'),(8742,707700873002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','jhaber8v0d','jhaber@optonline.net','jordan haber','1 Greenbriar Ln','dix hills','NY','UNITED STATES','11746-5313','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 17:44:56',0,NULL,3,1,1,1,NULL,'jhaber8v0d\r庄'),(8743,707716531002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','climbman69','oguzhanapaydin@hotmail.com','OGUZHAN APAYDIN','S.DEMİRSOY MH HARMAN SOK. 232 BLOK NO:50/4 TURKİS BLOKLARI<br>AYDINLIK EVLER','ANKARA','ANKARA','TURKEY','06130','+905325511504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:24:43',0,NULL,3,1,2,1,NULL,'climbman69\r庄'),(8744,666845017001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','borderlightphoto','ishkra@tiscali.it','Scapaticci Fabio','Viale Faenza 26/5','Milano','MI','ITALY','20142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 18:49:33',0,NULL,3,1,2,1,' ','borderlightphoto\r庄'),(8745,666852570001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','mjardeen','ebay@jardeen.com','Michael Jardeen','305 N K St<br>Apt 4','Tacoma','WA','UNITED STATES','98403-1661','(253) 312-1919','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-04-30 19:07:38',0,NULL,3,1,1,1,NULL,'mjardeen\r庄'),(8746,707755350002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tkachelik','karborund@ya.ru','Igor Tkach','str. Shevchenka 2, apartment 53','Brovary','Kievskaya obl','UKRAINE','07401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 20:01:02',0,NULL,3,1,2,1,NULL,'tkachelik\r庄'),(8747,665437109018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0035',7.99,'photographyacc','justa1204','justa1204@hotmail.com','Justyna Pietrzkiewicz','ul.Cegielniana 6<br>Posada Zarszyn','Zarszyn','','POLAND','38-530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-04-30 21:20:45',0,NULL,3,1,17,0,NULL,'justa1204'),(8748,707787440002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','nik_nis_018','cvetkovicn018@yahoo.com','Milan Stojkovic','Dimitrija Tucovica 145','Nis','','SERBIA','18000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 21:33:05',0,NULL,3,1,3,1,'RA117714573CN\r ','nik_nis_018'),(8749,666908919001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','valenova','eva.valenova@gmail.com','Eva Manakova','Banselova 37','Bratislava','','SLOVAK REPUBLIC','82104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-04-30 21:41:29',0,NULL,3,1,2,1,NULL,'valenova\r庄'),(8750,777580475015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',5,'AO0005',39.95,'hutongstore','tristan2101','tristanedgar@yahoo.co.uk','tristan edgar','7 warrenfield court, deighton','huddersfield','West Yorkshire','UNITED KINGDOM','hd2 1lh','01484348160','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-04-30 21:42:35',0,NULL,3,0,3,1,'RA117715208CN ','tristan2101\r(5块红色的）'),(8751,707819900002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','nirsarignir','nir_sarig1@walla.co.il','nir sarig','amirim<br>12','tel aviv','north tel aviv','ISRAEL','69357','0544775228','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-04-30 23:21:43',0,NULL,3,1,3,1,'RA117714936CN\r RA117714851CN\r','nirsarignir\r发红盒的灯架给他吧， 分两个小包发'),(8752,707835788002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','suzzuka','capatcha@gmail.com','Vilen Shushenachev','Sakhalinskaya st.<br>38 - 81','Vladivostok','Primorsky Kray','RUSSIAN FEDERATION','690080','+7 914 7060447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 00:24:37',0,NULL,3,1,17,0,NULL,'suzzuka'),(8753,666957114001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','thunderbird48','thunderbirdartgallery@yahoo.com','Charly Moore/Overland Canyon Tours','48-A-Lake Powell Blvd.','Page','AZ','UNITED STATES','86040','(928) 608-4072','NoPaymentFailure','CheckoutComplete','Other','2011-05-01 01:04:05',0,NULL,3,1,1,1,NULL,'thunderbird48\rM\r庄'),(8754,666967640001,110426238164,'Brand New Star 4 points filters for Cokin P Series',1,'AE2315',9.8,'hermeshine','wsbranson','branson@ndsupernet.com','Wade Branson','930 Shinagle Drive','Dickinson','ND','UNITED STATES','58601','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 01:48:23',0,NULL,3,1,1,1,NULL,'wsbranson\r庄'),(8755,707858635002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','pv008','davehollis@blueyonder.co.uk','DAVE HOLLIS','7 MADDOCKS HILL','WARMINSTER','WILTSHIRE','UNITED KINGDOM','BA12 8DJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 02:02:44',0,NULL,3,1,17,1,NULL,'pv008\r庄'),(8756,707877829002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','kykyky_99','kyang_99@yahoo.com','Ke yang','28 John Beal Dr','Garnet Valley','PA','UNITED STATES','19060-1126','(610) 732-3585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-01 03:31:33',0,NULL,3,1,1,1,NULL,'kykyky_99\r庄'),(8757,666989728001,110419738256,'Green.L 67mm Neutral Density ND4 Filter ND 4 67',1,'AE2305',6.7,'hermeshine','cheekim82','cheekim82@yahoo.com.sg','Foo Chee Kim','Block 134 Ang Mo Kio Avenue 3 #09-1689<br>Singapore','default','','SINGAPORE','560134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 03:40:40',0,NULL,3,1,11,1,NULL,'cheekim82'),(8758,707870556002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',6.2,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:20',0,NULL,3,1,17,0,NULL,'donyzac'),(8759,666969105001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:20',0,NULL,3,1,17,0,NULL,'donyzac'),(8760,707870430002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','donyzac','jozachar@indiana.edu','Joe Zachariah','30 Severance Cir<br>Apt 517','Cleveland Heights','OH','UNITED STATES','44118-1527','(765) 461-2160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 04:10:21',0,NULL,3,1,1,1,NULL,'donyzac\r绿叶 ND4  58mm   1\r绿叶 ND8  58mm   1\r爵影红外 5 in 1      1\r庄'),(8761,707902103002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','sunshaker0','sunshaker@gmail.com','Ken Vale','305-359 Railway Avenue','Stratford','ON','CANADA','N5A 2J3','(519) 574-4811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 05:57:47',0,NULL,3,1,2,1,NULL,'sunshaker0\r庄'),(8762,707909273002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bamboo2u','crazybluepanda@gmail.com','Khanh Vuong','303 Pamela Rd','Monrovia','CA','UNITED STATES','91016-5038','(626) 841-8160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 06:39:45',0,NULL,3,1,1,1,NULL,'bamboo2u\r庄'),(8763,665557968018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','tonylu1017','lulala25@hotmail.com','Tony xiao jun lu','16/23-25 sherbrook road','hornsby','New South Wales','AUSTRALIA','2077','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 06:56:28',0,NULL,3,1,2,1,' ','tonylu1017'),(8764,707914472002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','caring4parents','chrisacuff@ymail.com','Christopher K Acuff','311 SW 2nd St','Perkins','OK','UNITED STATES','74059-3505','(405) 334-2805','NoPaymentFailure','CheckoutComplete','Other','2011-05-01 07:09:13',0,NULL,3,1,1,1,NULL,'caring4parents\r庄'),(8765,667033901001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','junjunpang','jun-pang@hotmail.com','jun pang','1 Rosedale Ave Wattlepark','Adelaide','South Australia','AUSTRALIA','5066','0883317443','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 07:52:40',0,NULL,3,1,4,1,'YW866010660CN\r ','junjunpang\rlight stand  $20\r刘'),(8766,707937855002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',2,'AC3303',17.58,'hermeshine','koi0_18','vilkuna.k@gmail.com','Kyösti Vilkuna','Rihlaperä 3','Jyväskylä','Länsi-Suomen lääni','FINLAND','40630','(+358) 0400-627378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 08:44:33',0,NULL,3,1,3,1,'RA117714658CN\r ','koi0_18'),(8767,763073524016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','kerekes29','egyszeriember@gmail.com','Kerekes Zoltán','Mátyás Flórián tér 3.','Pécs','Baranya','HUNGARY','7631','0036302261783','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 10:05:08',0,NULL,3,1,3,1,'RA117714560CN\r ','kerekes29'),(8768,665620588018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','justa1204','justa1204@hotmail.com','Katarzyna Pietrzkiewicz','ul.Ogrodowa 33<br>Posada Zarszyn','Zarszyn','podkarpackie','POLAND','38-530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-01 10:42:13',0,NULL,3,1,2,1,NULL,'justa1204\rcanon 三角包  1\rsony 三角包   1\r王  519'),(8769,665619755018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','kittenkatyte','kate_cu@hotmail.com','Kate Nicolaou','93 Ruby Way','Braybrook','Victoria','AUSTRALIA','3019','0401805024','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 10:42:17',0,NULL,3,1,4,1,'YW866010656CN\r ','kittenkatyte\r河北的架子 + 1.6x2.1 白色背景布  1\rbackground support   $20\r王'),(8770,665627509018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','alanmkchan','mk_junk_box@hotmail.com','Alan Chan','Department of Transport<br>Level 9, 121 Exhibition Street','Melbourne','Victoria','AUSTRALIA','3000','0396556560','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 11:04:14',0,NULL,3,1,3,1,'RA117714587CN\r ','alanmkchan'),(8771,707984271002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','jurajstipetic1','juraj.stipetic@hotmail.com','Juraj Stipetic','K. Zvonimira 15','Kutina','Croatia','CROATIA','44320','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 11:18:18',0,NULL,3,1,3,1,'RA117714953CN\r','jurajstipetic1\r+8换成+4'),(8772,707948625002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',3,'AA3312',17.97,'hermeshine','maswino','w_1_no@yahoo.com','Winantu Rahardja','Jl. Gedong Kuning Selatan No. 17A','Yogyakarta','Daerah Istimewa Yogyakarta','INDONESIA','55198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 11:21:20',0,NULL,3,1,2,1,NULL,'maswino\r庄'),(8773,778999080015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','ghvilks1983','ghvilks@inbox.lv','Gundars Helds','Dammes 1-47','Riga','','LATVIA','LV-1069','(371) 26165280','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 12:14:45',0,NULL,3,1,2,1,NULL,'ghvilks1983'),(8774,667092526001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nosugarrr','honeyoff@gmail.com','Volha Tashkinava','Sedyh street, 34-64','Minsk','','BELARUS','220103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 12:28:14',0,NULL,3,1,3,1,'RA117714539CN\r ','nosugarrr'),(8775,708013395002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','samysamy35','samy.35@voila.fr','samy alamine','28 allée de la Sambre','VITRE','Bretagne','FRANCE','35500','0671745788','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 13:04:01',0,NULL,3,1,3,1,'RA117714556CN\r ','samysamy35'),(8776,667142430001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','sanyi_muzsik','muzsiksa@gmail.com','Sandor Muzsik','Mindszenti, 12.','Szegvár','','HUNGARY','6635','+36302623860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 13:41:28',0,NULL,3,1,2,1,NULL,'sanyi_muzsik\r庄'),(8777,665690763018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',7.8,'photographyacc','sam3512002','samriggio79@hotmail.com','Sam RIGGIO','26 Ervine Close','Sunbury','Victoria','AUSTRALIA','3429','0409199578','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 14:05:14',0,NULL,3,1,2,1,NULL,'sam3512002\r庄'),(8778,667161490001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','amperel2010','service@amperel.co.il','Amperel Danny','Shderot Jerusalem 168 Street<br>P.O. Box 2161','Holon','Israel','ISRAEL','58829','+97235594299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:31:37',0,NULL,3,1,3,1,'RA117714525CN\r ','amperel2010'),(8779,708056293002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','astral-v','vovaman@hotmail.com','Vova kaziev','Ahazav 13/10','Bene Aish','','ISRAEL','60860','0548023388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:46:08',0,NULL,3,1,2,1,NULL,'astral-v\r庄'),(8780,708054622002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','loraine_detera','loraine_detera@yahoo.com','Christine Loraine Detera','PO Box 24200, Conference Street<br>WestBay Area','Doha','','QATAR','24200','0097455026214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 14:48:06',0,NULL,3,1,3,1,'RA117714499CN\r ','loraine_detera'),(8781,763211062016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','mihiro','evilrufus@gmail.com','chia yuh shu','10 Melton Avenue<br>Camberwell','Melbourne','Victoria','AUSTRALIA','3124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 15:32:40',0,NULL,3,1,2,1,NULL,'mihiro\r庄'),(8782,708078325002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',4,'AO0009',283.6,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 15:37:52',0,NULL,3,1,4,1,'YW866010704CN\r ','ryrvikryrvik\r2m的背景架   \r共4套\rbackground support $40\r庄  \r  '),(8783,763216042016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','chris_leung','chris2002abc@hotmail.com','Christopher Leung Ki Fun','36 Burnside Crescent','London','Wembley','UNITED KINGDOM','HA0 1BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-01 15:40:41',0,NULL,3,1,2,1,NULL,'chris_leung\r庄'),(8784,779096726015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','coolrk1984','mischa_kojine@web.de','Michael Kojine','Randowstrasse 12','Hamburg','','GERMANY','22547','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-01 15:46:39',0,NULL,3,1,4,1,'YW866010693CN\r ','coolrk1984\r欧标  王'),(8785,708082231002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','medina_fjavier','medina.fjavier@gmail.com','Javier Medina Munuera','Calle del Ángel<br>Numero 2, 3C','EL ESPARRAGAL','Murcia','SPAIN','30163','610795727','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 15:46:46',0,NULL,3,1,3,1,'RA117714423CN\r ','medina_fjavier'),(8786,708098565002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','nemesis3k12','nemessis_22@hotmail.com','Richard Moreno','Travesia Cendea de Olza 3, 1 piso, puerta 3','Pamplona','Navarra','SPAIN','31015','691796152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 16:19:32',0,NULL,3,1,3,1,'RA117714508CN\r ','nemesis3k12'),(8787,667257247001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','mrtroudbill','lafricain70@free.fr','Stephane Francon','21, rue Gustave Dubois','Mitry Mory','Île-de-France','FRANCE','77290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 17:36:36',0,NULL,3,1,2,1,NULL,'mrtroudbill\r庄'),(8788,667292278001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','kelleyoo','kelleyre@adelphia.net','Raymond Kelley','147 E Shelby St','Junction City','KY','UNITED STATES','40440-8508','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-01 18:24:12',0,NULL,3,1,1,1,' ','kelleyoo\r庄'),(8789,779248632015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','fraperso','curro_perez@hotmail.com','Francisco Pérez Soto','Jardín Atalaya Bloque 1 3ºB<br>Camas','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41900','697803323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 18:55:23',0,NULL,3,1,2,1,NULL,'fraperso\r庄'),(8790,708213092002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','sadolkz','dolzhenko.sergei@gmail.com','Sergey Dolzhenko','Ch.Valihanova st., h-19/1, r-24','Temirtau','KZ','KAZAKHSTAN','101400','77015301392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 19:08:33',0,NULL,3,1,2,1,'','sadolkz\r庄'),(8791,666932967001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','nicobaricus','jmartos99@msn.com','Juan Carlos Martos Rojas','C/ Aguila de Oro, nº 6, 4º - 2','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41006','648550166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:03:35',0,NULL,3,1,3,1,'RA117714410CN\r ','nicobaricus'),(8792,667361416001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','firstnick','tosse99@gmail.com','Nicklas Lemaitre','Trorod Kollegiet 9E','Vedbaek','','DENMARK','2950','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-01 20:06:04',0,NULL,3,1,3,1,'RA117714825CN\r','firstnick\r+8换成+4\rND8 换成 ND4\r'),(8793,708248364002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','aldyna','seppo_aarne@hotmail.com','seppo aarne','ruohokatu 3','pori','','FINLAND','28130','00358407357451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:10:27',0,NULL,3,1,4,1,'YW866010682CN\r ','aldyna\rreflector holder  $18\r刘'),(8794,708273353002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ksta4539','krystian.stan@gmail.com','Krystian Staniszewski','#6F 9820-104st','Edmonton','AB','CANADA','T5K 0Z1','(780) 604-5902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:47:23',0,NULL,3,1,5,1,' CP27020344CN','ksta4539\r庄'),(8795,667381376001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','coussinrouge','x.toutchkov@wanadoo.fr','Xavier Toutchkov','5, Puy des Lauriers<br>Chemin Mouret','Aix-en-Provence','Provence-Alpes-Côte d\'Azur','FRANCE','13100','0610684461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 20:48:26',0,NULL,3,1,3,1,'RA117714675CN\r ','coussinrouge'),(8796,779370796015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',46.9,'hutongstore','leo_johnson','kev.bayliss@yahoo.co.uk','Kevin Bayliss','Yr Ystablau<br>Hendre Lane','Llandrinio','Powys','UNITED KINGDOM','sy22 6sf','01691831082','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-01 21:49:49',0,NULL,3,1,4,1,'YW866010730CN\r ','leo_johnson\rbackground support $20\r2m宽的+1.6x2.1 白色   \r王 '),(8797,665981474018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','dalred0','vista.its.me@hotmail.com','J Redding','4 Lady Nelson Drive<br>Eli Waters','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-01 23:04:47',0,NULL,3,1,2,1,NULL,'dalred0\r庄'),(8798,779405813015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 23:16:33',0,NULL,3,1,2,1,NULL,'zuhmia\r庄'),(8799,763516078016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',2,'AA1205',4.6,'hutongstore','stathe174','statheros@hotmail.com','Panagiotis Statheros','Papanastasiou 63','Athens','','GREECE','10445','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-01 23:28:02',0,NULL,3,1,2,1,NULL,'stathe174\r庄'),(8800,708333123002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','studiokiiro','mail@studiokiiro.com','Tom Huang','22A Jellicoe Street<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0398492595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 23:32:52',0,NULL,3,1,4,1,'YW866010726CN\r ','studiokiiro\r再加一个80cm 5in1 的反光板  \r一票两件\rreflector holder  $20\r刘\r'),(8801,667440231001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','studiokiiro','mail@studiokiiro.com','Tom Huang','22A Jellicoe Street<br>Box Hill South','Melbourne','Victoria','AUSTRALIA','3128','0398492595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-01 23:32:52',0,NULL,3,1,17,0,NULL,'studiokiiro'),(8802,763538344016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','fidelma9248','fidelmadonnelly@hotmail.com','fidelma donnelly','19 west high street<br>portgordon','buckie','scotland','UNITED KINGDOM','ab565qs','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 00:15:57',0,NULL,3,1,2,1,NULL,'fidelma9248\r庄'),(8803,708350037002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','arkitekt28','atlegoutbeek@hotmail.com','Atle Goutbeek','Granstien 11','Tvedestrand','','NORWAY','4900','004747336070','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 00:19:36',0,NULL,3,1,3,1,'RA117714692CN\r ','arkitekt28'),(8804,662714655001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 00:23:53',0,NULL,3,0,17,0,NULL,'crocopk1'),(8805,708411162002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','slg00012007','slg0001@gmail.com','Stephanus Goenawan','8 Hannans Road','Riverwood','New South Wales','AUSTRALIA','2210','61425881689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 03:23:06',0,NULL,3,1,2,1,NULL,'slg00012007\r庄'),(8806,708434075002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','greenspanx','johnjienanwong@yahoo.com','John Wong','977 Tulare Ave','Berkeley','CA','UNITED STATES','94707-2539','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 05:23:58',0,NULL,3,1,1,1,NULL,'greenspanx\r庄'),(8807,667545133001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','rdyk4033','dykstra1114@yahoo.com','Ron Dykstra','524 S 94th St','Tacoma','WA','UNITED STATES','98444','(253) 212-1600','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 06:42:09',0,NULL,3,1,1,1,NULL,'rdyk4033\r庄'),(8808,667546105001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','toys.over.food','ebay.toysoverfood@gmail.com','TOF Moy','9602 Glenwood Rd<br># 127','Brooklyn','NY','UNITED STATES','11236-2632','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 06:49:35',0,NULL,3,0,1,1,NULL,'toys.over.food\r1.6x2.1 2块\r黑色 + 白色\r庄'),(8809,708461774002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sollop123','evgeny.sollop@gmail.com','Yevgen Solop','kv.Eremenko,3-39','Lugansk','UKR','UKRAINE','91011','380505005275','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 07:50:28',0,NULL,3,1,3,1,'RA117714613CN\r ','sollop123'),(8810,708462335002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 07:51:24',0,NULL,3,1,3,1,'RA117714701CN\r ','neno63\rcanon R2 单肩包  1'),(8811,667566769001,110583278393,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'AA2303',6.7,'hermeshine','dkas01','daniel.kasal@gmail.com','Daniel Kasal','Jablonova 2882/102','Prague 10','','CZECH REPUBLIC','10600','+420602738708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 08:28:06',0,NULL,3,1,2,1,' ','dkas01\r\r'),(8812,763695040016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','adam.wol','adam.wolynszczak@gmail.com','Adam Wolynszczak','127 The Crescent<br>Park West Pointe','Dublin','Dublin','IRELAND','D12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 09:41:47',0,NULL,3,1,2,1,NULL,'adam.wol\r庄'),(8813,779593568015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','dianer40','dianerussell64@talktalk.net','Diane Russell','3 Lanfine View','Darvel','East Ayrshire','UNITED KINGDOM','KA170FE','01560321034','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-02 09:52:58',0,NULL,3,1,4,1,' YW866011393CN\r','dianer40\r英标\rlighting kit $26\r王  '),(8814,667589743001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:03:37',0,NULL,3,1,4,1,'YW866010763CN\r ','marcelinopozo\r301p 一拖二   1\r（需要测试，我来吧）\r背景架2m（白+黑）   1\rbackground support   $25\r庄'),(8815,708491507002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','marcelinopozo','marcelinopozoruiz@gmail.com','Marcelino Pozo Ruiz','Urb El Rocio 32','Malaga','Andalucía Ceuta y Melilla','SPAIN','29016','607540414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 10:03:37',0,NULL,3,1,17,0,NULL,'marcelinopozo'),(8816,667593908001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','linehafakot','line.hafakot@gmail.com','dudu','avraam markovitch 3','rishon letsion','','ISRAEL','65654','0543082332','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:22:33',0,NULL,3,1,5,1,'CP227020389CN\r ','linehafakot\r欧标\r庄'),(8817,708502032002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','alexg047','alexg@alexgarcia.com','Henry Garcia','198 Amboy Road','Matawan','NJ','UNITED STATES','07747','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-02 10:35:31',0,NULL,3,1,1,1,NULL,'alexg047\r庄'),(8818,667599863001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','maxelereque','avezipueze@hotmail.com','Antonio Trinidad Perea','C/ Lorca Nº 29','Dos Hermanas','Andalucía Ceuta y Melilla','SPAIN','41700','955084520','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 10:45:57',0,NULL,3,1,4,1,'YW866010752CN\r ','maxelereque\rtripod  $20\rft-686\r王'),(8819,763724840016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','foto.drazen','foto.priganica@gmail.com','Drazen Priganica','Calle de la Hoz 24','Oliva','Comunidad Valenciana','SPAIN','46780','693288507','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 11:14:14',0,NULL,3,1,4,1,'YW866010741CN\r ','foto.drazen\rlight stand $20\r刘'),(8820,708515950002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','RU','RUSSIAN FEDERATION','628624','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:28:22',0,NULL,3,0,17,0,NULL,'motorfoto'),(8821,667612367001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','RU','RUSSIAN FEDERATION','628624','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:28:22',0,NULL,3,0,3,1,'RA117715004CN\r ','motorfoto(已减库）\r摄影背心 红色薄 sony  XXL   1\r摄影背心 黑色厚 sony XXXL   1\r'),(8822,667614163001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','bjornasb','rog-asb@online.no','Bjørn Roger Asbjørnsen','Tølløseveien 6','Ås','','NORWAY','N-1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 11:32:14',0,NULL,3,1,3,1,'RA117714689CN\r ','bjornasb'),(8823,708521691002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','ripple*butterfly','ripple_effected666@hotmail.com','Kellie Hoy','12 Wooles Ave','Warrnambool','Victoria','AUSTRALIA','3280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 11:48:21',0,NULL,3,1,4,1,'YW866010796CN\r ','ripple*butterfly\r澳标\r布是1.6x2.1 白色\rlighting kit  $30\r庄'),(8824,763736751016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','evapomposo','evapomposo@hotmail.com','Eva Pomposo','49a Northdown Street\r\nKing\'s Cross','London','London','UNITED KINGDOM','N1 9BL','02078338415','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 11:49:56',0,NULL,3,1,2,1,NULL,'evapomposo\r庄'),(8825,667630347001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','ylim8951','acidburn0828@yahoo.com.sg','Yi Chieh Lim','Unit 17, 15 Clarence Road. Indooroopilly','Brisbane','Queensland','AUSTRALIA','4068','0738767140','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 12:30:18',0,NULL,3,1,3,1,'RA117714817CN ','ylim8951'),(8826,708543515002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','joker.gb','lombardo.lucap@gmail.com','Lombardo Luca','Via Pio XI Dir. De Domenico 10/a','reggio calabria','RC','ITALY','89133','3313652543','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 12:59:37',0,NULL,3,0,3,1,'RA117714896CN ','joker.gb\r实际发的是新款XL (已减库）\r申报 photo vest  $15'),(8827,763767582016,260660053640,'New TianYa Star 4 points filters for Cokin P Series',1,'AE2315',6.7,'hutongstore','jet_kit','chris.casselden@virginmedia.com','Chris J Casselden','159 Westminster Road','Sutton','Surrey','UNITED KINGDOM','SM1 3NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:15:49',0,NULL,3,1,17,0,NULL,'jet_kit'),(8828,779666066015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','jet_kit','chris.casselden@virginmedia.com','Chris J Casselden','159 Westminster Road','Sutton','Surrey','UNITED KINGDOM','SM1 3NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:15:50',0,NULL,3,1,2,1,NULL,'jet_kit\r52mm 环架   1\rstar4 星光镜   1\r庄'),(8829,763775471016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:36:30',0,NULL,3,1,17,0,NULL,'paulhuk'),(8830,763775948016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:37:45',0,NULL,3,1,17,0,NULL,'paulhuk'),(8831,763776426016,260660052333,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:39:18',0,NULL,3,1,17,0,NULL,'paulhuk'),(8832,763776870016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-02 13:40:16',0,NULL,3,1,17,0,NULL,'paulhuk'),(8833,667654621001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','paulhuk','paul@kilgrimol.com','Paul Higham','34,Clive Avenue','St.Annes-on-Sea','Lancashire','UNITED KINGDOM','FY8 2RX','01253727061','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-02 13:50:32',0,NULL,3,1,3,1,'RA117714940CN','paulhuk\r55mm 接口环  1\r58mm 接口环  1\r72mm 接口环  1\r77mm 接口环  1\r天涯cpl    1\r\r'),(8834,763784189016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 14:00:49',0,NULL,3,1,17,0,NULL,'pcooley63'),(8835,763783693016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 14:00:49',0,NULL,3,1,2,1,' ','pcooley63\r52mm 环架  1\rcpl   1\r庄'),(8836,779683851015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48,'hutongstore','ufuksevki','ushevki@gmail.com','Ufuk Sevki','Erdogan Sonsal Sok.<br>Blok4 No:2','Lefkosa','KKTC / Mersin 10','TURKEY','-----','5338646064','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-02 14:01:18',0,NULL,3,1,5,1,'CP227020375CN\r ','ufuksevki\r欧标\r庄'),(8837,708577680002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','eliha5','eli_hazan@012.net.il','Eli Hazan','Menahem Begin Ave<br>69/2','kiryat shmona','','ISRAEL','11632','972-54-8884031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 14:50:06',0,NULL,3,1,3,1,'RA117714715CN\rRA117714848CN\r','eliha5\r如果超过2kg就分两个发'),(8838,763811218016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','hidden_nature','leonidaspa@gmail.com','Leonidas Papadopoulos','Riga Fereou 173','Kalamata','','GREECE','24100','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-02 15:05:41',0,NULL,3,1,4,1,'YW866010785CN\r ','hidden_nature\r欧标\r申报：40$；lighting kit\r王'),(8839,667680129001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','keropino','vip-well@yandex.ru','Valeriy Taranta','Bolchoy Matrossky pereylok 1/252','Moscow','','RUSSIAN FEDERATION','107076','(903) 1234488','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 15:07:35',0,NULL,3,1,2,1,NULL,'keropino\r庄'),(8840,667733871001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','450tilou','jaboucher@videotron.ca','Jacques Boucher','130 rg ste-Julie','Notre-Dame-des-Prairies','QC','CANADA','j6e 8y6','(450) 756-1973','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 17:17:33',0,NULL,3,1,3,1,'RA117726449CN\r ','450tilou\rRA117714437CN\r上次发了个斜臂给客户，重发 肩架一个'),(8841,667733847001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','shaun.rogers.me','shaun.rogers@me.com','Shaun Rogers','Ivybridge Community College<br>Harford Road','Ivybridge','Devon','UNITED KINGDOM','PL21 0JA','07791636049','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-02 17:18:41',0,NULL,3,1,2,1,NULL,'shaun.rogers.me\r庄'),(8842,708650741002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','stormgod66','stormgod@gmail.com','Edward Negron','5227 ithaca ave','Los Angeles','CA','UNITED STATES','90032','(213) 840-8147','NoPaymentFailure','CheckoutComplete','Other','2011-05-02 17:39:49',0,NULL,3,1,4,1,'YW866010774CN\r ','stormgod66\r刘\r灯架发红盒的给他'),(8843,708671500002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','tugezu','tukezu@gmail.com','Tuomas Hämäläinen','Vanha Tapanilantie 62 C26','Helsinki','Uusimaa','FINLAND','00730','+358407030125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:16:54',0,NULL,3,1,4,1,'YW866010811CN\r ','tugezu\rlighting kit  $22\r刘'),(8844,708671921002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','grzegorzrajzer','exeloro@gmail.com','GRZEGORZ RAJZER -  AGATA STRÓŻYCKA','MAGI FABREGA 5.2.1','SURIA - BARCELONA','Cataluña','SPAIN','08260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 18:17:53',0,NULL,3,1,2,1,NULL,'grzegorzrajzer\r庄'),(8845,708702849002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 19:13:42',0,NULL,3,1,3,1,'RA117714485CN\r ','bobi1330\r申报：14$，Bag\rlenspen    6\rCanon 单肩包  D1    1\r'),(8846,779861961015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','romeup','romeup02@oninet.pt','Romeu Peitinho','Av. Padre Alberto Neto, 27, Bloco B, 1.º Esq.','Belas','','PORTUGAL','2605-289','00351214324261','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 19:16:13',0,NULL,3,1,3,1,'RA117726302CN ','romeup\r坏了一个，再发一个新的， 2011-5-18\r刘'),(8847,708706238002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',3,'AKT051',34.5,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 19:20:34',0,NULL,3,1,17,0,NULL,'bobi1330'),(8848,666377681018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','irasema.farina','emanuelafarina@hotmail.com','Irasema Emanuela Farina','Apt2, The Plantation<br>Herbert St','Dublin','Dublin','IRELAND','D2','0851396776','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-02 19:53:14',0,NULL,3,1,4,1,'YW866010800CN\r ','irasema.farina\r申报: Lighting Kit , $22\r白+黑\r庄'),(8849,667821904001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','emanyasli','ermanmanyasli@gmail.com','Erman MANYASLI','ODTU TEKNOKENT<br>GUMUS BLOKLAR C BLOK SEBIT A.Ş.','ANKARA','ODTÜ','TURKEY','06531','05334228456','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 19:59:36',0,NULL,3,1,3,1,'RA117714471CN\r ','emanyasli\r庄'),(8850,775296499015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','theresas211','jons13569@yahoo.com','Theresa Simon','225 S 9th St','North Wales','PA','UNITED STATES','19454-2913','(267) 304-0880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 20:11:06',0,NULL,3,1,1,1,NULL,'theresas211\r庄'),(8851,779658599015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',4.52,'hutongstore','977white','blanca56@hotmail.es','blanca mesa gonzalez','pompeu fabra 10-2º/2ª','cambrils','Cataluña','SPAIN','43850','977363863','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 20:14:14',0,NULL,3,1,2,1,NULL,'977white\r橡胶遮光罩 55mm   1\r橡胶遮光罩 58mm   1\r庄'),(8852,667834333001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','deux22000','felferrari@yahoo.com.br','Felipe Ferrari','St Butia 2B<br>Campo Grande','Rio de Janeiro','RJ','BRAZIL','23040080','55 21 91157285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 20:24:59',0,NULL,3,1,2,1,' ','deux22000\r申报：GIFT；\r庄\r'),(8853,667849592001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','arases.06','arases06@gmail.com','MASANTE Patrice','679 ROUTE DE LA GRAVE','L\'ESCARENE','Provence-Alpes-Côte d\'Azur','FRANCE','06440','0980105705','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-02 21:04:00',0,NULL,3,1,3,1,'RA117714732CN\r ','arases.06\rXL（已入库）'),(8854,667875261001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','tadi226','pusnik.tadej@gmail.com','Tadej Pušnik','cvetkova 23','murska sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:14:23',0,NULL,3,1,3,1,'RA117714468CN\r ','tadi226'),(8855,779957494015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','lundemann77','mch@datea.dk','Martin Lundemann Christensen','Henrik Nielsens Vej 19','Roskilde','Roskilde','DENMARK','4000','+45 51319182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-02 22:15:37',0,NULL,3,1,2,1,' ','lundemann77\r庄'),(8856,708789063002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rudithesandninja','rudigaum@gmail.com','Dunross Gaum','103 Welgevonden Boulevard<br>Welgevonden Estate','Stellenbosch','Western Cape','SOUTH AFRICA','7600','+27717432212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:27:31',0,NULL,3,1,2,1,NULL,'rudithesandninja\r庄'),(8857,667880278001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','fcalabrese2008','fcalabrese1@hotmail.com','Francesco Calabrese','234 Flournoy St','San Francisco','CA','UNITED STATES','94112-3911','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-02 22:33:03',0,NULL,3,1,3,1,'RA117715049CN ','fcalabrese2008\r庄'),(8858,708794726002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','gemsvillage.com','jcabres@gmail.com','José Cabré','C/Pamplona 45 int, bajos 9','barcelona','Cataluña','SPAIN','08005','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 22:49:20',0,NULL,3,1,2,1,NULL,'gemsvillage.com\r庄'),(8859,667889136001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','spy14hun','balint.sipter@gmail.com','Balint Sipter','Hamzsabegi ut 9. III/3.','Budapest','','HUNGARY','1117','0036702578300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-02 23:06:35',0,NULL,3,1,2,1,NULL,'spy14hun\r庄'),(8860,708812777002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','hutchfla','hutchfla@yahoo.com','chris hutchinson','8640 SW 12th St','pembroke pines','FL','UNITED STATES','33025-3347','(954) 483-3086','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 00:01:17',0,NULL,3,1,1,1,' ','hutchfla\rxl\r庄'),(8861,667910778001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','kmar69888','keith.martinet@gmail.com','Keith Martinet','13 Ahwahnee Street<br>P.O. Box 708','San Juan Bautista','CA','UNITED STATES','95045-0708','(408) 710-2339','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 00:37:18',0,NULL,3,0,1,1,NULL,'kmar69888\rXXXL(已入库）\r庄'),(8862,708828646002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','kameraman1973','bladeruner@atlas.sk','Milos Villem','Perecka 4','Levice','','SLOVAK REPUBLIC','93405','+421907134513','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 00:59:38',0,NULL,3,1,3,1,'RA117714542CN\r ','kameraman1973'),(8863,667939769001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ythpstr2b','ythpstr2b@aol.com','William Helms','5402 Gwen Ln','Pace','FL','UNITED STATES','32571','(850) 994-4508','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 02:41:14',0,NULL,3,1,1,1,' ','ythpstr2b\r庄'),(8864,667946299001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','fungm','phmui@yahoo.com','Peter H. Mui','3400 Meyer Woods Ln','Fairfax','VA','UNITED STATES','22033-1519','(703) 989-9420','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 03:08:06',0,NULL,3,1,1,1,NULL,'fungm\r庄'),(8865,707858575002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','pv008','davehollis@blueyonder.co.uk','DAVE HOLLIS','7 MADDOCKS HILL','WARMINSTER','WILTSHIRE','UNITED KINGDOM','BA12 8DJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 03:20:35',0,NULL,3,1,3,1,'RA117714882CN','pv008\r庄\r爵影无线 N1   2 '),(8866,708874750002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','orlibertha','dlauson@shaw.ca','Doug Lauson','2664 Brewster Drive','Coquitlam','BC','CANADA','V3B 7A4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 04:13:40',0,NULL,3,0,3,1,'RA117714746CN\r ','orlibertha\rL 已入库'),(8867,666257286001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','rwir7405','richard@a3logistics.net','Richard Wirski','PO BOX 2208','Seaford','Victoria','AUSTRALIA','3198','0397867007','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 04:41:42',0,NULL,3,1,4,1,'YW866011356CN\r ','rwir7405\r庄'),(8868,666544248018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3310',6.6,'photographyacc','mircostore','mircofun@hotmail.com','Miroslav Korenik','31940 Hillcrest Avenue','Mission','BC','CANADA','V2V 1K9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 06:12:13',0,NULL,3,0,2,1,NULL,'mircostore\r58mm 渐变灰   1\r庄'),(8869,708900985002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',4,'AKT061',145.6,'hermeshine','aramarmenia','aramderdzyan@gmail.com','Aram Derdzyan','72 Z. Sarkavagi st. app. 84','Yerevan','Yerevan','ARMENIA','0091','37491717010','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 06:47:15',0,NULL,3,1,5,1,'CP227020256CN\r ','aramarmenia\r2m 灯架   4\r单灯头  欧标   4\r王'),(8870,708907564002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chema1024','chema1024@hotmail.com','Chema Perez','Apartado 397','Villagarcia de Arosa','Galicia','SPAIN','36600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 07:23:40',0,NULL,3,1,3,1,'RA117714919CN\r ','chema1024\r王'),(8871,666559461018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','gladkovmaxim','maksimk@list.ru','Gladkov Maxim','K.Sutyusheva 47-3','Petropavlovsk','SKO','KAZAKHSTAN','150000','87152527469','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 07:34:37',0,NULL,3,1,3,1,'RA117714661CN\r ','gladkovmaxim\r王'),(8872,780126213015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','ian29swans','melding0001@aol.com','ian melding','20 Brookville Drive<br>Skewen','Neath','Neath Port Talbot','UNITED KINGDOM','SA106SR','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-03 08:39:46',0,NULL,3,1,4,1,'YW866010833CN ','ian29swans\r王\rtripod  $25\r'),(8873,668017666001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','d1truo','ovidiu@webproject.ro','Cocis Petre Ovidiu','Str. Koos Ferencz nr. 13 ap. 12','Tirgu-Mures','Mures','ROMANIA','540382','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:40:17',0,NULL,3,1,2,1,'','d1truo\r庄'),(8874,668020404001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','marijokristo','avs@st.t-com.hr','Marijo Kristo','Vrh Visoke 18','Split','Dalmatia','CROATIA','21000','+ 385-98-21-41-51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 09:53:30',0,NULL,3,1,3,1,'RA117731112CN ','marijokristo\r注意数量-一共5个\r王'),(8875,708943303002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','novfon','novgorodes@gmail.com','Евгений Иванов','Б.-Санктпетербургская д.117 кв.170','Великий Новгород','Новгородская область','RUSSIAN FEDERATION','173008','(7911)6413307','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 10:17:02',0,NULL,3,1,3,1,' RA117731055CN','novfon\r王'),(8876,708943537002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','stepheure','stcarrez@free.fr','Stéphane  Carrez','5, chemin des chaumières','Ferrières Haut Clocher','Haute-Normandie','FRANCE','27190','0232341848','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 10:18:48',0,NULL,3,1,3,1,'RA117731126CN ','stepheure\r庄'),(8877,779698476015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',6.1,'hutongstore','spennagallo123','andrespenna@hotmail.it','andrea spennagallo','via sacragni 25','arcisate','VA','ITALY','21051','0332471515','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 10:27:38',0,NULL,3,1,2,1,'','spennagallo123\r庄'),(8878,668030974001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','oiaganzoma','elgar_28@hotmail.com','Ola Huse Ramstad','Svensenga 38','Oslo','Oslo','NORWAY','0882','4797617555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 10:39:59',0,NULL,3,1,2,1,'','oiaganzoma\r庄'),(8879,708958557002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',62.79,'hermeshine','ainis10','ainoras.v@gmail.com','Ainoras Vaskys','Kudirkos 51','Prienai','','LITHUANIA','59113','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 11:17:39',0,NULL,3,1,3,1,'RA117731130CN ','ainis10\r2个\r庄'),(8880,666614522018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','jbc0072000','jb.carlton@gmail.com','James Carlton','23 Portland Place','New Lambton','New South Wales','AUSTRALIA','2305','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-03 11:31:18',0,NULL,3,1,3,1,'RA117731143CN ','jbc0072000\r庄'),(8881,668043394001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','cineindiana','pacocintado@hotmail.com','Francisco Cintado Briceño','Sierra de Atapuerca 12, Portal B 6ºC','Madrid','Castilla-La Mancha','SPAIN','28050','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 11:31:23',0,NULL,3,1,2,1,NULL,'cineindiana\r庄'),(8882,708982483002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',3,'AA3301',8.25,'hermeshine','anamariaken','zaba1@sympatico.ca','Kenneth Etcher','204-10 Ruddington Drive','North York','ON','CANADA','M2K 2J7','(416) 222-9280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 12:48:18',0,NULL,3,1,2,1,NULL,'anamariaken\r庄'),(8883,668072626001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','vdichev','hakera_sl@abv.bg','Valentin Dichev','Georgi Ikonomov 63','Sliven','Sliven','BULGARIA','8800','+359898424248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 13:18:55',0,NULL,3,1,2,1,NULL,'vdichev\r庄'),(8884,764308550016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','robertvangend','rvgend@tele2.nl','Robert van Gend','Spinhuispad 79','Schiedam','','NETHERLANDS','3111PX','010-4213040','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-03 13:51:48',0,NULL,3,1,2,1,NULL,'robertvangend\r庄'),(8885,668111145001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',2,'AO0005',61.6,'hermeshine','prodde_2007','prodde@online.no','Per Bjørnar Rødde','Kaaldfeltet<br>.','Hestvika','HESTVIKA','NORWAY','7247','004791761580','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-05-03 15:32:15',0,NULL,3,0,3,1,'RA117731165CN ','prodde_2007\r蓝+粉'),(8886,666689501018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','prodde_2007','prodde@online.no','Per Bjørnar Rødde','Kaaldfeltet<br>.','Hestvika','HESTVIKA','NORWAY','7247','004791761580','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-03 15:34:41',0,NULL,3,1,4,1,'YW866011441CN ','prodde_2007\r2m 背景架 （ 白）  \rbackground support  $20\r王   \r'),(8887,780271601015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','photo3','idstudiophoto@gmail.com','NIKOLAOS PSATHOGIANNAKIS','GEROKOSTOPOULOU 1<br>KAROLOU KOUN 49','Patrai','Achaia','GREECE','26221','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-03 15:56:49',0,NULL,3,1,4,1,'YW866011415CN ','photo3\r欧标\r庄\r\r'),(8888,666699666018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','strumfvalentin','valentin.kozjak@gmail.com','Mirela Behin','Stari Golubovec 84','Lobor','','CROATIA','49253','091-589-0685','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-03 16:06:05',0,NULL,3,1,2,1,' ','strumfvalentin'),(8889,666701670018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','tsamuel-james','samuel.shelton88@gmail.com','Daniel or Samuel Shelton','PO Box 282<br>Red Hill','Brisbane','Queensland','AUSTRALIA','4059','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-03 16:09:35',0,NULL,3,1,3,1,'RA117731157CN ','tsamuel-james\r庄'),(8890,709049705002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 16:21:02',0,NULL,3,1,3,1,'RA117731072CN ','arnorolf10\r庄'),(8891,780279693015,250599919356,'New 62mm Ring adapter for Cokin P Series Filter Holder',2,'AA2211',4.5,'hutongstore','colour-blind','donald18@btinternet.com','Donald Cleary','21 Ardmore Drive','Armagh','Armagh','UNITED KINGDOM','BT60 1JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 16:38:23',0,NULL,3,1,2,1,NULL,'colour-blind\r庄'),(8892,780296981015,250619800184,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',39,'hutongstore','ruipegas','rui.pegas@gmail.com','Rui Pegas','Rua da Fontinha 4<br>Vilarinho Melres Gondomar','Porto','Vilarinho Melres Gondomar','PORTUGAL','4515-523','(00351) 915002273','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-03 16:46:34',0,NULL,3,1,4,1,'YW866011404CN ','ruipegas\rtripod  $15'),(8893,668155576001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:32:34',0,NULL,3,1,4,0,NULL,'juanfernandez2007'),(8894,668155096001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 17:32:34',0,NULL,3,1,4,0,NULL,'juanfernandez2007'),(8895,709074679002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','juanfernandez2007','placido@rodriguez.name','Plácido Rodriguez','Raimundo Fdez. Villaverde, 49 - 11 DR','Madrid','Madrid','SPAIN','28003','656310120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 17:32:35',0,NULL,3,1,4,1,'YW866011430CN ','juanfernandez2007\r反光板 110cm 5合1   1\r摄影背心 蓝色薄 XXL   1\r闪光的柔光箱   60cm   2\rlighting accessory  $22'),(8896,668169083001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','starwealth','starwealth2008@gmail.com','Taj Karim','302 - 1155 Seymour Street','Vancouver','BC','CANADA','v6b1k2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:08:27',0,NULL,3,1,2,1,NULL,'starwealth\r庄'),(8897,709102717002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 18:57:38',0,NULL,3,1,17,0,NULL,'pentaxfriend'),(8898,668183293001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',2,'AB1405',10.98,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 18:57:39',0,NULL,3,1,3,1,'RA117731188CN ','pentaxfriend\r摄影背心 冬夏  L   1\r肩带 pentax   2\r庄'),(8899,707082582002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,3,1,4,1,'YW866011463CN ','xrobertojosuex\rlighting stand $20\r王'),(8900,709124747002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',5.99,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 19:16:56',0,NULL,3,1,17,0,NULL,'armdmd95'),(8901,709119985002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-03 19:16:57',0,NULL,3,1,17,0,NULL,'armdmd95'),(8902,668201506001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1304',7.4,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-03 19:16:57',0,NULL,3,1,17,0,NULL,'armdmd95'),(8903,668198777001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','armdmd95','dralexmagat@aol.com','Alex reyes','617 W Huntington Dr','Monrovia','CA','UNITED STATES','91016','(626) 599-2000','NoPaymentFailure','CheckoutComplete','Other','2011-05-03 19:16:58',0,NULL,3,1,3,1,'RA117731069CN ','armdmd95\rCANON 镜头盖  77mm   3\rc型大力夹   1\r带水平仪 热靴保护盖    1\r反光板支架   1\r庄'),(8904,708945009002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',3.55,'hermeshine','e_nk','nevkos@gmail.com','Neven Kos','Rim 61','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:48:39',0,NULL,3,1,17,0,NULL,'e_nk'),(8905,708944294002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','e_nk','nevkos@gmail.com','Neven Kos','Rim 61','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 19:48:39',0,NULL,3,1,2,1,NULL,'e_nk\r49mm 转接环   1\r广角托架   1\r庄'),(8906,709149354002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','xtanda','xtanda@ieee.org','Denis Kristanda','PO BOX 4102','Macquarie Center','New South Wales','AUSTRALIA','2113','0402672599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 20:34:46',0,NULL,3,1,2,1,NULL,'xtanda\r庄'),(8907,668257789001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','salmon404','apuusti6@welho.com','Aki Puustinen','Kyösti Kallion tie 10 D 34','Helsinki','','FINLAND','00570','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:08:35',0,NULL,3,1,3,1,'RA117731205CN ','salmon404\r庄'),(8908,780453680015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','pbd1997','pbd@btconnect.com','MIKE CHAPPELL','THE LAURELS<br>SPROUTES LANE','COOLHAM','WEST SUSSEX','UNITED KINGDOM','RH13 8QH','01403741004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 21:16:25',0,NULL,3,1,2,1,NULL,'pbd1997\r庄'),(8909,668259633001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','andrey007','2003-28-11@rambler.ru','Solomon Robinovich','Neve Yaakov 110/1','Jerusalem','','ISRAEL','97350','+972545755189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:16:51',0,NULL,3,1,2,1,NULL,'andrey007\r庄'),(8910,668265664001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mipro83','prilepokm@gmail.com','Miroslav Prilepok','Prievozska 1','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','+421905616600','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 21:30:46',0,NULL,3,1,3,1,'RA117731086CN ','mipro83\r庄'),(8911,709193515002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','manubbk','manuzarazaga@hotmail.com','manuel zarazaga','victor grignard 7121<br>Villa Belgrano','Cordoba','Cordoba','ARGENTINA','5147','3515641243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 21:37:10',0,NULL,3,1,2,1,NULL,'manubbk\r刘'),(8912,780469032015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','jackyg3','guest327@btinternet.com','Jacky Guest','12 Mornington Close','Baughurst','Hampshire','UNITED KINGDOM','RG26 5PQ','01189812102','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 21:51:19',0,NULL,3,1,2,1,NULL,'jackyg3\r庄'),(8913,668280852001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pichirla','rsuarez68@auna.com','Roberto Suárez','Sanchorreja, 1','Madrid','Madrid','SPAIN','28011','610700987','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-03 22:20:28',0,NULL,3,0,3,1,' RA117731041CN','pichirla\r2XL\r庄'),(8914,780482510015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','255255255255','dan.farmer@gmail.com','Dan Farmer','Flat 4<br>30A Craven Terrace','London','London','UNITED KINGDOM','W2 3EL','07871037891','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 22:25:55',0,NULL,3,1,2,1,NULL,'255255255255\r庄'),(8915,709211504002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 22:33:49',0,NULL,3,1,3,1,'RA117731090CN ','cajaibamarcos\r庄'),(8916,668288439001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pamy03','pamela_betancourt@yahoo.com','pamela betancourt','Metropolis calle 22 p.5','carolina','PR','UNITED STATES','00987','(787) 467-3863','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'pamy03\r庄'),(8917,764564347016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gaggalli2','ciaranrowan@hotmail.com','Ciaran Rowan','51<br>Victoria Crescent','London','London','UNITED KINGDOM','N15 5LP','07758431626','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-03 22:48:03',0,NULL,3,1,4,1,'YW866011452CN ','gaggalli2\r英标\rlighting kit  $40\r王  \r'),(8918,780490949015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','swr_2007','lukaszchowis@yahoo.com','Lukasz Chowis - James Paige Marketing','12 Cheshire Avenue<br>Cheshire Business Park','Lostock Gralam','Cheshire','UNITED KINGDOM','CW9 7UA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-03 22:52:10',0,NULL,3,1,3,1,'RA117731015CN ','swr_2007'),(8919,668296741001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','ramonpastormarco','rpastor@iberdrola.es','Ramón Pastor Marco','C/ Jorge Juan, nº 37','San Vicente del Raspeig','Alicante','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-03 23:20:01',0,NULL,3,1,2,1,NULL,'ramonpastormarco\r庄'),(8920,709232859002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','anirbantaran','anirbantaran@hotmail.com','Anirban Taran','1235 Spring Green Ln','Burnsville','MN','UNITED STATES','55306','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 00:07:42',0,NULL,3,1,1,1,NULL,'anirbantaran\r庄'),(8921,764588151016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','paul_ashton01','paul_ashton01@yahoo.co.uk','Paul Ashton','200 Monton Rd<br>Monton','Eccles','Greater Manchester','UNITED KINGDOM','M30 9LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 00:17:08',0,NULL,3,1,17,0,NULL,'paul_ashton01'),(8922,779929365015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','paul_ashton01','paul_ashton01@yahoo.co.uk','Paul Ashton','200 Monton Rd<br>Monton','Eccles','Greater Manchester','UNITED KINGDOM','M30 9LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 00:17:08',0,NULL,3,1,3,1,'RA117731109CN ','paul_ashton01\r庄\r斜臂    1\r背景布 1.6x3m   1 (黄）'),(8923,709240424002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','kk325ic','kokang@cox.net','Kongbin Kang','16 Elmway St','Providence','RI','UNITED STATES','02906-4710','(401) 863-2628','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-04 00:30:30',0,NULL,3,1,3,1,'RA117731024CN ','kk325ic\r庄'),(8929,709290753002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','mdjager','mdjager@telusplanet.net','Murray G DeJager','75 Mt. Kidd Point S.E.','Calgary','AB','CANADA','T2Z 3C5','(403) 257-4044','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 04:14:29',0,NULL,3,1,3,1,'RA117731174CN ','mdjager'),(8924,709269960002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','simongrinberg','simiongrinberg@bezeqint.net','Simon Grinberg','Herzel 208A , app10','Rehovot','','ISRAEL','76270','+972507730017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 02:30:00',0,NULL,3,1,3,1,' RA117731038CN','simongrinberg\r庄'),(8925,668120251001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','gerka9973','sibirier9973@mail.ru','Dmitry Uzentsev','4-Mikrorayon, 37-44','Tobolsk','Tumenskaya oblast','RUSSIAN FEDERATION','626150','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 02:44:21',0,NULL,3,1,5,1,'CP227020327CN ','gerka9973\r王\r单号换成CP226971873CN  5月26号'),(8926,709281417002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','lara_ellegance','elise.tabet@hec.ca','Elise Tabet','533 80 E Avenue','Chomedy Laval','QC','CANADA','H7V3J7','(514) 434-2432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 03:20:08',0,NULL,3,1,17,1,NULL,'lara_ellegance\r庄'),(8927,709286051002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','lara_ellegance','elise.tabet@hec.ca','Elise Tabet','533 80 E Avenue','Chomedy Laval','QC','CANADA','H7V3J7','(514) 434-2432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 03:44:12',0,NULL,3,1,3,1,'RA117731231CN','lara_ellegance\r王\r再加一个大力夹'),(8928,709288391002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mdldeleon','mariardeleon8@yahoo.com','Maria De Leon','424 N 13th St','Donna','TX','UNITED STATES','78537-2818','(956) 454-2512','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 03:59:41',0,NULL,3,1,1,1,NULL,'mdldeleon\r庄'),(8930,668362173001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','ezipman','yapls2002@yahoo.com.sg','William Yap','33 Ubi Avenue 3<br>#07-50 VERTEX (Tower A)','default','','SINGAPORE','408868','91808647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:33:45',0,NULL,3,1,3,1,'RA117714905CN ','ezipman\r庄'),(8931,709295438002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','mikzhukov','7648660@mail.ru','Zhukov Mikhail','korpus 440-176<br>Tsentralny prospect','Zelenograd','Moskow','RUSSIAN FEDERATION','124498','+79857648660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 04:54:02',0,NULL,3,1,2,1,NULL,'mikzhukov\r庄'),(8932,707157974002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','rachel.perkins','rachl181@hotmail.com','rachel perkins','40 clayton cres','rutherford','New South Wales','AUSTRALIA','2320','0432234108','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-04 04:56:04',0,NULL,3,0,3,1,'RA117731355CN\r ','rachel.perkins\r灰+黑'),(8933,709308959002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','boxrsnsox573','roger.vaughn@gmail.com','Roger Vaughn','502 Shamrock St','Cuba','MO','UNITED STATES','65453-1732','(573) 259-0772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 05:59:23',0,NULL,3,1,1,1,NULL,'boxrsnsox573'),(8934,668370377001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ultradx','juan_alvarado37@msn.com','Juan C Alvarado','5536 Kalahari Ln','Las Cruces','NM','UNITED STATES','88011-7253','(575) 993-0166','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 05:57:34',0,NULL,3,1,1,1,NULL,'ultradx'),(8935,666971500018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','oystein999','oysmat@so-hf.no','Øystein Mathisen','Pettersand 58 A','Fredrikstad','','NORWAY','1614','+4741901542','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-04 06:33:26',0,NULL,3,1,2,1,NULL,'oystein999'),(8936,709331325002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','keshavsujeeun','kesh2503@yahoo.com','keshav sujeeun','astoria road, goodlands','port-louis','','MAURITIUS','230','+230 9185083','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 08:01:28',0,NULL,3,1,3,1,'RA117731214CN ','keshavsujeeun'),(8937,709333031002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','edacs_247','mwallach1@msn.com','Mark Wallach','501 44th Ave SW','Vero Beach','FL','UNITED STATES','32968','(772) 473-3496','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-04 08:09:18',0,NULL,3,1,1,1,NULL,'edacs_247'),(8938,668406579001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','talnisim','talnisim@gmail.com','Tal Nisim','Reading 6/c','Tel Aviv','','ISRAEL','69022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 08:43:08',0,NULL,3,1,2,1,' ','talnisim\r庄'),(8939,667015518018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','janbo1960','ruzgar@tpg.com.au','Jan Ruzgar','1 Warawee Place','Hallett Cove','South Australia','AUSTRALIA','5158','0883816830','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-04 10:03:02',0,NULL,3,1,2,1,NULL,'janbo1960\r刘'),(8940,709368887002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','bluntus','handay1010@hotmail.com','Burhanuddin Hj Ahmad','No 41 Jln Kecil Agau Kg Parit,<br>Pengkalan Batu, Jln Limau Manis','Bandar Seri Begawan','Brunei','BRUNEI DARUSSALAM','BH 1123','+6738634405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 10:50:49',0,NULL,3,1,2,1,NULL,'bluntus\r'),(8941,780677001015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','jacky24460','jackycooper24460@aol.com','Jacqueline Cooper','53 Loanfern','Ballachulish','Highland','UNITED KINGDOM','PH49 4JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 10:52:32',0,NULL,3,1,2,1,NULL,'jacky24460\r刘'),(8942,709369020002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','tanerercan','hunter09_09@hotmail.com','TANER ERCAN','TURKOCAGI CAD.NO:11','NAZİLLİ/AYDIN','','TURKEY','09800','+902563138684','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 11:03:30',0,NULL,3,1,3,1,'RA117731378CN ','tanerercan\rXL   \r王'),(8943,780676249015,250692239397,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:37',0,NULL,3,1,17,0,NULL,'saxyrico'),(8944,764746590016,260660050260,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:39',0,NULL,3,1,17,0,NULL,'saxyrico'),(8945,780677015015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 11:05:38',0,NULL,3,1,17,0,NULL,'saxyrico'),(8946,764746028016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','saxyrico','eric.estournet@free.fr','eric estournet','bat b2 residence chante perdrix<br>7 rue docteur girbal','marseille','Provence-Alpes-Côte d\'Azur','FRANCE','13010','0684772220','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-04 11:05:40',0,NULL,3,1,4,1,'YW866010881CN','saxyrico\r反光板 100*150 5合1    1\r倒影板（白黑）   1\r反光板支架   1\r大力夹   2\r王\r一票两件     \rReceived and processed-0525-0630再去信确认----超过2个月,终止.'),(8947,668446772001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','swake57','reb_olivier@yahoo.fr','Olivier REB','77 rue Kellermann','METZ','Lorraine','FRANCE','57000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 11:42:44',0,NULL,3,1,4,1,'YW866011544CN ','swake57\r刘\rboom arm  $20'),(8948,709382745002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','cyber_m3nace','cybervand@gmail.com','Peter Bjorvand','Skogbrynet 17 D','Oslo','','NORWAY','0283','(+47)94263618','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 11:47:06',0,NULL,3,1,2,1,NULL,'cyber_m3nace\r庄'),(8949,668459677001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',2,'AA2205',7,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 12:30:38',0,NULL,3,1,2,1,NULL,'bobi1330\r庄'),(8950,709353837002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','carlinhos-brown','afrointheajo@hotmail.com','Carlos Torres','C/ Generalife, nº 4','Churriana de la Vega (Granada)','Andalucía Ceuta y Melilla','SPAIN','18194','622747316','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 13:10:10',0,NULL,3,1,4,1,'YW866011533CN ','carlinhos-brown\rtripod $26\r王'),(8951,780740146015,250610476275,'New Desktop Photography light Stand 10-15\" Tall ',1,'AKT010',20.9,'hutongstore','vlaw0241','veron_ron4@hotmail.com','Veronica law','56 walpole place<br>Brookhill Road','woolwich','London','UNITED KINGDOM','se18 6tp','07816158857','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 13:55:57',0,NULL,3,1,3,1,'RA117731395CN ','vlaw0241\r刘\r英标'),(8952,668446694001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jjeusano','jjeusano@wanadoo.es','juan jose esteban usano','ortega y gasset 7 2 C','cuenca','Castilla-La Mancha','SPAIN','16004','616011768','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:22:46',0,NULL,3,1,4,1,'YW866011522CN ','jjeusano\r庄\rtripod $20'),(8953,780750738015,250692240407,'Shutter Release Remote Cord For Pentax K20D K200D K7',1,'AA3210',2.98,'hutongstore','ppol78','ppol@inbox.lv','Pavel Porubovs','10 Leamouth Road','Beckton, London','Essex','UNITED KINGDOM','E6 5SJ','02085912375','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 14:23:55',0,NULL,3,1,2,1,NULL,'ppol78\r刘'),(8954,709431937002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:36:53',0,NULL,3,1,17,0,NULL,'skarp92'),(8955,668495963001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',59,'hermeshine','skarp92','erikskarp@hotmail.com','Erik Skarp','Ramshult Norrgård','Mjölby','','SWEDEN','59591','0707499450','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 14:39:09',0,NULL,3,1,4,1,'YW866011511CN ','skarp92\r欧标\r柔光箱 60-60cm  四灯头    2\r灯架  2m    2\rlighting kit  $26\r王'),(8956,709447613002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','webixe','webmaster@webixe.com','Pierre-Olivier Beaudry','1842 préfontaine','montreal','QC','CANADA','h1w2p1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 15:24:00',0,NULL,3,1,3,1,'RA117731364CN ','webixe\r刘'),(8957,668541461001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','viktoraraskog','banjomaniac@hotmail.com','Viktor Araskog','Högalidsgatan 11','Stockholm','','SWEDEN','11730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 16:53:23',0,NULL,3,1,2,1,NULL,'viktoraraskog\r庄'),(8958,780630494015,250692237341,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',2,'AA2201',5.5,'hutongstore','dott.obelix','mirkomala@virgilio.it','Boschi Dino','Via Ariosto 2','Pianoro','BO','ITALY','40065','3339094366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 17:24:42',0,NULL,3,1,2,1,NULL,'dott.obelix\r刘'),(8959,780832928015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','tabs4life','tab4lifes@gmail.com','Denis Vesely','Sevcenkova 19','Bratislava','','SLOVAK REPUBLIC','851 01','00421 908 636 785','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 17:30:34',0,NULL,3,1,2,1,NULL,'tabs4life\r刘'),(8960,668562017001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','vitorwood','vmcm@ci.uc.pt','Vitor Madeira','Department of Zoology<br>L. Marques de Pombal','Coimbra','Coimbra','PORTUGAL','3004-517','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 17:42:59',0,NULL,3,1,2,1,NULL,'vitorwood\r庄'),(8961,668566545001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','elnur1986','elnur86@gmail.com','Elnur Djafarov','bulvar Unih Lenincev dom 6 kvartira 306<br>2623-306','Naberejnie Chelny','Tatarstan','RUSSIAN FEDERATION','423827','+79179173836','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 17:53:30',0,NULL,3,0,3,1,'RA117731404CN ','elnur1986\r刘'),(8962,780232716015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','smatulevicius','saulius.matulevicius@gmail.com','Saulius Matulevicius','Laisves 22','Vilkaviskis','','LITHUANIA','70150','37068112122','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 19:46:51',0,NULL,3,1,2,1,NULL,'smatulevicius\r刘'),(8963,780931426015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','nicola.nordin','nicolanordin@hotmail.com','Nicola Nordin','Bergdalen 8','Stockholm','Sundbyberg','SWEDEN','17279','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 20:11:05',0,NULL,3,1,3,1,'RA117731316CN ','nicola.nordin\r刘'),(8964,709608816002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','jho718','domingos007@hawaii.rr.com','Sisto Domingo','1419 Ala Hoku Pl','Honolulu','HI','UNITED STATES','96819-1432','(808) 833-7769','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-04 21:36:08',0,NULL,3,1,1,1,NULL,'jho718'),(8965,780977257015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',18.3,'hutongstore','skyline350gtdan','degraaff87@hotmail.com','Dan de Graaff','De Graaff Trailers, Langshot Stud<br>Gracious Pond Road','Chobham','Surrey','UNITED KINGDOM','GU24 8HJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:41:19',0,NULL,3,1,3,1,'RA117731320CN ','skyline350gtdan\r庄'),(8966,780982942015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','damiank996','damian996@googlemail.com','Damian Kaminski','Melville Data Services<br>Curriers Close','COVENTRY','West Midlands','UNITED KINGDOM','CV48AW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 21:53:43',0,NULL,3,1,3,1,'RA117731381CN ','damiank996\r刘'),(8967,765005838016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:41',0,NULL,3,1,17,0,NULL,'koygirl'),(8968,764990679016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:42',0,NULL,3,1,17,0,NULL,'koygirl'),(8969,780938463015,250599364923,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3303',2.3,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:42',0,NULL,3,1,17,0,NULL,'koygirl'),(8970,780936372015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','koygirl','koy.tradera@gmail.com','Anna-Karin Nilsson','Banjogatan 23e','Karlstad','Koy','SWEDEN','65636','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-04 21:54:43',0,NULL,3,1,3,1,' 1','koygirl\r绿叶 UV  58mm   1\r眼罩 450D/500D   1\r镜头筒 中号    1\r镜头筒 小号    1\r刘 \r   号丢了   '),(8971,668613381001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','zappeastusa2','zappusa2@gmail.com','Andrei Second','25 Walpole Park S<br>Ste 4','Walpole','MA','UNITED STATES','02081-2522','(508) 734-5382','NoPaymentFailure','CheckoutComplete','Other','2011-05-04 22:27:29',0,NULL,3,1,1,1,' ','zappeastusa2\r在运单上写上：110668199161\r刘'),(8972,668677253001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','ascaflin','acostamolina@hotmail.com','andres acosta molina','c/ san isdro labrador edf. DIANA 3 PORTAL 1 5ºB','fuengirola (malaga)','Andalucía Ceuta y Melilla','SPAIN','29640','655401560','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-04 22:35:48',0,NULL,3,1,4,1,'YW866010844CN ','ascaflin\r庄\rtripod $22'),(8973,765065527016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','11clifford11','cliffordxwhite@gmail.com','Clifford Phang','4 COLNE WAY','BASINGSTOKE','Hampshire','UNITED KINGDOM','RG21 4BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-04 22:53:11',0,NULL,3,1,2,1,NULL,'11clifford11\r庄'),(8974,668691569001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','luisrubin','luis.rubin@gmail.com','Luis Rubin','3 Shillingstone Rd','Winnipeg','MB','CANADA','R3Y 1J3','(204) 489-1422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-04 23:07:03',0,NULL,3,1,2,1,NULL,'luisrubin\r庄'),(8975,707533006002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',2,'AO0005',25.6,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-04 23:36:27',0,NULL,7,0,18,0,NULL,'aligator_smile\r'),(8976,665235108018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-04 23:41:43',0,NULL,3,1,17,0,NULL,'sez87'),(8977,665236872018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','sez87','sarahc104@hotmail.com','sarah connolly','1B Clarendon Cres','basin View','New South Wales','AUSTRALIA','2540','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-04 23:42:45',0,NULL,3,1,4,1,'YW866011496CN ','sez87\r澳标\r背景架 2mx3m 河北   1\r灯架  2m   3\r斜臂   1\r50-70 单灯头柔光箱   3\r115w  220v   3\r灯架包   1\r1.6x2.1 白色背景布   1\r庄\r'),(8978,667326738018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','czechm878','czechm8_78@yahoo.com.au','Petr Typlt','18 Glen Street','Eastwood','New South Wales','AUSTRALIA','2122','0410781957','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 00:43:24',0,NULL,3,1,2,1,NULL,'czechm878\r刘'),(8979,668717631001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','ahchrisho','ahchrisho@yahoo.com.sg','Chris Ho','15 Jalan Kemajuan','default','','SINGAPORE','368981','+60127389578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 01:07:14',0,NULL,3,1,11,1,NULL,'ahchrisho'),(8980,667333170018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AC3304',68,'photographyacc','dj_danielsan','dj_danielsan@hotmail.com','Daniel James Thompson','80 Croydondale Drive','Melbourne','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 01:11:44',0,NULL,3,1,4,1,'YW866011485CN ','dj_danielsan\r刘'),(8981,668738380001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','stace1234','stacey_critch@hotmail.com','Stacey Critch','173 cokerill CR','Fort McMurray','AB','CANADA','t9k 2j3','(178) 020-1560 ext.: 2','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 02:39:39',0,NULL,3,1,5,1,'CP227020313CN ','stace1234\r庄\r\r灯泡是110v'),(8982,668739293001,110658437998,'Remote Shutter Release Cord for Nikon D70s D80 RE-G',1,'AA2221',4.68,'hermeshine','0520pup','r_nelson@bellsouth.net','Samuel Nelson','111 Smith rd.','Waco','GA','UNITED STATES','30182','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 02:44:11',0,NULL,3,1,1,1,NULL,'0520pup\r庄'),(8983,668631717001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',56.9,'hermeshine','photographyandvisualarts','ricardobandala@gmail.com','Ricardo Bandala','Av. Carranza 787 Col. Centro','San Luis Potosí','San Luis Potosí','MEXICO','78000','+524448100432','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 03:03:08',0,NULL,3,1,3,1,'RA117715097CN \rRA117715137CN','photographyandvisualarts\r分开发\r刘'),(8984,781079790015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',2.9,'hutongstore','tonysadr','t_sader@hotmail.com','Bonny Sadr','28, Buer Rd<br>Flat 5','London','London','UNITED KINGDOM','SW6 4LA','07852305701','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 03:25:06',0,NULL,3,1,18,0,NULL,'tonysadr'),(8985,765140387016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','tonysadr','t_sader@hotmail.com','Bonny Sadr','28, Buer Rd<br>Flat 5','London','London','UNITED KINGDOM','SW6 4LA','07852305701','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 03:25:07',0,NULL,3,1,2,1,NULL,'tonysadr\r绿叶 UV  77mm   1\r绿叶 渐变镜 77mm    1\r庄'),(8986,667362431018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102,'photographyacc','tom_888','7om8o87@gmail.com','Tom Brunsdon','29 Currawong Street','Mornington','Victoria','AUSTRALIA','3931','0359736617','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 03:27:40',0,NULL,3,1,4,1,'YW866011474CN ','tom_888\rballhead  $20\r王'),(8987,668704177001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',9.98,'hermeshine','espiritkiller','andrematos@virtualmagic.com.br','Andre de Matos Alves','Rua Travessa da Imprensa, 128<br>Jardim Aliança','Osasco','São Paulo','BRAZIL','06236-180','+55 11 35994110','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 03:40:31',0,NULL,3,1,3,1,' RA117732886CN','espiritkiller\rcanon  电子触点   1\rlenspen   2\r刘'),(8988,709700519002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','fototigerfoto','viktorpalkin@gmail.com','Palkina Yulia','st. D. Kovalchyk 252 kv.68','Novosibirsk','NSO','RUSSIAN FEDERATION','630082','8-913-940-86-88','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 03:40:44',0,NULL,3,1,5,1,'CP226269016CN ','fototigerfoto\r王'),(8989,668755189001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','abestrus','realtorluis@aol.com','Luis Trujillo','4736 W Allen St','Laveen','AZ','UNITED STATES','85339-2133','(602) 241-4411','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 04:10:26',0,NULL,3,1,1,1,NULL,'abestrus\r庄'),(8990,709713401002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','fatemaqa','love._.me009@hotmail.com','Fatema AL Medaihki','C Ring Road Navigation Plaza Oxy<br>P.O.Box : 22611','Doha','','QATAR','00974','00974-55128383','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 05:06:22',0,NULL,3,1,3,1,' RA117715018CN\r','fatemaqa\rM'),(8991,709714810002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','rm1one','lhum_1@graffiti.net','Leslie Hum','9 Jalan Sungai Emas 5A<br>Batu Ferringhi','Batu Ferringhi','Penang','MALAYSIA','11100','0124896915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 05:12:15',0,NULL,3,1,2,1,NULL,'rm1one'),(8992,668774203001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','v0xff','voxtobox@gmail.com','Vova Antonyuk','Filatova 4','Lutsk','Volyn region','UKRAINE','43018','380631788440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 06:26:26',0,NULL,3,1,2,1,NULL,'v0xff'),(8993,720754138017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','kolya_grain','274020742@mail.ru','Nikolay Pomortsev','Svobody<br>39','Kungur','Permskiy Kray','RUSSIAN FEDERATION','617470','+79655522722','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-05 06:42:10',0,NULL,3,1,5,1,'CP226269002CN ','kolya_grain\r套装里再加2个45w 灯泡\r欧标\r王'),(8994,667376603018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','kolya_grain','274020742@mail.ru','Nikolay Pomortsev','Svobody<br>39','Kungur','Permskiy Kray','RUSSIAN FEDERATION','617470','+79655522722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-05 06:44:00',0,NULL,3,1,17,0,NULL,'kolya_grain'),(8995,668783973001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 07:08:04',0,NULL,3,1,3,1,'RA117715070CN ','af_133\r庄'),(8996,781135038015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','snapo007','vilius.kavaliunas@gmail.com','Vilius Kavaliūnas','Neries kr. 32-26','Kaunas','','LITHUANIA','48463','+37067106414','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 07:43:43',0,NULL,3,1,3,1,'RA117715110CN ','snapo007\r王'),(8997,709744001002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:06',0,NULL,3,1,17,0,NULL,'gomendiobay'),(8998,668792172001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:07',0,NULL,3,1,17,0,NULL,'gomendiobay'),(8999,668792109001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:07',0,NULL,3,1,17,0,NULL,'gomendiobay'),(9000,668792266001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','gomendiobay','inaki.gomendio@ehu.es','Iñaki Gomendiourrutia','Universidad del País Vasco, Rectorado','Leioa','Bizkaia','SPAIN','48940','655705314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 07:59:08',0,NULL,3,1,3,1,'RA117715083CN ','gomendiobay\r82mm 接口环   1\r广角托架  1\r渐变橙   1\r星光镜 star6    1'),(9001,720793750017,270742403077,'New IR Wireless Remote Control for Pentax Canon Nikon ',1,'AA2205',5.48,'photographyacc','balmakov','balmakov.artmedia@gmail.com','Andrey Balmakov','100 Morozova st. app. 5','Stavropol','Stavropolskiy kray','RUSSIAN FEDERATION','355003','+79624478373','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-05 08:23:28',0,NULL,3,1,2,1,NULL,'balmakov\r庄'),(9002,668800538001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vipi2005','pivizara@gmail.com','PILAR BALLANO','SANTA OROSIA 42 5º B','Zaragoza','Aragón','SPAIN','50010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 08:34:13',0,NULL,3,1,3,1,'RA117715145CN ','vipi2005'),(9003,709765812002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','4x6zk','i4x6zk@013.net','shlomo shafir','4 frishman st','holon','israel','ISRAEL','58351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 09:43:07',0,NULL,3,1,2,1,'\\ ','4x6zk\r庄'),(9004,668812318001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','silvia79astro','alessandro.negro@unipd.it','Negro Alessandro','galleria Ognissanti 24<br>Padova','Padova','PD','ITALY','35120','3342498305','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 10:02:25',0,NULL,3,1,2,1,NULL,'silvia79astro\r庄'),(9005,709775984002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','aelita_23','vanesapires@yahoo.es','Vanessa Pires Alfonso','Izaro nº6 1º A Derecha','Getxo Fadura','País Vasco','SPAIN','48990','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 10:25:45',0,NULL,3,1,2,1,'\\ ','aelita_23\r庄'),(9006,781180951015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','blackwood1234','ryanblackwood1@gmail.com','Ryan Blackwood','16/7 Durar Drive','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH47JG','01314677497','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:33:25',0,NULL,3,1,17,0,NULL,'blackwood1234'),(9007,765240610016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.76,'hutongstore','blackwood1234','ryanblackwood1@gmail.com','Ryan Blackwood','16/7 Durar Drive','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH47JG','01314677497','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:33:26',0,NULL,3,1,2,1,NULL,'blackwood1234\r机身盖/镜头后盖  Canon   1\rCANON 镜头盖  77mm    2'),(9008,765242185016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','tylyla','stacey.stubbs@hotmail.co.uk','Stacey Stubbs','Church View, Washfield Lane<br>Treeton','Rotherham','South Yorkshire','UNITED KINGDOM','S60 5PU','07817783006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 10:39:52',0,NULL,3,1,2,1,NULL,'tylyla\r庄'),(9009,709786914002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','markcsy','markcho73@yahoo.com.sg','sai yan cho','blk 601 woodlands drive 42<br>#07-73','Singapore','','SINGAPORE','730601','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 11:10:36',0,NULL,3,1,9,1,'A05453451','markcsy\r刘'),(9010,668837729001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','rikirp','rikirp@yahoo.fr','Rikir Philippe','17 rue du gué','Mortier','Liege','BELGIUM','4670','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 11:23:14',0,NULL,3,1,4,1,'YW866010870CN ','rikirp\r王'),(9011,667457342018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE3401',35,'photographyacc','anhtruc','nguyentruc@hotmail.com','henry nguyen','Shop 1A, Kmart Plaza<br>176-210 Burwood Hwy','Burwood East','Victoria','AUSTRALIA','3151','0398861212','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-05 11:29:22',0,NULL,3,1,3,1,'RA117715300CN \r---\rRA117715622CN\r','anhtruc\r刘\r---\r反光板支架   1\r（当时发错了，重发一下吧）'),(9012,709791265002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','memorion.0003','alcazarrico@vodafone.es','Carlos de Alcázar Rico','Avda. Las Erillas, 12-2<br>La Pañoleta','Camas','Andalucía Ceuta y Melilla','SPAIN','41900','658560003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 11:35:30',0,NULL,3,1,17,0,NULL,'memorion.0003'),(9013,781206473015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','john170665','jonathancryan@eircom.net','John Ryan','7 Cascade Park','Clonmel','Tipperary','IRELAND','default','0526190802','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 11:55:22',0,NULL,3,1,2,1,NULL,'john170665\r庄'),(9014,668846083001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','mialeigh89','focuspointephotography@live.com.au','Mia Powter','1 Speedy St','Kelvin Grove','Queensland','AUSTRALIA','4059','0468689383','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-05-05 11:56:08',0,NULL,3,1,4,1,'YW866010914CN','mialeigh89\r刘'),(9015,667475731018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','r.o.s.s.c.o.2.0.1.1','rosscollado@gmail.com','Ross Collado','4 Barcelona Dr.','Prestons','New South Wales','AUSTRALIA','2170','0296082125','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-05 12:33:42',0,NULL,3,1,2,1,NULL,'r.o.s.s.c.o.2.0.1.1\r王'),(9016,709812211002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','eyalbm','eyalbm@gmail.com','Eyal Ben Meir','4 Sde Hemed st.','Mevasseret Zion','Israel','ISRAEL','90805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 12:46:21',0,NULL,3,1,2,1,' ','eyalbm\r庄'),(9017,668865942001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',2,'AB1405',10.98,'hermeshine','56paul61','suzannesellers@bigpond.com','Paul Sellers','336 Salvado Rd, Floreat','Perth','Western Australia','AUSTRALIA','6014','0893871611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 13:09:39',0,NULL,3,1,2,1,NULL,'56paul61\r庄'),(9018,666960806018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',135,'photographyacc','xaviervillalba','xavier_avt@yahoo.com','Xavier Villalba','Urb. Madrigal, sector Monjas, Antonia Salinas y Pedro Tobar E16-116','Quito','Pichincha','ECUADOR','E16-116','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 13:19:42',0,NULL,3,1,5,1,' CP226268877CN','xaviervillalba\r庄'),(9019,781257997015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','magdowi','m.mozga@gmail.com','Magdalena Mozga','62 Whitson Walk','Edinburgh','Midlothian','UNITED KINGDOM','EH11 3BY','07913721194','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-05 14:20:51',0,NULL,3,1,3,1,'RA117715185CN ','magdowi\r刘'),(9020,668887819001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','milton1601','miltonramalho@uol.com.br','São Milton Silva','Rua Claudio Rossi, 752','São Paulo','São Paulo','BRAZIL','01547-000','55 11 2063 4546','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 14:29:05',0,NULL,3,1,3,1,'RA117715211CN ','milton1601\r刘'),(9021,781274181015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 15:04:42',0,NULL,3,1,17,0,NULL,'melgesmoo'),(9022,781274025015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 15:04:43',0,NULL,3,1,4,1,'YW866010903CN','melgesmoo\r绿叶 UV  72mm   1\r三脚架 伟峰 EI-717   1\r王\r---\r9号被告知无法发到pobox地址，新地址是：\rGerald Hennessy\rMegalo Konstantiniou 3\rKalithies\r85100\rRhodes\rGreece.    \r地址问题-0630-超2个月,终止.\r'),(9023,668429889001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:09:58',0,NULL,3,1,17,0,NULL,'frdric840'),(9024,668831613001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 17:09:59',0,NULL,3,1,4,1,'YW866010892CN ','frdric840\r欧标\r大号灰卡   1\r麂皮   3\r永诺 Canon ttl线  3m    1\r背景架2m x 3m   1\r3x6 背景布    1（白色）\r2m灯架   2\r50-70 单灯头柔光箱   2\r115w 220v 灯泡   4\r灯架包   1\r庄\r'),(9025,668431267001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:10:00',0,NULL,3,1,17,0,' ','frdric840'),(9026,668430820001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 17:10:01',0,NULL,3,1,17,0,NULL,'frdric840'),(9027,709783578002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','frdric840','ebayfrdric840@orange.fr','Fouchenneret-Albiez Frédéric','36, rue Camille LENOIR','REIMS','Champagne-Ardenne','FRANCE','51100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 17:10:02',0,NULL,3,1,17,0,NULL,'frdric840\r'),(9028,707082450002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,'','xrobertojosuex\r'),(9029,765398479016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','inglezoid','ingles@netcabo.pt','João Andrade','Av. António Augusto de Aguiar, n.º 106, 8º andar','Lisboa','Lisboa','PORTUGAL','1050-019','+351213173660','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-05 17:37:03',0,NULL,3,1,2,1,NULL,'inglezoid\r庄'),(9030,765400851016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','sigmacanon','perttie4@gmail.com','pertti eronen','oinasjärventie 463','sonkajärvi','Oletus','FINLAND','74300','(050-5385071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 17:42:45',0,NULL,3,1,2,1,NULL,'sigmacanon\r庄'),(9031,668978726001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','xlorian10','jiannis2@mail.com','jiannis chloros','oik. eksikonomou 38','larisa','','GREECE','41223','0030 6948262304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 18:36:43',0,NULL,3,1,2,1,' ','xlorian10\r庄'),(9032,709950796002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',2,'AC2303',12.42,'hermeshine','gabealba','gabe_alba@yahoo.com','Gabe Alba','428 Brookside Pl','Cranford','NJ','UNITED STATES','07016-1635','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-05 19:14:26',0,NULL,3,1,1,1,' ','gabealba\r庄'),(9033,709962387002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','martin_nos','martinovic@azet.sk','Martin Nosal','Bidovce 278','Bidovce','','SLOVAK REPUBLIC','04445','+421907204097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 19:33:47',0,NULL,3,1,3,1,'RA117715199CN ','martin_nos\r王'),(9034,765520345016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','under.dradar','under.dradar@gmail.com','Darren Walsh','20 The View<br>Five Oaks','Drogheda','Louth','IRELAND','041','0864008915','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-05 21:15:54',0,NULL,3,1,2,1,NULL,'under.dradar\r庄'),(9035,664928875001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','arekuso2010','alexander.mapa.so@akersolutions.com','Alexander So','Ostersveien 6<br>Hundvåg','Stavanger','Rogaland','NORWAY','4085','9683 5792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 22:03:20',0,NULL,3,1,2,1,'\\','arekuso2010\r庄\r'),(9036,669071594001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','thiagomu','tsframos@hotmail.com','THIAGO RAMOS','RUA JOSE VARGAS DE FIGUEIREDO<br>NUMBER 46','VARRE-SAI','RIO DE JANEIRO / RJ','BRAZIL','28375000','(22)3843-3321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:16:38',0,NULL,3,1,3,1,'RA117715242CN ','thiagomu\r欧标\r王'),(9037,710048646002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','memorion.0003','alcazarrico@vodafone.es','Carlos de Alcázar Rico','Avda. Las Erillas, 12-2<br>La Pañoleta','Camas','Andalucía Ceuta y Melilla','SPAIN','41900','658560003','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-05 23:44:01',0,NULL,3,1,3,1,'RA117715239CN ','memorion.0003\r50-70柔光棚 通用塑料卡口    1\r斜臂     1\r（小包131，燕文166）\r刘'),(9038,710052697002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','tixtu','baritado@gmail.com','Alberto sánchez Ureña','colonia pernau  3 1,1','campdevanol','Gerona','SPAIN','17530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-05 23:59:11',0,NULL,3,1,2,1,NULL,'tixtu'),(9039,765577614016,260660050260,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:11:46',0,NULL,3,1,17,0,NULL,'vitoriasetubal'),(9040,765577927016,260660055182,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',15,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:13:10',0,NULL,3,1,17,0,NULL,'vitoriasetubal'),(9041,781526807015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 00:22:06',0,NULL,3,1,3,1,'RA117715225CN ','vitoriasetubal\r圆形柔光棚 50cm   1\r倒影板    1\r45w 220v 灯泡    2\r王'),(9042,669104780001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','rwk40y','richard@ribbons.com.au','Richard Kerslake','91 Westbrook Ave','Wahroonga','New South Wales','AUSTRALIA','2076','0294871881','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 01:08:30',0,NULL,3,0,3,1,'RA117730770CN ','rwk40y\rXXXL(已入库)\r庄'),(9043,669113945001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','designs4fun','desmarsol@aol.com','Paula Spagnuolo','1909 Shippan Ave','Stamford','CT','UNITED STATES','06902','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-06 01:50:31',0,NULL,3,1,1,1,NULL,'designs4fun\r庄'),(9044,710079163002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',20,'AA1310',109.8,'hermeshine','ruyguerra','ruyguerra1958@hotmail.com','Ruy Guerra','Rua Itapiru, 264 apto 34','Sao Paulo','SP','BRAZIL','04143-010','11-8613-6907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 01:51:29',0,NULL,3,1,3,1,'RA117715171CN ','ruyguerra\r申报：12$；gift\r庄'),(9045,710080430002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','buffy10478','ereynolds104@hotmail.com','Erin Reynolds','636 Amelia Cres','Burlington','ON','CANADA','L7L 6E5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 01:57:42',0,NULL,3,1,3,1,' RA117715168CN','buffy10478\r庄'),(9046,710087158002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','leandro.nemesio','lanemesio@gmail.com','Leandro Nemesio','Rua Ademar de Barros, 847<br>Centro','Artur Nogueira','São Paulo','BRAZIL','13160-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 02:36:21',0,NULL,3,1,17,0,NULL,'leandro.nemesio'),(9047,669121192001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','leandro.nemesio','lanemesio@gmail.com','Leandro Nemesio','Rua Ademar de Barros, 847<br>Centro','Artur Nogueira','São Paulo','BRAZIL','13160-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 02:36:22',0,NULL,3,1,3,1,'RA117715287CN ','leandro.nemesio\r欧标\r柔光箱 50-70cm 单灯头   1\r50-70柔光棚 通用塑料卡口   1\r庄 1.361\r'),(9048,710099610002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','hawthorntoo','cynneath@verizon.net','Kenneth Salewski','1704 Wrightfield Rd','Yardley','PA','UNITED STATES','19067-3131','(215) 321-6288','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 03:23:06',0,NULL,3,1,1,1,NULL,'hawthorntoo\r庄'),(9049,710106475002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','arakure_knight','clannad@tpg.com.au','Daryl Leong','431 Brisbane Corso','Yeronga','Queensland','AUSTRALIA','4104','61738922800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 04:01:31',0,NULL,3,1,3,1,'RA117715432CN','arakure_knight\r王'),(9050,721178233017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',8.88,'photographyacc','dags111','sdaggar@yahoo.com.au','steve   daggar','14 thomas st','tascott','New South Wales','AUSTRALIA','2250','0410513257','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-06 04:30:02',0,NULL,3,1,2,1,' ','dags111\r庄\r77mm 接口环   1\r广角托架    1\r'),(9054,668801286001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','korsar_64','konstantinas@soklys.lt','Konstantinas Samcenko','Svedes 43<br>Ginkunai','Siauliai','','LITHUANIA','81491','+37069827827','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 06:52:46',0,NULL,3,1,5,1,'CP226268885CN ','korsar_64'),(9051,669149999001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','msvenss1','onewheeler@hotmail.com','Mattias Svensson','Svarvaregatan 11','Huskvarna','','SWEDEN','56135','46704856661','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 05:09:40',0,NULL,3,1,3,1,'RA117715446CN ','msvenss1\r庄'),(9052,669157254001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','ranraanana','ranmor84@gmail.com','Ran Mor','Borocohov 22/6','Raanana','','ISRAEL','43433','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 05:56:42',0,NULL,3,1,2,1,NULL,'ranraanana\r庄'),(9053,669053828001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 06:39:41',0,NULL,3,1,3,1,'RA117715494CN ','anato01\r王'),(9055,669170185001,110583278199,'TianYa 58mm CPL filter New 58 Circular Polarizing C-PL',1,'AA2303',5.9,'hermeshine','ob_1969','matha@chello.at','Oliver Matha','Grosse Neugasse 40/9','Wien','','AUSTRIA','1040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 07:10:16',0,NULL,3,1,2,1,' ','ob_1969\r换发“绿叶 cpl 58mm    1”\r庄'),(9056,781655913015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','inphernomassacro','giuliano.froio@gmail.com','Grandolfo-Froio c/o McCann Erickson','via dei Magazzini Generali 18/20','Roma','RM','ITALY','00154','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-06 09:16:52',0,NULL,3,1,4,1,'YW865907281CN ','inphernomassacro\r再加一块 黑色的背景布  1.6x2.1\r欧标\rlighting kit  $26\r庄\r'),(9057,765704698016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','inphernomassacro','giuliano.froio@gmail.com','Grandolfo-Froio c/o McCann Erickson','via dei Magazzini Generali 18/20','Roma','RM','ITALY','00154','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 09:16:53',0,NULL,3,0,17,0,NULL,'inphernomassacro'),(9058,710172445002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rothovius','janne.ruotoistenmaki@pp.inet.fi','Janne Ruotoistenmäki','Luottamusmiehentie 11','Kangasala','','FINLAND','36100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 10:04:19',0,NULL,3,1,2,1,NULL,'rothovius'),(9059,669213999001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',5.98,'hermeshine','2010bokertov2010','pasov@012.net.il','Mikhael Pasov','Exodus 7/5','Qiryat Gat','','ISRAEL','82201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 10:48:00',0,NULL,3,1,2,1,NULL,'2010bokertov2010'),(9060,667858241018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','marcaextremadura','marca.extremadura@hotmail.com','Manuel Villafaina V.','C/ Antonio Reyes Huertas, nº7  1ºC','Cáceres','Extremadura','SPAIN','10002','637912461','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-06 11:02:34',0,NULL,3,1,2,1,NULL,'marcaextremadura'),(9061,669217263001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','mcamanda','amanda_mcgrath_91@hotmail.com','amanda mcgrath','182 braidwood drive','prestons','New South Wales','AUSTRALIA','2170','0466694330','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 11:04:04',0,NULL,3,1,4,1,'YW865907270CN ','mcamanda\r白+黑\r'),(9062,781695671015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mzarzuelar','manuel-zarzuela@hotmail.com','manuel zarzuela rodríguez','c/francisco de ariño  nº4, 2ºF','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41008','647235845','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 11:31:21',0,NULL,3,1,2,1,NULL,'mzarzuelar'),(9063,710195329002,120499333257,'Flash Softbox Diffuser for external flash SB800 580EX',1,'AB3302',8.8,'hermeshine','dan05myr08','igoumenidis@gmail.com','manolis igoumenidis','kanari 103','thessaloniki','macedonia','GREECE','54453','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 11:40:58',0,NULL,3,1,3,1,'RA117715640CN\r ','dan05myr08'),(9064,781710258015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','djnelio','lionel.ducos@free.fr','DUCOS Lionel - studio pasteur','24 rue pasteur','puteaux','Ile-de-France','FRANCE','92800','01.49.01.95.20','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-06 12:15:43',0,NULL,3,1,4,1,'YW865907362CN ','djnelio\rtripod $25\r王\r'),(9065,710217026002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','myklikers','redzuanharris@gmail.com','Mohamad Redzuan Harris','MIS TICIS, Legenda Education Group,<br>BUTL, Batu 12,','Mantin','Negeri Sembilan','MALAYSIA','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 13:12:07',0,NULL,3,1,2,1,NULL,'myklikers'),(9066,669266754001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','galminas666','ktvarte@yahoo.com','Nilius Galminas','Silutes pl. 22-83','Klaipeda','','LITHUANIA','91175','(370) 68440666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:08:46',0,NULL,3,1,2,1,NULL,'galminas666'),(9067,669268838001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','giuserico','giuchio@yahoo.it','Giuseppe Chierico','via Francesco Scotti 3','Civitavecchia','RM','ITALY','00053','0766546156','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:14:23',0,NULL,3,1,2,1,NULL,'giuserico'),(9068,710237409002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','972546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 14:15:27',0,NULL,3,1,2,1,NULL,'meir_shevach'),(9069,765802409016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','hollysnead100','snead@live.co.uk','Holly  Snead','9 Coniston Road','Bexleyheath ','Kent','UNITED KINGDOM','DA7 6PX','01322339569','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 14:25:37',0,NULL,3,1,4,1,' YW865907351CN','hollysnead100\r 英标\rlighting kit $40\r王'),(9070,669275436001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','wiendhof','r.withoff@kpnmail.nl','Rob Withoff','Aperloheve 15','Elburg','','NETHERLANDS','8081JL','0525685091','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 14:33:56',0,NULL,3,1,2,1,NULL,'wiendhof'),(9071,781773596015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','bekig06','beki.gregory@hotmail.co.uk','Beki Gregory','12 Mariners Wharf<br>Grosvenor Wharf Road','Ellesmere Port','Cheshire','UNITED KINGDOM','CH65 4AS','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 15:10:35',0,NULL,3,1,4,1,'YW865907384CN ','bekig06\r英标\rlighting kit  $22\r刘'),(9072,669298294001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','alisonpitcher','aliee54@hotmail.com','alison pitcher','305-2727 Princess Street','Kingston','ON','CANADA','K7P3K4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:48:45',0,NULL,3,1,2,1,NULL,'alisonpitcher'),(9073,707082582002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-06 15:50:39',0,NULL,7,0,18,0,NULL,'xrobertojosuex'),(9074,669300523001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',2,'AA3315',11.9,'hermeshine','jevgenijast','j_steinbe@yahoo.com','Jevgenija Steinberga','Dzelzavas 35 k1, 49','Riga','','LATVIA','LV-1084','+37126454313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 15:55:46',0,NULL,3,1,2,1,NULL,'jevgenijast'),(9075,669301181001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ethh13','etiennethuillier2000@yahoo.fr','Etienne THUILLIER','71 rue ghesquieres','HELLEMMES','Nord-Pas-de-Calais','FRANCE','59260','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 15:57:10',0,NULL,3,1,3,1,'RA117715653CN\r ','ethh13'),(9076,669316137001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','tricia5271','trishandchris@btinternet.com','Mrs T Seymour (Ebay)','Turners Transport Burton Road<br>St Faiths Ind Estate','Norwich','Norfolk','UNITED KINGDOM','NR6 6AU','01603779807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 16:42:02',0,NULL,3,1,2,1,NULL,'tricia5271'),(9077,668872588001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','731700728','hakis@centrum.cz','Josef Haken','SNP - 634','Hradec Králové','','CZECH REPUBLIC','50003','+420728700731','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-06 18:00:53',0,NULL,3,1,2,1,NULL,'731700728'),(9078,709815550002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','edwardfilm','edward_film@mail.ru','Eduard Filippov','Chilonzar 12-34-4','Tashkent','','UZBEKISTAN','700123','998-712-756131','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 18:03:44',0,NULL,3,1,3,1,'RA117715605CN\r ','edwardfilm'),(9079,668288439001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pamy03','pamela_betancourt@yahoo.com','pamela betancourt','Metropolis calle 22 p.5','carolina','PR','UNITED STATES','00987','(787) 467-3863','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 18:07:35',0,NULL,7,0,18,0,NULL,'pamy03'),(9080,669348909001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','genproject99','keyla99@yahoo.com','Keyla  Guevara','361 E Sheridan St<br>Apt 301','Dania Beach','FL','UNITED STATES','33004-5549','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 18:10:09',0,NULL,3,1,1,1,NULL,'genproject99'),(9081,709976109002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','javito_67','jasasal@hotmail.com','Javier Sanchez','Ortiz Mena,104-B','Chihuahua','Chihuahua','MEXICO','31203','6142308690','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 18:17:34',0,NULL,3,1,3,1,'RA117715724CN\r RA117715295CN','javito_67\r2个小包'),(9082,669379863001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:18',0,NULL,3,1,17,0,NULL,'xishuaipeng'),(9083,669379670001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:19',0,NULL,3,1,17,0,NULL,'xishuaipeng'),(9084,710351376002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','xishuaipeng','caopengjia@gmail.com','Pengjia Cao','505 W University Pkwy<br>Apt D11','Baltimore','MD','UNITED STATES','21210-3297','(443) 977-3510','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-06 19:25:20',0,NULL,3,1,1,1,NULL,'xishuaipeng\r镜头筒 中号   1\r中号内胆包 无字   1\r绿叶 UV  52mm   1'),(9085,710360029002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',70,'hermeshine','*blackrock*','blackrock111@gmail.com','Mitja Mlakar','Stantetova 26','Maribor','','SLOVENIA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 19:48:06',0,NULL,3,1,5,1,' CP227022725CN','*blackrock*\r蓝色、绿色背景板\r申报 gift  $20'),(9086,710278685002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','lauradellacasa','lauradel@hotmail.it','alice linardi','via san polo 15a','sassuolo','modena','ITALY','41049','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 20:01:02',0,NULL,3,1,4,1,'YW865907373CN ','lauradellacasa\rbackground support $20\r2m 背景架   白\r'),(9087,669395947001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',9.74,'hermeshine','77148207','e.matveev@mail.ru','Irina Khudzinskaya','Leninsky prospekt, 135-4, apt.41','St. Petersburg','','RUSSIAN FEDERATION','198216','(904)551-0039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:06:23',0,NULL,3,1,17,0,NULL,'77148207'),(9088,710369999002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','fordfebe','fordfebe@terra.es','Fernando Bernal Lopez','c/ Fuente Carrantona nº 38 portal A, 4º centro','Madrid','Madrid','SPAIN','28030','669543201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 20:09:25',0,NULL,3,1,4,1,'YW865907340CN ','fordfebe\r河北背景架   1\r1.6x2.1 白布\rbackground  $20\r'),(9089,710374092002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',2,'AA2322',14.4,'hermeshine','77148207','e.matveev@mail.ru','Irina Khudzinskaya','Leninsky prospekt, 135-4, apt.41','St. Petersburg','','RUSSIAN FEDERATION','198216','(904)551-0039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 20:20:30',0,NULL,3,1,3,1,'RA117715463CN\r ','77148207\r77mm 环架   2\r渐变灰   2\r刘'),(9090,781926113015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','jolene_1990','jolenebaxter1990@hotmail.co.uk','Jolene Baxter','496 Manchester road<br>Linthwaite','Huddersfield','West Yorkshire','UNITED KINGDOM','hd7 5rd','07927989165','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-06 20:27:32',0,NULL,3,1,4,1,'YW865907336CN ','jolene_1990\r英标\r刘'),(9091,781925569015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','bob2104','robertlobell@aol.com','robert lobell','94 kenilworth court<br>lower richmond road','london','London','UNITED KINGDOM','sw15 1ha','0207895050','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 20:33:41',0,NULL,3,1,2,1,NULL,'bob2104'),(9092,710389640002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','minis22','conceptrol@yahoo.com','Dominique Bouchard','2369 Lacordaire','Montreal','QC','CANADA','H1N2M1','(514) 253-5727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:01:11',0,NULL,3,1,3,1,'RA117730196CN ','minis22'),(9093,669426048001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','zaki0000','meir1980@yahoo.com','Tomer Meir','45 Hatomer','Zichron Yaakov','','ISRAEL','30900','(054) 462-3515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:31:25',0,NULL,3,1,2,1,NULL,'zaki0000'),(9094,669433950001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT057',130,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-06 21:56:15',0,NULL,3,1,6,1,'EE520583335CN ','princessvideo\r灯头控制在2kg以下发国内挂号， 灯泡是110v的。\r灯架发EMS外地\r王'),(9095,669438883001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','rootfus','rudi@bizwarcho.com','Rudi Meyenburg (buzzer #2706)','3711-608 9th St SW','Calgary','AB','CANADA','T2P2B3','(403) 880-7559','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 22:16:11',0,NULL,3,1,3,1,'RA117715477CN\r ','rootfus'),(9096,766005148016,260660053762,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',2.79,'hutongstore','ialbal','allison@albal.co.uk','Alison Donnellan','52 broadhurst gardens','Burnham on sea','Somerset','UNITED KINGDOM','TA8 1LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 23:22:29',0,NULL,3,1,2,1,NULL,'ialbal'),(9097,781994079015,250599358006,'Male to Male 52mm-58mm Macro Reverse Ring reversing New',1,'AA1212',2.52,'hutongstore','mjbarth1977','mike@mikebartholomew.com','Mike Bartholomew','21 Stadium Drive<br>Kingskerswell','Newton Abbot','Devon','UNITED KINGDOM','TQ125HP','01803393061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-06 23:40:39',0,NULL,3,1,2,1,NULL,'mjbarth1977'),(9098,669460314001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-06 23:50:47',0,NULL,3,1,4,1,'YW865907303CN ','jujusito\r2m 背景架 （白+黑）'),(9099,781998899015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','oraclefilms','willsmith1@live.com','Will Smith','Mitcheldene, Malvern Edge Court,<br>Areley Common','Stourport-on-Severn','Worcestershire','UNITED KINGDOM','DY13 0NP','01299825594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 00:01:16',0,NULL,3,1,2,1,NULL,'oraclefilms'),(9100,669465511001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','bogroll2000','steveliving@gmail.com','Robert Livingston','99 Pinecrest Ave.<br>p.o. box 59','Keene','ON','CANADA','K0L 2G0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 00:35:04',0,NULL,3,1,2,1,NULL,'bogroll2000'),(9101,782009410015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','mattmatt1873','matt.neale@gmail.com','Matthew Neale','25 Edward Road','Leicester','Leicestershire','UNITED KINGDOM','LE2 1TF','07890502854','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 00:45:55',0,NULL,3,1,2,1,NULL,'mattmatt1873'),(9102,710449729002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','grave500','zegrave@netcabo.pt','jose pereira','est. de benfica 447-3ºesq.','lisboa','lisboa','PORTUGAL','1500080','217784574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 01:11:05',0,NULL,3,1,2,1,NULL,'grave500'),(9103,669488678001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','johnkeys','johnnkeys@gmail.com','John Bowditch','p.o box 668','Griffith','New South Wales','AUSTRALIA','2680','0269630676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 02:23:06',0,NULL,3,1,2,1,NULL,'johnkeys'),(9104,669491407001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','berces514','berces514@hotmail.com','Rosa Cardenas','1500 San Remo Ave<br>Ste 140','Coral Gables','FL','UNITED STATES','33146-3041','(305) 666-0200','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 02:37:09',0,NULL,3,1,1,1,'LK003664640CN ','berces514\r再发一个67mm nikon 镜头盖   1\r'),(9105,721564480017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2203',30,'photographyacc','shanks-185','baileyshanks@hotmail.com','bailey shanks','6 nemesis place<br>golden grove','kalgoorlie','Western Australia','AUSTRALIA','6430','0890919157','PayPalPaymentInProcess','CheckoutComplete','AU_RegisteredParcelPost','0000-00-00 00:00:00',0,NULL,3,0,3,1,'RA117715698CN\r ','shanks-185\r4灯头 棚 伞孔   1\r没有棚的那款\r已减库'),(9106,710491964002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','abdulrahim79','lucky_3abdu@hotmail.com','Zayana Sulaiman  Albimani','P.O BOX NO:74 , P.CODE:122 ,mabellah, seeb<br>Oman','seeb','SEEB','OMAN','968','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 04:57:01',0,NULL,3,1,2,1,NULL,'abdulrahim79'),(9107,669518648001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','truebluesky66','littlewhitehouse@mail.com','valerie pribek','50 Rose Ave','Brantford','ON','CANADA','N3S 2M2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 05:34:47',0,NULL,3,1,2,1,NULL,'truebluesky66'),(9108,766126655016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','daizoff08','carlsand@tpg.com.au','sandra atkinson','15 john st','morphett vale','South Australia','AUSTRALIA','5162','0883824369','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 06:50:18',0,NULL,3,1,2,1,NULL,'daizoff08'),(9109,669536241001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','jsh3d','jsh3d@aol.com','James Hegarty','1134 Culverhill Dr','Saint Louis','MO','UNITED STATES','63119-4938','(314) 954-9019','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-07 07:26:44',0,NULL,3,1,1,1,NULL,'jsh3d'),(9110,669549261001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','ahmed4g','ahmed2xp@yahoo.com','Ahmed AlMohannadi','P.O. box 60175','AlKhor','','QATAR','60175','974 5584 1133','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 08:19:17',0,NULL,3,1,3,1,'RA117715525CN\r ','ahmed4g'),(9111,710551461002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jsei2539','seijas2000@hotmail.com','jose luis seijas escarti','Forestal del Atlántico<br>punta promontorio, sn','mugardos','Galicia','SPAIN','15620','639890315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 09:55:25',0,NULL,3,1,17,0,NULL,'jsei2539'),(9112,669574353001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',6.98,'hermeshine','jsei2539','seijas2000@hotmail.com','jose luis seijas escarti','Forestal del Atlántico<br>punta promontorio, sn','mugardos','Galicia','SPAIN','15620','639890315','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 10:04:06',0,NULL,3,1,2,1,NULL,'jsei2539\rEW-73B   1\r爵影快门线C1    1'),(9113,668260411018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','apichart_062518','apicaht_2518@hotmail.com','apichart kerdchengmeng','100/246 m.3 t.bangkurad s.vodladpladok','nontaburee','abangboutong jnontaburee','THAILAND','11110','089-177-4949','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-07 10:57:08',0,NULL,3,1,2,1,NULL,'apichart_062518'),(9114,710569311002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','recom71','vladislav@recom-km.cz','Vladislav Frantis','Spacilova 3036','Kromeriz','','CZECH REPUBLIC','76701','+420605781297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 11:04:48',0,NULL,3,1,2,1,NULL,'recom71'),(9115,705397259002,120654651653,'Pro Photo Vest Blue for Nikon D90 D300s D7000 D80  user',1,'AA2117',32,'hermeshine','soloilfatolivinse011','soloilfatolivinse@hotmail.it','massimo stefanelli','strada camporelle 19','nole','TO','ITALY','10076','011 9297991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 11:07:59',0,NULL,3,0,3,1,'RA117715517CN\r ','soloilfatolivinse011\rXXXL（已入库）'),(9116,669597962001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','visistudio','visi_photographer@hotmail.com','ERVIS BOSTANXHI','Ave Gjergj Kastrioti no.12<br>Lagja no 12','KORCA','AL','ALBANIA','7000','+355672065800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 11:34:36',0,NULL,3,0,3,1,'RA117715619CN\r ','visistudio\rXXL（已入库）'),(9117,668288113018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE3401',35,'photographyacc','carlomanzatti','c.manzatti@optusnet.com.au','Carlo Manzatti','1/20-22 Cumberland Rd','Ingleburn','New South Wales','AUSTRALIA','2565','0296187930','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-07 12:30:16',0,NULL,3,0,3,1,'RA117715551CN\r ','carlomanzatti\r反光板支架   1'),(9118,710612498002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3304',6.98,'hermeshine','mindbender91402','aMindbender@ca.rr.com','Philip G. Meyerson','7615 Yates St','Tujunga','CA','UNITED STATES','91042','(818) 951-1310','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 13:32:47',0,NULL,3,1,1,1,NULL,'mindbender91402'),(9119,710617494002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','winglet604','gilles.morin@vif.com','Gilles Morin','2365 Kensington','Saint-Hubert','QC','CANADA','J3Y 5H9','(450) 926-9767','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 13:48:48',0,NULL,3,1,3,1,'RA117715755CN\r ','winglet604'),(9120,710622819002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','kokoryta','koko.ryta@gmail.com','Jennifer Riccardi','51 Hasting App 209','Dollard des Ormeaux','QC','CANADA','H9G 1Y3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:11:12',0,NULL,3,1,2,1,NULL,'kokoryta'),(9121,710625299002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','lbuhhunyxl','buhhunyx@yahoo.com','Zgurskiy Oleg','Primorskiy kray<br>Kalinina 23-9','Vladivostok','','RUSSIAN FEDERATION','690035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 14:15:00',0,NULL,3,1,2,1,NULL,'lbuhhunyxl'),(9122,782250386015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','chris_9486','chris9486@googlemail.com','Chris Scott','16 Granville Place<br>Allerton','Bradford','West Yorkshire','UNITED KINGDOM','BD15 7QD','07900243445','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 14:52:49',0,NULL,3,1,3,1,'RA117715738CN\r ','chris_9486'),(9123,766311918016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','kevfreeflight','kevfreeflight1@aol.com','Kevin Moseley','42 Sharp House Road','Leeds','West Yorkshire','UNITED KINGDOM','LS10 4SD','07584324634','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 15:58:02',0,NULL,3,1,2,1,NULL,'kevfreeflight\r新地址：\r Kevin Moseley \rCustomer Care Manager Premier Foods Limited Fish Dam Lane Carlton Barnsley S71 3HQ \rUNITED KINGDOM'),(9124,669681539001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dimetras','manyhkin@mail.ru','DMITRY MIRONOV','50 LET OKTYBRY DOM3 KVARTIRA88','GELEZNOVODSK','RU','RUSSIAN FEDERATION','357443','+78793252952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 15:59:49',0,NULL,3,1,2,1,NULL,'dimetras'),(9125,782261097015,250599352972,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','rasmus2503','rasmusnes@gmail.com','Rasmus Nes','Paulus Plass 3 C','Oslo','Oslo','NORWAY','0554','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 16:21:56',0,NULL,3,1,2,1,NULL,'rasmus2503\r新地址：\rRasmus Nes\rAkersbakken 35 E\r0172 Oslo\rNorway\r\r'),(9126,782315065015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','susanns1','susanns1@yahoo.co.uk','Susann Schmidt','Interactive Data - BDG<br>13-17 Epworth Street','London','London','UNITED KINGDOM','EC2A 4DL','07786135252','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 17:13:30',0,NULL,3,1,2,1,NULL,'susanns1'),(9127,668726564001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tinatinamisdameana','tinerbeanerz@gmail.com','Tina Unger','214 little valley trail','Cheyenne','WY','UNITED STATES','82007-3637','(307) 286-8528','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'tinatinamisdameana\r电子支票已结清\r'),(9128,782322078015,250692239997,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',9.98,'hutongstore','jevgenijs2099','javgenijs@mail.ru','Jevgenijs Silava','15 Bronti close','London','London','UNITED KINGDOM','se17 2hd','07786553785','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 17:25:24',0,NULL,3,1,2,1,NULL,'jevgenijs2099'),(9129,669717571001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','1210giro','clupay@gmail.com','Claudio Lupayante Gonzalez','Avenida Valparaiso 363<br>Local 130','Viña del Mar','V Region','CHILE','2571493','(056) 322-9011 ext.: 74','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:30:32',0,NULL,3,1,2,1,NULL,'1210giro\r欧标'),(9130,709085954002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','acbustillo0','acbustillo@hotmail.com','Andres Cruz Bustillo','Francisco Canal 327','Veracruz','Veracruz','MEXICO','91700','(229) 150-3950','NoPaymentFailure','CheckoutComplete','Other','2011-05-07 17:38:08',0,NULL,3,1,17,0,NULL,'acbustillo0'),(9131,710691504002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',3,'AB2301',29.85,'hermeshine','acbustillo0','acbustillo@hotmail.com','Andres Cruz Bustillo','Francisco Canal 327','Veracruz','Veracruz','MEXICO','91700','(229) 150-3950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 17:38:09',0,NULL,3,1,3,1,'RA117715715CN\r ','acbustillo0\r2m 灯架  1\rb座   4\r柔光伞   1'),(9132,782359415015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','malliajo','malliaj63@gmail.com','Joseph Mallia','19, \'Agapimu\' Triq In- Newl','Zebbug','','MALTA','ZBG 2653','21464125','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 18:33:28',0,NULL,3,1,2,1,NULL,'malliajo'),(9133,766388706016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ashleygalea2011','ashleyjgalea@yahoo.co.uk','Ashley Galea','79B St Pauls Court<br>Block F, Door 81','Pioneer Rd','Bugibba','MALTA','SPB','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-07 18:34:46',0,NULL,3,1,5,1,'CP227022708CN\r ','ashleygalea2011\r英标'),(9134,709530899002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','zsofi17','zsofia_babak@yahoo.com','Babak Zsofia','Banffyhunyad u. 1/B','Budapest','','HUNGARY','H-1182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:12:19',0,NULL,3,1,2,1,NULL,'zsofi17'),(9135,669777762001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','mogy3','danbeaton1@shaw.ca','D. Beaton','#110-7428 19th Ave.,<br>(Buzzer #10)','Burnaby','BC','CANADA','V3N1E1','(604) 524-6723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 19:51:51',0,NULL,3,1,17,0,NULL,'mogy3\r'),(9136,766433912016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','245jenkin','bobjenkin@btinternet.com','Bob Jenkin','Sayers Croft Bungalow<br>The Street','Ewhurst','Surrey','UNITED KINGDOM','GU6 &PX','01483267019','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 19:58:06',0,NULL,3,1,3,1,'RA117715548CN\r ','245jenkin'),(9137,721879801017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','pikkijean','nikki.arena@gmail.com','Nicole Arena','20A Greylock Rd','Allston','MA','UNITED STATES','02134-2506','(732) 500-3603','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-07 20:07:47',0,NULL,3,1,1,1,NULL,'pikkijean'),(9138,669782754001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rosielinares','rosiesk33t@gmail.com','Rosamaria Linares','551 Walnut St<br>Apt 32','San Carlos','CA','UNITED STATES','94070-2336','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-07 20:11:53',0,NULL,3,1,1,1,NULL,'rosielinares'),(9139,782427937015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','erndal','dalesz100@t-online.hu','Ernő Dalmády','Csongrádi sgt.73.6/33.','Szeged','','HUNGARY','6723','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 20:40:51',0,NULL,3,1,2,1,NULL,'erndal'),(9140,710786729002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','pepepotamo64','marcovadanero@gmail.com','Marco Varela Adanero','Pablo Iglesias 57','Gijón','Asturias','SPAIN','33205','985130752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-07 21:06:23',0,NULL,3,1,2,1,NULL,'pepepotamo64'),(9141,782440558015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.88,'hutongstore','thaqee90','crossurarms1910@gmail.com','Nurthaqifah Farhani Mujiman','Royal College of Surgeons Ireland,<br>123 St. Stephen\'s Green,','Dublin','Dublin','IRELAND','2','0852426553','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-07 21:07:45',0,NULL,3,1,2,1,NULL,'thaqee90'),(9142,766473582016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','woodscj2005','chrisjameswoods@gmail.com','Chris Woods','12 Heathfield Mews<br>Martlesham Heath','Ipswich','Suffolk','UNITED KINGDOM','IP5 3UF','01473622446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 21:21:54',0,NULL,3,1,2,1,'','woodscj2005'),(9143,710813347002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',2,'AA1103',53.6,'hermeshine','xtralars82','xtralars@baluba.org','Lars Kristian Flor','Vektergata 8','Molde','More og Romsdal','NORWAY','N6413','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-07 22:23:47',0,NULL,3,1,3,1,'RA117715707CN\r ','xtralars82'),(9144,782477585015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','bonzowebber','mdwebber@ntlworld.com','Matthew Webber','1 Burnside Drive','HARROGATE','North Yorkshire','UNITED KINGDOM','HG12BH','01423560378','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-07 22:48:25',0,NULL,3,1,2,1,NULL,'bonzowebber'),(9145,669844474001,110665009924,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',9,'hermeshine','sys2matic328','rlparks@ncsu.edu','Reginald Parks','2001 Kanga Cir','Raleigh','NC','UNITED STATES','27603-2779','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-07 23:13:53',0,NULL,3,1,1,1,NULL,'sys2matic328'),(9146,782501366015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','stevens3876','stevenshiels071@yahoo.co.uk','STEVEN SHIELS','6 VALE VIEW<br>SOUTHSEA','WREXHAM','Wrexham','UNITED KINGDOM','LL116RY','01978721592','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 00:15:15',0,NULL,3,1,2,1,NULL,'stevens3876'),(9147,669869540001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','elected_angel','elected_angel@hotmail.com','Jonathan Massie','279 rue Rosedale','Brownsburg-Chatham','QC','CANADA','J8G 3A6','(450) 407-0505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 01:08:45',0,NULL,3,1,3,1,'RA117715741CN\r ','elected_angel'),(9148,782555371015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','borg1058','ray.borg@blueyonder.co.uk','Ray Borg','15 Millersgate<br>Cottam','Preston','Lancashire','UNITED KINGDOM','PR4 0AZ','01772768112','NoPaymentFailure','CheckoutIncomplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'borg1058'),(9149,669911953001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','mogy3','danbeaton1@shaw.ca','D. Beaton','#110-7428 19th Ave.,<br>(Buzzer #10)','Burnaby','BC','CANADA','V3N1E1','(604) 524-6723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 05:08:37',0,NULL,3,1,3,1,'RA117730205CN ','mogy3\r独脚架  WT-1005   1\r独脚架  WT-1007   1\r1.678'),(9150,710914416002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','jockos5','jockos@gmail.com','Joachim Andersson','estlandsgatan 4c','Göteborg','Västra Götaland','SWEDEN','41877','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:52:43',0,NULL,3,1,4,1,'YW865907410CN','jockos5\r刘\r'),(9151,710914427002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','and-all-in-one','gorynych2012@yandex.ru','Andrey Karlov','Berkimbaeva 95/1 190','Ekibastuz','KZ','KAZAKHSTAN','141200','87012258158','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 06:59:56',0,NULL,3,1,2,1,NULL,'and-all-in-one'),(9152,710926060002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','r3ivaxg','xgavalda@gmail.com','Xavier Gavalda','Entreauto (Gasolinera)<br>c. apel·les mestres 44','Reus','Cataluña','SPAIN','43205','615283176','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 07:39:52',0,NULL,3,1,3,1,'RA117730960CN ','r3ivaxg'),(9153,782615853015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',3.7,'hutongstore','jimjolli','jimjunk1@gmail.com','James R Jolliffe','4 North Worple Way','Mortlake','London','UNITED KINGDOM','SW14 8QG','02083922114','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 08:07:03',0,NULL,3,1,2,1,NULL,'jimjolli'),(9154,669960983001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','janvondeyen','vondeyen@post.tele.dk','Jan von Deyen','Engvej 25',' Nykøbing F','','DENMARK','DK 4800','54822030','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 08:48:05',0,NULL,3,0,3,1,'RA117715534CN\r ','janvondeyen\r3XL(已入库）'),(9155,766688004016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.62,'hutongstore','roryollieollie','galvinrory@hotmail.com','Rory Galvin','seafield road','quilty','Clare','IRELAND','default','0851370204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 10:11:12',0,NULL,3,1,17,0,NULL,'roryollieollie'),(9156,782679525015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',3.88,'hutongstore','roryollieollie','galvinrory@hotmail.com','Rory Galvin','seafield road','quilty','Clare','IRELAND','default','0851370204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 10:37:28',0,NULL,3,1,2,1,NULL,'roryollieollie\r方形滤镜接口环 52mm   1\r方形滤镜 镜片卡座    1\r绿叶 CPL 72mm     1'),(9157,782683179015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','yaboo06','styleguru@live.co.uk','Thomas Dick','17 The Granaries, Baker Lane<br>King\'s Lynn','norfolk','Norfolk','UNITED KINGDOM','PE30 1HY','01553782634','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 10:46:00',0,NULL,3,1,2,1,NULL,'yaboo06'),(9158,711024086002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','andredm74','andredm71@msn.com','Andre de Mornay','5000N MARINE PARADE ROAD<br>#04-60','default','','SINGAPORE','449295','98529288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:26:34',0,NULL,3,1,3,1,'RA117715636CN ','andredm74'),(9159,670041585001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','talanchor','kadavros@gmail.com','Alexander Levshin','Starokachalovskaya street, 1-2-210','Moscow','Moscow','RUSSIAN FEDERATION','117216','+7 495 7110241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:37:15',0,NULL,3,1,2,1,NULL,'talanchor'),(9160,670046928001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','brochar-2007','beag8175@hotmail.com','Bea Rocha Rodrigues','Carrer de les Escoles nº13<br>Escala A 1º 1º','Santa Coloma','Andorra la Vella','ANDORRA','AD500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 12:56:35',0,NULL,3,1,2,1,NULL,'brochar-2007'),(9161,711038521002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','moigol','moigol@netzero.net','Moisey Goltseker','2055 Ocean Ave<br>Apt 3H','Brooklyn','NY','UNITED STATES','11230-7307','','NoPaymentFailure','CheckoutComplete','Other','2011-05-08 13:08:41',0,NULL,3,0,17,0,NULL,'moigol\r已入库\r'),(9162,711037515002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','moigol','moigol@netzero.net','Moisey Goltseker','2055 Ocean Ave<br>Apt 3H','Brooklyn','NY','UNITED STATES','11230-7307','','NoPaymentFailure','CheckoutComplete','Other','2011-05-08 13:08:42',0,NULL,3,1,3,1,'RA117730125CN ','moigol\r摄影背心 黑色厚 无字 3XL    1\r摄影背心 冬夏 XL    1\r1.208\r新地址：\rMoisey Goltseker \rR and B Car Service 1011 Avenue Z Brooklyn NY, 11235 \rUNITED STATES'),(9163,711041058002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lukp123','lukas.pimper@seznam.cz','Lukas Pimper','Zeleznicaru 1343/17B','Prague 7','','CZECH REPUBLIC','17000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 13:10:14',0,NULL,3,1,2,1,NULL,'lukp123'),(9164,670049112001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 13:28:53',0,NULL,3,1,3,1,'RA117715675CN\r RA117730117CN','saud-p\r分2个小包\r布（黑+白）'),(9165,709350338002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','anabojan','anakaiser5@gmail.com','Ana Kajser','D. Gervaisa 14','Zagreb','','CROATIA','10000','00385911512958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 13:49:05',0,NULL,3,1,3,1,'RA117715667CN\r ','anabojan'),(9166,670080497001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:17:01',0,NULL,3,1,17,0,NULL,'nowell63'),(9167,670086166001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 14:30:26',0,NULL,3,1,2,1,NULL,'nowell63\r天涯方形滤镜系列  星光镜  star6    1\r天涯方形滤镜系列  星光镜  star8    1'),(9168,670099932001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','pecheur76','serge.renou@wanadoo.fr','renou serge','10 rue du merlin','criquetot-l\'ésneval','Haute-Normandie','FRANCE','76280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 15:01:18',0,NULL,3,1,2,1,NULL,'pecheur76'),(9169,710237130002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','charcoal257','ashmail69@gmail.com','Charlie Wan','50 Bridge St<br>Apt 215','Brooklyn','NY','UNITED STATES','11201-1176','(917) 770-1613','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 15:28:29',0,NULL,3,1,1,1,NULL,'charcoal257'),(9170,668812805018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','wakkymatty','ohhello@optusnet.com.au','Matthew Stokes','54 Paterson Drive<br>Lynbrook','Melbourne','Victoria','AUSTRALIA','3975','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-08 15:29:01',0,NULL,3,1,4,1,'YW865907292CN ','wakkymatty\r河北的架子 + 1.6x2.1 白色背景布  1\rbackground support   $20\r'),(9171,670148556001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','srbrn1968','srbrn1968srebrev@gmail.com','Srebrin Srebrev','54a, Vasil Drumev Str.','Parvomay','Plovdiv','BULGARIA','4270','+359887519544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 16:32:55',0,NULL,3,1,2,1,NULL,'srbrn1968'),(9172,766893250016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','thomas_bangalter','fatman88_2000@hotmail.com','Andy Brennan','788 Cumbernauld Road (If undelivered don\'t leave with neighbor)<br>Riddrie','Glasgow','North Lanarkshire','UNITED KINGDOM','G33 2EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 16:46:19',0,NULL,3,1,2,1,NULL,'thomas_bangalter'),(9173,782898662015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','cody-ru','codymail@mail.ru','Stanislav Burenkov','ul Makarenko 22 kv 128','Novosibirsk','','RUSSIAN FEDERATION','630027','+79137006583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 17:12:19',0,NULL,3,1,3,1,'RA117715684CN\r ','cody-ru\r刘'),(9174,670229230001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','bkbeaches','b_hoesly@hotmail.com','Barbara Carnahan','5950 Huntington Ave','Lincoln','NE','UNITED STATES','68507-2346','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-08 18:16:38',0,NULL,3,1,1,1,NULL,'bkbeaches'),(9175,711260816002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','olczacek','cyber-world@centrum.cz','Oldrich Mraz','Moskevska 3060/11<br>Most 434 01 Czech Republic','Most','CT','CZECH REPUBLIC','CZE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:05:46',0,NULL,3,1,2,1,NULL,'olczacek'),(9176,670284865001,110523253210,'Pentax 52mm Reverse Adapter Combined shipping discounts',1,'AA1209',3.58,'hermeshine','pa_banach','pa.banach@gmail.com','Paweł Banach','Ul.Chrobrego 40/23','Międzychód','wielkopolskie','POLAND','64400','66 5737917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:24:56',0,NULL,3,1,2,1,NULL,'pa_banach'),(9177,711281983002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:20',0,NULL,3,1,17,0,NULL,'volaart.m'),(9178,711277769002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:20',0,NULL,3,1,17,0,NULL,'volaart.m'),(9179,670288938001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:21',0,NULL,3,1,17,0,NULL,'volaart.m'),(9180,670288032001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 19:34:22',0,NULL,3,1,2,1,NULL,'volaart.m\r绿叶 UV  52mm    1\rNIKON 镜头盖 52mm    1\r橡胶遮光罩 52mm    2\r'),(9181,783088671015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cameraman645','sales@promedia.uk.com','Peter Dodgson','24a Park Road<br>Rhosymedre','Wrexham','Clwyd','UNITED KINGDOM','LL14 3YP','01978812930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 20:20:35',0,NULL,3,1,3,1,'RA117715565CN\r ','cameraman645'),(9182,711340396002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sarja01','sarja_01@hotmail.com','Jorge Adán Sánchez Reséndiz','Calle Donoso Cortes No. 80, 1º-5','Madrid','Madrid','SPAIN','28015','628763349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:09:54',0,NULL,3,1,2,1,NULL,'sarja01'),(9183,670339034001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','smashvideo','silvestar13@hotmail.com','SMASH VIDEO','LOVCENSKA 53','ZAGREB','','CROATIA','10000','+385915654849','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 21:25:22',0,NULL,3,1,5,1,'CP227022699CN ','smashvideo\r王   '),(9184,670354838001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','enk097','tanja.lakic@gmail.com','Tanja Lakic','Zvonimirova 63','Zagreb','Zagreb','CROATIA','10 000','+385 91 560 61 93','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:29:01',0,NULL,3,1,2,1,NULL,'enk097'),(9185,767143771016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','mickjigger','andycom@gmx.co.uk','Andreas Leja','Silverdale<br>Fieldhouse Lane, Hepscott','Morpeth','Northumberland','UNITED KINGDOM','NE61 6LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-08 21:32:50',0,NULL,3,1,2,1,NULL,'mickjigger'),(9186,670357804001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','abo-lamees','abo-lamees@hotmail.com','Ahmad Alsaedi','P.O.BOX 42612','Madina','Madina','SAUDI ARABIA','41551','00966503307752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 21:34:44',0,NULL,3,1,2,1,NULL,'abo-lamees'),(9187,669076327018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',3,'AO0034',23.97,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-08 21:41:00',0,NULL,3,1,2,1,NULL,'igrom78\r810'),(9188,783152781015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3311',5.2,'hutongstore','shiver_sk','shiver123@gmail.com','Martin Jelen','Martina Benku 2','Presov','','SLOVAK REPUBLIC','08001','00421907990152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-08 22:17:48',0,NULL,3,1,2,1,NULL,'shiver_sk\r刘\r62mm 渐变灰   1'),(9189,711383326002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','lo_quemesobra','roger.farrarons@hotmail.com','Roger Farrarons Clusella','C/ Aragó 12-16 Escalera A, 3r piso, 1ª puerta','Castelldefels','Cataluña','SPAIN','08860','617774455','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-08 23:18:40',0,NULL,3,1,4,1,' YW865907395CN\r','lo_quemesobra'),(9190,670400044001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','evo_studio','info@studio-evolution.com','Aleksander Roslavtsev','Pionerskaya st. 5a/62','Odessa','UA','UKRAINE','65009','+380503905902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-08 23:55:46',0,NULL,3,1,2,1,NULL,'evo_studio\r刘'),(9191,711447442002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','funkista','swanky9883@yahoo.com','Brian Tanchanco','89 magallanes avenue, magallanes village','Makati','Metro Manila','PHILIPPINES','1232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 02:37:53',0,NULL,3,1,2,1,NULL,'funkista'),(9203,670501379001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','csuzso','csukaszsolt@t-online.hu','Zsolt Csukás','Szója u. 47.','Békéscsaba','Békés','HUNGARY','5600','+36703189099','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 07:47:24',0,NULL,3,1,3,1,'RA117730182CN ','csuzso'),(9192,670455647001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','feramor','fighter666@inbox.ru','Ekaterina Kamaeva','ul. Universitetskaya, dom 20 korpus 1, kv. 109','Cheboksary','','RUSSIAN FEDERATION','428009','8-9603107067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 03:20:36',0,NULL,3,1,2,1,NULL,'feramor'),(9193,711469422002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','xgou1687','the8ears@gmail.com','Xuehong Gou','4812 Baker St','Norman','OK','UNITED STATES','73072-3858','(405) 445-3296','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 04:15:42',0,NULL,3,1,1,1,NULL,'xgou1687'),(9194,670467329001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','canlens','fbougee@gmail.com','Vladimir Podyukov','Uralskaya ul. 23,<br>korpus 4, kvartira 619','Moscow','','RUSSIAN FEDERATION','107065','+7 79175475967','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 04:25:17',0,NULL,3,1,5,1,'CP227022711CN ','canlens'),(9195,667696455018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',71,'photographyacc','asterx22jw','janwillem@moreto.nl','Jan Willem Bloemendaal','Sumatrastraat 22','BAARN','','NETHERLANDS','3742CW','06-51569466','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 04:38:27',0,NULL,3,1,4,1,'YW865907406CN ','asterx22jw\r灯架  2m    1\r110cm   5in1   1\r大力夹   2\r一票两件\r'),(9196,670481881001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5,'hermeshine','scscanlon','shawn@scanlonmail.com','Shawn Scanlon','4768 Canary Dr','Pleasanton','CA','UNITED STATES','94566-5302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 05:55:55',0,NULL,3,1,1,1,NULL,'scscanlon'),(9197,711488234002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','palmpang','bujakorn_thana@hotmail.com','Thana Bujakorn','12/174 Mu5 Supalai Orchid Park<br>T. Pantaynorasing','Muang','Samutsakorn','THAILAND','74000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:07:42',0,NULL,3,1,11,1,NULL,'palmpang'),(9198,783297159015,250692236486,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','cardyncoke','mr2ste@tiscali.co.uk','stephen horsley','21 lyncroft av.<br>Ripley','Derby','Derbyshire','UNITED KINGDOM','DE53bb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 06:19:47',0,NULL,3,1,2,1,NULL,'cardyncoke'),(9199,711496406002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',3,'AKT056',158,'hermeshine','qwerty_steve','stephenleeis@gmail.com','Stephen Lee','8 Garfield Avenue<br>Bonnet Bay','Sydney','New South Wales','AUSTRALIA','2226','0402248336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:50:50',0,NULL,3,1,4,1,'YW865907432CN ','qwerty_steve\rreflector holder  $30\r'),(9200,711498074002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','edwardfilm','edward_film@mail.ru','Eduard Filippov','Chilonzar 12-34-4','Tashkent','','UZBEKISTAN','700123','998-712-756131','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 06:59:34',0,NULL,3,1,2,1,NULL,'edwardfilm'),(9201,711500138002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','froschotastik','phillip_voigt@yahoo.de','Phillip Voigt','Storchsbrede 12','Bielefeld','','GERMANY','33613','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 07:10:21',0,NULL,3,1,4,1,'YW865907421CN ','froschotastik\rball head  $20'),(9202,670495899001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','pentaprizma','stakac@gmail.com','SERDAL TAKAC','konutkent 2 C6 BLOK B GIRIS DAIRE NO 8<br>CAYYOLU','ANKARA','-','TURKEY','06810','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 07:16:03',0,NULL,3,1,2,1,NULL,'pentaprizma'),(9204,711510515002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','magicdean16','dean@kenscones.com.au','Dean Murray','4 Redman Avenue','Thirroul','New South Wales','AUSTRALIA','2515','0242673477','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 08:02:28',0,NULL,3,1,3,1,'RA117730179CN ','magicdean16\rM（已入库）\r'),(9205,670509814001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','riendi','chochon@gmail.com','Marylise Devoyault','1066 Rang 1 Ouest','Sainte-Christine','QC','CANADA','J0H 1H0','(819) 858-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 08:29:28',0,NULL,3,1,2,1,NULL,'riendi'),(9206,711529982002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AD1105',40.99,'hermeshine','michael_and_carina2009','michael_and_carina@yahoo.com','Michael Bethea','Münchener Straße 30','Taufkirchen','','GERMANY','82024','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 09:33:33',0,NULL,3,0,3,1,'RA117730528CN\r ','michael_and_carina2009\rcanon N4 单肩包 （已减库）\r王'),(9207,783354225015,250611184205,'New Wireless Flash Sync Trigger Receiver D700 D90 5D II',1,'AB3322',13.19,'hutongstore','shark_74','andrea.fantacci@tin.it','Andrea Fantacci o Fantacci Virgilio','Via Vecchia Dell\'Arcale, 23','PISTOIA','PT','ITALY','51100','3357225841','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 09:54:19',0,NULL,3,1,2,1,'、 ','shark_74'),(9208,767363719016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','birokornel','birokornel@freemail.hu','Tamás Gerő','Hajó str. 8. IV/15.','Debrecen','Hajdú-Bihar','HUNGARY','4026','0036302920710','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 10:16:55',0,NULL,3,1,2,1,NULL,'birokornel\r庄'),(9209,711541072002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bertinluca','lucabertin@libero.it','Bertin Luca c/o SEROFFICE SRL','viale Pilone 87/e','Asti','AT','ITALY','14100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 10:21:09',0,NULL,3,0,17,0,NULL,'bertinluca'),(9210,711540611002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bertinluca','lucabertin@libero.it','Bertin Luca c/o SEROFFICE SRL','viale Pilone 87/e','Asti','AT','ITALY','14100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 10:21:09',0,NULL,3,0,3,1,'RA117730491CN\r ','bertinluca\rXXL    1\rXXXL     1  （已减库）\r王'),(9211,669246328018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',23,'photographyacc','shanepends0412','shanepends@yahoo.com.au','shane pendlebury','62 barondi ave<br>narre warren','melbourne','Victoria','AUSTRALIA','3805','0412682655','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-09 10:48:43',0,NULL,3,1,3,1,'RA117730505CN\r ','shanepends0412\r62mm ring adapter x3 , \r72mm ring adapter x3 \rand filter holder x 1 \r王'),(9212,722403333017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',16.85,'photographyacc','tach-ik','sergey.lagoutine@gmail.com','Sergey Lagoutine','Coniwa I-Dom K-32<br>Belgorod region','Starij Oskol','RI','RUSSIAN FEDERATION','309500','7(4725)426611','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 10:49:18',0,NULL,3,1,2,1,NULL,'tach-ik\r庄'),(9213,783373273015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','toby150_0','meonebay17@gmail.com','David Eason','7 Lime Grove','Holbeach','Spalding','UNITED KINGDOM','PE12 7NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 10:53:48',0,NULL,3,1,3,1,'RA117730430CN\r ','toby150_0\r刘'),(9214,709342088002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bikerbert1','ksslrbert1@aol.com','Roberta Kessler','1985 Sleepy Hollow Rd','Milan','OH','UNITED STATES','44846-9604','(419) 499-4055','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 11:00:01',0,NULL,3,1,1,1,NULL,'bikerbert1\r刘'),(9215,670555766001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','myniftybooks','chuck@camroux.com','Chuck Camroux','PO Box 2006','Niagara Falls','NY','UNITED STATES','14302','(905) 356-7336','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 11:40:36',0,NULL,3,1,1,1,NULL,'myniftybooks\r刘'),(9216,783390817015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','gonzila','klocek56@wp.pl','Piotr Kadziolka','2 temple Court<br>Palatine Square','Dublin','Dublin','IRELAND','7','0870928912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 11:53:25',0,NULL,3,1,2,1,NULL,'gonzila\r庄'),(9217,670559616001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','fendyjo','josf@iinet.net.au','Fendy Jo','29 Treetop Circuit','Quakers Hill','New South Wales','AUSTRALIA','2763','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 11:56:40',0,NULL,3,1,2,1,NULL,'fendyjo\r庄'),(9218,669295970018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','saunanen','aldis23@balticom.lv','Aldis Pirtnieks','Lielvardes 101-9','Riga','Riga','LATVIA','LV-1084','+37129422566','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-09 12:33:55',0,NULL,3,1,2,1,NULL,'saunanen\r庄'),(9219,783410925015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','patbell101','pat@patbell.co.uk','Patrick Bell','1 Saxon Way<br>Lindfield','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 2NT','07795690883','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 12:41:31',0,NULL,3,1,2,1,NULL,'patbell101\r庄'),(9220,711586511002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dekalos','sdekalo@gmail.com','shahar dekalo','hamelaacha 2','ramat hasharon','israel','ISRAEL','47445','0544578957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:01:58',0,NULL,3,1,2,1,NULL,'dekalos\r庄'),(9221,783415758015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:06',0,NULL,3,1,17,0,NULL,'jfarenden'),(9222,783417228015,250599406095,'Green.L 62mm 62 Neutral Density ND4 Filter ND 4 New',1,'AE2304',4.1,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:05',0,NULL,3,1,17,0,NULL,'jfarenden'),(9223,783412540015,250599383462,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3304',2.5,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:07',0,NULL,3,1,17,0,NULL,'jfarenden'),(9224,767414617016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:07',0,NULL,3,1,17,0,NULL,'jfarenden'),(9225,767415795016,260661403326,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',5.2,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:08',0,NULL,3,1,17,0,' ','jfarenden'),(9226,783413953015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:09',0,NULL,3,1,17,0,NULL,'jfarenden'),(9227,767417634016,260661403826,'TianYa 72mm ND8 filter New 72 Neutral Density Grey NIB',1,'AA2313',5.78,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:09',0,NULL,3,1,17,0,NULL,'jfarenden'),(9228,767417839016,260661403734,'TianYa 62mm ND8 filter New 62 Neutral Density Grey NIB',1,'AA2311',5.49,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:10',0,NULL,3,1,17,0,NULL,'jfarenden'),(9229,783415996015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','08935464486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 13:07:11',0,NULL,3,1,3,1,'RA117727679CN\r ','jfarenden\r绿叶 渐变镜 62mm   1\r天涯 ND8 62mm    1\r天涯 ND8 72mm    1\r绿叶 UV  72mm\r天涯 cpl 72mm\rlenspen    2\r绿叶 UV  62mm   1\r绿叶 ND4  62mm    1\r绿叶 渐变镜 72mm   1\r绿叶72mm    ND4   1\r绿叶62mm cpl    1\r'),(9230,670584060001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','bjossif','bfinnbogason@gmail.com','Björn Finnbogason','Langafit 14','Garðabær','','ICELAND','210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 13:35:57',0,NULL,3,1,17,0,NULL,'bjossif'),(9231,670583760001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','bjossif','bfinnbogason@gmail.com','Björn Finnbogason','Langafit 14','Garðabær','','ICELAND','210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 13:35:58',0,NULL,3,1,3,1,'RA117730488CN\r ','bjossif\r天涯方镜   渐变橙+蓝+灰    1\r天涯方镜   ND2+ND4+ND8  1\r6片装滤镜袋    1\r67mm 环+架   1\r王\r'),(9232,667383862018,280666888538,'New Green.L 55mm  Gradual Grey ND4 Filter 2-Stop 55 mm',1,'AA3316',6.2,'photographyacc','scrub_tas','lscrivin@bordernet.com.au','Alex Scrivin','125 Brittains Road','Garden Island Creek','Tasmania','AUSTRALIA','7112','0362978139','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-09 14:03:20',0,NULL,3,1,2,1,' ','scrub_tas\r庄'),(9233,0,110683185674,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',0.99,'hermeshine','jinyong72','sashimi72@hotmail.com','JINYONG WANG','141 S 110th St','OMAHA','NE','UNITED STATES','68154','(402) 850-4543','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:50:20',0,NULL,3,1,1,1,NULL,'jinyong72\r刘'),(9234,0,120720079958,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',1.85,'hermeshine','434434','ibrad3000@yahoo.com','ioan brad','5652 W Cullom Ave','chicago','IL','UNITED STATES','60634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:51:45',0,NULL,3,1,17,0,NULL,'434434'),(9235,0,120720079606,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.26,'hermeshine','434434','ibrad3000@yahoo.com','ioan brad','5652 W Cullom Ave','chicago','IL','UNITED STATES','60634','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 14:51:46',0,NULL,3,1,1,1,NULL,'434434\rnikon 反接环  52mm    1\rcanon 反接环  52mm   1\r刘'),(9236,711621161002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yairb','yair999@gmail.com','Yair Bartal','Hanasi Harishon 12','Rehovot','Israel','ISRAEL','76300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:53:43',0,NULL,3,1,2,1,NULL,'yairb\r庄\r'),(9237,670615208001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','gemahenlahen','alojzk@gmail.com','Alojz Kvocic','Balokoviceva 31','Zagreb','','CROATIA','10020','385992299988','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 14:59:25',0,NULL,3,1,2,1,NULL,'gemahenlahen\r庄'),(9238,670624596001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','proton_007','proton11@comcast.net','Gene Arrington','1125 troupe st','augusta','GA','UNITED STATES','30904','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 15:27:42',0,NULL,3,1,1,1,NULL,'proton_007\r刘'),(9239,0,110683184536,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',0.99,'hermeshine','cilonemsw','aphoenixrising@animail.net','Nicole or Dan Piper','1512 Gerald Ave','Lehigh Acres','FL','UNITED STATES','33972-2324','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 15:38:25',0,NULL,3,1,1,1,NULL,'cilonemsw\r刘'),(9240,0,110683184816,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',0.99,'hermeshine','rhoddity218','rhoddity@gmail.com','Ramiro Hernandez','5286 San Bernardo Ter','San Diego','CA','UNITED STATES','92114','(619) 453-4053','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:18:35',0,NULL,3,1,1,1,NULL,'rhoddity218\r刘'),(9241,0,110683184889,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',1.29,'hermeshine','wzhou2011','wzhou.yan@gmail.com','wei zhou','17A , Forest Village,<br>3001 south providence RD','columbia','MO','UNITED STATES','65203','(573) 823-4663','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:25:13',0,NULL,3,1,17,0,NULL,'wzhou2011'),(9242,0,110683184847,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',1.29,'hermeshine','wzhou2011','wzhou.yan@gmail.com','wei zhou','17A , Forest Village,<br>3001 south providence RD','columbia','MO','UNITED STATES','65203','(573) 823-4663','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 16:25:14',0,NULL,3,1,1,1,NULL,'wzhou2011\r橡胶遮光罩 62mm    1\r绿叶 CPL  62mm     1\r刘'),(9243,767521805016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','oraclefilms','willsmith1@live.com','Will Smith','Mitcheldene, Malvern Edge Court,<br>Areley Common','Stourport-on-Severn','Worcestershire','UNITED KINGDOM','DY13 0NP','01299825594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 17:07:22',0,NULL,3,1,2,1,' ','oraclefilms\r庄'),(9244,711674864002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',27.9,'hermeshine','chef000','eclipse7210@comcast.net','ED Horincewich','9727 Touchton Rd<br>Apt 1907','Jacksonville','FL','UNITED STATES','32246-8285','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-09 17:15:22',0,NULL,3,1,1,1,NULL,'chef000'),(9245,670666565001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','rainsdropz','alanng89@gmail.com','alan ng','2 Angklong lane, #06-02<br>S\'pore 579978','default','','SINGAPORE','579978','93832401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 17:17:12',0,NULL,3,1,11,1,NULL,'rainsdropz'),(9246,711696198002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','teletz','valerian.ramich@web.de','Valerian Ramich','Waldemar-Petersen-Str. 22','Kassel','','GERMANY','34123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 18:01:14',0,NULL,3,1,2,1,NULL,'teletz\r庄'),(9247,0,110683185240,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.26,'hermeshine','linebleu','phkdk@umich.edu','Per Kjeldsen','3069 N Foxridge Ct','Ann Arbor','MI','UNITED STATES','48105','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 18:02:47',0,NULL,3,1,1,1,NULL,'linebleu\r刘'),(9248,767556759016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','jvidalxx','jvidalx@gmail.com','Jose A. Vidal','Turquesa, 53, 3B<br>Urbanizacion Mediterraneo','Cartagena','Murcia','SPAIN','30310','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 18:08:16',0,NULL,3,1,4,1,'YW865907524CN\r ','jvidalxx\r王\r'),(9249,670693937001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','patou4266','ptremblay40@gmail.com','Patrice Tremblay','3267, St-Jacques','Montréal','QC','CANADA','H4c 1G8','(514) 678-0304','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 18:15:03',0,NULL,3,1,3,1,'RA117730426CN\r ','patou4266\r刘'),(9250,0,110683185354,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',3,'hermeshine','ilistu','weseemail@yahoo.com','Bogdan Melnichuk','6224 Opus Ct','Citrus Heights','CA','UNITED STATES','95621','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 18:21:37',0,NULL,3,1,1,1,NULL,'ilistu\r刘'),(9251,783575623015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','gragen67','negarg63@hotmail.com','George Ragen','172 Blackburn Road<br>Great Harwood','Blackburn','Lancashire','UNITED KINGDOM','BB67LU','01254889932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 18:29:31',0,NULL,3,1,2,1,NULL,'gragen67\r庄'),(9252,783594366015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','al999land','sanantoine@eircom.net','Alan Landers','San Antoine','Cahersiveen','Kerry','IRELAND','na','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 18:59:27',0,NULL,3,1,3,1,'RA117730602CN\r ','al999land\r刘\r新地址：\rAlan Landers \rSan Antoine\rCahersiveen\rCo Kerry\rIRELAND\r'),(9253,767590491016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','high-pockets83','beasleyj@gmail.com','John Beasley','69 Thornfields<br>Kilbrogan Hill','Bandon','','IRELAND','09','0861651752','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 19:03:28',0,NULL,3,1,2,1,NULL,'high-pockets83\r庄'),(9254,0,110683184476,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',1.3,'hermeshine','mamochka','roman.ginzburg@lausd.net','Roman Ginzburg','1314 N Fuller Ave<br>Apt 207','Los Angeles','CA','UNITED STATES','90046-4842','(323) 980-6459','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 19:40:10',0,NULL,3,1,1,1,NULL,'mamochka\r刘'),(9255,767640818016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','tigertim0101','timharwood1@aol.com','Tim Harwood','39 Hamble Drive','Abingdon','Oxfordshire','UNITED KINGDOM','OX14 3TF','07703554729','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:16:45',0,NULL,3,1,2,1,NULL,'tigertim0101\r庄'),(9256,0,110683184666,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',0.99,'hermeshine','thrifty_crystal','puppawuppa@yahoo.com','crystal herrera','14811 West Rd<br>Apt 4107','houston','TX','UNITED STATES','77095-3188','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-09 20:21:09',0,NULL,3,1,1,1,NULL,'thrifty_crystal\r刘'),(9257,780251777015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',2,'AA1315',4.4,'hutongstore','sriparna1','sriparnamukherjee@yahoo.com','Sriparna Mukherjee','Flat 12<br>1 Tavistock Road','Croydon','Surrey','UNITED KINGDOM','CR0 2AL','02086649388','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:27:50',0,NULL,3,1,2,1,' ','sriparna1\r庄'),(9258,711776611002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','ra100n','nemecr@gmail.com','Rastislav Nemec','Kapusianska 3','Bratislava','','SLOVAK REPUBLIC','82102','+421-903-386573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 20:36:52',0,NULL,3,1,2,1,NULL,'ra100n'),(9259,767653395016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',3,'AB1301',6.45,'hutongstore','konusso','lukaszkrawczak@poczta.onet.pl','LUKASZ KRAWCZAK','74 coleridge gardens','LINCOLN','Lincolnshire','UNITED KINGDOM','ln2 4nq','1522873004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-09 20:38:27',0,NULL,3,1,2,1,NULL,'konusso\r庄'),(9260,767662300016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','sbresling','s.bresling@mail.dk','Soren Bresling','Klostervej 36','Ry','','DENMARK','8680','+45 24875062','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-09 20:55:54',0,NULL,3,1,2,1,NULL,'sbresling\r黑\r庄'),(9261,670784269001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','teidepicoviejo','teidepicoguajara@yahoo.es','Manuel Suárez Izquierdo','Sargento Provisional, 51 - 7º I.','Santa Cruz de Tenerife','Canarias','SPAIN','38010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-09 21:29:20',0,NULL,3,1,2,1,NULL,'teidepicoviejo\r庄'),(9262,711801830002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','dhubhh','dhubhe@vodafone.es','Jose Manuel Beltran Puig','C/ Clapisa nº32','Benicarló','Castellon','SPAIN','12580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 21:37:56',0,NULL,3,1,2,1,NULL,'dhubhh\r庄'),(9263,783698391015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 22:00:57',0,NULL,3,1,17,0,NULL,'zuhmia'),(9264,767693516016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',58,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-09 22:03:02',0,NULL,3,1,4,1,'YW865907480CN ','zuhmia\r欧标\r灯架  2m   3\r50-70cm 单灯头 柔光箱   3\r斜臂   1\r115w 220v 灯泡   3\r灯架包   1\r庄\r'),(9265,711812562002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran Baća','Pavletićeva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 22:10:29',0,NULL,3,1,17,0,NULL,'fr4nt1k'),(9266,670799726001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','fr4nt1k','franbaca@yahoo.com','Fran Baća','Pavletićeva 12','Zagreb','','CROATIA','10000','+385 95 8580 218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-09 22:10:30',0,NULL,3,1,2,1,NULL,'fr4nt1k\r天涯方形滤镜  渐变灰   1\r方形滤镜接口环 77mm   1\r庄\r方形滤镜 镜片卡座    1'),(9267,670825939001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','photoadicted','chavez2jm@hotmail.com','Jose Chavez','2023 Castellana Ct','Livingston','CA','UNITED STATES','95334-1735','(209) 394-7812','NoPaymentFailure','CheckoutComplete','Other','2011-05-09 23:59:17',0,NULL,3,1,3,1,'RA117730457CN\r ','photoadicted\r刘'),(9268,711840511002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lininhaohara','linaohara@hotmail.com','Lina Ohara','Fujigaoka 1-1-1<br>Konan Danchi 5-302','Konan-shi','Aichi','JAPAN','483-8337','080-3611-9201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:01:37',0,NULL,3,0,17,0,NULL,'lininhaohara'),(9269,711843421002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lininhaohara','linaohara@hotmail.com','Lina Ohara','Fujigaoka 1-1-1<br>Konan Danchi 5-302','Konan-shi','Aichi','JAPAN','483-8337','080-3611-9201','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:11:50',0,NULL,3,1,3,1,'RA117730474CN\r ','lininhaohara\r摄影背心 Canon  老款  M   1\r摄影背心 Canon  老款  3XL   1（已入库）'),(9270,711843767002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','jamesa.0123','jamesagrady@btinternet.com','james grady','12 halifax rd','shortstown','Bedfordshire','UNITED KINGDOM','mk420uu','01234741882','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 00:13:32',0,NULL,3,1,4,1,'YW865907535CN\r ','jamesa.0123\r刘'),(9271,767736502016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','adsayer','adsayer_uk@yahoo.com','Adam Sayer','13AB02 (Enflo Research)<br>University of Surrey','Guildford','Surrey','UNITED KINGDOM','GU2 7XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 00:26:03',0,NULL,3,1,3,1,'RA117730531CN\r ','adsayer'),(9272,723018661017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','darkwhiterevolution','dj_darkwhite@hotmail.com','Kim Paroz','20 River Vista CRT','Maroochy River','Queensland','AUSTRALIA','4561','0449151184','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-10 00:54:47',0,NULL,3,1,2,1,NULL,'darkwhiterevolution\r庄'),(9273,670839762001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','skanske','gregefalk@bolina.hsb.se','Peter Gregefalk','Annebergsgatan 9c','Malmö','','SWEDEN','214 66','(040)82452','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 01:09:47',0,NULL,3,1,2,1,NULL,'skans\r庄'),(9274,711865974002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','coinman_in_jersey','andrewhager@msn.com','andrew hager','244 regina ave','mercerville','NJ','UNITED STATES','08619','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 01:38:27',0,NULL,3,1,1,1,' ','coinman_in_jersey'),(9275,670854812001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','cwehof','chuck@wehofer.com','Charles R. Wehofer','2608 W Irisado Cir','Mesa','AZ','UNITED STATES','85202-5419','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:04:27',0,NULL,3,1,1,1,NULL,'cwehof'),(9276,670861308001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','c2thew','pookythebear31@hotmail.com','Crandall Wong','251 E Kempton Pl','monterey park','CA','UNITED STATES','91755','(213) 999-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:41:27',0,NULL,3,1,17,0,NULL,'c2thew'),(9277,0,110683185067,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',0.99,'hermeshine','c2thew','pookythebear31@hotmail.com','Crandall Wong','251 E Kempton Pl','monterey park','CA','UNITED STATES','91755','(213) 999-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 02:41:28',0,NULL,3,1,1,1,NULL,'c2thew\rCANON 镜头盖  77mm   1\r77mm 环+架    1'),(9278,711892234002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','barm9762','barry.armstead@grapevine.com.au','Barry Armstead','2 Cope Place','Wanniassa','Australian Capital Territory','AUSTRALIA','2903','610401052548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 03:26:13',0,NULL,3,1,3,1,'RA117730514CN\r ','barm9762'),(9279,711896138002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:37',0,NULL,3,1,17,0,NULL,'ishamon'),(9280,711895702002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 03:49:37',0,NULL,3,1,17,0,NULL,'ishamon\r'),(9281,711895962002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:38',0,NULL,3,1,17,0,NULL,'ishamon'),(9282,670875310001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:38',0,NULL,3,1,17,0,NULL,'ishamon'),(9283,670875757001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 03:49:39',0,NULL,3,1,17,0,NULL,'ishamon'),(9284,670875566001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','ishamon','monishadas@msn.com','Monisha Das','1117 High Country Rd','Baltimore','MD','UNITED STATES','21286','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 03:49:39',0,NULL,3,1,4,1,'YW865907491CN ','ishamon\r中号内胆包 无字   1\r倒影板（白黑）    1\r圆形柔光棚 40cm  1\r反光板 60cm 2合1   1\r大力夹   1\r柔光伞   1\r1.660\r庄'),(9285,711900622002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','pyochi','pyly@vtr.net','Pilar Ramirez','General Blanche 11465<br>Las Condes','Santiago de Chile','','CHILE','7600061','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 04:16:01',0,NULL,3,1,2,1,NULL,'pyochi\r庄'),(9286,711902676002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','mawuchong','mawuchong@hotmail.com','Wuchong (Matthew) Ma','3755 Riverside Drive,P.O. Box 9707, Station T<br>IBM Co.','Ottawa','ON','CANADA','K1G 4K9','(613) 356-6875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 04:24:15',0,NULL,3,1,2,1,NULL,'mawuchong'),(9287,669626341018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','*sharklady*','sharkey@iinet.net.au','Lori Sharkey','60 Evelyn Street','Gosnells','Western Australia','AUSTRALIA','6110','0893986252','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-10 04:39:26',0,NULL,3,1,3,1,'RA117730806CN ','*sharklady*'),(9288,767828366016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','ellenorstyf','ellenors_@hotmail.com','Ellenor Styf','Sockenvagen 15','Vilhelmina','','SWEDEN','91234','073-8435780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 06:48:41',0,NULL,3,1,2,1,NULL,'ellenorstyf'),(9289,670905921001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','golgota8351','galenvp@hotmail.com','parianen veerasamy','gentilly branch road petit verger','st pierre','/','MAURITIUS','no postal co','2307739000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 06:58:39',0,NULL,3,1,3,1,'RA117730797CN ','golgota8351'),(9290,711930581002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',73.3,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 07:09:20',0,NULL,3,1,4,1,'YW865907465CN ','istokka'),(9291,765551897016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','bigpeter57','peter.nagy@bredband2.com','PETER NAGY','Linehedsv. 25','HALMSTAD','Halland','SWEDEN','30252','035-122636','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 07:45:40',0,NULL,3,1,2,1,NULL,'bigpeter57'),(9292,723112036017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','maximk1985','viciouskms@mail.ru','Maxim Kurmanov','Свердлова 30-35','Новкузнецк','Кемеровская обл','RUSSIAN FEDERATION','654080','89133117362','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-10 08:17:43',0,NULL,3,1,5,1,'CP227020622CN ','maximk1985\r欧标\r庄'),(9293,711969552002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','javivisteam','javivisteam@terra.es','Javier Mateos Caballero','Avd. Reina Sofía  24, portal 1, 2ºc','Mérida','Extremadura','SPAIN','06800','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 10:22:43',0,NULL,3,1,4,1,'YW865907572CN ','javivisteam\rtripod  $15\r庄'),(9294,670948707001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',3,'AB1302',10.02,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:24:32',0,NULL,3,1,17,0,NULL,'wswswswsgixxer'),(9295,711970724002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:25:49',0,NULL,3,1,17,0,NULL,'wswswswsgixxer'),(9296,670948336001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:26:57',0,NULL,3,1,17,0,NULL,'wswswswsgixxer'),(9297,670948128001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','wswswswsgixxer','woschnepf@googlemail.com','schnepf','kernerstrasse 1','Wiernsheim','','GERMANY','75446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 10:28:06',0,NULL,3,1,3,1,'RA117730987CN ','wswswswsgixxer\r52mm 橡胶罩   1\r58mm 橡胶罩   2\r77mm 橡胶罩   1\r55mm 橡胶罩   3\r刘'),(9298,670797652001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','medi-anna','mediannastudio@gmail.com','Aleksandr Demidov','prospekt Lenina, dom 53, kv.25','Novorossiysk','Krasnodarskiy kray','RUSSIAN FEDERATION','353913','905-494-8478','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 11:00:19',0,NULL,3,1,3,1,'RA117730871CN ','medi-anna\r刘'),(9299,783687305015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','etrader5858','ngng31@excite.com','Mr N Gapp','Russell Cottage<br>Catteshall Lane','Godalming','Surrey','UNITED KINGDOM','GU7 1UT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 11:04:21',0,NULL,3,1,3,1,'RA117730911CN ','etrader5858\r刘'),(9300,783913666015,250599922417,'New 58mm 58 Ring adapter and Holder for Cokin P Series ',1,'AKT020',3.62,'hutongstore','josepinheiroesales','pinheirojose@gmail.com','José Pinheiro','Rua José Monteiro de Castro Portugal 667 Ent B 1º DT','Vila Nova de Gaia','','PORTUGAL','4405-568','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 11:20:20',0,NULL,3,1,2,1,NULL,'josepinheiroesales\r刘'),(9301,711986976002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','bkphotog212','info@pavelshpakphotography.com','Pavel SHPAK','1871 W 5th St','BROOKLYN','NY','UNITED STATES','11223-2630','(917) 533-2308','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-10 11:27:09',0,NULL,3,1,1,1,NULL,'bkphotog212'),(9302,0,110683185116,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',1.14,'hermeshine','bobcat7677','bobcat7677@yahoo.com','Robert Bachelder','922 Prospect St<br>Apt A','Oregon City','OR','UNITED STATES','97045-3797','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 11:36:51',0,NULL,3,1,1,1,NULL,'bobcat7677\r刘'),(9303,712008386002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','fitzgibbon386','davidfitzgibbon@blueyonder.co.uk','DAVID FITZGIBBON','86,PORTER CLOSE','WEST THURROCK','Essex','UNITED KINGDOM','RM20 4AS','01375409656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 12:45:14',0,NULL,3,1,2,1,NULL,'fitzgibbon386\r刘'),(9304,723179398017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','egapretsel','page555@aanet.com.au','lester page','65  eucalyptus blvd canningvale','perth','Western Australia','AUSTRALIA','6155','0894557696','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-10 12:45:29',0,NULL,3,1,17,0,NULL,'egapretsel'),(9305,723178955017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','egapretsel','page555@aanet.com.au','lester page','65  eucalyptus blvd canningvale','perth','Western Australia','AUSTRALIA','6155','0894557696','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-10 12:47:46',0,NULL,3,1,4,1,'YW865907561CN ','egapretsel\r澳标\r再加一个爵影红外 canon   1\rlighting kit  $30\r庄'),(9306,712012406002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','poziruem','kofoto@mail.ru','Konstantin Semenets','Saratovski pereulok 14','Krasnodar','Krasnodarski kraĭ','RUSSIAN FEDERATION','350020','(918)311-1009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 13:08:34',0,NULL,3,1,3,1,'RA117733285CN ','poziruem\r刘'),(9307,767943949016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','bronwen1963','bronpeek@yahoo.co.uk','Jasmine (PD Services)','Office suite 3.24, QWest<br>Great West Road','Brentford','Middlesex','UNITED KINGDOM','TW8 0GP','02077857210','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 13:34:52',0,NULL,3,1,3,1,'RA117730823CN ','bronwen1963'),(9308,671005852001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','e-world-2010','evmatos2008@yahoo.com','Evelio Matos','1041 Lowell Dr<br>Apt 1','Oconomowoc','WI','UNITED STATES','53066-4302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 13:59:13',0,NULL,3,1,1,1,NULL,'e-world-2010\r刘'),(9309,712030392002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','alexeysamokhvalov','samohvalov@gmail.com','Alexey Samokhvalov','27 Engelsa street, apartment 37','Tambov','Tambovskaya oblast','RUSSIAN FEDERATION','392002','+79202341585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 14:01:43',0,NULL,3,1,2,1,NULL,'alexeysamokhvalov'),(9310,707082450002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','xrobertojosuex','xxrunkenxx@gmail.com','roberto josue naranjo rosario','BB72 CALLE 26<br>LAS VEGAS','catano','PR','UNITED STATES','00962-6428','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-10 14:04:46',0,NULL,7,1,18,0,' ','xrobertojosuex\r客户多付了一次,并没有发货.\r为了方便,标为\"重复取消\" /\'订单取消\''),(9311,767965405016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','deckchairboy','deckchairboy@industrialbuildings.info','Paul Richmond','Holly House<br>28 Belle Vue Gardens','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 7JH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-10 14:34:06',0,NULL,3,1,2,1,NULL,'deckchairboy'),(9312,671000559001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','enor2006','enorcarvalhousa@hotmail.com','Enor Carvalho','927 BURNSIDE AVE','EAST HARTFORD','CT','UNITED STATES','06108-2710','(860) 206-1458','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 14:43:00',0,NULL,3,1,1,1,NULL,'enor2006\r庄'),(9313,712057762002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','dcandrade','diogo.groselha@gmail.com','Diogo Carvalho de Andrade','Avenida dos Andradas, 430 apto 306 Bloco C<br>Centro','Juiz de Fora','Minas Gerais','BRAZIL','36036000','32 32173974','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:27:39',0,NULL,3,1,3,1,'RA117730783CN ','dcandrade\r刘'),(9314,0,110683185149,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',3,'hermeshine','meanbear','delmarvaind@netzero.net','John R Graziani','517 Fox Den Ln','Millersville','MD','UNITED STATES','21108-1467','(410) 987-0524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 15:29:58',0,NULL,3,1,1,1,NULL,'meanbear\r庄'),(9315,671034952001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','gamepood1300','lurichst@hot.ee','Valeria Lopatina','Tuulemaa 9-13','Tallinn','Eesti','ESTONIA','10312','(372) 5667 1671','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:33:01',0,NULL,3,1,3,1,'RA117731007CN ','gamepood1300'),(9316,669788063018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','hortam97','tamas125@freemail.hu','Tamás Horváth','Petőfi Sándor utca 16. 1/105','Kecskemét','Bács-Kiskun','HUNGARY','6000','0036706135972','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-10 15:34:47',0,NULL,3,1,2,1,' ','hortam97\r刘'),(9317,671037367001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','bgr881117','bigbuda@freemail.hu','Gergely Budafai','Erzsébet utca 19 IX/55','Budapest','Pest','HUNGARY','1043','0036306574899','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,17,0,' ','bgr881117'),(9318,671037963001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','njroze12','njroze@yahoo.com','Mr Nigel Rozairo','C/O HSBC<br>24 SIR BARON JAYATILEKE MAWATHA','COLOMBO 1','','SRI LANKA','000','94727116915','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 15:41:59',0,NULL,3,0,3,1,'RA117730810CN ','njroze12\r3XL（已入库）\r刘'),(9319,671041831001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','p373r_p','p373r.p@gmail.com','Peter Polak','Obr. mieru 347/8','Dubnica nad Vahom','Slovakia','SLOVAK REPUBLIC','01841','0903018771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:52:06',0,NULL,3,1,2,1,NULL,'p373r_p\r刘'),(9320,712067326002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','bgr881117','bigbuda@freemail.hu','Gergely Budafai','Erzsébet utca 19 IX/55','Budapest','Pest','HUNGARY','1043','0036306574899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 15:55:04',0,NULL,3,1,4,1,'YW865907550CN','bgr881117\r圆形柔光棚 40cm   1\r2B柔   2\r灯架包   1\r庄'),(9321,0,120720079386,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',1.04,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:39',0,NULL,3,1,17,0,NULL,'zeroone12345'),(9322,0,120720079828,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',0.99,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:39',0,NULL,3,1,17,0,NULL,'zeroone12345'),(9323,0,110683185418,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.99,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:40',0,NULL,3,1,17,0,NULL,'zeroone12345'),(9324,0,110683184992,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',1.04,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:41',0,NULL,3,1,17,0,NULL,'zeroone12345'),(9325,0,120720080138,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',2.25,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','14729 182nd St<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4028','(718) 553-8740','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 16:07:41',0,NULL,3,1,1,1,' ','zeroone12345\r爵影快门线C1   1\r方形滤镜接口环 67mm   1\r方形滤镜 镜片卡座    1\r眼罩 40D/50D    1\r眼罩 450D/500D   1\r绿叶 UV  67mm   1'),(9326,712073504002,120555973963,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',44,'hermeshine','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-0507254189','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 16:12:43',0,NULL,3,1,3,1,'RA117730995CN ','amnon064'),(9327,671051907001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','bsa7mmrm','m.miana@virgilio.it','Massimo Miana','via Monte Cresto ,8<br>Fraz. Vaglio di Biella','Biella','BI','ITALY','13900','338-8424082','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 16:22:45',0,NULL,3,0,3,1,'RA117730908CN ','bsa7mmrm\r3XL-已入库\r申报 photo vest  $10\r刘'),(9328,712083014002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','d_autohaus','d.autohaus@mail.ru','Evgeny Volkov','Konstitutsyi str. 17-139','Krasnoyarsk','Krasnoyarsky kray','RUSSIAN FEDERATION','660049','+79135345525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 16:39:54',0,NULL,3,1,2,1,NULL,'d_autohaus\r刘'),(9329,784042736015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','turboteddy67','turboted@gmx.de','Hans-Peter tenthoff','Auf dem Rüggen 15','Bochum','','GERMANY','44892','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 16:52:40',0,NULL,3,1,2,1,NULL,'turboteddy67\r刘'),(9330,671074438001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','mpie8004','magiamagia.it@gmail.com','massimiliano pierini','via zuccari 270-a','bagnaia (viterbo ) Italy','VT','ITALY','01100','3473723548','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 17:20:11',0,NULL,3,1,2,1,NULL,'mpie8004'),(9331,671076477001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','h_art_4eb','h-art@yandex.ru','Artur Khabibullin','R.Zorge 38/1-20','Ufa','Bashkortostan','RUSSIAN FEDERATION','450059','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 17:25:50',0,NULL,3,1,3,1,'RA117730925CN ','h_art_4eb\r刘'),(9332,712102421002,120578649319,'10 NEW UV filters Green.L 52mm - 77mm ',1,'AKT032',40,'hermeshine','andresc813','andrescab2003@yahoo.com','andres cabrera','6214 greenwich dr','tampa','FL','UNITED STATES','33647-1142','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 17:28:46',0,NULL,3,0,3,1,'RA117730956CN ','andresc813\r绿叶UV  58mm   10 (注意，是58mm！)\r已入库\r刘'),(9333,712168758002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','moniqueonishi','thais_onishi@hotmail.com','Ana thais onishi','rua: jesuino de brito, 303<br>apartamento 35','são paulo','são paulo','BRAZIL','02925-140','55-011-89645098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 19:46:01',0,NULL,3,1,2,1,NULL,'moniqueonishi\r庄'),(9334,668822639001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','petruchioo10','petruchioo@gmail.com','Petar Cholakov','Hristo Maksimov 16<br>floor 1','Sofia','Sofia','BULGARIA','1111','+35928717506','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 19:47:12',0,NULL,3,1,3,1,'RA117730899CN ','petruchioo10\r刘'),(9335,671150397001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','pagluca','yamato71@libero.it','Luca Paglialonga','Via Cesare Battisti, 21','Legnano','MI','ITALY','20025','+393355787806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:13:46',0,NULL,3,1,3,1,'RA117730766CN ','pagluca\r刘\rclamp   $10'),(9336,768145933016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 20:26:10',0,NULL,3,1,17,0,NULL,'ogg78'),(9337,712189359002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','rafaelzuc','rafazuc@hotmail.com','Rafael Zuccolotto','Rua Rio Guaiba, No 02, Hélio Ferraz<br>Ponto de referencia: Drograria Norte-Sul','Serra','Espirito Santo','BRAZIL','29160540','55-27-33370577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:28:36',0,NULL,3,1,2,1,NULL,'rafaelzuc\r刘'),(9338,768147142016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ogg78','oleg.gritsinevich@gmail.com','Oleg Grytsynevych','Webersgade 1, 4 th','Copenhagen','O','DENMARK','2100','4531955419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 20:28:53',0,NULL,3,1,3,1,'RA117730942CN ','ogg78\r申报：9$\r笔   2\r刘'),(9339,671170617001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','erhan_deniz','erhancagiral@hotmail.com','Erhan Deniz Cagiral','530 sokak no:23 Kat:4 Sirinyer','Izmir','','TURKEY','35150','+902324879222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 20:50:35',0,NULL,3,1,2,1,NULL,'erhan_deniz\r庄\r'),(9340,671175044001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-10 21:01:16',0,NULL,3,1,1,1,NULL,'green_dream_sky\r美标\r刘'),(9341,784203348015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.6,'hutongstore','mollerjensen','krause@post8.tele.dk','Ib Krause-Kjaer','Alrovej 380<br>Alro','Odder','','DENMARK','DK-8300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 21:29:55',0,NULL,3,1,2,1,NULL,'mollerjensen\r刘'),(9342,668664335018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','d-hargarten','d.hargarten@web.de','Dorian Hargarten','Wickenpfädchen 25','Bergisch Gladbach','','GERMANY','51427','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-10 21:43:44',0,NULL,3,1,2,1,NULL,'d-hargarten\r刘'),(9343,671190122001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','barsgo','barsgo@hotmail.com','BÁRBARA SERRANO GÓMEZ','C/ ABEJAR 22 B','CORDOBA','Andalucía Ceuta y Melilla','SPAIN','14002','680426252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-10 21:47:39',0,NULL,3,1,2,1,NULL,'bars\r庄'),(9344,711950028002,120458029512,'Marco O Flash o-flash Ring Light For SB800 SB600 F160 ',1,'AO0026',89.99,'hermeshine','mg3putt','mg3putt@sympatico.ca','Mark J Grottoli','3709 St. Laurent Court','Mississauga','ON','CANADA','L5L 4T3','(905) 828-4009','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-10 22:54:27',0,NULL,3,1,3,1,'RA117733201CN ','mg3putt\r闪光的柔光箱   60cm   1（已入库）\rO形闪光灯160    1\r'),(9345,784245511015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',125,'hutongstore','squidonius','pf224@bath.ac.uk','Paolo Ferla','22 oldfield Road','Bath','Avon','UNITED KINGDOM','BA2 3NF','39095494706','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-10 23:30:33',0,NULL,3,1,4,1,'YW865907546CN ','squidonius\r英标\r王'),(9346,784248703015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','cristovaoabreu','cristo2007@sapo.pt','Cristóvão Abreu','Rua da Azenha, nº1<br>Rio de Moinhos','Esposende, Marinhas','Portugal','PORTUGAL','4740-577','969014297','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-10 23:41:20',0,NULL,3,1,3,1,'RA117730868CN ','cristovaoabreu\r刘'),(9347,671234656001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','kokimk','snkoki83@yahoo.com','Nikola Spasenoski','bul J.N.A. 23/27<br>vlez4 stan10','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 00:55:20',0,NULL,3,1,3,1,'RA117730939CN ','kokimk\r刘'),(9348,784292356015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',6.8,'hutongstore','luissantos2006','luisig@sapo.pt','Luis Santos','Rua Vale do Lobo','Ourém','Santarém','PORTUGAL','2490-307','00351916036909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 02:14:43',0,NULL,3,1,2,1,NULL,'luissantos2006\r刘'),(9349,671251772001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',37.59,'hermeshine','brooklynking469','jacob@appleguyofdallas.com','Brook King','13423 Juneau Dr','Frisco','TX','UNITED STATES','75034','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 02:42:20',0,NULL,3,0,3,1,'RA117730837CN ','brooklynking469\r2.1x1.6m 背景布   4（绿+黄+蓝+粉）\r77mm Nikon镜头盖  1（已入库）\r\r'),(9350,712306422002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',5,'AC2304',31.2,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 03:43:14',0,NULL,3,1,3,1,'RA117730845CN ','gorrionsudaca\r刘'),(9351,712309641002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','dirtisgood','robertspendlove@gmail.com','Robert Spendlove','2164 S 1730 W','Syracuse','UT','UNITED STATES','84075-8558','(801) 543-9244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-11 04:02:54',0,NULL,3,1,3,1,'RA117730854CN ','dirtisgood\r'),(9352,784197971015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','szilard-ns','nsnagyszilard@gmail.com','Szilard Nagy','21 Decembrie, nr.148, ap.76','Cluj-Napoca','Cluj','ROMANIA','400604','+4 0740 414 449','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-11 05:28:00',0,NULL,3,0,5,1,'CP227020619CN ','szilard-ns'),(9353,671286271001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','admirolas','parkingas@gmail.com','Alenas Fainsteinas','K.Donelaicio 42-5','Kaunas','LT','LITHUANIA','44241','+37061066799','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 05:28:07',0,NULL,3,1,2,1,NULL,'admirolas'),(9354,712328451002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',2,'AKT030',111.98,'hermeshine','cntrygrl749','jrdeacon1976@roadrunner.com','Jaime Deacon','7439 W Wright st','Rathdrum','ID','UNITED STATES','83858-8452','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 05:51:31',0,NULL,3,1,4,1,'YW865907538CN ','cntrygrl749\rlight stand  $30\r已签收'),(9355,712330408002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','juster737','petrovecvlad@gmail.com','Petrov Vladimir','Tekstilshchikov prospekt<br>dom 5b kv.49','Ivanovo','','RUSSIAN FEDERATION','153040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:03:47',0,NULL,3,0,2,1,NULL,'juster737'),(9356,712336829002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','poziruem','kofoto@mail.ru','Konstantin Semenets','Saratovski pereulok 14','Krasnodar','Krasnodarski kraĭ','RUSSIAN FEDERATION','350020','(918)311-1009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 06:40:27',0,NULL,3,1,17,0,NULL,'poziruem'),(9357,784352794015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','z6lsd','ebay@rsskov.dk','Lars Skov','Hedeparken 1, 5. D<br>Døgnposten 635 / 42404020','Ballerup','','DENMARK','2750','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 06:43:05',0,NULL,3,1,2,1,NULL,'z6lsd'),(9358,712341039002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:06',0,NULL,3,1,17,0,NULL,'norgesmann'),(9359,712341019002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:06',0,NULL,3,1,17,0,NULL,'norgesmann'),(9360,671302117001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:01:07',0,NULL,3,1,17,0,NULL,'norgesmann'),(9361,712341028002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 07:01:07',0,NULL,3,1,4,1,'YW865907620CN ','norgesmann\r2B柔   1\r2m灯架+ 单灯头 欧标  +反光伞  1\r反光板支架  1\r防雨罩   1\rlight stand  $25\r'),(9362,768330944016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','yogi_gypsy','mrfoto2010@hotmail.com','Izam M R','Blk 709 Yishun Ave 5 # 04-64','default','','SINGAPORE','760709','91171044','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 07:23:02',0,NULL,3,1,11,1,NULL,'yogi_gypsy'),(9363,670765155001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','eoin.galtee','eoin@galteewood.net','Eoin Ryan','Cork Rd','Ballylanders','Limerick','IRELAND','','0879212509','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 07:49:30',0,NULL,3,1,4,1,'YW865907616CN ','eoin.galtee\r英标\rlighting kit   $40\r庄'),(9364,784381601015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','tinsunlee','tinsunglee@yahoo.com','Kevin Wright','7 Upavon Garth, Bransholme,','Hull','East Riding of Yorkshire','UNITED KINGDOM','Hu7 4rj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 08:36:08',0,NULL,3,1,2,1,NULL,'tinsunlee'),(9365,768351293016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','norad100','mj12templar@gmail.com','Oliver Galea','Blk 1, Flat 7, Appt. 21-09-1964,<br>Triq tal-Fieres,','Kirkop','','MALTA','KKP 1541','(356) 99062891','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 08:55:12',0,NULL,3,1,2,1,NULL,'norad100'),(9366,671324991001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','xxx-kuklus','kuklused@gmail.com','Yuriy Pechenkin','Arktika 6/1-40','Bilibino','','RUSSIAN FEDERATION','689450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:01:18',0,NULL,3,1,17,0,NULL,'xxx-kuklus'),(9367,712363542002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','xxx-kuklus','kuklused@gmail.com','Yuriy Pechenkin','Arktika 6/1-40','Bilibino','','RUSSIAN FEDERATION','689450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:01:18',0,NULL,3,1,3,1,'RA117730465CN ','xxx-kuklus\r40cm 棚   1\rlenspen  2'),(9368,671329751001,110316941375,'Remote Shutter Release for Canon PowerShot G10 =RS-60E3',1,'AA3210',4.3,'hermeshine','montresor_123','alain.crozemarie@orange.fr','alain crozemarie','23 rue braniky','montresor','Centre','FRANCE','37460','0679700268','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 09:20:31',0,NULL,3,1,2,1,NULL,'montresor_123'),(9369,671335843001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','noralyb','noraly_blaazer@hotmail.com','Noraly Blaazer','Cedrusstraat 3','Boskoop','','NETHERLANDS','2771 ZK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 09:54:22',0,NULL,3,1,2,1,NULL,'noralyb\r庄'),(9370,671350141001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:46:48',0,NULL,3,1,2,1,NULL,'ibico1974\r庄'),(9371,671352901001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','elmotjuuh','alyssa.westhoek@live.nl','Alyssa Westhoek','Doelensteeg 2','LEIDEN','','NETHERLANDS','2311VL','0625088176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 10:58:43',0,NULL,3,1,2,1,NULL,'elmotjuuh\r庄'),(9372,712402649002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','norrland_quattro','audi_cab@hotmail.com','mattias nyström','björkvägen 31','79340 insjön','','SWEDEN','79340','+46706508751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:41:16',0,NULL,3,1,2,1,NULL,'norrland_quattro\r庄'),(9373,712404417002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','keiyin77','angelkproducciones@gmail.com','Angel Cabrera Sánchez','AVDA. PUERTA DEL SUR 29, EL ESTRIBO<br>BLOQUE 2 BAJO D','JEREZ','Andalucía Ceuta y Melilla','SPAIN','11408','615916068','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 11:47:57',0,NULL,3,1,2,1,NULL,'keiyin77\r庄'),(9374,671007135001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',2,'AA1214',15.96,'hermeshine','2010rocker2010','meine-fotos24@web.de','Magnus Kühn','Poststr. 8c','Bochum','','GERMANY','44809','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 12:10:25',0,NULL,3,1,2,1,NULL,'2010rocker2010\r庄'),(9375,671379556001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','farhun','fatih.arhun@nyc.rr.com','Fatih Arhun','4141 46th St<br>Apt 6B','Sunnyside','NY','UNITED STATES','11104-1815','(718) 482-8834','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 12:38:59',0,NULL,3,1,1,1,NULL,'farhun\rXL   王'),(9376,671380194001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','gyllitz465','edgar.hellwig@online.de','Edgar Hellwig','Taubenstr. 23b','Dinslaken','','GERMANY','D-46539','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 12:42:37',0,NULL,3,1,3,1,'RA117731506CN ','gyllitz465\r刘'),(9377,671381678001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',12,'AE3103',117.6,'hermeshine','chrisxx178','csengel.krisztian@chello.hu','Krisztián Csengel','Kisfaludy u. 32.','Budapest','','HUNGARY','1047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 12:47:05',0,NULL,3,1,3,1,'RA117732679CN\rRA117731639CN\rRA117731642CN','chrisxx178\r客户要求：申报gift，9$,\r分成3票发，每票4个\r'),(9378,712433985002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','tadi226','pusnik.tadej@gmail.com','Tadej Pušnik','cvetkova 23','murska sobota','','SLOVENIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 13:31:41',0,NULL,3,1,3,1,'RA117731554CN ','tadi226'),(9379,784493368015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',1.85,'hutongstore','2ndfusilier','ttj375@hotmail.com','Terence Jones','49 Langwood Court<br>Castle Bromwich','Birmingham','West Midlands','UNITED KINGDOM','B36 9DN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 14:15:19',0,NULL,3,1,2,1,NULL,'2ndfusilier\r庄'),(9380,710588280002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jormo_corporation','jormocorporation@gmail.com','Manuel Peláez Pezzi','Armuñesa, 36','Monterrubio de Armuña','Castilla y León','SPAIN','37798','923288699','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 13:51:49',0,NULL,3,1,4,1,'YW865907605CN ','jormo_corporation\r庄\rtripod $15'),(9381,671410269001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','sachaagr31','grandstudio78290@yahoo.fr','Alexandre GRANDREMY','Lieu dit Cantonnier','Montesquieu Volvestre','Midi-Pyrénées','FRANCE','31310','0561976291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:29:27',0,NULL,3,1,2,1,' ','sachaagr31\r庄'),(9382,671414015001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','0792*ayres','henry@ayres9.wanadoo.co.uk','henry ayres','48 tylacoch<br>llanharry','pontyclun','Rhondda Cynon Taff','UNITED KINGDOM','cf72 9lt','01443449724','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-05-11 14:39:13',0,NULL,3,1,17,0,NULL,'0792*ayres'),(9383,671416324001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','0792*ayres','henry@ayres9.wanadoo.co.uk','henry ayres','48 tylacoch<br>llanharry','pontyclun','Rhondda Cynon Taff','UNITED KINGDOM','cf72 9lt','01443449724','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:45:33',0,NULL,3,1,3,1,'RA117731599CN\r ','0792*ayres\r天涯方形滤镜系列  CPL   1\r天涯方形滤镜系列  星光镜  star8    1\r庄'),(9384,712459667002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','bailey72379','jasonhewitt1979@hotmail.com','jason hewitt','8815 old number six hwy','santee','SC','UNITED STATES','29142','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 14:55:35',0,NULL,3,1,1,1,' ','bailey72379\r庄'),(9385,712459203002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','mma_79','phantomax@mail.ru','Maxim Alexandrovich Misovets','mikrorayon Gorsky 3-66','Novosibirsk','','RUSSIAN FEDERATION','630073','+7-913-949-07-49','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 14:56:14',0,NULL,3,1,2,1,NULL,'mma_79\r庄'),(9386,671422552001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','noisnaaria','superphillipe10@gmail.com','Phillipe Santos','Av. São João Batista, 638 - ed. sabará 101','Aracaju','Sergipe','BRAZIL','49097000','557932594957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:05:19',0,NULL,3,1,2,1,NULL,'noisnaaria\r庄'),(9387,666387692001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',3,'AA3310',47.16,'hermeshine','andrush85','progr_and@mail.ru','Sidorchenko Alexandr','40 let Pobedy 14 / 8','Nigniy Novgorod','','RUSSIAN FEDERATION','603137','+7(908)-75-743-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 15:11:38',0,NULL,3,1,3,1,'RA117731497CN ','andrush85\r(已入库)\r绿叶 52mm CPL   5\r绿叶 58mm UV     2\r绿叶 58mm CPL   3'),(9388,768481729016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','liamcoe8gac','liam.coe@gmail.com','Liam Coe','8 Gort an Chlochair<br>YJT-73-6VN','Portlaw','Waterford','IRELAND','','0861719902','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 15:19:15',0,NULL,3,1,2,1,NULL,'liamcoe8gac\r庄'),(9389,668726564001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','tinatinamisdameana','tinerbeanerz@gmail.com','Tina Unger','214 little valley trail','Cheyenne','WY','UNITED STATES','82007-3637','(307) 286-8528','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-11 16:07:04',0,NULL,7,1,18,0,' ','tinatinamisdameana\r庄'),(9390,669630798001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-11 16:46:51',0,NULL,3,1,17,0,NULL,'jagebbo'),(9391,669623712001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',13.99,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-05-11 16:50:41',0,NULL,3,1,3,1,'RA117731483CN ','jagebbo\r肩架    1\r柔光伞   1'),(9392,784562791015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','lionhart9990','comeupandseem6@hotmail.com','Brian  Lyons','Flat 19<br>47 Cherrywood Close','London','London','UNITED KINGDOM','E3 2DQ','02089833965','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 16:53:22',0,NULL,3,1,17,0,NULL,'lionhart9990'),(9393,784563620015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24.99,'hutongstore','lionhart9990','comeupandseem6@hotmail.com','Brian  Lyons','Flat 19<br>47 Cherrywood Close','London','London','UNITED KINGDOM','E3 2DQ','02089833965','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 16:55:15',0,NULL,3,1,3,1,'RA117731523CN ','lionhart9990\r\r1.266'),(9394,712496015002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jameball','chitpong_ball@hotmail.com','Siripach Mahagitsiri','411/173 Pracha Utit Road','Huaykwang','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-05-11 17:03:23',0,NULL,3,1,11,1,NULL,'jameball\r庄'),(9395,671483786001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','lrmiranda','leomiranda@gmail.com','Leonardo Miranda','Rua Michel Salomani, 288<br>Mosela','Petrópolis','RJ','BRAZIL','25675-321','+55 21 81180502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 17:50:00',0,NULL,3,1,2,1,NULL,'lrmiranda\r庄'),(9396,671493305001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','zigras','zigras52@msn.com','chris zigras','GRAVIAS 18','KARDITSA','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 18:10:19',0,NULL,3,1,17,0,NULL,'zigras'),(9397,712555181002,120555973963,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',44,'hermeshine','glowingstar71','tommycuellar@gmail.com','Thomas Cuellar','261 10th St<br>Ste 302','Oakland','CA','UNITED STATES','94607-4465','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 18:52:35',0,NULL,3,1,3,1,'RA117731470CN ','glowingstar71\r刘'),(9398,768609601016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mr_c_s','mrcleanshave@gmail.com','Mr G Pritchard','10 Laurel Mews<br>Garden Hedge','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','LU7 1FR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 19:25:36',0,NULL,3,1,2,1,NULL,'mr_c_s\r庄'),(9399,671552869001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','journeyman_gr','pcloukas@yahoo.gr','Loukas Kalantzis','Averof 20','Egaleo','Athenes','GREECE','12244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 20:14:20',0,NULL,3,1,2,1,NULL,'journeyman_gr\r庄'),(9400,768641088016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','zigras','zigras52@msn.com','chris zigras','GRAVIAS 18','KARDITSA','','GREECE','43100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 20:16:05',0,NULL,3,1,2,1,NULL,'zigras\rEW-73B    1\rlenspen    1\r庄'),(9401,784685327015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','moyleattic2011','my_orders4avon@yahoo.com','Vanessa Long','29 Moyle Park<br>Hilperton','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 7UE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-11 20:17:00',0,NULL,3,1,3,1,'RA117731510CN ','moyleattic2011\r2.1x1.6m  2(黑+白)\r庄'),(9402,768672957016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','surek.peter','surek.peter@gmail.com','Peter Šúrek','Gercenova 6/B<br>Petržalka','Bratislava','Bratislava','SLOVAK REPUBLIC','85101','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-11 21:20:54',0,NULL,3,1,5,1,'CP227020605CN','surek.peter'),(9403,712638893002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','luchouf','luchouf@hotmail.com','luis uechi','22527 Crenshaw Blvd<br>Ste 200','Torrance','CA','UNITED STATES','90505-3069','','NoPaymentFailure','CheckoutComplete','Other','2011-05-11 22:03:08',0,NULL,3,0,1,1,NULL,'luchouf\r3XL（已入库）\r753'),(9404,768695155016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','7jax','jacqwilkinson2002@yahoo.co.uk','Jacqueline Wilkinson','21, Stoney Croft<br>Hoyland','Barnsley','South Yorkshire','UNITED KINGDOM','S74 0LZ','01226748838','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-11 22:15:43',0,NULL,3,1,4,1,'YW865907594CN ','7jax\rlight stand  $20'),(9405,670393852018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','krzykjn2005','krzykjn@sbcglobal.net','Monique Pedersen','112 Rock Creek Rd','Morrilton','AR','UNITED STATES','72110','(501) 208-7212','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-11 22:21:07',0,NULL,3,1,3,1,'RA117731466CN ','krzykjn2005\r刘 '),(9406,712657302002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','xdonald85','fylki@hotmail.com','Ole Erik Fylkesnes','Tormodsveg 4A','Haugesund','Haugesund','NORWAY','5518','+4793410061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 23:31:49',0,NULL,3,1,2,1,NULL,'xdonald85\r庄'),(9407,671616215001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','thesolarcenter','ramimataev@gmail.com','Rami Mataev','Rambam ST<br>Number 10','Or Akiva','HaSharon','ISRAEL','30600','(972) 0544225995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-11 23:36:19',0,NULL,3,1,3,1,'RA117731608CN\r ','thesolarcenter\r庄'),(9408,721564480017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2202',30,'photographyacc','shanks-185','baileyshanks@hotmail.com','bailey shanks','6 nemesis place<br>golden grove','kalgoorlie','Western Australia','AUSTRALIA','6430','0890919157','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-11 23:40:38',0,NULL,7,1,18,0,NULL,'shanks-185\r刘\recheck的，已经发过了'),(9409,670413016018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','minhtuan1986','mr_handsome1986@yahoo.com','Tuan Phuong','4/14<br>Wattle Valley Rd','Canterbury','Victoria','AUSTRALIA','3126','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-11 23:41:23',0,NULL,3,1,3,1,'RA117731792CN ','minhtuan1986\r庄'),(9410,671623530001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 00:10:59',0,NULL,3,1,2,1,NULL,'arnorolf10\r刘'),(9411,670426895018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','wendy140975','wendy141625@hotmail.com','wendy stevenson','4 merion crt','banora point','New South Wales','AUSTRALIA','2486','0755246783','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-12 00:46:36',0,NULL,3,1,2,1,NULL,'wendy140975\r庄'),(9412,712678924002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tonytone1969','tonylewis2001@hotmail.com','Anthony Lewis','13313 - 122 Ave','Edmonton','AB','CANADA','T5L 2V4','(780) 709-9560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:14:56',0,NULL,3,1,2,1,NULL,'tonytone1969\r庄'),(9413,671640656001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',92,'hermeshine','photazimaginationproduction','photazimagination@gmail.com','khalid said','no:14 spg 1496 kg telisai','bsb','','BRUNEI DARUSSALAM','tc 1145','8161113','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 01:31:37',0,NULL,3,1,3,1,'RA117731775CN\rRA117731789CN ','photazimaginationproduction\r分2个小包发\r英标'),(9414,671645575001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','iodelbuono','maximilianoastetemillan@yahoo.com.ar','Maximiliano Astete Millán','Moreno 1337','Tandil','Buenos Aires','ARGENTINA','7000','+54 02293 15351386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 01:51:19',0,NULL,3,1,2,1,NULL,'iodelbuono\r庄'),(9415,712719039002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bagum.h','bagum_h@rambler.ru','Ильин Алексей','ул.Куйбышева, д.27/1, кв.99','Омск','','RUSSIAN FEDERATION','644070','+7(962) 044-1680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 03:56:20',0,NULL,3,1,2,1,NULL,'bagum.h'),(9416,712731554002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 05:08:27',0,NULL,3,1,3,1,'RA117731625CN ','green_dream_sky'),(9417,712737733002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','yuxia1986','yuxia@usc.edu','yu xia','365 A <br>S Atlantic','Monterey Park','CA','UNITED STATES','91754','(626) 382-9302','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 05:50:46',0,NULL,3,1,1,1,NULL,'yuxia1986'),(9418,712749422002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','osu1472','cl_komodo@hotmail.com','Khalil El Hamdani','C. Doctor Ferrán nº 70 , 3º/ 1ª','Terrassa','Barcelona','SPAIN','08226','628747090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 06:55:54',0,NULL,3,1,3,1,'RA117731801CN ','osu1472'),(9419,712749952002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','jan_oto','evgeny.oto@gmail.com','Evgeny Otovchyts','Ruven and Bat Sheva 1/25','Rishon Lezion','','ISRAEL','75357','972544449382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 06:58:56',0,NULL,3,1,2,1,' ','jan_oto'),(9420,784870418015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','iban1974iban','iban_g_g@yahoo.es','Iban Gonzalez','C/ Alfons Sala, 33-39, 4º-2ª','Sabadell','Cataluña','SPAIN','08202','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 07:00:04',0,NULL,3,1,2,1,NULL,'iban1974iban'),(9421,712753170002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',3,'AA1305',7.4,'hermeshine','ron512','ronald.nuzzolese@att.net','Ronald Nuzzolese','1495 Ashcroft Ave','Clovis','CA','UNITED STATES','93611','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 07:16:46',0,NULL,3,1,1,1,NULL,'ron512'),(9422,671714959001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','brandcj2','brandcj2@telkomsa.net','Cornelis Brand','P.O Box 3241','Pretoria','Gauteng','SOUTH AFRICA','0001','+27823713736','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 08:14:05',0,NULL,3,1,3,1,'RA117731979CN ','brandcj2'),(9423,671351956001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','athula_wijerathna','athulawijerathna@gmail.com','Athula Wijerathna','Homagama, Kelanigama,','Ginigathhena','Central Province','SRI LANKA','20688','094776552944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 09:17:54',0,NULL,3,1,2,1,NULL,'athula_wijerathna\r庄'),(9424,712403998002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','aka_paulo','aka_paulo1@bk.ru','Pavel Polyakov','Bogorodizerogdestvenskaya str. 17','Tver','Tverskaya oblast\'','RUSSIAN FEDERATION','170007','0079109390129','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 10:06:52',0,NULL,3,1,2,1,' ','aka_paulo\r庄'),(9425,712795359002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','iban1974iban','iban_g_g@yahoo.es','Iban Gonzalez','C/ Alfons Sala, 33-39, 4º-2ª','Sabadell','Cataluña','SPAIN','08202','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:37:11',0,NULL,3,1,2,1,NULL,'iban1974iban\r庄'),(9426,671749420001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','antonkharchenko','a-har4enko@ya.ru','Anton Kharchenko','50 let SSSR, dom 17, kvartira 26','Sochi','Krasnodarsky krai','RUSSIAN FEDERATION','354037','+79654697268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 10:53:33',0,NULL,3,1,2,1,NULL,'antonkharchenko\r庄'),(9427,671754648001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','eliavb88','yehiel_h@netvision.net.il','eliav bitton','Rachel  Emeno 66/15','Beer-Sheba','','ISRAEL','84513','972508212990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:13:18',0,NULL,3,1,2,1,' ','eliavb88\r庄'),(9428,784940104015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','amilmand','nagyszulejman@hotmail.com','Ádám Szabó','Budapest Ferenc krt 27 fsz 3.','Budapest','','HUNGARY','1094','+36303348522','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 11:15:45',0,NULL,3,1,2,1,NULL,'amilmand'),(9429,712804803002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','daovutruongson','vtsdao@civileng.kindai.ac.jp','Vu Truong Son Dao','Hishiya Nishi 1-15-26<br>Shine Hishiya Nishi # 506','Higashi-Osaka','Osaka','JAPAN','5770807','+819099947642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:17:10',0,NULL,3,1,2,1,NULL,'daovutruongson'),(9430,712808995002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','scufitulrosu','dcioba@yahoo.com','Dany Cioba','fundeni 237<br>bl.112, sc B, et 10, ap 87','BUCURESTI','sector 2','ROMANIA','022322','0723550492','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:32:38',0,NULL,3,1,3,1,'RA117731863CN ','scufitulrosu\r刘'),(9431,712809026002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','rescognita','rescognita@rescognita.com','JOSE ROMAN MONTESINOS LOPEZ','Rafael Alberti 1 5C<br>Fonteculler','Culleredo','A Coruna','SPAIN','15174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:32:48',0,NULL,3,1,3,1,'RA117731877CN ','rescognita\r欧标'),(9432,712815207002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','7760corinne','corinnemansill@wol.co.za','CORINNE MANSILL','PO BOX 55279<br>EERSTEMYN','WELKOM','FREE STATE','SOUTH AFRICA','9466','+27573525907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 11:59:06',0,NULL,3,0,3,1,'RA117731996CN ','7760corinne\r1.955'),(9433,784957701015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','20magnum07','m.purslow@ntlworld.com','Marc Purslow','Llamedos<br>3 Gaskell Avenue','Warrington','Cheshire','UNITED KINGDOM','WA4 1PB','01925480781','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 12:06:18',0,NULL,3,1,2,1,NULL,'20magnum07\r庄'),(9434,712830928002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kin-kan','abibaud@videotron.ca','alain bibaud','4465 des messanges','st-catherine','QC','CANADA','j5c 1p9','(450) 638-5139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 12:53:25',0,NULL,3,1,2,1,NULL,'kin-kan\r庄'),(9435,784979637015,250600508696,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','2010kingj','kingj97@hotmail.co.uk','James King','Hurst bank<br>Charing heath road','Ashford','Kent','UNITED KINGDOM','Tn270au','01233712999','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 13:06:58',0,NULL,3,1,2,1,NULL,'2010kingj\r庄'),(9436,670588800018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',3,'AO0033',24,'photographyacc','digitalmaster.rs','gustavodigital@terra.com.br','Gustavo Silveira Garcia','Rua Vitor Hugo, n. 37, sala 504','Porto Alegre','Rio Grande do Sul','BRAZIL','90630070','(51)33982593','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-12 13:07:14',0,NULL,3,1,3,1,'RA117731829CN ','digitalmaster.rs\r364'),(9437,671788244001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','stev05163','shockey@iinet.net.au','Stephen Hockey','Health Sciences Clinic Bldg<br>Via Car Park 9','La Trobe University','Victoria','AUSTRALIA','3086','0394795747','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 13:30:33',0,NULL,3,1,4,1,'YW865907664CN ','stev05163\r2m 弹簧灯架   2\r灯架  2m    1\r斜臂   1\r庄'),(9438,671787722001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',74.9,'hermeshine','stev05163','shockey@iinet.net.au','Stephen Hockey','Health Sciences Clinic Bldg<br>Via Car Park 9','La Trobe University','Victoria','AUSTRALIA','3086','0394795747','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 13:30:33',0,NULL,3,1,17,0,NULL,'stev05163'),(9439,671796968001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','flyparente','fparente@predileto.ind.br','FLEURY SILVA','RUA JANSEN, 50-VILA MARIANA<br>SÃO PAULO','SP','SÃO PAULO/SP','BRAZIL','04115070','55.11.8941.3510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 13:48:18',0,NULL,3,1,17,0,NULL,'flyparente'),(9440,671798198001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',4,'AC2302',24.84,'hermeshine','flyparente','fparente@predileto.ind.br','FLEURY SILVA','RUA JANSEN, 50-VILA MARIANA<br>SÃO PAULO','SP','SÃO PAULO/SP','BRAZIL','04115070','55.11.8941.3510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 13:52:05',0,NULL,3,1,3,1,'RA117731832CN ','flyparente\r小号内胆包 Nikon    5'),(9441,768946887016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','4wdcelica','hegedus14@gmail.com','Hegedűs Zoltán','COCA-COLA HBC<br>Szív utca 17.','Zalaszentgrót','','HUNGARY','8790','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 14:08:11',0,NULL,3,0,2,1,' ','4wdcelica\r庄'),(9442,671802735001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moebius1984','moebius@etxea.net','jon latorre martinez','bagatza 13, 6º A','barakaldo','Vizcaya','SPAIN','48902','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 14:09:09',0,NULL,3,1,3,1,'RA117731846CN ','moebius1984'),(9443,671307133001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','asaymirus','asad@thundi.com','Ibrahim Asad','Hirimaagoalhi<br>Hirimaage','Fuvahmulah','Southern Procince','MALDIVES','10350','9607781088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 14:31:48',0,NULL,3,1,2,1,NULL,'asaymirus\r庄'),(9444,710757244002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','marranca2007','josemar@libero.it','jose marranca','via san maurizio 49<br>alpignano','torino','TO','ITALY','10091','0119672478','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 14:54:40',0,NULL,3,1,3,1,'RA117727170CN\r ','marranca2007\rM'),(9445,785027591015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','angryrock123','mark_w_fisher@boltblue.com','mark fisher','37 greenlaw cresant','glenrothes','fife','UNITED KINGDOM','ky6 1jq','07709454471','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 15:12:18',0,NULL,3,1,3,1,'RA117731850CN ','angryrock123'),(9446,670130264001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',21.58,'hermeshine','nikitos333','nikita_nisenbaum@hotmail.com','Nikita Nisenbaum','Vorovskogo street 21-20','Murmansk','ru','RUSSIAN FEDERATION','183025','07 921 1523954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 15:46:01',0,NULL,3,1,2,1,NULL,'nikitos333\r防雨罩   1\r58mm Canon 镜头盖   1\r普通热靴保护盖    1\r庄\r'),(9447,0,120722456780,'New Lens Cleaning Cloth for Pentax DSLR',1,'AA1312',0.01,'hermeshine','kohelet_son_of_david','kullyev@yandex.ru','Andrey Kullyev','2930 N Pine Grove Ave<br>Apt 403','Chicago','IL','UNITED STATES','60657-5742','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:04:29',0,NULL,3,1,1,1,NULL,'kohelet_son_of_david\r庄'),(9448,671843000001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ktelectronicrepair','ktelectronicsales@gmail.com','Adam @ KT Electronicrepair','1640 alum rock ave','San jose','CA','UNITED STATES','95116-2429','(408) 641-9548','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:12:55',0,NULL,3,1,1,1,NULL,'ktelectronicrepair\r尽量控制在300g以内\r庄\r270'),(9449,0,120722456596,'New Lens Cleaning Cloth for Canon 40D 60D 7D 5D',1,'AA1312',0.22,'hermeshine','chevyman185','vlandino@gmail.com','Vincenzo M. Landino','48 Line Rd','Northford','CT','UNITED STATES','06472-1076','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:56:44',0,NULL,3,1,1,1,NULL,'chevyman185\r庄'),(9450,0,120722456563,'New Lens Cleaning Cloth for Nikon D80 D90 D300',1,'AA1312',0.06,'hermeshine','diamondsbyday','angiedayy@yahoo.com','Angela Yaun','10590 High Hollows Dr<br>Apt 287','Dallas','TX','UNITED STATES','75230-4717','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 16:57:15',0,NULL,3,1,1,1,NULL,'diamondsbyday\r庄'),(9451,785081019015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ratboyab','ratboyab@hotmail.com','Adam Brown','4 Salisbury Road','Gravesend','Kent','UNITED KINGDOM','DA117DE','07817672368','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 17:30:16',0,NULL,3,1,2,1,NULL,'ratboyab\r庄'),(9452,712937376002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','charly_853603','carlos-leguizamon@argentina.com','carlos leguizamon','Av Jose Maria Moreno 797 12 A','Capital Federal','buenos aires','ARGENTINA','1424','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 18:07:59',0,NULL,3,1,2,1,NULL,'charly_853603\r庄'),(9453,712939343002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','rlm5815','bmurphy72@tampabay.rr.com','Bob Murphy','5815 Kumquat Ct','Tampa','FL','UNITED STATES','33625-1951','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 18:10:06',0,NULL,3,1,1,1,NULL,'rlm5815\r庄'),(9454,712946996002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kalderaro','liorkk@gmail.com','Lior Kalderaro','Nurok Rabi 3/36','Ashkelon','Ashkelon','ISRAEL','888888','972-52-6095317','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-12 18:27:53',0,NULL,3,1,3,1,'RA117715579CN ','kalderaro'),(9455,785139544015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','sadgom1950','sfj100@btinternet.com','Stephen Jones','Old School, Snods Edge<br>Shotley Bridge','Consett','Durham','UNITED KINGDOM','DH8 9LE','01207255437','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 18:52:25',0,NULL,3,1,2,1,NULL,'sadgom1950\r庄'),(9456,712963173002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','stephanieeisentrout7','stephanieeisentrout@gmail.com','Steph Eisentrout','1211 N Shenandoah Ave','Front Royal','VA','UNITED STATES','22630-3531','(202) 316-0858','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-12 19:04:06',0,NULL,3,1,1,1,NULL,'stephanieeisentrout7\r庄'),(9457,671916856001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','itiarado','itiracook@yahoo.co.uk','Intira Cook','287/35 CHARAN SANITWONG 31<br>Bangkok Noi','Bangkok','','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:06:55',0,NULL,3,1,11,1,NULL,'itiarado\r庄'),(9458,712969960002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','gmclub','glm.email@email.it','Gianluca Montalbano','via Rorine 63','Alba','CN','ITALY','12051','0173975006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 19:16:58',0,NULL,3,1,3,1,'RA117732002CN ','gmclub'),(9459,785161176015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','louiseppurple','louise_p_home@hotmail.com','Louise Piotrowski','14 South View<br>Off Widmore Road','Bromley','Kent','UNITED KINGDOM','BR1 3DP','07983005870','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 19:26:33',0,NULL,3,1,2,1,NULL,'louiseppurple\r庄'),(9460,769110623016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jmseccon','joegermoroney@eircom.net','Joseph Moroney','70. Heathervue<br>Riverstown, Glanmire','Cork','Cork','IRELAND','default','0857709401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 19:52:34',0,NULL,3,1,3,1,'RA117731951CN ','jmseccon\r1.6x3m 背景布  2（黑+白）'),(9461,769114877016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','jmseccon','joegermoroney@eircom.net','Joseph Moroney','70. Heathervue<br>Riverstown, Glanmire','Cork','Cork','IRELAND','default','0857709401','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-12 19:55:19',0,NULL,3,1,17,0,NULL,'jmseccon'),(9462,671951946001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','dean.peace','dejansp@gmail.com','Dejan Mir','Šempas 127','Šempas','Šempas','SLOVENIA','5261','0038641365725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:21:48',0,NULL,3,1,2,1,NULL,'dean.peace\r庄'),(9463,713015578002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','aleksey1617','belonogov74@mail.ru','Aleksey Belonogov','Kaslinskaya 19b-116','Chelyabinsk','','RUSSIAN FEDERATION','454084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:52:49',0,NULL,3,1,2,1,NULL,'aleksey1617\r庄'),(9464,0,120722456729,'New Lens Cleaning Cloth for Sony',1,'AA1312',0.01,'hermeshine','fpsboston10','fpsboston@gmail.com','Steve Thomas','216 Rumney Rd','Revere','MA','UNITED STATES','02151-5624','(781) 629-2337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 20:54:49',0,NULL,3,1,17,0,NULL,'fpsboston10'),(9465,0,120722456891,'New Lens Cleaning Cloth for  Nikon DSLR',1,'AA1312',0.01,'hermeshine','fpsboston10','fpsboston@gmail.com','Steve Thomas','216 Rumney Rd','Revere','MA','UNITED STATES','02151-5624','(781) 629-2337','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 20:54:54',0,NULL,3,1,1,1,NULL,'fpsboston10\r麂皮   2\r庄'),(9466,713017204002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','m0rtag0n','arte@zopov.com','Yuri Zopov','Alcalde Porqueres 56, Piso 7','LLEIDA','Cataluña','SPAIN','25005','973831657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 20:56:37',0,NULL,3,1,2,1,NULL,'m0rtag0n\r庄'),(9467,785217398015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','goodtrader1000','trudy.barry@sky.com','trudy barry','32 windsor cresent','harrow','Middlesex','UNITED KINGDOM','ha2 8qw','02088646319','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-12 21:04:25',0,NULL,3,1,2,1,NULL,'goodtrader1000\r庄'),(9468,713035360002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','chemapucela','josemaria.alvar@gmail.com','José María Alvarez Aparicio','C/ Miño Nº 1 Esc. Dcha. 3º A','Laguna de Duero (Valladolid)','Castilla y León','SPAIN','47140','670661368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 21:46:20',0,NULL,3,1,2,1,NULL,'chemapucela\r庄'),(9469,713053047002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','theliftoftheyear','gcarsonau@gmail.com','Carson Au','1300 Boblett St<br>Unit A--3971','Blaine','WA','UNITED STATES','98230','(778) 882-0367','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 22:47:35',0,NULL,3,1,2,1,NULL,'theliftoftheyear\r新地址：\rCarson Au\rFaculty of Education, SFU,\r8888 University Drive,\rBurnaby, BC\rV5A 7E5\rCanada\r778-885-0367\r庄\r'),(9470,713052725002,120480630193,'New YONGNUO LCD Timer Remote Control  for Sony RM-S1AM',1,'AA3223',48.9,'hermeshine','7mila8','nimrodmilovich@mail.ru','Hrytsuk Anton','ul. Gamarnika 28-34','Minsk','','BELARUS','220131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-12 22:47:48',0,NULL,3,1,3,1,'RA117731885CN ','7mila8'),(9471,0,120722456639,'New Lens Cleaning Cloth',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:36',0,NULL,3,1,17,0,NULL,'chunkeih'),(9472,0,120722456682,'New Lens Cleaning Cloth for Pentax',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:36',0,NULL,3,1,17,0,NULL,'chunkeih'),(9473,0,120722456822,'New Lens Cleaning Cloth for Sony DSLR',1,'AA1312',0.01,'hermeshine','chunkeih','thewesthk@hotmail.com','Chun Kei Ho','300 N Valencia St','Alhambra','CA','UNITED STATES','91801-2750','(626) 607-4587','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-12 23:26:35',0,NULL,3,1,1,1,NULL,'chunkeih\r麂皮   3\r庄'),(9474,672017405001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',6,'AC2302',37.26,'hermeshine','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','11 83690999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:03:35',0,NULL,3,1,3,1,'RA117731903CN ','diogodrigo2009\r刘'),(9475,0,120722456854,'New Lens Cleaning Cloth for Canon DSLR',1,'AA1312',0.06,'hermeshine','luerasa','sandyluera@wavecable.com','Sandra Luera','1008 Elliot St','West Sacramento','CA','UNITED STATES','95605-2129','(916) 607-4208','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 00:13:05',0,NULL,3,1,1,1,NULL,'luerasa\r庄'),(9476,713074948002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27.8,'hermeshine','mosqintal','cimenk_3@yahoo.com','kevin rusli','mappanyuki street no. 31<br>makassar city','default','SN','INDONESIA','90141','081343637333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 00:27:00',0,NULL,3,1,3,1,'RA117731948CN ','mosqintal\r庄'),(9477,713083683002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','starsea122','alexchai80@gmail.com','Sing Hai Chai','12 Barrett Lennard PDE','Perth','Western Australia','AUSTRALIA','6150','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 01:07:13',0,NULL,3,1,3,1,'RA117731917CN ','starsea122\r刘'),(9478,769230661016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','crankyboots','markclehane@hotmail.com','Mark Clehane','37 Silverheights Drive,<br>Silversprings','Cork','Cork','IRELAND','1','0833911359','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 01:17:23',0,NULL,3,1,2,1,NULL,'crankyboots\r庄'),(9479,672040689001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','lindsaymichellecoffman','linzee777@hotmail.com','lindsay coffman','403 N Romig St','uhrichsville','OH','UNITED STATES','44683-2065','(740) 922-1715','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 01:53:59',0,NULL,3,1,1,1,NULL,'lindsaymichellecoffman\r庄'),(9480,672031766001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','jansun1','janicesun@aol.com','Janice Farr','PO Box 949','Grandy','NC','UNITED STATES','27939','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-13 02:00:34',0,NULL,3,1,1,1,NULL,'jansun1\r庄'),(9481,670651031018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','frost_bolt','husky.01@optusnet.com.au','daniel nycyk','96 rawlinson street','murrarie ,brisbane','Queensland','AUSTRALIA','4172','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 02:41:26',0,NULL,3,1,4,1,'YW865907653CN ','frost_bolt\r河北的架子+1.6x2.1白色布+夹子\rbackgournd support @$0\r王'),(9482,712420287002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','011 48657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 02:58:02',0,NULL,3,1,3,1,'RA117731894CN ','2010bousosheila\r申报 $10'),(9483,713123767002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nikonisti','arifyantow@yahoo.com','Arifyanto Wirawan Tjioe','Jl. Bangka Raya no. 27 unit B<br>Pela Mampang','Jakarta Selatan','DKI Jakarta','INDONESIA','12720','+62816801079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 04:12:09',0,NULL,3,1,2,1,NULL,'nikonisti'),(9484,713129477002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','gorbva','gorbva@mail.ru','Vladimir Gorbanev','Kominterna str. 8-92','Khanty-Mansiysk','Khanty-Mansy Autonomos Okrug','RUSSIAN FEDERATION','628011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 04:49:29',0,NULL,3,0,3,1,'RA117727016CN ','gorbva欧标'),(9485,672073797001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','fotofilia','sngfotografia@gmail.com','María Teresa Godoy León','Alonso de Córdova 3773, Vitacura','Santiago','Región Metropolitana','CHILE','7630492','(56) 6-8499240','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 04:55:07',0,NULL,3,1,3,1,'RA117727104CN ','fotofilia'),(9486,0,120722456933,'New Lens Cleaning Cloth for UV CPL',1,'AA1312',0.07,'hermeshine','wvashug1939','wvashug@hotmail.com','Robert F Cummings','1171 Epling Hollow Rd','Ashford','WV','UNITED STATES','25009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 05:15:04',0,NULL,3,1,1,1,NULL,'wvashug1939\r麂皮    2'),(9487,672086793001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','cttuan','ngtu2009@yahoo.com','CHAU, Tuan Thanh','Marikoji kaikan, #219<br>6-2 Yoshida Izumidono-cho, Sakyo-ku','Kyoto','Kyoto','JAPAN','606-8301','+818040135999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 06:11:06',0,NULL,3,1,2,1,NULL,'cttuan'),(9488,713158863002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','via_23','pierste@free.fr','Pierre Sassaro','50 rue de la chapelle','paris','Île-de-France','FRANCE','75018','0660160955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 07:39:30',0,NULL,3,1,2,1,NULL,'via_23'),(9489,713169697002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ytrio77','fermionjr@yahoo.es','Javier Rivas Ascondo','C/Lapurdi 3 1ºH','Leioa','País Vasco','SPAIN','48940','944631555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 08:33:12',0,NULL,3,1,2,1,NULL,'ytrio77'),(9490,669310206018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','tristravels','tristangautrey@gmail.com','tristan gautrey','IML, Level 4<br>60 Carrington Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 08:52:27',0,NULL,3,1,2,1,NULL,'tristravels'),(9491,712455489002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','lenalena2007','lena2002@aon.at','Kozlova Elena','Sunshine House, POBox 274<br>Providence','Victoria','Mahe','SEYCHELLES','0000','2482525283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 09:25:49',0,NULL,3,1,3,1,'RA117727722CN\r ','lenalena2007'),(9492,783414741015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',8.02,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','c/o Mark Garland<br>Moonfleet, North End Lane','Louth','Lincs','UNITED KINGDOM','LN11 7SP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 09:33:17',0,NULL,3,0,17,0,' ','jfarenden'),(9493,785421585015,250615147105,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB900',4,'AB3311',131.96,'hutongstore','mek8957','martin.keene@pa.press.net','Martin Keene','2 Clarence Road','Richmond','Surrey','UNITED KINGDOM','TW9 3NL','07815788817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 09:42:27',0,NULL,3,1,3,1,'RA117726130CN ','mek8957'),(9494,670957674018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','doogen09','becandbrett01@dodo.com.au','Rebecca Duler','708 Latrobe Street','Ballarat','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-13 09:46:13',0,NULL,3,1,4,1,'YW865907686CN ','doogen09\r背景架河北 +1.6x2.1 白+ 夹子\rbackground support  $25\r刘'),(9495,785432630015,250606687616,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2206',3.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:45',0,NULL,3,1,17,0,NULL,'kookykiwibird'),(9496,769353909016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:46',0,NULL,3,1,17,0,NULL,'kookykiwibird'),(9497,785430947015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:47',0,NULL,3,1,17,0,NULL,'kookykiwibird'),(9498,785431860015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.72,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:47',0,NULL,3,1,17,0,NULL,'kookykiwibird'),(9499,769354273016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','kookykiwibird','niamh.parker@sky.com','Niamh Parker','C/- Level 6 - Stockley House<br>130 Wilton Road','London','London','UNITED KINGDOM','SW1V 9LQ','07885722399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:30:48',0,NULL,3,1,3,1,'RA117727991CN\r ','kookykiwibird\r红外遥控canon 白盒的那个（就一个了应该是）   1\r中号内胆包 无字   1\r绿叶58mm cpl   1\r绿叶62mm cpl   1\r58mm 镜头盖  canon   1'),(9500,769364524016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','paulhodgson','paul@pihpropertyservice.co.uk','Paul Hodgson','24a Montague Road','Sale','Cheshire','UNITED KINGDOM','M33 3BU','01619692675','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 10:37:12',0,NULL,3,1,2,1,NULL,'paulhodgson'),(9501,785445539015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','mike1001101','binarek@gmail.com','Miroslav Šenkýř - ELNET-MOBIL','Lidická 43','Havířov','Moravskoslezský','CZECH REPUBLIC','73601','605071818','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-13 11:08:17',0,NULL,3,1,5,1,'CP227020565CN ','mike1001101'),(9502,672147882001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','mamaschnackel','pearlmam@web.de','Marion Perl','Haunswieserstrasse 5','Aichach','','GERMANY','86551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 11:09:10',0,NULL,3,1,2,1,NULL,'mamaschnackel'),(9503,671747569001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',5,'AA3310',63.84,'hermeshine','nord975','rid75@ukr.net','Mykhaylo Degtyarenko','p.o.box 701','Sumy','','UKRAINE','40003','+38 066 217-54-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:19:16',0,NULL,3,1,3,1,'RA117727736CN\r ','nord975\r（已入库）\r绿叶52mm uv  10\r绿叶67mm cpl   1\r绿叶58mm cpl   5\r红外遥控for olympus    1\r\r'),(9504,769398675016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','limmess','limmes@zebra.lt','Linas Pečkauskas','Šarkuvos 32-37','Kaunas','','LITHUANIA','48167','37061441448','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 12:24:51',0,NULL,3,1,2,1,NULL,'limmess'),(9505,672166625001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','tiper3x','lesny.jozef@gmail.com','Dagmar Semanová','Sokoľany 19','Haniska','','SLOVAK REPUBLIC','04457','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 12:25:31',0,NULL,3,1,2,1,NULL,'tiper3x'),(9506,785478501015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','lumen_art','remi.vimont@gmail.com','Rémi Vimont','30, square Nungesser et Coli','Wimereux','Nord-Pas-de-Calais','FRANCE','62930','06.17.10.72.23','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-13 12:43:45',0,NULL,3,1,4,1,'YW865907756CN','lumen_art\r新地址：\rREMI VIMONT\r34 RUE DE PARIS\r59800 LILLE\rFRANCE METROPOLITAINE\r0617107223\r'),(9507,671014359018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','leo_guevarra32','leoguevarra32@yahoo.com','LEO GUEVARRA','1590 Buckeye Dr','MILPITAS','CA','UNITED STATES','95035-7418','(408) 564-1971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-13 13:17:06',0,NULL,3,1,1,1,NULL,'leo_guevarra32\r庄'),(9508,769427244016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',3,'AA1212',7.56,'hutongstore','w_a_r_r_e_n','warren.gomez@gmail.com','Clayton Gomez','26 Miami Court<br>Harbour Views','GIBRALTAR (EUROPE)','','GIBRALTAR','GB11ZZ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 13:45:04',0,NULL,3,1,2,1,NULL,'w_a_r_r_e_n\r庄'),(9509,672204331001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','billbrach','bill@soundideasstereo.com','Sound Ideas - Glas Kats Studio','3215 NW 13th St<br>Attn: Bill Brachhold','Gainesville','FL','UNITED STATES','32609-2174','(352) 378-0192 ext.: 315','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 14:28:40',0,NULL,3,1,1,1,NULL,'billbrach\r庄'),(9510,713260110002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','snoopy91671','dhonma91671@yahoo.com','David Honma','1031 Wheatland Ave','Lancaster','PA','UNITED STATES','17603-3120','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 14:29:57',0,NULL,3,1,1,1,NULL,'snoopy91671\r庄'),(9511,712191262002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hlynurkr','hlynur.kr@gmail.com','Hlynur Kristjánsson','Silfurgata 11','Isafjordur','','ICELAND','400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 14:39:17',0,NULL,3,1,2,1,NULL,'hlynurkr\r庄'),(9512,672227320001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','lockstock2006','kozich@gmail.com','A. Kozich','Vostochnaja 28/2-43','Minsk','','BELARUS','220013','+375296173247','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 15:47:29',0,NULL,3,1,2,1,NULL,'lockstock2006\r庄'),(9513,785564820015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.49,'hutongstore','gerrym9225','gmcl@eircom.net','Gerry McLoughlin','Silverspruce, Lake Road, Cobh, Co. Cork','Cork','Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 16:19:54',0,NULL,3,1,2,1,NULL,'gerrym9225\r庄'),(9514,785567311015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',6,'hutongstore','billkou','billpckalamata@gmail.com','bill koutsouropoulos','agion anargyron petalo 21','kalamata','messhnia','GREECE','24100','6944664121','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 16:24:24',0,NULL,3,1,2,1,NULL,'billkou\r庄'),(9515,713299854002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-13 16:32:11',0,NULL,3,1,4,1,'YW865907701CN ','jabollo\r欧标\r王'),(9516,713303067002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','gnic4248','meestes@gmail.com','Michael Estes','121 N Mountain St','Blue Mountain','MS','UNITED STATES','38610','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 16:40:21',0,NULL,3,1,1,1,NULL,'gnic4248\r庄'),(9517,713326288002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','flemblue21','revhabutler@hotmail.com','Ray Butler','7412 Girard St','Omaha','NE','UNITED STATES','68122-1766','','NoPaymentFailure','CheckoutComplete','Other','2011-05-13 17:40:34',0,NULL,3,1,3,1,'RA117727824CN\r ','flemblue21\r630'),(9518,713323345002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lx_likes_to_smile','lx.dang.it@gmail.com','Alex Dang','14027 110th PL NE','Kirkland','WA','UNITED STATES','98034','(425) 445-5183','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 17:45:01',0,NULL,3,1,1,1,NULL,'lx_likes_to_smile\r庄'),(9519,713327351002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','filiplucin','filip@filiplucin.com','Filip Lucin','Dr. I. Novaka 20/1','Cakovec','Medjimurje','CROATIA','40000','0913902166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 17:56:27',0,NULL,3,1,2,1,NULL,'filiplucin\r庄'),(9520,713362798002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','spencer-creative','budspencer@mac.com','Robert Spencer','5057 Morning Dew Dr','Salt Lake City','UT','UNITED STATES','84123-4527','(801) 792-1052','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 19:15:38',0,NULL,3,1,17,0,NULL,'spencer-creative'),(9521,672305665001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','spencer-creative','budspencer@mac.com','Robert Spencer','5057 Morning Dew Dr','Salt Lake City','UT','UNITED STATES','84123-4527','(801) 792-1052','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 19:15:38',0,NULL,3,1,1,1,NULL,'spencer-creative\r绿叶 52mm uv   1\r52mm 橡胶罩   1\r庄'),(9522,724706008017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','mgt2710','miketyler@optusnet.com.au','Michael Tyler','45 Morehead Avenue, Norman Park','Brisbane','Queensland','AUSTRALIA','4170','0733957989','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-13 21:51:03',0,NULL,3,1,2,1,NULL,'mgt2710\r庄'),(9523,785733057015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','bladerunnervoidcomp2019','ramajayjay_69@yahoo.co.uk','Jason Crick','107 Kingsly Avenue','Kettering','Northamptonshire','UNITED KINGDOM','nn169es','01536515938','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'bladerunnervoidcomp2019\r庄'),(9524,785739878015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','mikekidwelly','mikedavid@dragontv.fsnet.co.uk','michael   David','94 Priory Street','Kidwelly','Carmarthenshire','UNITED KINGDOM','SA174TY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-13 22:26:42',0,NULL,3,1,2,1,NULL,'mikekidwelly\r庄'),(9525,672382513001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 22:46:52',0,NULL,3,1,17,0,NULL,'roseyranger'),(9526,713450006002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-13 23:13:54',0,NULL,3,1,2,1,NULL,'kosowar7\r庄'),(9527,769676035016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',2,'AE2501',43,'hutongstore','nkbanks51','nick@nicklory.com','Leo Claussen','Kösterbergstr. 62c','Hamburg','','GERMANY','22587','447984023163','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-13 23:37:20',0,NULL,3,1,4,1,'YW865907745CN ','nkbanks51\rreflector holder $20\r刘'),(9528,672396428001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','gaenari','jokdimbar@gmail.com','Kyung Sang Kim','21187 Ambushers St','Diamond Bar','CA','UNITED STATES','91765','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-13 23:52:34',0,NULL,3,1,1,1,NULL,'gaenari\r庄'),(9529,713463147002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','airwavesport1','info@heiho.be','Hedwig Ceulemans','Doornaardstraat 72','Wommelgem','','BELGIUM','2160','0475820458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 00:15:47',0,NULL,3,1,2,1,NULL,'airwavesport1\r庄'),(9530,785773696015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','iris_wan2003','iris_wan2003@yahoo.com.sg','Chan Wei Yee','Blk 72 Telok Blangah Heights #08-321','Singapore','','SINGAPORE','100072','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 00:33:08',0,NULL,3,1,11,1,NULL,'iris_wan2003'),(9531,671254952018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','puzzzl3r','puzzl3r1@hotmail.com','Alison Banister-Jones','po Box 496','Willetton','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-14 00:44:33',0,NULL,3,1,2,1,NULL,'puzzzl3r\r庄'),(9532,672409696001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','cookie.ns','lucyandroscoe2005@ns.sympatico.ca','jeff giles','489 alexander mackenzie rd','south farmington','NS','CANADA','b0p 1w0','(902) 840-3879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 01:02:25',0,NULL,3,1,3,1,'RA117728008CN\r ','cookie.ns\r王'),(9533,672418926001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','klimshelf','r.klimesh@horsekeeping.com','Richard Klimesh','PO Box 140','Livermore','CO','UNITED STATES','80536','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 01:59:44',0,NULL,3,1,1,1,NULL,'klimshelf\r庄'),(9534,672424124001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','gomes30','gomes_27desouza@yahoo.com.br','balbino gomes de souza','rua joenville n° 5363   8° rua<br>setor 09','Ariquemes','Rondonia','BRAZIL','76876200','0216984177514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 02:19:52',0,NULL,3,1,2,1,NULL,'gomes30\r庄'),(9535,713493699002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','syphlix','gregorytran@gmail.com','Greg Tran','17 Stuyvesant St<br>Apt 12A','New York','NY','UNITED STATES','10003-7573','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 02:43:42',0,NULL,3,1,1,1,NULL,'syphlix\r庄'),(9536,713505269002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','nsaenko','nikita.saenko@gmail.com','Никита Саенко','проезд Репина, дом 28, кв. 248','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350051','+7 (928) 201 1259','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 03:51:36',0,NULL,3,1,2,1,NULL,'nsaenko\r庄'),(9537,713516826002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 05:03:57',0,NULL,3,1,1,1,NULL,'roseyranger\r橡胶遮光罩 52mm   1\rHB-7 花瓣     1\r庄'),(9538,713517486002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','bijps2shtr','bijps2shtr@gmail.com','Bijan Dosi','1 Pike','irvine','CA','UNITED STATES','92620-2541','(949) 232-6179','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 05:05:37',0,NULL,3,1,1,1,NULL,'bijps2shtr\r庄'),(9539,769756269016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ikkuvaljo','ikkuvaljo@gmail.com','Tuomas Mäkynen','Nisulankatu 21 B 2','Jyväskylä','','FINLAND','40720','+358440430043','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 05:52:27',0,NULL,3,1,3,1,'RA117727912CN\r ','ikkuvaljo\r刘'),(9540,713558081002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','albeeday','abidee001@hotmail.com','Alexandre Bidée','Kosterstraat 93','DIEGEM','','BELGIUM','1831','485692211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 08:44:19',0,NULL,3,1,2,1,NULL,'albeeday\r庄'),(9541,672493942001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','rak200909','rsvitok@zvzapad.sk','Roman Svitok','Strazska cesta 1139/33','Zvolen','','SLOVAK REPUBLIC','960 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 08:54:58',0,NULL,3,1,2,1,NULL,'rak200909'),(9542,671381197018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','orwen98','orwenmari@yahoo.com','orwen  maribao','2/41 coolangatta road ','kirra','Queensland','AUSTRALIA','4225','0402145359','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-14 10:50:22',0,NULL,3,1,4,1,'YW865907690CN ','orwen98\rlight kit  $20\r刘\r'),(9543,713591112002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','ridux76','bhormo@hotmail.com','Bjørn-Henrik Ormo','Rosslyngveien 16B','Bronnoysund','','NORWAY','8900','+4795703065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 10:57:06',0,NULL,3,1,2,1,NULL,'ridux76\r庄'),(9544,672537232001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','9262.broker69','verybroke66@yahoo.com.sg','chan serene','22 eunos crescent<br>#08-3007','singapore','singapore','SINGAPORE','400022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:40:57',0,NULL,3,1,11,1,NULL,'9262.broker69'),(9545,713604113002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','rodrigoslater76','slater76@gmail.com','Rodrigo Souza','Av. Emb. Abelardo Bueno 3350<br>Bl 2 apt 503 Barra dda Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22775040','97030309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 11:43:01',0,NULL,3,1,2,1,NULL,'rodrigoslater76\r庄'),(9546,672566795001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','jennifers5890','jennifer.shu@optusnet.com.au','Jennifer Shu','15 Stotts Ave','Bardwell Park','New South Wales','AUSTRALIA','2207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 13:18:28',0,NULL,3,1,2,1,NULL,'jennifers5890\r庄'),(9549,672646576001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','fazullo','mirco.zanca@yahoo.it','Mirco Zanca c/o Banca Intesa Sanpaolo','Piazza Mozzarelli 3','Mantova','MN','ITALY','46100','333-2883538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 16:53:50',0,NULL,3,1,2,1,NULL,'fazullo\r庄'),(9547,672577934001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','tkincl','kincl_tomas@centrum.cz','Tomas Kincl','Jarosovska 1117','Jindrichuv Hradec','','CZECH REPUBLIC','37701','+420384417241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 15:07:22',0,NULL,3,1,2,1,NULL,'tkincl\r庄'),(9550,713644857002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','swirtun','swirtun33@gmail.com','Yuriy Swirtun','str.Karkom 9/13','Nazerat-illit','ISRAEL','ISRAEL','17095','972544790215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 17:31:10',0,NULL,3,1,2,1,' ','swirtun\r庄'),(9551,779248157015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','fraperso','curro_perez@hotmail.com','Francisco Pérez Soto','Jardín Atalaya Bloque 1 3ºB<br>Camas','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41900','697803323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 17:58:57',0,NULL,3,1,2,1,NULL,'fraperso\r庄'),(9552,672676078001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','tunurbos','jav110er@gmail.com','Javier Martín Pérez','Profesor Tierno Galvan<br>nº2','Fuenlabrada','Madrid','SPAIN','28942','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 17:59:11',0,NULL,3,1,2,1,NULL,'tunurbos\r庄'),(9553,786121422015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ankyjain','ankushjain1@hotmail.com','Ankush Jain','6 Gloucester Road<br>Brookhouse','Walsall','West Midlands','UNITED KINGDOM','WS5 3PN','07825324609','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 18:08:31',0,NULL,3,1,3,1,'RA117727926CN\r ','ankyjain'),(9554,713751121002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','shai_mim','efrat.mi@gmail.com','shai mimouni','21 Nissim Aloni','Tel Aviv','israel','ISRAEL','62919','972526994140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 18:15:57',0,NULL,3,1,2,1,NULL,'shai_mim\r庄'),(9555,672690154001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','timo454','t.sturtevant@gmail.com','Timothy Sturtevant','34 paul ave','Nashua','NH','UNITED STATES','03060-4848','(603) 365-7752','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-14 18:37:08',0,NULL,3,1,1,1,NULL,'timo454\r庄'),(9556,713751721002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','b3reeze','3reeze@gmail.com','Oleg Pertsovski','Profsoyuznaya<br>dom 85, korpus 1, kv 240.','Moscow','','RUSSIAN FEDERATION','117279','(929)6203580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 18:59:44',0,NULL,3,1,2,1,NULL,'b3reeze\r庄'),(9557,770084032016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 19:38:52',0,NULL,3,1,17,0,NULL,'volaart.m'),(9558,672732120001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','avi5087','eyalkeren38@yahoo.com','Ofer Almogi','Hanotrim 33','Zichron Yaakov','Israel','ISRAEL','30900','97246398717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 20:03:43',0,NULL,3,1,3,1,'RA117727665CN\r ','avi5087'),(9559,713802409002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','miguelpar','migelpar@yahoo.es','Miguel Ramiro Paredes','Sixto Celorrio  20-22   5º  C','Zaragoza','Aragón','SPAIN','50015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 20:13:08',0,NULL,3,1,3,1,'RA117727872CN\r ','miguelpar\r刘'),(9560,672737674001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','nightik','admin@rusro2.org','MAXIM GORBACHEV','Kalinina 109/24','Bryansk','Bryanskaya Oblast','RUSSIAN FEDERATION','241050','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 20:16:41',0,NULL,3,1,2,1,NULL,'nightik\r庄'),(9561,672744352001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','zhangcc09','zhangchengcheng09@yeah.net','Chengcheng Zhang','25E, deans court of University of Bristol<br>3st georges road','Bristol','Bristol','UNITED KINGDOM','Bs1 5ul','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-14 20:33:47',0,NULL,3,1,2,1,NULL,'zhangcc09\r庄'),(9562,713814831002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','josece182','josece@gmail.com','Jose Antonio Calleja Rodriguez','Av 11 No. 2815, entre calles 28 y 30<br>Col. Nuevo Cordoba','Cordoba','Veracruz','MEXICO','94550','(271) 712-7400','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 20:42:18',0,NULL,3,1,2,1,NULL,'josece182\r庄'),(9563,713824018002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',2,'AA3312',11.98,'hermeshine','alex2009vasi','fast_ukr@yahoo.com','Alexander Pugachev','39A Veliko-Tirnovskaya Street, apt.28','Poltava','','UKRAINE','36034','(380) 99 267 4886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 21:05:44',0,NULL,3,1,2,1,NULL,'alex2009vasi\r注意是2块\r庄'),(9564,672764488001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','customfirst','aint@wp.pl','Daniel Chojnacki','6 Twenty Fourth Street # 205','Etobicoke','ON','CANADA','m8v3n4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-14 21:28:07',0,NULL,3,1,2,1,NULL,'customfirst\r庄'),(9565,672769258001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-14 21:46:57',0,NULL,3,1,3,1,'RA117727890CN\r ','krisvisual'),(9566,786279483015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','epang2008','pangcc@gmail.com','Edwin Pang','Blk 692 Jurong West Central 1<br>07-65','default','','SINGAPORE','640692','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-14 23:52:06',0,NULL,3,1,11,1,' ','epang2008'),(9567,672807127001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','keen2by4586','lawrencetampzo@gmail.com','Lawrence Chow','Blk 491A Tampines Ave 9<br>#09-416','default','','SINGAPORE','520491','67828546','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 00:11:29',0,NULL,3,1,3,1,'RA117727974CN\r ','keen2by4586'),(9568,672818344001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','jimeflor','jimenavillaflor@gmail.com','Jimena Villaflor','lautaro 456','Arica',' XV region Arica y Parinacota','CHILE','1001017','56-58-231500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 00:58:50',0,NULL,3,1,2,1,NULL,'jimeflor\r庄'),(9569,713889673002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','b7seven7','dplockard@yahoo.com','David P Lockard','49 Dane Ct','Hampton','VA','UNITED STATES','23666','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 01:12:34',0,NULL,3,1,1,1,NULL,'b7seven7\r庄'),(9570,713909463002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','hnoyleon','melnikoff1@mail.ru','Леонид Мельников','ул. Ударная д. 31 кв. 140','Бийск','Алтайский край','RUSSIAN FEDERATION','659305','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 02:37:00',0,NULL,3,1,2,1,' ','hnoyleon\r庄'),(9571,672728515001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kjmamy70','stevemathews2@gmail.com','steve mathews','209 N Woodland Ave','clyde','OH','UNITED STATES','43410-1411','(419) 271-4193','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 03:18:17',0,NULL,3,1,1,1,NULL,'kjmamy70\r庄'),(9572,713927264002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','peyete2011','purba.yudha@gmail.com','Purba Yudha Tama','19/121 Bouverie','Carlton','Victoria','AUSTRALIA','3053','6141685421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 04:08:30',0,NULL,3,1,2,1,NULL,'peyete2011\r庄'),(9573,785979152015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.75,'hutongstore','ecilgi','ercument.turkay@ttnet.net.tr','Ercüment Türkay','SEBIT A.S.<br>ODTÜ Teknokent Gümüs Bloklar','C Blok','Ankara','TURKEY','06531','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 04:18:23',0,NULL,3,1,3,1,'RA117727930CN\r ','ecilgi\r（已加收挂号费）\r（欧标）\r'),(9574,724983200017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA3315',2.9,'photographyacc','teper','p_blanchette@live.ca','Pierre Blanchette','37 duchesne app 208','Rimouski','QC','CANADA','G5L 2E5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-15 04:59:11',0,NULL,3,1,2,1,NULL,'teper\r庄'),(9575,672864906001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','brianlam12','brian_lam12@hotmail.com','Brian Lam','6180 Cavalieri','Brossard','QC','CANADA','J4Z0H2','(450) 676-8446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 05:20:28',0,NULL,3,1,17,0,NULL,'brianlam12'),(9576,672864825001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','brianlam12','brian_lam12@hotmail.com','Brian Lam','6180 Cavalieri','Brossard','QC','CANADA','J4Z0H2','(450) 676-8446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 05:20:28',0,NULL,3,1,5,1,'CP227020582CN ','brianlam12\r2m 灯架   1\r斜臂  1\r60cm 柔光棚   1\r刘'),(9577,671341529018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','bergymon04','leighberger@bigpond.com','Leigh Berger','55 Queens Pde','Hillside','Victoria','AUSTRALIA','3337','0394491213','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-15 05:33:49',0,NULL,3,1,3,1,'RA117727943CN\r ','bergymon04\r刘'),(9578,770295271016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',40,'hutongstore','tartac','chaiyut_c@yahoo.com','Charoenchaikorn Chaiyut','PTT Public company / Phrakhanong Office Floor 2<br>555 Ardnarong Rd. Klongtoey','default','BA','THAILAND','10260','026444544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 07:38:37',0,NULL,3,1,3,1,'RA117727957CN\r ','tartac\r接口环是77mm的\r王'),(9579,672892520001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','konadirtjumper','kiter90@web.de','Chris Reichmann','Albert-Lehmann-Str.27','Haltingen','','GERMANY','79576','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 07:43:40',0,NULL,3,1,3,1,'RA117727886CN\r ','konadirtjumper\r金属卡口的那个\r刘'),(9580,786394879015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','9274julie','julie@itis.fm','Julie John','14 Elm Green','Billericay','Essex','UNITED KINGDOM','CM112LP','01277634563','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 07:49:45',0,NULL,3,1,2,1,NULL,'9274julie\r庄'),(9581,672929846001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','myartunik','sevilya@netvision.net.il','Nira Sevilya','Yarhev','Yarhev','','ISRAEL','45860','+972-52-4390104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 09:43:56',0,NULL,3,1,3,1,'RA117727869CN\r ','myartunik'),(9582,770361547016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','tonester1000','wa_wright@yahoo.com','Tony Wright','16 Kensington Manor','Dollingstown','Armagh','UNITED KINGDOM','BT66 7HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 10:26:47',0,NULL,3,1,2,1,NULL,'tonester1000\r庄'),(9583,672942810001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','jackmeck','berkkaleli@hotmail.com','Berk Kaleli','Zafer sokak zafer apartmani<br>numara 43 daire 2 nisantasi','istanbul','sisli','TURKEY','34000','5327813357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 10:33:01',0,NULL,3,1,2,1,NULL,'jackmeck\r庄'),(9584,725374328017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','blonde.mel','heart.of.art@hotmail.com','Melissa Ball','2 Lonsdale Place Wishart','Brisbane','Queensland','AUSTRALIA','4122','0733432102','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-15 11:46:03',0,NULL,3,1,2,1,NULL,'blonde.mel\r庄'),(9585,770417697016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','rephlexactions','rephlexactions@yahoo.com','gregory normand','34 st matthews road, cotham','bristol','Bristol','UNITED KINGDOM','bs6 5tu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 12:24:32',0,NULL,3,1,2,1,NULL,'rephlexactions\r庄'),(9586,673005792001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','aviv_r','aviv_r@netvision.net.il','aviv rubinstein','hachavazelet 2','kiryat ono','','ISRAEL','55454','(972) 37360401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 12:58:09',0,NULL,3,1,3,1,'RA117727841CN\r ','aviv_r'),(9587,713795146002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 13:00:58',0,NULL,3,1,3,1,'RA117727807CN\r RA117727078CN\r','saud-p\r分2个小包\r刘'),(9588,673023137001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','minhtuan1986','mr_handsome1986@yahoo.com','Tuan Phuong','4/14<br>Wattle Valley Rd','Canterbury','Victoria','AUSTRALIA','3126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 13:38:39',0,NULL,3,1,2,1,' ','minhtuan1986\r庄'),(9589,770470995016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','jadedhills23','goldlight23@ntlworld.com','Peter Brewster','21 Beech Drive','Berkhamsted','Hertfordshire','UNITED KINGDOM','HP4 2HG','01442383515','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 14:03:24',0,NULL,3,1,2,1,NULL,'jadedhills23\r庄'),(9590,786047262015,250615147105,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB900',1,'AB3311',32.99,'hutongstore','tcn3891','tc.newell@ntlworld.com','Katie Cockerell','Little Parndon School','Harlow','Essex','UNITED KINGDOM','CM20 1PU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 15:18:59',0,NULL,3,1,3,1,'RA117727719CN\r ','tcn3891\r王'),(9591,714165851002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5,'hermeshine','shearlf05','sharonfahnestock@yahoo.com','Sharon Fahnestock','361 Petersburg Rd','Carlisle','PA','UNITED STATES','17015-9219','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 15:52:25',0,NULL,3,1,1,1,NULL,'shearlf05\r庄'),(9592,673097951001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','martincu67','markcu67@gmail.com','martin moreno padilla','Candido Avilez # 3219 C0l Plutarco / Ernesto Damy y Fernando Cue','culiacan','sinaloa','MEXICO','80194','01 667 7144076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 16:06:52',0,NULL,3,1,17,0,NULL,'martincu67'),(9593,714170157002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','martincu67','markcu67@gmail.com','martin moreno padilla','Candido Avilez # 3219 C0l Plutarco / Ernesto Damy y Fernando Cue','culiacan','sinaloa','MEXICO','80194','01 667 7144076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 16:06:52',0,NULL,3,1,3,1,'RA117727798CN\r ','martincu67\r50-70柔光棚 通用塑料卡口  1\r50-70柔光棚 通用金属卡口 \r刘'),(9594,786656215015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','joekhu','joekhu79@gmail.com','Joseph Khu','Blk 427 Tampines St 41 #11-451','default','','SINGAPORE','520427','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 16:08:55',0,NULL,3,1,11,1,NULL,'joekhu'),(9595,673113727001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','cottage_based','cian_kj@hotmail.com','Kevin Carroll','6745H 190th Ln','Fresh Meadows','NY','UNITED STATES','11365-4168','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 16:29:08',0,NULL,3,1,1,1,NULL,'cottage_based'),(9596,673123826001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','lballari','lluisballarin@gmail.com','Lluís Ballarín Romero','St. Francesc de Paula, 75-77 1r 2a','Mataró','Barcelona','SPAIN','08301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 16:43:29',0,NULL,3,1,2,1,NULL,'lballari\r庄'),(9597,673138524001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','julzangelic','judy.adel@hotmail.com','Judy Adel','Um Hurair street, zomorroda building<br>Burdubai, Dubai','Dubai','Dubai','UNITED ARAB EMIRATES','504343','00971-50-9554433','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 17:05:47',0,NULL,3,1,8,1,'CP227020551CN ','julzangelic\r英标\r庄'),(9598,673142086001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','redacosta','asanchezacosta@orange.es','Antonio Sanchez Acosta','Alonso de Ojeda, 8  2º A','Murcia','Murcia','SPAIN','30007','968204757','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 17:13:15',0,NULL,3,1,3,1,'RA117727855CN\r ','redacosta\r两个螺丝的那款'),(9599,673234661001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','rozengeur44','tinekevisscher44@hotmail.com','tineke visscher','hoofdlingenpad 11','FROOMBOSCH','','NETHERLANDS','9619 PR','0598-390897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 18:50:56',0,NULL,3,1,17,0,NULL,'rozengeur44'),(9600,713299282002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','dav_vader','dav_vader@yahoo.es','Daniel Muñoz','Calle agua de cartuja 52 2-C','Granada','Andalucía Ceuta y Melilla','SPAIN','18012','655222556','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 18:53:39',0,NULL,3,1,4,1,'YW865907723CN ','dav_vader\rtripod $15'),(9601,714321486002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','rozengeur44','tinekevisscher44@hotmail.com','tineke visscher','hoofdlingenpad 11','FROOMBOSCH','','NETHERLANDS','9619 PR','0598-390897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 19:03:10',0,NULL,3,1,2,1,NULL,'rozengeur44\r反光板 80cm 2合1    1\rNIKON 镜头盖 67mm     1\r庄'),(9602,668993546001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','jmundo1217','jmundo@comcast.net','Jose Mundo','3 four seasons dr','charlottesville','va','UNITED STATES','22901-1376','(703) 581-4157','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 19:32:17',0,NULL,3,1,1,1,NULL,'jmundo1217\r庄'),(9603,673297890001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','ogsrsezar','srsezar@gmail.com','OlegNatan Gruzman','Rotshild 80','petah tikva','israel','ISRAEL','49473','050 2699994','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 20:08:56',0,NULL,3,1,3,1,'RA117727740CN\r ','ogsrsezar\r红盒的那个\r刘'),(9604,770806483016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','killineycolin','colinbehan@gmail.com','Colin Behan','39 Watson Avenue<br>Killiney','Dublin','Dublin','IRELAND','D00','0857380742','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 20:14:20',0,NULL,3,1,2,1,NULL,'killineycolin\r庄'),(9605,714382371002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',87.8,'hermeshine','kameraman1973','bladeruner@atlas.sk','Milos Villem','Perecka 4','Levice','','SLOVAK REPUBLIC','93405','+421907134513','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 20:19:29',0,NULL,3,1,5,1,'CP227020579CN ','kameraman1973\r刘'),(9606,673312482001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','1bestonly1','gigi@studiocafaro.com','Gargano Vincenza','Via Capotorti 30','Adelfia','BA','ITALY','70010','3491702090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 20:30:25',0,NULL,3,1,2,1,NULL,'1bestonly1\r庄'),(9607,786943934015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','cnc_user','luka@sepetavc.com','Cosylab d.d. (Luka Sepetavc)','Teslova 30','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-15 21:00:06',0,NULL,3,1,2,1,NULL,'cnc_user\r庄'),(9608,673336924001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','deema..2','deema2200@hotmail.com','Deema Suliman','2984 rabwah-jabal markoz street','riyadh','riyadh','SAUDI ARABIA','11466','0500000559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 21:21:34',0,NULL,3,1,3,1,'RA183613960CN\r ','deema..2\r庄\r---\r第一次平邮没收到,0709挂号重发一个给他'),(9609,673353647001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','salahatris64','salahatris@msn.com','DIEGO PIÑAR FELIGRERAS','CARRETERA DE BARCELONA<br>181 5º-3ª','BARBERA DEL VALLES','Cataluña','SPAIN','08210','630569032','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-15 22:05:09',0,NULL,3,1,4,1,'YW865907712CN ','salahatris64\rtripod $20'),(9610,673360154001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','beautiful_collectibles','cecilialotter76@yahoo.com.ar','Hernan Siludakis','Ascasubi 117','Monte Grande','Bs As','ARGENTINA','1842','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 22:14:43',0,NULL,3,1,2,1,' ','beautiful_collectibles\r庄'),(9611,714448162002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','wuxi0730','rewot@optusnet.com.au','Rendi Liu','4 Gwynne Street','Richmond','Victoria','AUSTRALIA','3121','0411322808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 22:37:22',0,NULL,3,1,2,1,NULL,'wuxi0730\r庄'),(9612,786999290015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','sjh31466','steven.harrow@talktalk.net','Steven Harrow','34 Overton Drive<br>Water Orton','Birmingham','Warwickshire','UNITED KINGDOM','B46 1QL','01217487217','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-15 22:48:01',0,NULL,3,1,2,1,NULL,'sjh31466\r庄'),(9613,673157942001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 23:27:36',0,NULL,3,1,17,0,NULL,'zetra450'),(9614,673158439001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-15 23:27:36',0,NULL,3,1,3,1,'RA117727815CN\r ','zetra450\r大力夹云台   2\r庄'),(9615,673389982001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','simple_hi','simple_hi@yahoo.com','Vien Chau','3957 Windansea St','Las Vegas','NV','UNITED STATES','89147-6545','(702) 379-4772','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-15 23:53:15',0,NULL,3,1,1,1,NULL,'simple_hi'),(9616,673392143001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','asdediamantes','jcorredera@ya.com','Jose Corredera Acero','CCamilo Jose Cela nº 9, portal 1,piso 2º - A','Las Rozas','Madrid','SPAIN','28230','916402606','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 00:00:32',0,NULL,3,1,3,1,'RA117727838CN\r ','asdediamantes'),(9617,714483561002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','ucatril78','ucatril@hotmail.com','ulises catril','avenida carcoop 1292<br>villa mora','coronel','chile/concepcion/coronel','CHILE','4200225','78981438','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 00:29:37',0,NULL,3,1,5,1,'CP227020517CN ','ucatril78\r王'),(9618,673083696001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','psyxolog','xcreativ@gmail.com','Sergei Gusev','proezd Belyatskogo, dom 15 kvartira 68','Orekhovo-Zuevo','Moskovskaya oblast\'','RUSSIAN FEDERATION','142613','89067302658','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 02:05:56',0,NULL,3,1,3,1,'RA117727753CN\r ','psyxolog'),(9619,671330751018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',9.99,'photographyacc','rinatmafia','rin9@mail.ru','Rinat Sharafutdinov','12-mikrorayon; 52- building; 19- flat','Nefteyugansk','Tyumen oblast; Khanty-Mansi Autonomous Okrug','RUSSIAN FEDERATION','628310','89044593585','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-16 02:57:23',0,NULL,3,0,2,1,NULL,'rinatmafia'),(9620,673467443001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','prowalun','alex_mykin@mail.ru','alexey mukin','Refa\'el Klatchkin<br>41/8','beer-sheva','','ISRAEL','84641','0546848710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 05:06:56',0,NULL,3,1,2,1,NULL,'prowalun'),(9621,714202835002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rus-market','russian-market@hotmail.com','Ihor Lukyanets','Rokossovskogo 49-a/28','Chernigiv','','UKRAINE','14027','+380954468947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 05:21:54',0,NULL,3,0,2,1,NULL,'rus-market'),(9622,711605630002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','martina14051986','ati.d@seznam.cz','Martina Drtinová','Sídliště Svákov 703/3','Soběslav','Česká reupublika','CZECH REPUBLIC','39201','728122311','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 05:58:09',0,NULL,3,0,3,1,'RA117727435CN\r ','martina14051986\rXXL\r已减库'),(9623,714589288002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','ferslot1973','ffmartin@ono.com','Fernando Fernández Martín','MARLA INDUSTRIAL - POL. IND. LA CERRADA','Maliaño','Cantabria','SPAIN','39600','618636275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 08:07:34',0,NULL,3,1,3,1,'RA117727427CN\r ','ferslot1973'),(9624,673501600001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','mharnang','mkh86@hotmail.com','Morten Harnang','Colletts Gate 57','Oslo','','NORWAY','0456','04797021656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 08:14:29',0,NULL,3,1,2,1,NULL,'mharnang'),(9625,786787114015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','theharefamily','mhare@emea.att.com','theharefamily','8 Morris Close<br>Bridgemary','Gosport','Hampshire','UNITED KINGDOM','PO13 0SS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 08:19:36',0,NULL,3,1,2,1,NULL,'theharefamily'),(9626,725944674017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','bulochkin1983','i3yjlka@gmail.com','Botov Yuri','ул. А.Невского, 9 - 158','Ярославль','Ярославская область','RUSSIAN FEDERATION','150052','+7915-997-3118','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-16 08:26:21',0,NULL,3,1,2,1,NULL,'bulochkin1983'),(9627,673505843001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','willzpogee','willypogi@rocketmail.com','Willy Pajayat','Blk 417 Canberra Rd #02-365','default','','SINGAPORE','750417','98230792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 08:39:55',0,NULL,3,1,17,0,NULL,'willzpogee'),(9628,787175631015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.38,'hutongstore','sanders6261','ebay@petesanders.com','Peter Sanders','38 The Woodlands, Hither Green','Lewisham','London','UNITED KINGDOM','se13 6ty','02084614735','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 08:50:24',0,NULL,3,1,2,1,NULL,'sanders6261'),(9629,787183692015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','tolapoto','javier.ruiz@vodafone.es','francisco javier ruiz roman','avd de la estacion 57 local VODAFONE','TORRIJOS','Castilla-La Mancha','SPAIN','45500','627413013','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-16 09:18:56',0,NULL,3,1,4,1,'YW865907793CN ','tolapoto\rtripod  $15\r'),(9630,787192176015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','panniers0','grahamrobinson2@o2.co.uk','Graham Robinson','29 Upper Lewes Road','Brighton','East Sussex','UNITED KINGDOM','BN2 3FH','01273685105','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 09:46:06',0,NULL,3,1,2,1,NULL,'panniers0\r庄'),(9631,713304629002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','maxflylow','m.pellegrini@tiscali.it','Marco Pellegrini C/O  MecService Srl','Via degli Artigiani 35','Rudiano','BS','ITALY','25030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 09:52:30',0,NULL,3,1,3,1,'RA117727603CN\r ','maxflylow\rM（已入库）\r'),(9632,673524628001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','willzpogee','willypogi@rocketmail.com','Willy Pajayat','Blk 417 Canberra Rd #02-365','default','','SINGAPORE','750417','98230792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 09:58:07',0,NULL,3,1,11,1,NULL,'willzpogee\r67mm 环+架\r77mm 环+架'),(9633,714623353002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','duccio_76','duccio.maglietta@hotmail.it','Duccio Maglietta','26 Rue Dominique Ingres','Toulouse','Midi-Pyrénées','FRANCE','31000','0633391974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 10:30:30',0,NULL,3,1,2,1,NULL,'duccio_76\r庄'),(9634,673538787001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','vlad-i-mir70','pwd70@rambler.ru','Vladimir Popchenko','293/1','Kalininets','Moscow reg','RUSSIAN FEDERATION','143371','+79166834919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 10:54:16',0,NULL,3,1,2,1,NULL,'vlad-i-mir70\r庄'),(9635,714640176002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','praza2011','prazanmichal@gmail.com','Michal Pražan','Čechovská 113','Příbram','Czech Republic','CZECH REPUBLIC','26101','+420732603528','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 11:35:13',0,NULL,3,1,3,1,'RA117727475CN\r ','praza2011\r刘'),(9636,714645303002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','fishingrod557','mgeuder@bellsouth.net','Rodney Geuder','968 E Main St','West Point','MS','UNITED STATES','39773','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 11:51:39',0,NULL,3,1,1,1,NULL,'fishingrod557\r庄'),(9637,672473461018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','cozzakipa','cozza28kipa@hotmail.com','cory kipa','49 Main Rd<br>Cardiff','newcastle','New South Wales','AUSTRALIA','2285','0402903916','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-16 12:13:24',0,NULL,3,1,4,1,'YW865907782CN ','cozzakipa\rbackground support  $20\r刘'),(9638,673567924001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','serginio06','borbor81@mail.ru','Serg Iv','Milutenko 11, 317','Kyiv','Kyiv','UKRAINE','02156','0675050524','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 12:39:04',0,NULL,3,1,2,1,NULL,'serginio06\r庄'),(9639,672486200018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','aticosjavier','aticos@terra.es','Javier Saez Sanz','Calle Sierra del Agua 25','Tres Cantos','Madrid','SPAIN','28760','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-16 12:52:11',0,NULL,3,1,2,1,NULL,'aticosjavier\r庄'),(9640,714671196002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','maximiva','ivma87@gmail.com','Maxim Ivanuta','Zhigura 14 flat 52<br>(Жигура 14 кв 52)','Vladivostok','Primorsky kray','RUSSIAN FEDERATION','690088','79502801110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 13:21:34',0,NULL,3,1,2,1,' ','maximiva\r庄'),(9641,673582436001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','rogers3137','rogersclan06@aol.com','Dana Rogers','115 Cedar Tree Ct','Statesville','NC','UNITED STATES','28677-9189','(704) 235-8403','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 13:26:46',0,NULL,3,1,1,1,NULL,'rogers3137\r庄'),(9642,673590807001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','shaungrenfell','shaungren@hotmail.com','shaun grenfell','27 klopper street<br>dan pienaarville','krugersdorp','Gouteng','SOUTH AFRICA','1739','0027849519014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 13:54:58',0,NULL,3,1,2,1,NULL,'shaungrenfell\r庄'),(9643,673604325001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','joaorubens','tuco@ig.com.br','JOAO RUBENS DEL DEBBIO','RUA DA CONSOLAÇÃO, 986, APTO. 161','SÃO PAULO','SÃO PAULO','BRAZIL','01302000','+551196999999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 14:38:40',0,NULL,3,1,2,1,NULL,'joaorubens\r庄'),(9644,673606239001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','mitchell5111','hrm.chitwood@sbcglobal.net','mitchell chitwood','2836 Barnhill Ln','frisco','TX','UNITED STATES','75034-4674','(469) 362-1223','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 14:45:49',0,NULL,3,1,3,1,'RA117727550CN\r ','mitchell5111\r刘'),(9645,787301446015,250692237499,'Large size Neoprene Lens Pouch Case 90mm x 220mm L',1,'AC1203',3.28,'hutongstore','canon-rockrider','photographed426@gmail.com','Richárd Tóth','Esze Tamás utca 7, földszint 8','Koppánymonostor','','HUNGARY','2903','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 14:46:07',0,NULL,3,1,2,1,NULL,'canon-rockrider\r庄'),(9646,787286905015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',63.99,'hutongstore','matthewbrownephotography','info@matthewbrownephotography.com','MATTHEW  BROWNE ','41B HALFPENNY GATE ROAD <br>BROOMHEDGE ','MOIRA ','Armagh','UNITED KINGDOM','bt670hw','07597743340','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-16 14:57:04',0,NULL,3,1,4,1,'YW865907815CN ','matthewbrownephotography\r英标\r庄'),(9647,787314970015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','uberboarder','alastair.campbell@worc.ox.ac.uk','Alastair Campbell','14, Viscount Point<br>199 The Broadway','Wimbledon','London','UNITED KINGDOM','SW19 1NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 15:15:04',0,NULL,3,1,2,1,NULL,'uberboarder\r庄'),(9648,714733640002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','dany0328','danyg1128@gmail.com','Daniel Gonzalez','12940 NW 107th Ct','Medley','FL','UNITED STATES','33178-3131','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'dany0328（电子支票）\r庄'),(9649,673651780001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','first77','jorsch1@web.de','Alexander Jorsch','Oesselser Str. 32a','Laatzen-Gleidingen','','GERMANY','30880','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:46:24',0,NULL,3,1,2,1,NULL,'first77\r庄'),(9650,714741002002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','fjgomber','fjgb60@gmail.com','Francisco José Gómez Berrocal','C/ Huerto de los claveles 4, 5ºC','Málaga','Andalucía Ceuta y Melilla','SPAIN','29013','657638024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:53:53',0,NULL,3,1,17,0,NULL,'fjgomber'),(9651,714741751002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',3.55,'hermeshine','fjgomber','fjgb60@gmail.com','Francisco José Gómez Berrocal','C/ Huerto de los claveles 4, 5ºC','Málaga','Andalucía Ceuta y Melilla','SPAIN','29013','657638024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:53:54',0,NULL,3,1,17,0,NULL,'fjgomber'),(9652,714742379002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','fjgomber','fjgb60@gmail.com','Francisco José Gómez Berrocal','C/ Huerto de los claveles 4, 5ºC','Málaga','Andalucía Ceuta y Melilla','SPAIN','29013','657638024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 16:53:54',0,NULL,3,1,2,1,NULL,'fjgomber\r方形滤镜接口环 72mm   1\r方形滤镜接口环 77mm   1\r广角托架   1\r80cm 2in1 反光板   1\r庄'),(9653,787363985015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','chris.mead','chris-mead@talktalk.net','Christopher Mead','2 Osprey Close<br>Hartford','Huntingdon','Cambs','UNITED KINGDOM','PE29 1UX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 16:54:43',0,NULL,3,1,3,1,'RA117727546CN\r ','chris.mead\r刘'),(9654,714761571002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','glos_closet','glos_closet@sbcglobal.net','Gloria Salvante','PO Box 7039<br>2697 Reid Lane','Clearlake','CA','UNITED STATES','95422-7039','(707) 994-4966','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 17:23:32',0,NULL,3,1,1,1,NULL,'glos_closet\r庄'),(9655,673671420001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',71,'hermeshine','vadim1972moskva','vadim-moskva72@mail.ru','Vadim Danilov','Zelenograd, 2028-241','Moscow','Moscow','RUSSIAN FEDERATION','124365','+7 9859928003','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 17:30:52',0,NULL,3,1,17,0,NULL,'vadim1972moskva'),(9656,714771990002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','vadim1972moskva','vadim-moskva72@mail.ru','Vadim Danilov','Zelenograd, 2028-241','Moscow','Moscow','RUSSIAN FEDERATION','124365','+7 9859928003','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-16 17:49:20',0,NULL,3,0,5,1,'CP227020401CN ','vadim1972moskva\rWT600    1\r摄影背心 冬夏 XL    1（已入库）'),(9657,771278592016,260660052497,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','matofarky','farkas.mato@gmail.com','Martin Farkaš','Rovníková 12','Bratislava','Slovakia','SLOVAK REPUBLIC','82102','+421944126514','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 17:53:06',0,NULL,3,1,2,1,NULL,'matofarky\r庄'),(9658,673688842001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','tannerfritz21','tannerfritz@gmail.com','Tanner Fritz','2223 Vail Ave','Charlotte','NC','UNITED STATES','28207-1529','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 18:03:37',0,NULL,3,0,1,1,NULL,'tannerfritz21\r黑'),(9659,787421641015,250619797712,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',46.9,'hutongstore','madfootballer88','ashleyharvey00@hotmail.com','ashley harvey','48 cantrell road braunstone','leicester','Leicestershire','UNITED KINGDOM','le3 1sd','07835686229','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-16 18:50:23',0,NULL,3,1,4,1,'YW865907804CN ','madfootballer88\r白色\rbackground support $20\r庄'),(9660,787440985015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','pokopelo','pokopelo@gmail.com','César Hernández','Calle Ignacio Zuloaga 5, 2º','Algeciras','Cadiz','SPAIN','11207','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-16 18:53:46',0,NULL,3,1,2,1,' ','pokopelo\r庄'),(9661,787461650015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',2,'AA1209',5.58,'hutongstore','thetippon','thetippon@yahoo.co.uk','Ryan Davies','25 Wordsworth St<br>Cwmaman','Aberdare','Rhondda Cynon Taff','UNITED KINGDOM','CF446HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-16 19:22:26',0,NULL,3,1,2,1,NULL,'thetippon\r庄'),(9662,714827118002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','robertpalicka','nrtm.baget@gmail.com','Robert Palicka','102 dara court','Celbridge','Kildare','IRELAND','default','0863406419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:26:09',0,NULL,3,1,2,1,NULL,'robertpalicka\r庄'),(9663,714829446002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','archibalts1','arvisziemelis@gmail.com','Arvis Ziemelis','10 Capdoo Court','Clane','Kildare','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 19:30:44',0,NULL,3,1,2,1,NULL,'archibalts1\r庄\r'),(9664,714855719002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rajkram','rajeshkram@yahoo.com','Rajesh Ramamurthy','3600 Bridge Pkwy<br>Ste 200','Redwood City','CA','UNITED STATES','94065-1170','(408) 931-6992','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-16 20:22:19',0,NULL,3,1,1,1,NULL,'rajkram\r庄'),(9665,672684154018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','birgitt1995','birgitt_surma@hotmail.com','Birgitt Surma','Frans Broeckaertlaan 20','Overmere','','BELGIUM','9290','093678776','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-16 20:23:31',0,NULL,3,1,2,1,NULL,'birgitt1995\r庄'),(9666,673774298001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','valkeajoki1','valkeajoki@gmail.com','Jussi Valkeajoki','Kääjäntie 15','Orivesi','FIN','FINLAND','35300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 20:50:07',0,NULL,3,1,2,1,NULL,'valkeajoki1\r庄'),(9667,672704270018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','jean_cf','nategrey_x@hotmail.com','Jean Carlos Farias','Domingo Lucio Farias','Sao Joao Batista','Santa Catarina','BRAZIL','88240000','(48) 3265-0722','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-16 21:01:21',0,NULL,3,1,5,1,'CP227020494CN ','jean_cf\r欧标\r庄'),(9668,672715186018,280666902955,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',7.99,'photographyacc','natana9','dylan.postel@hotmail.fr','dylan postel','12 sente de la folie','Etrechy','Ile-de-France','FRANCE','91580','0770594851','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-16 21:25:59',0,NULL,3,1,2,1,NULL,'natana9'),(9669,673792406001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nightmirage','nightmirage1@hotmail.com','Mahdi Zahedah \"AL EARA EST\"','South Ring Road Exit 20. AL MANSORA<br>Opp of Al Nokba School TEL:01-4481781','Riyadh','PO Box 280252','SAUDI ARABIA','11392','00966-55-7867137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 21:36:52',0,NULL,3,1,2,1,NULL,'nightmirage\r庄\r\r'),(9670,714834416002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','titosko','jalvarado.pacheco@gmail.com','Jose Alvarado Pacheco','483 Comunidad Caracoles 2','Peñuelas','PR','PUERTO RICO','00624','787-202-0013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-16 21:47:06',0,NULL,3,1,3,1,'RA117727461CN\r ','titosko'),(9671,673799911001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','john.wellington','johnw1973@hotmail.com','john wellington','rua mata grande 569 apto. 302<br>vila valqueire','rio de janeiro','rio de janeiro','BRAZIL','21321540','2124549019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 22:01:16',0,NULL,3,1,3,1,'RA117727532CN\r ','john.wellington\r刘\r欧标'),(9672,673821278001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','roses73blue','rmancuso_mtl@yahoo.com','Rosa Mancuso','47 Adam','Vaudreuil-Dorion','QC','CANADA','J7V 8P5','(514) 884-2864','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-16 23:21:19',0,NULL,3,1,2,1,NULL,'roses73blue\r庄'),(9673,673834585001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','that1mom','afkennett@yahoo.com','Annette Kennett','9283 Jean Dr','Sandy','UT','UNITED STATES','84070-6254','(801) 867-5111','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 00:17:23',0,NULL,3,1,1,1,NULL,'that1mom\r庄'),(9674,673837268001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 00:32:28',0,NULL,3,1,17,0,NULL,'pentaxfriend'),(9675,714935056002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','pentaxfriend','m.vanbalenjr@chello.nl','Thijs van Balen jr','Eenhoornstraat 3','hoek van Holland','','NETHERLANDS','3151RG','+31638824840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 00:32:29',0,NULL,3,0,3,1,'RA117727529CN\r ','pentaxfriend\r摄影背心 Nikon 老款 2XL（已入库）\r摄影背心 黑色厚 无字 2XL '),(9676,673842097001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','bellasdesserts','laurenmcortesi@gmail.com','Bella\'s','227 Icedale Rd','Honey Brook','PA','UNITED STATES','19344','(610) 942-2849','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 00:51:24',0,NULL,3,1,1,1,NULL,'bellasdesserts\r庄'),(9677,672776916018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','rusty_xt','levi_gardner@hotmail.com','Levi Gardner','1a Campbell Avenue','Normanhurst','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-17 01:06:25',0,NULL,3,1,3,1,'RA117727515CN\r ','rusty_xt\r刘    \r376'),(9678,673849767001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','scottvdk30','scottvdk@pga.com','Scott van der Kooy','5809 Lexington Dr','Parrish','FL','UNITED STATES','34219-5813','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 01:19:46',0,NULL,3,1,1,1,NULL,'scottvdk30'),(9679,714953783002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rackem','urackem@att.net','michael j sullivan','18151 Gardiner Ln','jupiter','FL','UNITED STATES','33458-4326','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 01:37:09',0,NULL,3,1,1,1,NULL,'rackem\r庄'),(9680,672791110018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',29,'photographyacc','manminhmai','ehehmylove@gmail.com','Minh Man Mai','59 Hill End road','Doonside','New South Wales','AUSTRALIA','2767','61435414351','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-17 02:02:11',0,NULL,3,1,3,1,'RA117727594CN\r ','manminhmai\r刘'),(9681,726333870017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',2,'AA1306',10.8,'photographyacc','pierreg1387','piga57@hotmail.com','Les Entreprises Pierre G.','7003 Route Principale','Wentworth-Nord','QC','CANADA','J0T 1Y0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-17 02:06:34',0,NULL,3,1,2,1,'\\ ','pierreg1387\rNIKON 镜头盖 62mm   2\rNikon 眼罩   2'),(9682,787632231015,250692236486,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',2,'AB3332',3.16,'hutongstore','cdfpromotions','chowley02@hotmail.com','Chris Howley','18 Harehills Park Avenue','Leeds','West Yorkshire','UNITED KINGDOM','Ls9 6BP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 02:16:00',0,NULL,3,1,2,1,NULL,'cdfpromotions'),(9683,673868776001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 02:38:30',0,NULL,5,0,18,0,'1234','测试数据segalu'),(9684,714702178002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',78.9,'hermeshine','loro_swett','lswettn@hotmail.com','Lorenzo Swett','Duble Almeyda 1617 dpto 406-C<br>Nunoa','Santiago','Region Metropolitana, Nunoa','CHILE',' 7750097','56-998026337','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 02:41:02',0,NULL,3,0,5,1,'CP227020525CN  ','loro_swett'),(9685,673869537001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','lucybluepeaches','davesports@centurytel.net','Donna Roberts','18874 Maries Road 527','Rolla','MO','UNITED STATES','65401-6472','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 02:43:29',0,NULL,3,1,1,1,NULL,'lucybluepeaches'),(9686,673885961001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','g_dealer','gary@springhillwholesale.com','Gary Figg','1430 E Springhill Dr','Terre Haute','IN','UNITED STATES','47802-4366','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 04:07:14',0,NULL,3,1,1,1,NULL,'g_dealer\r庄'),(9687,673901487001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','deodatusuniverse','bodyauniverse@gmail.com','Bogdan Kutin','Komsomolskaya 96 -4','Kaliningrad','NA','RUSSIAN FEDERATION','236023','79114577323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 05:44:11',0,NULL,3,1,2,1,NULL,'deodatusuniverse\r庄'),(9688,771550383016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','samirawadh','samirawadh@yahoo.com','Samir A. Awadh','P.O. Box 80206<br>Dar es Salaam','Dar es Salaam','Tanzania','TANZANIA','255','255713111999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 05:54:04',0,NULL,3,1,3,1,'RA117727585CN ','samirawadh'),(9689,787682040015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'AC1302',6.1,'hutongstore','adam.wol','adam.wolynszczak@gmail.com','Adam Wolynszczak','127 The Crescent<br>Park West Pointe','Dublin','Dublin','IRELAND','D12','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 05:55:10',0,NULL,3,1,2,1,NULL,'adam.wol\r庄'),(9690,672839596018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','drdan2469','danny@thecarcleaner.com.au','Danny Lang','2 Azure Court','Pakenham','Victoria','AUSTRALIA','3810','0395404402','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-17 06:16:12',0,NULL,3,1,3,1,'RA117727634CN ','drdan2469'),(9691,673908026001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','dthakankocaturkey','dthakankoca@hotmail.com','Hakan Koca','Dokuz Eylül Üniversitesi Tınaztepe Kampüsü Mediko Birimi<br>Tınaztepe /  BUCA','İZMİR','','TURKEY','35160','02324128092','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 06:25:29',0,NULL,3,1,3,1,'RA117727625CN ','dthakankocaturkey\r刘'),(9692,673911007001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','o1ka','olja-ja@inbox.ru','Olga Karbovskaja','Orumetsa 5/1 - 16','Maardu','Harjumaa','ESTONIA','74111','+37256757075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 06:44:12',0,NULL,3,1,2,1,'、 ','o1ka'),(9693,715016428002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','raider10jose','raiderdiez@hotmail.com','jose hidalgo','c/ la cañada 164','trijueque','Castilla-La Mancha','SPAIN','19192','695538958','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 07:01:47',0,NULL,3,1,2,1,NULL,'raider10jose\r庄'),(9694,715015689002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','qwests939','kaspars.shtolcers@gmail.com','Kaspars Shtolcers','Celmu 2-26','Riga','','LATVIA','LV-1079','37126550490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 07:03:35',0,NULL,3,1,2,1,NULL,'qwests939Vasiliy '),(9695,672849279018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',2,'AE1503',130,'photographyacc','jackzombie','dale.azzopardi@hotmail.com','Dale Azzopardi','81 plumpton road','diggers rest','Victoria','AUSTRALIA','3427','0397401712','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-17 07:13:32',0,NULL,3,1,4,1,'YW865907826CN ','jackzombie\r庄\r'),(9696,715030886002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','vasiliypol1981','vasiliypol@inbox.ru','Vasiliy Polunin','Shamil Usmanov street 109a flat 54','Naberezhnye Chelny','Republic of Tatarstan','RUSSIAN FEDERATION','423800','7-919-636-27-79','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 08:21:17',0,NULL,3,1,3,1,'RA117727648CN ','vasiliypol1981'),(9697,673939498001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','tthamma','ktthamma@kmitl.ac.th','Thammarat Taengtang','King Mongkut\'s Institute of Ladkrabang<br>3 M. 2  3rd floor Chulabhord building, Department of Physics Cho','Ladkrabang','Bangkok','THAILAND','10520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 09:10:21',0,NULL,3,1,2,1,NULL,'tthamma\r庄'),(9698,715058655002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gordhandas','kiritgordhandas@aol.com','Kirit Gordhandas (Mathematics Department)','Bootham School<br>51 Bootham','YORK','North Yorkshire','UNITED KINGDOM','YO30 7BU','07905588325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 10:22:39',0,NULL,3,0,17,0,NULL,'gordhandas'),(9699,715059075002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gordhandas','kiritgordhandas@aol.com','Kirit Gordhandas (Mathematics Department)','Bootham School<br>51 Bootham','YORK','North Yorkshire','UNITED KINGDOM','YO30 7BU','07905588325','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 10:24:03',0,NULL,3,0,3,1,'RA117726072CN ','gordhandas （已入库）\r摄影背心 Canon  老款  2XL   1\r摄影背心 Canon  老款  3XL   1'),(9700,715053424002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','cygb87','ceyugeba@hotmail.com','Cedric Yu','1113 Riverwood Gate','Port Coquitlam','BC','CANADA','V3B 8A2','(604) 472-0080','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 10:45:34',0,NULL,3,1,3,1,'RA117726038CN ','cygb87\r刘'),(9701,787764364015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','123-lotusesprit','lynn.hutchinson@ntlworld.com','Lynn Hutchinson','29 Brynhyfryd Road<br>Briton Ferry','Neath','Neath Port Talbot','UNITED KINGDOM','SA11 2HT','01639775790','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 11:01:25',0,NULL,3,1,2,1,NULL,'123-lotusesprit'),(9702,672906420018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',7.28,'photographyacc','ashish12280','ashish_kurt@yahoo.com','Ashish Gupta','18 John Fawkner Drive <br>Endeavour Hills','Melbourne','Victoria','AUSTRALIA','3802','0403652192','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-17 11:21:16',0,NULL,3,1,2,1,' ','ashish12280'),(9703,715074376002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','ekosogorovevgenii','e-kosogorov@yandex.ru','Evgenii Kosogorov','Rozdestvenskaya Nabereznaya d.29 kv.63','Krasnodar','Krasnodarskii krai','RUSSIAN FEDERATION','350089','8-905-401-51-96','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 11:26:46',0,NULL,3,1,2,1,NULL,'ekosogorovevgenii\r庄'),(9704,726463800017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','lukes-pins','sales@aviation-center.biz','Luke Hopkins','PO Box 255','Warburton','Victoria','AUSTRALIA','3799','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-17 11:40:15',0,NULL,3,1,2,1,NULL,'lukes-pins\r庄'),(9705,673983313001,110531023204,'JJC Leather Hand Strap Grip comfort stable D700 5DII',1,'AB1409',12.99,'hermeshine','alexandersarychev','sarychev@ovi.com','Alexander Sarychev','Baumana<br>4 -24','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630046','+79139866543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 12:05:41',0,NULL,3,1,2,1,NULL,'alexandersarychev；\r庄'),(9706,715093390002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','senkler','azaro@home.nl','A.Azaro','G.Flinclstraat 46','Meppel','','NETHERLANDS','7944 HB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 12:34:57',0,NULL,3,1,17,0,NULL,'senkler'),(9707,673990212001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',2,'AC2403',61.98,'hermeshine','senkler','azaro@home.nl','A.Azaro','G.Flinclstraat 46','Meppel','','NETHERLANDS','7944 HB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 12:34:57',0,NULL,3,1,3,1,'RA117726996CN ','senkler\r笔   3\r60cm 圆形柔光棚   2\r新地址：\rSergei Gazarov\rStr. Lisunova kvartal 1\rH.22 app.18\rHamzinskij rajon\r700204 Tashkent\rUzbekistan'),(9708,726486884017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','aulx0725','au_lx@yahoo.com','ROMAN ACHARYA','60/43 WATKIN STREET','ROCKDALE','New South Wales','AUSTRALIA','2216','0295973163','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-17 12:55:06',0,NULL,3,1,2,1,' ','aulx0725\r庄'),(9709,787805317015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','anthonyb9482','antbbb@yahoo.co.uk','Anthony Bowler','6 Nelson Street, Audenshaw','Manchester','Lancashire','UNITED KINGDOM','M34 5EA','07734824351','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 12:57:01',0,NULL,3,1,2,1,NULL,'anthonyb9482\r庄'),(9710,787814270015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','stevelitton','stevelitton@hotmail.com','Steve Litton (2nd Floor) Digital Department','Imagine Publishing Ltd.<br>Richmond House, 33 Richmond Hill','Bournemouth','Dorset','UNITED KINGDOM','BH2 6EZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 13:20:51',0,NULL,3,1,2,1,NULL,'stevelitton\r庄'),(9711,715108678002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',5,'AA1305',12.2,'hermeshine','pahanapp','alex_sachik@list.ru','Alex Sachik','Geroev Kosmosa, 11 -69','Kiev','','UKRAINE','03146','(099)060-8090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 13:27:58',0,NULL,3,1,17,0,NULL,'pahanapp'),(9712,715107302002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','pahanapp','alex_sachik@list.ru','Alex Sachik','Geroev Kosmosa, 11 -69','Kiev','','UKRAINE','03146','(099)060-8090','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 13:27:59',0,NULL,3,1,3,1,'RA117726143CN ','pahanapp\rNIKON 镜头盖 52mm   5\rCANON 镜头盖  58mm   5'),(9713,787822119015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mustine','velasco.lopez@gmail.com','Jose Velasco Lopez','Calle Pepe Pintado Numero 4','La Paloma - El Palmar','Murcia','SPAIN','30120','655052415','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 13:42:05',0,NULL,3,1,2,1,NULL,'mustine\r庄'),(9714,715115617002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','tomasi_030','tomers.ts@gmail.com','Tomer Shalom','p.o.box : 370','Givhat Shmuel','','ISRAEL','54103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 13:49:43',0,NULL,3,1,2,1,NULL,'tomasi_030\r庄'),(9715,715118551002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','tracer_one','tracer_dick@hotmail.com','Girard Yuzon','8 Tilden St.','Plumpton','New South Wales','AUSTRALIA','2761','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 13:59:41',0,NULL,3,1,4,1,'YW865907863CN ','tracer_one\r刘'),(9716,715120299002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ageo2veraedmund','ageo2vera@yahoo.com.my','Edmund Manior','No. 4679, Taman Ria 5, Jalan Utara','TAWAU','SABAH','MALAYSIA','91000','0198698393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:09:14',0,NULL,3,1,17,0,NULL,'ageo2veraedmund'),(9717,715122128002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ageo2veraedmund','ageo2vera@yahoo.com.my','Edmund Manior','No. 4679, Taman Ria 5, Jalan Utara','TAWAU','SABAH','MALAYSIA','91000','0198698393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:12:20',0,NULL,3,1,3,1,'RA117726069CN ','ageo2veraedmund\rHB-7 花瓣   2\r刘'),(9718,674023892001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','present_ptz','mpadarin@gmail.com','MIKHAIL PADARIN','Popova 13-41','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185014','79602157229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:23:06',0,NULL,3,1,2,1,NULL,'present_ptz\r庄'),(9719,672964299018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','nvgilk','kerberon@gmail.com','Gil Kreslavsky','Zohar 5','Ramat Gan','Gush Dan','ISRAEL','52442','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-17 14:28:53',0,NULL,3,1,2,1,' ','nvgilk\r庄'),(9720,673504387001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',10.47,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 14:32:31',0,NULL,3,1,2,1,NULL,'frankedisson\r52/58/77mm 遮光罩  各一个\r申报：Gift ， 12$\r庄'),(9721,715148015002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','bitonsudio','bitonstudio@gmail.com','shlomi biton','Irus 2/1','kiryat shmona','','ISRAEL','11632','972546705775','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 15:30:56',0,NULL,3,1,3,1,'RA117726086CN ','bitonsudio\r刘   '),(9722,715061398002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','2010laryn','e_laryn@abv.bg','Tsvetan Nenkov','Mara Gidik 36','Sevlievo','Gabrovo','BULGARIA','5400','+359888507596','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 16:30:35',0,NULL,3,1,2,1,NULL,'2010laryn\r庄'),(9723,787789479015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',4,'AA1314',8.8,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:49',0,NULL,3,1,17,0,NULL,'gtsussex'),(9724,771652849016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'AA1304',5.64,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:49',0,NULL,3,1,17,0,NULL,'gtsussex'),(9725,787788980015,250804357708,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',2,'AA1306',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:50',0,NULL,3,1,17,0,NULL,'gtsussex'),(9726,771653096016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',2,'AA1303',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:51',0,NULL,3,1,17,0,NULL,'gtsussex'),(9727,771653287016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',2,'AA1301',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:51',0,NULL,3,1,17,0,NULL,'gtsussex'),(9728,787788637015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',2,'AA1307',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:52',0,NULL,3,1,17,0,NULL,'gtsussex'),(9729,771653615016,260768456440,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',2,'AA1309',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:52',0,NULL,3,1,17,0,NULL,'gtsussex'),(9730,771653993016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',2,'AA1302',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:53',0,NULL,3,1,17,0,NULL,'gtsussex'),(9731,771654486016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',4,'AA1315',8.8,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:54',0,NULL,3,1,17,0,NULL,'gtsussex'),(9732,787788497015,250804358294,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',2,'AA1308',3.74,'hutongstore','gtsussex','guy.thatcher@hireacamera.com','Guy Thatcher','Unit 5, Wellbrook Farm<br>Berkeley Road','Mayfield','East Sussex','UNITED KINGDOM','tn20 6eh','01435873028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 16:55:54',0,NULL,3,1,3,1,'RA117726157CN ','gtsussex\r机身盖/镜头后盖  Canon    4\r机身盖/镜头后盖  Nikon    4\rCANON 镜头盖  58mm   2\rCANON 镜头盖  67mm   2\rCANON 镜头盖  72mm   2\rCANON 镜头盖  77mm   3\rNIKON 镜头盖 67mm   2\rNIKON 镜头盖 72mm   2\rNIKON 镜头盖 77mm   2\rNIKON 镜头盖 62mm   2'),(9733,673022216018,280673081875,'77mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 77 mm',2,'AB1307',11.32,'photographyacc','fair.go','nguyen.hiep@optusnet.com.au','Hiep Nguyen','13 Vincent Avenue','St. Albans','Victoria','AUSTRALIA','3021','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-17 17:04:05',0,NULL,3,1,2,1,NULL,'fair.go\r庄'),(9734,674082168001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','fraisy01','tarzan01@sympatico.ca','LOVE YU BIJOUX','JoAnn Huard<br>526 Grande Cote Ouest','Lanoraie','QC','CANADA','J0K 1E0','(514) 237-1625','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,' ','fraisy01\r庄'),(9735,715168753002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','protrekmao','protrek@centrum.cz','Martin Vylasek','Husova 101','Bedihost','','CZECH REPUBLIC','79821','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 17:16:37',0,NULL,3,1,2,1,NULL,'protrekmao\r庄'),(9736,715188164002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','avpigeon','avpigeon@hotmail.com','Andrew Pigeon','147 Allen Ave','Green Bay','WI','UNITED STATES','54302-4453','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 17:17:25',0,NULL,3,1,1,1,NULL,'avpigeon\r庄'),(9737,715189081002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','totemplateonnet','totemplate@gmail.com','Nuttapong Srimarak-on','4236/218-222 Wien Co.Ltd., Sathupradit Rd., Soi Pradoo 1<br>Bangklo, Bangkholaem','default','BA','THAILAND','10120','66840551434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 17:27:31',0,NULL,3,1,11,1,NULL,'totemplateonnet\r庄'),(9738,771797583016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','belaks2009','belaks82@inbox.lv','Igors Daumanis','Stirnu iela<br>48-43','Riga,Purvciems','Riga','LATVIA','LV-1084','37125980869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 17:55:04',0,NULL,3,1,3,1,'RA117726090CN ','belaks2009'),(9739,778095182015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','moraleejen','jamoralee@gmail.com','jenny Moralee','21 bewick lane ovingham','Ovingham','Northumberland','UNITED KINGDOM','NE42 6BT','7930919506','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-17 18:11:56',0,NULL,3,1,4,1,'YW865907830CN ','moraleejen\r刘\r英标'),(9740,715215130002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','fatmouse_xp','songhw@gmail.com','Haowei Song','7525 Parkdale Ave<br>Apt 3W','Clayton','MO','UNITED STATES','63105-2856','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 18:16:11',0,NULL,3,1,1,1,NULL,'fatmouse_xp\r庄'),(9741,673068691018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','lavradar','viakin@mail.ru','Alexander Vyakin','Dubai post office','DUBAI','Dubai','UNITED ARAB EMIRATES','PO BOX 32406','050-3067011','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-17 18:40:29',0,NULL,3,1,3,1,'RA117726055CN \rRA117726982CN','lavradar\r分2个小包发\r'),(9742,771832131016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','elppaaoife','elppa2@hotmail.com','Aoife Broderick','23 shenick rd ','Skerries','Dublin','IRELAND','','0861244230','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-17 18:56:39',0,NULL,3,1,4,1,'YW865907841CN ','elppaaoife\r（英标）\r绿色\r庄\r'),(9743,715250928002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','pvt030906','trentsthompson@yahoo.com','Trent Thompson','3545 Fishinger Blvd<br>Mills/James Productions','Hilliard','OH','UNITED STATES','43026-9489','(614) 777-9933 ext.: 2103','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 19:27:45',0,NULL,3,1,1,1,NULL,'pvt030906\r庄'),(9744,715252843002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 19:32:25',0,NULL,3,1,6,1,'EE520583383CN ','buyedv\r申报：Gift'),(9745,788006279015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','pedol029','plosilva@gmail.com','Pedro Silva','Bairro N.ª Sr.ª dos Remédios<br>Lote C6 - 2.º Dto','Guarda','Guarda','PORTUGAL','6300-590','969072909','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-17 19:44:59',0,NULL,3,1,2,1,NULL,'pedol029\r庄'),(9746,715276053002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','pyiyha','pyiyha@hotmail.com','Peter Yi','6356 Burnett Cir','Ventura','CA','UNITED STATES','93003-2411','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-17 20:17:16',0,NULL,3,1,1,1,NULL,'pyiyha\r庄'),(9747,788034079015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','stokelad','phil@60taylor.fsnet.co.uk','Phil Taylor','60 Chamberlain Avenue','Stoke-on-Trent','UK','UNITED KINGDOM','ST45EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 20:23:51',0,NULL,3,1,2,1,NULL,'stokelad\r庄'),(9748,674180626001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','nowell63','noel_carson@hotmail.com','NOEL  CARSON','CARRANTULLA','CLAREMORRIS ','Mayo','IRELAND','default','0949364883','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-17 20:29:13',0,NULL,3,1,2,1,NULL,'nowell63\r庄'),(9749,673129646018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','passig','s.passig@gmail.com','Steffan O\'Mara Passig','8/11 Blaxland Ave','Newington','New South Wales','AUSTRALIA','2127','0296485523','PayPalPaymentInProcess','CheckoutComplete','AU_RegisteredParcelPost','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117726041CN ','passig\r刘'),(9750,715303930002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','thomaskaufi','thomas@kaufmanas.dk','Thomas Kaufmanas','Slotsparken 22','Bagsværd','København','DENMARK','2880','40183424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 21:21:18',0,NULL,3,1,2,1,NULL,'thomaskaufi\r庄'),(9751,715313233002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','jubero49632','jubero4@hotmail.com','Maria Amparo Sanchis Estrems','peris y valero 134 pª19','valencia','Comunidad Valenciana','SPAIN','46006','622892611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 21:45:56',0,NULL,3,1,2,1,NULL,'jubero49632\r庄'),(9752,788106631015,250601903190,'Wireless Remote Shutter Release for Nikon D200/D300​/D3',1,'AA3201',11.47,'hutongstore','deerose01','fried_day12@yahoo.co.uk','isiah navarro','7 goodwood drive','stockport','Cheshire','UNITED KINGDOM','sk3 8xb','01614199614','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-17 23:04:34',0,NULL,3,1,2,1,NULL,'deerose01\r庄'),(9753,674242074001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','neoboby2006','adlane@hiktheb.com','L\'espace Carrosserie (Abbioui Adlane)','12 rue de Clermont','beauvais','60','FRANCE','60000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 23:55:32',0,NULL,3,1,17,0,NULL,'neoboby2006'),(9754,715348514002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','neoboby2006','adlane@hiktheb.com','L\'espace Carrosserie (Abbioui Adlane)','12 rue de Clermont','beauvais','60','FRANCE','60000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 23:55:32',0,NULL,3,1,17,0,NULL,'neoboby2006'),(9755,674242227001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','neoboby2006','adlane@hiktheb.com','L\'espace Carrosserie (Abbioui Adlane)','12 rue de Clermont','beauvais','60','FRANCE','60000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 23:55:33',0,NULL,3,1,17,0,NULL,'neoboby2006'),(9756,674242448001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','neoboby2006','adlane@hiktheb.com','L\'espace Carrosserie (Abbioui Adlane)','12 rue de Clermont','beauvais','60','FRANCE','60000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-17 23:55:33',0,NULL,3,1,17,0,NULL,'neoboby2006'),(9757,715348881002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','neoboby2006','adlane@hiktheb.com','L\'espace Carrosserie (Abbioui Adlane)','12 rue de Clermont','beauvais','60','FRANCE','60000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-17 23:55:34',0,NULL,3,1,4,1,'YW865907900CN ','neoboby2006\r2m 灯架   3\r单灯头   1\r60x60cm 四灯头 柔光箱   2\r反光伞   1\r115w 220v 灯泡   1\r45w 220v 灯泡   12\r灯架包  1\r欧标\r'),(9758,673200920018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','bachelorinc','dinesh.thapa26@yahoo.com','dinesh thapa','57/919 ,botany road<br>Rosebery','sydney','New South Wales','AUSTRALIA','2018','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-18 00:20:17',0,NULL,3,1,2,1,NULL,'bachelorinc\r庄'),(9759,714540442002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chadschaub','cschaub@liberty.edu','Chad Schaub','1432 Austin Mill Rd','Evington','VA','UNITED STATES','24550-4161','(434) 525-1516','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-18 00:40:46',0,NULL,3,1,3,1,'RA117726109CN ','chadschaub\r刘'),(9760,788161102015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','jota.ce.17','jota.ce.17@gmail.com','Tiago Pimentel Carvalho Tedim Dias','Rua Comandante Aníbal Oliveira<br>N26  2Frente','V N Famalicão','','PORTUGAL','4760-204','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 02:04:57',0,NULL,3,1,2,1,NULL,'jota.ce.17\r庄'),(9761,674316483001,110568758656,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',199,'hermeshine','fazzyboo','faran_saberi@inbox.com','Faran Saberi','31 Glendale Crescent<br>Jandakot','Perth','Western Australia','AUSTRALIA','6164','6140488980010','NoPaymentFailure','CheckoutComplete','AU_Other','2011-05-18 05:55:25',0,NULL,3,1,4,1,'YW865907922CN ','fazzyboo\r澳标\r庄\r'),(9762,673277048018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','lizwal72','elizabeth.wallis@bigpond.com','Elizabeth Wallis','3 Humphries Street','Muswellbrook','New South Wales','AUSTRALIA','2333','0265414205','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-18 06:33:03',0,NULL,3,1,3,1,'RA117726205CN\r ','lizwal72'),(9763,674330081001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','bosch_outlet','bosch-outlet@sydneytools.com.au','Elvis Bey','429 New Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','0295696139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 07:11:53',0,NULL,3,1,2,1,NULL,'bosch_outlet'),(9764,715441360002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',197,'hermeshine','moda-senza-limiti-2010','moda-senza-limiti@live.it','camelia troncota','via bezzi 3','trento','TN','ITALY','38122','3339193100','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 07:30:53',0,NULL,3,1,4,1,'YW865907896CN','moda-senza-limiti-2010（已入库）\r欧标\r背景架换成2x2m的\r2把伞换成柔光伞\r庄'),(9765,788240095015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','baklan4ikof','saveleva.da@gmail.com','Saveleva Darya','3 Vladimirskaya 8/1-8','Moskow','','RUSSIAN FEDERATION','111123','(926)345-5526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 07:41:16',0,NULL,3,1,2,1,NULL,'baklan4ikof'),(9766,674336449001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','victorcap','droit@atlas.cz','Viktor Cap','U Kovarny 24','Olomouc','','CZECH REPUBLIC','77900','+420605577858','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 07:47:00',0,NULL,3,1,3,1,'RA117726191CN\r ','victorcap'),(9767,772094352016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','otilja','jolita.liavaag@yahoo.no','Jolita Liavaag','Kaptein Hannevigsvei 15B','Skollenborg','Buskerud','NORWAY','3619','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 07:59:49',0,NULL,3,0,3,1,'RA117726174CN\r ','otilja\r1.6mx3m 白色'),(9768,673130649018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','borislaval','barbara.rehakova@gmail.com','Barbara Rehakova','Budovatelska 56','Sala','','SLOVAK REPUBLIC','92701','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-18 08:02:02',0,NULL,3,1,3,1,'RA117726188CN\r ','borislaval'),(9769,674345929001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','tomino1979','tome1979@pobox.sk','Tomas Caniga','Na Gruntoch -10','Nitra-Drazovce','','SLOVAK REPUBLIC','94901','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 08:35:08',0,NULL,3,1,2,1,NULL,'tomino1979'),(9770,726506829017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','passionateaboutbikes','skunky70@hotmail.com','Kylie Law','Suite 12, 62- 70 Allison Crs','menai','New South Wales','AUSTRALIA','2234','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-18 09:32:29',0,NULL,3,1,2,1,NULL,'passionateaboutbikes'),(9771,772124122016,260660050980,'Green.L 58mm 58 Neutral Density ND8 Filter ND 8 New',1,'AE2310',3.85,'hutongstore','barbadori','javier_cerrada@yahoo.es','Javier Cerrada','Apartment 15, Brookview Apartments<br>Dublin Road','Athlone','Westmeath','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 09:52:18',0,NULL,3,1,3,1,'RA117722124CN\r ','barbadori\r上次发错了，发了个渐变灰给客户\r补发58mm ND8 '),(9772,726890068017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','dynamix00','chrisholmes@adam.com.au','Chris Holmes','15 Lindsay Terrace','Belair','South Australia','AUSTRALIA','5052','0417834909','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-18 10:08:40',0,NULL,3,1,3,1,'RA117726280CN ','dynamix00\r刘'),(9773,715485658002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','algolum','post.pseudoscientist@gmail.com','Alexander Uminsky','Strelochnikov<br>dom 2, korpus G, kv. 43','Ekaterinburg','Sverdlovskaya  obl','RUSSIAN FEDERATION','620107','89536012154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 10:38:01',0,NULL,3,1,2,1,NULL,'algolum'),(9774,674380149001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',59.26,'hermeshine','eugene14m','gaastra16@mail.ru','Yevgen Katelchuk','Kirov st. 51/15','Melitopol','UA','UKRAINE','72319','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 11:20:12',0,NULL,3,1,3,1,'RA117726276CN ','eugene14m\r（共7个滤镜，11个镜盖）\r绿叶 UV 52/67/72/77mm   各一个\r绿叶 CPL 52/72/77mm    各一个\rNikon 机身、镜头后盖    1\rNikon 镜头盖  52/62/67//72/77mm 各一个\rCanon 镜头盖 58/58/67/72/77mm 各一个\r'),(9775,673349399018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','sproulie72','sprouley@bigpond.net.au','Grant Sproule','4 Lambton Rd','Waratah','New South Wales','AUSTRALIA','2298','0249608482','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-18 11:37:41',0,NULL,3,1,3,1,'RA117726262CN ','sproulie72'),(9776,772162885016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','apat4546','wegolandia@gmail.com','Alessio Patrini','Via Melchiorre gioia 6','Limbiate','MI','ITALY','20051','0299682723','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-18 11:55:56',0,NULL,3,1,4,1,'YW865907955CN ','apat4546\r欧标\rlighting kit  $40\r庄'),(9777,674389364001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','aliyestudio','drunkyrabbit@yandex.ru','Aliya Pavroz','63, 6, Gorkogo','Aprelevka','Moscow region','RUSSIAN FEDERATION','143360','79264678414','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 11:57:24',0,NULL,3,1,3,1,'RA117726355CN ','aliyestudio\r红盒的那个'),(9778,674372986001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','firstarcangelm','firstarcangelm@aol.com','Michael Harrell','18320 Crawley Rd','Odessa','FL','UNITED STATES','33556-4821','(813) 928-1776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 11:58:39',0,NULL,3,1,1,1,NULL,'firstarcangelm'),(9779,726922478017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','max_magus','coopermi@tpg.com.au','Michael COOPER','Apt 59,<br>679 Bourke Street','Surry Hills','New South Wales','AUSTRALIA','2010','0293101935','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-18 12:06:48',0,NULL,3,1,2,1,NULL,'max_magus'),(9780,715508139002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jlumikant','janne.lumikanta@nokia.com','Janne Lumikanta','Juhanankatu 2 as4','Turku','','FINLAND','20740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 12:11:12',0,NULL,3,1,2,1,NULL,'jlumikant'),(9781,771693865016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',3.74,'hutongstore','jkillick','james.killick@blueyonder.co.uk','Mr J Killick','55 Elmswood Road','Liverpool','Merseyside','UNITED KINGDOM','L17 0DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 12:15:19',0,NULL,3,1,2,1,NULL,'jkillick\rCANON 镜头盖  58mm   2\r注意是2个'),(9782,674401909001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','0573126','chee6618@yahoo.com','chee chuang ee chuang ee','no 5703/35 Taman Gemencheh Jaya<br>73200 Gemencheh','Negeri Sembilan','','MALAYSIA','73200','019-7490888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 12:30:55',0,NULL,3,1,2,1,NULL,'0573126'),(9783,715529538002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','babur74','dolin_74is@mail.ru','Aleksandr Dolin','Voroshilova 57-59','Cheliabinsk','Cheliabinskaya obl','RUSSIAN FEDERATION','454136','777 04 59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 13:18:12',0,NULL,3,1,3,1,'RA117726347CN ','babur74\r刘'),(9784,674418088001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','ppvvld791','ppvvld@mail.ru','Vladimir Popov','ul. Lelushenko 1A kv 28','Rostov-on-Don','','RUSSIAN FEDERATION','344045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 13:23:48',0,NULL,3,1,2,1,NULL,'ppvvld791'),(9785,674424699001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 13:45:37',0,NULL,3,1,3,1,'RA117726333CN ','diretordecriacao\r欧标\r刘'),(9786,788358125015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','youngrockdoc','mhoward5@talk21.com','Martin Howard','3 Achvraid Road','Inverness','Highland','UNITED KINGDOM','IV2 4LE','07890359333','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-18 13:49:29',0,NULL,3,1,2,1,NULL,'youngrockdoc'),(9787,715545730002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','daniel.milohnic','marijela.milohnic@gmail.com','Daniel Milohnić','Vrh 77a','Krk','','CROATIA','51500','+385995239833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 14:13:13',0,NULL,3,1,2,1,NULL,'daniel.milohnic'),(9788,674433683001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','fdkarl4u','kmaskos@rogers.com','Karl Maskos','22 Cannon Rd','Quispamsis','NB','CANADA','E2E3T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 14:15:35',0,NULL,3,1,2,1,' ','fdkarl4u'),(9789,715547877002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','dfel4785','dafemo2009@gmail.com','David Felipe Morales','Resopal Maquinas Vzz<br>Francisco Alonso nº2','Alcala de Henares','Madrid','SPAIN','28806','676515297','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 14:21:18',0,NULL,3,1,4,1,'YW865907944CN \rYW864488922CN','dfel4785\rtripod  $15\r庄\r上一票被扣了，再发一个'),(9790,726981255017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','ali_689','ali_689@hotmail.com','Alison Geeves','5 Booth Street','Parkdale','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-18 15:06:02',0,NULL,3,1,2,1,NULL,'ali_689'),(9791,788409002015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','thaqee90','crossurarms1910@gmail.com','Nurthaqifah Farhani Mujiman','Royal College of Surgeons Ireland,<br>123 St. Stephen\'s Green,','Dublin','Dublin','IRELAND','2','0852426553','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 15:50:52',0,NULL,3,1,2,1,NULL,'thaqee90\r刘'),(9792,674483219001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','comovos21','talibabe@yahoo.com','Natalia Casco COVEHN','1335 NW 98th Ct<br>Unit 9','Doral','FL','UNITED STATES','33172-2778','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-05-18 16:44:06',0,NULL,3,1,17,0,NULL,'comovos21'),(9793,674487367001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','comovos21','talibabe@yahoo.com','Natalia Casco COVEHN','1335 NW 98th Ct<br>Unit 9','Doral','FL','UNITED STATES','33172-2778','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 16:53:46',0,NULL,3,1,1,1,NULL,'comovos21\rNIKON 镜头盖 52mm    1\rNikon 三角包  D3    1'),(9794,715615411002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','zooraves','hikebikekayak@gmail.com','Christina Lane','21429 NW 43rd Ave','Ridgefield','WA','UNITED STATES','98642-8412','(360) 910-2851','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 17:28:35',0,NULL,3,1,1,1,NULL,'zooraves'),(9795,715637032002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','fjgomber','fjgb60@gmail.com','Francisco José Gómez Berrocal','C/ Huerto de los claveles 4, 5ºC','Málaga','Andalucía Ceuta y Melilla','SPAIN','29013','657638024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 18:15:49',0,NULL,3,0,17,0,NULL,'fjgomber\r（已经随上一票发走了！）'),(9796,674539442001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jmyeung','josephyeung@sbcglobal.net','Joseph Yeung','16538 Walnut St','Fountain Valley','CA','UNITED STATES','92708','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 18:51:59',0,NULL,3,1,1,1,NULL,'jmyeung'),(9797,674542133001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mikhaelsinenko','cper34@gmail.com','Mikhael Sinenko','bakhchivandzhi 2a flat138','Shelkovo-3','Moscow','RUSSIAN FEDERATION','141103','+79265594371','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 18:58:04',0,NULL,3,1,3,1,'RA117726320CN ','mikhaelsinenko\r刘'),(9798,674544778001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',29.67,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 19:02:41',0,NULL,3,1,3,1,'RA117726316CN ','krisvisual\r刘'),(9799,674547914001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 19:08:15',0,NULL,3,1,3,1,'RA117726214CN ','krisvisual\r刘'),(9800,772358933016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','murphyworm200mel9','lisajmuir@yahoo.co.uk','LISA MUIR','28 rue des 24 arpents','villiers le mahieu','Ile-de-France','FRANCE','78770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 19:11:15',0,NULL,3,1,17,0,NULL,'murphyworm200mel9'),(9801,772358934016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','murphyworm200mel9','lisajmuir@yahoo.co.uk','LISA MUIR','28 rue des 24 arpents','villiers le mahieu','Ile-de-France','FRANCE','78770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 19:11:16',0,NULL,3,1,17,0,NULL,'murphyworm200mel9'),(9802,772358936016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','murphyworm200mel9','lisajmuir@yahoo.co.uk','LISA MUIR','28 rue des 24 arpents','villiers le mahieu','Ile-de-France','FRANCE','78770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 19:11:17',0,NULL,3,1,2,1,NULL,'murphyworm200mel9\r机身盖/镜头后盖  Canon   1\rNIKON 镜头盖 52mm   1\r橡胶遮光罩 52mm   1'),(9803,715687140002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','obar5330','oscar_m5@hotmail.com','Oscar Barragan','902 Fulton Mall<br># M-32','Fresno','CA','UNITED STATES','93721-2509','(559) 779-7481','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,3,1,1,1,NULL,'obar5330'),(9804,772402088016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',4,'AA1303',7.48,'hutongstore','58xbror','alar.broberg@bredband.net','Alar Broberg','Högalidsgatan 13A','Stockholm','','SWEDEN','117 30','004607035023148','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-18 20:20:35',0,NULL,3,1,2,1,NULL,'58xbror'),(9805,674578877001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','willessean','swilles@cogeco.ca','Sean Willes','171 Emerald St. S','Hamilton','ON','CANADA','L8N 2V6','(905) 628-9138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 20:10:34',0,NULL,3,1,2,1,NULL,'willessean'),(9806,674589360001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','donybt','donybt@netvision.net.il','Dony BT','21st Ha Palmach st<br>POB 3','Kiryat Bialik','','ISRAEL','27053','972524347377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 20:34:02',0,NULL,3,1,3,1,'RA117726228CN ','donybt\r刘'),(9807,670999386001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',3,'AC2401',50.97,'hermeshine','ame200968','quicolaras@hotmail.com','lara martinez fenoll','Escultor Valentín García Quinto nº7 4ºA<br>phone 0034 691 531 125','Albatera','Alicante','SPAIN','03340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 20:40:28',0,NULL,3,1,3,1,'RA117723782CN\r ','ame200968'),(9808,715721921002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','andreavidovic','andire119@yahoo.com','Andrea Vidovic','Malesnica 3F<br>Malešnica 3F','Zagreb','','CROATIA','10090','+385958043987','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-18 21:10:11',0,NULL,3,1,2,1,NULL,'andreavidovic'),(9809,715736066002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','kulakova2010','magekanen@gmail.com','TATIANA KULAKOVA','307-62 HUNT AVE','RICHMOND HILL','ON','CANADA','L4C4G9','(289) 475-5331','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-18 22:06:05',0,NULL,3,1,3,1,'RA117726231CN ','kulakova2010\r刘'),(9810,674626924001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','albinousrex','kylekretch@gmail.com','Kyle Kretch','35175 Miles Rd','Chagrin Falls','OH','UNITED STATES','44022-2358','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-18 22:18:37',0,NULL,3,1,1,1,NULL,'albinousrex'),(9811,715752328002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','securityjr','jrandesi2@aol.com','James Randesi','790 Forest Hill Rd','Apalachin','NY','UNITED STATES','13732-1845','(607) 258-0051','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 22:41:54',0,NULL,3,1,1,1,NULL,'securityjr'),(9812,674638241001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','donaldmyers','rjmyers1977@yahoo.com','Donald Myers','203 dement rd.','Montgomery','LA','UNITED STATES','71454','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 23:02:34',0,NULL,3,1,1,1,NULL,'donaldmyers'),(9813,715769635002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jesssha435','gkich@sbcglobal.net','Gwendolyn Kichard (Crosson)','435 Cornwall Ave','Cheshire','CT','UNITED STATES','06410-2740','(203) 272-4076','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-18 23:54:39',0,NULL,3,1,1,1,NULL,'jesssha435'),(9814,788654427015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','postondemand','huwjenkins@uk2.net','huw jenkins','Avenida Marques De L\'Argentera 5, 1b','barcelona','Cataluña','SPAIN','08003','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 00:06:57',0,NULL,3,1,3,1,'RA117726245CN ','postondemand\r刘'),(9815,673629530018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','purplem76','emma@modusrealty.com.au','Emma Heffernan','18 Sanctuary Parkway','Waterford','Queensland','AUSTRALIA','4133','0414856242','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-19 00:18:14',0,NULL,3,1,3,1,'RA117726165CN ','purplem76\r刘'),(9816,715781053002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mroy3824','nanie3@globetrotter.net','mario roy','60, boul. notre-dame','pont-rouge','QC','CANADA','g3h 3k6','(418) 873-2975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 00:39:55',0,NULL,3,1,3,1,'RA117726395CN ','mroy3824\r刘'),(9817,715786743002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','cupid1598','larklandbrady@yahoo.com','L. Brady','109 Beaumont Cir<br>Apt 1','YONKERS','NY','UNITED STATES','10710-2026','(914) 361-9523','NoPaymentFailure','CheckoutComplete','Other','2011-05-19 01:05:02',0,NULL,3,1,1,1,NULL,'cupid1598\r2XL'),(9818,674665533001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','electricsystemsplus','themaryland2000@live.com','WMMCGRAW','15245 Hatton Landing Dr','NEWBURG','MD','UNITED STATES','20664-2609','','NoPaymentFailure','CheckoutComplete','Other','2011-05-19 01:09:40',0,NULL,3,1,4,1,'YW865907911CN ','electricsystemsplus'),(9819,674345756001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','kv8841b','bellman_96@yahoo.com','ARMINOOR SHAH BIN ARMIA','NKK PARTS AND SERVICES SDN BHD, LOT945, SG MENGHULU<br>MUKIM KUAH,','LANGKAWI','KEDAH','MALAYSIA','07000','0122626771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 01:51:57',0,NULL,3,1,2,1,NULL,'kv8841b'),(9820,715807996002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','elcanoseba2011','elcanoseba@hotmail.com','Sebastián Adagio','Bv Nicasio Oroño 918','Rosario','Santa Fe','ARGENTINA','2000','(54)341156413304','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 02:25:07',0,NULL,3,1,3,1,'RA117726404CN ','elcanoseba2011\r刘'),(9821,715827572002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','rvbpix','sgrennie@gmail.com','Stephen Rennie','74 avenue de Bordeaux','St Genis de Saintonge','Poitou-Charentes','FRANCE','17240','06.04.04.47.56','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 03:58:58',0,NULL,3,1,2,1,NULL,'rvbpix'),(9822,674702698001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','tatacaldas83','contatoc@gmail.com','Maria Virginia Bianco','Rua Buarque, 473','São Paulo','SP','BRAZIL','05618-060','(11) 9299-1933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 04:05:10',0,NULL,3,1,2,1,NULL,'tatacaldas83'),(9823,674545500001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','qinglinmeng','qinglinmeng@hotmail.com','Qing Lin Meng','14 Bridlewreath','Kitchener','ON','CANADA','N2E 3V5','(519) 579-5825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 04:24:14',0,NULL,3,1,3,1,'RA117726418CN ','qinglinmeng\r1.6mx2.1m   2块 （白+黑）'),(9824,715837231002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.85,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','011 48657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 05:00:55',0,NULL,3,1,3,1,'RA117726435CN ','2010bousosheila\r申报 $10'),(9825,674712428001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','elinby','elin2001ru@yahoo.ca','Uladzimir Pabryzgayeu','91/13 Waine Street<br>Surry Hills','Sydney','New South Wales','AUSTRALIA','2010','0423 092937','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 05:06:55',0,NULL,3,1,4,1,'YW865907734CN ','elinby\r2m 的背景架 （ 白 +黑+浅蓝）\rbackground $25'),(9826,772567039016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','kosmobabka','lewicki_m@yahoo.com','Mikolaj Lewicki','2633 22nd Ave West<br>Apt 1','Seattle','WA','UNITED STATES','98199','(206) 730-3397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 05:19:03',0,NULL,3,1,1,1,NULL,'kosmobabka'),(9827,715842115002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','kee9950','kee@basemail.no','Kai-Egil Evjen','Skagvn 75, PO Box 25','Vardø','','NORWAY','N-9950','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 05:23:47',0,NULL,3,0,3,1,'RA117726421CN ','kee9950\r2XL 已入库'),(9828,674719222001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jdeks','rowansreciever@hotmail.com','Rowan Sked','1/11 AvWO Course, School of Air Warfare<br>RAAF Base East Sale','Sale','Victoria','AUSTRALIA','3852','0422960419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 05:46:59',0,NULL,3,1,2,1,' ','jdeks'),(9829,674725588001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','apeltok','peltoarto@hotmail.com','Arto Peltokangas','Siihtalantie 54','Alajärvi','Kurejoki','FINLAND','62710','+35850-5285151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 06:28:36',0,NULL,3,1,2,1,' ','apeltok\r刘'),(9830,673720177018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','mathh29','m_liminana@hotmail.com','Mathieu Liminana','Palladium<br>Level 20- 44 Market Street','SYDNEY','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-19 07:24:57',0,NULL,3,1,2,1,NULL,'mathh29'),(9831,673723414018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','jennyzhang48','ms.jjzhang@gmail.com','Jenny Zhang','17A Crater Place','Rockingham','Western Australia','AUSTRALIA','6168','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-19 07:40:07',0,NULL,3,1,2,1,NULL,'jennyzhang48'),(9832,715867306002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 07:50:34',0,NULL,3,1,3,1,'RA117726510CN\rRA117726523CN ','saud-p\r2个小包'),(9833,788789116015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','yardleyf','mail@kbmagic.com','K Bennett','152 Yardley Fields Road','Stechford','Birmingham','UNITED KINGDOM','B33 8QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 09:10:17',0,NULL,3,1,3,1,'RA117726775CN\r ','yardleyf\r刘'),(9834,673927748001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','andriotis007','nikoskap07@yahoo.gr','NIKOLAOS KAPATAGIS','XORA','ANDROS','CYCLADES','GREECE','84500','2282024547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:11:42',0,NULL,3,1,2,1,NULL,'andriotis007\r庄'),(9835,715887221002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','max_monakhov','maxmonahov@gmail.com','MAxim Monakhov','1-stKrasnoselskiy per. 5-33','Moscow','Moscow','RUSSIAN FEDERATION','107140','+79296471522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:32:24',0,NULL,3,1,2,1,NULL,'max_monakhov'),(9836,715890859002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','201161r61820','norb1961@freenet.de','Norbert Rahn','Winkelstraße 14','Mitterteich','','GERMANY','95666','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 09:45:17',0,NULL,3,1,2,1,NULL,'201161r61820\r庄'),(9837,673583841018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','premierjack','jack@mu-zeek.com','jakris charoenphanich','4961 Santa Anita Ave<br>Ste K','TEMPLE CITY','CA','UNITED STATES','91780','(626) 255-4257','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-19 09:51:19',0,NULL,3,1,4,1,'YW866010962CN ','premierjack\r灯泡是110v\r庄'),(9838,673759341018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','mose17th','lkmoseley@optusnet.com.au','Lee Moseley','1 Baringa Rd<br>Croydon North','Melbourne','Victoria','AUSTRALIA','3136','0397799926','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-19 10:26:13',0,NULL,3,1,3,1,'RA117726792CN\r ','mose17th'),(9839,727347154017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',2,'AB1301',22.64,'photographyacc','winrecover','aussiesellers@gmail.com','Michaela Culham','21 The Fairway','Rowville','Victoria','AUSTRALIA','3178','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-19 11:07:20',0,NULL,3,1,2,1,NULL,'winrecover\r橡胶遮光罩 52mm   2\r橡胶遮光罩 77mm   2\r庄'),(9840,674782715001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','stelmi56','almast124@rambler.ru','Николай Ампилогов','ул. Ялтинская дом 8 кв. 22','Оренбург','Россия','RUSSIAN FEDERATION','460026','3532450173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 11:08:51',0,NULL,3,1,2,1,NULL,'stelmi56'),(9841,673784562018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',22,'photographyacc','mac0je','vojkanp@netspace.net.au','Vojkan Petronijevic','Pinnacle Print Group<br>288 Dundas St','Thornbury','Victoria','AUSTRALIA','3071','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-19 12:04:19',0,NULL,3,1,2,1,NULL,'mac0je'),(9842,714733640002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','dany0328','danyg1128@gmail.com','Daniel Gonzalez','12940 NW 107th Ct','Medley','FL','UNITED STATES','33178-3131','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 13:36:11',0,NULL,7,0,18,0,NULL,'dany0328'),(9843,674823795001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','granny6debby','dufusmegee@aol.com','Deborah Stephens','101 Penelope Ln','Blythewood','SC','UNITED STATES','29016-9650','(803) 691-8854','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 13:45:30',0,NULL,3,1,1,1,NULL,'granny6debby\r庄'),(9844,788888732015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','mrl-2k7','penege@gmail.com','Miguel Rodriguez Lago','Bulevar Jose Prat 29C 4B','MADRID','Madrid','SPAIN','28032','617816143','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-19 14:20:27',0,NULL,3,1,4,1,'YW866010973CN ','mrl-2k7\r'),(9845,674838600001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','momof3plusone','leslie_kovacs@yahoo.com','Leslie Kovacs','Kakas u. 7','Debrecen','','HUNGARY','4034','3652452010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 14:36:38',0,NULL,3,1,2,1,NULL,'momof3plusone'),(9846,715972043002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','solbebe','ttwin2000@hotmail.com','jade kim','2254 evans st','fullerton','CA','UNITED STATES','92833-2109','(213) 453-9638','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 14:54:26',0,NULL,3,1,1,1,NULL,'solbebe\r庄'),(9847,788907239015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','meltedwellies','mark@baschurch.com','Mark Davies','12 The Wheatlands<br>Baschurch','Shropshire','Shropshire','UNITED KINGDOM','SY42DL','01939260189','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 15:06:41',0,NULL,3,1,17,0,NULL,'meltedwellies'),(9848,788907240015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','meltedwellies','mark@baschurch.com','Mark Davies','12 The Wheatlands<br>Baschurch','Shropshire','Shropshire','UNITED KINGDOM','SY42DL','01939260189','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-19 15:06:42',0,NULL,3,1,4,1,'YW866010940CN ','meltedwellies\r英标\r45w 5500k 灯泡   2\r灯架  2m   2\r柔光箱 50-70cm 单灯头   2\r灯架包     1\r庄'),(9849,715978715002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','biki87','bikov.dima@gmail.com','Dima Bikov','Bar Kochva 57/8','Jerusalem','','ISRAEL','97892','+972542384399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 15:22:38',0,NULL,3,1,2,1,NULL,'biki87\r庄'),(9850,674871118001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','galiona','meggi-grey@yandex.ru','Galina Tcvetkova','ul Veresaeva  16 kv 69','Tula','','RUSSIAN FEDERATION','300034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 16:23:36',0,NULL,3,1,2,1,NULL,'galiona\r庄'),(9851,716003891002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','tuva47','tuvayanon@hotmail.com','Mr.Visanu    Tuvayanon','76 ,Soi Ladprao 62 ,Ladprao Road<br>,Wangthonglang  Sub-District ,Wangthonglang  District','Bangkok','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 16:33:11',0,NULL,3,1,11,1,NULL,'tuva47'),(9852,727457667017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','alvinandcc','alvin_huang@yahoo.com','Alvin Huang','8/72 George St<br>Norwood','Adelaide','South Australia','AUSTRALIA','5067','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-19 17:20:42',0,NULL,3,1,2,1,NULL,'alvinandcc\r庄'),(9853,674896952001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','oleksandrbilozerov','oleksandr.bilozerov@gmail.com','Oleksandr Bilozerov','Haperontie 6-8D 52','Jyvaskyla','Central Finland','FINLAND','40640','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 17:27:28',0,NULL,3,1,4,1,'YW866010984CN ','oleksandrbilozerov\r'),(9854,674898154001,110526979713,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','stephane_rp_91','slesmond@free.fr','Stéphane Lesmond','7, allée Cézanne','Les Ulis','Ile de France','FRANCE','91940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:33:44',0,NULL,3,1,2,1,NULL,'stephane_rp_91\r庄'),(9855,772793939016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 17:38:24',0,NULL,3,1,2,1,NULL,'eivindtafto\r庄'),(9856,674907706001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','ponha85','pontushamlin@gmail.com','Pontus Hamlin','Vaulenveien 39','Stavanger','Rogaland','NORWAY','4018','0046702993681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 17:54:14',0,NULL,3,1,2,1,NULL,'ponha85\r庄'),(9857,788991376015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','c.bland','chrisbland94@gmail.com','CHRIS BLAND','19 TANFIELD CLOSE ROYSTON','BARNSLEY','South Yorkshire','UNITED KINGDOM','S714JH','1226284951','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 18:09:29',0,NULL,3,1,2,1,NULL,'c.bland\r庄'),(9858,673910704018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',72,'photographyacc','vvictorix','bartush@mail.ru','VIKTOR BARTUSH','Kashirskoe shosse 55-6-1150','MOSCOW','','RUSSIAN FEDERATION','115211','7-905-510-2570','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-19 18:12:37',0,NULL,3,1,3,1,'RA117726850CN\r ','vvictorix\r一个是8个灯泡'),(9859,716051395002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','harry-0708','harry@hbc.nl','Harry van den Brink','Julianalaan 4','Naarden','','NETHERLANDS','1412 GS','(06) 51080387','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 18:27:00',0,NULL,3,0,3,1,'RA117726846CN\r ','harry-0708\r2XL（已入库）'),(9860,716044977002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','joao_guarapari','srjoao@terra.com.br','João Batista Assis de Oliveira','Rua Cachoeiro de Itapemirim, nº 243<br>Belo Horizonte (Meaipe)','Guarapari','Espirito Santo','BRAZIL','29208-230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 18:31:58',0,NULL,3,1,2,1,NULL,'joao_guarapari\r庄'),(9861,674930947001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 18:43:31',0,NULL,3,1,2,1,NULL,'dvdguychatter2\r庄'),(9862,674945983001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',113.97,'hermeshine','vitaliyukr','27poltava@mail.ru','Vitaliy Nazarenko','Borovikovskogo 9-85','Poltava','','UKRAINE','36023','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-19 19:16:48',0,NULL,3,1,5,1,'CP226268996CN ','vitaliyukr'),(9863,786174742015,250600322588,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','volaart.m','volaart.m@kpnplanet.nl','M Volaart','Lijterbesweg 50A','Middelharnis','','NETHERLANDS','3241BM','0187669417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-19 19:25:14',0,NULL,3,1,2,1,NULL,'volaart.m\r庄\rsb800 肥皂盒   2'),(9864,716077382002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','rakursd','rakurs02@mail.ru','Damir Mukhametov','ul. Bayazita Bikbaya, dom 19/1, kv. 67','Ufa','Bashkortostan','RUSSIAN FEDERATION','450099','79872541504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:30:03',0,NULL,3,1,2,1,NULL,'rakursd\r庄'),(9865,727529013017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','goranchagoran','gvelemir@gmail.com','Goran Velemir','Dobrovoljačka 32<br>Veternik','Novi Sad','Vojvodina/ Srbija','SERBIA','21203','021-820-282','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-19 19:40:52',0,NULL,3,1,2,1,NULL,'goranchagoran\r庄\r欧标'),(9866,674963107001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',3,'AA3308',14.85,'hermeshine','ciafquito','andres@ciaf-quito.com','Bolivar Vallejo','Alianza Francesa CIAF<br>Eloy Alfaro N32-468 y Rusia','Quito','Pichincha','ECUADOR','00000','(000) 000-0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:55:49',0,NULL,3,1,17,0,NULL,'ciafquito'),(9867,674961770001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',5,'AA3310',26.85,'hermeshine','ciafquito','andres@ciaf-quito.com','Bolivar Vallejo','Alianza Francesa CIAF<br>Eloy Alfaro N32-468 y Rusia','Quito','Pichincha','ECUADOR','00000','(000) 000-0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 19:55:50',0,NULL,3,1,3,1,'RA117723867CN ','ciafquito\r绿叶 CPL  52mm   3\r绿叶 CPL  58mm   5'),(9868,716095459002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mxxfm','maxxfm@gmail.com','Maksim Fomkin','Prionezhskaja, 27','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185002','+79317001037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 20:07:56',0,NULL,3,1,2,1,NULL,'mxxfm\r庄'),(9869,674969520001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 20:09:13',0,NULL,3,1,2,1,NULL,'nixette_nixette'),(9870,673890345018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','captainvilla','captainvilla@hotmail.com','Mi Casa / Juan M Villa','207 W Stillwell Ave','De Queen','AR','UNITED STATES','71832-2813','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-05-19 20:20:20',0,NULL,3,1,4,1,'YW866010951CN ','captainvilla\r美标灯泡是110v'),(9871,674975206001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','kitof40','kitof_2000@yahoo.fr','christophe LESAGE','4 allée de petit barrère','MONT-de-MARSAN','Aquitaine','FRANCE','40000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 20:22:04',0,NULL,3,1,2,1,NULL,'kitof40\r庄'),(9872,726637928017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','carolichan','carolichan@gmail.com','Carolina Ester Orellana Olivares','Av. Parque del Este #4333<br>Ciudad del Este','Puente Alto','Santiago','CHILE','8170429','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-19 20:51:09',0,NULL,3,1,3,1,'RA117726789CN\r ','carolichan'),(9873,716123055002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','stighr','stigr@online.no','Stig Harald Rasmussen','Galnaasen 39','Bodø','','NORWAY','8022','+4795732923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 21:09:08',0,NULL,3,1,2,1,NULL,'stighr\r庄'),(9874,789044938015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','westlondonbid','jkhot@hotmail.com','julian kowalewski','11 gransden road','london','London','UNITED KINGDOM','w12 9sa','07904234446','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 21:10:15',0,NULL,3,1,2,1,NULL,'westlondonbid\r庄'),(9875,789098740015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','timstopher','tim@stopher.co.uk','Stopher Associates','8 Hamilton Road','Newmarket','Suffolk','UNITED KINGDOM','CB8 0NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 21:20:32',0,NULL,3,1,2,1,NULL,'timstopher\r庄'),(9876,675012388001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','coinchantal','coinchantal@gmail.com','Chantal Groen in t wout','Putterstraat 5','Krimpen aan den ijssel','','NETHERLANDS','2922VM','0644375841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 22:07:51',0,NULL,3,1,2,1,NULL,'coinchantal\r庄'),(9877,772939409016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','johankwon','johankwon@hotmail.com','Sukha Kwon','65 Sheephouse Way','New Malden','Surrey','UNITED KINGDOM','KT3 5PF','02082417987','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-19 22:13:10',0,NULL,3,1,2,1,NULL,'johankwon\r庄'),(9878,716147688002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','videomathtutor','luis-ast@videomathtutor.com','Luis A. Ast','435 W Bowman St<br>Apt 2','Nogales','AZ','UNITED STATES','85621-2012','','NoPaymentFailure','CheckoutComplete','Other','2011-05-19 22:22:10',0,NULL,3,1,1,1,NULL,'videomathtutor\r庄'),(9879,674680111001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','evro9831','ifweirdisnormal@yahoo.com','Erin Triebold','2308 Tazewell St','Pekin','IL','UNITED STATES','61554-5350','(815) 257-2292','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 22:55:17',0,NULL,3,1,1,1,NULL,'evro9831\r庄'),(9880,675026891001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-19 23:01:41',0,NULL,3,1,2,1,NULL,'jabollo\r庄'),(9881,675036757001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','elkbayauction','joe@elkbayauction.com','jm Abad Enterprises','8458 Ardelle Way','Elk Grove','CA','UNITED STATES','95624-4100','(916) 226-6474','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 23:46:32',0,NULL,3,1,17,0,NULL,'elkbayauction'),(9882,716170573002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','elkbayauction','joe@elkbayauction.com','jm Abad Enterprises','8458 Ardelle Way','Elk Grove','CA','UNITED STATES','95624-4100','(916) 226-6474','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-19 23:54:13',0,NULL,3,1,1,1,' ','elkbayauction\rEW-73B   1\rET-65B   1'),(9883,675040979001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','dtrain041','dtrain41@netspace.net.au','Dale Gaylard','45 Church St','Colac','Victoria','AUSTRALIA','3250','0409314166','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 00:04:51',0,NULL,3,1,3,1,'RA117726761CN\r ','dtrain041\r刘'),(9884,716173139002,120439964418,'MACRO CLOSE UP Filter Lens kit +2 +3 +4 +8 40d d80 d90',1,'AKT012',23.6,'hermeshine','elkbayauction','joe@elkbayauction.com','jm Abad Enterprises','8458 Ardelle Way','Elk Grove','CA','UNITED STATES','95624-4100','(916) 226-6474','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 00:05:06',0,NULL,5,0,18,0,' ','elkbayauction\r\r67mm 近摄镜 +2/+4   各1块(带原包装) \r67mm ND4/ND8         各1块(带原包装) '),(9885,675042133001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','declic22','cotedenis@cablevision.qc.ca','Denis Cote','103 rue Morissette','Val-d\'Or','QC','CANADA','J9P6Z3','(819) 825-4949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 00:09:19',0,NULL,3,1,2,1,NULL,'declic22\r庄'),(9886,674044451018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','lanceburger','lance.dp@live.com','Lance Del Prado','115<br>Mort Street','Blacktown','New South Wales','AUSTRALIA','2148','0288074387','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-20 00:21:22',0,NULL,3,1,4,1,'YW866010936CN ','lanceburger\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子\r刘\r0630去信--系统显示已收到'),(9887,0,110683184742,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',0.99,'hermeshine','jendamsel','jennthelittlemonster@gmail.com','Jennifer Mercado','1459 Amsterdam Ave<br>Apt 5A','new york','NY','UNITED STATES','10027-7445','(347) 557-5329','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 01:03:52',0,NULL,3,1,1,1,NULL,'jendamsel\r庄'),(9888,716188563002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','jason1971666','jason1@bigpond.net.au','jason foster','12a brier court','golden beach','Queensland','AUSTRALIA','4551','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 01:10:59',0,NULL,3,1,2,1,NULL,'jason1971666\r庄'),(9889,675064018001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','iinspirationshopping','iinspiration@msn.com','Pichaya Punyakhetpimook','310 s 29th Street Penbrook','Harrisburg','PA','UNITED STATES','17103','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 01:54:58',0,NULL,3,1,1,1,NULL,'iinspirationshopping\r环-换成77mm'),(9890,727661598017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','ian_ranson','ianranson@live.com.au','Ian Ranson','16/540 North Road','Ormond','Victoria','AUSTRALIA','3204','0409790078','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-20 02:28:44',0,NULL,3,1,2,1,NULL,'ian_ranson\r52mm uv   1\r58mm uv   1'),(9891,715947995002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','yulby','rob@robertpaul.com.au','Robert Paul','PO Box 469','Charlestown','New South Wales','AUSTRALIA','2290','61249291417','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 03:34:33',0,NULL,3,1,3,1,'RA117723014CN ','yulby'),(9892,727676961017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','ian_ranson','ianranson@live.com.au','Ian Ranson','16/540 North Road','Ormond','Victoria','AUSTRALIA','3204','0409790078','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-20 03:41:16',0,NULL,3,1,17,0,NULL,'ian_ranson'),(9893,675089679001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 03:57:46',0,NULL,3,1,17,0,NULL,'aaivanov'),(9894,716225413002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 03:58:48',0,NULL,3,1,17,0,NULL,'aaivanov'),(9895,716225669002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 03:59:53',0,NULL,3,1,17,0,' ','aaivanov'),(9896,675090264001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 04:00:52',0,NULL,3,1,3,1,'RA117723102CN','aaivanov\r3片装的滤镜袋   1\r天涯方形滤镜  ND2/ND4/ND8\r58mm 转接环   1\r77mm 转接环   1\r广角托架  1\r普通托架  2\r'),(9897,675087110001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','rlanfk88','jocoona@gmail.com','Seok Youn Jo','3003 olivet st<br>Brentwood park apartment 510A','Halifax','NS','CANADA','B3L 4A1','(902) 209-7180','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 04:26:42',0,NULL,3,1,3,1,'RA117723028CN ','rlanfk88'),(9898,675098050001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','armenak*84','armenak84@mail.ru','Armenak Baghdasaryan','David Beki str. 90','Yerevan','Erebuni','ARMENIA','0008','(374)91010024','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 04:50:17',0,NULL,3,1,3,1,'RA117723093CN ','armenak*84'),(9899,727710139017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','nthbeach','pbubalo@hotmail.com','Predrag Bubalo','6 burchmore road Manly vale','Sydney','New South Wales','AUSTRALIA','2093','6120421341400','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-20 06:42:54',0,NULL,3,1,2,1,NULL,'nthbeach');
INSERT INTO `hmsh_ebay_transaction` VALUES (9900,716258291002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','tuchkay','tuchkay@hotmail.com','phumiphat tongkhambai','12 soi 2 sari 2 sari4 rd. (ram 24)<br>huamark','bangkapi','bangkok','THAILAND','10250','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 07:12:00',0,NULL,3,1,3,1,'RA117723080CN ','tuchkay'),(9901,675126996001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','brch321','brlekd@gmail.com','Ivana Ostojić Brlek','Starčevićeva 7','Križevci','Križevci','CROATIA','48260','00385915640091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 07:33:11',0,NULL,3,1,2,1,' ','brch321'),(9902,727721279017,270750677827,'New Camera shoulder bag D1 for Nikon D5000 D7000 D80',1,'AO0032',19.99,'photographyacc','atalyansky57','redsqr@bigpond.com.au','Aleksey Talyansky','6B Forster crt.<br>East Bentleigh','Melbourne','Victoria','AUSTRALIA','3165','0395703646','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-20 07:37:27',0,NULL,3,1,3,1,'RA117723062CN ','atalyansky57'),(9903,674368696001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','ashabella_2007','bellaskyangel@gmail.com','Jason Blaiklock','Park House<br>Level3, 295-301 Pitt Street','SYDNEY','New South Wales','AUSTRALIA','2000','0413509543','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 08:17:27',0,NULL,3,1,17,0,' ','ashabella_2007'),(9904,675136764001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','ashabella_2007','bellaskyangel@gmail.com','Jason Blaiklock','Park House<br>Level3, 295-301 Pitt Street','SYDNEY','New South Wales','AUSTRALIA','2000','0413509543','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 08:20:33',0,NULL,3,1,3,1,'RA117723337CN ','ashabella_2007\r伟峰 717 快装板    2'),(9905,789268214015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','aurius_vos','aurius.vos@gmail.com','Aurelijus Krikščiukas','Gytarių st. 4-6','Šiauliai','','LITHUANIA','LT-78363','+37062072628','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 08:23:55',0,NULL,3,1,17,0,NULL,'aurius_vos'),(9906,789265901015,250599910333,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','aurius_vos','aurius.vos@gmail.com','Aurelijus Krikščiukas','Gytarių st. 4-6','Šiauliai','','LITHUANIA','LT-78363','+37062072628','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 08:23:56',0,NULL,3,1,2,1,NULL,'aurius_vos\rlenspen   2\r庄'),(9907,789288459015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','dave9818','davebozy@sky.com','Dave Bozward','6, Westminster road, Ronkswood','Worcester','Worcestershire','UNITED KINGDOM','WR5 1PA','01905350259','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 09:10:00',0,NULL,3,1,2,1,NULL,'dave9818'),(9908,674169806018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',77,'photographyacc','jharbonn','jharbonn@free.fr','Jacques Harbonn','100 avenue Gambetta','Paris','Île-de-France','FRANCE','75020','01.40.30.30.77','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-20 10:06:16',0,NULL,3,1,4,1,'YW866011021CN ','jharbonn\r反光板 110cm 5合1    1\r2m 灯架   1\r反光板支架   1\r一票两件\rreflector holder  $25'),(9909,716295650002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','ness3601','ness3601@optusnet.com.au','Vanessa ADAMS','18 Stephens Avenue','Glendale','New South Wales','AUSTRALIA','2285','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 10:20:28',0,NULL,3,1,4,1,'YW866011010CN ','ness3601\rlighting kit $26'),(9910,716307183002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','shuricat','poyanov@gmail.com','Alexander Poyanov','pr. Solidarnosti, d. 10, korp. 3, kv. 18','St. Petersburg','RU','RUSSIAN FEDERATION','193312','+7 921 1888935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 11:01:48',0,NULL,3,1,2,1,NULL,'shuricat\r庄'),(9911,675176789001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','altau1972','tauman08@gmail.com','Александр Тимофеев','Санкт-Петербург,Гражданский пр. дом 130/1 кв. 432','Санкт-Петербург','Санкт-Петербург','RUSSIAN FEDERATION','195267','9533433983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 11:20:41',0,NULL,3,1,2,1,NULL,'altau1972\r庄'),(9912,675190316001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','simongrinberg','simiongrinberg@bezeqint.net','Simon Grinberg','Herzel 208A , app10','Rehovot','','ISRAEL','76270','+972507730017','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 12:14:43',0,NULL,3,1,3,1,'RA117723116CN ','simongrinberg'),(9913,716329218002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',5,'AA1302',12.2,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','(5521)2268-7693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:26:49',0,NULL,3,1,17,0,NULL,'mariomarques.com.br'),(9914,716329949002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',5,'AA1303',12.2,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','(5521)2268-7693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:29:25',0,NULL,3,1,17,0,NULL,'mariomarques.com.br'),(9915,789349966015,250692240254,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','pimpinrimssaab','fa230828@skynet.be','frank schoofs','spoorwegstraat 74','Berchem','','BELGIUM','2600','32495215455','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 12:30:22',0,NULL,3,1,2,1,NULL,'pimpinrimssaab\r庄'),(9916,716331141002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','sefco','sefco_m@orangemail.sk','Milan Sefcik','A. Sladkovica 19','Vojcice','Slovakia','SLOVAK REPUBLIC','07622','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:41:33',0,NULL,3,1,2,1,NULL,'sefco\r庄'),(9917,675199502001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',5,'AC1301',31.2,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','(5521)2268-7693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:48:32',0,NULL,3,1,3,1,'RA117723500CN ','mariomarques.com.br\rCANON 镜头盖  67mm   5\rCANON 镜头盖  72mm   5\r中号内胆包 无字    5\r\r'),(9918,716335463002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','mangum666','taponier@free.fr','Jean-Rémi Taponier','100 avenue Gambetta','Paris','Ile-de-France','FRANCE','75020','0660729986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:51:53',0,NULL,3,1,17,0,NULL,'mangum666'),(9919,675200100001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','mangum666','taponier@free.fr','Jean-Rémi Taponier','100 avenue Gambetta','Paris','Ile-de-France','FRANCE','75020','0660729986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 12:51:52',0,NULL,3,1,17,0,NULL,'mangum666'),(9920,675200447001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','mangum666','taponier@free.fr','Jean-Rémi Taponier','100 avenue Gambetta','Paris','Ile-de-France','FRANCE','75020','0660729986','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 12:51:52',0,NULL,3,1,2,1,' ','mangum666\r爵影红外 canon    1\r爵影快门线C1     1\rcanon 电子触点    1\r庄'),(9921,716338515002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 13:00:10',0,NULL,3,1,17,0,NULL,'aaivanov'),(9922,785733057015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','bladerunnervoidcomp2019','ramajayjay_69@yahoo.co.uk','Jason Crick','107 Kingsly Avenue','Kettering','Northamptonshire','UNITED KINGDOM','nn169es','01536515938','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 13:00:12',0,NULL,7,0,18,1,NULL,'bladerunnervoidcomp2019'),(9923,716338893002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 13:01:39',0,NULL,3,1,2,1,NULL,'aaivanov\r天涯 方形 渐变灰   1\r天涯   cpl        1'),(9924,675210850001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','triciasboutique','t.chavez@hotmail.com','Tricia Chavez','25 Craft Ave','Glen Cove','NY','UNITED STATES','11542-3508','(516) 629-6369','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 13:38:48',0,NULL,3,1,3,1,'RA117738274CN\r ','triciasboutique\r1.6x2.1  背景布   3\r白 黑  粉\r0.914\r0630-0701回信说会联系邮局.终止.'),(9925,716354854002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','neurofunker','hoper69@mail.ru','Oleg Kalinin','Krasina street, 53-144','Tver\'','Tver\' region','RUSSIAN FEDERATION','170041','7 920 694-7551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 13:57:07',0,NULL,3,1,2,1,NULL,'neurofunker\r庄'),(9926,789379126015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','ggrbld','gabri.garibaldi@virgilio.it','Gabriele Garibaldi','Via della rosa, 37','Viareggio','LU','ITALY','55049','0584-942292','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 13:57:52',0,NULL,3,1,2,1,NULL,'ggrbld\r庄'),(9927,675222939001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',38.88,'hermeshine','barkerbusinessmachines','ginabarker@cox.net','Barker Business Machines','1501 Breckenridge Dr','VAN BUREN','AR','UNITED STATES','72956-9026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-20 14:08:32',0,NULL,3,1,1,1,NULL,'barkerbusinessmachines'),(9928,675150011001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 14:49:54',0,NULL,3,1,3,1,'RA117723195CN ','jordano-jordano2000'),(9929,716371195002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','xykd11','xykd11@hotmail.com','Harley   Frederick','1339 W Shawtown Rd','Troy','TN','UNITED STATES','38260','(731) 885-7558','NoPaymentFailure','CheckoutComplete','Other','2011-05-20 14:53:30',0,NULL,3,0,1,1,NULL,'xykd11\rL   （已减库）'),(9930,773216284016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',2,'AKT028',15.98,'hutongstore','champmira','gordonyoung54@hotmail.com','Gordon Young','23/4 Wardieburn Road','Edinburgh','Midlothian','UNITED KINGDOM','EH5 1LX','01314765613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 15:03:26',0,NULL,3,0,3,1,'RA117723399CN ','champmira（已入库）\r渐变灰    1\r渐变蓝   1\r62mm 接口环   1\r77mm 接口环    1\r托架    2'),(9931,716381789002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','lexdetva','alexander.filo@post.sk','Alexander Filo','Obrancov mieru 6','Detva','','SLOVAK REPUBLIC','962 12','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 15:24:56',0,NULL,3,1,3,1,'RA117723178CN ','lexdetva'),(9932,675247587001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','baffosardi','baffosardi@tin.it','Avv. Gianluca Sardi','Via delle Cateratte 90 int. 6','Livorno','LI','ITALY','57122','+393392456953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:33:41',0,NULL,3,1,2,1,NULL,'baffosardi\r庄'),(9933,716392821002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','japalcab','javi.pal.cab@gmail.com','javier palacios caballero','calle campoamor, 35-41, 1º1ª<br>08940, cornella de llobregat','barcelona','Cataluña','SPAIN','08940','626915491','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 15:57:00',0,NULL,3,1,3,1,'RA117723249CN ','japalcab'),(9934,674571655001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',48.87,'hermeshine','martinkristal2010','martinkristal@gmail.com','Martin Kristal','11 After St.','Tel Aviv','Tel Aviv','ISRAEL','69362','972-3-6990171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 15:59:20',0,NULL,3,1,17,1,NULL,'martinkristal2010\r'),(9935,789434556015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',1,'AA3309',3.38,'hutongstore','vipergts252','pawelcieslik78@gmail.com','Pawel Cieslik','86 leixlip park','leixlip','Kildare','IRELAND','1','35385113171','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 16:08:36',0,NULL,3,1,2,1,NULL,'vipergts252\r庄'),(9936,716397428002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bsclark','brian@trinityfellowship.info','Brian Clark','806 Andrew Pl','Lowell','AR','UNITED STATES','72745-9318','(479) 770-5252','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 16:24:04',0,NULL,3,1,1,1,NULL,'bsclark\r庄'),(9937,675271660001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','gimapereira','gimapere@gmail.com','Giovanni Marques Pereira','Rua Gustavo Xavier Capanea, 143<br>Centro','Pitangui','Minas Gerais','BRAZIL','35650000','(37) 3271-2832','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-20 16:43:08',0,NULL,3,1,3,1,'RA117723354CN ','gimapereira'),(9938,789466390015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','green_groover','ash_eb_736sy2@greenbliss.co.uk','Ashley Westcar','1 Dickens Court','Biggleswade','Bedfordshire','UNITED KINGDOM','SG18 8QE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 17:18:19',0,NULL,3,1,2,1,NULL,'green_groover\r庄'),(9939,789477562015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','alberttheo','albert.teo@hotmail.com','Albert Teo','Palestra, 11th floor, Zone 11Y4<br>197 Blackfriars Road','London','London','UNITED KINGDOM','SE1 8NJ','02030541778','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 17:42:10',0,NULL,3,1,2,1,NULL,'alberttheo\r庄'),(9940,716431470002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','girvincn','girvincn@gmail.com','Cass Girvin','800 Eglinton Ln','Charlottesville','VA','UNITED STATES','22903','(434) 996-2828','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 17:50:29',0,NULL,3,1,1,1,NULL,'girvincn\r庄'),(9941,727911360017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','mofitor','manpher@gmail.com','FERNANDO BASTARDO','LEGARGAIN, 13 -3º IZDA','ARRASATE','País Vasco','SPAIN','20500','943794978','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-20 18:03:19',0,NULL,3,1,17,0,NULL,'mofitor'),(9942,674323745018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','mofitor','manpher@gmail.com','FERNANDO BASTARDO','LEGARGAIN, 13 -3º IZDA','ARRASATE','País Vasco','SPAIN','20500','943794978','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-20 18:06:55',0,NULL,3,1,4,1,'YW866011006CN ','mofitor\r2m灯架+云台 +柔光伞  1\r110cm 5in1 反光板   1\r一票两件  \rreflector $20'),(9943,716449285002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','dher8553','toniga@gmail.com','David Herguedas Cuadrado','Crta. de Liria, nº 57 pta. 1','Burjassot','Comunidad Valenciana','SPAIN','46100','695831488','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 18:25:55',0,NULL,3,1,4,1,'YW866011043CN ','dher8553\rtripod $16'),(9944,716449304002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mariol1707','admin@milespowerpoints.com','Mario López Vélez','La Cueva<br>Bº Villasante Nº23','Castañeda','Cantabria','SPAIN','39650','695415205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 18:26:47',0,NULL,3,1,2,1,NULL,'mariol1707\r庄'),(9945,773311128016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','trevor4417','trevdry@googlemail.com','Trevor Dry','Premier Tyres<br>29 Ladywell Rd Tunstall','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST65DE','01782767728','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-20 18:32:50',0,NULL,3,1,2,1,NULL,'trevor4417\r庄'),(9946,716459385002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','sierra_j','sierra5369@yahoo.com','James Sierra','7341 Sandalwood Dr<br>Apt 203','Tinley Park','IL','UNITED STATES','60477-3748','(708) 675-9387','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 18:51:28',0,NULL,3,1,1,1,NULL,'sierra_j\r庄'),(9947,716463694002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','nivas1958','nivas_58@hotmail.com','nick Vasilakis','moyson 57','iraklion','','GREECE','713 07','6983510646','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 19:00:49',0,NULL,3,1,2,1,NULL,'nivas1958\r帮我看一下，如果是最后一块了，提醒我一下\r发了这个还有2个.\r庄'),(9948,675348973001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','mindjakk','jond@mindjakk.com','Joanthan Defibaugh','1622 Lee St','Parkersburg','WV','UNITED STATES','26101-3652','(304) 422-7364','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 19:55:31',0,NULL,3,1,1,1,NULL,'mindjakk\r庄'),(9949,675350843001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','mike_fosh','mikelfosh@gmail.com','Mikhail Levin','25 claire pass','saratoga springs','NY','UNITED STATES','12866-7505','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 19:59:59',0,NULL,3,1,1,1,NULL,'mike_fosh'),(9950,716501215002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','alibar17','alebar17@sbcglobal.net','ALEX TAMAYO','3191 E Del Mar Blvd','PASADENA','CA','UNITED STATES','91107-4650','(626) 487-1021','NoPaymentFailure','CheckoutComplete','Other','2011-05-20 20:35:00',0,NULL,3,0,1,1,NULL,'alibar17\rXXL   (已入库）\r庄'),(9951,773405981016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','schiller_dk','ms@definitivt.dk','Mark Schiller','Vosborgvej 30','Kastrup','','DENMARK','2770','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-20 21:59:07',0,NULL,3,1,3,1,'RA117723439CN ','schiller_dk\r摄影背心 夏  XL'),(9952,727594416017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',2,'AKT039',511,'photographyacc','alshaaily','solvaij_sound3@hotmail.com','Khalid Al Shaaily','P.O.Box 688 Postal Code 121 ( Al seeb )<br>Road 3505 Building 407 ( Al Khoud )','Muscat','Muscat','OMAN','121','00968 99045394','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-20 22:13:52',0,NULL,3,1,8,1,'CP226268917CN ','alshaaily  （已入库）\r2m灯架   6\r斜臂   2\r50-70棚  欧标   2\r115w 220v    2\r4灯头棚   欧标   4\r45w 灯泡 16\r包  4\r'),(9953,674427261018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','hanatan99','hanatan@gmail.com','Harry Tan','15 Foulds Court','Berwick','Victoria','AUSTRALIA','3806','61417877899','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-20 22:27:22',0,NULL,3,1,2,1,NULL,'hanatan99\r庄'),(9954,716541128002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','homesik','homesik@yahoo.com','Jon Thiessen','16316 Prairie Farm Cir','Parker','CO','UNITED STATES','80134-3050','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-20 22:38:09',0,NULL,3,1,1,1,NULL,'homesik\r庄'),(9955,675412787001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','procrastination_alley','sweetie6220@hotmail.com','Brandee Dent','RR#1 8349 6th Line','Utopia','ON','CANADA','L0M 1T0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-20 23:27:56',0,NULL,3,1,2,1,NULL,'procrastination_alley'),(9956,728035880017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','kobi3473','kobi1973@bezeqint.net','kobi el','zfanya<br>3','gedera','','ISRAEL','70700','+972505367112','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-20 23:49:37',0,NULL,3,1,2,1,NULL,'kobi3473\r庄'),(9957,716559874002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','luisoliver','luisphoto2@yahoo.es','Luis Oliver Fabrega','Ronda Universitat  9,<br>planta 1','Barcelona','Cataluña','SPAIN','08007','647486334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 00:06:04',0,NULL,3,1,2,1,NULL,'luisoliver\r庄'),(9958,675433210001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','15067553123','arlenewinsor@nf.sympatico.ca','3Arlene Winsor','163 main st.<br>P.O.Box 123','St. Alban\'s','NL','CANADA','A0H 2E0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 01:18:43',0,NULL,3,1,5,1,'CP227020300CN ','15067553123'),(9959,789654455015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','mazrientes','maz121999@yahoo.com','Mazaharhusein Karim','126 Tooting Bec Road<br>Tooting','London','London','UNITED KINGDOM','SW17 8BQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 01:20:14',0,NULL,3,1,2,1,NULL,'mazrientes\r庄'),(9960,716582484002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ar_asd','daleinsular@gmail.com','Álvaro J Román Castillo','Duble Almeyda 1798-503, Nunoa','Santiago','','CHILE','7750029','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 01:59:37',0,NULL,3,1,3,1,'RA117723371CN ','ar_asd\r6662A    1\rRS-N1    1\r看看是否2kg以下'),(9961,675444616001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','ar_asd','daleinsular@gmail.com','Álvaro J Román Castillo','Duble Almeyda 1798-503, Nunoa','Santiago','','CHILE','7750029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 02:19:06',0,NULL,3,1,17,0,NULL,'ar_asd'),(9962,675449958001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','jasoncwt','jasonchuo@hotmail.com','Jason Wei Ta Chuo','1531, LORONG STUTONG 20A','KUCHING','SARAWAK','MALAYSIA','93350','0168656881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 02:49:46',0,NULL,3,1,17,0,NULL,'jasoncwt'),(9963,716591425002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','jasoncwt','jasonchuo@hotmail.com','Jason Wei Ta Chuo','1531, LORONG STUTONG 20A','KUCHING','SARAWAK','MALAYSIA','93350','0168656881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 02:49:47',0,NULL,3,1,2,1,NULL,'jasoncwt\r爵影红外 5 in 1    1\r肩带 无字    1\r庄\r'),(9964,674506667018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','peter_g2','pgphotos@hotmail.com','Peter Gordyn','25 westmoreland st','Geelong','Victoria','AUSTRALIA','3219','030438326198','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-21 05:16:53',0,NULL,3,1,3,1,'RA117723270CN ','peter_g2'),(9965,716623612002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','yason58','andron58@gmail.com','Andrey Ryzhenkov','Zarechnaya<br>8-65','Zarechnyi city','Penza region','RUSSIAN FEDERATION','442964','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 06:13:37',0,NULL,3,1,3,1,'RA117723408CN ','yason58\rM'),(9966,722132894017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','califloss','califloss@yahoo.com','NGA TRAN','1800 N Bristol St<br># C-601','SANTA ANA','CA','UNITED STATES','92706-3336','(714) 366-8583','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-21 06:27:24',0,NULL,3,1,1,1,NULL,'califloss\r庄'),(9967,716626162002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','roomeri','jtc.kuvaamo@gmail.com','Jari Tuomi','Kestalonkuja 6<br>Salo','24910 Halikko as','Finland','FINLAND','24910','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 06:28:35',0,NULL,3,1,2,1,NULL,'roomeri\r庄'),(9968,728119858017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',13.8,'photographyacc','kayleigh_june','kayleighj@exemail.com.au','Kayleigh Olds','5 Habeda Ave','Horsley','New South Wales','AUSTRALIA','2530','0242613680','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-21 07:16:55',0,NULL,3,1,2,1,NULL,'kayleigh_june\r庄'),(9969,675494639001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','algoughawardwinningphotographerwww.visionmasters.net','agough@telus.net','Alan Gough','36901 Cook St<br>Ste 8-828','Palm Desert','CA','UNITED STATES','92211-6066','(604) 926-7230','NoPaymentFailure','CheckoutComplete','Other','2011-05-21 07:32:41',0,NULL,3,1,1,1,NULL,'algoughawardwinningphotographerwww.visionmasters.net\r庄'),(9970,728138619017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','jacob0247','coreyandapril@bigpond.com','april','7 longdon close','south penrith','New South Wales','AUSTRALIA','2750','0247361254','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-21 08:40:00',0,NULL,3,1,2,1,NULL,'jacob0247\r庄'),(9971,674549799018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','waynecant','waynecantphotography@hotmail.com','Wayne Cant','38 Ashmore Close<br>Marsden','Brisbane','Queensland','AUSTRALIA','4132','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-21 09:01:47',0,NULL,3,1,3,1,'RA117723283CN ','waynecant'),(9972,675547317001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','n3o','aerogrits@comcast.net','Terry Hall','106 Elmer Street','Gadsden','AL','UNITED STATES','35901','','NoPaymentFailure','CheckoutComplete','Other','2011-05-21 11:14:43',0,NULL,3,0,1,1,NULL,'n3o\rXXL (已减库）\r庄'),(9973,674590650018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','dingolingo99','peterc59@gmail.com','Peter Cameron','191 Ryde Road','Gladesville','New South Wales','AUSTRALIA','2111','61299224278','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-21 11:37:14',0,NULL,3,1,2,1,NULL,'dingolingo99\r庄'),(9974,716702113002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','alyssajaynee','alyssapanikkk@hotmail.com','Alyssa-Jayne Galea','14 Hinkler Avenue<br>Macleod','Melbourne','Victoria','AUSTRALIA','3085','0394447809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 12:12:17',0,NULL,3,1,2,1,NULL,'alyssajaynee\r庄'),(9975,675562221001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','martinevdgoot','mvandergoot@hotmail.com','martine katalin van der goot','Kazernestraat 16-3','Amsterdam Noord Holland','','NETHERLANDS','1018 CC','+31203313811','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 12:13:20',0,NULL,3,1,3,1,'RA117723218CN ','martinevdgoot'),(9976,716703652002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',2,'AA1309',5,'hermeshine','winuser66','srjzone@online.no','Svein-Roger Jensen','kong olavs vei 292','Sørvågen','Norway','NORWAY','8392','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 12:16:00',0,NULL,3,1,2,1,NULL,'winuser66\r庄'),(9977,716728315002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',3,'AO0005',38.4,'hermeshine','fuzzbabies','furbabies1@hotmail.com','Bianca Lawrence','871 Chambers Flat Rd','Chambers Flat','Queensland','AUSTRALIA','4133','','PayPalPaymentInProcess','CheckoutComplete','AU_Other','0000-00-00 00:00:00',0,NULL,3,0,3,1,'RA117723221CN ','fuzzbabies\r灰色 ， 蓝色， 粉色'),(9978,674612709018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',12.8,'photographyacc','neoblytz','has2bna@gmail.com','Igor Solomon','187 Holland Rd','East Burwood','Victoria','AUSTRALIA','3151','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-21 14:53:58',0,NULL,3,1,2,1,NULL,'neoblytz\r52mm cpl  绿叶   1\r58mm cpl  绿叶   1\r庄'),(9979,773685672016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'',5.9,'hutongstore','pavlitovelpablo','pavlitovelpablo2@gmail.com','Pawel Koscik','14 Laurel Avenue','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 2RY','01623635171','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 15:18:37',0,NULL,3,1,2,1,' ','pavlitovelpablo'),(9980,716762940002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','simo.41','simoneborile@hotmail.it','Handtmann srl Simone Borile','via Tofane 23','villafranca di verona','VR','ITALY','37069','3474361032','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 15:27:19',0,NULL,3,1,3,1,'RA117723181CN ','simo.41\rlighting kit $15'),(9981,674665627018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','venus_la_vey','venus_la_vey@hotmail.com','Charlotte Verity','2 Fairhope Avenue','Salford','Greater Manchester','UNITED KINGDOM','M6 8AU','01612887504','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-21 15:32:28',0,NULL,3,1,4,1,'YW866011032CN ','venus_la_vey\r英标'),(9982,675538343001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',4,'AO0006',43.96,'hermeshine','bacoretajoseluis','jlyep@hotmail.com','JOSÉ LUIS YEPES ALARCÓN','C/ OESTE, 4 URB. LOS VIENTOS','MOLINA DE SEGURA','Murcia','SPAIN','30500','968641656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 16:00:20',0,NULL,3,1,3,1,'RA117723235CN ','bacoretajoseluis\r1.6x2.1 背景布  4\r白 黑 浅蓝  灰'),(9983,672278819001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',5.2,'hermeshine','lenstalensta','lensta@yandex.ru','STANISLAV KOCHERGIN','str.OBORONIY 43 арр. 27','ROSTOV-ON-DON','ROSTOV REGION','RUSSIAN FEDERATION','344082','(918)523-7725','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 16:20:37',0,NULL,3,1,2,1,NULL,'lenstalensta\r52mm nikon 镜头盖   2\r庄'),(9984,674703118018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','efesuxp1984','efesuxp@gmail.com','Ian Abdilla','Yahweh-Jire<br>Triq Merhba','Fgura','Fgura','MALTA','FGR1833','+35621806643','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-21 17:10:48',0,NULL,3,1,2,1,NULL,'efesuxp1984\r庄'),(9985,716785304002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','hefrocoopa','strasergio@hotmail.it','SERGIO STRAZZULLA','via Carlo Cattaneo<br>17','Viterbo','VT','ITALY','01100','3288283612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 17:24:26',0,NULL,3,1,17,0,NULL,'hefrocoopa'),(9986,531842876003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','hefrocoopa','strasergio@hotmail.it','SERGIO STRAZZULLA','via Carlo Cattaneo<br>17','Viterbo','VT','ITALY','01100','3288283612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 17:24:26',0,NULL,3,1,17,0,NULL,'hefrocoopa'),(9987,675650677001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','hefrocoopa','strasergio@hotmail.it','SERGIO STRAZZULLA','via Carlo Cattaneo<br>17','Viterbo','VT','ITALY','01100','3288283612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 17:24:27',0,NULL,3,1,17,0,NULL,'hefrocoopa'),(9988,716790420002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','hefrocoopa','strasergio@hotmail.it','SERGIO STRAZZULLA','via Carlo Cattaneo<br>17','Viterbo','VT','ITALY','01100','3288283612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 17:24:27',0,NULL,3,1,3,1,'RA117723385CN ','hefrocoopa\rHB-7 花瓣    1\r爵影红外 nikon   1\r反光板  80cm 5合1  1\r柔光伞    1\rreflector  $15'),(9989,789978445015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','pacharltonphoto','pacharlton@hotmail.co.uk','paul charlton','18 jedburgh street','middlesbrough','Cleveland','UNITED KINGDOM','ts12hx','01642244765','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-21 18:23:07',0,NULL,3,0,2,1,NULL,'pacharltonphoto\r1.6x2.1  黑色'),(9990,674876799001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','+7(903)4538945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 19:32:01',0,NULL,3,1,3,1,'RA117723204CN ','anato01'),(9991,716868662002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','lucaslapadias','lucaslapa@msn.com','Carlos Alberto Dias','Rua Pedro Coqueiro Filho, 176, Nobre.','Brumado','Bahia','BRAZIL','46100-000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-21 19:52:47',0,NULL,3,1,5,1,'CP226268982CN ','lucaslapadias\r欧标\r看看在2kg以上还是以下，如果不到2kg就小包挂号'),(9992,790031087015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','stribrnej','kopacka-pavel@seznam.cz','pavel kopacka','straznicka 24','Plzen','Plzen','CZECH REPUBLIC','32300','00420608877137','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-21 20:04:28',0,NULL,3,1,2,1,NULL,'stribrnej\r庄'),(9993,716896669002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',9.8,'hermeshine','hussainkolya','nabilkolya@gmail.com','nabil sheik','po box 288, Bin Omran Group<br>Salam Tower, 6th Floor. West Bay','Doha','Doha','QATAR','288','(009) 746-6139 ext.: 258','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 21:04:52',0,NULL,3,1,17,0,NULL,'hussainkolya'),(9994,716896601002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','hussainkolya','nabilkolya@gmail.com','nabil sheik','po box 288, Bin Omran Group<br>Salam Tower, 6th Floor. West Bay','Doha','Doha','QATAR','288','(009) 746-6139 ext.: 258','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-21 21:04:53',0,NULL,3,1,3,1,'RA117723425CN ','hussainkolya\rCANON 镜头盖  58mm   4\r机身盖/镜头后盖  Canon   1'),(9995,790072080015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','fotoequador','deangelistata@libero.it','salvatore de angelis','vico cacace n.6','meta di sorrento','NA','ITALY','80062','0815322210','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-21 21:33:02',0,NULL,3,1,3,1,'RA117723120CN ','fotoequador\rshoulder support  $15'),(9996,675789749001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','gradyb2','cranebinder@gmail.com','Grady Bowers/CRANE','9400 Watson Rd<br>Rear','Saint Louis','MO','UNITED STATES','63126-1514','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','gradyb2\r'),(9997,716937833002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','bholsey824','brannu824@yahoo.com','Brandon Holsey','505 W Baseline Rd<br>Apt 2017','Tempe','AZ','UNITED STATES','85283-5301','(330) 475-5381','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-21 23:27:04',0,NULL,3,1,1,1,NULL,'bholsey824\r庄'),(9998,716937682002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','rtemmett','temmett0104@aol.com','Tracey Emmett','12406 W Monroe St','Avondale','AZ','UNITED STATES','85323-8004','(602) 410-9695','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-21 23:28:10',0,NULL,3,1,1,1,NULL,'rtemmett\r庄'),(9999,674848099018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','edgarnejip','jonwendellp@gmail.com','youn park','2995 Roundhill Rd','akron','OH','UNITED STATES','44333','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-21 23:40:43',0,NULL,3,1,1,1,NULL,'edgarnejip\r庄'),(10000,716956833002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jupterparts','jasonsauro@gmail.com','JASON SILVA','RUA VISCONDE DE NACAR, Nº 1200 Apto 14<br>BAIRRO CENTRO','CURITIBA','PR','BRAZIL','80410-201','55 41 84030681','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 01:13:17',0,NULL,3,1,3,1,'RA117723252CN ','jupterparts'),(10001,675816139001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','archdiz29','jongdiaz29@yahoo.com','ARCHIE DIAZ','18902 Damasco St','WEST COVINA','CA','UNITED STATES','91792-3037','(909) 263-5287','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-22 01:13:15',0,NULL,3,1,1,1,NULL,'archdiz29\r庄'),(10002,790140933015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','sacr1f1c3','achu.ckr@googlemail.com','Arjuna Chandrakumar','Portobello Post Office<br>325 Portobello Road','Kensington','London','UNITED KINGDOM','W105SY','07929612377','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 01:22:07',0,NULL,3,1,2,1,NULL,'sacr1f1c3\r庄'),(10243,718813832002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','msjirvin','msjirvin@hotmail.com','Melinda S Irvin','2006 Loomis St','Winfield','KS','UNITED STATES','67156-5416','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 01:22:18',0,NULL,3,1,1,1,NULL,'msjirvin\r庄'),(10003,674879639018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',1,'AE2316',12.9,'photographyacc','zadark1','davecall1@bigpond.com','Dave Callaway','22 Kumala Drive','Somerville','Victoria','AUSTRALIA','3912','0359779653','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 02:13:22',0,NULL,3,1,2,1,NULL,'zadark1\r庄'),(10004,716989070002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','01drewsgraphix','rebecca@drewsgraphix.com.au','D. Andrew MacDonald','2 Jayne Court<br>Kelso','Townsville','Queensland','AUSTRALIA','4815','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 03:24:36',0,NULL,3,1,4,1,'YW866011076CN ','01drewsgraphix\rlighting kit $20\r刘\r'),(10005,674915571018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','mattypoon','mattyp_pyttam@hotmail.com','Matthew Poon','Midland Kalamunda Reporter<br>12 Old Great Northern Hwy','MIDLAND, PERTH','Western Australia','AUSTRALIA','6056','0892371900','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-22 05:28:37',0,NULL,3,1,3,1,'RA117723297CN ','mattypoon'),(10006,675870764001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','okunk0zi6','orystkunka@yahoo.com','Oryst N. Kunka','179 N 7th St','Brooklyn','NY','UNITED STATES','11211-2905','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 06:29:56',0,NULL,3,1,17,0,NULL,'okunk0zi6'),(10007,717019586002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','okunk0zi6','orystkunka@yahoo.com','Oryst N. Kunka','179 N 7th St','Brooklyn','NY','UNITED STATES','11211-2905','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 06:29:57',0,NULL,3,1,1,1,NULL,'okunk0zi6\r绿叶 渐变镜 67mm    1\r绿叶 渐变镜 58mm    1\r庄'),(10008,790213909015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','aaronfromsouth','f-streetmovements@hotmail.com','AARON GRAY','31 BREWHOUSE ROAD<br>WOOLWICH','LONDON','London','UNITED KINGDOM','SE18 5SJ','02088549422','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 06:46:56',0,NULL,3,1,2,1,NULL,'aaronfromsouth\r庄'),(10009,728535937017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','will2rob','will2rob@exemail.com.au','Rob Williams','29 Perseus Circuit','Kellyville','New South Wales','AUSTRALIA','2155','0412000039','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 06:57:09',0,NULL,3,1,2,1,NULL,'will2rob\r庄'),(10010,728536212017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','mt_industries','mt_industries@hotmail.com','Marcus Cricenti','143 Blyth St','East Brunswick','Victoria','AUSTRALIA','3057','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 06:59:09',0,NULL,3,1,3,1,'RA117722115CN\r ','mt_industries\r庄\r上次发给客户一个55mm的uv， 补发一个58mm uv给他'),(10011,674937564018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','brm65','brambilw@yahoo.it','Walter Brambillasca','via Lecco 34','Agrate Brianza','Monza Brianza','ITALY','20864','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-22 07:20:57',0,NULL,3,1,2,1,NULL,'brm65\r庄'),(10012,728575146017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','igun9435','ayamgoreng74@yahoo.com.au','Ika Gunawan Saputera','Unit 204/4 Broughton Road','Artarmon','New South Wales','AUSTRALIA','2064','0413298990','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 09:08:35',0,NULL,3,1,2,1,NULL,'igun9435\r庄'),(10013,717065474002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','avsclipmaker','al8action@gmail.com','Alexander Vozhik','15, Himikov street, kv. 27','Lermontov','Stavropol Region','RUSSIAN FEDERATION','357340','+7 928 267 57 52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 09:19:14',0,NULL,3,1,2,1,NULL,'avsclipmaker\r庄'),(10014,675920004001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','danuvid','deividbox-23@yahoo.es','DAVID ARRANZ NIETO','C/ ALFONSO XII Nª26 5-A','MOSTOLES','Madrid','SPAIN','28934','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 09:27:28',0,NULL,3,1,2,1,NULL,'danuvid\r庄'),(10015,774058942016,260660053517,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',14.5,'hutongstore','aigars007','sarunbiedrs@e-apollo.lv','Aigars Kreicbergs','Saules iela 60','Madona','Madonas novads','LATVIA','LV4800','(371)29294442','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 09:28:44',0,NULL,3,1,3,1,'RA117723456CN ','aigars007\r摄影背心 夏  XL     1'),(10016,717076941002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','zekmjhq','zekmjhq@gmail.com','ZAKARIA AHMAD','SMK ROMPIN','KUALA ROMPIN','PAHANG','MALAYSIA','26800','0139556177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 09:51:28',0,NULL,3,1,2,1,NULL,'zekmjhq\r庄'),(10017,716654995002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','youst75','youst@ukr.net','Yuriy Druzhinets','Lenina str., 27A-38','Tokmak','Zaporozhye region','UKRAINE','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 10:11:02',0,NULL,3,1,2,1,NULL,'youst75\r庄'),(10018,675939964001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','rockerd85','rockerd85@gmail.com','Darshana Ranasinghe','Amex (Saudi Arabia) Ltd<br>P.O.Box 6624','Riyadh','Riyadh','SAUDI ARABIA','11452','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 10:23:57',0,NULL,3,1,2,1,NULL,'rockerd85\r庄'),(10019,675005520018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','colm4840','cfr57506@bigpond.net.au','Cath Friel','21 Stagpole St','WEST END','Queensland','AUSTRALIA','4810','0747721375','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-22 10:41:41',0,NULL,3,1,4,1,'YW866011102CN ','colm4840\rreflector holder $20\r0630-0712-回信说已经收到.'),(10020,675935708001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',13.99,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-05-22 10:42:10',0,NULL,3,1,6,1,'EE506555452CN ','jagebbo\r柔光伞  1\r反光板支架   2\rJJC 腕带  JJC-2     1\rreflector holder  $20'),(10021,790306111015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','alice-rose1993','al1ce_rose@hotmail.com','alice perry','3 beech house<br>doctors bank','ashley','Shropshire','UNITED KINGDOM','tf94le','07851860336','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 10:48:18',0,NULL,3,1,2,1,NULL,'alice-rose1993\r庄'),(10022,675952081001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',61,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 10:58:11',0,NULL,3,1,17,0,NULL,'jagebbo'),(10023,675039531018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','anatoliyovich','yansek7@gmail.com','Yan Sek','79 Tucketts Road','Mount Macedon','Victoria','AUSTRALIA','3441','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-22 12:06:06',0,NULL,3,1,3,1,'RA117723442CN ','anatoliyovich'),(10024,717137988002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dizeaz','eziztm@gmail.com','Eziz Annagurban','Kozakova 123/14','Praha 10','','CZECH REPUBLIC','10400','00420728733623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 12:35:15',0,NULL,3,1,2,1,NULL,'dizeaz\r庄'),(10025,675997058001,110531023204,'JJC Leather Hand Strap Grip comfort stable D700 5DII',1,'AB1409',12.99,'hermeshine','jagebbo','gellingdale@gmail.com','Julie Gebbing','PO Box 212','Woori Yallock','Victoria','AUSTRALIA','3139','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 12:56:27',0,NULL,3,1,17,0,NULL,'jagebbo'),(10026,676014762001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','ernest19640040','provitamed@gmail.com','Ernest Valea','Bucovinei 11','Timisoara','RO','ROMANIA','300361','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 13:38:42',0,NULL,3,1,2,1,NULL,'ernest19640040\r庄'),(10027,728688809017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','purple_line2','jerome_cornick@yahoo.com','Jerome Cornick','12 Wooramel Way','Cooloongup','Western Australia','AUSTRALIA','6168','0895924648','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 13:44:30',0,NULL,3,1,2,1,NULL,'purple_line2\r庄'),(10028,717170416002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','001stephane','stephska@voo.be','Stéphane ska','Rue de grand hallet, 15','Avernas le bauduin','','BELGIUM','4280','019-516144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:14:30',0,NULL,3,1,17,0,NULL,'001stephane'),(10029,676031414001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','001stephane','stephska@voo.be','Stéphane ska','Rue de grand hallet, 15','Avernas le bauduin','','BELGIUM','4280','019-516144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:16:42',0,NULL,3,1,2,1,NULL,'001stephane\r大号内胆包canon   1\r橡胶遮光罩 58mm   1\r庄'),(10030,676040517001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','iandris70','andris.adamovs@gmail.com','Andrejs Adamovs , Gunita Adamova','Skolas<br>18-16','Brocēni','Saldus rajons','LATVIA','LV-3851','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 14:35:54',0,NULL,3,1,2,1,NULL,'iandris70\r庄\r'),(10031,717210709002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kameramantv','demjancikmarek@hotmail.com','Marek Demjančík','Hlavná č.d.193','Cejkov','','SLOVAK REPUBLIC','07605','+421903512218','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 15:31:13',0,NULL,3,1,3,1,'RA117723345CN ','kameramantv'),(10032,675165974018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','ferrarigtr','thomas@xinsynergy.com','Thomas Wong','31 Rosewood Drive<br>#02-30, Tower 6','Casablanca','Singapore','SINGAPORE','737922','+65-9752-7729','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-22 16:21:15',0,NULL,3,1,11,1,' ','ferrarigtr'),(10033,676106263001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','rexyrexzillaz','rexzillaz@gmail.com','Panuwat Wongsakulchai','276/38 Suksawad Road Soi.6<br>Jomthong District','Bangkok','Bangkok','THAILAND','10150','66890574565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 16:33:05',0,NULL,3,1,11,1,NULL,'rexyrexzillaz\r转接环 要 77mm的\r庄'),(10034,676108955001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 16:35:55',0,NULL,3,1,2,1,NULL,'m.petrosyan\r庄'),(10035,717264042002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','konrad_za','konrad.blum@gmail.com','Konrad Blum','12 Crozier Street (Hadewijch Flats)','Stellenbosch','Western Cape','SOUTH AFRICA','7600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 16:44:36',0,NULL,3,1,2,1,NULL,'konrad_za\r（打印一张Invoice，随货一起发走）'),(10036,717280005002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','gdmopassan','cyber80@mail.ru','Eugene Kostromin','Belinskogo St.<br>180 - 24','Yekaterinburg','Sverdlovsk','RUSSIAN FEDERATION','620142','89022617761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 17:07:16',0,NULL,3,1,2,1,NULL,'gdmopassan\r庄'),(10037,676134349001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','omegas91','mr.markin@gmail.com','Aleksandr Markin','Trolleynaya 152 - 317','Novosibirsk','','RUSSIAN FEDERATION','630107','79139104036','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 17:11:53',0,NULL,3,1,3,1,'RA117723306CN ','omegas91'),(10038,717299532002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','fotografia55','fotografiskbild@telia.com','Caj Hållberg','Fyrskeppsv 48<br>Johanneshov','Stockholm','','SWEDEN','121 54','070-301 53 23','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 17:43:26',0,NULL,3,1,17,0,' ','fotografia55\r'),(10039,774357585016,260660055167,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','hashhak','maciej_walczak@poczta.fm','MACIEJ WALCZAK','116 WOOLCOMBERS WAY','BRADFORD','West Yorkshire','UNITED KINGDOM','BD4 8JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 17:45:11',0,NULL,3,1,2,1,NULL,'hashhak\r庄'),(10040,676186590001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','romankarasev','rbkarasev@gmail.com','Roman Karasev','Artilleriyskaya 63-206','Kaliningrad','RU','RUSSIAN FEDERATION','236016','79118556040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:13:12',0,NULL,3,1,2,1,NULL,'romankarasev\r庄'),(10041,717300170002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','fotografia55','fotografiskbild@telia.com','Marie Gunnarsson','Stallgärdsgatan 4c','Kalmar','','SWEDEN','393 53','070-301 53 23','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 18:22:08',0,NULL,3,0,3,1,'RA117723368CN ','fotografia55\r摄影背心 Canon 老款    2（M+3XL)（已入库）'),(10042,676149998001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','zoncreation','marianna7080@narod.ru','ilona krumkacheva','borovskoye chaussee<br>44/1 apt 124','moscow','moscow','RUSSIAN FEDERATION','119634','0117-495-732-46-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:30:36',0,NULL,3,1,3,1,'RA117723310CN ','zoncreation'),(10043,717354880002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','martinkristal2010','martinkristal@gmail.com','Martin Kristal','11 After St.','Tel Aviv','Tel Aviv','ISRAEL','69362','972-3-6990171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:36:02',0,NULL,3,1,3,1,'RA117776621CN\r ','martinkristal2010\r上次一大票货里，客户说没找到柔光伞，再发一次给他，一把普通的柔光伞'),(10044,676205045001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','martinkristal2010','martinkristal@gmail.com','Martin Kristal','11 After St.','Tel Aviv','Tel Aviv','ISRAEL','69362','972-3-6990171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 18:36:03',0,NULL,3,1,17,0,NULL,'martinkristal2010'),(10045,676201030001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','martinkristal2010','martinkristal@gmail.com','Martin Kristal','11 After St.','Tel Aviv','Tel Aviv','ISRAEL','69362','972-3-6990171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 18:36:03',0,NULL,3,1,17,0,NULL,'martinkristal2010'),(10046,717375063002,120562082179,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',96.8,'hermeshine','martinkristal2010','martinkristal@gmail.com','Martin Kristal','11 After St.','Tel Aviv','Tel Aviv','ISRAEL','69362','972-3-6990171','NoPaymentFailure','CheckoutComplete','AU_OtherInternational','2011-05-22 19:00:58',0,NULL,3,1,3,1,'RA117723884CN\r','martinkristal2010\r背景架2mx2m     1\r背景布   2（浅蓝+白）\r2m 灯架   1\r柔光伞   1\r小号灰卡   1\r100-150 5in1  反光板    1\r刘\r试试分3个小包发\rRA117723907CN\rRA117723819CN\rRA117723898CN \r'),(10047,774480859016,260660055197,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','hilaryquinnphotography','hilary@hqphotostudio.ie','Hilary Quinn','16 Frankfield Terrace<br>Summerhill South','Cork City','Cork','IRELAND','default','0851415852','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-22 19:44:03',0,NULL,3,1,2,1,NULL,'hilaryquinnphotography'),(10048,774521941016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','pip.perry','abbie369@hotmail.co.uk','Abbie Perry','54 Windsor Avenue','Newton Abbot','Devon','UNITED KINGDOM','TQ12 4DW','07788733299','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 20:35:20',0,NULL,3,1,2,1,NULL,'pip.perry\r庄'),(10049,717427682002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','squale230','pdigout@sfr.fr','Pascal DIGOUT','1 bis rue Bellavoine','LE PECQ','Île-de-France','FRANCE','78230','06.79.78.27.72','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-22 20:44:13',0,NULL,3,0,3,1,'RA117723411CN ','squale230\rXL（已入库）'),(10050,717464783002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','ramirocastrorj','ramirorj@gmail.com','Ramiro Silva','Travessa Marciano Farias<br>226, apto 304 ou 405 - Parada 40','São Gonçalo','Rio de Janeiro','BRAZIL','24435140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 21:15:43',0,NULL,3,1,3,1,'RA117717464CN\r ','ramirocastrorj\r庄\r---\r第一次平邮没收到,0706挂号小包再发一次'),(10051,716564849002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','cc0489866','ccote321@gmail.com','chris cote','1314 N 1st Ave','upland','CA','UNITED STATES','91786-3220','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 21:20:01',0,NULL,3,1,1,1,NULL,'cc0489866\r庄'),(10052,774547304016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','buckledcranium','buckledcranium@gmail.com','Luke Leslie','4 Islington Avenue, Dun Laoghaire<br>Sandycove','Dublin','Dublin','IRELAND','6W','0879146278','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-22 21:21:04',0,NULL,3,1,4,1,'YW866011135CN ','buckledcranium\r英标\r背景布   绿色\r申报：Lighting kit；40$\r庄\r\r'),(10053,729019211017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','clares88','clare_shelley@hotmail.com','clare shelley','15 napper st<br>south coogee','sydney','New South Wales','AUSTRALIA','2034','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-22 21:42:29',0,NULL,3,1,2,1,NULL,'clares88\r庄'),(10054,676328642001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','photoente','info@hauslemon.com','Michael Mardner','7721 Loyola Road, P.O.BOX 329','Slocan','BC','CANADA','V0G 2C0','(250) 355-2536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 21:53:51',0,NULL,3,1,2,1,NULL,'photoente\r庄'),(10055,717491039002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 22:20:49',0,NULL,3,1,17,0,NULL,'bobi1330'),(10056,676338288001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','jonasa4','jonas.ohrfeldt@bredband.net','Jonas Öhrfeldt','Skogslyckegatan 24A','Linköping','','SWEDEN','58727','+46703705826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 22:20:56',0,NULL,3,1,2,1,NULL,'jonasa4\r庄'),(10057,790792782015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','kaffe2latte','vik.alexander@gmail.com','Alexander Vik','Karpgatan 6','Saltsjöbaden','Stockholm','SWEDEN','13341','+46702386851','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-22 22:23:42',0,NULL,3,1,3,1,'RA117723164CN ','kaffe2latte'),(10058,676339630001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 22:25:18',0,NULL,3,1,2,1,NULL,'bobi1330\r笔   3\r爵影红外 5 in 1   1\r庄'),(10059,676341474001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','hojo4u','hojo4utwo@yahoo.com','david kaplan','4960 N Cimarron Rd','las vegas','NV','UNITED STATES','89149-4752','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-22 22:32:07',0,NULL,3,1,1,1,'LK004407687CN','hojo4u\r刘\r之前系统原因发错了,这次补发一个\"金属\"卡口环---注意,只是环\r0603NEW-LK004407687CN\r'),(10060,790807357015,250601901408,'Wireless Remote Control Cord for Canon 500D/1000D/450D',1,'AA3203',11.47,'hutongstore','lucyloophole','sherbert_lemon@hotmail.com','Lesley Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-22 22:56:38',0,NULL,3,1,2,1,NULL,'lucyloophole\r庄'),(10061,673129646018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','passig','s.passig@gmail.com','Steffan O\'Mara Passig','8/11 Blaxland Ave','Newington','New South Wales','AUSTRALIA','2127','0296485523','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-22 23:15:37',0,NULL,7,0,18,0,NULL,'passig'),(10062,717512854002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','cursosw5','contato@cursosw5.com.br','Edson Souza','Panama<br>330','Marília','São Paulo / Marília','BRAZIL','17520-100','5514-34511354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-22 23:29:27',0,NULL,3,1,2,1,'\\ ','cursosw5\r庄'),(10063,675442968018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',7.28,'photographyacc','taurus7119','ren7119@hotmail.com','renato batarina','13028 trailside way','germantown','MD','UNITED STATES','20874-1811','(301) 540-4371','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-22 23:45:06',0,NULL,3,1,1,1,NULL,'taurus7119\r庄'),(10064,790837184015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','tomasdinda','lapiokas@walla.com','Tomas Dinda','24 boyne view<br>Johnstown','Navan','Meath','IRELAND','','0851301299','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 00:21:51',0,NULL,3,1,2,1,NULL,'tomasdinda\r庄'),(10065,676375074001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','hitachi_outlet','hitachi-outlet@sydneytools.com.au','Ecommerce Dept','429 New Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','0295696140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 00:48:24',0,NULL,3,1,2,1,NULL,'hitachi_outlet\r庄'),(10066,676380462001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ideasparalelas','neo808080@hotmail.com','Jorge Piovano','Pte Roca 1947 8 B','Rosario','Santa Fe','ARGENTINA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 00:52:04',0,NULL,3,1,17,0,NULL,'ideasparalelas'),(10067,676380495001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','ideasparalelas','neo808080@hotmail.com','Jorge Piovano','Pte Roca 1947 8 B','Rosario','Santa Fe','ARGENTINA','2000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 00:52:04',0,NULL,3,1,2,1,NULL,'ideasparalelas\r橡胶遮光罩 52mm    1\r橡胶遮光罩 58mm    1\r庄'),(10068,676397533001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','dewalt_outlet','dewalt-outlet@sydneytools.com.au','ST Ecoms Dept','429 New Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 01:43:07',0,NULL,3,1,2,1,NULL,'dewalt_outlet\r庄'),(10069,717562864002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','cwlor','eviz.cw@gmail.com','Chan Chee Weng','PO Box 25','Croydon','New South Wales','AUSTRALIA','2132','0421128238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 02:01:55',0,NULL,3,1,2,1,NULL,'cwlor\r庄'),(10070,717578736002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ferjrpanther','fernandokk707@gmail.com','Fernando Jorge','1535 Range Ave<br>Apt 1','Santa Rosa','CA','UNITED STATES','95401-4226','(707) 331-8081','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 02:56:12',0,NULL,3,1,1,1,NULL,'ferjrpanther\r庄'),(10081,774763530016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','20magnum07','m.purslow@ntlworld.com','Marc Purslow','Llamedos<br>3 Gaskell Avenue','Warrington','Cheshire','UNITED KINGDOM','WA4 1PB','01925480781','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 09:05:00',0,NULL,3,1,2,1,NULL,'20magnum07'),(10071,717589084002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',4,'AKT055',250,'hermeshine','polamsky','vlad.barreto@gmail.com','Vlad da Cunha','Locked Bag 15','Rozelle','New South Wales','AUSTRALIA','2039','0293511051','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 03:37:31',0,NULL,3,1,4,1,'YW866011216CN ','polamsky\r王\r'),(10072,676428428001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','scaffolding_central','scaffolding-central@sydneytools.com.au','ST Ecomms Dept','429 New Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 03:45:08',0,NULL,3,1,2,1,NULL,'scaffolding_central'),(10073,729139711017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','pisoca1','ursula@gil.com.au','Ursula Norton-Smith','6/23 Victoria Tce','Annerley','Queensland','AUSTRALIA','4103','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-23 04:29:03',0,NULL,3,1,2,1,NULL,'pisoca1'),(10074,774706879016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','leopold_milton','axelsson@me.com','Markus Axelsson','Granitvägen 8','LAHOLM','','SWEDEN','312 32','070-580 90 05','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 05:04:36',0,NULL,3,1,2,1,NULL,'leopold_milton'),(10075,676443105001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','quaternion-msu','roman180@rambler.ru','Roman Jandarov','315 W Beaver Ave<br>Apt. 12','State College','PA','UNITED STATES','16801-4007','(814) 441-7759','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 05:14:56',0,NULL,3,1,1,1,NULL,'quaternion-msu'),(10076,676448511001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','stanley_outlet','stanley-outlet@sydneytools.com.au','ST Ecommerce Dept','429 new Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 05:48:51',0,NULL,3,1,2,1,NULL,'stanley_outlet'),(10077,675534581018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',68,'photographyacc','amalia0910','miss.amalia@hotmail.com','Amalia Wakid','98 Lakemba Street<br>Lakemba','Sydney','New South Wales','AUSTRALIA','2195','0297033555','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-23 06:04:35',0,NULL,3,1,4,1,'YW866011150CN','amalia0910\rbackground board $15'),(10078,717627210002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','samurailast','neftaly.yanes@gmail.com','JOSE NEFTALY YANES','Col. San antonio,<br>Pasaje Pilar Vasquez #4-A','MEJICANOS','San Salvador','EL SALVADOR','7777','2102 2121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 07:13:57',0,NULL,3,1,2,1,NULL,'samurailast'),(10079,717629868002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','anvalku2008','anvalku@gmail.com','Andrey Kucherenko','Shipilovskaya 48-2-138','Moscow','Moscow','RUSSIAN FEDERATION','115573','79262357590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 07:25:24',0,NULL,3,1,3,1,'RA117724006CN\r ','anvalku2008'),(10080,675563832018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',15.6,'photographyacc','52432730','crbrand@bigpond.com','Chris Brand','TAC<br>Level 3, 60 Brougham Street','Geelong','Victoria','AUSTRALIA','3220','0423554186','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-23 08:32:14',0,NULL,3,1,2,1,' ','52432730'),(10082,729199156017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','katom0494','kathryn.body@thinkplace.com.au','Kathyrn Body','33 Faunce Crescent','O\'Connor','Australian Capital Territory','AUSTRALIA','2602','0261049362','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-23 09:27:36',0,NULL,3,1,3,1,'RA117723990CN\r ','katom0494\r174'),(10083,790993704015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','brandmegastore','fucawi@gmail.com','steve jones','11 brand Road','rugby','Warwickshire','UNITED KINGDOM','cv211af','01788310500','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 09:46:52',0,NULL,3,1,2,1,NULL,'brandmegastore'),(10084,717675613002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','dlrpgmsvc','dario.paganini@aruba.it','dario paganini','via vasco de gama 8','verona','vr','ITALY','37138','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 10:48:19',0,NULL,3,1,2,1,NULL,'dlrpgmsvc\r庄'),(10085,717468737002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','celilmollahasangmail','celilmollahasan@gmail.com','Olcay Yavas','Kemalpasa M. Baglar C. Adil S.<br>No:4 D:3','Istanbul','Turkiye','TURKEY','34295','(535) 775 - 8477','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-23 10:52:00',0,NULL,3,1,3,1,'RA117723915CN\r ','celilmollahasangmail'),(10086,717454802002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','osnoflaalfonso','alf196342@yahoo.es','Alfonso Fernandez Fortes','Doctor Jimenez Diaz 12 Blq3 1ºA','Alicante','Comunidad Valenciana','SPAIN','03005','657039152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 10:59:49',0,NULL,3,1,2,1,NULL,'osnoflaalfonso\r庄'),(10087,791055339015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','pathxc','david.daillet@gmail.com','david daillet','6 RUE DU QUEVREMONT','JUVIGNIES','Picardie','FRANCE','60112','0344454470','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-23 12:45:33',0,NULL,3,1,4,1,'YW866011220CN','pathxc\r庄\r欧标'),(10088,675643798018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','picnic_bar','firstmolar82@hotmail.com','Kim Om','705 Mt Alexander Road','Moonee Ponds','Victoria','AUSTRALIA','3039','0433302900','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-23 13:20:52',0,NULL,3,1,4,1,'YW866011183CN ','picnic_bar\r'),(10089,676536462001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','vitalis1985','dangus.mums@gmail.com','Vitalis Bogdanovicius','Ukmerges g. 300f - 38','Vilnius','Aukstaitija','LITHUANIA','06146','867557510','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-23 13:21:00',0,NULL,3,1,3,1,'RA117738212CN\r','vitalis1985\r刘'),(10090,790101723015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',47,'hutongstore','tvieira2003','junior@ideiasfrescas.com','Anibal Tiago Vieira','Prc Alexandre Herculano,<br>22 - 4º D','FARO','Algarve','PORTUGAL','8000-160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 13:39:25',0,NULL,3,1,3,1,'RA117723986CN\r ','tvieira2003\r刘\r欧标'),(10091,676313949001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',21.33,'hermeshine','alarane','mikael@leferfort.info','Mikael LEFERFORT','4383 avenue Girouard','Montréal','QC','CANADA','H4A 3E5','(514) 544-3434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 13:50:14',0,NULL,3,1,3,1,'RA117723972CN\r ','alarane(已入库)\r绿叶  58mm ND8   1\r笔    1\rCanon 450D 眼罩   2\r67mm UV   1\r庄'),(10092,676290582001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','edom.eu','edom.ltd.eu@gmail.com','Marin Naydenov','prof.N Mihailov 6<br>ap.16 -E DOM OOD-','Sofia','','BULGARIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 14:05:09',0,NULL,3,1,2,1,NULL,'edom.eu\r庄'),(10093,675662524018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','ozzie0i','ozzieoi415@hotmail.com','jon Leslie','415Nowland Avenue','Albury','New South Wales','AUSTRALIA','2641','0260400124','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-23 14:19:45',0,NULL,3,1,2,1,NULL,'ozzie0i\r庄'),(10094,676578957001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','6674.jose','jfgm1@sapo.pt','José Machado','Rua da Pica 52<br>Delães','Vila Nova de Famalicão','Braga','PORTUGAL','4765-649','00351962026674','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-23 14:38:13',0,NULL,3,1,2,1,NULL,'6674.jose\r庄'),(10095,717747684002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','classicblackbeauty','jayhawksg@yahoo.com.sg','TAN YEW MENG JOHN','BLK 889 TAMPINES ST 81<br>#02-1056','Singapore','','SINGAPORE','520889','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 14:48:30',0,NULL,3,1,11,1,NULL,'classicblackbeauty\r庄'),(10096,791117126015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','bolderwoode','tim1214@hotmail.co.uk','tim mansfield','56 the ridgeway','burbage','Leicestershire','UNITED KINGDOM','le102nr','01455633157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 15:18:07',0,NULL,3,1,2,1,NULL,'bolderwoode\r庄'),(10097,676603901001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 15:52:59',0,NULL,3,0,3,1,'RA117738359CN\r ','frankedisson\r申报 $10\r庄(已入库)\r1X 52mm 3-stage Rubber lens hood \r2X 55mm 3-stage Rubber lens hood\r2X 58mm 3-stage Rubber lens hood\r1X 62mm 3-stage Rubber lens hood\r1X 67mm 3-stage Rubber lens hood\r1X 72mm 3-stage Rubber lens hood\r2X 77mm 3-stage Rubber lens hood \r\r'),(10098,716303805002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',5,'AA1301',12.2,'hermeshine','kajanakis','al.petrov@live.se','Alexander Petrov','Valhallavägen 57, 2 tr','Stockholm','','SWEDEN','11422','+46762728172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 16:40:13',0,NULL,3,1,3,1,'RA117723969CN\r ','kajanakis\r庄'),(10099,774946136016,260660055008,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','mygiftmatters','cdp.cilantro@googlemail.com','COLLIN.D.PEREIRA','35A-MARLDON AVENUE','PAIGNTON','Devon','UNITED KINGDOM','TQ33NY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 17:08:39',0,NULL,3,1,2,1,' ','mygiftmatters\r黑色   1.6x2.1'),(10100,774740125016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','picprog','rikard_alard@hotmail.com','Rikard Alard','Dr Westrings gata 13B','Göteborg','','SWEDEN','41324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 17:34:22',0,NULL,3,1,17,0,NULL,'picprog'),(10101,790943105015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','picprog','rikard_alard@hotmail.com','Rikard Alard','Dr Westrings gata 13B','Göteborg','','SWEDEN','41324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 17:34:23',0,NULL,3,1,4,1,'YW866011205CN ','picprog\r反光板 100*150  5合1    1\r灯架  2m    1\r斜臂    1\r\r'),(10102,717820549002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rafael5974','rafael@diplomat1.com','Rafael Crespo','13853 SW 9th St','Miami','FL','UNITED STATES','33184','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 17:54:29',0,NULL,3,1,1,1,NULL,'rafael5974\r庄'),(10103,675749972018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','nicdotnet','niccjd@gmail.com','Nic Duthie','17 Connock Street<br>Urangan','Hervey Bay','Queensland','AUSTRALIA','4655','0401924846','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-23 18:03:38',0,NULL,3,1,2,1,NULL,'nicdotnet\r庄'),(10104,791211059015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','darklemon','kierakirby@yahoo.com','Kier Kirby','72a London Road','Maidstone','Kent','UNITED KINGDOM','me16 0dt','07595768741','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 18:15:30',0,NULL,3,1,3,1,'RA117723938CN\r ','darklemon'),(10105,717837186002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',3,'AKT051',34.5,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 18:20:55',0,NULL,3,1,3,1,NULL,'igrom78\r庄'),(10106,717856347002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','sotereos123','sammyjojos@yahoo.com','Sotereos Tziotzios','Georgiou Drosini 11','Argos','Argolidas','GREECE','21200','(30)2751021868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 18:58:08',0,NULL,3,1,4,1,'YW866011194CN ','sotereos123\r欧标\r庄\r0630-0703-来信说已收到'),(10107,717863502002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',9.6,'hermeshine','niekduregger1986','niekduregger@hotmail.com','Niek Duregger','Anna Paulownastraat 44','GRONINGEN','','NETHERLANDS','9725JT','0031614548765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:09:53',0,NULL,3,1,2,1,NULL,'niekduregger1986\r庄'),(10108,791257040015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','tikkathreebarrels','55grainvmax@talktalk.net','P. Ansbro','5 Troon Court<br>Fornham St Martin','Bury St Edmunds','Suffolk','UNITED KINGDOM','IP28 6TJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-23 19:22:45',0,NULL,3,1,2,1,NULL,'tikkathreebarrels\r庄'),(10109,717872873002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','suppebuss','tommlars@yahoo.no','Tommy Larsen','Daleveien 306','Sandnes','','NORWAY','4329','004792244124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:29:08',0,NULL,3,1,2,1,NULL,'suppebuss\r庄'),(10110,676705210001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','zbylutcorp','setsunamedia@hawaiiantel.net','Zbylut Corporation','2031 Kilauea Ave','Hilo','HI','UNITED STATES','96720-6520','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 19:30:47',0,NULL,3,1,1,1,NULL,'zbylutcorp\r黑'),(10111,717878351002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','reniclus','shultziner@012.net.il','Shultziner Philip','Hashikmah 36/4','Nesher','north israel','ISRAEL','36812','972-4-8210133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:41:48',0,NULL,3,1,2,1,NULL,'reniclus\r庄'),(10112,676716035001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','canada8329','chic-kloodie@hotmail.com','Normand Lavoie','605 rue Girard','St-Prime','QC','CANADA','g8j 1p5','(418) 251-5022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-23 19:50:49',0,NULL,3,1,5,1,'CP226268979CN ','canada8329\r背景布  2(白+黑)'),(10113,676719172001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','00420-608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 19:58:14',0,NULL,3,1,3,1,'RA117738288CN\r\r ','robertbookshop\r应该是金属卡口的'),(10114,791298083015,250692236486,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','scas100','stevencassidy5@hotmail.com','steven cassidy','crefogue','enniscorthy','Wexford','IRELAND','','0877518215','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 20:24:17',0,NULL,3,1,2,1,NULL,'scas100\r庄'),(10115,791308815015,250599945601,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',2,'AA1201',3.7,'hutongstore','75ama','alina_maniu@yahoo.com','Alina Maniu','Str. Pe-Tocile nr.8, ap.2','Brasov','','ROMANIA','500117','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 20:40:52',0,NULL,3,1,2,1,NULL,'75ama\r庄'),(10116,676746035001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','kz1m9w','randy.williams@eds.com','Randy Williams','737 Ridgemont Dr','Allen','TX','UNITED STATES','75002-6102','(972) 396-5923','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-23 20:53:17',0,NULL,3,1,1,1,NULL,'kz1m9w\r庄'),(10117,775091648016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',7.5,'hutongstore','nikal01','inkal00@hotmail.com','Nikos Kalpakidis','(TEL. 6946289780)<br>Leoforos Hatzikyriakou 104','Pireaus','','GREECE','18538','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-23 21:06:08',0,NULL,3,1,2,1,' ','nikal01\r'),(10118,717929188002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','yalghofaili','abuyzeed@gmail.com','Yousef A. A. Al-Ghofaili','Qassim,Ar Rass, 0503979600<br>Ar Rass, ZIP:51921, BOX:849','Ar Rass','Qassim','SAUDI ARABIA','51921','0503979600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:28:54',0,NULL,3,1,17,0,NULL,'yalghofaili\r庄'),(10119,676758624001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','yalghofaili','abuyzeed@gmail.com','Yousef A. A. Al-Ghofaili','Qassim,Ar Rass, 0503979600<br>Ar Rass, ZIP:51921, BOX:849','Ar Rass','Qassim','SAUDI ARABIA','51921','0503979600','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-23 21:28:55',0,NULL,3,1,17,0,NULL,'yalghofaili'),(10120,717928937002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','yalghofaili','abuyzeed@gmail.com','Yousef A. A. Al-Ghofaili','Qassim,Ar Rass, 0503979600<br>Ar Rass, ZIP:51921, BOX:849','Ar Rass','Qassim','SAUDI ARABIA','51921','0503979600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:28:55',0,NULL,3,1,3,1,'RA117723941CN\r ','yalghofaili\r英标\r800w红头灯     1\r800w  220v 灯泡   1\r反光板支架    1\rc型大力夹    1\rRA117738226CN\r'),(10121,717933113002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',2.99,'hermeshine','ptitepatchouli55','mosellev2@free.fr','moselle vanessa','9, rue ruest','colmar','alsace','FRANCE','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:41:32',0,NULL,3,1,17,0,NULL,'ptitepatchouli55'),(10122,717931446002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ptitepatchouli55','mosellev2@free.fr','moselle vanessa','9, rue ruest','colmar','alsace','FRANCE','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:41:33',0,NULL,3,1,17,0,NULL,'ptitepatchouli55'),(10123,676761960001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','ptitepatchouli55','mosellev2@free.fr','moselle vanessa','9, rue ruest','colmar','alsace','FRANCE','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:41:34',0,NULL,3,1,17,0,NULL,'ptitepatchouli55'),(10124,717931618002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','ptitepatchouli55','mosellev2@free.fr','moselle vanessa','9, rue ruest','colmar','alsace','FRANCE','68000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 21:41:34',0,NULL,3,1,2,1,NULL,'ptitepatchouli55\rNIKON 镜头盖 52mm    1\r绿叶 UV  77mm    1\rHB-7 花瓣   1\r眼罩 D300   1\r庄'),(10125,676796442001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','mixe-moi','florys@mixe-moi.com','Florys BONNEFOND','14, rue de la Briance','BOSMIE L\'AIGUILE','Limousin','FRANCE','87110','0555361654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-23 23:39:38',0,NULL,3,1,3,1,'RA117738305CN\r ','mixe-moi\r庄'),(10126,675911117018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',1,'',80,'photographyacc','stimp5000andone','stimp_nz@hotmail.com','Renn Makan','89 Caxton St','Brisbane','Queensland','AUSTRALIA','4000','0061413352197','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-24 00:47:54',0,NULL,3,1,3,1,'RA117738053CN\r ','stimp5000andone\r一定要仔细包装'),(10127,715687140002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5,'hermeshine','obar5330','oscar_m5@hotmail.com','Oscar Barragan','902 Fulton Mall<br># M-32','Fresno','CA','UNITED STATES','93721-2509','(559) 779-7481','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 01:06:34',0,NULL,5,0,18,0,NULL,'obar5330\r庄'),(10128,676826039001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','zohan_81','never_jones@yahoo.com','Jose Miguel Matias Alves','Rua Nova nº76, Jancido<br>Foz-do-Sousa','Gondomar','Porto','PORTUGAL','4515-162','0351912599107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 01:43:31',0,NULL,3,1,2,1,NULL,'zohan_81\r庄'),(10129,775200212016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','squirrelgirl1966','wintershine@att.net','Diane  Kern','449 W Main St','Yukon','OK','UNITED STATES','73099-1203','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-24 02:45:20',0,NULL,3,1,1,1,NULL,'squirrelgirl1966'),(10130,729584479017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','mrdenmac','nkwells75@gmail.com','Colin Wells','23 Hughes St','Point Clare','New South Wales','AUSTRALIA','2250','0412857259','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-24 03:01:31',0,NULL,3,1,3,1,'RA117723955CN\r ','mrdenmac'),(10131,675952883018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',15.99,'photographyacc','kvishon','idanbraslavi@gmail.com','Idan Braslavi','51 Bilu st.<br>Apt. #5','Tel-Aviv','','ISRAEL','64256','+972-52-6747575','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 03:25:07',0,NULL,3,1,3,1,'RA117738291CN\r ','kvishon\r223'),(10132,718027723002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','buckstuffer2008','buckstuffer@gmail.com','Jeffery S. Cline','47 Forest Brook Ln<br>Box 102','Brenton','WV','UNITED STATES','24818-8093','(304) 732-9152','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 03:35:59',0,NULL,3,1,1,1,NULL,'buckstuffer2008'),(10133,729598790017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','kidman55','kidman5@optusnet.com.au','Kellie Murphy','98 Hillcrest Drive<br>Westmeadows','Melbourne','Victoria','AUSTRALIA','3049','0433399446','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 04:11:12',0,NULL,3,1,2,1,NULL,'kidman55'),(10134,729609759017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','4bobjin','bj-x@hotmail.com','Bob Jin','38 Chapman St, Sunshine','Melbourne','Victoria','AUSTRALIA','3020','0393110623','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 05:12:48',0,NULL,3,1,2,1,NULL,'4bobjin'),(10135,716995799002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','plechtian','plecht@yahoo.co.jp','Heath Cozens','Room 701<br>Shimomeguro 3-10-32, Meguro','Tokyo','Tokyo','JAPAN','153-0064','(+81) 80-6665-4340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 05:20:33',0,NULL,3,1,6,1,'EE520583556CN ','plechtian'),(10136,676870301001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 05:32:23',0,NULL,3,1,2,1,NULL,'cmontechi\r庄'),(10137,676874610001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','husqvarna_outlet','husqvarna-outlet@sydneytools.com.au','ST Ecomms Dept','429 New Canterbury Rd','Dulwich Hill','New South Wales','AUSTRALIA','2203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 06:04:09',0,NULL,3,1,2,1,' ','husqvarna_outlet\r庄'),(10138,676659058001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','kokoparts','kokoparts@yahoo.com','Thomas Lee','500 Balboa St','San Francisco','ca','UNITED STATES','94118-3823','(415) 752-2075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 07:27:59',0,NULL,3,0,1,1,NULL,'kokoparts\r1.6x2.1  2块\r灰色， 浅蓝'),(10139,676893942001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',2,'AC1303',15,'hermeshine','obbelixx','hiller.and@t-online.de','Andreas Hiller','Feldstrasse 1','Steinfurt','','GERMANY','48565','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 07:45:09',0,NULL,3,1,2,1,NULL,'obbelixx'),(10146,676038479018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','2004nevillep','cocky2@tpg.com.au','Neville Peacock','5 Sandhurst Avenue<br>Noarlunga Downs','Adelaide','South Australia','AUSTRALIA','5168','0881866776','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-24 10:38:19',0,NULL,3,1,3,1,'RA117738328CN\r ','2004nevillep'),(10140,676016039018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','absolutlion','alex_moon2000@mail.ru','Aleksey Misyachenko','Gorshkova st 7/6, ap 87','Rostov on Don','Rostovskaya oblast','RUSSIAN FEDERATION','344016','(928)148-30-58','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 09:03:16',0,NULL,3,1,2,1,NULL,'absolutlion'),(10141,729655164017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','harrold9295','loveslimegreen@gmail.com','David Harrold','74 dublin st','port lincoln','South Australia','AUSTRALIA','5606','0886830605','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 09:07:41',0,NULL,3,1,2,1,NULL,'harrold9295\r庄'),(10142,718090728002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','ebemilton','ebenabumbu@hotmail.com','Ester Bragado Echeverría','C/ Mingorria 6 - 1ºA','Madrid','Madrid','SPAIN','28024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 09:23:44',0,NULL,3,1,2,1,NULL,'ebemilton\r庄'),(10144,718097797002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','bodhitawa','d.acosta@hotmail.com','DANIEL ACOSTA STAJNER. 51675158T','C/ EL FORT, 26. URB. EL PARADISO. BUZÓN 124.','ALTEA LA VELLA. ALICANTE','Comunidad Valenciana','SPAIN','03599','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 09:55:06',0,NULL,3,1,17,0,NULL,'bodhitawa'),(10204,718499448002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','mjmotton','matti@laskikymppi.com','Matti Möttönen','Tuulimyllynkatu 11 A 1','OULU','','FINLAND','90140','+358 442905569','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 09:06:39',0,NULL,3,1,3,1,'RA117738623CN ','mjmotton'),(10145,676923480001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','chrysalide77','webgrrrrl@hotmail.com','Stephanie Dunn','3930 lausanne','saint-hubert','QC','CANADA','J3Y 4C7','(450) 443-4064','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 10:06:40',0,NULL,3,0,3,1,'RA117738362CN\r ','chrysalide77\r1.6X2.1  背景布  2\r粉色 + 黄色'),(10205,775795369016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',1,'AA1303',1.87,'hutongstore','bexyb00','abellamy555@hotmail.com','Andrew Bellamy','19 Waterfront<br>Preston on the Hill','Warrington','Cheshire','UNITED KINGDOM','WA4 4AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 09:44:00',0,NULL,3,1,2,1,NULL,'bexyb00'),(10209,792061322015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','allied_aviation','allied_aviation@hotmail.com','Antony Meadley','6 Cabot Close','Eastbourne','East Sussex','UNITED KINGDOM','BN23 6RT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 10:36:49',0,NULL,3,1,3,1,'RA117738685CN\r ','allied_aviation'),(10203,677303082001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','fergzzzzzz','fergzzzzzz@hotmail.com','Patrick Collins','56  Scarborough  St<br>U 1168','Southport','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 08:16:19',0,NULL,3,1,2,1,NULL,'fergzzzzzz'),(10220,677401256001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','lucasthekiwi','lucasjahn@aol.com','Lucas Jahn','Kamelienweg 12','Dresden','','GERMANY','01279','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 14:41:49',0,NULL,3,1,3,1,'RA117738708CN\r ','lucasthekiwi'),(10269,792606362015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','spkvideopro','kopanosvideo@yahoo.gr','SPRYROS KOPANOS','IOANNI DOMPOLI 23','THESSALONIKI','','GREECE','54454','030 2310931146','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 13:13:26',0,NULL,3,1,17,1,NULL,'spkvideopro'),(10147,729683656017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',5.66,'photographyacc','adrock_123','a_j_harris@hotmail.com','Adam Harris','2/83 Charles Street','Abbotsford','Victoria','AUSTRALIA','3067','0430231631','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 10:56:06',0,NULL,3,1,2,1,NULL,'adrock_123\r庄'),(10148,791559629015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lubo5555','lubo555@lubo555.com','Lubomir Levterov','j-k Meden Rudnik bl 457 vh 3 et 6<br>ap 63','Bourgas','Bourgas','BULGARIA','8011','0883326241','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 11:05:05',0,NULL,3,1,2,1,NULL,'lubo5555\r庄'),(10149,718131254002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.4,'hermeshine','bxnyice','bxnyice@verizon.net','Jerry Bradley','14146 Rockinghorse Dr','Dale City','VA','UNITED STATES','22193-3765','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 12:09:33',0,NULL,3,1,17,0,NULL,'bxnyice'),(10150,676954122001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','bxnyice','bxnyice@verizon.net','Jerry Bradley','14146 Rockinghorse Dr','Dale City','VA','UNITED STATES','22193-3765','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 12:09:33',0,NULL,3,1,1,1,NULL,'bxnyic\r小号镜头筒   2\r58mm canon 镜头盖   3\r庄'),(10151,718131013002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tamirlaan','ktimor@gmail.com','Timor Kuliev','Hamahtarot 1/13','Jerusalem','','ISRAEL','93781','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 12:21:05',0,NULL,3,1,2,1,NULL,'tamirlaan\r庄'),(10152,675996794018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','flagertyflanagan','flagertyflanagan@yahoo.es','Hugo González Palmero','Numancia, 1 1ºIzq','Valladolid','Castilla y León','SPAIN','47005','983000000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 12:32:57',0,NULL,3,1,2,1,NULL,'flagertyflanagan\r庄'),(10153,676961783001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','eiken_eiken','info@xbox2.dk','Claes Eiken Jensen','Brydes Allé 7<br>St. Tv.','Kbh. S.','','DENMARK','2300','30201039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 12:53:27',0,NULL,3,1,2,1,NULL,'eiken_eiken\r庄'),(10154,676081508018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','eldonso','morten@vampyr.dk','Morten Dons','Skolebakken 46, 2.th.','Galten','','DENMARK','8464','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 13:12:11',0,NULL,3,1,2,1,NULL,'eldonso'),(10155,790282434015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','amish153','invoice.us1@salsadynamite.com','Anmol Mishra','4/492-500 Elizabeth St<br>Surry Hills','Sydney','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-24 13:30:13',0,NULL,3,1,4,1,'YW865718045CN ','amish153\rtripod  $25'),(10156,791617970015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',118,'hutongstore','rajneshkumar1984','lalitadevikumar@hotmail.com','Rajnesh Kumar','33 Roth Street','Casula','New South Wales','AUSTRALIA','2170','0416796372','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-24 13:51:29',0,NULL,3,1,4,1,'YW865718034CN ','rajneshkumar1984\rtripod $25'),(10157,676985940001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','woodrow0_5','aladdin@nexicom.net','Glen Smith','1128 Peacock Rd.<br>R.R.#4','Peterborough','ON','CANADA','K9J 6X5','(705) 652-3248','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-24 13:58:00',0,NULL,3,0,3,1,'RA117738376CN\r ','woodrow0_5\rXXXL  （已入库）'),(10158,791631018015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','ngac76','nunocabral76@gmail.com','Nuno Cabral','Rua de Jesus, 52','Praia da Vitória','PR','PORTUGAL','9760-478','(351) 914574325','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-24 14:23:13',0,NULL,3,1,3,1,'RA117738455CN\r ','ngac76'),(10159,673681748001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',7.13,'hermeshine','mdrconcepts','mdrconcepts@yahoo.com','michael d rogers','1701 stone river rd','richmond','VA','UNITED STATES','23235-6276','(804) 687-1694','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 16:15:32',0,NULL,3,1,1,1,NULL,'mdrconcepts\r52mm 遮光罩    1\r62mm 遮光罩    1\r庄'),(10160,718222346002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','drmhfw','mhfw@yahoo.com','Michael Hoong','86, Lorong Ujana<br>Taman Ujana Kingfisher Fasa 3','Kota Kinabalu','Sabah','MALAYSIA','88400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 16:54:27',0,NULL,3,1,11,1,NULL,'drmhfw\r庄'),(10161,718225606002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','arkakh','arkgah@gmail.com','Arkadiy Akhmetshin','Partizana Germana, dom 10, korp. 2, kv. 64','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198205','+79119186055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 17:02:01',0,NULL,3,1,2,1,NULL,'arkakh\r庄'),(10162,718227205002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','rodrigodias21','rodrigovfcdias@gmail.com','Rodrigo VAL-FLOR DE CALDAS DIAS','RUA SILVIO TIBIRIÇA 167 / 202<br>TURIAÇU','RIO DE JANEIRO','RIO DE JANEIRO','BRAZIL','21540-200','55-21-33500446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 17:04:46',0,NULL,3,1,2,1,NULL,'rodrigodias21\r庄'),(10163,791701861015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',126,'hutongstore','lukeabi7','reg_dragon@hotmail.com','Luke Abi-Khattar','23 Chamberlain Road, Guildford','Sydney','New South Wales','AUSTRALIA','2161','0424577994','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-24 17:10:37',0,NULL,3,1,4,1,'YW865718104CN\r ','lukeabi7\r申报: tripod $25'),(10164,677041292001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jakutee','jakute@info.lt','Giedrius Jakulevičius','Ukmergės 9-46','Kaunas','','LITHUANIA','49342','+37060354223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 17:15:50',0,NULL,3,1,2,1,NULL,'jakutee\r庄'),(10165,718235223002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','arthur1961','arthur.costigan@gnscon.com','Arthur Costigan','448 Ridgewood Dr','New Paris','PA','UNITED STATES','15554','(814) 620-2006','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 17:24:54',0,NULL,3,1,1,1,NULL,'arthur1961\r庄'),(10166,718236582002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','(923)289-2744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 17:28:30',0,NULL,3,1,5,1,'CP227020477CN ','zenitar16'),(10167,709544361002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',25.99,'hermeshine','loris2301vela','loris.roselli@fastwebnet.it','Loris Roselli','via Bertola, 48','Torino','TO','ITALY','10122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 18:00:02',0,NULL,3,1,3,1,'RA117738433CN\r ','loris2301vela'),(10168,676223655018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','rgambuti','rgambuti@email.it','Roberto Gambuti','Via Dei Pini, 2','Riccione','RN','ITALY','47838','3389026083','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-24 19:22:29',0,NULL,3,1,2,1,NULL,'rgambuti\r庄'),(10169,718305210002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','thenryschild','todd_schild@yahoo.com','Todd Schild','100 W Prairie Ave<br>Ste 2','Coeur D Alene','ID','UNITED STATES','83815-6042','(208) 704-4825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 19:51:08',0,NULL,3,1,1,1,NULL,'thenryschild'),(10170,791800460015,250692236486,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','bm5009','babu50@hotmail.co.uk','Babu Mistry','50 Milton Street','Coventry','West Midlands','UNITED KINGDOM','CV2 4NP','02476458522','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 20:05:11',0,NULL,3,1,2,1,NULL,'bm5009\r庄'),(10171,677132748001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','frenchi38','jens.helbig@gmx.net','Jens Helbig','5, rue du Pre de la Treille','Eybens','Rhône-Alpes','FRANCE','38320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:05:23',0,NULL,3,1,2,1,NULL,'frenchi38\r庄'),(10172,676745711001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',16.99,'hermeshine','kima_thomas','kim@kimathomas.ca','Kim Thomas','711 Richter Street','Kelowna','BC','CANADA','V1Y2J6','(250) 317-2299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 20:06:11',0,NULL,3,1,2,1,NULL,'kima_thomas\r庄'),(10173,718315000002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','riamia1','md.martinez@hotmail.com','maria martinez','1050 B St<br>unit 1001','san diego','CA','UNITED STATES','92101-4726','(619) 504-6185','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 20:15:00',0,NULL,3,1,1,1,NULL,'riamia1\r庄'),(10174,677148794001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','belkin1973','belkin@comtv.ru','Vladimir Belyayev','Zelenograd, 801-214','Moscow','Moscow','RUSSIAN FEDERATION','124527','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-24 20:39:54',0,NULL,3,1,3,1,'RA117738393CN\r ','belkin1973'),(10175,791855468015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','anje4000','ali.idrissi-sbai@uwclub.net','ali idrissi-sbai','DEERNESS  PARK MEDICAL CENTRE<br>SUFFOLK STREET','SUNDERLAND','TYNE AND WEAR','UNITED KINGDOM','SR2 8AD','01915670961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 21:37:10',0,NULL,3,1,17,0,NULL,'anje4000'),(10176,791854597015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','anje4000','ali.idrissi-sbai@uwclub.net','ali idrissi-sbai','DEERNESS  PARK MEDICAL CENTRE<br>SUFFOLK STREET','SUNDERLAND','TYNE AND WEAR','UNITED KINGDOM','SR2 8AD','01915670961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 21:37:10',0,NULL,3,1,2,1,NULL,'anje4000\r绿叶 渐变镜 72mm    1\r绿叶 渐变镜 58mm    1\r庄'),(10177,718350918002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',3,'AD1402',26.7,'hermeshine','leondcx','allan_hudson@hotmail.com','Allan Hudson','Av. General Rondon, 3542<br>Vila Leopodina','Duque de Caxias','Rio de Janeiro','BRAZIL','25050-230','552126528640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:37:40',0,NULL,3,1,3,1,'RA117738380CN\r ','leondcx\r庄'),(10178,791858518015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','dakinii','ana.tutaonana@gmail.com','Ana Bacler','10/5 Restalrig Drive','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH7 6FY','07518358494','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-24 21:44:17',0,NULL,3,1,3,1,'RA117738402CN\r ','dakinii'),(10179,677177126001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:56:59',0,NULL,3,1,17,0,NULL,'jujusito'),(10180,718358304002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.55,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:58:17',0,NULL,3,1,17,0,NULL,'jujusito'),(10181,718358654002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 21:59:25',0,NULL,3,1,17,0,NULL,'jujusito'),(10182,718358997002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 22:00:27',0,NULL,3,1,17,0,NULL,'jujusito'),(10183,718359304002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 22:01:29',0,NULL,3,1,3,1,'RA117738447CN\r ','jujusito\r3片装的滤镜袋   1\r方镜卡座 广角托架   1\r方形滤镜接口环 77mm   1\r方形滤镜接口环 67mm   1\r天涯方形  星光镜  star8   1\r庄'),(10184,729951249017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','nathan6566','cyberbish@hotmail.com','Nathan A Bichard','PO Box 1659','PORT LINCOLN','South Australia','AUSTRALIA','5606','0407391615','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 22:18:58',0,NULL,3,1,2,1,NULL,'nathan6566\r庄'),(10185,718364852002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','marinmarinov','map0@abv.bg','Marin Marinov','Aleksandar Stamboliiski 5','Karlovo','Plovdiv','BULGARIA','4300','(359) 899 252964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 22:20:32',0,NULL,3,1,2,1,' ','marinmarinov'),(10186,718369120002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','raharrison65','editorboy2003@yahoo.com','Rich Harrison','914 N Victory Blvd','Burbank','CA','UNITED STATES','91502-1632','(818) 219-9212','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-24 22:36:11',0,NULL,3,1,1,1,NULL,'raharrison65\r庄'),(10187,717860783002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','paulant28','kajzar@tiscali.it','Paula Kajzar','Via Spagnolio 11a','Reggio Calabria','Reggio Calabria','ITALY','89128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-24 23:33:27',0,NULL,3,1,2,1,NULL,'paulant28\r庄'),(10188,676326703018,280680883047,'Dslr Remote Shutter Release Cord RS-S1 SONY RM-S1AM',1,'AA3212',5.69,'photographyacc','jamesc7499','james_cogo@hotmail.com','James Cogo','7 seri place','bossley park','New South Wales','AUSTRALIA','2000','0405506070','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-24 23:54:42',0,NULL,3,1,2,1,NULL,'jamesc7499\r庄'),(10189,675531445001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','mruslan2009','mruslan2008@yahoo.com','Mochamad Ruslan','Telkom Multimedia Service Area Batam<br>GD MMC Batam Center','Batam','Kepulauan Riau','INDONESIA','29400','+62778469401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 00:17:41',0,NULL,3,1,17,0,NULL,'mruslan2009'),(10190,675528427001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','mruslan2009','mruslan2008@yahoo.com','Mochamad Ruslan','Telkom Multimedia Service Area Batam<br>GD MMC Batam Center','Batam','Kepulauan Riau','INDONESIA','29400','+62778469401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 00:17:42',0,NULL,3,1,17,0,NULL,'mruslan2009'),(10191,675531306001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','mruslan2009','mruslan2008@yahoo.com','Mochamad Ruslan','Telkom Multimedia Service Area Batam<br>GD MMC Batam Center','Batam','Kepulauan Riau','INDONESIA','29400','+62778469401','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 00:17:42',0,NULL,3,1,2,1,NULL,'mruslan2009\r52-58mm 双阳环    3\r庄\r'),(10192,718394224002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','photographe-nice','webmaster@planmedia.net','Xavier Vuillemin','8 rue mascoïnat','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06300','06.33.28.51.89','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 00:22:23',0,NULL,3,1,4,1,'YW865718071CN\r ','photographe-nice\r0630 -- 已经退款了.'),(10193,718419015002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','timber1320','andrew_rasouliyan@hotmail.com','Andrew Rasouliyan','5 Fairfield Dr','Ellenwood','GA','UNITED STATES','30294-2802','(770) 808-5302','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-25 02:05:59',0,NULL,3,1,1,1,NULL,'timber1320'),(10194,677237358001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','hanz_33','hansmagelssen@gmail.com','hans magelssen','166 Gordonhurst Ave<br>Apt 2','Montclair','NJ','UNITED STATES','07043-1700','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 02:15:19',0,NULL,3,1,1,1,NULL,'hanz_33'),(10195,718433931002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.3,'hermeshine','zoopita','dyoung@shcs.school.nz','Dave Young','2 Cobden Street','Dunedin','Otago','NEW ZEALAND','9016','021883244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 03:19:46',0,NULL,3,1,6,1,'EE520583406CN ','zoopita'),(10196,676374090018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','alicia09trevor','trevorball@live.com.au','ambiance hair','113 kendal st','cowra','New South Wales','AUSTRALIA','2794','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-25 03:24:35',0,NULL,3,1,4,1,'YW865718082CN ','alicia09trevor\rbackground support  $20'),(10197,677254975001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','smartdave99','smartdave99@yahoo.com','Hao Luu','1710 Oakwood Ave','Arcadia','CA','UNITED STATES','91006','(626) 836-8936','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 03:43:23',0,NULL,3,1,1,1,NULL,'smartdave99'),(10198,676976914001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',1,'AO0005',20.8,'hermeshine','shouter1980','shouter1980@msn.com','Liren Jiang','9 bedford street','Reservoir','Victoria','AUSTRALIA','3073','0433286105','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-05-25 03:45:59',0,NULL,3,1,3,1,'RA117737574CN\r ','shouter1980\r背景布   1 (深灰色-客户已经认同颜色)'),(10199,676395838018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',68,'photographyacc','cleabeater2010','c_leabeater@yahoo.com.au','Cary Leabeater','10<br>Iluka Street','Palm Beach','Queensland','AUSTRALIA','4221','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-25 05:27:15',0,NULL,3,1,4,1,'YW865718060CN ','cleabeater2010\r申报: reflector $20'),(10200,730063005017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','blkmrkt.9','blkmrkt_009@hotmail.com','Grant Oliver','91 Cemetery Road','Sale','Victoria','AUSTRALIA','3850','0351443414','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-25 06:50:28',0,NULL,3,1,2,1,NULL,'blkmrkt.9'),(10201,730065007017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','elcapritx','anagcastillejos@gmail.com','Ana Gomez Castillejos','meridiana 128 3º 1ª','barcelona','Barcelona','SPAIN','08018','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-25 06:59:24',0,NULL,3,1,2,1,NULL,'elcapritx'),(10202,676415262018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','gegeblu3','kao2uz@hotmail.com','Jason Chee','CHEVRON HOUSE 30 RAFFLES PLACE #31-00','default','','SINGAPORE','048622','97927159','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-25 07:13:04',0,NULL,3,1,11,1,NULL,'gegeblu3'),(10206,792052451015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','lorefold','lorefold@wp.pl','Michael Laskowski','PayPal Europe Services, Ballycoolin Business Park,<br>Ballycoolin Road','Blanchardstown','Dublin','IRELAND','15','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-25 10:07:11',0,NULL,3,1,3,1,'RA117738668CN\r ','lorefold\r背景布 1.6x2m   2 (黑+绿)'),(10207,718514718002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','agp977','aleceinpet@yahoo.ca','Alejandro Peralta','Jan Evertsenstraat 59-3','Amsterdam','','NETHERLANDS','1057 BN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 10:16:39',0,NULL,3,1,4,1,'YW865718001CN ','agp977'),(10208,792057825015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','thebeej123','b3nb123@googlemail.com','Ben Brown','Lavenham Photographic Studio Ltd<br>3 Church Street','Lavenham','Suffolk','UNITED KINGDOM','CO10 9QT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 10:22:31',0,NULL,3,1,2,1,NULL,'thebeej123\r庄'),(10210,676473417018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','noaid2','stiborek@seznam.cz','Bretislav Stiborek','Stankova 22','Ostrava','','CZECH REPUBLIC','700 30','+420608982810','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-25 11:23:40',0,NULL,3,1,2,1,' ','noaid2\r庄'),(10211,677346515001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','noaid2','stiborek@seznam.cz','Bretislav Stiborek','Stankova 22','Ostrava','','CZECH REPUBLIC','700 30','+420608982810','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 11:26:54',0,NULL,3,1,2,1,NULL,'noaid2\r庄'),(10212,792087014015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','marcin_digger','office@artkrupa.com','Marcin Krupa','27 Brightwater','Crosshaven','Cork','IRELAND','021','87 3230663','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-25 11:55:31',0,NULL,3,1,2,1,NULL,'marcin_digger\r庄'),(10213,718130205002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','rafanbr','rafaelnbr@uol.com.br','Rafael Narduzzi borlenghi ruas','Rua vitoantonio del vecchio, 226 ap:11','São Paulo','São Paulo','BRAZIL','03124-070','55 (11) 7884-6261','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 12:58:52',0,NULL,3,1,2,1,NULL,'rafanbr\r庄'),(10214,677370714001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2203',24.99,'hermeshine','baklan4ikof','saveleva.da@gmail.com','Saveleva Darya','3 Vladimirskaya 8/1-8','Moskow','','RUSSIAN FEDERATION','111123','(926)345-5526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 13:03:54',0,NULL,3,1,3,1,'RA117738756CN\r ','baklan4ikof\r是金属卡口的'),(10215,718563521002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','mesabassman','mesab2000@bellsouth.net','John Gilmore Jr','6620 Riverside Dr<br>Ems, Inc Ste 105','Metairie','LA','UNITED STATES','70003-7107','(504) 994-6994','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 13:25:06',0,NULL,3,1,1,1,NULL,'mesabassman\r庄'),(10216,676509543018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','assasinates','crossover.inc@gmail.com','Christian Ross','27 malabar rd','coogee','New South Wales','AUSTRALIA','2034','0413886832','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-25 13:30:41',0,NULL,3,1,2,1,NULL,'assasinates\r庄'),(10217,718572719002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','whh2006','zonghe.lai@gmail.com','Zonghe Lai','Flöjtgatan 22','Gothenburg','Västra Götaland','SWEDEN','42139','0317723091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 13:57:20',0,NULL,3,1,2,1,NULL,'whh2006\r庄'),(10218,677391307001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 14:08:53',0,NULL,3,1,3,1,'RA117738739CN\r ','m.petrosyan\r921'),(10219,677391711001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','zera5','sami1993@hotmail.com','Sami Söderholm','Tornipolku 17 c 420','Porvoo','Finland','FINLAND','06400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 14:10:39',0,NULL,3,1,2,1,NULL,'zera5\r庄'),(10221,675789749001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','gradyb2','cranebinder@gmail.com','Grady Bowers/CRANE','9400 Watson Rd<br>Rear','Saint Louis','MO','UNITED STATES','63126-1514','','NoPaymentFailure','CheckoutComplete','Other','2011-05-25 15:21:17',0,NULL,3,1,4,1,'YW866011080CN  ','gradyb2\r庄45w 灯泡是110v的'),(10222,677429417001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','shygirlkiki','chi_hye2003@yahoo.com','Chi Hye Guerrero','CMR 445 Box 934','APO','AE','AA','09046','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-25 16:08:55',0,NULL,3,1,1,1,NULL,'shygirlkiki\r庄'),(10223,677432561001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','veterinar2007','andriy.cl@gmail.com','Olena Cherkashyna','Largo 25 de Abril,17','Samora Correia','Benavente','PORTUGAL','2135-318','964675891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 16:15:23',0,NULL,3,1,2,1,NULL,'veterinar2007\r庄'),(10224,677440455001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','okmelberg11','okmelberg@gmail.com','oddkåre melberg','vågen','jørpeland','','NORWAY','4100','91567170','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-25 16:38:59',0,NULL,3,1,3,1,'RA117738699CN ','okmelberg11\rXL'),(10225,677470477001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','vesla18','jessica.haydahl@gmail.com','Jessica K Haydahl','4495 Ross Lane','West Vancouver','BC','CANADA','V7w2Z2','(604) 922-9536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 17:51:32',0,NULL,3,1,2,1,NULL,'vesla18\r庄'),(10226,718692004002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','levibianco','levi_bianco@yahoo.com.br','Levi Bianco','CP 21130','São Paulo','SP','BRAZIL','04556-970','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 19:10:18',0,NULL,3,1,2,1,NULL,'levibianco'),(10227,677521544001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','basakatu74','picardvolant@gmail.com','Hervé Lartigue','1 rue du paradis','Gaillard','Rhône-Alpes','FRANCE','74240','04 50 39 05 13','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-25 19:40:23',0,NULL,3,1,3,1,'RA117738742CN\r ','basakatu74\rM'),(10228,677520896001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sandro_s87','livewinter@gmail.com','Sandro Antonucci','Via cavalieri di vittorio veneto<br>n. 3','Pianella','PE','ITALY','65019','3285689388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 19:40:41',0,NULL,3,1,3,1,'RA117738610CN ','sandro_s87\r申报: shoulder support 20$'),(10229,677523062001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','soletv','soletv@yahoo.es','Alejandro Soler','Panama, 8 - 2 - 1','Alicante','Alicante/Alacant','SPAIN','03008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 19:45:42',0,NULL,3,1,2,1,NULL,'soletv\r庄'),(10230,677527617001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','darja_mikl','osabosa@gmail.com','darja miklauzic','drenov gric 76','Vrhnika','','SLOVENIA','1360','0038651417249','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 19:53:32',0,NULL,3,1,2,1,NULL,'darja_mikl\r庄'),(10231,676686157018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',9.9,'photographyacc','travellinterrie','hiranii@internode.on.net','terrie kelly','26 vale street','wilston','queensland','AUSTRALIA','4051','0409050830','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-25 20:40:29',0,NULL,3,1,2,1,NULL,'travellinterrie\r3片装的滤镜袋    1\r6片装的滤镜袋    1\r庄\r'),(10232,718739569002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oiled27','delio.ramos@gmail.com','Delio Duarte Ramos','47B Rue de Chantepie','Prevessin Moens','Rhône-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 20:52:03',0,NULL,3,1,2,1,' ','oiled27\r庄'),(10233,717626654002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','samurailast','neftaly.yanes@gmail.com','JOSE NEFTALY YANES','Col. San antonio,<br>Pasaje Pilar Vasquez #4-A','MEJICANOS','San Salvador','EL SALVADOR','7777','2102 2121','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 21:11:24',0,NULL,3,1,2,1,NULL,'samurailast\r庄'),(10234,677563032001,110587011464,'Original New Nikon 90th Anniversary Lens Bag 4 x 10 in',1,'AB2401',13.99,'hermeshine','ipsique','ecaipsi@msn.com','Esteban  Casado Alonso','c/la noria nº 1<br>Santovenia de Pisuerga','valladolid','Castilla y León','SPAIN','47155','645801506','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-25 21:18:06',0,NULL,3,1,2,1,NULL,'ipsique\r庄'),(10235,677572199001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','iskendro','icarnier@gmail.com','Ivana Skendrovi?','8.Pozarinje 5a','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 21:42:46',0,NULL,3,1,2,1,NULL,'iskendro\r庄'),(10236,676121483018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-25 22:15:17',0,NULL,3,1,8,1,'CP226268925CN ','saud-p\r欧标\r王\r7014\r'),(10237,718782647002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','gmzsur','cosasparafotos@gmail.com','Jose Antonio  Gamez Mangas','MUEBLES CASANDRES Ctra. Badajoz-Montijo km.22 (EX209)','Pueblonuevo del Guadiana','Extremadura','SPAIN','06184','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-25 23:06:43',0,NULL,3,1,2,1,NULL,'gmzsur\r庄'),(10238,792297961015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','jojo_worms','jojo.joannap@googlemail.com','joanna plocienniczak','flat 5, 25 Bath road','cheltenham','Gloucestershire','UNITED KINGDOM','gl53 7hg','07512321028','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-25 23:29:31',0,NULL,3,1,2,1,NULL,'jojo_worms\r庄'),(10239,676059748018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','daldry2531','slayerind@gmail.com','Luke Daldry','7 Moorlands Road','Hectorville','South Australia','AUSTRALIA','5076','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-25 23:39:33',0,NULL,3,1,4,1,'YW865718023CN ','daldry2531'),(10240,676455566018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','nattietheferal','amyl.young@yahoo.com.au','Amy Young','Po box 1338','Millicent','South Australia','AUSTRALIA','5280','0887344188','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-25 23:50:13',0,NULL,3,1,4,1,'YW865718012CN ','nattietheferal\r背景布 两块  （ 白 + 灰）'),(10241,677606224001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','josh_willmont','joshwillmont2004@att.net','Joshua Willmont','904 W Madison St','O Fallon','IL','UNITED STATES','62269-1032','(618) 974-2072','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 00:00:39',0,NULL,3,0,1,1,NULL,'josh_willmont\r58-58mm 双阳环   1'),(10242,730414365017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','jd173','jed5052@gmail.com','John Davis','2 Prahran Ct','ROBINA','Queensland','AUSTRALIA','4226','0417740856','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-26 00:08:14',0,NULL,3,1,2,1,NULL,'jd173\r庄\r'),(10244,676770546018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mihaag85','michelhaag@hotmail.com','Michel Haag','101/6-14 Oxford St','Sydney','New South Wales','AUSTRALIA','2010','0403429154','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,3,1,4,1,'YW865716866CN ','mihaag85\r'),(10245,677423640001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',31.87,'hermeshine','carpediem711','whitehat@gmx.net','Michael Foerster','Theodor-Schnitzler-Weg 2','Koeln Porz','','GERMANY','51149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 02:00:09',0,NULL,3,1,3,1,'RA117738671CN ','carpediem711(已入库)\r52mm-52mm 反接环    1\r52mm-58mm 反接环    1\r58mm-58mm 反接环    1\r热靴盖   2\r大力夹  1\r大力夹云台   1'),(10246,718827833002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','markbls','malpaso@netnitco.net','mark sheptock','10127 Maumee Dr','demotte','IN','UNITED STATES','46310-8403','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 02:29:06',0,NULL,3,1,1,1,' ','markbls'),(10247,718834595002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','mr_geoff2','ihaveteeth@hotmail.com','Geoff Wols','58-60 Redfern Street','Wetherill Park','New South Wales','AUSTRALIA','2165','020401954534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 02:54:43',0,NULL,3,1,2,1,NULL,'mr_geoff2\r庄'),(10248,718839866002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','dethcentral','brotonite@yahoo.com','Jason Huskey','4383 Hardtimes Rd','Prospect','VA','UNITED STATES','23960-7921','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 03:21:15',0,NULL,3,1,1,1,' ','dethcentral'),(10249,677660915001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','taz_ufrj','kiwi2free@yahoo.com','JULIO CORAL','92-28 LAMONT Ave.  FL.3<br>ELMHURST','New York','NY','UNITED STATES','11373','(718) 301-9139','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 04:46:12',0,NULL,3,1,1,1,' ','taz_ufrj'),(10250,675771547001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','koutaun','kchanthanivong@yahoo.com','Phonepraseuth Aun','6315 Canyon Lake Dr','Dallas','TX','UNITED STATES','75249-3019','(214) 288-4825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 04:56:35',0,NULL,3,1,1,1,NULL,'koutaun'),(10251,677664773001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','lillaurie63','laurietom@optonline.net','Laura Lee  Spadaccini','32 lakeside ave','Haskell','NJ','UNITED STATES','07420','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 05:11:40',0,NULL,3,1,1,1,NULL,'lillaurie63'),(10252,677673172001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','shinovi09','caifajuan@hotmail.com','Juan Carlos Romero Lomeli','Fontaneros #776<br>Col. Prados del Nilo','Guadalajara','Jalisco','MEXICO','44840','33 36595441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 06:07:15',0,NULL,3,1,3,1,'RA117738946CN ','shinovi09\r50-70金属卡口棚 里面的四个支架\rRA117774271CN'),(10253,677676621001,110566019452,'JueYing Wireless Remote Control Cord for Sony RM-S1AM',1,'AA3205',18.5,'hermeshine','mc_lopez','mclmascaro@hotmail.com','Maria del Carmen Lopez Mascaro','Avda Puerta del Sol, Edificio Mirador da Frouxeira nº 26, 5ºK','Valdoviño','La Coruna','SPAIN','15552','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 06:26:26',0,NULL,3,1,2,1,NULL,'mc_lopez'),(10254,776240255016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','colinmchugo','colin@mchugo.com','Colin Mc Hugo','15 Waterside Court<br>Malahide','Co Dublin','Dublin','IRELAND','na','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 06:58:07',0,NULL,3,1,2,1,NULL,'colinmchugo'),(10255,715105895002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','1984alez','alexboz@hotmail.it','Alessandro Bozzelli','c.da Collotti, 8','atri','teramo','ITALY','64032','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-26 07:14:56',0,NULL,3,1,3,1,'RA117738725CN ','1984alez'),(10256,676834226018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','osetia1','art-osetia@mail.ru','Ljubishin Andrey','10 street Menzhinsky<br>apartment 26','Bryansk','','RUSSIAN FEDERATION','241020','+79604057018','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-26 07:28:59',0,NULL,3,1,5,1,'CP227125279CN ','osetia1\r白'),(10257,718711690002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','linktothethink','8001@bk.ru','Aleksey Pyatnitskiy','Sovetskaya<br>d.14 kv.22','Reutov','Moskovskaya Oblast','RUSSIAN FEDERATION','143960','+79264639220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 09:26:08',0,NULL,3,1,2,1,NULL,'linktothethink\r庄'),(10258,677714043001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','007kasper','holger.kasper@t-online.de','Holger Kasper','Maximilianstr. 24 a','Berlin','','GERMANY','10317','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-26 09:37:13',0,NULL,3,0,17,0,NULL,'007kasper\r'),(10275,775399258016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','mrjustindallas','studio@impakt.co.za','Justin Dallas','19 Ukosi Road','Kloof','KwaZulu-Natal','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 14:40:47',0,NULL,3,1,17,0,NULL,'mrjustindallas'),(10259,718909087002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','007kasper','holger.kasper@t-online.de','Holger Kasper','Maximilianstr. 24 a','Berlin','','GERMANY','10317','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 09:47:13',0,NULL,3,1,4,1,'YW865717990CN ','007kasper\r摄影背心 蓝色薄 无字    XXXL （已减库）   1\rWFC-592T + WF-570H    1\rtripod  $26'),(10260,676872256018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','dragon15371','patrick15371@hotmail.com','patrick jarvis','p.o. box 1015','bunbury','Western Australia','AUSTRALIA','6231','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-26 10:19:06',0,NULL,3,1,3,1,'RA117738901CN\r ','dragon15371\r75周年那款的L'),(10261,792076331015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','baklan4ikof','saveleva.da@gmail.com','Saveleva Darya','3 Vladimirskaya 8/1-8','Moskow','','RUSSIAN FEDERATION','111123','(926)345-5526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 10:33:29',0,NULL,3,0,2,1,NULL,'baklan4ikof\r1.6x2.1 灰色\r庄'),(10262,718922083002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','acab6961','anousska@hotmail.com','ANA CABANA','PASEO URIBITARTE 8 6B','BILBAO','País Vasco','SPAIN','48001','656767282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 10:43:34',0,NULL,3,1,2,1,NULL,'acab6961\r庄'),(10263,730550431017,270755020831,'800W Red Head for Studio Continuous Light Bulb x 5 220v',2,'AKT059',100,'photographyacc','stingray0','rayjardine118@gmail.com','ray jardine','11a pyrite place','eaglevale','New South Wales','AUSTRALIA','2558','0296039068','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-05-26 11:04:51',0,NULL,3,1,3,1,'RA117738875CN\r ','stingray0'),(10264,730559573017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','digitalebola','anthony@consultexcel.com.au','Kylie and Anthony Martin','20 mallee circuit','pakenham','Victoria','AUSTRALIA','3810','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-26 11:22:05',0,NULL,3,1,2,1,NULL,'digitalebola\r庄'),(10265,718934482002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','banixart','banix.norbi@gmail.com','Norbert Katona','Akácfa utca 17','Dunaújváros','Fejér','HUNGARY','2400','0036703417814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 11:34:14',0,NULL,3,1,2,1,NULL,'banixart\r庄'),(10266,718930041002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','cmor9683','morrisonsgold@yahoo.com','Cynthia Morrison','6271 Ga Highway 41 N','Box springs','GA','UNITED STATES','31801','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 11:39:31',0,NULL,3,1,1,1,NULL,'cmor9683\r'),(10267,730569273017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','becsassine','bec.sassine@hotmail.com','Rebecca Sassine','PO Box 1250','Cronulla','New South Wales','AUSTRALIA','2230','0414308987','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-26 11:57:29',0,NULL,3,1,2,1,NULL,'becsassine'),(10268,718961181002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',10,'AA1301',26,'hermeshine','star031','eric.gueant@aliceadsl.fr','Guéant Eric','11 esplanade Sainte Germaine','Pibrac','Midi-Pyrénées','FRANCE','31820','06.81.86.63.71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:12:13',0,NULL,3,1,3,1,'RA117738773CN\r ','star031'),(10270,718961333002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','plutonioradioattivo','bernardocorsetti@gmail.com','Bernardo Corsetti','via Napoli 10','Fontana Liri','FR','ITALY','03035','0776525067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:13:44',0,NULL,3,1,4,1,'YW865717986CN ','plutonioradioattivo\rtripod  $16'),(10271,674082168001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','fraisy01','tarzan01@sympatico.ca','LOVE YU BIJOUX','JoAnn Huard<br>526 Grande Cote Ouest','Lanoraie','QC','CANADA','J0K 1E0','(514) 237-1625','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:16:01',0,NULL,7,0,18,0,NULL,'fraisy01'),(10272,718725194002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','kozak571','kozak_dp@mail.ru','Alexey Kozak','22 Pisargevskogo str. #12','Dnipropetrovsk','','UKRAINE','49005','380689753950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:33:08',0,NULL,3,1,2,1,NULL,'kozak571\r庄'),(10273,677778340001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:46:50',0,NULL,3,1,2,1,NULL,'viong\r庄'),(10274,718973292002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','norgesmann','trond.oliversen@gmail.com','Trond Oliversen','Gamle Prestveien 38 C','Stavanger','Rogaland','NORWAY','4025','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 13:55:49',0,NULL,3,1,3,1,'RA117738950CN\r ','norgesmann\r闪光灯B座    1\r柔光伞   1\r反光伞   1'),(10276,776380088016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','mrjustindallas','studio@impakt.co.za','Justin Dallas','19 Ukosi Road','Kloof','KwaZulu-Natal','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 15:21:15',0,NULL,3,1,17,0,NULL,'mrjustindallas'),(10277,776386390016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','mrjustindallas','studio@impakt.co.za','Justin Dallas','19 Ukosi Road','Kloof','KwaZulu-Natal','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 15:21:15',0,NULL,3,1,3,1,'RA117738892CN\r ','mrjustindallas\r分2个小包发\r反光板支架    1\r反光板 100*150 40*60 5合1   1\r绿叶 渐变镜 77mm    1\rRA117738861CN\r'),(10278,776394011016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',2,'AC3201',38,'hutongstore','spkvideopro','kopanosvideo@yahoo.gr','SPRYROS KOPANOS','IOANNI DOMPOLI 23','THESSALONIKI','','GREECE','54454','030 2310931146','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 15:23:52',0,NULL,3,1,4,1,'YW865717975CN ','spkvideopro\r4灯头孔   2\r斜臂   1\r'),(10279,719005323002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',108,'hermeshine','mixe-moi','florys@mixe-moi.com','Florys BONNEFOND','14, rue de la Briance','BOSMIE L\'AIGUILE','Limousin','FRANCE','87110','0555361654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 15:38:12',0,NULL,3,1,4,1,'YW865717964CN ','mixe-moi\rreflector holder  $26\r'),(10280,719027956002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','mrc8485','bandj42@comcast.net','william campbell','200 harbor walk dr<br>unit 355','punta gorda','FL','UNITED STATES','33950-3714','(941) 639-9590','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-26 16:41:01',0,NULL,3,1,1,1,NULL,'mrc8485'),(10281,792698884015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','drottningsolid','snuttan7777@hotmail.com','Ann-Kristin Eriksson','Karlhovsvägen 3','Södertälje','','SWEDEN','15137','0735326525','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-26 16:49:28',0,NULL,3,1,4,1,'YW865717953CN ','drottningsolid\r欧标\r庄\r'),(10282,677856977001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','sixties-and-seventies','adnan_pamukcu@hotmail.com','Adnan Pamukçu','Caferaga Mah. Yaver Bey Sok. No. 2/2<br>Moda-Kadiköy','Istanbul','-','TURKEY','34710','902164186956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 17:38:09',0,NULL,3,1,5,1,' CP227125282CN','sixties-and-seventies\r欧标'),(10283,719052894002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','mjasoed','iriska@jucom.lv','Anton Abramov','Sarkandaugavas 33-31','Riga','','LATVIA','LV_1005','+371 29572085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 17:44:32',0,NULL,3,1,3,1,'RA117738858CN\r ','mjasoed'),(10284,719056245002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','butch32154','bobbywhicker@comcast.net','BOBBY WHICKER','122 CHELSEA DR','ERWIN','TN','UNITED STATES','37650-8909','(423) 743-5369','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 17:52:49',0,NULL,3,1,1,1,NULL,'butch32154'),(10285,677869931001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','maflin','maflin.photography@gmail.com','Sébastien  Arsenijevic','6 rue de la faïencerie','Carouge','Genève','SWITZERLAND','1227','0223003343','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-26 18:05:48',0,NULL,3,1,3,1,'RA117738827CN\r ','maflin\r刘'),(10286,677873199001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','13lackspyder','kevin.seto88@gmail.com','Kevin Seto','57 Harkness Dr.','Whitby','ON','CANADA','L1R 0C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:13:29',0,NULL,3,1,17,0,NULL,'13lackspyder'),(10287,677873356001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','13lackspyder','kevin.seto88@gmail.com','Kevin Seto','57 Harkness Dr.','Whitby','ON','CANADA','L1R 0C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:13:28',0,NULL,3,1,3,1,'RA117738813CN\r ','13lackspyder\r圆形柔光棚 40cm   1\r倒影板（白黑）    1'),(10288,719087521002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','rinchai25','rinch25@hotmail.com','Rinchai Chaivaraporn','122/126 Pracha-utit 76, Pracha-utit road<br>Thungkru district','Bangkok','','THAILAND','10140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:55:08',0,NULL,3,1,2,1,NULL,'rinchai25\r方镜卡座 广角托架   2\r方形滤镜接口环 82mm    1\r庄'),(10289,677894024001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','rinchai25','rinch25@hotmail.com','Rinchai Chaivaraporn','122/126 Pracha-utit 76, Pracha-utit road<br>Thungkru district','Bangkok','','THAILAND','10140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 18:55:09',0,NULL,3,1,17,0,NULL,'rinchai25'),(10290,677050818018,280663389140,'Professional Photo Studio Continuous Lighting Kit boom',1,'AKT066',200,'photographyacc','d.loffler','dloffler@gmail.com','Danilo  Loffler','Rua Dr. Faivre, 855 Centro','Curitiba','Paraná','BRAZIL','80060-140','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-26 19:00:49',0,NULL,3,1,5,1,'CP226268948CN','d.loffler\r欧标\r庄 '),(10291,776516829016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','grella81','grethe81@hotmail.com','Grethe Øyeflaten','Skulestadvegen 150','Skulestadmo','','NORWAY','5710','+4748298939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 19:22:23',0,NULL,3,1,2,1,NULL,'grella81\r庄'),(10292,792812758015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','moppersmurfje1971','mario@redeker.nl','Mario Redeker','Elise van Calcarstraat 66','Den Haag','','NETHERLANDS','2522MD','0622929989','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 20:08:34',0,NULL,3,1,2,1,NULL,'moppersmurfje1971\r庄'),(10293,677904955001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','valerafoto','lvv-i@yandex.ru','Valera Lankov','bulvar Karpova dom 11 kv.73','Miass','chelyabinskay obl','RUSSIAN FEDERATION','456300','89080585919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 20:10:54',0,NULL,3,1,2,1,NULL,'valerafoto\r庄'),(10294,677939692001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','thedunker','dw1campbell@comcast.net','Duncan Campbell','1561 Kinross Ln','Keswick','VA','UNITED STATES','22947-9112','(434) 984-1873','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-26 20:34:10',0,NULL,3,1,3,1,'RA117738835CN\r ','thedunker\r刘'),(10295,792854230015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','lucyloophole','sherbert_lemon@hotmail.com','Lesley Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 21:29:25',0,NULL,3,1,2,1,NULL,'lucyloophole\r庄'),(10296,730804023017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','desiderius68','zeljko.smolec1@zg.t-com.hr','Zeljko Smolec','Gjalskoga 78','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-26 21:32:07',0,NULL,3,1,2,1,NULL,'desiderius68\r庄'),(10297,792856370015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','tcatseller','tcatcarson@yahoo.co.uk','Lee Carson','34 Chesser Grove','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH141SZ','01314432688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-26 21:34:39',0,NULL,3,1,2,1,NULL,'tcatseller'),(10298,677966891001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','josemartinp','josemartinp1@gmail.com','jose martin-serrano peña','Av. Juan Gris, 61','Villanueva de la Cañada','Madrid','SPAIN','28691','918157702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-26 21:48:10',0,NULL,3,1,3,1,'RA117738844CN\r ','josemartinp\r刘'),(10299,792871368015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',49.98,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-26 22:12:58',0,NULL,3,1,17,1,NULL,'zuhmia'),(10300,792870839015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 22:12:59',0,NULL,3,1,17,1,NULL,'zuhmia'),(10301,776600745016,260660050260,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-26 22:12:59',0,NULL,3,1,4,1,'YW865718056CN\r','zuhmia\r申报:Lighting Kit\r倒影板（白黑）   1\r柔光箱 60-60cm  四灯头    1  欧标\r115w 5500k 灯泡  220v    4\rc型夹    4\r庄 \r点不了已发货，其实已经发了。\r'),(10302,677980303001,110618902967,'Pro Photo Vest Blue for Canon 500D 550D 7D 60D  user',1,'AA2116',32,'hermeshine','byungkhyun','hbk0191@gmail.com','Byung Hyun','1118 S Spaulding Ave<br>Apt 7','Los Angeles','CA','UNITED STATES','90019-2413','(818) 370-0090','NoPaymentFailure','CheckoutComplete','Other','2011-05-26 22:35:24',0,NULL,3,1,1,1,' ','byungkhyun\r3XL(没入库)'),(10303,677987790001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','kadaus_maximus','spin_king69@hotmail.com','Kade Moir','10 Loretta Ave','Cairns','Queensland','AUSTRALIA','4870','070409599476','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,' ','kadaus_maximus\r庄\r'),(10304,719198605002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','fotografitty','pablojmutal@yahoo.com.ar','Pablo Javier Mutal','Av. Rafael Nuñez 3884<br>Barrio. Cerro de Las Rosas','Cordoba','Cordoba','ARGENTINA','5009','03543-496695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 00:12:54',0,NULL,3,1,3,1,'RA183619211CN\r ','fotografitty\r庄\r-----\r0713客户要求重发(已入库)\r'),(10305,730856557017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','vitothiago','thiagovito@gmail.com','Thiago Vito - Nextgen Gaming','Level 5<br>189 Miller Street','North Sydney','New South Wales','AUSTRALIA','2060','0299649111','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-27 00:51:44',0,NULL,3,1,17,0,NULL,'vitothiago'),(10306,677172854018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','vitothiago','thiagovito@gmail.com','Thiago Vito - Nextgen Gaming','Level 5<br>189 Miller Street','North Sydney','New South Wales','AUSTRALIA','2060','0299649111','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-27 00:51:45',0,NULL,3,1,3,1,'RA117738889CN\r ','vitothiago\r2云柔    1\r肩带 Q-strap 单    1\r'),(10307,719213178002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','logtar','john.guzman@gmail.com','John Guzman','1719 Grove St<br>Apt 20','Glenview','IL','UNITED STATES','60025-3050','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 01:11:56',0,NULL,3,1,1,1,NULL,'logtar'),(10308,678020092001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','tao1964','pfong@sirinna.com','Po   Fong','12 Brookhill Rd','East Brunswick','NJ','UNITED STATES','08816-2908','(732) 432-9803','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 01:41:06',0,NULL,3,1,1,1,' ','tao1964'),(10309,677186558018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','gonewiththegarage','fernandoaesteves@hotmail.com','Fernando Esteves','Alameda dos Oceanos, Lote 4.32.01-D, 1ºA','Lisboa','','PORTUGAL','1990-238','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-27 01:49:54',0,NULL,3,1,2,1,NULL,'gonewiththegarage'),(10310,678046333001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','greenoysteronline','ebay@greenoyster.com','Jeremy Coffey','7516 NW 36th Ave','Gainesville','FL','UNITED STATES','32606','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-27 04:04:42',0,NULL,3,1,17,0,NULL,'greenoysteronline'),(10311,678046216001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','greenoysteronline','ebay@greenoyster.com','Jeremy Coffey','7516 NW 36th Ave','Gainesville','FL','UNITED STATES','32606','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-27 04:04:43',0,NULL,3,1,1,1,NULL,'greenoysteronline\r绿叶 UV  77mm   1\r绿叶 渐变镜   77mm    1'),(10312,678046471001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 04:05:21',0,NULL,3,1,17,0,NULL,'ciafquito'),(10313,719248222002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',2,'AB1305',7.58,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 04:05:22',0,NULL,3,1,17,0,NULL,'ciafquito'),(10314,719248488002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 04:05:23',0,NULL,3,1,3,1,'RA117738932CN ','ciafquito\r绿叶 CPL  67mm   1\r绿叶 ND8  67mm   1\r橡胶遮光罩 67mm   2'),(10315,678051009001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','ebla3736','eddieblack85@hotmail.com','Sgt. Black','7908 N Tokay Ave<br>Spc 53','Fontana','CA','UNITED STATES','92336-1802','(909) 631-0423','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-27 04:28:45',0,NULL,3,0,3,1,'RA117738915CN ','ebla3736\r110v\r404\r0630-0708来信说已经收到'),(10316,678055485001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',220,'hermeshine','sh8p4holic','jelliphish77@yahoo.com.au','Kelly Reynolds','37 Spiller St','Brandon','Queensland','AUSTRALIA','4808','','NoPaymentFailure','CheckoutComplete','AU_Express','2011-05-27 04:59:27',0,NULL,3,1,4,1,'YW865717920CN ','sh8p4holic\r澳标  白布'),(10317,719260461002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',4,'AE3104',38.72,'hermeshine','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 05:15:57',0,NULL,3,0,17,0,NULL,'zuhmia'),(10318,719260915002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vipzonestudio','vipzone@list.ru','Valeriy Potapenko','ул. Николая Василенко дом 17 кв. 15','Киев','','UKRAINE','03124','+380503234668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 05:20:57',0,NULL,3,1,2,1,NULL,'vipzonestudio'),(10319,678061486001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','shicoera','chicovera@gmail.com','felipe vera','Av. pedro lira urquieta 10731','Santiago','lo barnechea, región metropolitana','CHILE','n/a','569-9-4370873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 05:43:45',0,NULL,3,1,3,1,'RA117738929CN ','shicoera\r220v'),(10320,719272076002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeongsookim','red567g@naver.com','jeongsookim','835 N 50 E<br>Apt 120','provo','UT','UNITED STATES','84604-6539','(801) 691-4945','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','jeongsookim'),(10321,677240661018,280680853908,'JYC-C1 Wireless Remote Control for Canon 60D 550D 450D',1,'AA3203',18,'photographyacc','jeremyverdouw','jezverdouw@gmail.com','Jeremy Verdouw','11 Snow Gum Drive','Snug','Tasmania','AUSTRALIA','7054','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-27 06:43:49',0,NULL,3,1,2,1,' ','jeremyverdouw'),(10322,719274616002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 06:47:10',0,NULL,3,1,17,0,NULL,'aaivanov'),(10323,719275074002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 06:48:51',0,NULL,3,1,2,1,NULL,'aaivanov\r天涯 cpl 52mm    1\r绿叶 UV  52mm    1'),(10324,776734962016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','fej2000bay','fej2000@hotmail.com','Frederik Jensen','Rådmandsgade 61, 5. 507','København N','','DENMARK','2200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 07:47:17',0,NULL,3,1,2,1,NULL,'fej2000bay'),(10325,677748214001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','aproximos','xaniared@gmail.com','Ioannis Mathioudakis','Fallasarnis 33','xania','Xanion','GREECE','73100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 07:51:37',0,NULL,3,1,2,1,NULL,'aproximos'),(10326,719287091002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','xtanda','xtanda@ieee.org','Denis Kristanda','PO BOX 4102','Macquarie Center','New South Wales','AUSTRALIA','2113','0402672599','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-27 08:16:33',0,NULL,3,0,3,1,'RA117738985CN\r ','xtanda\r背心 Canon  老款  3XL    1(已入库)'),(10327,730937099017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','john.moh','valdracool@hotmail.com','Jonathan Mohabuth','6 Abbotford','Sydney / Kensington','New South Wales','AUSTRALIA','2033','0430969846','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-27 08:17:58',0,NULL,3,1,2,1,NULL,'john.moh'),(10328,719294751002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','karakai.andras','karakai.andras@gmail.com','András Karakai','Szabadság u. 14.','Söjtör','Zala','HUNGARY','H-8897','36209789402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 08:26:32',0,NULL,3,1,2,1,NULL,'karakai.andras'),(10329,677263573018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','sanne-balou','swindworley@adam.com.au','Sandra Wind','25 Gault road','Belair','South Australia','AUSTRALIA','5052','0883702084','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-27 08:29:48',0,NULL,3,1,3,1,'RA117738994CN\r ','sanne-balou'),(10330,678099982001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','gunn-rnd','naturra@list.ru','Igor Lugancev','40 let Pobedy 79,  154','Rostov-na-Donu','','RUSSIAN FEDERATION','344111','89198935203','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 09:02:50',0,NULL,3,1,5,1,'CP227125543CN ','gunn-rnd'),(10331,678110114001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','RU','RUSSIAN FEDERATION','628624','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-27 09:45:05',0,NULL,3,0,3,1,'RA117737398CN\r ','motorfoto\r摄影背心 红色薄 sony  3XL   1(已入库)'),(10332,677284778018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-27 10:01:39',0,NULL,3,1,2,1,NULL,'bfg27248937'),(10333,793051782015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ziedlapis','zieduna.gedgaudaite@gmail.com','ANDRIUS  R.','38 GROOMBRIDGE CL','WELLING','Kent','UNITED KINGDOM','DA162BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-27 10:01:52',0,NULL,3,1,2,1,NULL,'ziedlapis'),(10334,719078319002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','spzphoto','info@spzphoto.gr','Spiros Zacharakis','Digeni Akrita 3','Chania','Crete','GREECE','73100','00302821054282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 10:09:39',0,NULL,3,1,4,1,'YW865716844CN\r ','spzphoto\rtripod  $26\r'),(10335,730975465017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','dixon3100','kdix3148@bigpond.net.au','Keith Dixon','167 Belgrave Esplanade','Sylvania','New South Wales','AUSTRALIA','2224','0295223117','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-27 10:11:53',0,NULL,3,1,2,1,NULL,'dixon3100'),(10336,674032204001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','manolovian','mvianh@hotmail.com','Manuel Vian Hernando','C/ San juan 11-13 1ºB<br>Medina de Rioseco','Valladolid','Castilla y León','SPAIN','47800','650478444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 10:58:03',0,NULL,3,1,3,1,'RA117737248CN\r ','manolovian\r1.6x2.1m 背景布    3  (白+黑+粉)'),(10337,678130694001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:10:50',0,NULL,3,1,3,1,'RA117737194CN\r ','junglistic_maxim'),(10338,678133976001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','hankyvarta1952','hankyvarta@gmail.com','henk vaags','Malrove 86','APELDOORN','','NETHERLANDS','7322GC','0613238741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:25:44',0,NULL,3,1,2,1,NULL,'hankyvarta1952'),(10339,718561576002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','mx-vice','mx.ryabov@gmail.com','Maxim Ryabov','Yakubovskogo str., 59-53','Mogilev','Mogilev region','BELARUS','212026','+375291286657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:28:38',0,NULL,3,1,2,1,' ','mx-vice'),(10340,678136793001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jukachujukachu','jukachu@gmail.com','IVAN JUKIĆ','MARJANSKI PUT 23','SPLIT','CROATIA','CROATIA','21000','38521271379','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:36:17',0,NULL,3,1,2,1,NULL,'jukachujukachu'),(10341,678138546001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','im.simply.me','naturallymorbid@gmail.com','Matan Eshel','Antot 12A','Tel Aviv','','ISRAEL','69080','0545806362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 11:44:04',0,NULL,3,1,3,1,'RA117737129CN\r ','im.simply.me'),(10342,793085301015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','arabian82','fizza_sabir@yahoo.co.uk','Fizza Sabir','29 Lascelles road','slough','Berkshire','UNITED KINGDOM','SL3 7PN','01753539072','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-05-27 11:49:24',0,NULL,3,1,4,1,'YW865716833CN\r ','arabian82\rbackdrop system\r白+黑'),(10343,793096969015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',16,'hutongstore','ondon1501','klinc@volny.cz','Ondrej Kincl','Pod Zameckem 1057','Hradec Kralove','','CZECH REPUBLIC','50006','490510548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 12:25:10',0,NULL,3,1,3,1,'RA117737336CN\r ','ondon1501'),(10344,677335664018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','gremax5','gremax5@optusnet.com.au','Greg Curwood','15 Tucker Rd','Vermont','Victoria','AUSTRALIA','3133','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-27 13:02:03',0,NULL,3,1,3,1,'RA117737177CN','gremax5\r再发一个斜臂里的袋子给他，说上次漏发了'),(10345,731034428017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','bockie09','datbock@gmail.com','Douglas Bock','6 Bailey Street','Collingwood Park','Queensland','AUSTRALIA','4301','0738183335','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-27 13:32:03',0,NULL,3,1,2,1,NULL,'bockie09'),(10346,719372887002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','rcares','rodolfo.cares@gmail.com','Rodolfo Cares Moreno','Pasaje Dos 2862','Independencia','Metropolitana','CHILE','8380730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 13:36:39',0,NULL,3,1,3,1,'RA117737185CN\r ','rcares'),(10347,719374441002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jujulitaliano','juju2381@hotmail.fr','JULIEN MARGARITTA','12 SQUARE DU LIMOUSIN','PARIS','Ile-de-France','FRANCE','75013','06.72.22.06.24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 13:41:39',0,NULL,3,1,2,1,NULL,'jujulitaliano'),(10348,793134848015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mackem1966','darrengoodlad@hotmail.co.uk','DARREN GOODLAD','64 RODIN AVENUE<br>WHITELEAS ESTATE','SOUTH SHIELDS','Tyne and Wear','UNITED KINGDOM','NE34 8JA','07947574625','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-27 14:08:03',0,NULL,3,1,2,1,NULL,'mackem1966'),(10349,678179611001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','gerty-dreamer','h_ohtsu@hokuriku.me','Ohtsu Kouhei','4035-1, Ngasawa, Fuchu-machi','Toyama-shi','Toyama','JAPAN','939-2606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 14:08:17',0,NULL,3,1,11,1,NULL,'gerty-dreamer\r白 1.6x2.1 '),(10350,793172523015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','vanda_c_oliveira','vanda.c.oliveira@gmail.com','Vanda Oliveira Marques','Urbanização da Matinha, Edificio Verde<br>Rua 2, 3º Esq.º','Lisboa','Portugal','PORTUGAL','1950-073','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 15:35:18',0,NULL,3,1,3,1,'RA117737115CN\r ','vanda_c_oliveira'),(10351,793188095015,250692241086,'YongNuo SF-18 Flash Battery Pack 8*AA for Nikon SB900',1,'AB3311',32.99,'hutongstore','iwan16','_sommi_@web.de','Benjamin Sommer','Großenhainer Str 130','Dresden','','GERMANY','01129','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-27 16:10:43',0,NULL,3,1,3,1,'RA117737075CN\r ','iwan16'),(10352,678219492001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','alemirbe','consultasurologia@gmail.com','Alejandro Miranda Benabarre','Los Militares 5326. Departamento 162TO<br>Las Condes','Santiago','RM','CHILE','7560871','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 16:33:53',0,NULL,3,1,2,1,NULL,'alemirbe'),(10353,678241925001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','heathermurray77','cherishedmemoriesforever@yahoo.ca','Heather Murray','386 Elmwood Drive','Belleville','ON','CANADA','K8N 4Z4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 17:02:02',0,NULL,3,1,2,1,NULL,'heathermurray77'),(10354,731124454017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',58,'photographyacc','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-27 17:29:04',0,NULL,3,1,3,1,'RA117737424CN\r ','m.petrosyan\r'),(10355,677459970018,280680853908,'JYC-C1 Wireless Remote Control for Canon 60D 550D 450D',1,'AA3203',18,'photographyacc','24599bro','noshab@talktalk.net','norman brown','6 saffron close<br>padgate','warrington','Cheshire','UNITED KINGDOM','wa2 0qz','01925816003','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-27 18:31:48',0,NULL,3,1,2,1,NULL,'24599bro'),(10356,719482271002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','denistenchi','tenchido@gmail.com','Denis Kriga','Orehovaya str.<br>house 9, flat 8','Kaliningrad','Kaliningrad','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 18:42:04',0,NULL,3,1,3,1,'RA117737455CN\r ','denistenchi'),(10357,731195006017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','nhp-hank289c','davel49@yahoo.com','derrick lawless','1707 E Main St','Olney','IL','UNITED STATES','62450-3156','(618) 395-3945','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-05-27 20:01:26',0,NULL,3,1,4,1,'YW865716822CN\r ','nhp-hank289c\r申报: Lighting Kit, 25$\r灯泡  110v\r'),(10358,719521036002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','golf_bkkfixed','goodguystudio@yahoo.com','thamrat panpumchuen','7/2 moo5 Bangyarprak','phrapradang','Samut Prakan','THAILAND','10130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 20:14:08',0,NULL,3,1,2,1,NULL,'golf_bkkfixed'),(10359,793323833015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','balla3998','harleykim159@googlemail.com','kim maurer','56 Byron Road<br>Greenmount','Bury','Lancashire','UNITED KINGDOM','BL8 4EN','07903784400','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-27 20:35:26',0,NULL,3,1,17,0,NULL,'balla3998'),(10360,793322550015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','balla3998','harleykim159@googlemail.com','kim maurer','56 Byron Road<br>Greenmount','Bury','Lancashire','UNITED KINGDOM','BL8 4EN','07903784400','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-27 20:35:27',0,NULL,3,1,2,1,NULL,'balla3998\r镜头筒 小号    1\r镜头筒 xl 大号    1'),(10361,677520056018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',2,'AD1110',40,'photographyacc','tomerba','tomermazal@gmail.com','tomer badani','haliyot 19','hod hasharon','israel','ISRAEL','45111','97297451551','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-27 20:48:08',0,NULL,3,1,3,1,'RA117737092CN\r ','tomerba'),(10362,719551723002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 21:38:41',0,NULL,3,1,3,1,'RA117737251CN\r ','tawfeekmohammed'),(10363,719562681002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','strange_v','strange.rand@gmail.com','Volodymyr Fuchenko','Gnata Hotkevucha 65a/57','Ivano-Frankivsk','','UKRAINE','76002','+38 095 4089373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 22:05:22',0,NULL,3,1,2,1,NULL,'strange_v'),(10364,719567025002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','mega_uno','mblecker@rogers.com','Matt Blecker','37 Arjay Trail','Brampton','ON','CANADA','L6X 4M4','(905) 455-4486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 22:18:36',0,NULL,3,1,17,0,NULL,'mega_uno'),(10365,719566238002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','mega_uno','mblecker@rogers.com','Matt Blecker','37 Arjay Trail','Brampton','ON','CANADA','L6X 4M4','(905) 455-4486','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 22:18:37',0,NULL,3,1,3,1,'RA117737279CN\r ','mega_uno\r摄影背心 冬夏  L    1\r摄影背心 冬夏 XL    1'),(10366,777088115016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','whs8293','billspencer47@googlemail.com','Mr W. Spencer','5 High Street<br>Gnosall','Stafford','Staffordshire','UNITED KINGDOM','ST20 0EX','01785823821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-27 22:23:36',0,NULL,3,1,2,1,NULL,'whs8293'),(10367,719580903002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','micmic1987','micmic87@hotmail.com','Michael Wong','74 East 56th ave','Vancouver','BC','CANADA','v5x 1p8','(778) 865-8855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-27 23:13:09',0,NULL,3,1,2,1,NULL,'micmic1987'),(10368,731267835017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','elarroyojc','arroyojcar@yahoo.es','Juan Carlos Arroyo Rodríguez','Calle El Saltillo 36','Zaratán (Valladolid)','Castilla y León','SPAIN','47610','649274592','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-27 23:40:50',0,NULL,3,1,2,1,NULL,'elarroyojc'),(10369,730863021017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',9.78,'photographyacc','zboost07','downtime_solutions@bigpond.com','Shane Downes','70A Phillipson Road','Charters Towers','Queensland','AUSTRALIA','4820','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-28 00:14:46',0,NULL,3,1,2,1,NULL,'zboost07\rNikon 62mm 镜头盖   1\rNikon 肩带    1'),(10370,719270434002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',10.4,'hermeshine','kirst0705','stolls3@bigpond.com','Kirsty Stoll','7 Norwood St, Glen Iris','Melbourne','Victoria','AUSTRALIA','3146','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 00:28:16',0,NULL,3,1,2,1,NULL,'kirst0705'),(10371,777127346016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',2,'AC1302',12.2,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 01:20:54',0,NULL,3,1,17,0,NULL,'eivindtafto'),(10372,793408691015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',2.48,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 01:20:55',0,NULL,3,1,17,0,NULL,'eivindtafto'),(10373,793408785015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',1.88,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 01:20:55',0,NULL,3,1,17,0,NULL,'eivindtafto'),(10374,793409740015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',4.3,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 01:34:20',0,NULL,3,1,17,0,NULL,'eivindtafto'),(10375,793408601015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','eivindtafto','eivind.tafto@gmail.com','Eivind Taftoe','Skjetnemarkvegen 68','TRONDHEIM','','NORWAY','7081','(47) 90014316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 01:34:21',0,NULL,3,1,3,1,'RA117737469CN\r ','eivindtafto\r镜头筒 小号   1\r带水平仪 热靴保护盖    1\rNIKON 镜头盖 67mm   1\r镜头筒 中号    1\r大号内胆包 无字    2'),(10376,719614999002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','samysandiving','adrozdovs@gmail.com','Alexander Drozdov','Rigas Rajons<br>Lauku Ter. \"Dundurini\" Tilderi','Riga','Salaspils','LATVIA','LV-2121','+37126741781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-28 02:00:25',0,NULL,3,1,3,1,'RA117737234CN\r ','samysandiving'),(10377,677604594018,280680835308,'YongNuo Wireless Studio Flash Camera Trigger CTR-301P',1,'AKT013',26,'photographyacc','hildaxe','john@manageperformance.com','John B Sullivan','PO Box 1340','Runaway Bay','Queensland','AUSTRALIA','4216','0755308820','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-28 02:34:48',0,NULL,3,1,2,1,NULL,'hildaxe'),(10378,719637620002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','pfartbat','jistrong@bentonrea.com','James A. Strong Jr','2433 G. Washington Way, APT 7202','Richland','WA','UNITED STATES','99354','(509) 375-1024','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-28 04:09:47',0,NULL,3,1,1,1,NULL,'pfartbat'),(10379,678431606001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',59.99,'hermeshine','ksmolka','kurt.smolka@optus.com.au','Kurt Smolka','1 Lyonpark Rd','Macquarie Park','New South Wales','AUSTRALIA','2113','610415581333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-28 04:27:39',0,NULL,3,1,3,1,'RA117737217CN\r ','ksmolka'),(10380,719640481002,120454225464,'Green.L 52mm Neutral Density ND8 Filter ND 8 52',1,'AE2308',5.8,'hermeshine','anterow','antero1966@hotmail.com','antero williams luna arrarte','jr.juana riofrio 126 Urb. pando   San miguel','Lima','lima','PERU','32','5660867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 04:28:27',0,NULL,3,1,2,1,NULL,'anterow'),(10381,678432471001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','timboakers33eb','timboakers@aol.com','Timothy W. Akers','1080 Stonebridge Park Dr','Franklin','TN','UNITED STATES','37069-4000','(615) 370-5738','NoPaymentFailure','CheckoutComplete','Other','2011-05-28 04:31:55',0,NULL,3,1,3,1,'RA117737132CN\r ','timboakers33eb\r0630-0712-0717来信说已收到'),(10382,677656353018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','alesshans','yi2han@hotmail.com','Yih Han Tan','492A-3-17,<br>JALAN AIR ITAM','AIR ITAM','PENANG','MALAYSIA','11400','0174011007','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-28 07:34:58',0,NULL,3,1,2,1,NULL,'alesshans'),(10383,678463733001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3302',5.9,'hermeshine','jogananda_subudhi','joganandasubudhi@gmail.com','chinamcheti Jogananda subudhi','Finsensvej 37B 1 tv','Frederiksberg','','DENMARK','2000','004551284777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 07:42:34',0,NULL,3,1,2,1,NULL,'jogananda_subudhi'),(10384,793503056015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','pdonnelly1988','pdonnelly88@gmail.com','Paul Donnelly','51 Tickner CLose<br>Botley','Southampton','Hampshire','UNITED KINGDOM','so30 2sw','01489789265','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 08:16:22',0,NULL,3,1,2,1,NULL,'pdonnelly1988'),(10385,793505200015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','westsidecreations','johnmerritt4@yahoo.com','John Merritt','48 Station Road','Forest gate','London','UNITED KINGDOM','E7 0ET','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 08:20:47',0,NULL,3,1,3,1,'RA117737163CN\r ','westsidecreations'),(10386,793506205015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','alextai6','alextai60@yahoo.com','alex tai tai','38,Jalan Rejang 7,Setapak Jaya','Kuala Lumpur','W Persekutuan','MALAYSIA','53300','016-6568053','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 08:25:14',0,NULL,3,1,17,0,NULL,'alextai6'),(10387,793505847015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','alextai6','alextai60@yahoo.com','alex tai tai','38,Jalan Rejang 7,Setapak Jaya','Kuala Lumpur','W Persekutuan','MALAYSIA','53300','016-6568053','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 08:25:15',0,NULL,3,1,2,1,NULL,'alextai6\r橡胶遮光罩 58mm    1\r橡胶遮光罩 52mm    1'),(10388,678474689001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','goyotiti','goyosam@terra.es','Gregorio Samperio Rodriguez','C/ Francisco Rivas Moreno, Nº 8 - 2º C','Santander','Cantabria','SPAIN','39011','675185443','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 08:30:05',0,NULL,3,1,4,1,'YW865716855CN ','goyotiti\r申报:tripod  $22'),(10389,719681709002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 08:31:03',0,NULL,3,1,3,1,'RA117737101CN\r ','luizfernandoborgesnomura\r1.6x3m 白色'),(10390,677670662018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','mushroomstyle','bboymorales@tiscali.it','giuseppe volpe','via antonio muscettola 24','napoli','NA','ITALY','80147','3663214786','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-28 08:36:05',0,NULL,3,1,2,1,NULL,'mushroomstyle'),(10391,678488836001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','tomer1983','tomerbenita@gmail.com','Tomer Benita','PO box 2746 ,shikun hamizrach','Rishon Lezion','','ISRAEL','PO 2746','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 09:28:18',0,NULL,3,1,2,1,NULL,'tomer1983'),(10392,678494423001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3305',7.32,'hermeshine','a-hilh','a-hilh@zonnet.nl','Anton Hilhorst','De Molle 23','Gelselaar','','NETHERLANDS','7275 AS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 09:50:41',0,NULL,3,1,2,1,NULL,'a-hilh'),(10393,677705992018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','industrial_dave_supreme','davidlongford@hotmail.com','David Longford','11 Ringtail Circuit','Blackbutt','New South Wales','AUSTRALIA','2529','0242969762','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-28 10:47:20',0,NULL,3,1,2,1,NULL,'industrial_dave_supreme'),(10394,678512154001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','acidophilis','sk8erkidstack@yahoo.com','Tyler Stackhouse','6705 Greenleaf Dr','Citrus Heights','CA','UNITED STATES','95621-6354','(916) 889-9134','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-28 11:01:08',0,NULL,3,1,1,1,NULL,'acidophilis'),(10395,793563327015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','animilesprower','kimball.evans@gmail.com','Peter Kimball-Evans','15 College Road','Fishponds','Bristol','UNITED KINGDOM','BS16 2HN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 11:28:48',0,NULL,3,1,2,1,NULL,'animilesprower'),(10396,731437403017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','calmsoul88','calmsoul88@hotmail.com','Yosh Ricardo','#809/270 King Street','Melbourne','Victoria','AUSTRALIA','3000','0396003670','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-28 12:24:04',0,NULL,3,1,2,1,NULL,'calmsoul88'),(10397,719756485002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','john.wellington','johnw1973@hotmail.com','john wellington','rua mata grande 569 apto. 302<br>vila valqueire','rio de janeiro','rio de janeiro','BRAZIL','21321540','2124549019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:04:22',0,NULL,3,1,17,0,NULL,'john.wellington'),(10398,719757401002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','john.wellington','johnw1973@hotmail.com','john wellington','rua mata grande 569 apto. 302<br>vila valqueire','rio de janeiro','rio de janeiro','BRAZIL','21321540','2124549019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:06:46',0,NULL,3,1,17,0,NULL,'john.wellington'),(10399,719758110002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','john.wellington','johnw1973@hotmail.com','john wellington','rua mata grande 569 apto. 302<br>vila valqueire','rio de janeiro','rio de janeiro','BRAZIL','21321540','2124549019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:09:02',0,NULL,3,1,3,1,'RA117737472CN\r ','john.wellington\r欧标\r绿叶 UV  72mm   1\r灯架  2m    1\r单灯头   1\r反光伞   1\r柔光伞   1'),(10400,719763984002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','1865582','bbrv@inbox.ru','Konstantin V. Bobrov','pr. Bolshevikov, d. 13 korp. 3, kv. 43','St. Petersburg','Russia','RUSSIAN FEDERATION','193168','+7 911 7413079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 13:28:45',0,NULL,3,1,2,1,NULL,'1865582\r留意一下是2只\r'),(10401,677756151018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','ollllllo','v.sam.v@hotmail.com','NanZhu Li, Sam','Blk 22 Boon Lay Way #01-58 Tradehub 21','default','','SINGAPORE','609968','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-28 13:34:21',0,NULL,3,1,3,1,'RA117737340CN\r ','ollllllo'),(10402,793635696015,250693635105,'TianYa 77mm ND8 filter New 77 Neutral Density Grey NIB',2,'AA2314',11.56,'hutongstore','aerosoulzx','aerosoulz_x@hotmail.co.uk','Ian McDowall','Fron Deg<br>Caergeiliog','HOLYHEAD','Isle of Anglesey','UNITED KINGDOM','LL65 3YD','07833967846','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 14:29:38',0,NULL,3,1,2,1,' ','aerosoulzx'),(10403,719792394002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','z_likar','z_likar@yahoo.com','Zoran Likar','64 A  HASSETT  CRES','Keilor East','Victoria','AUSTRALIA','3033','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-28 14:52:06',0,NULL,3,1,3,1,'RA117737353CN\r ','z_likar'),(10404,777370392016,260660056304,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','millwall_200','mark.bigeagle@googlemail.com','mark pullen','37 Greenfields<br>Sellindge','Ashford','Kent','UNITED KINGDOM','TN25-6HF','01303814647','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 15:13:45',0,NULL,3,1,2,1,NULL,'millwall_200'),(10405,677793917018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','jonathanw9113','jpward7@btopenworld.com','Jonathan Ward','21 Church Hill','Aldershot','Hampshire','UNITED KINGDOM','GU12 4JT','01252320210','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-28 15:14:53',0,NULL,3,1,2,1,NULL,'jonathanw9113'),(10406,731004106017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',65.85,'photographyacc','girformi','ale.zanet@gmail.com','Alessandro Zanetti - Plantechno','Via Staffolo 60','Vicomoscano','CR','ITALY','26040','3473134449','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-28 15:54:53',0,NULL,3,1,3,1,'RA117737322CN\r ','girformi\r反光板  80cm 5合1   1\r60cm 柔光棚   1\r爵影无线快门线N1      1\rreflector  $15\r\r'),(10407,773131868016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jacobass87','sargonlunghi@virgilio.it','Giacomo Saragoni Lunghi','viale<br>don bosco 24','Macerata','MC','ITALY','62100','3299573035','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-28 16:50:37',0,NULL,3,1,4,1,'YW865716800CN\r ','jacobass87\r欧标\r申报:Lighting Kit, $40\r'),(10408,678635923001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','floydavenir','artem007@sibmail.com','Артем Григорьев','Интернационалистов 3-66','Томск','','RUSSIAN FEDERATION','634059','(952)805-6500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 17:08:51',0,NULL,3,1,2,1,NULL,'floydavenir'),(10409,793722587015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','masterkata','adrian@zenshinkai.com','Mr A Elven','26 Burleigh Piece','Buckingham','Buckinghamshire','UNITED KINGDOM','MK18 7BB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 17:30:24',0,NULL,3,1,2,1,NULL,'masterkata'),(10410,719856067002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','macavibo','marcelocvb@gmail.com','Marcelo Carvalho','Rua São Francisco Xavier<br>553 / 603 apto','Rio de Janeiro','Rio de Janeiro /RJ','BRAZIL','20550-011','55-21-86072889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 17:36:53',0,NULL,3,1,3,1,'RA117734286CN\r ','macavibo'),(10411,719857924002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','dressskara','tradera@telia.com','Jenny Johannesson','Brunsbogatan 40','Skara','','SWEDEN','S53238','+4651118218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 17:40:56',0,NULL,3,1,2,1,NULL,'dressskara'),(10412,719863444002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zoomiedoc','mcdavidst@aol.com','Stephen McDavid','3611 Perryman Rd','Ocean Springs','MS','UNITED STATES','39564','(228) 818-0122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 17:53:57',0,NULL,3,1,1,1,NULL,'zoomiedoc'),(10413,793737686015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',29,'hutongstore','jondel84','joni.linna@netikka.fi','Joni Linna','Loimitie 159','Vaasa','Vaasa','FINLAND','65300','+358503308025','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-28 17:59:44',0,NULL,3,1,3,1,'RA117737225CN\r ','jondel84\r反光伞   1\r2云柔    1'),(10414,793738877015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',6.2,'hutongstore','jondel84','joni.linna@netikka.fi','Joni Linna','Loimitie 159','Vaasa','Vaasa','FINLAND','65300','+358503308025','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 17:59:44',0,NULL,3,1,17,0,NULL,'jondel84'),(10415,678658964001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','ferryratel','ferry_vs_jason@hotmail.com','Ferry Ratelband','haagsebos 152<br>Netherlands','Zoetermeer','','NETHERLANDS','2715XX','1244-0649894169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 18:03:37',0,NULL,3,1,2,1,NULL,'ferryratel'),(10416,793749570015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','daniele82111','teko@2die4.com','Daniele Caneve','Via General Cantore 56','Puos D\'Alpago','BL','ITALY','32015','0437-46311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 18:18:12',0,NULL,3,1,2,1,NULL,'daniele82111'),(10417,777479808016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','babio10','michelleponte@supanet.com','Michelle Ponte','10 Ashill Close','Taunton','Somerset','UNITED KINGDOM','TA14HX','01823353917','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 19:01:58',0,NULL,3,1,2,1,NULL,'babio10'),(10418,719893013002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','tansj83','tansj83@yahoo.com','Sun Jeng Tan','28, Lorong Saujana Permai 13,<br>Taman Saujana Permai,','Bukit Mertajam','Penang','MALAYSIA','14000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 19:12:38',0,NULL,3,1,2,1,NULL,'tansj83'),(10419,678707076001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','einer-nervt','patrick@photostudio.ch','Patrick Geissmann','Foto Lüthard AG Seminarstrasse 91','Wettingen','','SWITZERLAND','5430','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-28 19:52:16',0,NULL,3,1,3,1,'RA117737265CN\r ','einer-nervt\r2XL(已入库)'),(10420,678719595001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','marciomoretzsohn','tenmarcio@hotmail.com','Marcio Mello','Conde de Bonfim, 1357, 805. Tijuca.','RIO DE JANEIRO','RIO DE JANEIRO','BRAZIL','20530-001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-28 20:20:59',0,NULL,3,1,2,1,NULL,'marciomoretzsohn'),(10421,793818014015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','sagheer2006','segia45@hotmail.com','sagheer  hussain','101 burlington road<br>small heath','birmingham','West Midlands','UNITED KINGDOM','b10 9pt','07866464149','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 20:25:15',0,NULL,3,1,2,1,NULL,'sagheer2006\r注意是2个'),(10422,678718505001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','38undulater','itravin@mail.ru','ILYA TRAVIN','VOINOV-INTERNATSIONALISTOV, 12-87','APATITY','MURMANSK REGION','RUSSIAN FEDERATION','184207','+7(906)2889004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 20:37:55',0,NULL,3,1,3,1,'RA117737203CN\r ','38undulater'),(10423,777562054016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','dave47frame','poppie4879@hotmail.com','DAVID DAVIES','UNIT D96 UPPER PARLIAMENT STREET BUSINESS PARK<br>COMMERCE WAY','LIVERPOOL','MERSEYSIDE','UNITED KINGDOM','L8 7BA','01517079100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 21:36:31',0,NULL,3,1,2,1,NULL,'dave47frame'),(10424,719960250002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','t-smera-s','smera@op.pl','Tomasz Smereka','Kopernika 22F/8','Milicz','dolnośląskie','POLAND','56300','605 261264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 21:53:48',0,NULL,3,1,17,0,NULL,'t-smera-s'),(10425,678753733001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','t-smera-s','smera@op.pl','Tomasz Smereka','Kopernika 22F/8','Milicz','dolnośląskie','POLAND','56300','605 261264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 21:58:23',0,NULL,3,1,2,1,NULL,'t-smera-s\r绿叶 UV  52mm    1\r绿叶 渐变镜 52mm    1'),(10426,793221685015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',4.5,'hutongstore','ashley.cort','ashleycort31@yahoo.com','Ashley Cort','179 Castlelawn Heights','Galway','Galway','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 22:03:51',0,NULL,3,1,2,1,NULL,'ashley.cort\r方形滤镜接口环 52mm     1\r方形滤镜接口环 58mm    1'),(10427,719001190002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rayincola','cfkusa@aol.com','RAYMOND STEPPLING','6909 SANDY SHORE RD','COLUMBIA','SC','UNITED STATES','29206-2325','(803) 429-3919','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-28 22:05:53',0,NULL,3,1,1,1,NULL,'rayincola'),(10428,719970076002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE3102',23.67,'hermeshine','nike.khoe','nike@mycutecow.com','Lucy Gunawan','Jan Pettersonstraat 68','ROTTERDAM','','NETHERLANDS','3077MN','0104790779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 22:37:07',0,NULL,3,1,3,1,'RA117737375CN\r ','nike.khoe'),(10429,793882751015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','nathanquiff','nathanjohnsparks@hotmail.com','Nathan Sparks','104 Stapleton Road','London','London','UNITED KINGDOM','SW17 8AX','02086824984','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-28 23:10:14',0,NULL,3,1,2,1,NULL,'nathanquiff'),(10430,793890532015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.79,'hutongstore','picareto75','sergiocmendes75@gmail.com','sergio mendes','rua principal<br>carrasqueiro','alcobaça','leiria','PORTUGAL','2460-781','+351917058889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-28 23:40:24',0,NULL,3,1,2,1,NULL,'picareto75'),(10431,678778018001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','cabasa777','imoroko@gmail.com','Ivans Moroko','Flat 73 Stephenson House<br>Bath Terrace','London','London','UNITED KINGDOM','SE1 6PR','447784689769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-28 23:41:20',0,NULL,3,1,4,1,'YW865716796CN\r ','cabasa777\r申报: tripod $25'),(10432,678012813018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','lindyt3216','lindat@ncable.net.au','Linda Trusiak','10 Corriedale Crt.<br>Belmont','Geelong','Victoria','AUSTRALIA','3216','0352434418','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-29 01:27:43',0,NULL,3,1,3,1,'RA117737044CN\r ','lindyt3216'),(10433,720012848002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5.2,'hermeshine','carmag09','marsten@xtra.co.nz','Margarete Schladitz','88Valley Road<br>RD 1','Wakefield','Nelson','NEW ZEALAND','7095','6435418061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 01:44:38',0,NULL,3,1,2,1,NULL,'  carmag09\rNIKON 镜头盖 72mm    2\rNIKON 镜头盖 52mm    2'),(10434,678804594001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1308',5.2,'hermeshine','carmag09','marsten@xtra.co.nz','Margarete Schladitz','88Valley Road<br>RD 1','Wakefield','Nelson','NEW ZEALAND','7095','6435418061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 01:49:12',0,NULL,3,1,17,0,NULL,'carmag09'),(10435,720022635002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pablorwc','pablo206@live.com.ar','Pablo Andres Barraza','Diaz Velez 2263','Benavidez','Buenos Aires','ARGENTINA','1621','47361631','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 02:33:54',0,NULL,3,0,3,1,'RA117737035CN\r ','pablorwc\rL(已入库)'),(10436,678813687001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','juanflight','britodesigns@gmail.com','Juan Brito','2089 Beaverbrook Avenue<br>Unit 3','London','ON','CANADA','N6H 0A9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 02:38:24',0,NULL,3,1,2,1,NULL,'juanflight'),(10437,678824600001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','onesfist010','onesfist@gmail.com','Seung Hee Lee','801-ho 101-dong, DongSin Apt., Dori-ri<br>Hayang-eup, Gyeongsan-si','Gyeongbuk','N/A','KOREA,REPUBLIC OF','712907','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 03:44:23',0,NULL,3,1,3,1,'RA117737296CN\r ','onesfist010'),(10438,720037552002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','lininhaohara','linaohara@hotmail.com','Lina Ohara','Fujigaoka 1-1-1<br>Konan Danchi 5-302','Konan-shi','Aichi','JAPAN','483-8337','080-3611-9201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 03:53:46',0,NULL,3,1,11,1,NULL,'lininhaohara'),(10439,720057989002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','carlos_gbran1','carlos_gbran@hotmail.com','Carlos  Giron-Bran','4420 Ave. Laval #6','Montréal','QC','CANADA','H2W2J8','(514) 803-8658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 06:03:07',0,NULL,3,1,3,1,'RA117737319CN\r ','carlos_gbran1'),(10440,678060983018,280685224536,'50x70cm 20\"x28\" Folding Easy Soft box  E27 Bulb Socket',1,'AE2401',35,'photographyacc','sunsetmoonvideo','troy@sunsetmoon.com.au','Troy Burley','87 the bucketts way','Twelve Mile Creek','New South Wales','AUSTRALIA','2324','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-05-29 06:08:28',0,NULL,3,1,3,1,'RA117737438CN\r ','sunsetmoonvideo\r澳标'),(10441,678868992001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','poddy102','huang.adrian@gmail.com','Zhao Ren Adrian Joseph Huang','16 Pine Grove #12-06','default','','SINGAPORE','597593','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 07:55:06',0,NULL,3,1,17,0,NULL,'poddy102'),(10442,720115236002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','b3reeze','3reeze@gmail.com','Oleg Pertsovski','Profsoyuznaya<br>dom 85, korpus 1, kv 240.','Moscow','','RUSSIAN FEDERATION','117279','(929)6203580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 09:41:46',0,NULL,3,1,2,1,NULL,'b3reeze'),(10443,794050862015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','ij277','imjones@me.com','Ian Jones','31 Tilney Close','Alton','Hampshire','UNITED KINGDOM','gu342bg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 09:44:09',0,NULL,3,1,2,1,NULL,'ij277'),(10444,678113279018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','yamyabasha','bdkasher@yahoo.com.au','kasher B','2746 Old Coast road','Herron','Western Australia','AUSTRALIA','6211','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-29 09:56:53',0,NULL,3,1,4,1,'YW865716914CN','yamyabasha\rreflector holder  $22'),(10445,720128192002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','emypausiniana','emypausinianadoc@live.it','Emily Raineri','via sosio 19','Catania','CT','ITALY','95121','3458340091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 10:17:20',0,NULL,3,1,3,1,'RA117737441CN\r ','emypausiniana\r欧标\rlighting kit  $15'),(10446,678748621001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','sergejstrelchenko2010','sergej.strelchenko@mail.ru','Сергей Стрельченко','Фрунзе 14<br>Фрунзе 14','станица Платнировская','Краснодарский край Кореновский район','RUSSIAN FEDERATION','353177','89284162835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 10:19:36',0,NULL,3,1,3,1,'RA117737407CN\r ','sergejstrelchenko2010'),(10447,794078800015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','michaelw7565','esmo-we@online.no','Michael Webb','Hetlevikstraumen 3<br>5173 Bergen, Norway','Bergen','','NORWAY','N-5173','+47 55931094','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-29 10:42:18',0,NULL,3,1,4,1,'YW865716903CN ','michaelw7565\r申报: tripod dolly, $25\r'),(10448,678929454001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','s-dmit','s-dmit@mail.ru','Dmitriy Sergeev','Oktyabrskaya 134-18','Orel','Orlovskaya obl','RUSSIAN FEDERATION','302040','+7-910-300-48-30','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 10:48:28',0,NULL,3,1,3,1,'RA117737384CN\r ','s-dmit'),(10449,720138221002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','aijogeorgez','aijogeorge@yahoo.com','Aijo George','Unit 2, 23 Park St<br>Pimlico','Townsville','Queensland','AUSTRALIA','4812','0747798864','NoPaymentFailure','CheckoutComplete','NotSelected','2011-05-29 10:52:07',0,NULL,3,1,2,1,NULL,'aijogeorgez\r白'),(10450,720139364002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','cyberguru656','robert_k_rouse99@yahoo.com','Robert K Rouse','120 Montrose West Ave<br>Ste 723','Copley','OH','UNITED STATES','44321-1372','(310) 902-9743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 10:57:38',0,NULL,3,1,1,1,NULL,'cyberguru656'),(10451,777791752016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','engrui','ruiadf@gmail.com','Rui Ferreira','Travessa da Abelheira, 22<br>Fonte Coberta','Barcelos','','PORTUGAL','4775-109','351932370683','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 11:02:50',0,NULL,3,1,2,1,NULL,'engrui'),(10452,720168445002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','ni-ki-tas','nmixalakis@gmail.com','Nikitas Michalakis','Maria Polidouri 4<br>Maria Polidouri 3','Agia Marina Gazi','Heraklion Crete','GREECE','71414','+306972898817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 12:03:19',0,NULL,3,1,3,1,'RA117737415CN\r ','ni-ki-tas'),(10453,678192728018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','darkenedhue','butcher.hugh@gmail.com','Hugh Butcher','35 Smith St','Kensington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-29 12:36:30',0,NULL,3,1,3,1,'RA117737367CN\r ','darkenedhue'),(10454,720186796002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','wisky_studio','wisky@wisky.ru','Andrey Guryanov','Melnikova 20/1 - ap.12','Kirov','','RUSSIAN FEDERATION','610006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 12:50:02',0,NULL,3,1,2,1,NULL,'wisky_studio'),(10455,678976209001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','bergy10','robertbergsma@greymane.bm','Robert Bergsma','11 Orchard Drive','Soutampton','','BERMUDA','SN02','441-330-8180','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 12:50:18',0,NULL,3,1,3,1,'RA117737146CN\r ','bergy10'),(10456,777848385016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','kirgon','matthieu.fynes@lesplansj.com','Matthieu FYNES','12 rue des couvre-toits','FRELINGHIEN','Nord-Pas-de-Calais','FRANCE','59236','0699039033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 12:59:06',0,NULL,3,1,2,1,NULL,'kirgon'),(10457,678207625018,280667759184,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.88,'photographyacc','**decoder**','milo2piles@gmail.com','miles ferguson','54 Grand Central Ave','HALLETT COVE','South Australia','AUSTRALIA','5158','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-29 13:29:08',0,NULL,3,1,2,1,NULL,'**decoder**'),(10458,777851815016,260660051871,'New 3 pcs filters for Cokin System P Series',1,'AKT062',13.8,'hutongstore','ainscough29','ainscough.c@sky.com','Paul Ainscough','115 Edward Street<br>Bamber Bridge','Preston','Lancashire','UNITED KINGDOM','PR5 6FD','01772334496','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 13:30:33',0,NULL,3,1,2,1,NULL,'ainscough29'),(10459,679006206001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','romzef','feofanovra@gmail.com','Roman Feofanov','7/7 Komsomolskaya','Rossoch','Voronezh Obl','RUSSIAN FEDERATION','396656','+7 908 1415735','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 14:03:38',0,NULL,3,1,3,1,'RA117737778CN\r ','romzef'),(10460,678233344018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','simmy1680','long_black88@hotmail.com','Asim Haque','11/7 purnell place','Calwell','Australian Capital Territory','AUSTRALIA','2905','0404048778','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-29 14:09:46',0,NULL,3,1,2,1,' ','simmy1680'),(10461,720236859002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','ruslya','hekzart@gmail.com','Ruslan Chirkov','Elena Teligi 37a/3','Kyiv','','UKRAINE','04086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 14:47:25',0,NULL,3,1,2,1,NULL,'ruslya'),(10462,794211159015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','maszine','sylwiusz@poczta.onet.pl','Sylwester Dziegielewski','31 Wodehouse Road','Leicester','Leicestershire','UNITED KINGDOM','LE3 1PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 14:55:55',0,NULL,3,1,2,1,NULL,'maszine'),(10463,679046026001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','poddy102','huang.adrian@gmail.com','Zhao Ren Adrian Joseph Huang','16 Pine Grove #12-06','default','','SINGAPORE','597593','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:23:24',0,NULL,3,1,11,1,NULL,'poddy102\r52-52mm 双阳环  1\rnikon 反接环  52mm   1'),(10464,679046703001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','rubber_83','jackal83@tiscali.it','Maurizio Di Liberto','Via Boito 1','Quartu Sant\'Elena','CA','ITALY','09045','070812321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 15:27:28',0,NULL,3,1,2,1,NULL,'rubber_83'),(10465,720288763002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','voiceoveip','i@ztup.com','AI Trade SARL - Ingmar Putz','Chateau de Bimare<br>1, rue de Bimare','Saint Germain des Essourts','Haute-Normandie','FRANCE','76750','0951381378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 16:21:56',0,NULL,3,1,2,1,NULL,'voiceoveip'),(10466,720289414002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','ariefinn','ariefin+ebay@gmail.com','Arie Fineshtein','Cochavit 1<br>apartment 18','nazareth illit','IL','ISRAEL','17097','(972) 52-2823705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 16:28:42',0,NULL,3,1,3,1,'RA117770204CN\r ','ariefinn\r第一次的运输中压坏了,再发一个.'),(10467,716716333002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','mariajosedc','mjdc@terra.com.br','Maria José Dias Cerqueira','Rua Universo 284 ap 02','Belo Horizonte','Minas Gerais','BRAZIL','30350612','31-3344-5640','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 16:39:05',0,NULL,3,1,3,1,'RA117737061CN\r ','mariajosedc'),(10468,720320875002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','morlidge','morlidge@jerseymail.co.uk','Jack Morlidge','Le Pradel','Hautefage','','FRANCE','19400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 17:11:51',0,NULL,3,0,3,1,'RA117737027CN\r ','morlidge\rXL'),(10469,778026718016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',3,'AA1301',5.61,'hutongstore','plecandloach','rambler77@btinternet.com','robert campion','26 wilmore crescent','leicester','Leicestershire','UNITED KINGDOM','le3 1sw','07968049429','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 17:28:40',0,NULL,3,1,2,1,NULL,'plecandloach'),(10470,720265193002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','dwltoys','losd@cox.net','David Los','22436 Atomo','Mission Viejo','CA','UNITED STATES','92691-1524','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 17:47:25',0,NULL,3,1,1,1,NULL,'dwltoys'),(10471,720361760002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','differenteagles','miloraddivnic@gmail.com','Ljubinko Divnich','53. Divizije 211','Derventa','','BOSNIA AND HERZEGOVINA','74400','0038765643627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 17:58:20',0,NULL,3,1,3,1,'RA117737490CN\r ','differenteagles'),(10472,720365770002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','ferrariaccess','asarkissian1@yahoo.com','Arman Sarkissian','1751 N Stanley Ave','Los Angeles','CA','UNITED STATES','90046-2262','(323) 383-8593','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 18:02:24',0,NULL,3,1,1,1,NULL,'ferrariaccess'),(10473,794381735015,250692242647,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','allsupp','rjscarreira@gmail.com','Ricardo Carreira','Rua Dr. Manuel Rodrigues Sousa, 82 11º ESQ SUL','Matosinhos','Matosinhos','PORTUGAL','4450-181','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 18:15:22',0,NULL,3,1,2,1,NULL,'allsupp'),(10474,720379888002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','artcrimes1985','starry_eyes15@hotmail.com','Art  Crimes','9 st vincents house','london','London','UNITED KINGDOM','se1 3ea','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 18:16:52',0,NULL,3,1,2,1,NULL,'artcrimes1985'),(10475,794389145015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','mishoo90','misha_hu@hotmail.com','Zara Hussain','Grorudveien 113 a','oslo','Oslo','NORWAY','1053','96709525','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 18:21:54',0,NULL,3,1,2,1,' ','mishoo90'),(10476,778125080016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','fitzer0_6','eamonf@vodafone.ie','Eamon Fitzpatrick','Teer<br>Brandon','Tralee','Kerry','IRELAND','default','0872380949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 18:57:02',0,NULL,3,1,3,1,'RA117737013CN\r ','fitzer0_6\r1.6x3m\r白色'),(10477,720415342002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','ffuffe','ffuffe@hotmail.com','jose  gonzalez moreno','padura 3, 3º D','elorrio','País Vasco','SPAIN','48230','666 81 29 22','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 18:58:53',0,NULL,3,1,3,1,'RA117737509CN\r ','ffuffe'),(10478,719487299002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',140,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-29 19:12:45',0,NULL,3,1,3,1,'RA117738977CN\r ','saud-p\r分4个小包\r背景架 2x3m 河北 + 1.6x2.1 白 +夹子   x2套\rRA117738963CN\rRA117737058CN\r'),(10479,720410574002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','bigcomposer','kusche-tomasini@libero.it','Ingeborg Endl','Bassano di Sutri, 19<br>la via si trova tra Vicarello e Trevignano','Bracciano','RM','ITALY','00062','3334846448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-29 19:45:07',0,NULL,3,1,3,1,'RA117737150CN\r ','bigcomposer\rlighting kit  $20'),(10480,720482269002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','rsqar35','rsqar1@yahoo.com','Virginia Harman','25709 Smith Grove Rd','Petersburg','VA','UNITED STATES','23803','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 20:33:00',0,NULL,3,1,1,1,NULL,'rsqar35'),(10481,720485506002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ksnguyen81','ksnguyen81@yahoo.com','Kevin Nguyen','10071 Lampson Ave<br>Apt 37','Garden Grove','CA','UNITED STATES','92840-4732','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 20:38:52',0,NULL,3,1,1,1,NULL,'ksnguyen81'),(10482,720491877002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','hidrums','dharmendra.agarwal@cognizant.com','Dharmendra Agarwal','136 Claire Ln<br>Apt 207','Mooresville','NC','UNITED STATES','28117-5589','(201) 604-4677','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 21:03:00',0,NULL,3,1,1,1,NULL,'hidrums'),(10483,778231069016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','fready911','fready69@yahoo.com','Frode Grindheim','Vilhelm Bjerknes vei 51','Bergen','','NORWAY','N-5081','+4793055944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 21:14:20',0,NULL,3,1,4,1,'YW865716752CN\r ','fready911\r灯架  2m   1\r反光板支架    1\r'),(10484,794544502015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',18.5,'hutongstore','fready911','fready69@yahoo.com','Frode Grindheim','Vilhelm Bjerknes vei 51','Bergen','','NORWAY','N-5081','+4793055944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-29 21:24:14',0,NULL,3,1,17,0,NULL,'fready911'),(10485,678531786018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','freefoods','nickmoy@gmail.com','Nick Moy','699 John St<br>Unit 519','Seattle','WA','UNITED STATES','98109','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-29 21:28:33',0,NULL,3,1,1,1,NULL,'freefoods'),(10486,720518373002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',20,'AA1301',52,'hermeshine','arphotovideo','ra1612@gmail.com','AR Photo Inc','2901 Nostrand ave','Brooklyn','NY','UNITED STATES','11229-1817','(718) 998-1688','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 21:51:06',0,NULL,3,1,1,1,NULL,'arphotovideo'),(10487,794563982015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','1pompey','mick.halliday@ntlworld.com','Mr M Halliday','1 Littlepark Avenue','Havant','Hants','UNITED KINGDOM','PO9 3QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 22:05:23',0,NULL,3,1,2,1,NULL,'1pompey\r绿叶 渐变镜 77mm   1\r绿叶 渐变镜 62mm   1'),(10488,778261487016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','1pompey','mick.halliday@ntlworld.com','Mr M Halliday','1 Littlepark Avenue','Havant','Hants','UNITED KINGDOM','PO9 3QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-29 22:07:42',0,NULL,3,1,17,0,NULL,'1pompey'),(10489,679314851001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','cfmneto','cirofranco@ig.com.br','Flavio Medeiros','2122 Rachel Ln','Round Rock','TX','UNITED STATES','78664-7452','(512) 922-4017','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-29 22:13:29',0,NULL,3,1,3,1,'RA117737486CN\r ','cfmneto\r0630-0712-回信说已经收到.'),(10490,720544743002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','keziah2013','irievibes501@yahoo.com','Keziah Craib','2861 camomile Dr','Orlando','FL','UNITED STATES','32837','(407) 816-6020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-29 23:21:12',0,NULL,3,1,1,1,' ','keziah2013'),(10491,678582659018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',6.2,'photographyacc','alexlewers','cbb_6@hotmail.com','Alex Lewers','189 Magellan St','Lismore','New South Wales','AUSTRALIA','2480','0411313439','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-30 00:22:27',0,NULL,3,1,2,1,NULL,'alexlewers'),(10492,678583444018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','integer13','astar4013@yahoo.com','Alexander Starostin','10/18 Batchworth rd<br>n/a','Molendinar','Queensland','AUSTRALIA','4214','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-30 00:25:39',0,NULL,3,1,2,1,NULL,'integer13'),(10493,720115801002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',4,'AA1216',55.6,'hermeshine','boyxez','anton.yulianto@pertamina.com','anton yulianto','Jl Jagir Wonokromo 88<br>Lt II Fungsi SI&K','Surabaya','East Java','INDONESIA','60244','+6285645000099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 00:53:22',0,NULL,3,1,3,1,'RA117737089CN\r ','boyxez'),(10494,679390884001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','johnny-b1','kateb1@q.com','Johnny I. Barnes','19705 NE 234th St','Battle Ground','WA','UNITED STATES','98604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 03:23:33',0,NULL,3,1,1,1,NULL,'johnny-b1'),(10495,720624911002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','nizam.hashim','cool_daylite@yahoo.co.uk','Hairulnizam Hashim','19, Jalan Dedap 39<br>Taman Johor Jaya','Johor Bahru','Johor','MALAYSIA','81100','0177229902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 04:54:50',0,NULL,3,1,6,1,'EE506555466CN ','nizam.hashim'),(10496,720629846002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','haphananh','ha_trung@yahoo.com','Trung Ha','366 Maguire Vlg<br>Apt 5','Gainesville','FL','UNITED STATES','32603-2065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-30 05:26:22',0,NULL,3,1,1,1,' ','haphananh'),(10497,720639215002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','blkmesa77','blkmesa77@hotmail.com','Paul Hare','62 Dania Dr.','Cheektowaga','NY','UNITED STATES','14225','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 06:23:53',0,NULL,3,1,4,1,'YW865716870CN ','blkmesa77\r三脚架 伟峰 EI-717  180     1\rWT600    1'),(10498,679421123001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','blkmesa77','blkmesa77@hotmail.com','Paul Hare','62 Dania Dr.','Cheektowaga','NY','UNITED STATES','14225','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 06:25:23',0,NULL,8,1,17,0,NULL,'blkmesa77'),(10499,794721733015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','pearl-works','dsolidsnake@gmail.com','Jacob Sammut','55 Bethsaida<br>Kavetti Street','Marsaskala','','MALTA','MSK3470','+356 21639188','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-30 07:44:17',0,NULL,3,1,3,1,'RA117737557CN\r ','pearl-works'),(10500,679434640001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','addie101507','jordhan23@aol.com','roldan abalos','1814 findley dr','milpitas','CA','UNITED STATES','95035-6018','(408) 772-8755','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-30 07:45:39',0,NULL,3,1,1,1,NULL,'addie101507'),(10501,720655683002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','santijurado','jurado.santiago@gmail.com','Santiago Jurado Defez','C/ Marqués de Dosaguas patio 18 puerta 16','Picassent','Comunidad Valenciana','SPAIN','46220','675727605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 07:56:45',0,NULL,3,1,4,1,'YW865716936CN ','santijurado\rtripod  $16'),(10502,679442054001,110583709607,'NEW 55mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT043',22.9,'hermeshine','snepperman','svaze@rambler.ru','Ruslan Veretenik','Socialisticheskaya 62/20','Kharkov','','UKRAINE','61098','80935164957','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-30 08:16:40',0,NULL,3,1,17,0,NULL,'snepperman'),(10503,679441421001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','snepperman','svaze@rambler.ru','Ruslan Veretenik','Socialisticheskaya 62/20','Kharkov','','UKRAINE','61098','80935164957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 08:18:03',0,NULL,3,1,3,1,'RA117734140CN ','snepperman\r绿叶 UV  55mm    1\r绿叶 CPL  55mm    1\r绿叶 ND8  55mm   1\r绿叶 近摄 +4  55mm   1\r绿叶 渐变灰  55mm    1\r4片装滤镜袋   1'),(10504,678682540018,280685239247,'Pro Spanner Wrench For Lens Repair Tool Stainless Steel',1,'AA2401',42,'photographyacc','x-speeddog','prince_speeddog@hotmail.com','Mr. Suebpong  Techapom','12-14  Jarernmueang Rd.<br>Tambol.Watgate','Ampur.Mueang','Chiang Mai','THAILAND','50000','0861851349','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 08:30:48',0,NULL,3,1,3,1,'RA117737906CN\r ','x-speeddog'),(10505,679450942001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','janot6700','janot67@free.fr','jean galonnier','2 square Berthier<br>\"La Grognarde\"','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-30 08:58:38',0,NULL,3,1,3,1,'RA117734860CN\r ','janot6700'),(10506,720675911002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','mariksas','mariuksus@yahoo.com','Romas Miklovas','Connaberry 21','Buncrana','Donegal','IRELAND','default','086 6649344','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-30 09:28:39',0,NULL,3,1,3,1,'RA117734873CN\r ','mariksas'),(10507,732444036017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','yulia_k','julie_x@mail.ru','Julia Kuznetsova','Kallhällsleden 12','Stockholm','Järfälla','SWEDEN','176 71','46739561355','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 09:39:25',0,NULL,3,1,3,1,'RA117734958CN\r ','yulia_k'),(10508,679468229001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','karelpavel','k_pavel@centrum.cz','Karel Kovar','Alsova 229','Upice','','CZECH REPUBLIC','54232','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 10:14:20',0,NULL,3,1,2,1,NULL,'karelpavel'),(10509,679456389001,110658438313,'Remote Shutter Release Cord for Canon 40D 50D 5DII RE-A',2,'AA2219',9.36,'hermeshine','zeroone12345','free_moh_2005@hotmail.com','Mohammad Shaaban','18221 150th Ave<br>AMM 4388','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 10:46:52',0,NULL,3,1,1,1,NULL,'zeroone12345'),(10510,679477285001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','zaaz89','zaaaz89@gmail.com','Andraž Radovan','Zvezna 21','Ljubljana','','SLOVENIA','1000','040-414-707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 10:49:37',0,NULL,3,1,2,1,NULL,'zaaz89'),(10511,794770290015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','papillon620','petitnono62@hotmail.com','arnaud capendu','appt 4  résidence la tourelle ,boulevard agniel','noeux les mines','Nord-Pas-de-Calais','FRANCE','62290','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-30 10:59:01',0,NULL,3,1,3,1,'RA117734989CN\r ','papillon620'),(10512,794780383015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1301',36.6,'hutongstore','nabeel411','aloraifann@yahoo.com','Nabeel Aloraifan','P.O.Box 26130','Safat','Kuwait','KUWAIT','13122','(965) 996-4441 ext.: 1','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-30 11:02:42',0,NULL,3,1,3,1,'RA117734992CN\r ','nabeel411\r欧标'),(10513,720700861002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','nightwolf62','wolf62@rogers.com','Richard  Phillips','2 Wrendale Cres.','Keswick','ON','CANADA','L4P 4C4','(905) 476-3530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 11:08:01',0,NULL,3,1,2,1,NULL,'nightwolf62'),(10514,678726497018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','jackjackjacklee85','jackjackjacklee@hotmail.com','Jack Lee','15b addlewell glen','kiara','Western Australia','AUSTRALIA','6054','0862781362','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-30 11:37:16',0,NULL,3,1,2,1,' ','jackjackjacklee85'),(10515,678516429001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','zuckermacher','zuckermacher@gmx.de','Ralph Ziesmer','Zühlsdorfer Straße 38','Berlin','','GERMANY','12679','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:09:13',0,NULL,3,1,2,1,NULL,'zuckermacher'),(10516,679502243001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','owenzhang90','owenzhang@rocketmail.com','Wensheng Zhang','3/7 Walter St<br>Cranbourne','Melbourne','Victoria','AUSTRALIA','3977','0395853144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:23:27',0,NULL,3,1,4,1,'YW865716984CN\r ','owenzhang90\r白\rbackground  $20'),(10517,678211614018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','syxt3','mailamatic@optusnet.com.au','Roger Moore','73 A MITCHAM ROAD DONVALE','MELBOURNE','Victoria','AUSTRALIA','3111','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-05-30 12:25:54',0,NULL,3,1,2,1,NULL,'syxt3'),(10518,720721030002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',8,'AA1310',43.92,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:27:05',0,NULL,3,1,17,0,NULL,'budda001'),(10519,720721193002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',4,'AA2203',14,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:27:04',0,NULL,3,1,17,0,NULL,'budda001'),(10520,679501902001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:27:05',0,NULL,3,1,3,1,'RA117734887CN\r ','budda001\r55mm - 2\r62mm - 2\r67mm - 1\r72mm - 4\r77mm - 1\r爵影红外 sony    4\rlenspen    8\r看看是否2kg以下'),(10521,720722646002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','domeraro','domenico.semeraro2@tin.it','domenico semeraro','via roma 243 - presso ferramenta gigante<br>ferramenta gigante annalisa','monteiasi','TA','ITALY','74020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 12:28:10',0,NULL,3,1,2,1,NULL,'domeraro'),(10522,732490595017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','climb70','m.lancia@email.it','Maurizio Lancia - Symantec','Via Nazario Sauro, 38','Sesto San Giovanni','MI','ITALY','20099','+393336768750','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 12:30:33',0,NULL,3,1,3,1,'RA117734961CN\r ','climb70\r申报  shoulder strap  $12'),(10523,794817160015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','vgorska','vgorska1@wp.pl','Violetta Gorska','5, Wessex Trade Centre<br>Ringwood Road','Poole','Dorset','UNITED KINGDOM','BH12 3PF','447935951119','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 12:52:19',0,NULL,3,0,3,1,'RA117773293CN\r ','vgorska\r黑 1.6x2.1\r----------\r第一次发的,角上撕裂了,这次一定发个完整的'),(10524,720736329002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','nikkilee702','nikkirogers79@live.com','Nicole Rogers','830 N Lamb Blvd<br>Spc 105','Las Vegas','NV','UNITED STATES','89110-5450','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 13:14:32',0,NULL,3,1,1,1,NULL,'nikkilee702'),(10525,720739007002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','rboot_rboot','fgutierrez@gmail.com','Fernando Gutierrez','c pinar 19<br>(SGAI-CSIC)','Madrid','Madrid','SPAIN','28006','636638551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:26:08',0,NULL,3,1,17,0,NULL,'rboot_rboot'),(10526,720736674002,120448646606,'New ND4 Filter for Cokin P Series Neutral Density ND 4',1,'AA2324',7.2,'hermeshine','rboot_rboot','fgutierrez@gmail.com','Fernando Gutierrez','c pinar 19<br>(SGAI-CSIC)','Madrid','Madrid','SPAIN','28006','636638551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:26:09',0,NULL,3,1,17,0,NULL,'rboot_rboot'),(10527,679516674001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','rboot_rboot','fgutierrez@gmail.com','Fernando Gutierrez','c pinar 19<br>(SGAI-CSIC)','Madrid','Madrid','SPAIN','28006','636638551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:26:09',0,NULL,3,1,17,0,NULL,'rboot_rboot'),(10528,720738394002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','rboot_rboot','fgutierrez@gmail.com','Fernando Gutierrez','c pinar 19<br>(SGAI-CSIC)','Madrid','Madrid','SPAIN','28006','636638551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:26:10',0,NULL,3,1,17,0,NULL,'rboot_rboot'),(10529,679516850001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.87,'hermeshine','rboot_rboot','fgutierrez@gmail.com','Fernando Gutierrez','c pinar 19<br>(SGAI-CSIC)','Madrid','Madrid','SPAIN','28006','636638551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:26:10',0,NULL,3,1,3,1,'RA117734900CN\r ','rboot_rboot\r方形滤镜接口环 58mm    1\r方形滤镜 镜片卡座     1\r天涯方形滤镜  渐变灰    2\r天涯方形滤镜  ND8    1\r天涯方形滤镜  ND4    1\r'),(10530,679523802001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','field_of_dreams58','lexdenn@hotmail.com','robert dennison','PO Box 178','bishop','CA','UNITED STATES','93515','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 13:40:40',0,NULL,3,1,1,1,NULL,'field_of_dreams58\r58mm 转接环 +卡座 +渐变灰     1(套)\r'),(10531,679526926001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','lesa75lesa','sasa.prijic1@zg.t-com.hr','sasa prijic','vladimira ruzdjaka 12','zagreb','','CROATIA','10000','+0038516050522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:48:32',0,NULL,3,1,2,1,NULL,'lesa75lesa'),(10532,679530141001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','dragoncilloyeye','benalbares@hotmail.com','Benjamin Albares Moreno','c/Heroes de Sostoa 25 - 3D','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29002','677125070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 13:59:58',0,NULL,3,1,3,1,'RA117735009CN\r ','dragoncilloyeye'),(10533,679549663001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','eegypto','eyogui@hotmail.com','Elaine Egypto','Rua Barao do Triunfo, 550 - cj 54','Sao Paulo','Sao Paulo','BRAZIL','04602002','551150930750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 14:58:49',0,NULL,3,1,2,1,NULL,'eegypto'),(10534,679552453001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','idelaporte','ignaciodelaporte@gmail.com','Ignacio Delaporte','Av Pueyrredon 2410 piso 12','Buenos Aires','Buenos Aires','ARGENTINA','1119','5491130273651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 15:05:20',0,NULL,3,1,2,1,NULL,'idelaporte'),(10535,720772661002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','solegovich','molokov78@gmail.com','Сергей Молоков','Мурзинская,<br>28, 86','Екатеринбург','Свердловская','RUSSIAN FEDERATION','620033','+79222014483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 15:10:46',0,NULL,3,1,2,1,NULL,'solegovich'),(10536,732544330017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',248,'photographyacc','pierrec9393','mrbidunga@hotmail.com','pierre carlier','188 rue de courbevoie','nanterre','Île-de-France','FRANCE','92000','06 03 19 59 33','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-30 15:20:42',0,NULL,3,1,4,1,'YW865716973CN\r ','pierrec9393\r欧标\r灯架  2m    3\r斜臂   1\r柔光箱60-60cm 四灯头   2\r柔光箱 50-70cm 单灯头    1\r115w 5500k灯泡  220v      1\r45w 220v 灯泡    8\r灯架包   1'),(10537,679559053001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','manioti_maria_123','manioti_maria@hotmail.com','BOLANI EVAGELIA','MIHAIL KARAOLI 25','ATHENS','','GREECE','17341','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 15:27:13',0,NULL,3,1,2,1,NULL,'manioti_maria_123'),(10538,778584384016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','walloux77','walloux@hotmail.com','walid kocht','11 avenue robert schuman','Emerainville','Ile-de-France','FRANCE','77184','0658857886','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-30 16:03:41',0,NULL,3,1,4,1,'YW865717006CN\r ','walloux77'),(10539,678824562018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','vantheyh','vanthey_heng@yahoo.com','Vanthey Heng','6 Emily Ct','Clarinda','Victoria','AUSTRALIA','3169','61421139017','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-30 16:16:40',0,NULL,3,1,2,1,NULL,'vantheyh'),(10540,679561772001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 16:38:12',0,NULL,3,1,3,1,'RA117734913CN\r ','nixette_nixette'),(10541,679430335001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','annylo2011','annylo@designstudioarts.com','ANA LOPEZ','156 W Mariposa Rd<br>Ste 10-61','NOGALES','AZ','UNITED STATES','85621-1039','(520) 432-1233','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-30 17:14:21',0,NULL,3,1,1,1,NULL,'annylo2011'),(10542,720500142002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','spzphoto','info@spzphoto.gr','Spiros Zacharakis','Digeni Akrita 3','Chania','Crete','GREECE','73100','00302821054282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 17:32:01',0,NULL,3,1,4,1,'YW865716995CN\r ','spzphoto\r'),(10543,778655019016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','k2vu','khoa.d.vu2@gmail.com','K. Vu','46 Checkerberry Cr.','Brampton','ON','CANADA','L6R2S6','(416) 509-3179','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-30 18:19:16',0,NULL,3,1,2,1,NULL,'k2vu'),(10544,794994013015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','nicholascowen','n.cowen@hotmail.co.uk','nicholas cowen','22 buckton vale road','stalybridge','Cheshire','UNITED KINGDOM','sk153lw','01457837473','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 18:51:48',0,NULL,3,1,3,1,'RA117734975CN\r ','nicholascowen'),(10545,732663730017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','bettyyu1985','betty_yu1985@yahoo.com','Bolei Yu','35 Winslow Rd.','London','London','UNITED KINGDOM','w6 9SF','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 19:17:28',0,NULL,3,1,2,1,NULL,'bettyyu1985'),(10546,732666691017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','jillynik','jillymouse@westnet.com.au','Jill & Nick  Mandas','31 Kennedy St','Singleton','New South Wales','AUSTRALIA','2330','0265724658','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-30 19:26:43',0,NULL,3,1,2,1,NULL,'jillynik'),(10547,795025992015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',85,'hutongstore','subcognition','johnforde1@gmail.com','John Forde','Kilcavan<br>Tara Hill','Gorey','Wexford','IRELAND','default','0833654250','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-30 19:42:50',0,NULL,3,1,4,1,'YW865716962CN\r ','subcognition\r英标\r'),(10548,720903154002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','sdlatta','sdlatta@aol.com','Sharon  Latta','401 S. Donaldson','Kerens','TX','UNITED STATES','75144','(903) 396-2146','NoPaymentFailure','CheckoutComplete','Other','2011-05-30 19:53:50',0,NULL,3,1,4,1,'YW865716951CN\r ','sdlatta'),(10549,795045215015,250804358294,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',1,'AA1308',1.87,'hutongstore','mightysmfc1','andybonner.bonner@btopenworld.com','andrew bonner','31 margaret street','coatbridge','North Lanarkshire','UNITED KINGDOM','ml5 4eh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 20:11:57',0,NULL,3,1,2,1,NULL,'mightysmfc1'),(10550,679688505001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1305',7.8,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:14:03',0,NULL,3,1,17,0,NULL,'olexter'),(10551,720911623002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:14:03',0,NULL,3,1,17,0,NULL,'olexter'),(10552,679688132001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1304',7.8,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:14:04',0,NULL,3,1,17,0,NULL,'olexter'),(10553,720911565002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:14:04',0,NULL,3,1,17,0,NULL,'olexter'),(10554,720911728002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5.2,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:14:05',0,NULL,3,1,3,1,'RA117734895CN\r ','olexter\rNIKON 镜头盖 52mm    3\rCANON 镜头盖  67mm   1\rCANON 镜头盖  77mm   3\rCANON 镜头盖  58mm   3\rCANON 镜头盖  72mm   2'),(10555,679691190001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','javicaneu','caneu@wanadoo.es','Javier Martinez Lopez','C/ Salamanca, 48 - 3º','Monovar','Comunidad Valenciana','SPAIN','03640','629364626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:18:28',0,NULL,3,1,2,1,NULL,'javicaneu'),(10556,720921222002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','burnstim2003','tim@timothyaburnsimages.com','Timthy Burns','161 Took Dr','Antioch','TN','UNITED STATES','37013-1944','(615) 473-9035','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-30 20:34:43',0,NULL,3,1,1,1,NULL,'burnstim2003'),(10557,720930618002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','javiloro','javiloro.curro@hotmail.com','Francisco Javier Loroño Abad','Barrio Samano 29A casa 2<br>Urbanizacion Las Azaleas','Castro Urdiales','Cantabria','SPAIN','39709','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 20:52:52',0,NULL,3,1,2,1,NULL,'javiloro'),(10558,795070459015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','cimettinanostop','a.palombo@my.westminster.ac.uk','Alessia Palombo','1 Beck Road','London','London','UNITED KINGDOM','E8 4RE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-30 20:54:07',0,NULL,3,1,2,1,NULL,'cimettinanostop'),(10559,679719155001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','nivalsran','slavin@017.net.il','Ran Slavin','8 Yehuda Halevy','tel aviv','ID','ISRAEL','65135','03-5162601','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-30 21:28:46',0,NULL,3,1,3,1,'RA117734944CN\r ','nivalsran'),(10560,679723477001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','jesus.p.s','amroth90@hotmail.com','Jesus Privado Soto','Estda. Cesantes, Nº21 - Barrio Carballiño<br>Redondela','Pontevedra','Galicia','SPAIN','36693','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-30 21:40:23',0,NULL,3,1,4,1,'YW865716940CN\r ','jesus.p.s'),(10561,720949432002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ggidd4629','ggidd4629@bellsouth.net','gregg giddings','195 red giddings rd.','coushatta','LA','UNITED STATES','71019','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-30 21:41:38',0,NULL,3,1,1,1,NULL,'ggidd4629'),(10562,678971374018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','thedotindotcom','mail@danenelson.com','.COM Computers','2111 Myers St','Oroville','CA','UNITED STATES','95966-5342','(530) 533-0202','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-30 22:03:12',0,NULL,3,1,1,1,NULL,'thedotindotcom'),(10563,720969398002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','mgx4u','mtothex@arcor.de','Markus Baur','Uhlandstr. 5a','Eching','','GERMANY','85386','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 22:50:40',0,NULL,3,1,2,1,NULL,'mgx4u'),(10564,676770546018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mihaag85','michelhaag@hotmail.com','Michel Haag','101/6-14 Oxford St','Sydney','New South Wales','AUSTRALIA','2010','0403429154','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-30 22:59:12',0,NULL,5,0,18,0,' ','mihaag85'),(10565,679746044001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','yinhong82','yinhong82@yahoo.com','Yin Hong Lim','4302 Center St<br>Apt X304','Tacoma','WA','UNITED STATES','98409-8622','(614) 602-7549','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-30 23:01:04',0,NULL,3,1,1,1,NULL,'yinhong82'),(10566,679747652001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','felipefurtado','felipesfurtado@gmail.com','Felipe Furtado','SQN 308 Bloco J Apto 106<br>Asa Norte','Brasília','Distrito Federal','BRAZIL','70747100','556184577637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 23:09:22',0,NULL,3,1,17,0,NULL,'felipefurtado'),(10567,720973598002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','felipefurtado','felipesfurtado@gmail.com','Felipe Furtado','SQN 308 Bloco J Apto 106<br>Asa Norte','Brasília','Distrito Federal','BRAZIL','70747100','556184577637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 23:09:22',0,NULL,3,1,5,1,'CP227024902CN\r ','felipefurtadoRA117734927CN\r欧标\r50-70柔光棚 通用金属卡口    1\r灯架  2m   1\r单灯头       1\r反光伞       1'),(10568,720998617002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','simonk28july','s.karpin@exemail.com.au','Simon Karpin','24 Stonehaven Rd.','Stanwell Tops','New South Wales','AUSTRALIA','2508','0425211124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:06:47',0,NULL,3,1,17,0,NULL,'simonk28july'),(10569,679770809001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','simonk28july','s.karpin@exemail.com.au','Simon Karpin','24 Stonehaven Rd.','Stanwell Tops','New South Wales','AUSTRALIA','2508','0425211124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:06:48',0,NULL,3,1,2,1,NULL,'simonk28july\r77mm 转接环     1\r普通卡座    1\r广角卡座    1\r'),(10570,721003063002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','troleibus','allotovarasi@yahoo.com','Vornicov Victor','5661 brisset str,   apt 7','Montreal','QC','CANADA','h4e4c9','(514) 999-3202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:14:16',0,NULL,3,1,2,1,NULL,'troleibus\rc型大力夹    2\rCANON 镜头盖  77mm     1'),(10571,679777042001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','troleibus','allotovarasi@yahoo.com','Vornicov Victor','5661 brisset str,   apt 7','Montreal','QC','CANADA','h4e4c9','(514) 999-3202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 01:22:24',0,NULL,3,1,17,0,NULL,'troleibus'),(10572,679777336001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','cathy_g_77','camp_glover@yahoo.com','Catherine Glover','1312 Winter Springs Blvd','Winter Springs','FL','UNITED STATES','32708-3801','(407) 366-6364','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 01:30:57',0,NULL,3,1,1,1,NULL,'cathy_g_77'),(10573,732801287017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',57,'photographyacc','nostalgic_appeal','retro.glamour.vintage@gmail.com','MARIA SEAR','PO Box 6170','North Ryde','New South Wales','AUSTRALIA','2113','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-31 02:09:44',0,NULL,3,1,3,1,'RA117734935CN\r ','nostalgic_appeal\r澳标\r45W  220v   2\r2m 灯架   1\r单灯头    1\r反光伞    1'),(10574,721016464002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','s.gaspar','scott_gaspar@sbcglobal.net','Lizette Ortiz','18275 raymond ct','Fontana','CA','UNITED STATES','92336-3021','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 02:11:27',0,NULL,3,1,1,1,NULL,'s.gaspar'),(10575,679790931001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','guruggame','guruggamer@gmail.com','Olzhas Izmuratov','7microdistrict 24home 3ap.<br>7-24-3','Aktau','Mangistau','KAZAKHSTAN','130000','512897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 02:26:31',0,NULL,3,1,2,1,NULL,'guruggame'),(10576,730367179017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','salbekaa','salbekaa@yahoo.com','Samira Albekaa','8 Wallangara Street<br>O\'Malley','canberra','Australian Capital Territory','AUSTRALIA','2606','0424174660','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-05-31 03:03:36',0,NULL,3,1,3,1,'RA117734604CN\r ','salbekaa'),(10577,679807263001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','foreversomething','thehasoe@gmail.com','Mr Soe Thiha','Simpson Spence & Young, 50 Raffles Place<br>#14-01/02, Singapore Land Tower','Singapore','','SINGAPORE','048623','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 03:52:41',0,NULL,3,1,11,1,NULL,'foreversomething'),(10578,679816708001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','rashev90','dimitar@rashev.org','Dimitar Rashev','Mladost 447, entr. 2(b), fl. 7, app. 42','Sofia','','BULGARIA','1715','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 04:52:31',0,NULL,3,1,2,1,NULL,'rashev90'),(10579,795216056015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','amihay_h','a.hayut@gmail.com','Amihay Hayut','Kibutz galuyot 70 / 6','Nahariya','IL','ISRAEL','22266','(972)528709-789','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 05:18:12',0,NULL,3,1,2,1,NULL,'amihay_h'),(10580,732840204017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','tazdonnelly','tazd@ozemail.com.au','John Donnelly','51 Princes St.','Mortdale','New South Wales','AUSTRALIA','2223','0295805248','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-31 05:21:33',0,NULL,3,1,2,1,NULL,'tazdonnelly'),(10581,679080488018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','nicjantim','niciesla@hotmail.com','Janine Ciesla','14 Ainslie Court Kardinya','Perth','Western Australia','AUSTRALIA','6163','0893142255','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-31 05:25:33',0,NULL,3,1,4,1,'YW865717032CN ','nicjantim\rbackground support $25'),(10582,679083165018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',42,'photographyacc','infxus','info@videoedge.com.au','Ian Cope','12 Chelsea Close','Flinder\'s View','Queensland','AUSTRALIA','4305','0403312755','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-31 05:42:22',0,NULL,3,1,3,1,'RA117734595CN\r ','infxus'),(10583,679089021018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','madmax069ben','benrstevenson@gmail.com','Ben Stevenson','17 Grey Gums Dr','Woodford','New South Wales','AUSTRALIA','2778','00409817733','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-31 06:15:38',0,NULL,3,1,2,1,NULL,'madmax069ben'),(10584,721063137002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','rliya0410','fazlyn3103@yahoo.com.sg','Illya Fazlyn Abdullah','Block 5 Teck Whye Ave<br>#12-142','default','','SINGAPORE','680005','+6591500339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 06:38:58',0,NULL,3,1,11,1,NULL,'rliya0410'),(10585,679099760018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','o3digitalbath','o3digitalbath@cfl.rr.com','Garrett Wade','323 Falling Leaf Way','Casselberry','FL','UNITED STATES','32707','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-31 07:12:25',0,NULL,3,1,1,1,' ','o3digitalbath'),(10586,721070406002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','kami_crafts','dmckeon452@aol.com','Kamala L McKeon','531 Meadow Ln','Creswell','OR','UNITED STATES','97426-9738','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 07:21:49',0,NULL,3,1,1,1,NULL,'kami_crafts'),(10587,679841102001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','dani9batan','dbramiro@gmail.com','Daniel Borreguero Ramiro','Paseo Extremadura 200 2º Izq.','Madrid','Madrid','SPAIN','28011','666721928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 07:24:44',0,NULL,3,1,4,1,'YW865717021CN','dani9batan\r三脚架 伟峰 WF-6663A     1\r爵影红外 canon     1'),(10588,721071640002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','dani9batan','dbramiro@gmail.com','Daniel Borreguero Ramiro','Paseo Extremadura 200 2º Izq.','Madrid','Madrid','SPAIN','28011','666721928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 07:28:48',0,NULL,3,1,17,0,NULL,'dani9batan\r'),(10589,679842487001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','tbilisi17david','tbilisi17@gmail.com','Ben Aharon David','Burla 30/22','haifa','','ISRAEL','32811','0502832760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 07:41:31',0,NULL,3,1,2,1,NULL,'tbilisi17david'),(10590,795247644015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 07:56:14',0,NULL,3,1,17,0,NULL,'quasar6903'),(10591,795245867015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','quasar6903','stefang@sz.inetg.bg','Stefan Georgiev','Sv. Kniaz Boris 93, floor 7, office 4','Stara Zagora','SZ','BULGARIA','6000','(359) 888261706','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 07:56:14',0,NULL,3,1,2,1,NULL,'quasar6903\r肩带 无字   1\rpentax 反接环  52mm   1'),(10592,679848010001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','accessoriconsollepc','la-cometa@hotmail.it','Laura Valleriani','via cremona, 28','Ardea','Roma','ITALY','00040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 07:59:44',0,NULL,3,0,3,1,'RA117734136CN ','accessoriconsollepc\rXXXL  已入库\rphoto vest  $15'),(10593,679111087018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','wdtnjxtr','elle1571@gmail.com','Tatyana Yakupova','Pionerskaja st. 45-33','Volzhskij','RU','RUSSIAN FEDERATION','404125','89064098918','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-31 08:08:42',0,NULL,3,1,5,1,'CP227190003CN','wdtnjxtr\r2x16m 背景布   1(白)\r背景架2mx2m     1'),(10594,732849736017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0038761914941','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-31 08:16:20',0,NULL,3,1,3,1,'RA117734119CN ','palamuda387\r去掉任何商标used lighting kit ,申报$23'),(10595,721083631002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','mkucukart','grafimustafa@hotmail.com','Mustafa Küçük','Musallabagları mahallesi ruhibagdadi sokak<br>no: 54 selçuklu','konya','Turkey / Konya / Selçuklu','TURKEY','42060','+905066519422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 08:28:14',0,NULL,3,1,3,1,'RA117734207CN ','mkucukart'),(10596,679861043001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','amebixus','amebix@azet.sk','Martin Tomečko','Novomeskeho 4','Pezinok','Slovakia','SLOVAK REPUBLIC','90201','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 09:02:06',0,NULL,3,1,3,1,'RA117734241CN\r ','amebixus\r+8的换成+4的'),(10597,679872580001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ricardo777','r.schuijff@gmail.com','R.R Schuijff','Aldebaranhof 58','DORDRECHT','','NETHERLANDS','3318BC','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 09:55:12',0,NULL,3,1,2,1,NULL,'ricardo777'),(10598,679142059018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','osetia1','art-osetia@mail.ru','Mihnevsky Vladislav Valerevich','13 Street Vorovskogo<br>Apartment 59','Kazan','','RUSSIAN FEDERATION','420057','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-05-31 10:38:27',0,NULL,3,1,5,1,'CP227189985CN\r ','osetia1\r白'),(10599,679158031018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','tday67','trollie06@internode.on.net','Troy Day','413 Chapple St','Broken Hill','New South Wales','AUSTRALIA','2880','0880879135','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-05-31 11:26:20',0,NULL,3,1,3,1,'RA117734167CN\r ','tday67'),(10600,679893445001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','javinium','javinian@hotmail.com','Socheat Pheng','1 av Haroun Tazieff<br>appt 111, digicode 2153B','Bussy Saint Georges','Ile-de-France','FRANCE','77600','0685834300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 11:29:20',0,NULL,3,1,3,1,'RA117734198CN\r ','javinium'),(10601,721132879002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tomskitekats','tomaass@one.lv','Toms everts','derwentwalk25','corby','Northamptonshire','UNITED KINGDOM','nn17 2jz','07530672962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 12:02:11',0,NULL,3,1,2,1,NULL,'tomskitekats'),(10602,795324688015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','beatingpayment','beating.payment@gmail.com','Rimvydas Staniukynas','J. Basanaviciaus 79-23','Kedainiai','','LITHUANIA','57279','+37065813499','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 12:04:59',0,NULL,3,1,2,1,NULL,'beatingpayment'),(10603,721138392002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',10,'AA1301',26,'hermeshine','nattapong_suk','technic@phuketalpha.com','Nattapong Suksanguan','261 Talang Road<br>Muang','Phuket','Phuket','THAILAND','83000','076215796','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 12:20:42',0,NULL,3,1,17,0,NULL,'nattapong_suk'),(10604,795329717015,250746712937,'55mm Graduated Neutral Density Filter Gradual Grey 55',1,'AA3316',4.8,'hutongstore','frantons','fantonsen@gmail.com','Frode Antonsen','default','Nyborg','','NORWAY','5131','(+47)98219555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 12:21:30',0,NULL,3,1,2,1,' ','frantons\r新地址:\rFrode Antonsen\rHeiane 73\rNyborg  5131\rNORWAY\r(+47)98219555'),(10605,679908710001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',10,'AA1304',26,'hermeshine','nattapong_suk','technic@phuketalpha.com','Nattapong Suksanguan','261 Talang Road<br>Muang','Phuket','Phuket','THAILAND','83000','076215796','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 12:22:45',0,NULL,3,1,3,1,'RA117722053CN\r ','nattapong_suk\rCANON 镜头盖  77mm   10\rCANON 镜头盖  58mm   10'),(10606,679905111001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','epwdmd','epw.daad@gmail.com','Daniel Golovkin','Keren Hayesod 15<br>Apartment 12','Ashdod','IL','ISRAEL','77404','972547761848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 12:33:53',0,NULL,3,1,2,1,NULL,'epwdmd'),(10607,677212343018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','tenzinglodge','chateaubells@aapt.net.au','Steve Peters','9 tenzing Court','Warner','Queensland','AUSTRALIA','4500','0438796349','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-31 12:33:54',0,NULL,3,1,3,1,'RA117734215CN\r ','tenzinglodge'),(10608,677861690018,280680102981,'YongNuo Flash Battery Pack for Nikon SB900 SD-9  /8AA',1,'AB3311',52,'photographyacc','hrs1349','hrs1971@hotmail.com','Hamidreza Soroush','12 Thurlow Ave<br>Yokine','Perth','Western Australia','AUSTRALIA','6060','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-31 12:38:01',0,NULL,3,1,3,1,'RA117734255CN\r ','hrs1349'),(10609,721143749002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jeffjar','rumbaugh@mcmsys.com','Jeff Rumbaugh','2258 County Road 2315','Moberly','MO','UNITED STATES','65270-5505','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-05-31 12:39:30',0,NULL,3,1,1,1,' ','jeffjar'),(10610,795347164015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','matt2930','themightyrod@gmail.com','Matt Watkins','Willoughby PR<br>43 Calthorpe Road','birmingham','West Midlands','UNITED KINGDOM','B151TS','01214563004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 13:08:31',0,NULL,3,1,2,1,NULL,'matt2930'),(10611,677270677018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',143.99,'photographyacc','hotfizz82','fizzy_mizzy@hotmail.com','Michelle Mizzi','10 Melbourne Close','Port Kennedy','Western Australia','AUSTRALIA','6172','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-05-31 13:45:42',0,NULL,3,1,4,1,'YW865717076CN\rYW865703581CN \r ','hotfizz82\r1.6x4m   背景布   2(黑+灰)\r1.5x2m   背景板（黑，白）    1\r背景架 2mx3m 河北    1\r夹子   3\r0613来信说只收到一个包裹-0630去信问是否收到另一个0703-来信说收到另一个'),(10612,679922857001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','aliriza20','alirizaizgi@hotmail.com','Ali Rıza İZGİ','Lise Cad. Nu:33/1','Denizli','','TURKEY','20100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 13:50:10',0,NULL,3,1,3,1,'RA117734309CN\r ','aliriza20\rXL'),(10613,679937452001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','rumeng69','qsc135@abv.bg','Rumen Georgiev','Br.Miladinovi 1/B/30','Vratza','Vratza','BULGARIA','3000','359 889787904','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 14:04:52',0,NULL,3,0,3,1,'RA117734238CN\r ','rumeng69\rXXXL  已入库'),(10614,721177758002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','quanigou','quany@orange.fr','M PHUNG','Edition DALLOZ<br>80 Avenue de la Marne','Montrouge','Île-de-France','FRANCE','92120','01 41 48 47 66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 14:39:59',0,NULL,3,1,2,1,NULL,'quanigou'),(10615,721192090002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','javivigeo','javivigeo@hotmail.com','Javier Muñoz','Avd. Region de Murcia , nº13, 3ºA','Puerto Lumbreras','Murcia','SPAIN','30890','653329746','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 15:20:28',0,NULL,3,1,17,0,NULL,'javivigeo'),(10616,679960858001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','javivigeo','javivigeo@hotmail.com','Javier Muñoz','Avd. Region de Murcia , nº13, 3ºA','Puerto Lumbreras','Murcia','SPAIN','30890','653329746','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 15:20:29',0,NULL,3,1,4,1,'YW865717065CN\r ','javivigeo\r三脚架 伟峰 wf-6662A+ 6160H 球台   1\r爵影红外 sony    1\rtripod $22'),(10617,679994271001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','peter12160','nguyenph@cisco.com','Cisco, Attn: Peter Nguyen 53607','5030 Sugarloaf Pkwy','Lawrenceville','GA','UNITED STATES','30044','(770) 236-5287','NoPaymentFailure','CheckoutComplete','Other','2011-05-31 16:57:36',0,NULL,3,0,3,1,'RA117734224CN\r ','peter12160\r摄影背心 冬夏  L    1\r摄影背心 Nikon 老款 L    1(已入库)'),(10618,721221335002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',26.8,'hermeshine','peter12160','nguyenph@cisco.com','Cisco, Attn: Peter Nguyen 53607','5030 Sugarloaf Pkwy','Lawrenceville','GA','UNITED STATES','30044','(770) 236-5287','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 16:57:36',0,NULL,3,1,17,0,NULL,'peter12160'),(10619,680000909001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','ashrithshetty','ashrithshetty15@gmail.com','Ashrith  Shetty','#184,7th Cross,Omkar Nagar<br>Arekere , Bannergatta Road','Bangalore','KA','INDIA','560076','9611234765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 17:06:15',0,NULL,3,1,2,1,NULL,'ashrithshetty'),(10620,679275793018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','carlos4970','carlitus@three.com.au','Carlos Velasco','P.O. Box 7719<br>Bondi Beach','Sydney','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-05-31 17:19:14',0,NULL,3,1,2,1,NULL,'carlos4970'),(10621,721245043002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ekphoton2000','ekphoton@aol.com','Gary Carson','34 58th St SE','Washington','DC','UNITED STATES','20019-6542','(202) 584-2020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-05-31 17:39:39',0,NULL,3,1,1,1,NULL,'ekphoton2000'),(10622,721248590002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','sarmat1968','ivanromanyuk68@gmail.com','Ivan Romanuk','Kosmonavtov str. d.2 kv.20','Trostyanets','','UKRAINE','24300','(097)3403985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 17:45:57',0,NULL,3,1,17,0,NULL,'sarmat1968'),(10623,721247383002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','sarmat1968','ivanromanyuk68@gmail.com','Ivan Romanuk','Kosmonavtov str. d.2 kv.20','Trostyanets','','UKRAINE','24300','(097)3403985','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 17:45:58',0,NULL,3,1,3,1,'RA117734175CN\r ','sarmat1968\r欧标\r单灯头   2\r圆形柔光棚 50cm   1'),(10624,795476798015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','dazcrawley','darrencrawley@hotmail.com','darren crawley','278 the uplands<br>palacefields','runcorn','Cheshire','UNITED KINGDOM','wa7 2uf','01928833890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 18:00:57',0,NULL,3,1,2,1,NULL,'dazcrawley'),(10625,680046342001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','denistenchi','tenchido@gmail.com','Denis Kriga','Orehovaya str.<br>house 9, flat 8','Kaliningrad','Kaliningrad','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-05-31 18:46:41',0,NULL,3,1,5,1,'CP227189963CN\r ','denistenchi'),(10626,721279238002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','davidaguilerasoria','aguilerasoria@hotmail.es','David Aguilera Soria','C/ Llevant Nº 28 Casa F','Masquefa','Barcelona','SPAIN','08783','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 18:48:19',0,NULL,3,1,2,1,NULL,'davidaguilerasoria'),(10627,795535384015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','sadgom1950','sfj100@btinternet.com','Stephen Jones','Old School, Snods Edge<br>Shotley Bridge','Consett','Durham','UNITED KINGDOM','DH8 9LE','01207255437','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-05-31 19:34:18',0,NULL,3,1,2,1,NULL,'sadgom1950'),(10628,795540370015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'AKT026',16.9,'hutongstore','mirojank','jankovicmail@gmail.com','Miroslav Jankovic','F.Tudmana 59A','Jastrebarsko','','CROATIA','10450','+385981771051','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 19:42:06',0,NULL,3,1,17,0,NULL,'mirojank'),(10629,795541288015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','mirojank','jankovicmail@gmail.com','Miroslav Jankovic','F.Tudmana 59A','Jastrebarsko','','CROATIA','10450','+385981771051','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 19:43:33',0,NULL,3,1,17,0,NULL,'mirojank'),(10630,721309532002,120618815235,'TianYa 52mm CPL filter New 52 Circular Polarizing C-PL',1,'AA2301',5.7,'hermeshine','dublinnn','aleksandr.svedov@mail.ru','aleksandr svedov','apt 3 Saffron house,station road<br>sutton','Dublin','Dublin','IRELAND','13','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 19:46:51',0,NULL,3,1,2,1,NULL,'dublinnn'),(10631,795542087015,250599919356,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',2.25,'hutongstore','mirojank','jankovicmail@gmail.com','Miroslav Jankovic','F.Tudmana 59A','Jastrebarsko','','CROATIA','10450','+385981771051','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 19:48:01',0,NULL,3,1,3,1,'RA117734520CN\r ','mirojank\r方形滤镜接口环 52mm    1\r方形滤镜接口环 58mm    1\r方形滤镜接口环 62mm    1\r天涯方镜  ND2/4/8         各1个\r滤镜卡座   1\r'),(10632,795567413015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',48.9,'hutongstore','shukri_adams','forhekset@mail.usa.com','Shukri Adams','c/o Swush<br>Vesterbrogade 46 1.tv','Copenhagen V','','DENMARK','1620','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-05-31 20:29:07',0,NULL,3,1,4,1,'YW865717054CN\r ','shukri_adams\r欧标'),(10633,721329997002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','olegendabay','olegenda@gmail.com','Oleg Kremerov','Prof. Shor str. 8b','Petah-Tiqwa','Hamerkaz','ISRAEL','49289','0545717143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 20:33:35',0,NULL,3,1,11,1,' ','olegendabay'),(10634,679379910018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','palhenf','palhenrik@gmail.com','Pål Henrik Finsrad','Cecilie Løvøs veg 2','Trondheim','','NORWAY','7050','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-31 20:49:14',0,NULL,3,1,2,1,NULL,'palhenf'),(10635,733156621017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','grgng','grgnrg@gmail.com','NIKOLAS GRIGORIOU','62 Martyron<br>Ano Archanes','Heraklion/Crete','Greece','GREECE','70100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-31 21:08:21',0,NULL,3,1,2,1,NULL,'grgng'),(10636,721353648002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','eshop_masenka','masenka@masenka.eu','Miroslav Horák','Jiřího Wolkera 1888<br>eshop.masenka@masenka.eu','Nymburk','ČR','CZECH REPUBLIC','28802','+420606204980','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 21:57:24',0,NULL,3,1,5,1,'CP227189932CN ','eshop_masenka'),(10637,679415143018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','artemkonb','konbwarlock@mail.ru','Artem Konovodov','keramicheskiy proezd<br>47-1-85','moscow','moscow','RUSSIAN FEDERATION','127540','89162066972','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-05-31 22:25:43',0,NULL,3,1,5,1,'CP227189977CN\r ','artemkonb'),(10638,795624373015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','flaa.bdez','flavia.bdez.rguez@gmail.com','Flavia Bernárdez Rodríguez','Pabellón de Uruguay. Avda. de Chile s/n.','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41013','625429897','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-05-31 22:36:17',0,NULL,3,1,2,1,NULL,'flaa.bdez'),(10639,680125103001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','enistr','info@enis.fr','Enis Tekdogan','1 place de la corniche','firminy','Rhône-Alpes','FRANCE','42700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-31 22:48:29',0,NULL,3,1,2,1,NULL,'enistr'),(10640,677987790001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','kadaus_maximus','spin_king69@hotmail.com','Kade Moir','10 Loretta Ave','Cairns','Queensland','AUSTRALIA','4870','070409599476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-05-30 10:21:44',0,NULL,3,0,18,0,NULL,'kadaus_maximus'),(10641,795652440015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','gongle40','cfrard435@gmail.com','Richard Copeland','69 Delamere Road.','Bedworth','Warwickshire','UNITED KINGDOM','CV12 8SG','02476314961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 00:10:08',0,NULL,3,1,3,1,'RA117734184CN\r ','gongle40\r45w 5500k 灯泡 220v    4'),(10642,679179927018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','mikokik5','mikokiks@gmail.com','Michael Bollozos','Unit 8, 2-4 Hampton Court Road','Carlton','New South Wales','AUSTRALIA','2218','0291186837','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-01 01:18:21',0,NULL,3,1,2,1,NULL,'mikokik5'),(10643,733242050017,270750650619,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.88,'photographyacc','ali_689','ali_689@hotmail.com','Alison Geeves','5 Booth Street','Parkdale','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-01 02:07:59',0,NULL,3,1,2,1,NULL,'ali_689'),(10644,733245759017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','space.noodle','julian.c.chung@gmail.com','Julian Chung','504E / 138 Carillon Av','Newtown','New South Wales','AUSTRALIA','2042','0405444594','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-01 02:23:20',0,NULL,3,1,2,1,' ','space.noodle'),(10645,795695109015,250746713895,'67mm Graduated Neutral Density Filter Gradual Grey 67',1,'AA3319',5.2,'hutongstore','sausage_1','debral@iprimus.com.au','John Baxter','3 Ingram Street','Wyong','New South Wales','AUSTRALIA','2259','02407435699','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 02:38:26',0,NULL,3,1,2,1,NULL,'sausage_1'),(10646,680197007001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','tangmusi1801','omastho@hotmail.com','Lim W. C. Thomas','Block 170 Yishun Ave 7<br>#08-865','default','','SINGAPORE','760170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 02:48:16',0,NULL,3,1,17,0,NULL,'tangmusi1801'),(10647,680204618001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','tangmusi1801','omastho@hotmail.com','Lim W. C. Thomas','Block 170 Yishun Ave 7<br>#08-865','default','','SINGAPORE','760170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 03:25:18',0,NULL,3,1,3,1,'RA117734290CN\r ','tangmusi1801\r大力夹云台   1\r永诺 Canon ttl线  3m   1'),(10648,720645863002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','suddig','patrik@suddig.com','Patrik Svensson','Runstensvägen 155','Handen','Stockholm','SWEDEN','13645','+4687713855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 04:59:47',0,NULL,3,1,2,1,NULL,'suddig'),(10649,679479268018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','krystledance37','brock.krystle@hotmail.com','Krystle Carter','33 Gaynor Rd','Munruben','Queensland','AUSTRALIA','4125','0704158185','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-01 05:05:29',0,NULL,3,1,4,1,'YW865717080CN ','krystledance37\rbackground support  $20\r-0615客户回信说已经收到'),(10650,679513142018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','ryanmoses18','sbd_moses@hotmail.com','Ryan George','2052 E 54th St','Brooklyn','NY','UNITED STATES','11234-4713','(305) 978-3952','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 06:08:18',0,NULL,3,1,4,1,'YW865717102CN ','ryanmoses18\r灯泡 110v\r申报:Lighting kit , $30'),(10651,778269390016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','kimo1342','karim2000@ntlworld.com','karim boussif','39 great ganett','welwyn garden city','hertfordshire','UNITED KINGDOM','al7 3db','01707882344','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 06:11:28',0,NULL,3,1,2,1,NULL,'kimo1342'),(10652,680235535001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','pawnazar','nazar1@o2.pl','Pawel Nazarewycz','20 Sycamore Crt','Narre Warren South','Victoria','AUSTRALIA','3805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 06:30:35',0,NULL,3,0,4,1,'YW865717091CN ','pawnazar\r白色  3mx6m\r'),(10653,721483675002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','farpcmv','fernandoruiz@terra.cl','fernando alejandro ruiz palma','jose miguel carrera 439 dpto 606<br>barrio universitario','santiago','santiago','CHILE','8370213','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 07:20:38',0,NULL,3,1,5,1,'CP227189699CN ','farpcmv\r2.233'),(10654,795767364015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','fd_sa_bayer','faosamdababi@yahoo.com','Faouzi Dababi','Danah Compound, Ericsson Company<br>Al-Nahdah District, Khurais Road (next to Volvo Showroom)','P.O. Box 6121','Riyadh','SAUDI ARABIA','11442','+966564140729','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 07:59:28',0,NULL,3,1,2,1,NULL,'fd_sa_bayer'),(10655,718866063002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','hasanovhasan','gasan_g@yahoo.ca','Hasan Hasanov','Sherif-Zade 48, ap.19','Baku','','AZERBAIJAN','az1100','994502210420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 08:08:17',0,NULL,3,1,2,1,NULL,'hasanovhasan'),(10656,679537214018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','brbfree','director@mentallogic.com.au','Mark Pinoli','Mental Logic Pty Ltd<br>Unit 1, 119 Little Smith Street','Fitzroy','Victoria','AUSTRALIA','3065','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-01 08:13:36',0,NULL,3,1,2,1,NULL,'brbfree'),(10657,679539419018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','ratonnettoyeur','bonkoskithomas@gmail.com','Thomas Bonkoski','11, rue thibault<br>La pommeraie','Marly le roi','Île-de-France','FRANCE','78160','0679568646','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-01 08:21:29',0,NULL,3,1,2,1,NULL,'ratonnettoyeur'),(10658,733324065017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','yiit18','yiit_gunal18@hotmail.com','Yigit gunal','308-1348 barclay st','Vancouver BC','BC','CANADA','V6E1H7','(425) 369-9443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-01 09:03:41',0,NULL,3,1,3,1,'RA117734459CN ','yiit18'),(10659,679547380018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','pies1984_73','adams_pat805@yahoo.com.au','Patrick Adams','15 Flora St','Oyster Bay','New South Wales','AUSTRALIA','2225','0406004271','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-01 09:06:24',0,NULL,3,1,3,1,'RA117722040CN\r ','pies1984_73'),(10660,679556700018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','nishandj007','nishandj@gmail.com','Anushka Fernando','55/1, Church Road,','Colombo - 15','Western Province','SRI LANKA','00094','0777 740010','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-01 09:40:12',0,NULL,3,1,3,1,'RA117734357CN ','nishandj007'),(10661,721514479002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','clem.latour','clemlatour@yahoo.fr','Latour','Soléo<br>Créativa - Agroparc BP 21221','Avignon','Provence-Alpes-Côte d\'Azur','FRANCE','84911','0490271250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 09:56:15',0,NULL,8,1,17,0,NULL,'clem.latour'),(10662,680275114001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','clem.latour','clemlatour@yahoo.fr','Latour','Soléo<br>Créativa - Agroparc BP 21221','Avignon','Provence-Alpes-Côte d\'Azur','FRANCE','84911','0490271250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 09:56:15',0,NULL,8,1,17,0,NULL,'clem.latour'),(10663,721514247002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','clem.latour','clemlatour@yahoo.fr','Latour','Soléo<br>Créativa - Agroparc BP 21221','Avignon','Provence-Alpes-Côte d\'Azur','FRANCE','84911','0490271250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 09:56:16',0,NULL,3,1,2,1,NULL,'clem.latour\rcanon 机身盖、镜头后盖  1\r52-58mm 双阳环   1\r52mm uv    1'),(10664,721516956002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','mmikki90','fuxmalder@azet.sk','Marek Mikulášek','Nitrianska 13','Hlohovec','','SLOVAK REPUBLIC','92001','00421911307606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 10:03:10',0,NULL,3,1,2,1,NULL,'mmikki90'),(10665,795807339015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',1,'AA3310',3.5,'hutongstore','buryastronomer','rogerkershaw@hotmail.co.uk','roger kershaw','63 goldfinch drive','bury','Greater Manchester','UNITED KINGDOM','bl96jt','01617645452','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 10:20:53',0,NULL,3,1,2,1,NULL,'buryastronomer'),(10666,779476087016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','mike_4261','bakerm1@live.co.uk','Michael Baker','106 Harcourt Street','Luton','Bedfordshire','UNITED KINGDOM','LU1 3QL','01582529982','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 10:38:43',0,NULL,3,1,2,1,NULL,'mike_4261'),(10667,779493606016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','bcinc1789','ben.creemers@gmail.com','Ben Creemers','Hoogveld 18','Peer','','BELGIUM','3990','32486911955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 11:31:09',0,NULL,8,1,17,0,NULL,'bcinc1789'),(10668,795827703015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','bcinc1789','ben.creemers@gmail.com','Ben Creemers','Hoogveld 18','Peer','','BELGIUM','3990','32486911955','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 11:31:09',0,NULL,3,1,2,1,NULL,'bcinc1789\r眼罩 450D/500D  1\r橡胶遮光罩 55mm   1'),(10669,721069733002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','skuratov2011','skuratov86@yandex.ru','Alexandr Skuratov','Kalinina street 62 apartment 56','Seversk','Tomsk Oblast','RUSSIAN FEDERATION','636000','(983) 232-77-33','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 11:39:29',0,NULL,3,1,3,1,'RA117734343CN ','skuratov2011'),(10670,680304438001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','segovij','jmsaguillo@gmail.com','Jose Maria. Saguillo Segovia','CHEP ESPAÑA Calle Cincel 1','Fuenlabrada','Madrid','SPAIN','28947','669445362','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 11:45:30',0,NULL,3,1,17,0,NULL,'segovij'),(10671,680304179001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','segovij','jmsaguillo@gmail.com','Jose Maria. Saguillo Segovia','CHEP ESPAÑA Calle Cincel 1','Fuenlabrada','Madrid','SPAIN','28947','669445362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 11:45:31',0,NULL,3,1,17,0,NULL,'segovij'),(10672,721541825002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',1,'AA3202',18.5,'hermeshine','segovij','jmsaguillo@gmail.com','Jose Maria. Saguillo Segovia','CHEP ESPAÑA Calle Cincel 1','Fuenlabrada','Madrid','SPAIN','28947','669445362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 11:45:31',0,NULL,3,1,4,1,'YW865717183CN\r','segovij\r三脚架  伟峰 WF-6662A   1\r麂皮   1\r爵影无线N3   1\rtripod  $18\r'),(10673,680309396001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',29.12,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 12:03:25',0,NULL,3,1,2,1,NULL,'arnorolf10'),(10674,733378328017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',5.68,'photographyacc','ode19','steph@rockus.com.au','Steph Edwardes','PO Box 2425','Richmond South','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-01 12:19:50',0,NULL,3,1,2,1,NULL,'ode19'),(10675,721546239002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','offpix','info@offpix.de','Alissa Maxman','Leipziger Strasse 40','Berlin','','GERMANY','10117','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,'YW865717150CN ','offpix\r欧标\rlighting kit  $26'),(10676,791557163015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','harvijack2011','harvikaur2011@hotmail.co.uk','Harpreet Kaur','4 Main Street<br>Yoxall','Burton on Trent','Staffordshire','UNITED KINGDOM','DE13 8NQ','07795224477','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-01 12:37:22',0,NULL,3,1,4,1,'YW865717146CN ','harvijack2011\r英标\r申报：Lighting kit；30$'),(10677,680289530001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','iggy-rock','igor.b.good@gmail.com','Igor Bulog','D. Domjanica 15','Djakovo','','CROATIA','31400','+385 98 9668 590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 12:51:36',0,NULL,3,1,2,1,NULL,'iggy-rock\r打一个invoice一起发给他'),(10678,680326026001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','firstarcangelm','firstarcangelm@aol.com','Michael Harrell','18320 Crawley Rd','Odessa','FL','UNITED STATES','33556-4821','(813) 928-1776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-01 13:06:54',0,NULL,3,1,1,1,NULL,'firstarcangelm'),(10679,795858957015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',4,'AA2208',9,'hutongstore','good_biddy','steve.ioio@talktalk.net','Steve Hughes','15, Kempton Close,<br>Thornbury','Bristol','South Glos','UNITED KINGDOM','BS35 1SL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 13:13:56',0,NULL,3,1,2,1,NULL,'good_biddy\r注意是4个'),(10680,795873049015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','ukcommando','dave@sparkes.info','Dave Sparkes','5 Beauport Gardens','St Leonards-on-Sea','East Sussex','UNITED KINGDOM','TN37 7PQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 13:36:11',0,NULL,3,1,2,1,NULL,'ukcommando'),(10681,721576961002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','efmuffin','lewiswe.e@hotmail.com','Lewis Wee','Blk 405C Fernvale Lane<br>#09-101','default','Singapore','SINGAPORE','793405','90266263','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:50:02',0,NULL,3,1,11,1,NULL,'efmuffin'),(10682,721570183002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','mcsim512','maxim7r@gmail.com','Maksim Bugrimenko','pr.Selmash, dom18, kv40','Rostov-on-Don','','RUSSIAN FEDERATION','344029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:55:33',0,NULL,3,1,17,0,NULL,'mcsim512'),(10683,721574087002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','mcsim512','maxim7r@gmail.com','Maksim Bugrimenko','pr.Selmash, dom18, kv40','Rostov-on-Don','','RUSSIAN FEDERATION','344029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 13:55:34',0,NULL,3,1,2,1,NULL,'mcsim512\r闪光灯B座     1\r爵影红外 canon     1\r'),(10684,721571511002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 13:57:27',0,NULL,8,1,17,0,NULL,'saud-p'),(10685,679220150001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 13:57:28',0,NULL,8,1,17,0,NULL,'saud-p'),(10686,720787039002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 13:57:30',0,NULL,3,1,8,1,'CP227020429CN ','saud-p\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子  2套\r背景架2m x 3m    1\r8.5之内'),(10687,721495132002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-01 14:03:50',0,NULL,3,1,3,1,'RA117734388CN ','m.petrosyan'),(10688,680346566001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','dgeride1','gerald.malblanc@free.fr','Gérald MALBLANC','19 rue des Bornes','STRASBOURG','Alsace','FRANCE','67200','0388278020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 14:29:12',0,NULL,3,1,3,1,'RA117734365CN ','dgeride1'),(10689,679646187018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','junodana1983','junodana@yahoo.com','Jimmy Hak','18 robinia ave','Fairfield east','New South Wales','AUSTRALIA','2165','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-01 14:55:46',0,NULL,3,1,3,1,'RA117734326CN ','junodana1983'),(10690,721591089002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ulrikkeck','ulrikkekjaer@hotmail.com','Ulrikke Christina Kjær','Skivebakken 38b','Bergen','','NORWAY','5018','41617363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 15:05:13',0,NULL,3,1,2,1,NULL,'ulrikkeck'),(10691,680383746001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','e.khattar','khattarelias@gmail.com','elias khattar','fliederweg 6','juelich','','GERMANY','D-52428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:15:57',0,NULL,3,1,17,0,NULL,'e.khattar'),(10692,721625091002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','e.khattar','khattarelias@gmail.com','elias khattar','fliederweg 6','juelich','','GERMANY','D-52428','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:20:28',0,NULL,3,1,2,1,NULL,'e.khattar\rnikon 反接环  52mm    1\r镜头笔    1'),(10693,721627989002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',46.99,'hermeshine','milouspp','milospp@azet.sk','Milous Chab','Okruzna 766/51','Poprad','Slovakia','SLOVAK REPUBLIC','05801','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 16:28:42',0,NULL,3,1,3,1,'RA117734312CN ','milouspp'),(10694,680394138001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','aruneedang','tungtding@gmail.com','Arunee Dangvilailerds','5809 47th Ave<br>Fl 3','Woodside','NY','UNITED STATES','11377-5549','(917) 670-4008','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-01 16:44:59',0,NULL,3,1,1,1,NULL,'aruneedang'),(10695,680341393001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 17:15:53',0,NULL,3,1,3,1,'RA117734391CN ','tim-vl'),(10696,680430621001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','archana278','archshej@gmail.com','Archana Shejwalkar','38405, 2373 Lam Circle','Victoria','BC','CANADA','V8N6K8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:16:10',0,NULL,3,1,2,1,NULL,'archana278'),(10697,680438535001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','ad_riano','adrianotorii@hotmail.com','Adriano Leite','Av. 11 de Junho, 875<br>(apto 122)','São Paulo','São Paulo','BRAZIL','04041-053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:34:12',0,NULL,3,1,3,1,'RA117734405CN ','ad_riano\r欧标'),(10698,796009221015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','archivlad','spirov.vladimir@gmail.com','Vladimir Spirov','6 Cleveland Road','Ealing','London','UNITED KINGDOM','W13 8AU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-01 18:39:59',0,NULL,3,1,3,1,'RA117734462CN\r ','archivlad'),(10699,775530646016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','hermillio2011','herman.opelele@yahoo.co.uk','Hermillio opel','18 carrigmore terrace saggart<br>citywest','dublin','Dublin','IRELAND','24','0852050379','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-01 18:43:16',0,NULL,3,1,4,1,'YW865717135CN ','hermillio2011\r英标\r背景布   绿色\r申报：Lighting kit；40$\r'),(10700,721683865002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','babsurecord','frijolete_13@yahoo.com.ar','Ariel Delgado','Italia Nº 950<br>e/ Larrea y Las Heras','Carlos Spegazzini (Ezeiza)','Buenos Aires','ARGENTINA','1813','02274-450816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 18:46:46',0,NULL,3,1,2,1,NULL,'babsurecord'),(10701,680455091001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','hariscruff','beatlesfanforever@gmail.com','Susan Fischer','1883 San Lucas Ln','Fenton','MO','UNITED STATES','63026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-01 19:11:02',0,NULL,3,1,1,1,NULL,'hariscruff'),(10702,721702647002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mechy97','iamshlee@gmail.com','seung hwan Lee','1415 Natalie Ln<br>Apt 206','Ann Arbor','MI','UNITED STATES','48105-2913','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 19:25:27',0,NULL,3,1,1,1,NULL,'mechy97'),(10703,721712857002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','garbona21','gusarb21@gmail.com','Gustavo Arbona C01-016109','1316 N.W. 78 th Ave. Doral, FL 33126-1606','Doral','FL','UNITED STATES','33126','305 200 8619','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 19:47:28',0,NULL,3,1,4,1,'YW865717124CN ','garbona21\r申报：Lighting kit；20$\r'),(10704,680283034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','paratype','a.leskoff@gmail.com','Andrii Lieskov','4 Boychenko St., Apt.8','Kiev','','UKRAINE','02192','+380679370638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 20:22:18',0,NULL,3,1,2,1,NULL,'paratype'),(10705,721755425002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','oleg.patriot','oleg.patriot@gmail.com','Oleg Borisenko','moshe sharet 12/6','BAt-YAM','IL','ISRAEL','59504','972504280945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 21:39:31',0,NULL,3,1,2,1,NULL,'oleg.patriot'),(10706,721770152002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mostofizadeh','mostofizadeh@yahoo.com','Ali Mostofizadeh','2936 Sapra St','Thousand Oaks','CA','UNITED STATES','91362','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 22:12:53',0,NULL,3,1,1,1,NULL,'mostofizadeh'),(10707,721776303002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tup6ro','jlr2482@earthlink.net','Jennifer Robertson','2701 Scarlet Rd','Winter Park','FL','UNITED STATES','32792-4328','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 22:34:14',0,NULL,3,1,1,1,NULL,'tup6ro'),(10708,721781649002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',2,'AE2310',12.4,'hermeshine','jorgecostaalves','jorgecostaalves@gmail.com','Jorge Costa Alves','Loteamento AM SOUSA, lote 6<br>Fernandinho','fernandinho','Ventosa - Torres Vedras','PORTUGAL','2565-841','00351918510666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 22:55:57',0,NULL,3,1,2,1,NULL,'jorgecostaalves'),(10709,721781860002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','baldertsang','balder0219@yahoo.com.hk','Balder Tsang','1761 E 17th St','Brooklyn','NY','UNITED STATES','11229-2101','(646) 639-9955','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-01 22:57:19',0,NULL,3,1,1,1,NULL,'baldertsang'),(10710,679601537018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',200,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-01 22:59:42',0,NULL,3,1,8,1,'CP227020415CN ','saud-p\r欧标\r2m 灯架  3\r斜臂   3\r50-70单灯头棚   欧标  3\r115w 220v   3\r包   1'),(10711,796139031015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','questillusions','dazz_1084_@hotmail.com','DARREN PARNELL','49 THE ESPLANADE SYLVANIA HEIGHTS','SYDNEY','New South Wales','AUSTRALIA','2224','0295225508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-01 23:12:54',0,NULL,3,1,2,1,NULL,'questillusions'),(10712,680089329001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',36.97,'hermeshine','gan-dalf','ifarber@web.de','Ilja Farber','Lucas Cranach Str 17a','Walldorf','','GERMANY','69190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-01 23:18:24',0,NULL,3,1,3,1,'RA117734374CN ','gan-dalf\r欧标\r45w 5500k 220v 灯泡   2\r双灯头    1'),(10713,721802986002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','karatekarate2009','teatroa@hotmail.com','Federico R Bongiorno','Calle 65 N789 (entre 10 y11)','La Plata','Buenos Aires','ARGENTINA','1900','(005) 422-1423 ext.: 5795','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-02 00:31:39',0,NULL,3,1,3,1,'RA117734330CN ','karatekarate2009'),(10714,796162339015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','kgaf12052010','katiepivot3@hotmail.com','katelyn griffiths','21a belmont st<br>preston','melbourne','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-02 00:41:11',0,NULL,3,1,4,1,'YW865717113CN ','kgaf12052010\r澳标\r申报：Lighting kit；30$'),(10715,733654768017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','redninjatwo','jared@jaredpatterson.com','Jared Patterson','1878 Deerhaven Ln NE<br>Apt 15','Rochester','MN','UNITED STATES','55906','(507) 884-9674','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-02 00:43:04',0,NULL,3,1,1,1,NULL,'redninjatwo'),(10716,679869132018,280680856652,'New JYC-N1 Wireless Remote Control for Nikon D300s D700',1,'AA3201',18,'photographyacc','redandjen','mlee1970@bigpond.com','Michael Lee','3 Burt Street<br>Mt Clarence','Albany','Western Australia','AUSTRALIA','6330','0898418774','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 00:53:30',0,NULL,3,1,2,1,NULL,'redandjen'),(10717,721823560002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','mequinjim','mequonjim@netzero.net','James Nigbor','12116 W Donges Bay Rd','Mequon','WI','UNITED STATES','53097','','NoPaymentFailure','CheckoutComplete','Other','2011-06-02 01:59:07',0,NULL,3,0,1,1,'第2次EUB:\rLK002115482CN','mequinjim\r3XL(已入库)(已入库)\r--\r第一次的货后背的拉链拉手掉了,这次尽量给他挑个好点的发'),(10718,721828435002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','leontina4ever','fudan_lilin@hotmail.com','Lin Li','Box 0845<br>2205 Lower Mall','Vancouver','BC','CANADA','V6T1Z4','(604) 349-0510','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 02:21:33',0,NULL,3,1,2,1,NULL,'leontina4ever\r新地址:\rLin Li\r7177 Broadway\rBurnaby BC V5A1R7\rCanada\r'),(10719,721653986002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','deepsky3','deepsky3@gmail.com','Byunghang Ha','167-125 Deokjin dong 2 ga<br>Deokjin ku','Cheonju','Chollabuk do','KOREA,REPUBLIC OF','561-851','(820) 632-7730 ext.: 76','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-02 02:51:32',0,NULL,3,1,11,1,NULL,'deepsky3'),(10720,679896718018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','tarahiquily','taraconservation@museetahiti.pf','Tara Hiquily','BP 13 338','Punaauia','TAHITI','FRENCH POLYNESIA','98717','(689) 74 75 02','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-02 02:57:18',0,NULL,5,0,18,0,' ','tarahiquily'),(10721,679897336018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','jrbloom2','jrbloom.au@hotmail.com','Juan Bloom','317 Beaudesert-Nerang Rd, Nerang','Gold Coast','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-02 02:58:17',0,NULL,3,1,2,1,NULL,'jrbloom2'),(10722,679911964018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','candykida','candykida@hotmail.com','Candy AU','EnergyAustralia<br>Level 6, 570 George Street','Sydney','New South Wales','AUSTRALIA','2000','61411089837','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-02 04:19:28',0,NULL,3,1,2,1,NULL,'candykida'),(10723,679922831018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','dearp77','david@ct.gs','David Earp','11 Wyoming Road','Wyoming','New South Wales','AUSTRALIA','2250','0243293514','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-02 05:42:52',0,NULL,3,1,3,1,'RA117734431CN ','dearp77'),(10724,679942021018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','-sg-','steven@bx.com.au','Steven George','14 St Cuthberts Court','Marshall','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 07:24:06',0,NULL,3,1,2,1,NULL,'-sg-'),(10725,721880401002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','14102512','roman_mukhin@list.ru','Roman Mukhin','Gorskiy str. 8a-48','Novosibirsk','','RUSSIAN FEDERATION','630073','(913)944-4800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 07:30:49',0,NULL,3,1,2,1,NULL,'14102512'),(10726,679964581018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 09:08:18',0,NULL,3,1,2,1,NULL,'tan6111'),(10727,680653299001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','irghael','tramoni.stephane@neuf.fr','Stéphane Tramoni','le Chypre 1 bat.A Res des Iles<br>Rte des Iles Sanguinaires','Ajaccio','Corse','FRANCE','20000','0495210761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 09:12:38',0,NULL,3,1,2,1,NULL,'irghael'),(10728,680656299001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','sinawacht','brigadoon3@xtra.co.nz','Mr P Craze','15/7 Cracroft Street<br>Parnell','Auckland','New Zealand','NEW ZEALAND','1052','+6494365772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 09:24:49',0,NULL,3,1,2,1,NULL,'sinawacht'),(10729,796287788015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','jadedhills23','goldlight23@ntlworld.com','Peter Brewster','21 Beech Drive','Berkhamsted','Hertfordshire','UNITED KINGDOM','HP4 2HG','01442383515','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-02 09:28:02',0,NULL,3,1,2,1,NULL,'jadedhills23'),(10730,721929899002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','maratka80','kanmarat@gmail.com','MARAT KANIBALOTSKI','HANEVIM 365','ASHDOD','ISRAEL','ISRAEL','77473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 11:11:08',0,NULL,3,1,3,1,'RA117722036CN\r ','maratka80'),(10731,733791238017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','enjay42','jeffo42@bigpond.com','Neil Jeffrey','1 Coolong Close<br>Tumbi Umbi','Wyong Shire','New South Wales','AUSTRALIA','2261','0243897513','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 11:17:51',0,NULL,3,1,2,1,NULL,'enjay42'),(10732,680683758001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-02 11:37:52',0,NULL,8,1,17,0,NULL,'saud-p'),(10733,680683871001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-02 11:37:53',0,NULL,3,1,8,1,'CP227020432CN\r ','saud-p\r背景架2mx2m   (白+黑）  x  2'),(10734,779987634016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',38.99,'hutongstore','julesblimited','ebay@julesb.co.uk','Rafal Rutyna','Yellow Brick House, Back New Bridge Street','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE1 2TY','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-02 11:52:57',0,NULL,3,1,3,1,'RA117722019CN\r ','julesblimited'),(10735,796338726015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',63,'hutongstore','ellahowson','ellpal_rules@hotmail.com','3850Ella Howson','23 wandana road','sale','Victoria','AUSTRALIA','3850','0351432763','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-02 12:07:47',0,NULL,3,1,4,1,'YW865717220CN\r ','ellahowson\r澳标 \rlighting kit  $30\r'),(10736,721950390002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','betchie09','betchie70@gmail.com','Maribeth Ecolango','2/4 Pope Street','Aitkenvale','Queensland','AUSTRALIA','4814','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 12:27:48',0,NULL,3,1,3,1,'RA117722022CN\r ','betchie09'),(10737,733622232017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',29.02,'photographyacc','3420craig','clintlowe@googlemail.com','Mr Clint Lowe','11 Willow Brook','Abingdon','Oxfordshire','UNITED KINGDOM','OX14 1TD','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-02 12:31:36',0,NULL,3,1,3,1,'RA117722209CN\r ','3420craig\r6片装滤镜袋   1\r67mm 橡胶罩   1\r广角托架   1\r绿叶77mm cpl   1\r52mm 橡胶罩   1\r'),(10738,680719409001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','romary2','duryr@pt.lu','Romain Dury','rue Jos. Mille ,10','Kayl','','LUXEMBOURG','L-3657','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 13:28:00',0,NULL,3,1,3,1,'RA117722138CN\r ','romary2'),(10739,796371842015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','anime_t3d','anime_t3d@yahoo.com','takis vezakis','7940 Agia Paraskeui','Rethymno','Crete','GREECE','74100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 13:40:21',0,NULL,3,1,2,1,NULL,'anime_t3d'),(10740,680040127018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','beretta9mm0','feldtest@optusnet.com.au','Adam Feldman','VISITS<br>Level 12, 114 Albert Road','South Melbourne','Victoria','AUSTRALIA','3205','0390152583','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 13:45:52',0,NULL,3,1,2,1,NULL,'beretta9mm0'),(10741,796388020015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','kdamgaard00','vem@nuddi.dk','Kai Damgaard','Irisvej 4','Borkop','','DENMARK','7080','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 14:25:46',0,NULL,3,1,2,1,NULL,'kdamgaard00'),(10742,796388477015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','sarusalvadoralfredo','mattahitori@hotmail.com','SALVADOR ALFREDO DIAZ MATSUDA','NAKAGAWA-KU<br>SHOMEICHO 4-40-1','NAGOYA-SHI','Aichi','JAPAN','454-0854','08036593770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 14:27:39',0,NULL,3,1,17,0,NULL,'sarusalvadoralfredo'),(10743,680737445001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','sarusalvadoralfredo','mattahitori@hotmail.com','SALVADOR ALFREDO DIAZ MATSUDA','NAKAGAWA-KU<br>SHOMEICHO 4-40-1','NAGOYA-SHI','Aichi','JAPAN','454-0854','08036593770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 14:31:12',0,NULL,3,1,3,1,'RA117722141CN\r ','sarusalvadoralfredo\r圆形柔光棚 50cm    1\r反光板支架   1\r'),(10744,796386023015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0001',150,'hutongstore','photoscubaman','hinton_john@hotmail.com','john hinton','1 westworth close<br>leven park','yarm','cleveland','UNITED KINGDOM','ts15 9sy','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-02 14:31:15',0,NULL,3,1,4,1,'YW865717205CN\r ','photoscubaman\rtripod  $25\r717 155高'),(10745,680061089018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','todopolar','majoreig@hotmail.es','SERGIO GIL DELEGIDO','AV/ ALMAIG 25<br>FARMACIA Mª JOSE SEGURA BONO','ONTINYENT','Comunidad Valenciana','SPAIN','46870','665129803','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-02 14:55:05',0,NULL,3,1,4,1,'YW865717194CN\r ','todopolar\r'),(10746,780055656016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','egoiq','egoiq@wp.pl','Lukasz Hyjek','Chestnut Lodge<br>3 Woodfield Road','Ealing','London','UNITED KINGDOM','W5 1SL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-02 15:11:34',0,NULL,3,1,2,1,NULL,'egoiq'),(10747,733876337017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','ebkye','sexymumma_6@hotmail.com','Mark Mazza','5 Bendock Crt','Traralgon','Victoria','AUSTRALIA','3844','0413457869','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-02 15:57:12',0,NULL,3,0,3,1,'RA117722186CN\r ','ebkye\r1.6x3m 白色'),(10748,796423137015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','raycodca','playmobil_21@hotmail.com','RAYCO CANO','C/ PARROCO GARCIA PEREZ Nº28','SAN CRISTOBAL DE LA LAGUNA','Canarias','SPAIN','38205','610081859','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 15:58:36',0,NULL,3,1,2,1,NULL,'raycodca'),(10749,680082162018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','ozcountrycandles','countrycandles@bigpond.com','Debra Paton','Lot 225 Homestead Road','Harvey','Western Australia','AUSTRALIA','6220','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-02 16:00:09',0,NULL,3,1,2,1,NULL,'ozcountrycandles'),(10750,796428989015,250678485422,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10ft)',1,'AO0018',28.9,'hutongstore','wolfsnet','coyote_souris@hotmail.com','Sylvain PLEIGNEUR','5 rue Pavée<br>Appartement 51','Rouen','Haute-Normandie','FRANCE','76100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 16:12:50',0,NULL,3,0,3,1,'RA117722243CN\r ','wolfsnet\r白色 3mx3m\r1.259'),(10751,733887863017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','rabie-photography','crash_30@hotmail.com','Rabie Al-Buraiky','P.O.Box: 105898<br>Auckland City Postshop','Auckland','Auckland','NEW ZEALAND','1143','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-02 16:33:38',0,NULL,3,1,3,1,'RA117722075CN\r ','rabie-photography'),(10752,722043032002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ju08ra','jvidoni@net.amis.hr','Juraj Vidoni','Prilaz Gjure Dezelica 60','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 17:33:09',0,NULL,3,1,2,1,NULL,'ju08ra'),(10753,796483496015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.62,'hutongstore','1danika_007','dandy111@zoznam.sk','Daniel Stefanik','2 Dublin Road','Fermoy','Cork','IRELAND','default','0857348449','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 18:09:44',0,NULL,3,1,2,1,NULL,'1danika_007'),(10754,796518950015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','rumblebeat','liverani@avvenire.it','luca  liverani','via g. barracco 12','roma','RM','ITALY','00162','06-68823213','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 19:17:10',0,NULL,3,1,2,1,NULL,'rumblebeat'),(10755,780143271016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.88,'hutongstore','mrjustindallas','studio@impakt.co.za','Justin Dallas','19 Ukosi Road','Kloof','KwaZulu-Natal','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 19:20:54',0,NULL,3,1,17,0,NULL,'mrjustindallas'),(10756,780141928016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','mrjustindallas','studio@impakt.co.za','Justin Dallas','19 Ukosi Road','Kloof','KwaZulu-Natal','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-02 19:20:55',0,NULL,3,1,3,1,'RA117722084CN\r ','mrjustindallas\rCANON 镜头盖  77mm      1\r反光板支架    1\r'),(10757,680845622001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','acid_burn92','raja_nashrul1992@yahoo.com.my','mr nashrul','473,LRG TITIWANGSA 6<br>TMN BUKTI SETIA,AMPANGAN','SEREMBAN','NEGERI SEMBILAN','MALAYSIA','70400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 19:32:18',0,NULL,3,1,2,1,NULL,'acid_burn92'),(10758,796055025015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','sirbion','polustudio@yandex.ru','Stepan Martynov','Lenin avenue, 131, 48','Voronezh','','RUSSIAN FEDERATION','394042','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-02 20:17:18',0,NULL,3,1,3,1,'RA117722098CN\r ','sirbion'),(10759,722138359002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','pasmanik','liotel@gmail.com','Otel Lilian','Decebal 80 app.26','Chisinau','','MOLDOVA, REPUBLIC OF','2038','(373) 681-7444 ext.: 4','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 21:27:25',0,NULL,3,1,3,1,'RA117722155CN\r ','pasmanik'),(10760,719272076002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jeongsookim','red567g@naver.com','jeongsookim','835 N 50 E<br>Apt 120','provo','UT','UNITED STATES','84604-6539','(801) 691-4945','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 21:24:58',0,NULL,3,1,1,1,NULL,'jeongsookim'),(10761,722157699002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zeild','kruegercrew@gmail.com','Christopher Krueger','942 NE Spitzenberg St','college place','WA','UNITED STATES','99324-9703','(509) 386-5799','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-02 22:26:43',0,NULL,3,1,1,1,NULL,'zeild'),(10762,680248806018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','ricklan0224','ricklan@eternity.at','Shinyi Li','Centre Management<br>Cannon Hill Shopping Centre, 1145 Wynnum Rd','Cannon HILL','Queensland','AUSTRALIA','4170','0402186169','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-02 23:13:48',0,NULL,3,1,3,1,'RA117775379CN\r ','ricklan0224\r又是一个没有快装板的，用挂号小包补发，另外，以后发货前确认是否有在发'),(10763,680918971001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','cegato11','cegato11@yahoo.es','Antonio Devesa','Plaza de Andalucía 25','Montellano','Sevilla','SPAIN','41770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 23:18:00',0,NULL,3,1,17,0,NULL,'cegato11'),(10764,722170051002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','cegato11','cegato11@yahoo.es','Antonio Devesa','Plaza de Andalucía 25','Montellano','Sevilla','SPAIN','41770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 23:18:00',0,NULL,3,1,3,1,'RA117722067CN\r ','cegato11\r灯架  2m    1\r圆形柔光棚 50cm     1'),(10765,722174954002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-02 23:37:22',0,NULL,3,1,12,1,'BJ8822701','princessvideo\r美标 110v\r再加\r2m灯架  1\r斜臂  1\r50-70单灯头棚  1\r115w 110v   1\r包  1\r8.756\r'),(10766,680944809001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','dabudge30','dabudges@yahoo.com','Kyle Budge','4371 S 200 W','Washington Terrace','UT','UNITED STATES','84405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 01:15:24',0,NULL,3,1,1,1,NULL,'dabudge30'),(10767,780309731016,260661735101,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',20.8,'hutongstore','hayden.s','shepherd.hayden@gmail.com','Hayden Shepherd','Level 5<br>6 Eden Park Drive','Macquarie Park','New South Wales','AUSTRALIA','2113','0297444500','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-03 01:41:49',0,NULL,3,1,3,1,'RA117722107CN\r ','hayden.s\r+8的近摄镜换成+4的, 其他不变.'),(10768,680964287001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','piquix','super.piquix@gmail.com','valquiria ballin','av plinio arlindo de nês, 1105 - ed. desbravador<br>sala 211 - centro','xaxim','Santa Catarina','BRAZIL','89825-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 02:45:07',0,NULL,3,1,17,0,NULL,'piquix'),(10769,680964288001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','piquix','super.piquix@gmail.com','valquiria ballin','av plinio arlindo de nês, 1105 - ed. desbravador<br>sala 211 - centro','xaxim','Santa Catarina','BRAZIL','89825-000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-03 02:45:08',0,NULL,3,1,17,0,' ','piquix'),(10770,680964289001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','piquix','super.piquix@gmail.com','valquiria ballin','av plinio arlindo de nês, 1105 - ed. desbravador<br>sala 211 - centro','xaxim','Santa Catarina','BRAZIL','89825-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 02:45:10',0,NULL,3,1,17,0,NULL,'piquix'),(10771,722216797002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','piquix','super.piquix@gmail.com','valquiria ballin','av plinio arlindo de nês, 1105 - ed. desbravador<br>sala 211 - centro','xaxim','Santa Catarina','BRAZIL','89825-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 02:45:10',0,NULL,3,1,17,0,NULL,'piquix'),(10772,535710834003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','piquix','super.piquix@gmail.com','valquiria ballin','av plinio arlindo de nês, 1105 - ed. desbravador<br>sala 211 - centro','xaxim','Santa Catarina','BRAZIL','89825-000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 02:45:09',0,NULL,3,1,3,1,'RA117736295CN\r ','piquix\r爵影红外 nikon     1\r绿叶 UV  52mm    1\r绿叶 UV  67mm   1\r摄影背心 Nikon 老款 (M)    1\r反光板  80cm 5合1     1'),(10773,734117641017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',5.68,'photographyacc','bibbajuana.09','sblispet@optusnet.com','Steven Lispet','48 Jacaranda Avenue','Boronia Heights','Queensland','AUSTRALIA','4124','0738001982','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 03:54:29',0,NULL,3,1,2,1,NULL,'bibbajuana.09'),(10774,722235403002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',3,'AA3312',17.97,'hermeshine','maswino','w_1_no@yahoo.com','Winantu Rahardja','Jl. Gedong Kuning Selatan No. 17A','Yogyakarta','Daerah Istimewa Yogyakarta','INDONESIA','55198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 04:32:16',0,NULL,3,1,3,1,'RA117736287CN\r ','maswino'),(10775,680984800001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','green_dream_sky','volya.dzemka@gmail.com','Anna Karptsova','3000 Royal Hills Dr SE<br>Apt 9H','Renton','WA','UNITED STATES','98058-3856','(206) 370-1567','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 04:42:31',0,NULL,3,1,1,1,NULL,'green_dream_sky\r欧标头， 客户自己要的'),(10776,680993363001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','allsmay','skuber70@yahoo.com','Robert Travelbee','114 Northshore Dr','Coldwater','MI','UNITED STATES','49036-1299','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 05:41:11',0,NULL,3,1,1,1,NULL,'allsmay'),(10777,734137597017,270748975009,'Hot Shoe Protector Cover Cap for Sony Alpha A550 A900',1,'AA1205',2.5,'photographyacc','rhui2767','rhuisman@optusnet.com.au','Robert Huisman','3/84 The Avenue','Spotswood','Victoria','AUSTRALIA','3015','0393993664','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 05:55:01',0,NULL,3,1,2,1,NULL,'rhui2767'),(10778,681002576001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','holden925','holden925@yahoo.com','Christopher Holden','1675 Clay St<br>Apt 7','San Francisco','CA','UNITED STATES','94109-3722','(415) 286-3938','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 06:41:25',0,NULL,3,1,1,1,NULL,'holden925'),(10779,676338981018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','missyb2009','missyb@live.com.au','ami bradstreet','4/19 little norman street<br>southport','gold coast','Queensland','AUSTRALIA','4215','0400701228','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-03 06:55:50',0,NULL,3,1,4,1,'YW865717242CN','missyb2009'),(10780,734150130017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','arisdc2009','arisdc30@yahoo.com','Aristotle Dela Cruz','4123 Puerto Rico St., Palanan','Makati','Metro Manila','PHILIPPINES','1235','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-03 07:03:55',0,NULL,3,1,11,1,NULL,'arisdc2009'),(10781,680322266018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','streetstreamer','rjmhayes@hotmail.com','Ray Hayes','10a Rockville Avenue','Daw Park','South Australia','AUSTRALIA','5041','0882777852','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-03 07:31:38',0,NULL,3,1,2,1,NULL,'streetstreamer'),(10782,680337577018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','jessicca.marion','jessicca.marion@yahoo.com.au','Jason Wilkinson','4 Parker Place','Bentley','Western Australia','AUSTRALIA','6102','0862679235','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-03 07:34:58',0,NULL,3,1,3,1,'RA117722230CN\r ','jessicca.marion'),(10783,681032776001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','papillon620','petitnono62@hotmail.com','arnaud capendu','appt 4  résidence la tourelle ,boulevard agniel','noeux les mines','Nord-Pas-de-Calais','FRANCE','62290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 09:18:29',0,NULL,3,1,2,1,NULL,'papillon620'),(10784,680900737001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',28.99,'hermeshine','deambuladorjack','cevagon@telecable.es','Cesar Vallejo Gonzalez','c/ Juan Carlos I nº36 3ºc','Gijon','Asturias','SPAIN','33212','647262550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 09:24:41',0,NULL,3,1,3,1,'RA117722597CN\r ','deambuladorjack\r广角托架   1\r大号镜头筒   2\r小号镜头筒   2\r'),(10785,680375919018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','driver423','fhowlings@bigpond.com','Frank Howlings','P.O. BOX  7029<br>KARINGAL CENTRE','FRANKSTON','Victoria','AUSTRALIA','3199','0397891608','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 10:04:55',0,NULL,3,1,2,1,NULL,'driver423'),(10786,681042710001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','prisouza.br','pri.freelancer@yahoo.com','Priscila Souza','32/98 Dee Why Parade','Sydney - Dee Why','New South Wales','AUSTRALIA','2099','0243023268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:07:00',0,NULL,3,1,2,1,NULL,'prisouza.br'),(10787,680336663018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','bubblebath_productions','alingarra@bigpond.com','Michael G Rayment','15 Oswald Lane Lochinvar','Maitland','New South Wales','AUSTRALIA','2321','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 10:08:46',0,NULL,3,1,2,1,NULL,'bubblebath_productions'),(10788,722298866002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','chekhova2011','chekhova84@mail.ru','Galina Chekhova','Dorojnikov home17 apartment 2','Karasu ','Kostanay','KAZAKHSTAN','111000','87145221816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:29:11',0,NULL,3,1,17,0,NULL,'chekhova2011'),(10789,681048545001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','chekhova2011','chekhova84@mail.ru','Galina Chekhova','Dorojnikov home17 apartment 2','Karasu ','Kostanay','KAZAKHSTAN','111000','87145221816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:32:33',0,NULL,3,1,5,1,'CP227189711CN\r ','chekhova2011\r\r红头灯   1\r800w 220v   1\r1转4 灯头   2\rlenspen    1'),(10790,681042250001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:01',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10791,681042180001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:01',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10792,722293384002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:02',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10793,722295470002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:00',0,NULL,3,1,3,1,'RA117722606CN\r ','lokkovieira\r新地址:\rRua Diana No. 513 Apto.102\rPerdizes\rSao Paulo\rSao Paulo 05019-000 \rBRAZIL\rPhone +55 11 78171757\r------------\r小号灰卡   1\r爵影红外 canon    1\r(送)小号镜头筒   1\r方镜卡座    2\r广角卡座    1\r10片装滤镜袋     1\r方形滤镜接口环 58mm    1\r方形滤镜接口环 82mm    1\r方形滤镜接口环 49mm    1\r52.55.58.62.67.72.77mm 转接环    1\r方镜套装(ND2/4/8,渐变红/橙/黄/绿/蓝/灰/棕)     1\r天涯方形滤镜系列  星光镜  star6   1\r天涯方形滤镜系列  星光镜  star8   1\r带水平仪 热靴保护盖    3\r天涯方形滤镜系列  CPL    1\rnikon 反接环  52mm   1\r申报：photo accessory   $20'),(10794,722293242002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',3,'AA1206',17.97,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:03',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10795,681042052001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:03',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10796,722293179002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:04',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10797,681042297001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:05',0,NULL,3,1,17,0,NULL,'lokkovieira\r'),(10798,722293330002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:57:04',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10799,681042230001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:58:43',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10800,681042203001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:58:44',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10801,722293421002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',3.55,'hermeshine','lokkovieira','lokkovieira@gmail.com','Bruno Vieira','Rua  Apinagés N.º1967 Apto.93<br>Perdizes','São Paulo','São Paulo','BRAZIL','01258-001','551291388713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 10:58:44',0,NULL,3,1,17,0,NULL,'lokkovieira'),(10802,722306738002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','oxliros','k_manousaridis@yahoo.com','KONSTANTINOS MANOYSARIDIS','ALEXI MINOTI 13','KOZANI','GREECE','GREECE','50100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:05:00',0,NULL,3,1,2,1,NULL,'oxliros'),(10803,722301882002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','rbpai','rajasekhr@gmail.com','Rajasekhar B Pai','APT 303, Vedhas Vantage Apts, PLOT No. 204,<br>SURVEY OF INDIA SOCIETY, Near 100 Ft ROAD, MADHAPUR,','HYDERABAD','Andhra Pradesh','INDIA','500081','08885558141','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-03 11:14:44',0,NULL,3,1,3,1,'RA117722265CN\r ','rbpai'),(10804,722309643002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','chekhova2011','chekhova84@mail.ru','Galina Chekhova','Dorojnikov home17 apartment 2','Karasu ','Kostanay','KAZAKHSTAN','111000','87145221816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 11:17:22',0,NULL,3,1,17,0,NULL,'chekhova2011'),(10805,722310578002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','firstarcangelm','firstarcangelm@aol.com','Michael Harrell','18320 Crawley Rd','Odessa','FL','UNITED STATES','33556-4821','(813) 928-1776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 11:21:12',0,NULL,3,1,1,1,NULL,'firstarcangelm'),(10806,796777360015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','www_photos-sales_com','dswba813@gmail.com','David Smith','43 Godwin Road<br>Hove','Brighton','East Sussex','UNITED KINGDOM','BN3 7FQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-03 11:34:09',0,NULL,3,1,3,1,'RA117722760CN','www_photos-sales_com\r1.6x2.1 2块    粉!!!!! + 黑'),(10807,680400338018,280666892339,'New Green.L 62mm  Gradual Grey ND4 Filter 2-Stop 62 mm',1,'AA3318',6.6,'photographyacc','taavos','taavo23@gmail.com','Taavo Soodla','Meeliku 24/4-253','Tallinn','Harjumaa','ESTONIA','13915','53024233','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-03 11:45:40',0,NULL,3,1,2,1,NULL,'taavos'),(10808,722320086002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','joelsimpson7','joel.simpson.77@gmail.com','Joel Simpson','130 N 89th St','Wauwatosa','WI','UNITED STATES','53226-4502','(414) 778-1849','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 12:03:36',0,NULL,3,1,1,1,NULL,'joelsimpson7'),(10809,730958065017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','kathrynchs','kathrynhschin@gmail.com','Hui San Chin','208 / 6<br>High Street','North Melbourne','Victoria','AUSTRALIA','3051','0431055560','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-03 12:33:57',0,NULL,3,1,2,1,NULL,'kathrynchs'),(10810,734248712017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','jwar516','jgpc23@iinet.net.au','James Lau','8 Alexander Drive','Burwood','Victoria','AUSTRALIA','3125','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 13:41:25',0,NULL,3,1,2,1,NULL,'jwar516'),(10811,681103596001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','javierbarba','jbrueda@hotmail.com','Javier Barba Rueda','C/Juan XXIII 1A 1ºB','Muriedas','Cantabria','SPAIN','39600','606740744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:13:45',0,NULL,3,1,17,0,NULL,'javierbarba'),(10812,681103521001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','javierbarba','jbrueda@hotmail.com','Javier Barba Rueda','C/Juan XXIII 1A 1ºB','Muriedas','Cantabria','SPAIN','39600','606740744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:13:45',0,NULL,3,1,17,0,NULL,'javierbarba'),(10813,681103028001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','javierbarba','jbrueda@hotmail.com','Javier Barba Rueda','C/Juan XXIII 1A 1ºB','Muriedas','Cantabria','SPAIN','39600','606740744','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-03 14:13:46',0,NULL,3,1,4,1,'YW865717312CN\r ','javierbarba\r申报: $25, Tripod & bag\rCanon D8 单肩包   1\r三脚架 伟峰 WF-6663A      1\r52-58mm 双阳环    1\r热靴保护盖  普通    1\r'),(10814,680439895018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','dommo60','dgrunewa@bigpond.net.au','Daniela Grunewald','P.O.Box 2260<br>Wattletree Road','Malvern East/ Local Post Office','Victoria','AUSTRALIA','3145','0398246403','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 14:15:53',0,NULL,3,0,2,1,NULL,'dommo60'),(10815,680443173018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','gampliek','faisalsyahputra@yahoo.com','Faisal Syahputra','39 Sturt Road Bedford Park','Adelaide','South Australia','AUSTRALIA','5042','61432177173','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 14:24:07',0,NULL,3,1,2,1,NULL,'gampliek'),(10816,681110079001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','javierbarba','jbrueda@hotmail.com','Javier Barba Rueda','C/Juan XXIII 1A 1ºB','Muriedas','Cantabria','SPAIN','39600','606740744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:33:15',0,NULL,3,1,17,0,NULL,'javierbarba'),(10817,722362390002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','gutier029','gutier029@hotmail.com','Gutier Puga Fernández','Joaquín Loriga, nº 24','Lalín','Galicia','SPAIN','36500','659000983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:52:13',0,NULL,3,1,17,0,NULL,'gutier029'),(10818,681101598001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','gutier029','gutier029@hotmail.com','Gutier Puga Fernández','Joaquín Loriga, nº 24','Lalín','Galicia','SPAIN','36500','659000983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:52:14',0,NULL,3,1,17,0,NULL,'gutier029'),(10819,681100640001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','gutier029','gutier029@hotmail.com','Gutier Puga Fernández','Joaquín Loriga, nº 24','Lalín','Galicia','SPAIN','36500','659000983','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 14:52:14',0,NULL,3,1,4,1,'YW865717301CN\r ','gutier029\r绿叶 ND8  77mm    1\r肥皂盒 柔光罩  430EX    1\rWFC-592T + WF-570H    1\rtripod $26'),(10820,680455752018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',11.32,'photographyacc','shadyjin','farisluv@hotmail.com','Ahmed Faris','UWS Village, 70 Pemberton ST<br>Victoria Road NSW 2150','Parramatta','New South Wales','AUSTRALIA','2150','61404388882','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-03 15:02:18',0,NULL,3,1,2,1,NULL,'shadyjin\r橡胶遮光罩 58mm  2'),(10821,680456592018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',5,'AKT007',90,'photographyacc','niyama','byrdsong.ebay@gmail.com','Michael Wiseman','265 Mardells Rd','Central Bucca','New South Wales','AUSTRALIA','2450','0266564436','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-03 15:05:13',0,NULL,3,1,3,1,'RA117722331CN\r ','niyama\r注意是10个'),(10822,780521984016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','gunn056','gunn056@gmail.com','Gunnar Grünbaum','Ehitajate tee 88-107','Tallinn','','ESTONIA','12915','3725015963','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-03 15:18:15',0,NULL,3,1,2,1,NULL,'gunn056'),(10823,681136567001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','fourmiel','alex.albert@gmail.com','Alexandre Albert','8270, Lajeunesse, #3','Montréal','QC','CANADA','H2P2E5','','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'fourmiel\recheck 结清再发'),(10824,681146021001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-03 16:32:12',0,NULL,3,1,3,1,'RA117722393CN\r ','leofotografias'),(10825,681147734001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','libinga495','libinga@yandex.ru','Sergey Isaev','Borovskoe Shosse 44-1-378','Moscow','','RUSSIAN FEDERATION','119634','89036714847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:38:05',0,NULL,3,1,17,0,NULL,'libinga495'),(10826,722396244002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','libinga495','libinga@yandex.ru','Sergey Isaev','Borovskoe Shosse 44-1-378','Moscow','','RUSSIAN FEDERATION','119634','89036714847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:38:06',0,NULL,3,1,17,0,NULL,'libinga495'),(10827,681146410001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','libinga495','libinga@yandex.ru','Sergey Isaev','Borovskoe Shosse 44-1-378','Moscow','','RUSSIAN FEDERATION','119634','89036714847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:38:06',0,NULL,3,1,3,1,'RA117725355CN\r ','libinga495\r欧标\r45w 5500k 灯泡 220v     4\r115w 5500k 灯泡  220v    1\r单灯头   1\rlenspen    1\r小号灰卡    1'),(10828,681146140001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','libinga495','libinga@yandex.ru','Sergey Isaev','Borovskoe Shosse 44-1-378','Moscow','','RUSSIAN FEDERATION','119634','89036714847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:38:07',0,NULL,3,1,17,0,NULL,'libinga495'),(10829,722394934002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','libinga495','libinga@yandex.ru','Sergey Isaev','Borovskoe Shosse 44-1-378','Moscow','','RUSSIAN FEDERATION','119634','89036714847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 16:38:07',0,NULL,3,1,17,0,NULL,'libinga495'),(10830,722408363002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','frankarabaic','fkarabaic@gmail.com','Fran Karabaić','Dražine 4','Malinska - island Krk','','CROATIA','51511','+385 99 595 65 97','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 17:10:01',0,NULL,3,1,3,1,'RA117725341CN\r ','frankarabaic'),(10831,681192316001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','waperr','waperr@gmail.com','Rafał Tkaczyk','Wiślana 3a','Łomianki Dolne','mazowieckie','POLAND','05092','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 18:43:25',0,NULL,3,1,2,1,NULL,'waperr'),(10832,722452356002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',74.3,'hermeshine','12xtrefilm','xtrefilm@seznam.cz','Miroslav Trefil','Sladovní 461','Kojetín','','CZECH REPUBLIC','75201','+420777865242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 19:13:29',0,NULL,3,1,5,1,'CP227189739CN\r ','12xtrefilm\r灯架  2m   2\r单灯头 (欧标)   2\r反光伞   2\rlenspen    2\r镜头笔的数目不对，需要拿出来两只'),(10833,722454174002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','12xtrefilm','xtrefilm@seznam.cz','Miroslav Trefil','Sladovní 461','Kojetín','','CZECH REPUBLIC','75201','+420777865242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 19:39:44',0,NULL,3,1,17,0,NULL,'12xtrefilm'),(10834,722463141002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','2011mega555','mega-1985@yandex.ru','alexander agafonov','kirova 95<br>513','Сочи-а','Краснодарский край','RUSSIAN FEDERATION','354340','89631646244','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-03 19:44:39',0,NULL,3,1,3,1,'RA117722795CN\r ','2011mega555'),(10835,681221251001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',62,'hermeshine','mendibla','sangrebla@hotmail.com','Carlos Serrano','avila 32, pasaje montoya edif 2','Barcelona','Cataluña','SPAIN','08005','622619847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 20:05:40',0,NULL,8,0,17,0,NULL,'mendibla'),(10836,681221837001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','mendibla','sangrebla@hotmail.com','Carlos Serrano','avila 32, pasaje montoya edif 2','Barcelona','Cataluña','SPAIN','08005','622619847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 20:05:41',0,NULL,3,1,4,1,'YW865717404CN','mendibla\r圆形柔光棚 60cm    1\r反光板支架     2\r斜臂     1\r方形滤镜接口环 62mm     1\r方镜卡座    1\r10片装滤镜盒     1\r方镜套装(ND2/4/8,渐变红/橙/黄/绿/蓝/灰/棕)     1\r---------\rlighting kit  $26\r新地址:\rCARLOS SERRANO\rCarreta Portichol 89, local 1 \rJavea (Alicante) 03730\rSPAIN\r'),(10837,681219631001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','mendibla','sangrebla@hotmail.com','Carlos Serrano','avila 32, pasaje montoya edif 2','Barcelona','Cataluña','SPAIN','08005','622619847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 20:05:42',0,NULL,8,1,17,0,NULL,'mendibla'),(10838,722465607002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mendibla','sangrebla@hotmail.com','Carlos Serrano','avila 32, pasaje montoya edif 2','Barcelona','Cataluña','SPAIN','08005','622619847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 20:05:41',0,NULL,8,1,17,0,NULL,'mendibla\r'),(10839,722488817002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','fishingrod557','mgeuder@bellsouth.net','Rodney Geuder','968 E Main St','West Point','MS','UNITED STATES','39773','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 20:49:55',0,NULL,3,1,1,1,NULL,'fishingrod557'),(10840,681239065001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','ricabras','photobrasil@gmail.com','Ricardo Brasil','Rua Mucu nº 10 apto 102, Alto da Boa Vista','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531-180','5521-2570-4633','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-03 20:50:47',0,NULL,3,1,3,1,'RA117722481CN\r ','ricabras'),(10841,681254859001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','chen1254umn','chen1254@gmail.com','KAI-YUAN CHENG','320 7th St SE<br>Apt 315','MINNEAPOLIS','MN','UNITED STATES','55414-1243','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-03 21:38:48',0,NULL,3,1,1,1,NULL,'chen1254umn'),(10842,681142091001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','wkimbro','wkimbrom@netscape.net','Willie Kimbrough','111 BethPage Rd','Kannapolis','NC','UNITED STATES','28081','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-03 21:46:44',0,NULL,3,1,3,1,'RA117725196CN\r ','wkimbro\r留意一下是3个'),(10843,681271989001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 22:52:48',0,NULL,8,1,17,0,NULL,'saud-p'),(10844,681270420001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','sidarath.sharma','sidmed5@gmail.com','Sidarath Sharma','#08-231 , Block 675B, Jurong West<br>Street 64, Singapore','default','Singapore','SINGAPORE','642675','84184501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 23:05:43',0,NULL,3,1,11,1,NULL,'sidarath.sharma'),(10845,734457568017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',5.68,'photographyacc','skippie*luvs*lambs','bvenegas@sbcglobal.net','Betty Venegas','516 E Myrtle St','Hanford','CA','UNITED STATES','93230-4023','(559) 583-7419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-03 23:41:18',0,NULL,3,1,1,1,NULL,'skippie*luvs*lambs'),(10846,681287276001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','cmontechi','carloslm@uol.com.br','Carlos Oliveira','Av Bem Te Vi 362 ap 53C','Sao Paulo','SP','BRAZIL','04524030','551155356430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-03 23:47:28',0,NULL,3,1,3,1,'RA117722478CN\r ','cmontechi'),(10847,681289164001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','musica49purple','faina_samara@hotmail.com','Faina Teplitskaya','7952 Cliffbrook Dr<br>Apt 2006','Dallas','TX','UNITED STATES','75254-8251','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 00:04:48',0,NULL,3,1,17,0,NULL,'musica49purple'),(10848,681289878001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','musica49purple','faina_samara@hotmail.com','Faina Teplitskaya','7952 Cliffbrook Dr<br>Apt 2006','Dallas','TX','UNITED STATES','75254-8251','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 00:04:49',0,NULL,3,1,1,1,NULL,'musica49purple\r倒影板（白黑）    1\r圆形柔光棚 40cm   1'),(10849,734470284017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',19.99,'photographyacc','flaviadorjo','flaviadorjo@hotmail.com','FLAVIA PEDRA','RUA MARCO AURELIO DE MIRANDA<br>386 AP 101  BAIRRO BURITIS','BELO HORIZONTE','MINAS GERAIS','BRAZIL','30575210','3132640638','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-04 00:55:12',0,NULL,3,1,3,1,'RA117722328CN\r ','flaviadorjo\r1.6x3m 白色'),(10850,722549931002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','hendertuckyliving','nicksnowebay@gmail.com','Nicholas Snow','811 E Bridger Ave<br>Apt 306','Las Vegas','NV','UNITED STATES','89101-5588','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 00:57:42',0,NULL,3,1,17,0,NULL,'hendertuckyliving'),(10851,722550036002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','hendertuckyliving','nicksnowebay@gmail.com','Nicholas Snow','811 E Bridger Ave<br>Apt 306','Las Vegas','NV','UNITED STATES','89101-5588','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 00:57:41',0,NULL,3,1,1,1,NULL,'hendertuckyliving\rc型大力夹    1\r反光板 60cm 2合1     1'),(10852,797114492015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','maximaniac25','cortomaltese25@wanadoo.fr','jean luc serra','36 rue de morteau','pontarlier','Franche-Comté','FRANCE','25300','06.70.21.19.13','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 01:11:25',0,NULL,3,1,2,1,NULL,'maximaniac25'),(10853,681308119001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','lastyearsqueens','mungold1@aol.com','Jeanne Caruso','PO Box 320682','Alexandria','VA','UNITED STATES','22320','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 01:37:01',0,NULL,3,1,1,1,NULL,'lastyearsqueens'),(10854,722571475002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','programmizer','programmizer@gmail.com','Sergey Goncharov','Avrorovskaya, 17, 136','Vladivostok','Primorskiy Kray','RUSSIAN FEDERATION','690091','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 02:47:11',0,NULL,3,1,2,1,NULL,'programmizer'),(10855,734510246017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','hafiy2011','mohdhafiy@hotmail.com','hafiy fadil','283 Bell Street','Preston','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-04 04:12:26',0,NULL,3,1,2,1,NULL,'hafiy2011'),(10856,722583482002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','srikumar.s','srikumar.subramaniam@yahoo.com','Srikumar Subramaniam','1235 Wildwood ave<br>Apt 244','Sunnyvale','CA','UNITED STATES','94089-2717','(408) 802-8349','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 04:18:32',0,NULL,3,1,1,1,' ','srikumar.s'),(10857,680692358018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',2,'AB1303',11.32,'photographyacc','ml2027','mhervzl@yahoo.com.au','Mervill Legaspi','Level 5<br>33 Alfred Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 04:55:45',0,NULL,3,1,2,1,NULL,'ml2027'),(10858,680698925018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','erin1976erin','erin@emsproperty.com.au','Erin Cole','37 Bainbridge Cct','Sippy Downs','Queensland','AUSTRALIA','4556','0412625696','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 05:39:55',0,NULL,3,1,2,1,NULL,'erin1976erin'),(10859,722615375002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','slayerizm','whocares1122@gmail.com','Hiep Bui','7 Ivey Ln','Harrisburg','PA','UNITED STATES','17104','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 07:29:30',0,NULL,3,1,1,1,NULL,'slayerizm'),(10860,734548303017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','appwkc','wcorbin@velocitynet.com.au','Wayne K Corbin','43 Florence Fuller Crescent','Conder','Australian Capital Territory','AUSTRALIA','2906','0262961406','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTracking','2011-06-04 07:55:51',0,NULL,3,1,4,1,'YW865717286CN\r ','appwkc\rtripod  $20'),(10861,680723058018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','nbrepa','nbrepacholi@iprimus.com.au','Norman Repacholi','c- Dairy Australia, Level 5, IBM Centre<br>60 City Road','Southbank','Victoria','AUSTRALIA','3006','0396943752','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-04 08:03:41',0,NULL,3,1,3,1,'RA117722314CN\r ','nbrepa'),(10862,721546239002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','offpix','info@offpix.de','Alissa Maxman','Leipziger Strasse 40','Berlin','','GERMANY','10117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 08:11:22',0,NULL,3,1,4,1,'YW865717150CN  ','offpix\r欧标 220v\r申报:$25, Lighting Kit'),(10863,797204425015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','kinhellmick','m.hannush@ntlworld.com','m.hannush','33 essetford rd','ashford','Kent','UNITED KINGDOM','tn23 5bt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 08:18:27',0,NULL,3,1,2,1,NULL,'kinhellmick'),(10864,681384108001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','mdim666','mdimaulo0@gmail.com','KAREN DIMAULO','196 SILVERVIEW WAY NW','CALGARY','AB','CANADA','T3B 3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 09:07:12',0,NULL,3,1,2,1,NULL,'mdim666'),(10865,722524335002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','eightyjoeeinstein','eightyeinstein@gmail.com','joe kim','2121 Valderas Dr<br>Apt 53','glendale','CA','UNITED STATES','91208-1364','(818) 245-0154','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-04 10:19:59',0,NULL,3,1,3,1,'RA117722402CN\r ','eightyjoeeinstein'),(10866,722638646002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','uncle.sam113','samir.gozalov@bp.com','Samir Gozalov','Bayil, Neftchilar av.<br>Villa Petrolea (BP Office)','Baku','','AZERBAIJAN','AZ1003','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-04 10:23:20',0,NULL,3,1,17,0,NULL,'uncle.sam113'),(10867,722638466002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','uncle.sam113','samir.gozalov@bp.com','Samir Gozalov','Bayil, Neftchilar av.<br>Villa Petrolea (BP Office)','Baku','','AZERBAIJAN','AZ1003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 10:23:21',0,NULL,3,1,3,1,'RA117722787CN\r ','uncle.sam113\r背景布 3x1.6m      1(白)\r反光板 100*150 40*60 5合1     1'),(10868,734583612017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',8.14,'photographyacc','dilupan','vipula9999@yahoo.com','Vipula Dharmasena','27<br>Ainslie Parade','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 10:39:31',0,NULL,3,1,2,1,NULL,'dilupan\r绿叶 UV  58mm   1\r58mm - canon   反接环  1'),(10869,722660760002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','fox*mulder','maximdavgalev@gmail.com','Maxim Davgalev','Bestuzhevih 10, kv. 137','Moscow','','RUSSIAN FEDERATION','127566','+79166962592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 11:02:50',0,NULL,3,1,2,1,NULL,'fox*mulder'),(10870,681414407001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','sevland1','krappe.no@hotmail.com','AKL Trading by Anita K. Lund','Vestre Karmoyveg 264','Saevelandsvik','','NORWAY','4275','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 11:18:15',0,NULL,3,1,2,1,NULL,'sevland1'),(10871,780888381016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','yenfnd','yen.fnd@gmail.com','Yenny Effendy','chez Speos<br>8 Rue Jules Valles','Paris','Ile-de-France','FRANCE','75011','0659309901','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 11:32:41',0,NULL,3,1,3,1,'RA117722800CN\r ','yenfnd'),(10872,780891458016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','roooster75','j_hayes666@yahoo.co.uk','jamie hayes','2 o briens terrace<br>ballycotton','cork','Cork','IRELAND','1','0873253880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 11:37:11',0,NULL,3,1,2,1,NULL,'roooster75'),(10873,780912104016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',17.8,'hutongstore','raw_is_thetopbanana','scott@theoneliner.com','Scott Morris','Flat 1/3','30 Niddrie Road','Glasgow','UNITED KINGDOM','G428NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 12:40:32',0,NULL,3,1,3,1,'RA117722362CN\r ','raw_is_thetopbanana'),(10874,681423916001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','inabollo','izurutuza@euskalnet.net','Ignacio Zurutuza C/O Femy Pinto','NTFP-EP Cambodia<br>#10Eo, Street 420 Sangkat Boeung Trabek, Khan Chamkarmon','Phnom Penh','','CAMBODIA','20000','+85512514289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 12:44:01',0,NULL,3,1,17,0,NULL,'inabollo'),(10875,681423178001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',12.42,'hermeshine','inabollo','izurutuza@euskalnet.net','Ignacio Zurutuza C/O Femy Pinto','NTFP-EP Cambodia<br>#10Eo, Street 420 Sangkat Boeung Trabek, Khan Chamkarmon','Phnom Penh','','CAMBODIA','20000','+85512514289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 12:44:02',0,NULL,3,1,17,0,NULL,'inabollo'),(10876,681423850001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','inabollo','izurutuza@euskalnet.net','Ignacio Zurutuza C/O Femy Pinto','NTFP-EP Cambodia<br>#10Eo, Street 420 Sangkat Boeung Trabek, Khan Chamkarmon','Phnom Penh','','CAMBODIA','20000','+85512514289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 12:44:03',0,NULL,3,1,3,1,'RA117722455CN\r ','inabollo\r小号内胆包 无字    2\rcanon 反接环  52mm    1\rcanon 反接环  58mm     1'),(10877,780915110016,260661403957,'TianYa 82mm UV filter New 82 Protects Your Lens NIB',1,'AA2315',5.2,'hutongstore','pfpt2454','shop.1@o2.co.uk','Peter Tornabene','9 Eldon Lodge<br>196-200 Kings Road','Reading','Berkshire','UNITED KINGDOM','RG1 4NH','01189582399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 12:50:13',0,NULL,3,1,2,1,NULL,'pfpt2454'),(10878,734624140017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','emm_a83','emm_a83@yahoo.com.au','Emma O\'Grady','1/549 Station Street<br>CARRUM','Melbourne','Victoria','AUSTRALIA','3197','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-04 12:54:16',0,NULL,3,1,3,1,'RA117725369CN\r ','emm_a83\r1.6x3m 白色'),(10879,734627072017,270750650619,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.88,'photographyacc','ksmolka','kurt.smolka@optus.com.au','Kurt Smolka','1 Lyonpark Rd','Macquarie Park','New South Wales','AUSTRALIA','2113','610415581333','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 13:06:25',0,NULL,3,1,17,0,NULL,'ksmolka'),(10880,734629062017,270750651332,'New Large size Neoprene Lens Pouch / Case 90mm x 220mm ',1,'AC1203',5.98,'photographyacc','ksmolka','kurt.smolka@optus.com.au','Kurt Smolka','1 Lyonpark Rd','Macquarie Park','New South Wales','AUSTRALIA','2113','610415581333','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 13:11:11',0,NULL,3,1,2,1,NULL,'ksmolka\r镜头筒 中号    1\r镜头筒 大号   1'),(10881,722699529002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.49,'hermeshine','jordisalichs','jordisalichs@yahoo.com','Jordi Salichs','Les Torres, 15','Sant Celoni','Cataluña','SPAIN','08470','938672986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 13:29:10',0,NULL,3,1,2,1,NULL,'jordisalichs'),(10882,797303700015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','pendo-2009','trevorpendergast@yahoo.co.uk','trevor pendergast','58redshank lane oakwood','warrington','Cheshire','UNITED KINGDOM','wa36rd','01925838009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 13:38:32',0,NULL,3,1,2,1,NULL,'pendo-2009'),(10883,734642157017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1114',12.99,'photographyacc','chrischat2u','holdensgalore@bigpond.com','Chris Holden','1200 Dawson Highway','Burua Gladstone','Queensland','AUSTRALIA','4680','0749787557','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-04 13:54:52',0,NULL,3,1,2,1,NULL,'chrischat2u\r留意一下，新款的中号是那个没有eos logo的'),(10884,722712655002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','mini_volt','flaunders@mail.ru','Alexey N','Malisheva, 26-2,  73','Moscow','','RUSSIAN FEDERATION','109263','+79265391677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:15:21',0,NULL,3,1,2,1,NULL,'mini_volt'),(10885,722713726002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5.2,'hermeshine','lovligbredt','dikteren@online.no','Ståle Haugstulen Meyer','Hoegtun','EIDSVOLL','EIDSVOLL','NORWAY','2080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 14:20:06',0,NULL,3,1,2,1,NULL,'lovligbredt'),(10886,722731065002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','plusphotoau','davidtha@tpg.com.au','David Thatcher','29 Barton Crescent','Burton','South Australia','AUSTRALIA','5110','0412961931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:20:16',0,NULL,3,1,17,0,' ','plusphotoau'),(10887,681481380001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','plusphotoau','davidtha@tpg.com.au','David Thatcher','29 Barton Crescent','Burton','South Australia','AUSTRALIA','5110','0412961931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:20:17',0,NULL,3,1,17,0,NULL,'plusphotoau'),(10888,681481395001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','plusphotoau','davidtha@tpg.com.au','David Thatcher','29 Barton Crescent','Burton','South Australia','AUSTRALIA','5110','0412961931','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:20:17',0,NULL,3,1,2,1,NULL,'plusphotoau.\r绿叶 CPL  58mm\r绿叶 ND8  58mm\r绿叶 CPL  52mm'),(10889,681483777001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','aimishboy','nadavbagim@gmail.com','Nadav Bagim','Nahardea 2<br>Ramat Amidar','Ramat Gan','Israel','ISRAEL','52260','(972) 052 - 8776950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 15:23:15',0,NULL,3,1,3,1,'RA117722583CN\r ','aimishboy'),(10890,733891456017,270751510931,'YongNuo 10m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3326',48,'photographyacc','maxxxwinter','dr.winter@gmx.at','Milovan Malimarcov','VIDEO2BRAIN<br>Idlhofgasse 5','Graz','','AUSTRIA','8020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-04 15:44:04',0,NULL,3,1,3,1,'RA117722226CN\r ','maxxxwinter'),(10891,734690150017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',42.29,'photographyacc','the_epic_photomusician','abeerkamal1@hotmail.com','Abeer Attia','77 Finch Ave E<br>Apt. B444','Toronto','ON','CANADA','M2N6H8','(647) 477-8555','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-04 16:17:34',0,NULL,3,1,3,1,'RA117722495CN\r ','the_epic_photomusician\r绿叶 UV  58mm   1\r2m 灯架   1\r单灯头   1\r反光伞    1\r货退回来了   无人领取'),(10892,722751337002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',2,'AC2304',12.48,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 16:17:36',0,NULL,3,1,2,1,NULL,'solsuny'),(10893,781006141016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','jonathansmith7','jonathansmith7@hotmail.com','jonathan smith','69 Castle park Estate<br>Tallaght','dublin','Dublin','IRELAND','24','0872443196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 16:45:08',0,NULL,3,1,2,1,NULL,'jonathansmith7'),(10894,681518277001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','haringbay','p.haringhuizen@kpnplanet.nl','Peter Haringhuizen','Reigersbek 88','Nieuwegein','','NETHERLANDS','3434XM','0306063275','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 17:03:16',0,NULL,3,1,2,1,NULL,'haringbay'),(10895,722772821002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','lagartijoazul','carlosquirante@hotmail.com','Carlos Quirante Sánchez','Yeseras, s/n','BENAMAUREL','GRANADA','SPAIN','18817','651409487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 17:18:04',0,NULL,3,1,3,1,'RA117722447CN\r ','lagartijoazul'),(10896,781022653016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','davidzil10','davidzil@bezeqint.net','david zilberman','agalil 2a','cfar saba','cfar saba','ISRAEL','44233','972526039386','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 17:25:09',0,NULL,3,1,2,1,NULL,'davidzil10'),(10897,722792021002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','pacosatu','correo@pacosatu.es','José Francisco Satué Porta','CALERUEGA, 106 Esc 2 3º-B','Madrid','Madrid','SPAIN','28033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 18:08:17',0,NULL,3,1,17,0,NULL,'pacosatu'),(10898,797422031015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','humbucker101','humbucker1@hotmail.co.uk','Keith Lenihan','100 The Markhams New Ollerton','Newark','Nottinghamshire','UNITED KINGDOM','NG229QY','01623861219','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 18:14:33',0,NULL,3,1,2,1,NULL,'humbucker101'),(10899,681545235001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','pacosatu','correo@pacosatu.es','José Francisco Satué Porta','CALERUEGA, 106 Esc 2 3º-B','Madrid','Madrid','SPAIN','28033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 18:22:19',0,NULL,3,1,17,0,NULL,'pacosatu'),(10900,722800644002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',11.34,'hermeshine','pacosatu','correo@pacosatu.es','José Francisco Satué Porta','CALERUEGA, 106 Esc 2 3º-B','Madrid','Madrid','SPAIN','28033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 18:30:54',0,NULL,3,1,3,1,'RA117722535CN\r ','pacosatu\r万用遮光罩    1\r反光板 60cm 2合1    1\rNG128 柔光罩     1'),(10901,781093944016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','tuctucak','garfield.sleepyhead@gmail.com','Alena Rezankova','Zazvorkova 2004/12<br>schranka c. 17','Praha 13','Luziny','CZECH REPUBLIC','15500','+420724119102','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-04 19:50:32',0,NULL,3,1,2,1,' ','tuctucak'),(10902,797475160015,250627432317,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','gavor10','wales@techemail.com','Gavin Roberts','5 Garth Estate<br>Pontllyfni','Caernarfon','Gwynedd','UNITED KINGDOM','LL54 5ET','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 20:03:41',0,NULL,3,1,3,1,'RA117722212CN\r ','gavor10'),(10903,722838699002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','santiagorutle','sm.backdoorman@gmail.com','Santiago Morena','C/Virgen de los Reyes 23','Madrid','Madrid','SPAIN','28027','657144074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 20:08:02',0,NULL,3,1,3,1,'RA117722552CN\r ','santiagorutle\r摄影背心 夏  XL   1'),(10904,722839599002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',3,'AO0014',23.7,'hermeshine','boris-heger','boris_heger@excite.com','Boris Heger','Communal 18','Le Locle','NE','SWITZERLAND','2400','0041329316221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 20:10:33',0,NULL,3,1,2,1,NULL,'boris-heger'),(10905,722847232002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','luisoliver','luisphoto2@yahoo.es','Luis Oliver Fabrega','Ronda Universitat  9,<br>planta 1','Barcelona','Cataluña','SPAIN','08007','647486334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 20:28:19',0,NULL,3,1,2,1,NULL,'luisoliver'),(10906,722853409002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','kd5qn','kd5qn@carolina.rr.com','Donald W. Adkins','2333 Heathershire Ln','Matthews','NC','UNITED STATES','28105-4076','(704) 846-6580','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 20:47:39',0,NULL,3,1,1,1,NULL,'kd5qn'),(10907,797419631015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','millybeans','madmilly03@hotmail.com','emily baker','28 redmere drive','bury','Greater Manchester','UNITED KINGDOM','bl9 9gb','07557346814','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-04 20:56:42',0,NULL,3,1,4,1,'YW865717275CN\r ','millybeans\r2m 架子\r背景布是1.6x2.1 两块  白  黑'),(10908,722860250002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','smiffyman','smiffy.man@virgin.net','Dave  Smith','74 Hurst rd','Erith','Kent','UNITED KINGDOM','DA8 3EN','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-04 21:05:33',0,NULL,3,0,3,1,'RA117725165CN\r ','smiffyman\r背心 Canon  老款  3XL     1(已入库)'),(10909,722861018002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gjgibson','gjgibson@bestgib.co.za','Dr GJ Gibson','Fichmed 5<br>Rosepark Hospitaal','Bloemfontein','','SOUTH AFRICA','9317','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 21:15:57',0,NULL,3,1,17,0,NULL,'gjgibson'),(10910,722860410002,120454221534,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','gjgibson','gjgibson@bestgib.co.za','Dr GJ Gibson','Fichmed 5<br>Rosepark Hospitaal','Bloemfontein','','SOUTH AFRICA','9317','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 21:15:58',0,NULL,3,1,2,1,NULL,'gjgibson\rlenspen    1\r绿叶 ND4  77mm    1'),(10911,781145872016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','csha6336','chris.j.shaw@hotmail.com','Chris JJ Shaw','62 Vine Lane, The Vineyards<br>Acocks Green','Birmingham','West Midlands','UNITED KINGDOM','B27 6SY','07900385932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-04 21:43:21',0,NULL,3,1,2,1,NULL,'csha6336\r52mm 接口环  1\r托架   1\r渐变灰    1'),(10912,681622500001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-04 21:48:40',0,NULL,3,1,3,1,'RA117725275CN\r ','krisvisual'),(10913,722874019002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 21:49:23',0,NULL,3,1,17,0,NULL,'galtamirgal'),(10914,722873853002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-04 21:49:24',0,NULL,3,1,3,1,'RA117722416CN\r ','galtamirgal\r2B柔      1\r单灯头   1\r欧标'),(10915,680821554018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',228,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-04 21:53:46',0,NULL,3,1,8,1,'CP227189835CN','saud-p\r欧标\r申报 lighting kit  $200\r包装里需要放invoice--已打印'),(10916,681462034001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-04 21:59:45',0,NULL,8,1,17,0,NULL,'saud-p'),(10917,681621181001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-04 21:59:46',0,NULL,3,1,12,1,'BJ8822901 ','saud-p\r背景架2m x 3m    4\r背景架2m x 2m    1\r背景布 2x1.6m    2(白+黑)\r灯架包    3\r反光板支架    3\r16.5以内'),(10918,722904325002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','international_noo','beale.amg3@gmail.com','Ronnie Beale','1420 Hull St<br>Apt 211','Richmond','VA','UNITED STATES','23224-3957','(757) 572-7732','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-04 23:48:42',0,NULL,3,1,1,1,' ','international_noo'),(10919,681679330001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-05 02:33:14',0,NULL,8,1,17,0,' ','saud-p'),(10920,681050352018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','cabooltureqld','sales@weddingportraitphotographer.com.au','Steven Hayes','12 Wilson Street','Caboolture','Queensland','AUSTRALIA','4510','0405921920','PayPalPaymentInProcess','CheckoutComplete','AU_Other','0000-00-00 00:00:00',0,NULL,7,0,18,0,' ','cabooltureqld'),(10921,734922037017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','josh74261700027','joshhendry666@hotmail.com','Joshua hendry','23a Donavon Rise<br>Murdoch','Perth','Western Australia','AUSTRALIA','6150','0403527451','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 05:16:08',0,NULL,3,1,2,1,NULL,'josh74261700027'),(10922,722967158002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tdannar1525','tdannar@cox.net','Terry Dannar','1525 Lakeside Ridge Dr','Sand Springs','OK','UNITED STATES','74063','(918) 245-8033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 05:25:08',0,NULL,3,1,1,1,NULL,'tdannar1525'),(10923,722972376002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','whh2006','zonghe.lai@gmail.com','Zonghe Lai','Flöjtgatan 22','Gothenburg','Västra Götaland','SWEDEN','42139','0317723091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 05:59:35',0,NULL,3,1,2,1,NULL,'whh2006'),(10924,681101177018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','design_me35','design_me35@yahoo.com.au','RYAN LE','Suite 3, 80 Kitchener Parade','Bankstown','New South Wales','AUSTRALIA','2200','0287641247','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-05 06:58:29',0,NULL,3,1,2,1,NULL,'design_me35'),(10925,734944351017,270748975009,'Hot Shoe Protector Cover Cap for Sony Alpha A550 A900',2,'AA1205',5,'photographyacc','elwagondriver','chrisfoote@lizzy.com.au','chris foote','11 narida st hallett cove','adelaide','South Australia','AUSTRALIA','5158','0405197548','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 07:22:00',0,NULL,3,1,2,1,NULL,'elwagondriver'),(10926,734944627017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','sketchthat_com','kimpton@gmail.com','Michael Kimpton','15 Nottingham Street','Kensington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 07:24:52',0,NULL,3,1,2,1,NULL,'sketchthat_com'),(10927,681108816018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-05 07:34:21',0,NULL,3,1,4,1,'YW865717264CN\r ','joneff51\rbackground support  $20\r-来信说0614收到货'),(10928,681110367018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','mrbozzy19','bozz_di_kyut@yahoo.com','boz oji lingat','3/45 alt street','ashfield','New South Wales','AUSTRALIA','2131','0297993064','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 07:40:52',0,NULL,3,1,2,1,NULL,'mrbozzy19'),(10929,797675584015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','tonkopali','pavel.tonko@gmail.com','Tonko Pavel','Hlavna 670','Horne Saliby','SK','SLOVAK REPUBLIC','92503','+421 903 430537','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-05 08:17:48',0,NULL,3,1,2,1,' ','tonkopali'),(10930,723004132002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','colnitawn','niko_gl@hotmail.com','Nicolás Garrido Labrado','Pza. Ciudad de la Habana, Num. 13 2B','Gijon','Asturias','SPAIN','33212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 08:35:25',0,NULL,3,1,3,1,'RA117725182CN\r ','colnitawn'),(10931,681752832001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','eran.cr','3deran@gmail.com','Eran Croitoru','HaRimon 10','Givat Shmuel','Israel','ISRAEL','54403','+972547573351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 08:41:30',0,NULL,3,1,2,1,NULL,'eran.cr'),(10932,734972882017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','balasino68','rolandosupan@live.com.au','Rolando Supan','35 Samantha Crescent','Glendenning','New South Wales','AUSTRALIA','2761','0296753736','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 09:05:26',0,NULL,3,1,2,1,NULL,'balasino68'),(10933,734972500017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','joeliefish','igotcancer@gmail.com','Joel Eschler','unit 11, 18 lonsdale St Braddon','Canberra','Australian Capital Territory','AUSTRALIA','2612','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 09:05:28',0,NULL,3,1,2,1,NULL,'joeliefish'),(10934,723013841002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','raniasulin','asulinrani@gmail.com','rani asulin','hamachtarot','atlit','israel','ISRAEL','30300','(972) 542-3397 ext.: 73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 09:07:17',0,NULL,3,1,2,1,' ','raniasulin\rEW-73B    1\rCANON 镜头盖  58mm    1'),(10935,723017468002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','juliangv','jgamon2@gmail.com','Julian Gamon','calle el roble nº33','Burguillos, Sevilla','Andalucía Ceuta y Melilla','SPAIN','41220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 09:19:23',0,NULL,3,1,2,1,NULL,'juliangv'),(10936,681142829018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','alexbriggs2001','acb1609@hotmail.com','Alexander Briggs','30 Penaton Street','Corinda','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-05 10:06:47',0,NULL,3,1,2,1,NULL,'alexbriggs2001'),(10937,723033687002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','jgo269','jgo269@hotmail.com','Julian Garcia Ortiz','C/ Ramon Esteban, 27  2  B','San Sebastian de los Reyes','Madrid','SPAIN','28701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 10:07:53',0,NULL,3,1,2,1,' ','jgo269\r欧标'),(10938,797718800015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','euan_mckendrick','euan@mindless.com','Euan McKendrick','Hoover Candy<br>Breightmet Industrial Estate','Breightmet Fold Lane','Bolton','UNITED KINGDOM','BL2 6PU','01204556132','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 10:08:42',0,NULL,3,1,2,1,' ','euan_mckendrick'),(10939,723042653002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','raniasulin','asulinrani@gmail.com','rani asulin','hamachtarot','atlit','israel','ISRAEL','30300','(972) 542-3397 ext.: 73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 10:34:39',0,NULL,3,1,17,0,NULL,'raniasulin'),(10940,681170228018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','2345jayj','tajj_88@hotmail.com','Janarthanan','15 Millpond Drive','Point Cook','Victoria','AUSTRALIA','3030','0405711364','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 10:51:54',0,NULL,3,1,2,1,NULL,'2345jayj'),(10941,735023719017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',68,'photographyacc','richotiger','rgtatti@hotmail.com','Richard Tatti','1 Dawson Drive','Maiden Gully','Victoria','AUSTRALIA','3551','0354496351','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-05 11:28:43',0,NULL,3,1,4,1,'YW865717334CN\r ','richotiger\r澳标\rlighting kit $25'),(10942,735028694017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','vascoboon','vascoboon1@hotmail.com','vasco de sousa','caminho da mae de deus edf magos II boloco a 2j','caniço','ilha da madeira portugal','PORTUGAL','9125-101','00351969587140','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-05 11:41:48',0,NULL,3,1,2,1,NULL,'vascoboon'),(10943,723068433002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','adadens','adamka39@gmail.com','Vladislav Smertenko','Hanikra<br>4/6','Maale Adumim','','ISRAEL','98559','=972-54-799-1341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 11:48:55',0,NULL,3,1,17,0,NULL,'adadens'),(10944,723065859002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','adadens','adamka39@gmail.com','Vladislav Smertenko','Hanikra<br>4/6','Maale Adumim','','ISRAEL','98559','=972-54-799-1341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 11:48:55',0,NULL,3,1,2,1,NULL,'adadens\rEW-73B    1\rlenspen    1'),(10945,723063618002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vaness19862111','vaness.88@mail.ru','Иван Комонов','физкультурная,дом 86 квартира 45','Самара','','RUSSIAN FEDERATION','443058','89277083598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 11:36:24',0,NULL,3,1,2,1,NULL,'vaness19862111'),(10946,797776523015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',51,'hutongstore','paul181073','emmaf@worldonline.co.uk','Paul Funnell','11 Saunders park view','Brighton','East Sussex','UNITED KINGDOM','BN24AY','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-05 12:18:16',0,NULL,3,1,4,1,'YW865717323CN\r ','paul181073\r2x2m 背景架    1\r2x1.6m 背景布   2(白+黑)\r申报: Lighting Kit , $22'),(10947,681777322001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','simadiakos','simadiakos@yahoo.com','Michalis Simadiakos','Vasili Michailidi 1<br>Peristerona,','Nicosia,','','CYPRUS','2731','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 12:41:58',0,NULL,3,1,2,1,NULL,'simadiakos'),(10948,735054753017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','divebudd1971','divebudd@gmail.com','Shahar Glass','29 Bialik St.','Ramat-Gan','ISRAEL','ISRAEL','52479','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-05 12:44:26',0,NULL,3,1,2,1,NULL,'divebudd1971'),(10949,735064521017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','youngguns84','johnloh84@hotmail.com','John Wen Jia Loh','18/3 Eshelby Drive','Cannonvale','Queensland','AUSTRALIA','4802','0749481788','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-05 13:22:11',0,NULL,3,1,2,1,NULL,'youngguns84'),(10950,681234027018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT004',78,'photographyacc','wharfnuts','wharfnuts@msn.com','REBECCA SLOANE','400 Yowrie Rd','Cobargo','new south wales','AUSTRALIA','2550','0264937315','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-05 13:39:07',0,NULL,3,1,4,1,'YW865717356CN\r ','wharfnuts\r澳标\rlighting kit  $25'),(10951,681870620001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:14:35',0,NULL,3,1,17,0,NULL,'rexina09'),(10952,681872820001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','rexina09','mihkel.tiitus@atlet.se','Mihkel Tiitus','Lilla Bällskärsgatan 12','Hisings Backa','','SWEDEN','42244','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:19:50',0,NULL,3,1,2,1,NULL,'rexina09\r绿叶 UV  67mm    1\r绿叶 UV  55mm    1'),(10953,681855420001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-05 14:22:44',0,NULL,3,1,17,0,NULL,'saud-p'),(10954,681855589001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',62,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:22:44',0,NULL,3,1,17,0,' ','saud-p'),(10955,723135072002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','hfd1981','heritagefurniture1981@comcast.net','Steve Payne','1626 Corinth Ct','Stone Mountain','GA','UNITED STATES','30087','(678) 641-9189','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 14:42:03',0,NULL,3,1,1,1,NULL,'hfd1981'),(10956,681889993001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','fiemaki','eudoko@hotmail.com','Evdokia Liakou','Harilaou Trikoupi 29 B Rodopolis','Athens','Attiki','GREECE','14574','00306973773957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 14:59:07',0,NULL,3,1,2,1,NULL,'fiemaki'),(10957,681274828018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','american.nostalgia','suebeevo@earthlink.net','Susan Van Orman','1422 Riggle Rd','Bellville','OH','UNITED STATES','44813','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 15:15:41',0,NULL,3,1,4,1,'YW865717345CN\r ','american.nostalgia\rlighting kit  $40\r灯泡110v'),(10958,723175476002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','movado93','pacdeepmusic@yahoo.co.uk','richard moody','93 rectory park avenue','northolt','Middlesex','UNITED KINGDOM','ub5 6sa','02084386756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 16:02:57',0,NULL,3,1,2,1,' ','movado93'),(10959,681931833001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','kimievh','kimievh@aol.com','Kim Van Horn','20 Sandstone','Irvine','CA','UNITED STATES','92604','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-05 16:19:19',0,NULL,3,1,1,1,NULL,'kimievh'),(10960,735182649017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','laguariza','zacampoo@gmail.com','gonzalo gutierrez fernandez','C/ Rafael Alberti 121-A<br>Peñacastillo','Santander','Cantabria','SPAIN','39011','655684251','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-05 16:53:23',0,NULL,3,1,2,1,NULL,'laguariza'),(10961,797952637015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','janvondeyen','vondeyen@post.tele.dk','Jan von Deyen','Engvej 25',' Nykøbing F','','DENMARK','DK 4800','54822030','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-05 17:13:06',0,NULL,3,1,2,1,NULL,'janvondeyen'),(10962,735201210017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','hannakxx','hanaex_x@hotmail.com','HANAE KAMEI','2 Stirling Avenue','Malvern East','Victoria','AUSTRALIA','3145','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-05 17:17:49',0,NULL,3,1,2,1,NULL,'hannakxx'),(10963,797977805015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','roytwickers','roycharlie@hotmail.co.uk','Roy Archer','13 Mallard Close','Basingstoke','Hampshire','UNITED KINGDOM','RG225JP','01256810990','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 17:45:06',0,NULL,3,1,2,1,NULL,'roytwickers'),(10964,682042716001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',59,'hermeshine','fiaadmin','billot1@voila.fr','billot jocelyne chez ets. bmc','20 rue du temple','paris','Île-de-France','FRANCE','75004','01.42.78.58.86','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-05 18:50:32',0,NULL,3,1,4,1,'YW865717382CN\r ','fiaadmin\r注意,一共是2个'),(10965,682049322001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','caraduraoo7','super-mario64@hotmail.es','efren corzon vazquez','c/coruña,ed.jardin,1ºA','santa comba','Galicia','SPAIN','15840','676632374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 19:06:51',0,NULL,3,1,2,1,NULL,'caraduraoo7'),(10966,723316022002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','pochacco_18','laumarcuscw@hotmail.com','Marcus Lau','11510-11 Ave SW','Edmonton','AB','CANADA','T6W 1W7','(780) 436-4718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 19:19:44',0,NULL,3,1,2,1,' ','pochacco_18'),(10967,781741322016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','hraven007','raven@wo.cz','Jiri Havran','ul. Gen. Svobody 637','Trebic','','CZECH REPUBLIC','67401','+420724680361','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-05 20:06:01',0,NULL,3,1,2,1,NULL,'hraven007\r77mm 接口环'),(10968,798171692015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','p-h-i-l-t-h-y','phillyt2k@hotmail.com','Phillip Tran','13 Greenfields Avenue','Bromborough','Wirral','UNITED KINGDOM','CH62 6DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-05 21:24:33',0,NULL,3,1,2,1,NULL,'p-h-i-l-t-h-y'),(10969,682142676001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','joseballes01','joseballes@ono.com','Ballesteros Quilez Jose Manuel','C/. Campos Crespo, 6-34','Valencia','Comunidad Valenciana','SPAIN','46017','963258780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-05 21:45:51',0,NULL,3,1,2,1,NULL,'joseballes01'),(10970,781814495016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','harveylyndon','lyndonharvey@aol.com','Westdex Ltd','unit c1 Yelverton Business Park, Crapstone,','Yelverton','Devon','UNITED KINGDOM','PL20 7PE','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117722380CN\r ','harveylyndon'),(10971,681560160018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','8209veronica','ricnrond@bigpond.com','Veronica Davies','1 Coorow Rd','Coorow','Western Australia','AUSTRALIA','6515','0427521141','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-05 23:03:07',0,NULL,3,1,2,1,NULL,'8209veronica'),(10972,723444843002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','kanarboy','jean.huard@polymtl.ca','Jean Huard','7111<br>10E avenue','Montreal','QC','CANADA','H2A 3A8','(514) 340-4711 ext.: 4755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 00:12:01',0,NULL,3,1,2,1,NULL,'kanarboy'),(10973,735474284017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','ptrocenko','paksty@gmail.com','Pavel Trotsenko','7/ 60-66 Auburn Street','Sutherland','New South Wales','AUSTRALIA','2232','0422087816','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-06 02:08:27',0,NULL,3,1,3,1,'RA117722861CN\r ','ptrocenko'),(10974,723483225002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',2,'AA3101',33.98,'hermeshine','viteloni','enio@spadvogados.com.br','Enio Olavo Bacchereti','Rua Jose de Jesus, 66<br>Apto: 81-A','Sao Paulo','Sao Paulo','BRAZIL','05630-090','55 11 2338-3008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 02:16:56',0,NULL,3,1,3,1,'RA117722433CN\r ','viteloni'),(10975,680701097018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','tenzinglodge','chateaubells@aapt.net.au','Steve Peters','9 tenzing Court','Warner','Queensland','AUSTRALIA','4500','0438796349','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-06 03:05:11',0,NULL,3,1,3,1,'RA117725240CN\r ','tenzinglodge'),(10976,682232017001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','f_madika','liga.lysa@gmail.com','Fransisko Madika','Mulia Group, Wisma Mulia 53rd Floor<br>Jl. Jend. Gatot Subroto No. 42','Jakarta Selatan','DKI Jakarta','INDONESIA','12710','(62) 817-0876037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 03:11:36',0,NULL,3,0,3,1,'RA117722305CN\r ','f_madika   (已入库)\r52mm橡胶遮光罩       7\r77mm橡胶遮光罩       3'),(10977,723521136002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sj6497','seokju.kang@sg.verizonbusiness.com','SJ Kang','10 Collyer Quay<br>Ocean Financial Centre, #16-00 Verizon business','default','','SINGAPORE','049315','+65-82226269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 05:20:41',0,NULL,3,1,3,1,'RA117725205CN\r ','sj6497'),(10978,682275425001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','salvator_v','salvator_v@hotmail.com','Sotiris Vlachos','125, Kalvou Str.','Athens','','GREECE','GR-11475','+306944510690','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-06 07:15:23',0,NULL,3,1,3,1,'RA117722504CN\r ','salvator_v'),(10979,682275954001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','1ctsmith36','ctsmith36@hotmail.com','Charles T Smith','2700 Chert Cv','Round Rock','TX','UNITED STATES','78681-1605','','NoPaymentFailure','CheckoutComplete','Other','2011-06-06 07:17:40',0,NULL,3,1,1,1,NULL,'1ctsmith36'),(10980,798345618015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','agenturaraj','agenturaraj@yahoo.co.uk','Ludmila Simalova','39 Colchester Road','Ardleigh','Essex','UNITED KINGDOM','CO7 7NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-06 07:28:50',0,NULL,3,1,2,1,NULL,'agenturaraj'),(10981,682278724001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','ayarmots2010','ayarmots@gmail.com','Алексей Ярмоц','ул. Некрасова, 19 Д, кв. 40','Камышин','Волгоградская область','RUSSIAN FEDERATION','403877','+7 927 5230935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 07:41:34',0,NULL,3,1,3,1,'RA117725117CN\r ','ayarmots2010'),(10982,781975042016,260661403957,'TianYa 82mm UV filter New 82 Protects Your Lens NIB',1,'AA2315',5.2,'hutongstore','258000-2009','performar@abv.bg','Nikolay Todorov','Krali Marko 11 ,G ,11,4','Pleven','','BULGARIA','5800','+359895464934','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 07:45:19',0,NULL,3,1,2,1,NULL,'258000-2009'),(10983,681675662018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','fruengalli','stevefrost@tpg.com.au','steve frost','20 Birugan Close','valla beach','New South Wales','AUSTRALIA','2448','0265695359','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-06 07:47:50',0,NULL,3,1,2,1,NULL,'fruengalli'),(10984,682283744001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','yanithas','yanitha.sapu@gmail.com','Yanitha Halim','ASSA Rent<br>Jl. Pengayoman Blok F22 No. 2','Makassar','South Sulawesi','INDONESIA','90222','08999871111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:07:52',0,NULL,3,1,17,0,NULL,'yanithas'),(10985,723548822002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','yanithas','yanitha.sapu@gmail.com','Yanitha Halim','ASSA Rent<br>Jl. Pengayoman Blok F22 No. 2','Makassar','South Sulawesi','INDONESIA','90222','08999871111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:07:51',0,NULL,3,1,2,1,NULL,'yanithas\rCANON 镜头盖  77mm    1\r肥皂盒 柔光罩   580EX    1'),(10986,682286426001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','fernando.hervas','fernando.hervas@gmail.com','Fernando Hervás','c. de Dalt 3','Pontós','Cataluña','SPAIN','17773','972560208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:15:33',0,NULL,3,1,17,0,NULL,'fernando.hervas'),(10987,723550957002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','fernando.hervas','fernando.hervas@gmail.com','Fernando Hervás','c. de Dalt 3','Pontós','Cataluña','SPAIN','17773','972560208','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:15:34',0,NULL,3,1,2,1,' ','fernando.hervas\r伟峰 6662A 快装板     1\r普通有线快门线C1     1'),(10988,723553421002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:26',0,NULL,8,0,17,0,NULL,'formlogic'),(10989,723553492002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:25',0,NULL,8,0,17,0,NULL,'formlogic'),(10990,723553005002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:26',0,NULL,8,0,17,0,NULL,'formlogic'),(10991,682288995001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-06 08:34:27',0,NULL,8,0,17,0,NULL,'formlogic'),(10992,682288742001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:27',0,NULL,8,0,17,0,NULL,'formlogic'),(10993,723553282002,120454221534,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:28',0,NULL,8,0,17,0,' ','formlogic'),(10994,682288939001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','formlogic','mark@formlogic.co.za','Mark Leonard','13 Putney Road<br>Kenilworth','Cape Town','Western Province','SOUTH AFRICA','7708','0027741777474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 08:34:28',0,NULL,5,0,18,0,NULL,'formlogic\r绿叶 ND8  77mm    1\r绿叶 ND4  77mm    1\r反光板  80cm 5合1    1\r伟峰 717 快装板    1\r三脚架 伟峰 EI-717  180     1\r3片装的滤镜袋    1\r防雨罩   1\r6.947'),(10995,723555598002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-06 08:37:25',0,NULL,3,1,3,1,'RA117722288CN\r ','vacarciucalexandru'),(10996,723560315002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','puntocom.internetyocio','lalegion@internetyocio.com','MARISOL PORTERO PORTERO','C/ GARCIA LORCA 14, LOCAL<br>VIATOR','ALMERIA','Andalucía Ceuta y Melilla','SPAIN','04240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 09:01:26',0,NULL,3,1,3,1,'RA117725267CN\r ','puntocom.internetyocio'),(10997,798379817015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.25,'hutongstore','f.faria.link','fernando.faria@link.pt','Fernando Faria','Av Duque Avila, 23','Lisboa','','PORTUGAL','1000-138','213100049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 09:28:51',0,NULL,3,1,2,1,NULL,'f.faria.link'),(10998,735566672017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','alexhome007','me@alexdraper.net','Alex Draper','4 Hexham Street','Warranwood','Victoria','AUSTRALIA','3134','0398790581','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-06 09:32:57',0,NULL,3,1,3,1,'RA117722570CN\r ','alexhome007\r澳标\r538'),(10999,681706958018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-06 10:09:56',0,NULL,3,1,2,1,NULL,'tan6111'),(11000,682312084001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','kreditt','erlend@hatteberg.com','Erlend Hatteberg','Vindharpevegen 30E','BERGEN','HORDALAND','NORWAY','5239','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 10:11:37',0,NULL,3,1,3,1,'RA117725219CN\r ','kreditt'),(11001,723580231002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vipzonestudio','vipzone@list.ru','Valeriy Potapenko','ул. Николая Василенко дом 17 кв. 15','Киев','','UKRAINE','03124','+380503234668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 10:27:51',0,NULL,3,1,2,1,NULL,'vipzonestudio'),(11002,682319178001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','bdmblesa','blesa@blesa.ru','Oksana Bleskina','ul. Suzdalskaya, d.14, korpus.1, kv.74','Moscow','RU','RUSSIAN FEDERATION','111673','+7(495)702-4607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 10:38:52',0,NULL,3,1,3,1,'RA117722291CN\r ','bdmblesa'),(11003,735603362017,270748510307,'NIB TianYa Gradual grey Color Filter for Cokin P series',2,'AA2322',14.58,'photographyacc','7593gn','grantandjen1@bigpond.com','Grant newland','14 view st','cessnock','New South Wales','AUSTRALIA','2325','0249917439','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-06 11:47:55',0,NULL,3,1,2,1,NULL,'7593gn'),(11004,682339439001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',87,'hermeshine','v.khimenko','vkhimenko@inbox.ru','Khimenko Vasiliy','Mustaphina dom.8 kv.34','Karaganda','','KAZAKHSTAN','100000','(7212) 517-184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 11:56:10',0,NULL,3,1,5,1,'CP227189725CN\r ','v.khimenko'),(11005,723611578002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','manupav','manupav@ya.com','MANUEL PAVON ARGUIJO','PARE BALDIRI DE SANT BOI 2 BAJOS 1','sant boi de llobregat','Catalu','SPAIN','08830','936523374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 12:21:36',0,NULL,3,1,17,0,NULL,'manupav'),(11006,681759580018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','citytec3','dimadis@grevenain.gr','KONSTANTINOS DIMADIS','ATH. DIAKOU 2','GREVENA','GREVENA','GREECE','51100','+302462087250','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-06 13:14:55',0,NULL,3,1,4,1,'YW865717371CN\r ','citytec3\r欧标\r套装再加一个50cm 棚\r'),(11007,735629844017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','citytec3','dimadis@grevenain.gr','KONSTANTINOS DIMADIS','ATH. DIAKOU 2','GREVENA','GREVENA','GREECE','51100','+302462087250','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-06 13:16:09',0,NULL,3,1,17,0,NULL,'citytec3'),(11008,723630731002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wadevb','wadevb@ti.com','Wade VonBergen','608 Rockcrossing Ln','Allen','TX','UNITED STATES','75002-5262','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 13:27:18',0,NULL,3,1,1,1,NULL,'wadevb'),(11009,682374016001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','manupav','manupav@ya.com','MANUEL PAVON ARGUIJO','PARE BALDIRI DE SANT BOI 2 BAJOS 1','sant boi de llobregat','Catalu','SPAIN','08830','936523374','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 13:54:42',0,NULL,3,1,2,1,NULL,'manupav\r气吹 + 布   1\r普通有线快门线C1    1'),(11010,682375881001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','f242526','cfio@mail.ru','Фёдор Юдин','мкр.5 дом 10 кв.75','Актау','Мангистауская область','KAZAKHSTAN','130000','(87292) 521567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 14:00:29',0,NULL,3,1,2,1,NULL,'f242526'),(11011,782099000016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','eatmybologna902','natalie-toombs@hotmail.com','Natalie Toombs','69 Churchill Avenue ','Charlottetown','PE','CANADA','C1A1Z2','(902) 892-2311','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'eatmybologna902'),(11012,682394755001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','vadim1972moskva','vadim-moskva72@mail.ru','Vadim Danilov','Zelenograd, 2028-241','Moscow','Moscow','RUSSIAN FEDERATION','124365','+7 9859928003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 14:59:40',0,NULL,3,1,3,1,'RA117722274CN\r ','vadim1972moskva'),(11013,681795276018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','plhh','jheid@gmx.net','Jens Heidebleck','Lilienthalstr. 18','Offenbach am  Main','','GERMANY','63073','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-06 15:04:07',0,NULL,3,1,2,1,NULL,'plhh'),(11014,723662587002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','jpre7974','kivirowei@yahoo.es','Jorge Pérez Díaz','Av. Mare de Deu de Bellvitge Nº36 8º1ª','L\'Hospitalet de Llobregat, Barcelona','Cataluña','SPAIN','08907','607933241','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 15:08:03',0,NULL,3,1,3,1,'RA117725284CN\r ','jpre7974'),(11015,682420032001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','pascalb6781','thematrixx83@hotmail.com','Steve Beaudoin','651 rue d\'acton','Acton Vale','QC','CANADA','J0H1A0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 16:09:27',0,NULL,3,1,2,1,NULL,'pascalb6781'),(11016,681831292018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','hilaryspiteri','hilary.spiteri@gmail.com','Hilary Spiteri','1, Golden Ring<br>Triq Anglu Borg','Qormi','','MALTA','QRM 08','+00356 21466811','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-06 16:47:06',0,NULL,3,1,2,1,' ','hilaryspiteri'),(11017,723707874002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','victorphotography','spcglez@hotmail.com','Victor Gonzalez','Urb.Villa Universitaria<br>Calle 12 E26','Humacao','PR','UNITED STATES','00791','(787) 360-5848','NoPaymentFailure','CheckoutComplete','Other','2011-06-06 17:10:01',0,NULL,3,1,3,1,'RA117725298CN\r ','victorphotography'),(11018,682446439001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',2,'AE3301',27.96,'hermeshine','mikointermaggio','miko.intermaggio@gmail.com','miko intermaggio / sirioinformatica','viale della liberta 2/a','pordenone','PN','ITALY','33170','3298747702','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 17:15:18',0,NULL,3,1,3,1,'RA117725125CN\r ','mikointermaggio\rlight head  $10'),(11019,723726175002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','sundar220','sundarananda@mail.ru','Sergey Okulov','Sl. Kurteevi 18','Kirov','Kirovskaya','RUSSIAN FEDERATION','610011','+79229259714','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 17:50:15',0,NULL,3,1,2,1,NULL,'sundar220'),(11020,682048367001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','lirvadsa','lirvad@gmail.com','Davril Roman','2 LANGEMERE STREET<br>NORTHPINE','BRACKENFELL','WESTERN-CAPE','SOUTH AFRICA','7560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 18:17:40',0,NULL,3,1,3,1,'RA117725253CN\r ','lirvadsa'),(11021,682473183001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','lavey666julien','daliprod@hotmail.com','Julien Humbert-Droz','Alexis-Marie-Piaget 21','La Chaux-de-Fonds','Neuchâtel','SWITZERLAND','2300','0041786744872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 18:20:31',0,NULL,3,1,3,1,'RA117725338CN\r ','lavey666julien'),(11022,723742193002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tricklelife','elastic_trend@hotmail.com','wasim akhram','564 Sentinel Road','toronto','ON','CANADA','m3j3r9','(647) 204-5092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 18:32:48',0,NULL,3,1,2,1,NULL,'tricklelife'),(11023,723752643002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','aydincolor2000','aydincolor@windowslive.com','ERCAN ERBAY','AYDIN COLOR ucyildiz cad. no:24','SURMENE','TRABZON','TURKEY','61600','+90 4627462469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 18:53:11',0,NULL,3,1,2,1,NULL,'aydincolor2000'),(11024,682512552001,110583278265,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',6.9,'hermeshine','septimiunemes','septimiu_nemes@yahoo.com','Nemes Septimiu-Sever','Neptun 26 A , sc B , ap 8 , et 1','Brasov','','ROMANIA','500352','+400761335441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 19:23:51',0,NULL,3,1,2,1,NULL,'septimiunemes'),(11025,723396828002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','closdamont','christian.c2@scarlet.be','christian collignon','sur fond barbette 24','Flawinne','','BELGIUM','5020','081738272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 19:26:13',0,NULL,3,1,2,1,NULL,'closdamont'),(11026,682538600001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','unseeni','juha.pellonpaa@gmail.com','Juha Pellonpää','Niittytie 8 A 10','Jyväskylä','','FINLAND','40250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 20:18:52',0,NULL,3,1,2,1,NULL,'unseeni'),(11027,682542953001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5.2,'hermeshine','cadd1122','pkhuddleston@swbell.net','Julius Klehm','19203 Evendale Court','Houston','TX','UNITED STATES','77094','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-06 20:27:34',0,NULL,3,1,1,1,NULL,'cadd1122'),(11028,681960962018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','andreagaltea','andrea.gian@gmail.com','Andrea Giannini','Via Valdichiana 57','Firenze','FI','ITALY','50127','3475446282','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-06 20:53:26',0,NULL,3,1,2,1,' ','andreagaltea\r老款内胆包 加大的那个'),(11029,782315785016,260660052658,'New Camera shoulder bag D1 for Canon body and 1-2 lens',1,'AO0031',13.9,'hutongstore','jballes75','javier.ballesteros@dezeque.com','Javier Ballesteros','Résidence Villapollonia<br>1 Villa Théodore Géricault','Élancourt','Île-de-France','FRANCE','78990','0667360246','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 20:56:01',0,NULL,3,1,3,1,'RA117725134CN\r ','jballes75'),(11030,723834135002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','(5521)2268-7693','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-06 21:32:18',0,NULL,3,1,3,1,'RA117722711CN\r ','mariomarques.com.br'),(11031,723839013002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','38smac','dsmmac@shaw.ca','Darren MacDonald','9369 207 Street','Langley','BC','CANADA','V1M 2W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 21:45:36',0,NULL,3,1,3,1,'RA117725222CN\r ','38smac'),(11032,723843870002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','gitanabudd','gjbudd@attglobal.net','Graham Budd','90 Trig Road<br>Whitford','Auckland','','NEW ZEALAND','2571','(09)5308891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 21:59:16',0,NULL,3,1,2,1,NULL,'gitanabudd'),(11033,798735517015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','appleboxbay','gerardmckenzie@hotmail.com','Gerard Mckenzie','25 Hasting Close<br>Balbriggan','Dublin','Dublin','IRELAND','Co','0877643048','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 22:01:02',0,NULL,3,1,2,1,NULL,'appleboxbay'),(11034,782376024016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',2,'AO0033',10,'hutongstore','junixena','rgeir@online.no','Geir Rosvoll','Jon Klæbos vei 10a','Bodø','','NORWAY','8019','91849812','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-06 23:35:32',0,NULL,3,1,2,1,NULL,'junixena'),(11035,723870728002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','fredericj84270','jacopofre@numericable.fr','frederic jacopo','175 allée de la garance','vedene','Provence-Alpes-Côte d\'Azur','FRANCE','84270','0684258143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 23:44:37',0,NULL,3,1,3,1,'RA117722376CN\r ','fredericj84270'),(11036,681075396018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','jemjem3_10','j.croad87@gmail.com','Jemma Croad','327 Miller Road<br>Logan Village','Brisbane','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-06 23:51:15',0,NULL,3,1,4,1,'YW865717360CN\r ','jemjem3_10\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子\rbackground support   $20'),(11037,682607091001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ckilicarslan','cemkilicarslan@yahoo.com','Cem KILICARSLAN','Amerikan Kulturu ve Edebiyati Bol. Edebiyat Fak., Beytepe Kampus<br>Beytepe','Ankara','Ankara','TURKEY','06532','05323840271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-06 23:58:27',0,NULL,3,1,2,1,NULL,'ckilicarslan'),(11038,682037006018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',2,'AA3312',13.2,'photographyacc','ant332','ant332@uow.edu.au','Andrew Thomas','272 Gladstone Ave','Mt St Thomas','New South Wales','AUSTRALIA','2500','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-07 01:20:13',0,NULL,3,1,2,1,NULL,'ant332'),(11039,682040195018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','imageroyale','bensmyew@gmail.com','Shung Ming  Yew','275 Old Coast Road','Australind','Western Australia','AUSTRALIA','6233','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-07 01:36:07',0,NULL,3,1,3,1,'RA117722739CN\r ','imageroyale'),(11182,724910355002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','brunno.eu','henrich@brunno.eu','Henrich BRUNNER','Partizanska 17','Bardejov','Slovakia','SLOVAK REPUBLIC','08501','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 16:34:34',0,NULL,3,1,2,1,NULL,'brunno.eu'),(11040,682637435001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','taz_ufrj','kiwi2free@yahoo.com','MARYBEL VASQUEZ CAYAO','Jiron RIO BRANCO, 2583<br>SAN MARTIN DE PORRAS','LIMA -','LIMA','PERU','31','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 02:05:21',0,NULL,3,1,2,1,NULL,'taz_ufrj'),(11041,682661353001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','paulo_san_terros','paul.ryan4@gmail.com','Paul Ryan','32 Grattan Street<br>Carlton','Melbourne','Victoria','AUSTRALIA','3053','030468565248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 04:10:17',0,NULL,3,1,2,1,NULL,'paulo_san_terros'),(11042,782072237016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ivz026','ivan.degiorgio@gmail.com','Ivan Degiorgio','88 Syed<br>Triq il-Koppla','Fgura','','MALTA','FGR 1514','+35699260783','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-07 05:03:29',0,NULL,3,1,3,1,'RA117722725CN\r ','ivz026'),(11043,682671556001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','runnin5k','denaut@att.net','Dennis De Naut','7402 Walnut Lane','Sebastopol','CA','UNITED STATES','95472','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 05:08:11',0,NULL,3,1,1,1,NULL,'runnin5k'),(11044,782465012016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','sonic_toys','neil_baigent@yahoo.co.uk','neil baigent','118A GREEN LANES','LONDON','London','UNITED KINGDOM','N16 9EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 05:32:12',0,NULL,3,1,2,1,NULL,'sonic_toys\r 62mm 接口环   '),(11045,682676630001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','jimbo77777','seven_7th@yahoo.com','Asrinna Bakri','No 19<br>Jalan 2/2C','Bandar Baru Bangi','Selangor','MALAYSIA','43650','0196367732','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-07 06:05:52',0,NULL,3,0,3,1,'RA117725236CN\r ','jimbo77777\r3XL(已入库)'),(11046,682442682001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','mikhael_techno','gerasimov.mikhael@gmail.com','Mikhael Gerasimov','Shkolny boulvar 16, 64','Chernogolovka','Moskow region','RUSSIAN FEDERATION','142432','89104353813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 06:27:02',0,NULL,3,1,2,1,NULL,'mikhael_techno'),(11047,682124602001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',19,'hermeshine','feonn','mahacandra@gmail.com','Aleksandar Bogdanov','12 Shipka St','Sofia','Sofia','BULGARIA','1504','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-07 07:14:28',0,NULL,3,1,3,1,'RA117725307CN\r ','feonn'),(11048,735994572017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','sunkissedgirls','hayley@thesunkissedgirls.com.au','Hayley Skinner','10 Moana Court<br>Mountain Creek','Sunshine Coast','Queensland','AUSTRALIA','4557','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-07 07:41:09',0,NULL,3,1,3,1,'RA117722464CN\r ','sunkissedgirls\r澳标\r2m 灯架   1\r单灯头  1\r反光伞   1\r'),(11049,682115814018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','tyronestacey','tyrone-stacey@hotmail.com','tyrone stacey','8/41 roseberry ave','manly vale','New South Wales','AUSTRALIA','2093','0417485149','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-07 08:10:27',0,NULL,3,1,3,1,'RA117722518CN\r ','tyronestacey'),(11050,798892192015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','lineoverdeput','lineoverdeput@hotmail.com','Line Overdeput','sint-lievenspoortstraat 288','gent','','BELGIUM','9000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-07 08:13:42',0,NULL,3,1,2,1,NULL,'lineoverdeput'),(11051,682118234018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','sxy_toy','sxy_toy@hotmail.com','Sav Morm','35 pleasant road Thomastown','Melbourne','Victoria','AUSTRALIA','3074','0434264914','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-07 08:22:16',0,NULL,3,1,2,1,NULL,'sxy_toy'),(11052,736008622017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','seller_woody','woodyinsydney@hotmail.com','Mark Wood','14/16-18 Waterloo Street','Surry Hills','New South Wales','AUSTRALIA','2010','0412037033','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-07 08:40:03',0,NULL,3,1,2,1,NULL,'seller_woody'),(11053,682712113001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','moineau323','bernard.frossard@celsa.ch','Bernard Frossard','Route du Collège 40','Riaz','Fribourg','SWITZERLAND','1632','0266529301','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 08:58:14',0,NULL,3,1,3,1,'RA117722708CN\r ','moineau323'),(11054,682129429018,280687532335,'Studio Light 1000W Continuous Lighting Complete Kit  ',1,'AKT005',197,'photographyacc','rippasales','georgejohnroy@yahoo.com','George Roy','14 McIntosh Ave','Hoppers Crossing','Victoria','AUSTRALIA','3029','0397494225','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-07 09:15:49',0,NULL,3,1,4,1,'YW865717430CN ','rippasales\r澳标\r2.1x1.6m 背景布  1(白色)\r申报:30$ Lighting kit'),(11055,682717312001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','cindystrappazzon','studiocindys@gmail.com','Cindy Strappazzon','2nd Street<br>380','Karibib','Erongo Region','NAMIBIA','9000','002640640550177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 09:22:47',0,NULL,3,1,2,1,NULL,'cindystrappazzon'),(11056,682718061001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','pas2par','paskay@bezeqint.net','GIDEON PASKAY','SHMARIAHU LEVIN 23/16','RISHON LE ZION','','ISRAEL','75278','972548110224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 09:25:06',0,NULL,3,1,3,1,'RA117722610CN\r ','pas2par'),(11057,736030756017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',1,'AB2401',10.9,'photographyacc','roberjoaqui','gerarober@hotmail.com','roberto pirani','solanet 440','general rodriguez','buenos aires','ARGENTINA','1748','02374853753','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-07 10:14:43',0,NULL,3,1,2,1,NULL,'roberjoaqui'),(11058,682740388001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',2,'AO0032',41.98,'hermeshine','ferdos','varinelli.cristian@gmail.com','Cristian Varinelli','Via Falconi, 75','Castelli Calepio','BG','ITALY','24060','328-9520341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 11:03:19',0,NULL,3,1,3,1,'RA117722671CN\r ','ferdos\r申报 photo bag  $16'),(11059,724010771002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','eradnort','trondaret@gmail.com','Trond Are Thomassen','Vågsveien','Hjørungavåg','Møre og Romsdal','NORWAY','6063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 11:22:55',0,NULL,3,1,2,1,NULL,'eradnort'),(11109,683107765001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','faith83_03','m.bechis83@gmail.com','Bechis Maria Lucia','via Piave 13/2','Piossasco','TO','ITALY','10045','0119064068','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 08:55:18',0,NULL,3,0,3,1,'RA117722844CN ','faith83_03\rxl(已入库）\rphoto vest  $10'),(11060,682767984001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','srwaynel','wlabonte@burlingtontelecom.net','Wayne LaBonte Sr','115 Woodbury Rd','Burlington','VT','UNITED STATES','05408','(802) 658-2771','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 12:47:52',0,NULL,3,1,1,1,' ','srwaynel'),(11061,724032229002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','enchere.wilux','email.wilco@gmail.com','Benjamin Boisseau','39, rue dupont des loges','Rennes','Bretagne','FRANCE','35000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:48:57',0,NULL,3,1,3,1,'RA117722623CN\r ','enchere.wilux\r肩架    1\r绿叶 CPL  55mm    1\r绿叶 UV  55mm      1\r绿叶 渐变镜 55mm   1'),(11062,724031636002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','enchere.wilux','email.wilco@gmail.com','Benjamin Boisseau','39, rue dupont des loges','Rennes','Bretagne','FRANCE','35000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:48:58',0,NULL,3,1,17,0,NULL,'enchere.wilux'),(11063,682765134001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','enchere.wilux','email.wilco@gmail.com','Benjamin Boisseau','39, rue dupont des loges','Rennes','Bretagne','FRANCE','35000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:48:59',0,NULL,3,1,17,0,NULL,'enchere.wilux'),(11064,682766662001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','enchere.wilux','email.wilco@gmail.com','Benjamin Boisseau','39, rue dupont des loges','Rennes','Bretagne','FRANCE','35000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 12:48:59',0,NULL,3,1,17,0,NULL,'enchere.wilux'),(11065,782588401016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',1,'AA1303',1.87,'hutongstore','arppatsiippa','ari_kauppinen@hotmail.com','ari kauppinen','tiemiehenkatu 4 c 17','kajaani','Oletus','FINLAND','87250','0405747961','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-07 13:08:33',0,NULL,3,1,2,1,NULL,'arppatsiippa'),(11066,682118598001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','soniamb','soniamb2001@hotmail.com','Sonia Martinez','Bonavista 14, Atico','Ripollet','Cataluña','SPAIN','08291','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 13:42:56',0,NULL,3,1,2,1,NULL,'soniamb'),(11067,682796451001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',64,'hermeshine','z_likar','z_likar@yahoo.com','Zoran Likar','64 A  HASSETT  CRES','Keilor East','Victoria','AUSTRALIA','3033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 14:27:16',0,NULL,3,1,17,0,NULL,'z_likar'),(11068,724063291002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','vintage-mech','jeffreyl.davis@att.net','Jeff Davis','9558 Shepard Pl','Wellington','FL','UNITED STATES','33414-6420','','NoPaymentFailure','CheckoutComplete','Other','2011-06-07 14:31:15',0,NULL,3,1,1,1,NULL,'vintage-mech\r115w 5500k 灯泡  110v    2'),(11069,682801023001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 14:46:16',0,NULL,3,1,5,1,'CP227020450CN ','mellogabriel'),(11070,724090262002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',3,'AB2301',29.85,'hermeshine','z_likar','z_likar@yahoo.com','Zoran Likar','64 A  HASSETT  CRES','Keilor East','Victoria','AUSTRALIA','3033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 15:54:16',0,NULL,3,1,17,0,NULL,'z_likar'),(11071,682825727001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',75.9,'hermeshine','z_likar','z_likar@yahoo.com','Zoran Likar','64 A  HASSETT  CRES','Keilor East','Victoria','AUSTRALIA','3033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 15:58:25',0,NULL,3,1,4,1,'YW865717463CN ','z_likar\r2m 弹簧灯架    2\r反光板支架    2\r闪光灯B座     3\r5.68'),(11072,799049340015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','charlietmurphy','charlietm@hotmail.com','Charlie Murphy','Media Junction<br>2 Archer St','London','London','UNITED KINGDOM','W1D7AW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-07 16:01:25',0,NULL,3,1,2,1,NULL,'charlietmurphy'),(11073,682250590018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-07 16:24:47',0,NULL,3,1,4,1,'YW865717426CN ','tan6111\r0630 - 0712系统显示货已收到.'),(11074,682834068001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','cow-juke12','comindbar@yahoo.com','Jackie Downs','121 Town Center Dr','Highland Park','MI','UNITED STATES','48203-3680','(313) 865-8281','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-07 16:25:06',0,NULL,3,1,1,1,NULL,'cow-juke12'),(11075,724119172002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','ffuffe','ffuffe@hotmail.com','jose  gonzalez moreno','padura 3, 3º D','elorrio','País Vasco','SPAIN','48230','666 81 29 22','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-07 17:14:47',0,NULL,3,1,3,1,'RA117722637CN\r ','ffuffe'),(11076,682278317018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','naorsaso1','naor_s3@walla.com','naor sasones','sokolov 34 / 9','bat-yam','','ISRAEL','59452','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-07 17:24:27',0,NULL,3,1,2,1,NULL,'naorsaso1'),(11077,682871306001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','anatoliy_buravlev','buravlevfilm@mail.ru','Anatoliy Buravlev','Barnaulskiy pereulok № 34','Novosibirsk','Novosibirskay oblost','RUSSIAN FEDERATION','630028','8-913-478-1333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 17:57:42',0,NULL,3,1,3,1,'RA117722699CN\r ','anatoliy_buravlev'),(11078,736214202017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',7.28,'photographyacc','ehgrms','eringilmer@att.net','Erin Grimes','2110 Elm St','St. Charles','MO','UNITED STATES','63301','(636) 577-1314','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-07 18:53:52',0,NULL,3,1,1,1,NULL,'ehgrms'),(11079,682915398001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',2,'AA2205',7,'hermeshine','youst75','youst@ukr.net','Yuriy Druzhinets','Lenina str., 27A-38','Tokmak','Zaporozhye region','UKRAINE','71700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 19:38:37',0,NULL,5,1,18,0,NULL,'youst75\r客户要机身上带\"Photon\"的那款,如果没有告我一声.6月9日10日,分别发信追问,均无回答.\r'),(11080,724007409002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','gambiton','gambitaw@gmail.com','Amir Weiss','Nurdeo 889','Tel Aviv','IL','ISRAEL','00000','+972544639383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 19:50:58',0,NULL,3,1,3,1,'\rRA117720715CN','gambiton\r单发一个斜臂的杆给他，上次的上面有非常多的划痕， 检查一下发\rRA117722645CN\rRA117720715CN\r\r'),(11081,724189723002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.99,'hermeshine','dutik2007','alexdormadikhin@gmail.com','Alex Dormadikhin','Airport 11 ap. 30','Chisinau','','MOLDOVA, REPUBLIC OF','MD2026','37368033233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 19:52:41',0,NULL,3,1,2,1,NULL,'dutik2007'),(11082,724216202002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','nefintidis','cyparagogi@ymail.com','Alexandros Nefintidis','Pallados 21','Paphos','Cyprus','CYPRUS','8046','0035799544091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 20:50:41',0,NULL,3,1,2,1,NULL,'nefintidis'),(11083,724239284002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','xikusa','micropequenia@hotmail.com','Laura Rivas','Avda. Monforte de Lemos, 69. Bajo B','Madrid','Madrid','SPAIN','28029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 21:53:34',0,NULL,3,1,2,1,NULL,'xikusa'),(11084,682977634001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','jcs4769','jcscoles@comcast.net','John Scoles','6704 NW 92nd Ter','Tamarac','FL','UNITED STATES','33321-3526','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 22:01:32',0,NULL,3,1,1,1,NULL,'jcs4769'),(11085,724224024002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','reuta2309','reuthagage@hotmail.com','Reut Hagage','Hashoftim st\' 32A','KARKUR','','ISRAEL','37106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:05:42',0,NULL,3,1,2,1,NULL,'reuta2309'),(11086,724249962002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','iluvam88','linnmarion88@gmail.com','Linn-Marion Stenkjær','Skogvegen 117 B','Harstad','Harstad','NORWAY','9403','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-07 22:23:38',0,NULL,3,1,2,1,' ','iluvam88'),(11087,724272656002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rhondakomar','shellkomar@yahoo.com','Rhonda Komar','1614 Clemson Dr','Brunswick','OH','UNITED STATES','44212-6100','(330) 220-4816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-07 23:57:27',0,NULL,3,1,1,1,NULL,'rhondakomar'),(11088,683015604001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','rfh_hockey','rfhcasa@yahoo.com','robert herman','13 glendale rd','southampton','MA','UNITED STATES','01073-9377','(413) 244-9167','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-08 00:42:25',0,NULL,3,1,1,1,NULL,'rfh_hockey'),(11089,682459251018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','dayonesociety89','dayonesociety@gmail.com','tyler davis','4007 arnst way','spring hill','TN','UNITED STATES','37174-9265','(615) 881-9811','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 01:40:22',0,NULL,3,1,4,1,'YW865717415CN ','dayonesociety89\r灯泡 110v\r申报: lighting kit  $25\r'),(11090,722510567002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','dooceccotto','ececcotto@gmail.com','Eduardo Campos','Rua Baronesa de Itu, 709<br>apto 11 - Santa Cecília','São Paulo','São Paulo / São Paulo / Sudeste','BRAZIL','01231001','55 11 3667 3189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 02:22:11',0,NULL,3,1,2,1,' ','dooceccotto'),(11091,683046317001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mama2aw','keranderson@new.rr.com','Kerri Anderson','127 Fellows Dr','Green Bay','WI','UNITED STATES','54303-2640','(715) 254-5268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-08 03:05:19',0,NULL,3,1,1,1,NULL,'mama2aw\r绿色'),(11092,724318910002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 03:27:30',0,NULL,3,1,6,1,'EE520583468CN ','buyedv\r申报：Gift'),(11093,682236435001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','lucandy16','cwiewiora_04@hotmail.com','Chris Wiewiora','13a Michael Cres','Kiama Downs','New South Wales','AUSTRALIA','2533','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 03:59:35',0,NULL,3,1,2,1,NULL,'lucandy16'),(11107,682527200018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','merimou909','meris909@gmail.com','MARY IOANNIDES','1035 OLD CALDER HWY<br>KEILOR MELBOURNE','MELBOURNE','Victoria','AUSTRALIA','3036','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-08 07:44:54',0,NULL,3,1,2,1,NULL,'merimou909'),(11094,724338174002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','chosencro','d0mbaa@gmail.com','Domagoj Buljan','Sjenjak 55','Osijek','Osiječko-Baranjska','CROATIA','31000','+385955532174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:24:46',0,NULL,3,1,2,1,NULL,'chosencro'),(11095,683073372001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','dikovsky_studio','studio@dikovsky.com','Konstantin Dikovsky','Serebristy boulevard 38-205','Saint Petersburg','','RUSSIAN FEDERATION','197341','+79112207007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 05:55:28',0,NULL,3,1,3,1,'RA117722773CN ','dikovsky_studio'),(11096,724347936002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','ryanjackson94','suedoble@iinet.net.au','suzanne doble','24 larkspur lane<br>ballajura','perth','Western Australia','AUSTRALIA','6066','0892496355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:27:47',0,NULL,3,1,4,1,'YW865717452CN ','ryanjackson94\r0630-0712回信说已经收到'),(11097,683080410001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','scotty3da','scott3d@westnet.com.au','Scott Butler','140 Targo Road','Girraween','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:32:59',0,NULL,3,1,2,1,NULL,'scotty3da'),(11098,724350691002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','mkucukart','grafimustafa@hotmail.com','Mustafa Küçük','Musallabagları mahallesi ruhibagdadi sokak<br>no: 54 selçuklu','konya','Turkey / Konya / Selçuklu','TURKEY','42060','+905066519422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:44:02',0,NULL,3,1,2,1,NULL,'mkucukart'),(11099,682516603018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','2345jayj','tajj_88@hotmail.com','Janarthanan','15 Millpond Drive','Point Cook','Victoria','AUSTRALIA','3030','0405711364','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-08 06:51:29',0,NULL,3,1,2,1,NULL,'2345jayj'),(11100,683084986001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','rusz326','rusz@nm.ru','Rustem Zakirov','lazareva<br>3-2','Kazan','Tatarstan','RUSSIAN FEDERATION','420033','7895563245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:56:03',0,NULL,3,1,2,1,NULL,'rusz326\rlenspen    1\r绿叶 CPL  55mm    1'),(11101,724353310002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rusz326','rusz@nm.ru','Rustem Zakirov','lazareva<br>3-2','Kazan','Tatarstan','RUSSIAN FEDERATION','420033','7895563245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:56:03',0,NULL,3,1,17,0,NULL,'rusz326'),(11102,683084299001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','jibe111','peterv@bluewin.ch','Peter Vogt','Dachlisserstrasse 28','Mettmenstetten','','SWITZERLAND','8932','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 06:57:07',0,NULL,3,1,2,1,NULL,'jibe111'),(11103,782983806016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 07:25:56',0,NULL,3,1,17,0,NULL,'geflesa'),(11104,799383491015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 07:25:57',0,NULL,3,1,17,0,NULL,'geflesa'),(11105,782979703016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',3.5,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 07:25:57',0,NULL,3,1,2,1,NULL,'geflesa\r气吹 + 布    1\r热靴保护盖  普通     1\rlenspen    1'),(11106,682523166018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','1585noel','noelattard@onvol.net','Francis Attard','\'Dawl\', Xghajra street,<br>Xghajra street,','Zabbar','','MALTA','ZBR06','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-08 07:30:23',0,NULL,3,1,2,1,NULL,'1585noel'),(11108,683101477001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','elinetsev','elinets@yandex.ru','evgeny volynets','Karla Marksa, 7b - 50','Bolshoy Kamen','Primorskiy Kray, RU','RUSSIAN FEDERATION','692806','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 08:27:02',0,NULL,3,1,5,1,'CP227020463CN ','elinetsev'),(11110,683114135001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','mbjeep1942','duccionu@tin.it','Duccio Nutini','Via Brunelleschi 30','Prato','PO','ITALY','59100','0574-574012','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 09:24:03',0,NULL,3,0,3,1,'RA117722889CN\r ','mbjeep1942\rxl  （已入库）\rphoto vest  $10'),(11111,723823199002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','lachmiva','lachman.cz@gmail.com','Kryštof','Společná 7','Praha-8','','CZECH REPUBLIC','18200','00420603985782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 09:42:42',0,NULL,3,1,5,1,'CP227189861CN ','lachmiva'),(11112,783025600016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','tvieira2003','junior@ideiasfrescas.com','Anibal Tiago Vieira','Prc Alexandre Herculano,<br>22 - 4º D','FARO','Algarve','PORTUGAL','8000-160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 10:03:40',0,NULL,3,1,2,1,NULL,'tvieira2003'),(11113,683131306001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','gengiskp','gengis@tpg.com.au','Khanh Pham','1 Woolworths Way<br>Bella Vista','Sydney','New South Wales','AUSTRALIA','2153','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 10:42:13',0,NULL,3,1,3,1,'RA117773231CN\r ','gengiskp'),(11114,799459574015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','pedroescalona01','bg1pedro@hotmail.com','pedro bethencourt','19 sandrock road','wrexham','Wrexham','UNITED KINGDOM','LL128LT','01978853494','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 11:29:59',0,NULL,3,1,2,1,NULL,'pedroescalona01'),(11115,682585189018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','gabeimakefilms','gaberoxburgh@hotmail.com','Senator Gabe Roxburgh','P.O BOX 32','Woodburn','New South Wales','AUSTRALIA','2472','0266822655','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'gabeimakefilms'),(11116,683162748001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','amercatic','amer_catic@yahoo.com','Amer Catic','Muje Pasica 7b','Mostar','','BOSNIA AND HERZEGOVINA','88000','+38761158441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 12:39:21',0,NULL,3,1,2,1,NULL,'amercatic'),(11117,724436905002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','bollullos','bollullosm@hotmail.com','angel rivas alba','picos de aroche, 76<br>bollullos de la mitacion','sevilla','Andalucía Ceuta y Melilla','SPAIN','41110','650292245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 12:56:47',0,NULL,3,1,2,1,NULL,'bollullos'),(11118,682613220018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','2010veaceslav','saitan.cristina@gmail.com','Veaceslav Lujan','Mircea Cel Batrîn 4/1<br>ap.17','Chișinău','Chișinău','MOLDOVA, REPUBLIC OF','2044','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-08 13:21:17',0,NULL,3,1,5,1,'CP227189858CN ','2010veaceslav\r'),(11119,682615197018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','johnnyt85','forsaken_paradise85@hotmail.com','Johnny Tran','11 Mandolong Street Bonnyrigg Heights','Sydney','New South Wales','AUSTRALIA','2177','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-08 13:27:49',0,NULL,3,1,2,1,NULL,'johnnyt85'),(11120,720663862002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tomamak','tomamak@hotmail.com','tom mamakos','chrisomallousis 31 b<br>chrisomallousis 31 b mytilene','Mitilini','lesvos','GREECE','81100','6942653752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 13:47:54',0,NULL,3,1,2,1,NULL,'tomamak'),(11121,683210960001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','mudder3510','mudder351@comcast.net','grant stacy','51709 Hollyhock Rd','south bend','IN','UNITED STATES','46637-2719','(574) 271-1816','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-08 15:17:01',0,NULL,3,1,1,1,NULL,'mudder3510'),(11122,682655720018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','obmac_57','chilim57@tpg.com.au','CHI LIM','12 Margitich Street','Croydon Park,','South Australia','AUSTRALIA','5008','0883465434','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-08 15:27:31',0,NULL,3,1,2,1,NULL,'obmac_57'),(11123,682647621018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',2,'AO0010',110,'photographyacc','sandx79','xavier_seona@hotmail.com','Xavier Anderson','7 Edwards street<br>South Brighton','Adelaide','South Australia','AUSTRALIA','5048','0422440800','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-08 15:32:58',0,NULL,3,1,4,1,'YW865717485CN ','sandx79\r申报: backdrop support  $25'),(11124,682669970018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','xyzchristianxyz86','xyzchristianxyz@vtxmail.ch','Christian Graf','studenbühlstrasse 39','Wollerau','','SWITZERLAND','8832','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-08 16:05:33',0,NULL,3,1,2,1,NULL,'xyzchristianxyz86'),(11125,724500012002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','gil_photo','just.gil@gmail.com','Gil Levy','No.3 Shkediya St. Apt.5','Ramat Gan','Israel','ISRAEL','52447','+972523892798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 16:11:19',0,NULL,3,1,2,1,NULL,'gil_photo'),(11126,724516000002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','betfaldi','indah@freemail.hu','Bea Betfaldi','Nyírpalota út 13<br>10 emelet 29.','Budapest','Pest','HUNGARY','1157','00361419-1647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 16:52:47',0,NULL,3,1,2,1,NULL,'betfaldi'),(11127,683246670001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',72,'hermeshine','dominusmagister','ercankarapinar@hotmail.com','ercan karapınar','namık kemal mahallesi, cengiz topel caddesi<br>no:18 ümraniye','istanbul','','TURKEY','34760','902163354391','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 16:57:34',0,NULL,3,0,17,0,NULL,'dominusmagister'),(11128,724518972002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','dominusmagister','ercankarapinar@hotmail.com','nurettin polat','ankara caddesi hocapasa sokak<br>hocapasa is merkezi kat:3 no:152 eminonu','istanbul','','TURKEY','34112','+902125220257','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 17:01:06',0,NULL,3,0,3,1,'RA117773302CN\r ','dominusmagister  (已入库)\r摄影背心 Canon  老款    L    2\r摄影背心 Nikon    老款    L    2\r2.568(分成2个挂号小包发)\rRA117773214CN\r'),(11129,783187547016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','ianabutler','ian_a_butler@hotmail.com','Ian Butler','22 Ermine Road','London','London','UNITED KINGDOM','SE137JS','02086922134','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 17:13:11',0,NULL,3,1,2,1,NULL,'ianabutler'),(11130,724541233002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','pitttaya','pitt.taya@gmail.com','Amnart Taya','80 Railway rd. Wongwien-Yai<br>Bangyeerua Thonburi','BANGKOK','BANGKOK','THAILAND','10600','66873278457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 17:53:10',0,NULL,3,1,3,1,'RA117722827CN\r ','pitttaya'),(11131,799620575015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',6.1,'hutongstore','memento_74','epauepeo@hotmail.com','alessandro argiolas','via 9 novembre 1989 S.N.   località cortexandra','sestu','CA','ITALY','09028','3408797464','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 17:54:22',0,NULL,3,1,2,1,NULL,'memento_74'),(11132,724551101002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','classic.rus','classic.ru@gmail.com','Sergey Shishkin','Krasina St. 2 - 33','Krasnodar','Krasnodar Region','RUSSIAN FEDERATION','350063','+7 988 2448299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:13:55',0,NULL,3,1,2,1,NULL,'classic.rus'),(11133,724553218002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','odryak','tarasstanislav@yandex.ru','Stanislav Tarasov','Svobody 234-54','Samara','','RUSSIAN FEDERATION','443051','9261321','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 18:18:43',0,NULL,3,1,3,1,'RA117722835CN\r ','odryak'),(11134,683293672001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','h_art_4eb','h-art@yandex.ru','Artur Khabibullin','R.Zorge 38/1-20','Ufa','Bashkortostan','RUSSIAN FEDERATION','450059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:43:23',0,NULL,3,1,3,1,'RA117722901CN\r ','h_art_4eb'),(11135,724565299002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','nik1-s','nik1shtets@gmail.com','Nikolay Shtets','Сhusovskaya ulitsa, 5/2,16','Moscow','RU','RUSSIAN FEDERATION','107207','74954673583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:45:09',0,NULL,3,1,17,0,NULL,'nik1-s'),(11136,683294593001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','nik1-s','nik1shtets@gmail.com','Nikolay Shtets','Сhusovskaya ulitsa, 5/2,16','Moscow','RU','RUSSIAN FEDERATION','107207','74954673583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:45:10',0,NULL,3,1,2,1,NULL,'nik1-s\r方镜卡座 广角托架    1\rnikon 反接环  52mm   1\r方形滤镜接口环 77mm    1'),(11137,724564931002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nik1-s','nik1shtets@gmail.com','Nikolay Shtets','Сhusovskaya ulitsa, 5/2,16','Moscow','RU','RUSSIAN FEDERATION','107207','74954673583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:45:11',0,NULL,3,1,17,0,NULL,'nik1-s'),(11138,683302745001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',12,'AA3307',52.2,'hermeshine','fotoglobal7070','fotoglobal@gmail.com','Ivan Sanches','Av Pedroso de Morais 99','Sao Paulo','São Paulo','BRAZIL','05419-000','11.81347070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 18:58:39',0,NULL,3,1,17,0,NULL,'fotoglobal7070'),(11139,683307761001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',3,'AE3601',54,'hermeshine','fotoglobal7070','fotoglobal@gmail.com','Ivan Sanches','Av Pedroso de Morais 99','Sao Paulo','São Paulo','BRAZIL','05419-000','11.81347070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 19:08:56',0,NULL,3,1,5,1,'CP227189760CN ','fotoglobal7070\r绿叶 UV  77mm     12\r115w 5500k 灯泡  220v     3\r2.13'),(11140,682756232018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','vlomo','matjaz.trapecar@siol.net','TRAPEČAR MATJAŽ','GRADIŠČE I 84','1291 ŠKOFLJICA','SLOVENIJA','SLOVENIA','705','0038641623214','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-08 19:14:49',0,NULL,3,1,5,1,'CP227189795CN ','vlomo\r欧标\r'),(11141,724609304002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','alisaeed2011','partsglobalali@yahoo.com','hussain saeed kadem','3306 alkateb- aloroubah safwa<br>unit1 safwa 6642-32833','safwa','eastern province','SAUDI ARABIA','32833-6642','00966555877547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 20:14:38',0,NULL,3,1,3,1,'RA117722892CN\r ','alisaeed2011'),(11142,683386445001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','12xtrefilm','xtrefilm@seznam.cz','Miroslav Trefil','Sladovní 461','Kojetín','','CZECH REPUBLIC','75201','+420777865242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-08 22:28:19',0,NULL,3,1,3,1,'RA117722813CN\r ','12xtrefilm'),(11143,799761035015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',4,'AC1201',8.72,'hutongstore','schoolteacher2860','bjorn@matsen.dk','bjorn matsen','niels bohrs allé 15','soborg','','DENMARK','2860','+4539699675','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-08 22:33:08',0,NULL,3,1,2,1,NULL,'schoolteacher2860'),(11144,683194075001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 22:57:00',0,NULL,3,1,17,0,NULL,'saud-p'),(11145,682849721018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','khyetan','kctan@krhs.net.au','Khye Tan','15 Weeks Close','Rowville','Victoria','AUSTRALIA','3178','0359979757','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-08 23:14:32',0,NULL,3,1,4,1,'YW865717474CN ','khyetan\r'),(11146,681050352018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',5.48,'photographyacc','cabooltureqld','sales@weddingportraitphotographer.com.au','Steven Hayes','12 Wilson Street','Caboolture','Queensland','AUSTRALIA','4510','0405921920','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-08 23:33:18',0,NULL,3,1,2,1,NULL,'cabooltureqld'),(11147,724683161002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-09 00:07:31',0,NULL,3,1,3,1,'RA117773245CN\r ','boyadjy'),(11148,795648206015,250692241006,'YongNuo SF-17 Flash Battery Pack for SB-800 SD-8A /6AA',1,'AB3315',28.99,'hutongstore','fotoesequiel','esequielfreitas@gmail.com',' freitas esequiel osorio alves','rua são miguel porta 207','serzedelo gmr','guimaraes','PORTUGAL','4765-557','351253537555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 00:15:56',0,NULL,3,1,3,1,'RA117722875CN\r ','fotoesequiel'),(11149,724713373002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','luplini_jsa','jones.salvador@gmail.com','Jones Alves','Av. Dr. Arthur Andrade Filho, 3320 quadra 48','Mairiporã','São Paulo','BRAZIL','07600-000','5511 44851994','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 02:25:38',0,NULL,3,1,5,1,'CP227189813CN ','luplini_jsa'),(11150,724718818002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','28bambu','tanax350@yahoo.com','Alex Wong','2007-1 Rean Drive','North York','ON','CANADA','M2K3C1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 02:58:27',0,NULL,3,1,2,1,' ','28bambu'),(11151,724725661002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','zoot-capri','zootcapri@msn.com','Bill Hammond','Vision International<br>3030 West Directors Row','Salt Lake City','UT','UNITED STATES','84104','(801) 230-0406','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 03:25:12',0,NULL,3,1,3,1,'RA117773228CN\r ','zoot-capri'),(11152,682905886018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','sooty_59','sooty271159@gmail.com','JOHN SUTTON','32 banksia cct','FORESTLAKE','Queensland','AUSTRALIA','4078','0732789602','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-09 03:35:17',0,NULL,3,1,2,1,NULL,'sooty_59'),(11153,724738469002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','asw99','andees27@aol.com','carl west','2376 W Warner Ave','fresno','CA','UNITED STATES','93711','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 04:46:19',0,NULL,3,1,3,1,'RA117773418CN','asw99'),(11154,736844801017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','cxni777','curtis.x.ni@gmail.com','Xinye Ni','Monsanto Australia Ltd<br>L 12, 600 St Kilda Road','Melbourne','Victoria','AUSTRALIA','3004','0409549638','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-09 05:33:03',0,NULL,3,1,2,1,NULL,'cxni777'),(11155,682926260018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','reggie1303','damiengosson@hotmail.com','Damien Gosson','8 erin court','Armidale','New South Wales','AUSTRALIA','2350','0267724575','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-09 05:39:34',0,NULL,3,1,4,1,'YW865717500CN ','reggie1303'),(11156,683472818001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','aarkej','adikej@gmail.com','Ms Ritu AGARWAL','52B, Shambhunath Pundit Street, Flat No. 301<br>Near Bangur Institute of Neurology, Bhowanipore','Kolkata','WB','INDIA','700025','9980197797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 05:50:53',0,NULL,3,1,2,1,' ','aarkej'),(11157,682930921018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','btchplzr','chris.montealegre@gmail.com','Christopher Montealegre','1303/2 Atchison St, St Leonards','Sydney','New South Wales','AUSTRALIA','2065','0433110663','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-09 06:05:54',0,NULL,3,1,2,1,NULL,'btchplzr'),(11158,736852726017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','svaz000','black_sv_900@hotmail.com','Shayne Vaz','74 Essington St','Wentworthville','New South Wales','AUSTRALIA','2145','0296875243','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-09 06:17:23',0,NULL,3,1,2,1,NULL,'svaz000'),(11159,724753788002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','pirazzitong','pirazzitong@yahoo.com','wilson w tong','2227 Blackwell Chase Ct','Marietta','GA','UNITED STATES','30062-8505','(404) 771-9979','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 06:30:00',0,NULL,3,1,3,1,'RA117773863CN ','pirazzitong'),(11160,682944631018,280680879798,'Camera Remote Shutter Release Cord RS-C3 Canon 40D 50D ',2,'AA3211',11.38,'photographyacc','karink100','karink@amdocs.com','Karin Kadosh','Kibbutz nir-am<br>D.N Hof Ashqelon','Kibbutz nir-am','','ISRAEL','79155','972507254409','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-09 07:19:55',0,NULL,3,1,2,1,' ','karink100'),(11161,683499665001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','tuanbaru','bornbatavia@lagoon.nc','Hadi LUKMAN','71 Rue Charleroi','NOUMEA','Province SUD','NEW CALEDONIA','98800','6879237440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:16:12',0,NULL,3,1,2,1,NULL,'tuanbaru'),(11162,682956722018,280683075819,'Stereo Microphone for DC DV Camcorder 60D 5D II 7D 550D',1,'AA1215',42.99,'photographyacc','boydbowlin','amljm@hotmail.com','Anthony Woodbine','66 Brandon St','Suffolk Park','New South Wales','AUSTRALIA','2481','0266853096','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-09 08:21:38',0,NULL,3,1,3,1,'RA117773497CN\r ','boydbowlin'),(11163,783496943016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','fitzer0_6','eamonf@vodafone.ie','Eamon Fitzpatrick','Teer<br>Brandon','Tralee','Kerry','IRELAND','default','0872380949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 08:36:17',0,NULL,3,1,3,1,'RA117773545CN ','fitzer0_6\r1.6x3m  背景布    1 (黑色)'),(11164,683503679001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','3123michael','mokb4@hawaiiantel.net','Michael Okubo','3237 Francis St','Honolulu','HI','UNITED STATES','96815-4139','(808) 737-8904','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-09 08:36:25',0,NULL,3,1,1,1,NULL,'3123michael'),(11165,683505469001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','dlks2009','dvolsh@gmail.com','Dmitry Olshevskiy','207 Hreschatik St., #5','Chercassy','','UKRAINE','18000','380674736922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:44:55',0,NULL,3,1,2,1,NULL,'dlks2009'),(11166,724783532002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','chris0241','post@lizard-king.com','Chris Burton','10 Kingsway<br>Middleton','Manchester','Greater Manchester','UNITED KINGDOM','M24 1LS','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 08:59:25',0,NULL,3,1,2,1,NULL,'chris0241'),(11223,682160712018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','hkwinkle1991','hkwinkle@gmail.com','Holly Winkle','Unit 2/4 Sepia Crt Rockingham','Perth','Western Australia','AUSTRALIA','6168','0423618133','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-10 10:10:43',0,NULL,3,1,4,1,'YW865717640CN ','hkwinkle1991\rbackground support $25\r6月27日,补发一块1.6x2.1 白色背景布\rRA117720622CN'),(11167,682972209018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','orbostonian','admin@egipps.net','Rene Sundermann','77 Boundary Road','Orbost','Victoria','AUSTRALIA','3888','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-09 09:31:07',0,NULL,3,1,2,1,NULL,'orbostonian'),(11168,799935985015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','andrejanna','andrejanna@inbox.lv','Andrejs Muizulis','Atlantijas iela 32','Rīga','','LATVIA','LV1015','+37127020691','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 09:33:44',0,NULL,3,1,2,1,NULL,'andrejanna'),(11169,736911663017,270750677827,'New Camera shoulder bag D1 for Nikon D5000 D7000 D80',1,'AO0032',19.99,'photographyacc','mpbosman6719','mpbosman@hotmail.com','Mark Bosman','715 Wellington Ave. S.','Listowel','ON','CANADA','N4W 3S8','(519) 497-7085','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-09 10:44:58',0,NULL,3,1,3,1,'RA117773537CN ','mpbosman6719'),(11170,724807423002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','el_pelayo','mvaque@gmail.com','Jose Manuel Fontela Gómez','C/ Piscina, 3 2ºG','Espinardo - Murcia','Murcia','SPAIN','30100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 10:48:15',0,NULL,3,1,4,1,'YW865717544CN ','el_pelayo\rlight stand $20'),(11171,799963195015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','ahmad_s_asal','ahmad.s.asal@gmail.com','Ahmad Al-Joboori','Hamdan St. / BHS Bldg. / Penthouse / Heberger Eng.','Abu Dhabi','','UNITED ARAB EMIRATES','45262','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-09 11:06:25',0,NULL,3,1,3,1,'RA117773554CN ','ahmad_s_asal'),(11172,683006262018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','pvm1602','menssink@gmail.com','Paul Menssink','27 Bella Vista Close','Macleod','Victoria','AUSTRALIA','3085','0407223260','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-09 11:46:51',0,NULL,3,1,2,1,NULL,'pvm1602'),(11173,736866997017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','dilcine','dil_cine@yahoo.com','Dilan Jayathilaka','4/494 Glenferrie rd','Hawthorn','Victoria','AUSTRALIA','3122','0466597991','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-09 12:28:19',0,NULL,3,1,2,1,NULL,'dilcine'),(11174,724848069002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','aviramku','aviramkupfer@gmail.com','Aviram Kupfer','Hadas 1/10','Nesher','','ISRAEL','36791','972-52-8513425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 13:20:47',0,NULL,3,1,2,1,NULL,'aviramku'),(11175,724859500002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','arbeliko','arbel.levy@gmail.com','arbel  levy','hateenim 1','kiryat bialik','','ISRAEL','27063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 14:01:24',0,NULL,3,1,3,1,'RA117773466CN ','arbeliko'),(11176,683586460001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','yuly6774','yuli6774@hotmail.com','july alvarez','1221 sw 122nd ave apt 110','miami','FL','UNITED STATES','33184','(786) 443-4812','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 14:08:36',0,NULL,3,1,1,1,NULL,'yuly6774'),(11177,683590301001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','raibyn','raibyn@gmail.com','Raibyn Cabiling','1225 E Pennsylvania Ave','Escondido','CA','UNITED STATES','92027-3020','(619) 920-1160','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 14:23:14',0,NULL,3,1,1,1,NULL,'raibyn'),(11178,683593345001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','annaleigh89','annaleigh8889@yahoo.com','Annaleigh Ussery','6661 Perkins Circle','Macon','GA','UNITED STATES','31216','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 14:32:52',0,NULL,3,1,1,1,NULL,'annaleigh89\r1.6x2.1m 背景布   1 (黑)\r新地址：\rAnnaleigh Ussery\r558 BrAdy Drive, Apt. B\rFORT CAMPBELL, ky 42223\rUNITED STATES'),(11179,736979201017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','princejay07','quinslay@yahoo.com','AUGUSTE QUINSLAY','5 RUE MAMZELLE STE CROIX','Por Louis','','MAURITIUS','00230','2304919249','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-09 14:48:23',0,NULL,3,1,2,1,NULL,'princejay07'),(11180,724872260002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','pedrovicky','pesahuna@hotmail.com','Pedro Sahuquillo Navarro','Humanista Mariner, 11 pta 26','Valencia','Valencia','SPAIN','46018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 14:50:02',0,NULL,3,1,4,1,'YW865717533CN ','pedrovicky\rtripod  $20'),(11181,683598509001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','aczer65','czeranowski@post.pl','Andrzej Czeranowski','Derkaczy 54B','Warszawa','mazowieckie','POLAND','04-969','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 14:50:44',0,NULL,3,1,3,1,'RA117773829CN\r ','aczer65\r439'),(11183,724911369002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','uatumanroyal','leon_vavricuk@t-2.net','LEON VAVRICUK','UL.XIV.DIV. 8','RIMSKE TOPLICE','','SLOVENIA','3272','0038640680336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 16:38:30',0,NULL,3,1,2,1,NULL,'uatumanroyal'),(11184,724914550002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','zuckermacher','zuckermacher@gmx.de','Ralph Ziesmer','Zühlsdorfer Straße 38','Berlin','','GERMANY','12679','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 16:43:34',0,NULL,3,1,2,1,NULL,'zuckermacher'),(11185,800097963015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','emmett9890','je@bpr.org.uk','John Emmett','BPR Ltd, Teddington Studios','Teddington','Middlesex','UNITED KINGDOM','TW11 9NT','02086142535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-09 16:55:55',0,NULL,3,1,2,1,NULL,'emmett9890'),(11186,683650559001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','tobalseverin','cseverin.ad@gmail.com','Cristobal Severin','Villanelo Alto 522 casa 2','Viña del mar, Valparaíso','Valparaíso','CHILE','2520000','09 83378396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 17:22:25',0,NULL,3,1,2,1,' ','tobalseverin'),(11187,783688069016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','attekovacs80','attekovacs@gmail.com','Attila Kovacs','Becsi ut 130 III/4.','Budapest','Pest','HUNGARY','1034','36302820411','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 17:34:27',0,NULL,3,1,2,1,NULL,'attekovacs80'),(11188,683291160001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','abcmommy78','trisha878@yahoo.com','Trisha Johnson','112 S Main St','Blackwell','OK','UNITED STATES','74631-2943','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 18:33:37',0,NULL,3,1,1,1,NULL,'abcmommy78\r1.6x2.1m   背景布  1 (黑)'),(11189,800171595015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','chrisroun','chris.rounce@lineone.net','christopher rounce','15 manse close','doncaster','south yorkshire','UNITED KINGDOM','dn4 6qx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-09 19:07:25',0,NULL,3,1,2,1,NULL,'chrisroun'),(11190,683697318001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','des-hilache','deshilache@gmail.com','veronica martinez cabo','Plz. Cronista Chabret 23-3º','Sagunto','Comunidad Valenciana','SPAIN','46500','605325604','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-09 19:08:00',0,NULL,3,1,4,1,'YW865717522CN ','des-hilache\r申报: $25 , tripod'),(11191,724977819002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','rockfshr','jstgettinby@gmail.com','Lori Veneris','511 Lester Rd','Newport News','VA','UNITED STATES','23601','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 19:12:12',0,NULL,3,1,1,1,NULL,'rockfshr'),(11192,724978214002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','core-world','core_world_pro@hotmail.com','Corby Martin','1299 20th Street West','North Vancouver','BC','CANADA','V7P 2B8','(604) 345-4046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:12:23',0,NULL,3,1,3,1,'RA117773483CN ','core-world'),(11193,720904918002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bolshakov17','o.bolshakov@gmail.com','Oleg N Bolshakov','Lenina<br>house 151 office 506','Cherepovets','Vologodskaya area','RUSSIAN FEDERATION','162600','7(921)718-02-25','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:26:41',0,NULL,3,1,2,1,NULL,'bolshakov17'),(11194,683716128001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','juanan1971','juanan1971@yahoo.com','Juan Andres Pinar Feligreras','C/ Riera Blanca, 31, 1 - 1','BARCELONA','Barcelona','SPAIN','08028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:44:28',0,NULL,3,1,4,1,'YW865717511CN ','juanan1971\r申报: $25, Tripod'),(11195,683719004001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','bieterbauer','hlenz@web.de','Harald Lenz','Hauptstrasse 34','Üttfeld','','GERMANY','54619','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 19:49:00',0,NULL,3,1,2,1,NULL,'bieterbauer'),(11196,800199653015,250599390705,'58mm CPL Circular Polarizing Filter 58 CPL Green.L New',2,'AA3310',7,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 19:54:44',0,NULL,3,1,17,0,NULL,'pcooley63'),(11197,800201559015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.38,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','Eire','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-09 19:56:40',0,NULL,3,1,2,1,NULL,'pcooley63\r绿叶 CPL  58mm   2\r绿叶 CPL  52mm   1'),(11198,725018430002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','jbh','jharynuk@shaw.ca','Jack Harynuk','727 Larch Dr','Qualicum Beach','BC','CANADA','V9K 1H5','(250) 752-2163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 20:38:25',0,NULL,3,1,2,1,NULL,'jbh'),(11199,725042778002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','feresbe','fotoesberard@gmail.com','Fernando Esberard','R. Gal. Renato Paquet, 199 Bl.3 - 708','Rio de janeiro','Rio de Janeiro','BRAZIL','22973-060','(55)(21)9100-6661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 21:41:03',0,NULL,3,1,2,1,' ','feresbe'),(11200,683772464001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','tracey0412262603','tracey@thurmer.org','Tracey Ford','Landstadsgate 28','SANDEFJORD','','NORWAY','3210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-09 22:09:31',0,NULL,3,1,4,1,'YW865717566CN ','tracey0412262603\r欧标, 220v\r客户要求: Lightning kit , $34\r'),(11201,725054997002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','ss7shopper','shso7@hotmail.com','Shinichiro Soga','PO Box 642414','San Francisco','CA','UNITED STATES','94164-2414','(415) 260-6971','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-09 22:19:19',0,NULL,3,1,1,1,NULL,'ss7shopper'),(11202,800291723015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','rash*123','genrash@yahoo.co.uk','Rashmi Parmar','26 Carr manor Grove','Leeds','West Yorkshire','UNITED KINGDOM','LS17 5AJ','07763856871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-09 23:19:31',0,NULL,3,1,2,1,NULL,'rash*123'),(11203,683282165018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','nlight99','adamhauldren@gmail.com','Adam Hauldren','4, Moogerah Court<br>Albany Creek','Brisbane','Queensland','AUSTRALIA','4035','0731614306','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-10 00:36:28',0,NULL,3,1,3,1,'RA117773470CN ','nlight99'),(11204,725091428002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 01:03:23',0,NULL,3,1,17,0,NULL,'galtamirgal'),(11205,683810515001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 01:03:23',0,NULL,3,1,3,1,'RA117720809CN\r ','galtamirgal\r115w 5500k 灯泡  220v      1\rNG200 柔光罩       1\r-------------------------------------------------\r6重发一个115w 220v 灯泡给他\rRA117773700CN\r\r'),(11206,683289060018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','vivacycling','accounts@freshenterprises.com.au','Viva Cycling','107 Jefferson lane','Palm Beach','Queensland','AUSTRALIA','4221','0883612448','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-10 01:07:39',0,NULL,3,1,4,1,'YW865717555CN ','vivacycling\r2m 背景架  （ 白 黑）   1\rbackground support  $25'),(11207,683822932001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 01:55:16',0,NULL,3,1,3,1,'RA117773611CN\r ','saud-p'),(11208,683305884018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','summer_art_teacher','sbj09@bigpond.com','Summer Brook-Jones','26 Pauls Pde','Ellesmere','Queensland','AUSTRALIA','4610','0429621943','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-10 02:18:47',0,NULL,3,1,17,0,NULL,'summer_art_teacher'),(11209,683304378018,280667757262,'New Green.L 55mm Macro Close-up Filter +4',1,'AE3216',6.25,'photographyacc','summer_art_teacher','sbj09@bigpond.com','Summer Brook-Jones','26 Pauls Pde','Ellesmere','Queensland','AUSTRALIA','4610','0429621943','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-10 02:18:48',0,NULL,3,1,2,1,NULL,'summer_art_teacher\r绿叶近摄镜 +4  55mm     1\r背景布 1.6x2.1m      1 (白)'),(11210,725111082002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','rolf297','arnold_rodolfo@hotmail.com','Alejandro Arnold','Calle Italia 1370 piso 2 D','B1638BMV Vicente Lopez','Prov Buenos Aires','ARGENTINA','(1638)','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 02:23:43',0,NULL,3,1,2,1,NULL,'rolf297'),(11211,725113639002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','sorairo_eb','ednilson.obana@mandic.com.br','Ednilson Obana','Rua Raul Marques Marinho, 120','Sao Paulo','Sao Paulo','BRAZIL','04653-150','+55 (11) 71309563','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-10 02:35:18',0,NULL,3,1,5,1,'CP227189844CN ','sorairo_eb\r2m 背景架  +  1.6x2.1 绿色\r补发：\r背景架灯架上面的第一个夹子\rRA117777295CN\r'),(11212,737273435017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',2,'AC1201',11.36,'photographyacc','bluetoaster_45','bluetoaster45@hotmail.com','Bobby Nenadovic','32 Angela Drive','Hoppers Crossing','Victoria','AUSTRALIA','3029','0416030294','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-10 05:08:11',0,NULL,3,1,17,0,NULL,'bluetoaster_45'),(11213,737273655017,270750650619,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',2,'AC1202',11.76,'photographyacc','bluetoaster_45','bluetoaster45@hotmail.com','Bobby Nenadovic','32 Angela Drive','Hoppers Crossing','Victoria','AUSTRALIA','3029','0416030294','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-10 05:09:24',0,NULL,3,1,3,1,'RA117770853CN ','bluetoaster_45\r镜头筒 小号    2\r镜头筒 中号    2'),(11214,683865788001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','novot76','alex.novogrebelsky@gmail.com','alex novogrebelsky','2911 Oakwood Dr SW','calgary','AB','CANADA','t2v3y2','(403) 472-6352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 05:53:03',0,NULL,3,1,5,1,'CP227189901CN','novot76\r灯泡是110v的'),(11215,683347219018,280680856652,'New JYC-N1 Wireless Remote Control for Nikon D300s D700',1,'AA3201',18,'photographyacc','lacotah','bghollis@adam.com.au','Gary Hollis','559 Brodie Road','Huntfield Heights','South Australia','AUSTRALIA','5163','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-10 06:05:15',0,NULL,3,1,2,1,NULL,'lacotah'),(11216,682631218018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','tanman69blue','tanvir_22@hotmail.com','tanvir islam','5b chesham pde','glenfield','New South Wales','AUSTRALIA','2167','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-10 06:31:08',0,NULL,3,1,3,1,'RA117773832CN\r ','tanman69blue'),(11217,725154708002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','smooff2011','sm00ff@yandex.ru','Виталий Мартынов','ул. Мира, д. 19, кв. 187','Люберцы','Московская область','RUSSIAN FEDERATION','140006','8(926)399-63-96','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 06:37:06',0,NULL,3,1,2,1,NULL,'smooff2011'),(11218,725155707002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',5,'AB2301',49.75,'hermeshine','la-geria','liracoins@gmail.com','Albert Kabirov','Absalymova 23-28','Kazan','Tatarstan','RUSSIAN FEDERATION','420069','+79274327616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 06:43:00',0,NULL,3,1,3,1,'RA117773815CN\r ','la-geria'),(11219,683360764018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',2,'AE3101',76,'photographyacc','rhysmford','rmford_@hotmail.com','Rhys Ford','30 Wells St','Stepney','South Australia','AUSTRALIA','5069','0407151810','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-10 07:15:56',0,NULL,3,1,4,1,'YW865717651CN ','rhysmford\r'),(11220,725181794002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','aibru','adriaom@gmail.com','Adrià Ortiz','Francisco Giner 28 1-1','Gràcia - Barcelona','Cataluña','SPAIN','08012','655608557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 09:05:24',0,NULL,3,1,2,1,' ','aibru'),(11221,800434722015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','dprezes','michal.wojciga@gmail.com','Michał Wójciga','ul. Wł. Łokietka 236B/B3','Kraków','małopolskie','POLAND','31-334','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-10 09:12:24',0,NULL,3,1,5,1,'CP227125509CN ','dprezes'),(11222,737322934017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','grgroverenata','conti_75@hotmail.com','David Conti','Rundle Mall Pharmacy<br>151 Rundle Mall','Adelaide','South Australia','AUSTRALIA','5000','0408763144','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-10 09:13:55',0,NULL,3,1,3,1,'RA117773951CN ','grgroverenata\r澳标'),(11224,725197816002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mich_maz','michmaz@gmail.com','Michael Mazin','Hartzit 46/3-A','Netanya','','ISRAEL','42490','054-2050989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 10:17:21',0,NULL,3,1,2,1,NULL,'mich_maz'),(11225,800457245015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','123pelliott','peterell28@gmail.com','Peter Elliott','28 Farmhouse Close','Blackburn','Lancs','UNITED KINGDOM','BB1 2BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 10:26:11',0,NULL,3,1,2,1,NULL,'123pelliott'),(11226,725208725002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lukyfly','lucamajor@alice.it','Luca Majorano','Piazza Albania 15','Roma','RM','ITALY','00153','06.5750105','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-10 10:59:25',0,NULL,3,0,3,1,'RA117721336CN\r ','lukyfly\rcanon 老款背心 XXL   1(已入库）\r麂皮   2\r热靴保护盖  普通   5\rphoto  vest  $15'),(11227,683925791001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','lukyfly','lucamajor@alice.it','Luca Majorano','Piazza Albania 15','Roma','RM','ITALY','00153','06.5750105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 10:59:26',0,NULL,3,1,17,0,NULL,'lukyfly'),(11228,683925934001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',5,'AA1204',9.95,'hermeshine','lukyfly','lucamajor@alice.it','Luca Majorano','Piazza Albania 15','Roma','RM','ITALY','00153','06.5750105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 10:59:25',0,NULL,3,1,17,0,NULL,'lukyfly'),(11229,683412047018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','carmel44','carmenlaing@optusnet.com.au','Carmel Laing','44 Chesterfield RD','Penrith','New South Wales','AUSTRALIA','2750','0247364097','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-10 11:02:22',0,NULL,3,1,4,1,'YW865717636CN ','carmel44\rbackground support $25'),(11230,683921967001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','extraterrestrial2910','acidflight@yandex.ru','Dmitriy Strukov','Srednay Lugovaya 24','Kursk','Kurskaya oblast','RUSSIAN FEDERATION','305003','9045212604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 11:25:49',0,NULL,3,1,17,0,NULL,'extraterrestrial2910'),(11231,683427225018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',90,'photographyacc','soils1111','rapleybassett@iprimus.com.au','John C Rapley','PO Box 493','Seymour','Victoria','AUSTRALIA','3661','0357822544','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-10 11:59:55',0,NULL,3,1,4,0,'YW865717684CN ','soils1111\r反光板支架   2\r灯架    1\r新地址:\rJohn C Rapley\r11 Hanley Crescent Seymour, \rVictoria, 3660\rAUSTRALIA\r0357822544\r'),(11232,683426381018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','soils1111','rapleybassett@iprimus.com.au','John C Rapley','PO Box 493','Seymour','Victoria','AUSTRALIA','3661','0357822544','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-10 11:59:56',0,NULL,3,1,3,1,'RA117721866CN ','soils1111\rJohn C Rapley\r11 Hanley Crescent Seymour, \rVictoria, 3660\rAUSTRALIA\r0357822544'),(11233,725199979002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','gatalak2','profondosudct@tiscali.it','luca vitello','via scalia 24','Tremestieri Etneo','CT','ITALY','95030','3479519295','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 12:06:37',0,NULL,3,1,3,1,'RA117773885CN\r ','gatalak2\rClip   $5'),(11234,800493549015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','adamjcruiseevolution','adam@cruise-evo.co.uk','Adam Jones','15 Bedford Street<br>Bletchley','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK2 2TX','01908644349','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 12:21:31',0,NULL,3,1,3,1,'RA117721092CN','adamjcruiseevolution'),(11235,800496346015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','daydreamerswindows123','daydreamerswindows@live.com','Hayley Riordan','14 St michaels ave<br>bishops cleeve','cheltenham','Gloucestershire','UNITED KINGDOM','gl52 8nx','01242671092','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 12:27:15',0,NULL,3,1,2,1,NULL,'daydreamerswindows123'),(11236,683950613001,110583278265,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',6.9,'hermeshine','tracey0412262603','tracey@thurmer.org','Tracey Ford','Landstadsgate 28','SANDEFJORD','','NORWAY','3210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 12:29:08',0,NULL,3,1,2,1,NULL,'tracey0412262603'),(11237,683965949001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','7759dimitrov','ivailo.dimitrov@gmail.com','Ivailo  Dimitrov','Manastirski livadi, bl.12A vh.A et.3 ap.18','Sofia','Sofia','BULGARIA','1404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 13:30:11',0,NULL,3,1,2,1,NULL,'7759dimitrov'),(11238,683970719001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',2,'AA3210',8.36,'hermeshine','olegskod','utkin2009@gmail.com','Oleg Utkin','Shmidta 45-97','Murmansk','','RUSSIAN FEDERATION','183038','+79113046592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 13:42:03',0,NULL,3,1,2,1,NULL,'olegskod'),(11239,683969723001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','a-luisete','afinolira@yahoo.com','Angel Afino','praga<br>3 1A','alcorcon','Madrid','SPAIN','28922','634339157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 13:47:48',0,NULL,3,1,4,1,'YW865717614CN ','a-luisete\rtripod $25'),(11240,682420546001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',39.9,'hermeshine','vaizdostudija','uab@vaizdostudija.com','Arunas Eimulis','Tulpiu 13-3','Klaipeda','','LITHUANIA','91210','+370 673 92399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 13:50:16',0,NULL,3,1,3,1,'RA117721089CN\r ','vaizdostudija\r欧标'),(11241,683690280001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',89.16,'hermeshine','extraterrestrial2910','acidflight@yandex.ru','Dmitriy Strukov','Srednay Lugovaya 24','Kursk','Kurskaya oblast','RUSSIAN FEDERATION','305003','9045212604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 14:26:11',0,NULL,3,1,5,1,'CP227189994CN','extraterrestrial2910\r肩架   2\r80cm 5in1 反光板   2'),(11242,800550026015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','06050028','theodre@gmail.com','Theodore Kallergis','7 kells place<br>Stanwix','Carlisle','Cumbria','UNITED KINGDOM','CA39DT','07596468023','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 14:51:44',0,NULL,3,1,3,1,'RA117773996CN ','06050028'),(11243,684008367001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','yukoss','kostyura@gmail.com','Viktor Soloviov','Morozenka str 1/160','Ternopil','','UKRAINE','46016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 15:43:41',0,NULL,3,1,2,1,NULL,'yukoss'),(11244,684012676001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','edom.eu','edom.ltd.eu@gmail.com','Marin Naydenov','prof.N Mihailov 6<br>ap.16 -E DOM OOD-','Sofia','','BULGARIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 15:56:10',0,NULL,3,1,2,1,NULL,'edom.eu'),(11245,781814495016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','harveylyndon','lyndonharvey@aol.com','Westdex Ltd','unit c1 Yelverton Business Park, Crapstone,','Yelverton','Devon','UNITED KINGDOM','PL20 7PE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-08 11:30:08',0,NULL,3,0,18,0,'RA117722380CN ','harveylyndon'),(11246,725337757002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','fahilanweri','haddip@gmail.com','Fahil Anweri','Hjortevegen 42','Nannestad','Nannestad','NORWAY','2030','48142849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 17:54:58',0,NULL,3,1,3,1,'RA117774002CN ','fahilanweri'),(11247,684058422001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','eddy_dc','info@eddydc.be','Eddy De Coster','Ricardplein 17','Deinize','','BELGIUM','9800','32498391890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 18:00:20',0,NULL,3,1,3,1,'RA117721075CN ','eddy_dc'),(11248,800638579015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','honeysuckleboy','edwards_jonathan@btinternet.com','Jonathan Edwards','Honeysuckle Cottage<br>6 Red Hill, Camerton','Bath','Somerset','UNITED KINGDOM','BA2 0NY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 18:04:05',0,NULL,3,1,2,1,NULL,'honeysuckleboy'),(11249,725356766002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bocha55','bosha@list.ru','Yury Bochkov','Obukhovskoy Oborony street, 111 ap 4','Saint-Petersburg','SZFO','RUSSIAN FEDERATION','192029','911-151-90-90','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 18:40:28',0,NULL,3,1,2,1,NULL,'bocha55'),(11250,800662325015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','petaverde','ebay@petaverde.co.uk','Geoff Wilkins','5 Gilwell Grove','Telford','Shropshire','UNITED KINGDOM','TF2 9SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 18:49:46',0,NULL,3,1,2,1,NULL,'petaverde'),(11251,725362477002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','88gubeikou','dalucg@shaw.ca','G. William Trimble','Suite 204<br>312 Village Way','Qualicum Beach','BC','CANADA','V9K 2H8','(250) 752-9283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 18:58:44',0,NULL,3,1,2,1,NULL,'88gubeikou'),(11252,735388789017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','trifon_2112','alexbezdicek@yahoo.es','Alex Bezdicek','Alde Zaharra 24','Lekunberri','Navarra','SPAIN','31870','948604630','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-10 19:35:41',0,NULL,3,1,2,1,NULL,'trifon_2112'),(11253,684110636001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','stereobuff48','byron4878@yahoo.com','BYRON K EVANS','187 S Villa Ave','ELMHURST','IL','UNITED STATES','60126-3030','','NoPaymentFailure','CheckoutComplete','Other','2011-06-10 20:07:03',0,NULL,3,0,1,1,NULL,'stereobuff48\r2XL(已入库)'),(11254,725262576002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','max1972sub','mferrantino1@alice.it','Massimiliano Ferrantino','2°trav. taverna campanile n.2','monteforte irpino','AV','ITALY','83024','3807258880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 20:51:17',0,NULL,3,1,2,1,NULL,'max1972sub'),(11255,683634017018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','valentinocrossi','valbntin@tpg.com.au','Damien Cross','c/o Bailin Compters<br>115 Newcastle Road','East Maitland','New South Wales','AUSTRALIA','2323','0249348411','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-10 21:06:27',0,NULL,3,1,2,1,NULL,'valentinocrossi'),(11256,800741363015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jaelithe0','saperring@talktalk.net','sarah perring','43 Camperdown rd','salcombe','Devon','UNITED KINGDOM','TQ88BN','01548842713','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-10 21:28:37',0,NULL,3,1,2,1,NULL,'jaelithe0'),(11257,683644621018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','dazndan1982','danndaz@bigpond.com','Daniel Elias','12 Hauff Close<br>Eagleby','Brisbane','Queensland','AUSTRALIA','4207','0738072671','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-10 21:38:25',0,NULL,3,1,4,1,'YW865717603CN ','dazndan1982\rbackdrop support $25\r'),(11258,684160381001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',32.98,'hermeshine','mrtcal','outland2001@hotmail.com','reginald burrus','110 E 22nd St<br>Ste 400','Norfolk','VA','UNITED STATES','23517-2319','','NoPaymentFailure','CheckoutComplete','Other','2011-06-10 22:38:24',0,NULL,3,1,3,1,'RA117721061CN ','mrtcal'),(11259,684160393001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','krysterkk','kaisercast@msn.com','ka kit leung','#329 - 5600 Andrews road','richmond','BC','CANADA','V7E 6N1','(778) 898-3003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-10 22:38:52',0,NULL,3,1,3,1,'RA117721225CN\r ','krysterkk\r'),(11260,683676018018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','emilymcn1981','mcnaughton.emily@gmail.com','Emily McNaughton','70 Nepean Street','Watsonia','Victoria','AUSTRALIA','3085','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'emilymcn1981'),(11261,737641545017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',65,'photographyacc','rosscataldo','ross@cataldo.com.au','Dodo Australia - Ross Cataldo','L14, 600 St Kilda Rd','Melbourne','Victoria','AUSTRALIA','3004','1300725095','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-11 00:57:00',0,NULL,3,1,4,1,'YW865717592CN ','rosscataldo\rtripod $25\r----0627,客户来信说,已经收到.'),(11262,724802947002,120570270849,'YONGNUO WIRELESS REMOTE CORD FOR SONY RM-S1AM A700',1,'AA3214',25,'hermeshine','xxlwurschtel','niharo@sunrise.ch','Horst Pfingsttag','Espili 12','Schleitheim','','SWITZERLAND','8226','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 01:04:35',0,NULL,3,1,2,1,NULL,'xxlwurschtel'),(11263,725488404002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','lekcej','tugolukoff@gmail.com','Aleksey Tugolukov','ul. Kuibisheva, d.55, k.6','Kaliningrad','','RUSSIAN FEDERATION','236041','+79527993234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 02:24:15',0,NULL,3,1,3,1,'RA117773925CN ','lekcej'),(11264,737660563017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','jianyangaus','adslk0yu@tpg.com.au','JIAN YANG','Unit 6, 596 NEERIM RD, HUGHESDALE','MELBOURNE','Victoria','AUSTRALIA','3166','0422839786','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-11 02:26:14',0,NULL,3,1,2,1,NULL,'jianyangaus'),(11265,737662218017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','tommo20001','toms@connexus.net.au','Tom Sargant','34 Queens Avenue','Caulfield East','Victoria','AUSTRALIA','3145','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-11 02:33:57',0,NULL,3,1,2,1,NULL,'tommo20001'),(11266,684004732001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',206.98,'hermeshine','vrisa*0*','classic_of_love_vrisa@hotmail.com','Varisa Prukhatthapong','NOP Place (Room 313)<br>290 M.4 Bangna-Garden Rd.','T.Bangbor A.Bangbor','Samutprakran','THAILAND','10560','(668) 681-4972 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 02:48:53',0,NULL,3,1,6,1,'EE520583508CN ','vrisa*0*\r英标, 220v(已入库)\r背景架 2x1.6m    1\r背景布 2x1.6m    3  (白+灰+粉)\r柔光箱 50-70cm 单灯头   2\r2m 灯架   2\r115w 5500k 灯泡  220v    2\r灯架包     1\r'),(11267,725504619002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','son.truong','son.truong@bigpond.com','Son Truong','B2/88-98 Marsden Street','Parramatta','New South Wales','AUSTRALIA','2150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 03:54:22',0,NULL,3,1,17,0,NULL,'son.truong'),(11268,684224249001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','dvk73','d.kolyadko@gmail.com','Dzmitry Kalyadka','kalinina 15 / 57','Dzerginsk','Minsk dstr','BELARUS','222720','+375297764361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-11 04:24:15',0,NULL,5,1,18,0,NULL,'dvk73'),(11269,737698320017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','tngo8','bi_chocolate89@yahoo.com','Thuc-Tram Ngo','14 weldon street<br>birkdale','brisbane','Queensland','AUSTRALIA','4159','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-11 06:05:41',0,NULL,3,1,2,1,NULL,'tngo8'),(11270,725525885002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','elisd2','larrydee@netspace.net.au','Larry Devenish','11 Nathan Close<br>Hoppers Crossing','Melbourne','Victoria','AUSTRALIA','3029','0392795774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 06:16:59',0,NULL,3,1,2,1,NULL,'elisd2'),(11271,725529421002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','mieki1973','pmiekina@gmail.com','PIOTR MIEKINA','4824 N Damen Ave<br>Apt 404','CHICAGO','IL','UNITED STATES','60625-1477','(773) 742-9314','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 06:38:50',0,NULL,3,1,1,1,'RA117721150CN\r----\rLK009591375CN\r ','mieki1973\r第一次挂号小包的状态不对，用e邮宝重发'),(11272,684241970001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','son.truong','son.truong@bigpond.com','Son Truong','B2/88-98 Marsden Street','Parramatta','New South Wales','AUSTRALIA','2150','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-11 06:24:18',0,NULL,3,1,3,1,'RA117773982CN ','son.truong\r斜臂     1\r大力夹    1'),(11273,737713245017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','jemcor','corjem@bigpond.com','Craig Stevens','Foster\'s Australia<br>cnr Darlington Drive and Cuthbert Street Yatala','Brisbane','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTracking','2011-06-11 07:35:28',0,NULL,3,1,4,1,'YW865717581CN ','jemcor\rtripod $25\r'),(11274,683818730018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',70,'photographyacc','dordtenaar.111','john.kuiters@gmail.com','John Kuiters','PO Box 926','Tamworth','New South Wales','AUSTRALIA','2340','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-11 11:02:26',0,NULL,3,1,4,1,'YW865717706CN ','dordtenaar.111\rreflector holder  $20\r'),(11275,784502006016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','atom916','anthony.emmett@orange.fr','Anthony Emmett','42 rue de la Barrière','La Mothe St Héray','Poitou-Charentes','FRANCE','79800','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-11 11:06:04',0,NULL,3,1,2,1,NULL,'atom916'),(11276,800952387015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','boueur','ian.suewright@tiscali.co.uk','ian wright','184 dinerth road','colwyn bay','Conwy','UNITED KINGDOM','LL284UP','01492540081','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-11 11:07:10',0,NULL,3,1,2,1,NULL,'boueur'),(11277,725592273002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tompiqacha','lzoli@yahoo.com','Zoltán Lőrinczi','Szent László út 143. II/30.','Budapest','Pest','HUNGARY','1131','+36-30-9998086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 11:11:41',0,NULL,3,1,2,1,NULL,'tompiqacha'),(11278,684310555001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',8.2,'hermeshine','vinkopr','vinko@email.com','Vinko Prenkocaj','ul 27 mart br 1','Podgorica','ME','MONTENEGRO','20000','+38267575971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 11:23:19',0,NULL,3,1,17,0,NULL,'vinkopr'),(11279,684299867001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vinkopr','vinko@email.com','Vinko Prenkocaj','ul 27 mart br 1','Podgorica','ME','MONTENEGRO','20000','+38267575971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 11:23:19',0,NULL,3,1,2,1,NULL,'vinkopr\r绿叶 ND8  77mm   1\r反光板  80cm 5合1   1'),(11280,683823882018,280666847645,'Nikon Original Photo Vest D3s D3x D300s D700 D90 XL',1,'AA2112',60,'photographyacc','jodoformica','jodoformica.ebay@katamail.com','Carlo Rondelli','Corso Garibaldi 74','Cremona','CR','ITALY','26100','3400083560','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-11 11:26:37',0,NULL,3,1,3,1,'RA117721305CN\r ','jodoformica\r摄影背心 Nikon 原厂 XL\r申报 photo vest  $15'),(11281,725600922002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',63.78,'hermeshine','rockstar_simon','simonwhyte@hotmail.com','Simon Whyte','130B / 361-363 Kent Street','Sydney','New South Wales','AUSTRALIA','2000','0414712052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 11:43:08',0,NULL,3,1,4,1,'YW865717695CN ','rockstar_simon\rboom arm $25'),(11282,725605798002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','enlisette','lis1_svensson@hotmail.com','Lisette Svensson','Eksjögatan 31','Jönköping','Jönköping','SWEDEN','554 54','0046704489953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 12:00:55',0,NULL,3,1,2,1,NULL,'enlisette'),(11283,725627844002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','taffpike','taffpike@hotmail.com','Alan Pike','13 Alma Court<br>Bramcote','Nuneaton','Warwickshire','UNITED KINGDOM','CV11 6QQ','01455220173','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-11 13:17:03',0,NULL,3,0,3,1,'RA117721058CN\r ','taffpike\rXL(已入库)'),(11284,683862891018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','shannuu','shannu.0505@gmail.com','shannu palamuru','12/115, Knox street, watson, canberra','canberra','Australian Capital Territory','AUSTRALIA','2602','0433300143','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-11 13:24:46',0,NULL,3,1,2,1,NULL,'shannuu'),(11285,684354391001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','stuz10yun','yun10@singnet.com.sg','Chris Lim','Blk 183 Jelebu Road #17-42','default','','SINGAPORE','670183','98287232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 13:50:50',0,NULL,3,1,17,0,NULL,'stuz10yun'),(11286,684354638001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','stuz10yun','yun10@singnet.com.sg','Chris Lim','Blk 183 Jelebu Road #17-42','default','','SINGAPORE','670183','98287232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 13:50:50',0,NULL,3,1,11,1,NULL,'stuz10yun\r绿叶 渐变镜 77mm   1\r绿叶 渐变镜 67mm   1'),(11287,784563993016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','mctarakan','oportunity@mail.ru','Sergei Mistsuk','15 Ashfield<br>Raheen','Limerick','Limerick','IRELAND','LK','0857707470','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-11 13:58:26',0,NULL,3,1,2,1,NULL,'mctarakan\r注意是2只'),(11288,684355485001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ahmetakduman','ahmetakduman@windowslive.com','hasan duygu','olukbasi ilkogretim okulu','Bozdogan','Aydin','TURKEY','09760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 14:23:08',0,NULL,3,1,2,1,NULL,'ahmetakduman'),(11289,725658961002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','sks-ak-man','fleastop@yahoo.com','James Heiden','6055 Malloy Ave','Ferndale','WA','UNITED STATES','98248-9354','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 14:47:08',0,NULL,3,1,1,1,NULL,'sks-ak-man'),(11290,684385438001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','ron8786ron','ron8786@gmail.com','ron schwarz','pika 26','petah tikva','israel','ISRAEL','49611','972544904891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 15:20:27',0,NULL,3,1,3,1,'RA117721044CN\r ','ron8786ron'),(11291,737860362017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','samellemby','sam@ellemby.com','Sam Reich','ELLEMBY RESOURCES<br>67 Bulwer Street','MAITLAND','New South Wales','AUSTRALIA','2320','0418402644','NoPaymentFailure','CheckoutIncomplete','AU_SmallParcelWithTracking','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA117721027CN\r ','samellemby'),(11292,725676639002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','13horsepower','iacovoutheodora@gmail.com','Theodora Iacovou','8, Arch. Makariou Mahairiote','Larnaca','Larnaca','CYPRUS','6051','+357 99486518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 15:37:29',0,NULL,3,1,3,1,'RA183619724CN\r\r ','13horsepower\r6月12号的单号：RA117721340CN\r\r补发一个配件给他，我来准备'),(11293,725677533002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','13horsepower','iacovoutheodora@gmail.com','Theodora Iacovou','8, Arch. Makariou Mahairiote','Larnaca','Larnaca','CYPRUS','6051','+357 99486518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 15:39:11',0,NULL,3,1,3,1,'RA117721353CN\r ','13horsepower\r'),(11294,684410635001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','rustemsteamru','steamru@yandex.ru','Rustem Musairov','Rossiyskaya<br>dom 43, korpus 4, kv 25','Ufa','Bashkortostan','RUSSIAN FEDERATION','450104','79174350204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 16:27:20',0,NULL,3,1,3,1,'RA117721234CN ','rustemsteamru'),(11295,725696959002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','rustemsteamru','steamru@yandex.ru','Rustem Musairov','Rossiyskaya<br>dom 43, korpus 4, kv 25','Ufa','Bashkortostan','RUSSIAN FEDERATION','450104','79174350204','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-11 16:29:14',0,NULL,3,1,3,1,'RA117721129CN\r ','rustemsteamru\r'),(11296,801093480015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','anje4000','ali.idrissi-sbai@uwclub.net','ali idrissi-sbai','DEERNESS  PARK MEDICAL CENTRE<br>SUFFOLK STREET','SUNDERLAND','TYNE AND WEAR','UNITED KINGDOM','SR2 8AD','01915670961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-11 16:46:13',0,NULL,3,1,2,1,NULL,'anje4000'),(11297,725713501002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tsdkarategrl','jbeatty@gmail.com','John Beatty','411 Perendale Dr','Red Lion','PA','UNITED STATES','17356-9607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-11 17:10:47',0,NULL,3,1,1,1,NULL,'tsdkarategrl'),(11298,683953004018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','pierandream','pierandrea.maxia@tiscali.it','Pierandrea Maxia','Via Calatafimi 47','Selargius','Cagliari','ITALY','09047','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-11 17:22:33',0,NULL,3,1,2,1,NULL,'pierandream'),(11299,725742902002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','vo_danh2dkny','cuoctinhxotxa2004@yahoo.com','Nam Ly','993 Dorchester Ave<br>Apt 2','Dorchester','MA','UNITED STATES','02125-1343','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-11 18:17:49',0,NULL,3,1,1,1,NULL,'vo_danh2dkny'),(11300,725797640002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','powshots','yoshishi29@hotmail.com','yoshi watanabe','2136 thomas park dr','nanaimo','BC','CANADA','V9X1K2','(250) 722-3841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 20:28:06',0,NULL,3,1,2,1,NULL,'powshots'),(11301,801214760015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',3,'AB1301',6.45,'hutongstore','dunjon7888','jcpelham@eircom.net','J.C.Pelham','19 Silversprings','Dungarvan','Co Waterford','IRELAND','','05845701','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-11 20:33:01',0,NULL,3,1,2,1,NULL,'dunjon7888\r注意是3个'),(11302,725809679002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','djspilerzzhu','djspilerzz@citromail.hu','Matuz István','Kút utca 132.','Debrecen','','HUNGARY','4028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 21:03:14',0,NULL,3,1,3,1,'RA117773979CN\r ','djspilerzzhu\r'),(11303,684529757001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','elamine67','ejegab@gmail.com','Roger Gagnon','1671 Lavoie # 3','Laval','QC','CANADA','h7m 2m9','(514) 274-1136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 21:13:34',0,NULL,3,1,2,1,' ','elamine67'),(11304,801248634015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','lesterwoodward','lester.woodward1@ntlworld.com','lester woodward','61 plains road<br>mapperley','nottingham','Nottinghamshire','UNITED KINGDOM','NG3 5QT','01159539830','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-11 21:46:51',0,NULL,3,1,2,1,NULL,'lesterwoodward'),(11305,725848521002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','fdkarl4u','kmaskos@rogers.com','Karl Maskos','22 Cannon Rd','Quispamsis','NB','CANADA','E2E3T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-11 23:05:35',0,NULL,3,1,2,1,NULL,'fdkarl4u'),(11306,801294065015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','paulh5665','paul_c_haines@hotmail.com','Paul Haines','The Old Bake House<br>Cheriton','Alresford','Hampshire','UNITED KINGDOM','SO24 0NQ','07733306194','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 00:07:21',0,NULL,3,1,2,1,NULL,'paulh5665'),(11307,684115129018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','schroederamos','luminiferousether@gmail.com','Adam Antonio','43 Yeramba St','Turramurra','New South Wales','AUSTRALIA','2074','0425290594','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-12 00:52:31',0,NULL,3,1,3,1,'RA117721265CN\r ','schroederamos\r1.6x2m   背景布  2 (黑+白)'),(11308,738098616017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','sagiboysibs','sibysibs@hotmail.com','siby itty','48 17th St<br>Apt D6','Jericho','NY','UNITED STATES','11753-2435','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-12 02:22:08',0,NULL,3,1,1,1,NULL,'sagiboysibs'),(11309,684622000001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','noi4220','jc_chaikaew@yahoo.com','Jarunee Chaikaew','4220 Simsburry Comm','Santa Ana','CA','UNITED STATES','92704','(714) 775-2970','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-12 03:53:27',0,NULL,3,1,1,1,NULL,'noi4220'),(11310,684163673018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','ericd5488','el_444@hotmail.com','Eric Dias','32 palmerston rd, Fairfield west','sydney','New South Wales','AUSTRALIA','2165','0404040554','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-12 05:21:16',0,NULL,3,1,2,1,NULL,'ericd5488\r背景布 1.6x2m  1(白)'),(11311,738129975017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','louie2006','louie206@bigpond.com','Luigi Barbera','42 GOLDEN GROVE CIRCUIT','TERRIGAL','New South Wales','AUSTRALIA','2260','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 05:31:15',0,NULL,3,1,2,1,NULL,'louie2006'),(11312,737755655017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','billbagger7','billyroberts7@gmail.com','Billy Roberts','12 Hurlingham St.','East Brighton','Victoria','AUSTRALIA','3187','0395306560','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-12 07:00:48',0,NULL,3,1,2,1,NULL,'billbagger7'),(11313,801399583015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','shoaibawan2010','shoaibawan@me.com','Shoaib Awan','35 Oaks Avenue','Romford','Essex','UNITED KINGDOM','RM5 3BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 07:43:55',0,NULL,3,1,2,1,NULL,'shoaibawan2010'),(11314,684194444018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','vantheyh','vanthey_heng@yahoo.com','Vanthey Heng','6 Emily Ct','Clarinda','Victoria','AUSTRALIA','3169','61421139017','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 07:52:45',0,NULL,3,1,17,0,NULL,'vantheyh'),(11315,684193714018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','chippy1530','hamers2@optusnet.com.au','eric lee','18 neville drive<br>wanneroo','perth','Western Australia','AUSTRALIA','6065','0893062439','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-12 07:53:39',0,NULL,3,1,3,1,'RA117773948CN ','chippy1530'),(11316,684195871018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','vantheyh','vanthey_heng@yahoo.com','Vanthey Heng','6 Emily Ct','Clarinda','Victoria','AUSTRALIA','3169','61421139017','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 07:57:49',0,NULL,3,1,2,1,NULL,'vantheyh\r方形滤镜接口环 72mm  1\r方形滤镜接口环 77mm  1\r普通托架  2'),(11317,684665726001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','manutdjo','mujjlouis@hotmail.com','Louis Joël','99a, Pouce St<br>Tranquebar','Port Louis','','MAURITIUS','00230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 08:03:16',0,NULL,3,1,3,1,'RA117721251CN\r ','manutdjo'),(11318,801415640015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','bebris19','kaspars.brivers@gmail.com','Kaspars Brivers','S.Eizensteina 71-96','Riga','','LATVIA','LV-1079','25557157','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-12 08:31:29',0,NULL,3,1,2,1,NULL,'bebris19'),(11319,801421238015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','chucholuis','serretmiralles@hotmail.com','jose luis serret miralles','plaza Nueva de San Anton 9 2º i','Murcia','Murcia','SPAIN','30009','626468151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-12 08:49:38',0,NULL,3,1,3,1,'RA117773917CN\r ','chucholuis'),(11320,684250571018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','yippiekaiay','crys_stew2005@hotmail.com','Crystal King','300 Linburn Lane','LINBURN','New South Wales','AUSTRALIA','2850','0401372872','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-12 10:34:18',0,NULL,3,1,3,1,'RA117721185CN\r ','yippiekaiay'),(11321,684259392018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',2,'AB1303',11.32,'photographyacc','industrial_dave_supreme','davidlongford@hotmail.com','David Longford','11 Ringtail Circuit','Blackbutt','New South Wales','AUSTRALIA','2529','0242969762','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 10:56:19',0,NULL,3,1,17,0,NULL,'industrial_dave_supreme'),(11322,738228780017,270746361119,'72mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 72 mm',1,'AB1306',5.66,'photographyacc','industrial_dave_supreme','davidlongford@hotmail.com','David Longford','11 Ringtail Circuit','Blackbutt','New South Wales','AUSTRALIA','2529','0242969762','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 10:58:04',0,NULL,3,1,2,1,NULL,'industrial_dave_supreme\r橡胶遮光罩 58mm  2\r橡胶遮光罩 72mm   1'),(11323,684264996018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','5839barryc','unumgar2@bigpond.com','BARRY COLLINS','UNUMGAR<br>385 LUNDS ROAD','MOURA','Queensland','AUSTRALIA','4718','0749962146','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 11:12:35',0,NULL,3,1,2,1,NULL,'5839barryc'),(11324,785032528016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lemaildetom','thomas.desalle@gmail.com','Thomas Desalle at Flaws\'s','8 old scapa road','kirkwall','Orkney','UNITED KINGDOM','kw15 1bb','07512244064','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 11:29:49',0,NULL,3,1,2,1,NULL,'lemaildetom'),(11325,684741378001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.6,'hermeshine','arthur_j61','arthur.yusupov@gmail.com','Artur Dzhigangerovich Yusupov','Radischeva Str, 152, Flat 7','Ulyanovsk','','RUSSIAN FEDERATION','432027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:38:43',0,NULL,3,1,3,1,'RA117773894CN\r ','arthur_j61\r欧标，看看是不是现在单灯头本身就是欧标头？'),(11326,726028896002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','yannsolo','yann.gourhant@france2.fr','Yann Gourhant','168 avenue Aristide Briand','Bagneux','-','FRANCE','92220','0674883509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 11:45:47',0,NULL,3,1,4,1,'YW865717673CN ','yannsolo\rreflector holder  $20\r'),(11327,684280600018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','throne538','winnalls@isage.net.au','Stephen Winnall','PO Box 319','Barmera','South Australia','AUSTRALIA','5345','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-12 11:49:09',0,NULL,3,1,2,1,NULL,'throne538'),(11328,684773561001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','tizziani18','emerson.tizziani@gmail.com','Emerson Tizziani','Rua Cruz Lima, 26<br>apto 301','Rio de Janeiro','Rio de Janeiro','BRAZIL','22230-010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 12:57:56',0,NULL,3,1,2,1,NULL,'tizziani18'),(11329,684312862018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','baggydude','theresamackin@hotmail.com','Theresa M Mackin','5 Tooronga Street','North Dandenong','Victoria','AUSTRALIA','3175','0397946681','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-12 13:06:28',0,NULL,3,1,3,1,'RA117721146CN\r ','baggydude'),(11330,684795717001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','monsardi','monsardi@pandora.be','peter monsaert','dendermondsesteenweg 477','Gent','','BELGIUM','9040','0477861709','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-12 13:50:19',0,NULL,3,1,17,0,NULL,'monsardi'),(11331,684796470001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',6,'AB1303',20.04,'hermeshine','photogear-ch','denis.linine@gmail.com','Denis  Linine','Neugutstrasse 7a','Wallisellen','','SWITZERLAND','8304','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 13:51:55',0,NULL,3,1,3,1,'RA117721217CN\r ','photogear-ch'),(11332,684797453001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.99,'hermeshine','monsardi','monsardi@pandora.be','peter monsaert','dendermondsesteenweg 477','Gent','','BELGIUM','9040','0477861709','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-12 13:54:10',0,NULL,3,1,3,1,'RA117721282CN\r ','monsardi\rNG128 柔光罩   1\r肩架   1'),(11333,801575819015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.99,'hutongstore','sohailyz','sohailyz@gmail.com','Sohail Yousafzai','Ericsson , Unit4 , Midelton Gate,<br>Guildford Busines Park,','Guildford','Surrey','UNITED KINGDOM','GU2 8SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 14:05:44',0,NULL,3,1,2,1,NULL,'sohailyz'),(11334,682898277018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','felicity_reilly','felicityreilly@yahoo.com.au','Felicity Reilly','7 Denebola Drive','Australind','Western Australia','AUSTRALIA','6233','0488120605','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-12 15:24:52',0,NULL,3,1,4,1,'YW865717662CN ','felicity_reilly\r'),(11335,684380238018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','gourrranga','gregory.zhukovsky@gmail.com','Gregory Zhukovsky','Ma\'ale Ort 46','Karmi\'el','','ISRAEL','21982','(972)546576902','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-12 15:28:27',0,NULL,3,1,3,1,'RA117773934CN\r ','gourrranga\r分成几个挂号小包发货\rRA117721923CN\rRA117721945CN'),(11336,684849384001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','chapsnap1','antolinez@gmail.com','Felipe Antolinez','Sennhauserweg 14','Zürich','','SWITZERLAND','8032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 15:39:01',0,NULL,3,1,3,1,'RA117721132CN\r ','chapsnap1\r2B柔   1\r反光板  80cm 5合1   1'),(11337,726130868002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','chapsnap1','antolinez@gmail.com','Felipe Antolinez','Sennhauserweg 14','Zürich','','SWITZERLAND','8032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 15:39:01',0,NULL,3,1,17,0,NULL,'chapsnap1'),(11338,726144419002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','famstor','famstory@mail.ru','Anatoly Epaneshnikov','Bluhera 32/1, k,718','Novosibirsk','','RUSSIAN FEDERATION','630092','952-925-21-21','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:01:58',0,NULL,3,1,3,1,'RA117721248CN\r ','famstor'),(11339,726148206002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mika.seppa','mika.seppanen@gmail.com','Mika Seppänen','Käenpolku 12 as 5','Paltamo','','FINLAND','88300','+358445035027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:07:12',0,NULL,3,1,3,1,'RA117721194CN\r ','mika.seppa'),(11340,785222439016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','silent_screaming_fencer','latvijas@gmail.com','ILJA PISCEVS','Saules 66-2','Daugavpils','','LATVIA','LV-5401','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-12 16:43:19',0,NULL,3,1,2,1,NULL,'silent_screaming_fencer'),(11341,684875040001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:44:32',0,NULL,3,1,3,1,'RA117721279CN\r ','saud-p\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子    1\r反光板支架    1\rRA117721937CN'),(11342,725830088002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-12 16:44:35',0,NULL,3,1,17,0,NULL,'saud-p'),(11343,726171413002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','iris_slootheer','iris_slootheer@hotmail.com','Iris Slootheer','Mercuriusstraat 15','Enschede','','NETHERLANDS','7521WP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 16:45:25',0,NULL,3,1,2,1,NULL,'iris_slootheer'),(11344,801690375015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','rmoss3475','qy@dr.com','Rob Moss','62 Stubbins Street<br>Ramsbottom','Bury','Lancashire','UNITED KINGDOM','BL0 0NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 16:52:01',0,NULL,3,1,2,1,NULL,'rmoss3475'),(11345,801747332015,250606686795,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2202',2.75,'hutongstore','monearn','camwellhouse@btinternet.com','Jeannette Cameron','Wellhouse Farm','MUIR OF ORD','Highland','UNITED KINGDOM','IV6 7SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 17:55:33',0,NULL,3,1,2,1,NULL,'monearn'),(11346,684966067001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','row-2008','roland.rollig@yahoo.com','Roland Röllig','28A Borgundvegen','Alesund','More og Romsdal','NORWAY','6003','(47)92885889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 18:28:35',0,NULL,3,1,3,1,'RA117721203CN\r ','row-2008\r挂号67,只比4px平邮贵￥4.5'),(11347,801794915015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','merlin_shropshire','martyn.musgrove@blueyonder.co.uk','Martyn Musgrove','29 Spoutway','Telford','Shropshire','UNITED KINGDOM','tf3 2hd','01952401165','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 18:43:05',0,NULL,3,1,2,1,NULL,'merlin_shropshire'),(11348,801832136015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',1.88,'hutongstore','bat650z','bat.coot@virgin.net','adam west','Dychwelfa<br>Waunfawr','Caernarfon','Gwynedd','UNITED KINGDOM','LL55 4YS','07876774912','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 19:18:09',0,NULL,3,1,2,1,NULL,'bat650z'),(11349,726317700002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jeanmarie445','requins_99@yahoo.fr','Jean-Marie DESMARTIS','13 rue des rosiers','Bourg la Reine','Île-de-France','FRANCE','92340','0675764150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 20:01:12',0,NULL,3,1,2,1,NULL,'jeanmarie445'),(11350,685046630001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','simbad52','simbad@videotron.ca','Gerald Morissette','140 de la Providence','Lachute','QC','CANADA','J8H3L5','(450) 562-8140','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-12 20:18:37',0,NULL,3,1,3,1,'RA117721115CN\r ','simbad52'),(11351,685064765001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1307',5.2,'hermeshine','swoo2836','sw3156@earthlink.net','Sharon Wood','944 Madrid Road','Waynesboro','VA','UNITED STATES','22980','(804) 543-6667','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-12 20:50:10',0,NULL,3,1,1,1,' ','swoo2836'),(11352,685070634001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','amfilip','a.m.filipovic@gmail.com','Antun Matija Filipovic','Mljekarska 7','Zagreb','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 21:21:43',0,NULL,3,1,2,1,NULL,'amfilip'),(11353,685086275001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','fernando5694','ferlaguna22@hotmail.com','Fernando Laguna Lopez','Sabino   nº22','Cañada Rosal','Sevilla','SPAIN','41439','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-12 21:37:20',0,NULL,3,1,2,1,NULL,'fernando5694'),(11354,801956560015,250692241834,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','2010ritaboo','marieprestleton@gmail.com','marie prestleton','121 alder drive<br>chelmsley wood','birmingham','West Midlands','UNITED KINGDOM','b37 7qg','07704081773','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 22:21:36',0,NULL,3,1,2,1,NULL,'2010ritaboo'),(11355,801966850015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','apr_042011','apr042011@live.com','m singh','29 cowdrey close','swindon','Wiltshire','UNITED KINGDOM','sn58jp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-12 22:54:33',0,NULL,3,1,2,1,NULL,'apr_042011'),(11356,684682710018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','teegz2108','teegz_88@hotmail.com','Teegan Rush','40 Laurence Way','Tarneit','Victoria','AUSTRALIA','3029','0399743252','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'teegz2108\reCheck结清再付款.\r'),(11357,801977943015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','maciej0305','dub3@wp.pl','Maciej Malinowski','5 Cameronian Court','Keighley','West Yorkshire','UNITED KINGDOM','BD21 5PW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 00:12:41',0,NULL,3,1,3,1,'RA117721177CN\r ','maciej0305'),(11358,738677551017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',3,'AA1206',8.7,'photographyacc','itcomau','detlev@itcommarketing.com','Detlev Litzkow','5/12 Baird St.','Tuncurry','New South Wales','AUSTRALIA','2428','0265549125','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-13 00:26:27',0,NULL,3,1,2,1,NULL,'itcomau'),(11359,685139573001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','chris_aycin','trackash@gmail.com','Guy Mor','29b Hertzog St. APT. 11','Givatayim','PW','ISRAEL','53602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 00:32:22',0,NULL,3,1,3,1,'RA117721035CN\r ','chris_aycin'),(11360,684693601018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','bphoto57','bphotousa@live.com','steve brudzinski','5 S Longyard Rd<br>Apt C4','southwick','MA','UNITED STATES','01077-9379','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-13 00:32:30',0,NULL,3,1,1,1,NULL,'bphoto57'),(11361,802014260015,250600521662,'Remote Control Cord Shutter Nikon D300/D200/D700​ MC-30',1,'AA3207',2.98,'hutongstore','davidous','davidbartle100@hotmail.com','David Bartle','20 Tenterden Road, Wincobank','Sheffield','South Yorkshire','UNITED KINGDOM','S5_6AJ','01142432082','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 00:55:49',0,NULL,3,1,2,1,NULL,'davidous'),(11362,738686540017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','flaviadorjo','flaviadorjo@hotmail.com','Flavia Pedra','Alameda da Serra,405','Nova Lima','Minas Gerais','BRAZIL','34000-000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-13 01:06:02',0,NULL,3,1,2,1,' ','flaviadorjo'),(11363,726458446002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mrtcw6','tcwluk@rogers.com','Thomas Luk','4080 Steeles Avenue East<br>Unit 8','Markham','ON','CANADA','L3R4C3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 02:07:15',0,NULL,3,1,5,1,'CP227125490CN ','mrtcw6'),(11364,802060439015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','litlechinatown','litlechinatown@gmail.com','Matthew Fisher','2235 Haste St<br>Apt A','Berkeley','CA','UNITED STATES','94704-2122','(562) 637-5166','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 03:05:30',0,NULL,3,1,1,1,NULL,'litlechinatown'),(11365,685192681001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','playing-by-heart39','jack4u1@hotmail.com','Yip Seng Lee','No3, Jalan PJS 9/4, Bandar Sunway','Sunway','Selangor','MALAYSIA','46150','0173610932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 03:43:07',0,NULL,3,1,2,1,' ','playing-by-heart39'),(11366,685200018001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','leslie821225','leslie_kjl@hotmail.com','koo jock lim','44,jalan enau,taman bukit belimbing','balakong','selangor','MALAYSIA','43300','012-9168999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 04:26:02',0,NULL,3,1,2,1,NULL,'leslie821225'),(11367,726498515002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','claudiojean','cji_5@hotmail.com','Claudio Inacio','644 Laguna Honda Blvd','San Francisco','CA','UNITED STATES','94127-1020','(415) 374-6388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 05:14:18',0,NULL,3,1,1,1,NULL,'claudiojean'),(11368,726500703002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','innostunutsonni','heikki.salovaara@kolumbus.fi','Heikki Salovaara','Ruskeeahteent. 16','Lempäälä','.','FINLAND','37550','050-3137646','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-13 05:27:01',0,NULL,3,1,3,1,'RA117770558CN ','innostunutsonni\r绿叶近摄镜 +8  77mm  换成 +4的'),(11369,738752339017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.88,'photographyacc','sterculias','dougt@powerup.com.au','Doug Thompson','120 Upper Camp Mountain Road','Camp Mountain','Queensland','AUSTRALIA','4520','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-13 05:29:32',0,NULL,3,1,2,1,NULL,'sterculias'),(11370,685221968001,110532007471,'HB-7 HB7 Lens Hood for Nikon AF 80mm-200mm f/2.8D NEW',1,'AA3403',9.8,'hermeshine','bugber','dgr002s@hotmail.com','LERPONG NILKHIEW','225/153 Prugsa Ville 1 , Moo6 , Tumbon Kukot<br>Ampher Lamlukka','default','PT','THAILAND','12130','66816559861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 06:48:21',0,NULL,3,1,17,0,NULL,'bugber'),(11371,726512529002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bugber','dgr002s@hotmail.com','LERPONG NILKHIEW','225/153 Prugsa Ville 1 , Moo6 , Tumbon Kukot<br>Ampher Lamlukka','default','PT','THAILAND','12130','66816559861','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 06:48:22',0,NULL,3,1,3,1,'RA117721778CN ','bugber\rHB-7 花瓣    1\rHB-7    1'),(11372,738781679017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','b35ty','b35ty@optusnet.com.au','Chris Best','1/23 Lane Cove Road','Ryde','New South Wales','AUSTRALIA','2112','0280347997','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-13 08:01:36',0,NULL,3,1,2,1,NULL,'b35ty'),(11373,685240639001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mika.seppa','mika.seppanen@gmail.com','Mika Seppänen','Käenpolku 12 as 5','Paltamo','','FINLAND','88300','+358445035027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 08:17:18',0,NULL,3,1,2,1,NULL,'mika.seppa\r2.1x1.6m  背景布   1 (黑)'),(11374,685251152001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 09:01:07',0,NULL,3,1,17,0,NULL,'jaimeluanco'),(11375,726542215002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','jaimeluanco','nico1967@ymail.com','JAIME GONZALEZ FERNANDEZ','LA CRUZ  37 BAJO A','LUANCO','Asturias','SPAIN','33440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 09:01:06',0,NULL,3,1,3,1,'RA117721852CN\r ','jaimeluanco\r50cm 棚  1\r80cm 5in1 反光板   1'),(11376,726546907002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 09:18:45',0,NULL,3,1,17,0,NULL,'cd11675'),(11377,684821483018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','fotodinida','danlukephotography@googlemail.com','Danijel Lukic','2/39<br>Bellevue Street','North Parramatta','New South Wales','AUSTRALIA','2151','0296304605','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-13 09:56:01',0,NULL,3,1,3,1,'RA117770840CN\r ','fotodinida'),(11378,684831756018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','tyronestacey','tyrone-stacey@hotmail.com','tyrone stacey','8/41 roseberry ave','manly vale','New South Wales','AUSTRALIA','2093','0417485149','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-13 10:30:16',0,NULL,3,1,4,1,'YW865717916CN ','tyronestacey\rreflector holder  $25'),(11379,785705946016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','tatu-pekka','tatupekka.heikkila@gmail.com','Tatu-Pekka Heikkilä Heikkilä','Ruovedenkatu 13 D 48','Tampere','Pirkanmaa','FINLAND','33720','0405402609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 10:36:15',0,NULL,3,1,17,0,NULL,'tatu-pekka'),(11380,785705786016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','tatu-pekka','tatupekka.heikkila@gmail.com','Tatu-Pekka Heikkilä Heikkilä','Ruovedenkatu 13 D 48','Tampere','Pirkanmaa','FINLAND','33720','0405402609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 10:36:15',0,NULL,3,1,2,1,NULL,'tatu-pekka\r眼罩 450D/500D   2'),(11381,685302768001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','mek2j','mek2j@buckeye-express.com','matthew kieper','258 jennings rd','rossford','OH','UNITED STATES','43460-1126','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-13 12:00:45',0,NULL,3,1,3,1,'RA117770164CN\r ','mek2j\r-已经收到好评'),(11382,685307696001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 12:21:28',0,NULL,3,1,17,0,NULL,'cd11675'),(11383,685307154001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 12:21:28',0,NULL,3,1,17,0,' ','cd11675'),(11384,726593589002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 12:21:28',0,NULL,3,0,17,0,NULL,'cd11675'),(11385,685299519001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-13 12:21:29',0,NULL,3,1,17,0,NULL,'cd11675'),(11386,684866394018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',29,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-13 12:24:48',0,NULL,3,1,3,1,'RA117721821CN\r ','tan6111'),(11387,726600885002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','vs_tanman','vstanman@virginbroadband.com.au','Vicente Sunel Tan','2/14 Silver Street','Randwick','New South Wales','AUSTRALIA','2031','0414846111','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-13 12:26:01',0,NULL,3,1,3,1,'RA117770822CN\r ','vs_tanman'),(11388,685311078001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 12:27:54',0,NULL,3,1,8,1,'CP227125486CN ','cd11675\r爵影红外 canon    1\r中号内胆包 无字   1\r45w 220v    4\r2m 宽背景架  1  \r1.6x2.1 背景布  3  （ 白  黑  绿）\r2m 灯架   2\r双灯头   2  欧标\r反光伞  2\r包   1\r'),(11389,685326554001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','michalina.dominik','dominik.michalina@gmail.com','Dominik Michalina','Chalupkova 155','CADCA','Zilinsky kraj','SLOVAK REPUBLIC','02204','+421910581940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 13:18:18',0,NULL,3,1,2,1,NULL,'michalina.dominik'),(11390,785769889016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','bolagraphy','balazskrisko@gmail.com','Balazs Krisko','No.7 Kinvara Close<br>GreenAcres','Donegal Town','Donegal','IRELAND','1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 13:26:52',0,NULL,3,1,2,1,NULL,'bolagraphy'),(11391,685334074001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','mtdanni','daniela.paulikova@gmail.com','Daniela Paulíková','Dominika Tatarku 7','Piestany','','SLOVAK REPUBLIC','921 01','00421911442114','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 13:42:17',0,NULL,3,1,2,1,NULL,'mtdanni'),(11392,685335599001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','thedaveshow','thedave100@gmail.com','David L Kerr Jr','808 Gladstell Rd<br>Apt 1208','Conroe','TX','UNITED STATES','77304-2785','','NoPaymentFailure','CheckoutComplete','Other','2011-06-13 13:47:58',0,NULL,3,0,1,1,NULL,'thedaveshow\rXXXL（已入库）'),(11393,685344488001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','cd11675','aalaqal@gmail.com','Abdallah Alaqal','P.Box 102204','Riyadh','','SAUDI ARABIA','11675','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 14:14:42',0,NULL,3,1,17,0,NULL,'cd11675'),(11394,802291637015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','simonok44','simontibi44@gmail.com','tibor simon','Bem József utca 33','Litér','alapértelmezés','HUNGARY','8196','06304771760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 15:24:15',0,NULL,3,1,2,1,NULL,'simonok44'),(11395,684932050018,280666892339,'New Green.L 62mm  Gradual Grey ND4 Filter 2-Stop 62 mm',1,'AA3318',6.6,'photographyacc','olibenny33','olibenny@hotmail.com','Olivier Beine','rue Soldat F. Charles 1','AUTRE-EGLISE','','BELGIUM','1367','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-13 15:36:27',0,NULL,3,1,2,1,NULL,'olibenny33'),(11396,802306523015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','houlihan2853','thoul@eircom.net','Thomas Houlihan','1,Avondale St.','Dingle, ','Kerry','IRELAND','1','0669151120','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 15:46:39',0,NULL,3,1,2,1,NULL,'houlihan2853'),(11397,726674096002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-13 15:59:08',0,NULL,3,1,3,1,'RA117721818CN\r ','dvdguychatter2'),(11398,726680196002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','aimrcaldron','caldron@bezeqint.net','Amir Calderon','HaCarcom 10','Neve Ziv','Israel','ISRAEL','25123','0776166167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 16:13:11',0,NULL,3,1,3,1,'RA117721906CN\r ','aimrcaldron'),(11399,685399867001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','sceptyk_031','vladislav.kovalchuk@gmail.com','Vladislav Covalciuc','Livezilor<br>31A','Stauceni','Chisinau','MOLDOVA, REPUBLIC OF','MD-4839','37379098532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 16:41:44',0,NULL,3,1,2,1,NULL,'sceptyk_031'),(11400,685402905001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','jamminhandbags','lesliesstyle@aol.com','Leslie Smith','2927 N Platina','Mesa','AZ','UNITED STATES','85215-1542','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-13 16:46:57',0,NULL,3,1,1,1,NULL,'jamminhandbags'),(11401,802341581015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','lordfreedom','lord_freedom@live.dk','Martin Wilsted','Gadegårdsvej 8','Hvornum','','DENMARK','9500','+45 29330264','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 16:53:38',0,NULL,3,1,3,1,'RA117770836CN\r ','lordfreedom'),(11402,685427038001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','folkestaderik','tuffeerik@hotmail.com','erik folkestad','reiakvam, 6260','skodje','møre og romsdal','NORWAY','6260','(+47) 92082891','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-13 17:37:38',0,NULL,3,1,3,1,'RA117721870CN\r ','folkestaderik'),(11403,726723885002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','teapot32','john@hohneckers.com','John Hohnecker','2200 Kennedy Road','Dubuque','IA','UNITED STATES','52002','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 17:53:36',0,NULL,3,1,1,1,NULL,'teapot32'),(11404,685435862001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','heatherangelchandler','heather@theimgstudio.com','Heather Angel Chandler','21252 Gathering Oak #100<br>IMG/Kimberly Howell Properties','San Antonio','TX','UNITED STATES','78260','(210) 464-6858','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-13 17:55:10',0,NULL,3,0,1,1,NULL,'heatherangelchandler\r52mm   2\r55mm   2\r58mm   2\r62mm   1\r67mm   1\r72mm   1\r77mm   1\r----\r新地址:\rAtt-- Heather Angel Chandler\rCompany-- IMG/Kimberly Howell Properties\rAdd--  21252 Gathering Oak #100\rSan Antonio TX 78260\rUNITED STATES\r(210) 464-6858'),(11405,726728936002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','danniek14','djanae18@aol.com','Danielle Kinney','503 Groton Rd','Freeville','NY','UNITED STATES','13068-9415','(607) 591-1064','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-13 18:02:00',0,NULL,3,1,1,1,NULL,'danniek14'),(11406,685441772001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','a3boost.th','a3boost@gmail.com','THERDSAK  WACHIRASAKSOPHANA','21/45 R.505 SOI CHAWAKUN<br>RANGNAM ROAD','RAJTHEVI','Bangkok','THAILAND','10400','(663)243-2468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 18:05:38',0,NULL,3,1,2,1,' ','a3boost.th'),(11407,685468558001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','knijz16','dominic_alba07@yahoo.com','dominic alba','179 E 213th St','Carson','CA','UNITED STATES','90745-1530','(310) 977-1006','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-13 18:55:54',0,NULL,3,1,1,1,NULL,'knijz16'),(11408,685525890001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','jkorni77','omase@otenet.gr','Ioannis Korlinis','RIGA FEREOU<br>35','PERAIA','Thessaloniki/Macedonia/Greece','GREECE','57019','00302392023356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 20:50:55',0,NULL,3,1,2,1,NULL,'jkorni77'),(11409,786028583016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','konharry','hazza1969@yahoo.co.uk','Stephen Harrison','14 Summerhill Green','Banbridge','Down','UNITED KINGDOM','BT32 3GY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-13 21:32:59',0,NULL,3,1,2,1,NULL,'konharry'),(11410,682585189018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','gabeimakefilms','gaberoxburgh@hotmail.com','Senator Gabe Roxburgh','P.O BOX 32','Woodburn','New South Wales','AUSTRALIA','2472','0266822655','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-13 22:59:25',0,NULL,3,1,2,1,NULL,'gabeimakefilms'),(11411,726869093002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','wabano52','jcjouiel@videotron.ca','Jean-Charles Joyal','20 pelletier','Gatineau','QC','CANADA','J8Z1C5','(819) 770-9999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-13 23:35:13',0,NULL,3,1,2,1,NULL,'wabano52'),(11412,786082923016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','zoniesis','diane.f.wood@gmail.com','Diane Wood','7524 N 31st Dr','Phoenix','AZ','UNITED STATES','85051','(602) 793-4885','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-13 23:57:23',0,NULL,3,1,1,1,NULL,'zoniesis'),(11413,739157167017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','tommo224','tommo_tom@hotmail.com','Thomas Williams at ITS Management','Level 8<br>55 Grafton St','Bondi Junction','New South Wales','AUSTRALIA','2022','0288987000','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-14 00:13:06',0,NULL,3,1,2,1,NULL,'tommo224'),(11414,681136567001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','fourmiel','alex.albert@gmail.com','Alexandre Albert','8270, Lajeunesse, #3','Montréal','QC','CANADA','H2P2E5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-08 11:41:04',0,NULL,3,1,3,1,'RA117721835CN\r ','fourmiel'),(11415,685179976018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','kajtekpis','kajtekpisarek@gmail.com','Wojciech Pisarek','18 David Avenue','Black Forest','South Australia','AUSTRALIA','5035','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 02:09:36',0,NULL,3,1,2,1,NULL,'kajtekpis'),(11416,739202633017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',3,'AA1310',17.85,'photographyacc','dirtywindow82','dirtywindow@iprimus.com.au','Colin Herbert','Shop 7/1 North Beach Road','North Beach','Western Australia','AUSTRALIA','6020','0894446437','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 03:01:17',0,NULL,3,1,2,1,NULL,'dirtywindow82'),(11417,685198347018,280685224536,'50x70cm 20\"x28\" Folding Easy Soft box  E27 Bulb Socket',2,'AE2401',70,'photographyacc','druce2004','nicoledruce@bigpond.com','N. Druce','9 Kelmscott way','St Clair','New South Wales','AUSTRALIA','2759','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 03:31:07',0,NULL,3,1,3,1,'RA117770663CN ','druce2004\r澳标'),(11418,685194911018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT004',113,'photographyacc','rasaji','rasasilver@yahoo.com','Rasa Jamyang c/o Tsering Samdup','Friends Shop/ Cafe<br>Distt. Kangra','Bir, Tibetan Colony','HP','INDIA','17 60 77','919805408892','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-14 03:37:18',0,NULL,3,1,8,1,'CP227125472CN ','rasaji\r再加115w 220v 灯泡 2个'),(11419,726929103002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','mirrocle','pyry.hurula@uta.fi','Pyry Hurula','Hameenpuisto 9 A 3','Tampere','FI','FINLAND','33210','+358400666697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 03:59:03',0,NULL,3,1,2,1,NULL,'mirrocle'),(11420,685634306001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','sx70s201','loutianzhi@live.ca','TIANZHI LOU','809 - 96 St Patrick Street','TORONTO','ON','CANADA','M5T1V2','(416) 887-0731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 04:03:49',0,NULL,3,0,2,1,NULL,'sx70s201'),(11421,685210373018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','c-zine','chrismddrn@gmail.com','Chris Maddern','101 Chandlers Hill Road','O\'Halloran Hill','South Australia','AUSTRALIA','5158','0883846161','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-14 04:37:20',0,NULL,3,1,17,0,NULL,'c-zine'),(11422,685211362018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','c-zine','chrismddrn@gmail.com','Chris Maddern','101 Chandlers Hill Road','O\'Halloran Hill','South Australia','AUSTRALIA','5158','0883846161','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-14 04:42:50',0,NULL,3,1,2,1,' ','c-zine\rNG128 柔光罩    1\r绿叶 CPL  77mm     1'),(11423,739224811017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','kwijibo79','rtnewton@gmail.com','Ryan Newton','503 Milne Road','Ridgehaven','South Australia','AUSTRALIA','5097','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 05:08:46',0,NULL,3,1,2,1,NULL,'kwijibo79'),(11424,739234099017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','pyaarnalini','miss.fruitnalini@yahoo.com','Sara Uduwela','16 Winderadeen Ct.','Nerang','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 05:53:39',0,NULL,3,1,2,1,NULL,'pyaarnalini'),(11425,739241338017,270758475500,'Photo Studio translucent white umbrella soft 85cm /33\" ',1,'AD1402',7.8,'photographyacc','slowboat02','slowboat@iprimus.com.au','David Rowland','34 Sierra Ave','Bateau Bay','New South Wales','AUSTRALIA','2261','0243331036','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 06:35:00',0,NULL,3,1,17,0,NULL,'slowboat02'),(11426,739240650017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','slowboat02','slowboat@iprimus.com.au','David Rowland','34 Sierra Ave','Bateau Bay','New South Wales','AUSTRALIA','2261','0243331036','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-14 06:35:01',0,NULL,3,1,17,0,NULL,'slowboat02'),(11427,685229333018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','slowboat02','slowboat@iprimus.com.au','David Rowland','34 Sierra Ave','Bateau Bay','New South Wales','AUSTRALIA','2261','0243331036','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-14 06:35:02',0,NULL,3,1,17,0,NULL,'slowboat02'),(11428,685228636018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT004',78,'photographyacc','slowboat02','slowboat@iprimus.com.au','David Rowland','34 Sierra Ave','Bateau Bay','New South Wales','AUSTRALIA','2261','0243331036','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-14 06:35:02',0,NULL,3,1,4,1,'YW865717732CN ','\rslowboat02\r澳标\rlighting kit  $20\r------\r柔光伞   1\r肥皂盒 柔光罩   580EX    1\r反光板 60cm 2合1    1\r灯架  2m    1\r柔光箱 50-70cm 单灯头    1\r斜臂    1\r115w 5500k 灯泡  220v    1\r灯架包      1'),(11429,685659759001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','bhabdija','bozimir@gmail.com','Božidar Habdija','Slavka Kolara 8','Krizevci','','CROATIA','48260','+38548682969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 06:41:38',0,NULL,3,1,2,1,NULL,'bhabdija'),(11430,685660868001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','night.tea0','night_tea0@yahoo.com','Kwek Soon Hang','Blk 145, Potong Pasir<br>Ave 2, #10-66','default','','SINGAPORE','350145','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 06:46:38',0,NULL,3,1,11,1,NULL,'night.tea0'),(11431,726978470002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','saginov','timur_saginov@mail.ru','Timur Saginov','Proectnyi<br>19/1','Karagandy','','KAZAKHSTAN','100019','+7-7212-419062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 08:45:44',0,NULL,3,1,2,1,NULL,'saginov'),(11432,685258199018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mum_n_me','tanyamstuart@gmail.com','T M Stuart','48 Freshwater Drive','Berrinba','Queensland','AUSTRALIA','4117','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-14 09:08:21',0,NULL,3,1,17,0,NULL,'mum_n_me'),(11433,685258436018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','mum_n_me','tanyamstuart@gmail.com','T M Stuart','48 Freshwater Drive','Berrinba','Queensland','AUSTRALIA','4117','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 09:08:21',0,NULL,3,1,4,1,'YW865717872CN ','mum_n_me\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1\r背景布 2.1x1.6m    1 (粉色)\r'),(11434,802721059015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','jakinens','jakinens@hotmail.com','David Gallego Sánchez','C/Yugoslavia Nº7 2ºB','Leganes','Madrid','SPAIN','28916','916883808','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-14 10:05:53',0,NULL,3,1,2,1,NULL,'jakinens'),(11435,685306500018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','offand','andsoff@gmail.com','Andrew Offield','284 Warringah Road','Beacon Hill','New South Wales','AUSTRALIA','2100','0292400745','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-14 12:06:07',0,NULL,3,1,2,1,NULL,'offand'),(11436,685735873001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','nirsarignir','nir_sarig1@walla.co.il','nir sarig','amirim<br>12','tel aviv','north tel aviv','ISRAEL','69357','0544775228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 12:24:59',0,NULL,3,1,3,1,'RA117770116CN\r ','nirsarignir'),(11437,727032322002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bakryhernan','ducat_88@hotmail.com','hernan villanueva','77 orton park rd.','scarborough','ON','CANADA','m1g 3g7','(647) 339-4562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 12:33:59',0,NULL,3,1,2,1,NULL,'bakryhernan'),(11438,685366086001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','vassilisa81','vassilisa@one.lv','Katerina Lebedeva','Aleksandra 9-4','Ventspils','','LATVIA','LV3601','29648453','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 12:59:16',0,NULL,3,1,2,1,NULL,'vassilisa81'),(11439,685746998001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','4809linda','lindasphotoshop@yahoo.com','Linda Finley','21 McLendon Rd','Fort mitchell','AL','UNITED STATES','36856-5412','(334) 855-1256','NoPaymentFailure','CheckoutComplete','Other','2011-06-14 13:04:18',0,NULL,3,0,1,1,NULL,'4809linda\rXL(已入库)'),(11440,684652952001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','hernsell','hernsell88@hotmail.com','Filip Hernsell','Stora Hammars Bygata 2','HÖLLVIKEN','Skåne','SWEDEN','23691','0046736987879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 13:17:21',0,NULL,3,1,2,1,NULL,'hernsell'),(11441,685756982001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.99,'hermeshine','v40fenbg','muggsy@abv.bg','Veselin Nikolov','18.Silivria str.','Plovdiv','Plovdiv','BULGARIA','4000','+35988837238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 13:38:46',0,NULL,3,1,2,1,NULL,'v40fenbg'),(11442,685770015001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','hotukai','ebay@kevkev.com','John Phillip Vallespin','St. Oliver\'s Dormitory<br>V. Castro - V. Neri St.,','Cagayan De Oro City','','PHILIPPINES','9000','(323) 668-1423','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-14 14:23:49',0,NULL,3,1,6,1,'EE506555568CN ','hotukai\r2m 灯架   2\r双灯头   2\r反光伞   2\r灯架包   1\r\r背景架2x2m  1\r夹子    3\r背景布 1.6x2.1m   2 (白+黑)'),(11443,727067598002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','hotukai','ebay@kevkev.com','John Phillip Vallespin','St. Oliver\'s Dormitory<br>V. Castro - V. Neri St.,','Cagayan De Oro City','','PHILIPPINES','9000','(323) 668-1423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 14:34:50',0,NULL,3,1,17,0,NULL,'hotukai\r2m 灯架   2\r双灯头   2\r反光伞   2\r灯架包   1\r\r背景架2x2m  1\r背景布1.6x2.1m   1\r夹子    3\r背景布 1.6x?m   2\r'),(11444,727080493002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.99,'hermeshine','vaclav4671','kftpvenca@seznam.cz','Vaclav Sraut','Sladovnicka 422','Vysoke Myto','Europe','CZECH REPUBLIC','56601','420 465 422571','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 15:16:20',0,NULL,3,1,2,1,' ','vaclav4671'),(11445,739380241017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-14 15:19:49',0,NULL,3,1,2,1,NULL,'tan6111'),(11446,786353078016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','em4dog','groomperfect@aol.com','emma grigg','29 high street<br>camelford','camelford','Cornwall','UNITED KINGDOM','pl329pq','01840212514','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 15:52:30',0,NULL,3,1,2,1,NULL,'em4dog'),(11447,727098427002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sjon2427','sljjones44@hotmail.com','Sam Jones','11889 Helmer Lane','San Diego','CA','UNITED STATES','92131','(858) 395-4494','NoPaymentFailure','CheckoutComplete','Other','2011-06-14 16:06:17',0,NULL,3,0,1,1,NULL,'sjon2427\r2XL(已入库)'),(11448,727118910002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','pdaroseturkey','pdarose@hotmail.com','HUSEYIN BOSTANCI','PK.32','SEYDISEHIR','KONYA','TURKEY','42370','+903325821062','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 17:02:19',0,NULL,3,1,2,1,NULL,'pdaroseturkey'),(11449,685827370001,110658438313,'Remote Shutter Release Cord for Canon 40D 50D 5DII RE-A',1,'AA2219',4.68,'hermeshine','wirez1234','sawtooth@gawab.com','Sharandran Chandra','Blk 698c hougang st.52<br>#14-29','default','','SINGAPORE','533698','98304254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 17:07:58',0,NULL,3,1,11,1,' ','wirez1234'),(11450,685821308001,110445658830,'YONGNUO LCD Timer Remote Control for Sony RM-S1AM A700',1,'AA3223',48.9,'hermeshine','saint1118','blibby1014@hotmail.com','Brian Libby','178 Kinsley St<br># B','Nashua','NH','UNITED STATES','03060-3650','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 16:53:13',0,NULL,3,1,1,1,NULL,'saint1118'),(11451,727123268002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',1,'AA3202',18.5,'hermeshine','sfcjkjoseph','sfcjkjoseph@yahoo.com','John K Joseph','1714 Piedmont Way','Burlington','NC','UNITED STATES','27217-4256','(336) 266-2989','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-14 17:14:15',0,NULL,3,1,1,1,NULL,'sfcjkjoseph'),(11452,727132871002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47-30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-14 17:47:01',0,NULL,3,1,3,1,'RA117770195CN\r ','arnorolf10'),(11453,685862131001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','mkhitar73','gel73@mail.ru','Mkhitar Hovhannisyan','Lernagorcner st. 16/30','Qajaran','Syunik','ARMENIA','3309','+37491223355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 18:26:57',0,NULL,5,0,18,0,NULL,'mkhitar73\rSAL可以到,要248元'),(11454,685881958001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',3,'AC3301',43.68,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 19:13:02',0,NULL,3,1,3,1,'RA117770178CN\r ','nixette_nixette'),(11455,802958664015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',63.99,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-14 19:21:59',0,NULL,3,1,4,1,'YW865717883CN ','leifs123\r欧标\r$20 light kit\r'),(11456,802964233015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','nicky3371','nickygit@blueyonder.co.uk','Nicola Gittings','101 Harper Avenue, Wednesfield','Wolverhampton','West Midlands','UNITED KINGDOM','WV11 1HD','01902560493','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-14 19:30:38',0,NULL,3,1,2,1,NULL,'nicky3371'),(11457,684828656001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',2.95,'hermeshine','tuskenification','alexander.vbrandt@gmail.com','alexander v brandt','myrmalmsvägen 13','Nybro','kalmar län','SWEDEN','38293','0722763283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 19:41:10',0,NULL,3,1,2,1,NULL,'tuskenification'),(11458,685917795001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','mechborira2005','mechbor@yahoo.com','Boris Mechnikov','Mark Hasman 39','Beer sheva','','ISRAEL','84899','972-54-6162258','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 20:24:49',0,NULL,3,1,2,1,NULL,'mechborira2005'),(11459,685928503001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jourmano','jourmani@yahoo.com','Rami Katzav','#50 Melchet street','Tel-Aviv','','ISRAEL','64287','972-54-7828322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 21:10:31',0,NULL,3,1,3,1,'RA117770181CN\r ','jourmano\r肩架    1\r大力夹云台    1'),(11460,727096100002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','jourmano','jourmani@yahoo.com','Rami Katzav','#50 Melchet street','Tel-Aviv','','ISRAEL','64287','972-54-7828322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 21:10:32',0,NULL,3,1,17,0,NULL,'jourmano'),(11461,727238381002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','sboisvert1364','boisvertsylvie@videotron.ca','Sylvie Boisvert','2460 Boul. Lafontaine<br>Condo# 402','St-Jerome','QC','CANADA','J7Y 5L2','(450) 592-1895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-14 21:23:04',0,NULL,3,1,2,1,NULL,'sboisvert1364'),(11462,685547156018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',7.28,'photographyacc','gordillologo','jm8588@hotmail.com','jose manuel  tejada collado','2250 NW 114th AVE<br>unit 1A (10187)','miami','FL','UNITED STATES','33172-3652','(305) 471-0000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-14 22:11:28',0,NULL,3,1,1,1,NULL,'gordillologo'),(11463,803061062015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','maxim17171','maxim17171@gmail.com','massimiliano burzio','reg. borgovecchio 11','villafranca d\'asti','AT','ITALY','14018','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-14 22:40:05',0,NULL,3,1,2,1,NULL,'maxim17171'),(11464,685558115018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','wennberg1','geirw@netcom.no','Geir Ivar Wennberg','hjelms vei 18 a<br>5063','Bergen','bergen','NORWAY','5063','+47 92011133','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-14 22:48:17',0,NULL,3,1,17,0,NULL,'wennberg1\r'),(11465,739580346017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','wennberg1','geirw@netcom.no','Geir Ivar Wennberg','hjelms vei 18 a<br>5063','Bergen','bergen','NORWAY','5063','+47 92011133','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-14 22:53:09',0,NULL,3,1,2,1,NULL,'wennberg1\rCANON 镜头盖  58mm   1\r6片装的滤镜袋    1'),(11466,685992563001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','aftasi','antogo@hotmail.es','antonio gonzalez carretero','plaza del progreso 7A Estanco','badajoz','Extremadura','SPAIN','06007','675808286','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 00:35:50',0,NULL,3,1,4,1,'YW865717861CN ','aftasi\r申报: $25 , tripod\r0630-0712YW系统显示收到'),(11467,727287306002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',14.39,'hermeshine','chris_aycin','trackash@gmail.com','Guy Mor','29b Hertzog St. APT. 11','Givatayim','PW','ISRAEL','53602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 01:31:10',0,NULL,3,1,3,1,'RA117770399CN\r ','chris_aycin\r柔光伞    1\r无字肩带    1'),(11468,727305692002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','divinepassion1','divinepassion@hotmail.com','Jason Hamshaw','307 Screven St','Georgetown','SC','UNITED STATES','29440-3645','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 01:38:46',0,NULL,3,1,1,1,NULL,'divinepassion1'),(11469,727184645002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','hawgmanjr','hawgman@mycoppr.com','Michael Hopper','329 Columbia Ave','Lansdale','PA','UNITED STATES','19446','(215) 362-7709','NoPaymentFailure','CheckoutComplete','Other','2011-06-15 01:45:43',0,NULL,3,0,1,1,NULL,'hawgmanjr\r3XL(已入库)'),(11470,686020668001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',3,'AE1401',111.9,'hermeshine','geco1968','videos@gecoproducciones.cl','Gerardo Campos Pelayo','San Eugenio #1085 depto. 11-A','santiago','santiago','CHILE','7750000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 02:35:00',0,NULL,3,1,5,1,'CP227125469CN ','geco1968'),(11471,685611021018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',68,'photographyacc','tibbi9','afay@iinet.net.au','Amanda Fay','Shop 3, 1 Resort Place<br>Gnarabup','Margaret River','Western Australia','AUSTRALIA','6285','0897571266','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-15 02:36:05',0,NULL,3,1,4,1,'YW865717894CN ','tibbi9\r0630-0712YW系统显示,已签收'),(11472,685628421018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','nursesonly','sales@nursesonly.com.au','bronwyn lord','3 the terrace','watanobbi','New South Wales','AUSTRALIA','2259','0243534212','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-15 04:07:28',0,NULL,3,1,2,1,NULL,'nursesonly'),(11473,739656069017,270748510307,'NIB TianYa Gradual grey Color Filter for Cokin P series',1,'AA2322',7.29,'photographyacc','sterculias','dougt@powerup.com.au','Doug Thompson','120 Upper Camp Mountain Road','Camp Mountain','Queensland','AUSTRALIA','4520','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-15 04:15:08',0,NULL,3,1,2,1,NULL,'sterculias'),(11474,727345329002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','netshopper5','rhm250@hawaii.rr.com','Ronald Murabayashi','2301 Kanealii Ave.','Honolulu','HI','UNITED STATES','96813','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-15 04:58:56',0,NULL,3,1,1,1,NULL,'netshopper5'),(11475,727349446002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','comey647','urbkris@yahoo.ca','Kris Urban','70 Dundas St. East','Toronto','ON','CANADA','M5B 1C7','(647) 201-1003','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 05:25:32',0,NULL,3,1,5,1,'CP227125441CN ','comey647\r美标\r背景布 (2.1x1.6m   x1   白色)\r灯泡是110v的'),(11476,739670216017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','justaddh2o','clintgreentree@hotmail.com','Clinton Greentree','1/11 Lorne St<br>Alderly','Brisbane','Queensland','AUSTRALIA','4051','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-15 05:32:36',0,NULL,3,1,2,1,NULL,'justaddh2o'),(11477,803176208015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vincetoro','viciotoro@gmail.com','Vincenzo Santoro','Via Paladini 280','Caltanissetta','CL','ITALY','93100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 06:12:31',0,NULL,3,1,2,1,NULL,'vincetoro'),(11478,685653461018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','hugochaparro','juice2getloose@hotmail.com','Hugo Chaparro','3-90 Coogee Bay Road<br>Coogee','Coogee','New South Wales','AUSTRALIA','2034','0416171212','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-15 06:38:37',0,NULL,3,1,3,1,'RA117770337CN\r ','hugochaparro'),(11479,803191183015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','krisisx','krisis5311@abv.bg','Krasimir Yordanov','1 Josif Daynelov str.','Rousse','Rousse','BULGARIA','7016','00359899975571','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 07:18:20',0,NULL,3,1,2,1,NULL,'krisisx'),(11480,786692886016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','mastixmastix','cristianbaitg@cristianbaitg.com','Nuria Florenza Gellida','Pg Ferrocarrils Catalans 27 bajos','Cornella de LLobregat','Barcelona','SPAIN','08940','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 07:19:26',0,NULL,3,1,3,1,'RA117770310CN\r ','mastixmastix'),(11481,739692663017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','determan','determans@gmail.com','halil ibrahim tanriverdi','Girisim Pazarlama<br>GOSB 1000. sk. No:1028 ','Gebze','Kocaeli','TURKEY','41480','+902626771111','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-15 07:32:03',0,NULL,3,1,5,1,'CP227125438CN','determan'),(11482,686074425001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','willzpogee','willypogi@rocketmail.com','Willy Pajayat','Blk 417 Canberra Rd #02-365','default','','SINGAPORE','750417','98230792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 07:45:32',0,NULL,3,1,11,1,NULL,'willzpogee'),(11483,739697579017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','fitzabroad','fitzabroad@aapt.net.au','John FitzGerald','27 Albert Road','Warrandyte','Victoria','AUSTRALIA','3113','0398442727','PayPalPaymentInProcess','CheckoutComplete','AU_SmallParcels','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'fitzabroad'),(11484,684122678018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',10,'AC2403',300,'photographyacc','lianajustin-2008','lianajustin@virginbroadband.com.au','Liana Tarr','4 Opal Court','Caboolture','Queensland','AUSTRALIA','4510','0754951145','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-15 08:13:00',0,NULL,3,1,4,1,'YW866011345CN ','lianajustin-2008'),(11485,685685983018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT004',83,'photographyacc','garseklis','garseklis@gmail.com','Andrius Paulavicius','Maumedziu 8-13','Vilniaus','','LITHUANIA','08309','37067341036','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-15 09:12:58',0,NULL,3,1,5,1,'CP227125455CN ','garseklis\r欧标'),(11486,686095074001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','skn.zaman','skn_zaman@yahoo.com','Shoukat Zaman Khan','UNASCO Building, Al Qouz Ind. Area<br>Behind Emirates Glass Factory','Dubai','Dubai','UNITED ARAB EMIRATES','73042','00971508525135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 09:37:04',0,NULL,3,1,2,1,NULL,'skn.zaman'),(11487,727396376002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','segreto7474','claudioriggio@libero.it','Claudio Riggio','Via madonna in campagna 43','gallarate','varese','ITALY','21013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 09:40:35',0,NULL,3,1,2,1,NULL,'segreto7474'),(11488,727398127002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',21.96,'hermeshine','d_autohaus','d.autohaus@mail.ru','Evgeny Volkov','Konstitutsyi str. 17-139','Krasnoyarsk','Krasnoyarsky kray','RUSSIAN FEDERATION','660049','+79135345525','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 09:58:18',0,NULL,3,1,3,1,'RA117774104CN\r ','d_autohaus'),(11489,685697106018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','grillsy54','iangrills@bigpond.com','Ian Grills','22 Cluny Road','Armidale','New South Wales','AUSTRALIA','2350','0428689087','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-15 09:59:20',0,NULL,3,1,2,1,NULL,'grillsy54'),(11490,686103486001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','geoffreychow79','geoffreychow79@yahoo.com','Geoffrey chow','Blk 227 serangoon ave 4 #11-01','default','','SINGAPORE','550227','93372681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:03:33',0,NULL,3,1,11,1,NULL,'geoffreychow79'),(11491,685860085001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','5848alainb','lods.denise@yahoo.fr','alain bocquillon','37 rue docteur mas','maraussan','Languedoc-Rousillon','FRANCE','34370','0467903439','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 10:07:30',0,NULL,3,1,3,1,'RA117774020CN\r ','5848alainb'),(11492,686109176001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','alexsomapala','e_alexlanka@yahoo.com','Alex Somapala','209/1,Gangasirigama,<br>Teldeniya','Kandy','','SRI LANKA','20900','+94776004782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 10:28:04',0,NULL,3,1,2,1,NULL,'alexsomapala'),(11493,686123281001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','niemalshier','wirwarenniemalshier@yahoo.es','Raquel Leton','Av. Monforte de Lemos 165, 11-1','Madrid','Madrid','SPAIN','28029','913863684','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 11:22:16',0,NULL,3,1,4,1,'YW864488933CN ','niemalshier'),(11494,727425595002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','the.shaman.king.1','jean-francois.host@laposte.net','Jean-François HOST','Résidence Boffrand<br>Domaine des Jardins','SARREBOURG','Lorraine','FRANCE','57400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 11:39:03',0,NULL,3,1,3,1,'RA117774047CN\r ','the.shaman.king.1'),(11495,686128949001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',10,'AB1301',33.4,'hermeshine','rodcar007','rodrigo@linxaut.com.br','Rodrigo Cararo','Rua Jose Bonifacio, 882<br>Bairro Cruzeiro','Caxias do Sul','Rio Grande do Sul','BRAZIL','95074-240','+55 054 32285664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 11:45:51',0,NULL,3,1,3,1,'RA117774033CN\r ','rodcar007'),(11496,803284416015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','nordicimport','pridemman@yahoo.com','Eugene Glynn','Mollevn 7','Bjorkelangen','Akershus','NORWAY','N-1940','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 12:29:51',0,NULL,3,1,2,1,NULL,'nordicimport'),(11497,739776092017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','tipti.chy','tipti.cheung@gmail.com','Kevin Cheung Ho Yan','130, Currie Hall, Winthrop Avenue, Crawley','Perth','Western Australia','AUSTRALIA','6009','','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTracking','2011-06-15 12:49:06',0,NULL,3,1,4,1,'YW864488955CN ','tipti.chy\rtripod $20'),(11498,686157810001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',11,'AA3307',47.85,'hermeshine','fotoglobal7070','fotoglobal@gmail.com','Ivan Sanches','Av Pedroso de Morais 99','Sao Paulo','São Paulo','BRAZIL','05419-000','11.81347070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 13:22:55',0,NULL,3,1,2,1,NULL,'fotoglobal7070'),(11499,686159246001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','ayaw28','wind2aya@gmail.com','Aya Windmuller','Ahad ha Am ST 120<br>APT 9','Tel Aviv','AL','ISRAEL','65208','972525323617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 13:28:46',0,NULL,3,1,2,1,NULL,'ayaw28'),(11500,686168136001,110407145231,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','brads_legend','bdt22@earthlink.net','brad d thompson','15816 Fairfield Dr','matthews','NC','UNITED STATES','28104-2209','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-15 13:57:09',0,NULL,3,1,1,1,NULL,'brads_legend'),(11501,686175709001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','eakluck','hutecommerce@gmail.com','Ekkaluk Worathamrong','343 Soi Onnut 70/1<br>Prawet','Prawet','Bangkok','THAILAND','10250','662-321-6032','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 14:24:24',0,NULL,3,1,3,1,'RA117774055CN\r ','eakluck'),(11502,686179989001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','edom.eu','edom.ltd.eu@gmail.com','Marin Naydenov','prof.N Mihailov 6<br>ap.16 -E DOM OOD-','Sofia','','BULGARIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 14:37:46',0,NULL,3,1,2,1,NULL,'edom.eu'),(11503,727485627002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','johntoth','darkroom@bellsouth.net','The Darkroom','3600 Frederica Rd<br>Ste 5','Saint Simons Island','GA','UNITED STATES','31522-1380','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 15:05:29',0,NULL,3,1,1,1,NULL,'johntoth'),(11504,727493543002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','peros941','per.oster87@gmail.com','Per Öster','rosengatan 6','Linköping','östergötland','SWEDEN','58432','0768949982','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 15:28:21',0,NULL,3,1,3,1,'RA117770368CN\r ','peros941'),(11505,727499140002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','gcam1886','giorgio.camponeschi@hotmail.it','Giorgio Camponeschi','Via Angelo Emo 131','Roma, Italy','RM','ITALY','00136','3394173127','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 15:44:05',0,NULL,3,1,3,1,'RA117770411CN\r ','gcam1886\rlight stand  $16'),(11506,685805392018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','kristoferskog','info@digitalfoto.se','Kristofer Skog','Stationsgatan 19A','Borlänge','Dalarna','SWEDEN','78433','070-466 21 25','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-15 15:50:56',0,NULL,3,1,3,1,'RA117774078CN\r ','kristoferskog'),(11507,686205746001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','rmsoares','rafael.msoares@terra.com.br','Rafael Mello','Estrada do Pau Ferro 378 Bloco 2 Apto 405 Pechincha','Rio de Janeiro','Rio de Janeiro','BRAZIL','22743051','55 21 24261305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 15:54:00',0,NULL,3,1,17,0,NULL,'rmsoares'),(11508,803367859015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',1.88,'hutongstore','2011adamc','adam.col30@hotmail.com','Adam Colbeck','27 slaithwaite avenue<br>thornhill lees','dewsbury','West Yorkshire','UNITED KINGDOM','wf12 9dh','01924522817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 15:55:38',0,NULL,3,1,2,1,NULL,'2011adamc'),(11509,686206906001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rmsoares','rafael.msoares@terra.com.br','Rafael Mello','Estrada do Pau Ferro 378 Bloco 2 Apto 405 Pechincha','Rio de Janeiro','Rio de Janeiro','BRAZIL','22743051','55 21 24261305','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 15:57:15',0,NULL,3,1,2,1,NULL,'rmsoares\r肥皂盒 柔光罩  430EX   1\r反光板  80cm 5合1       1'),(11510,686208710001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','ahboytutu','ahboytutu@yahoo.com','Mark Tan','Blk 121 Paya Lebar Way #06-2825','default','','SINGAPORE','381121','(659) 010-1328','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 16:04:32',0,NULL,3,1,3,1,'RA117774585CN\r ','ahboytutu\r反光板  80cm 5合1    1\r大力夹云台    2'),(11511,739843987017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','andrewayling123456789','andrewayling30@hotmail.com','Andrew Ayling','2/19 Midway Street<br>Midway Point','Hobart','Tasmania','AUSTRALIA','7171','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-15 16:09:49',0,NULL,3,1,2,1,NULL,'andrewayling123456789'),(11512,686210262001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','ahboytutu','ahboytutu@yahoo.com','Choon Eng Tan','900 SE Centerpointe Dr<br>Apt P103','CORVALLIS','OR','UNITED STATES','97333-3220','(541) 714-1234','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-15 16:12:28',0,NULL,3,1,17,0,NULL,'ahboytutu\r\r发到新加坡的地址 \r\r'),(11513,739863753017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',13.8,'photographyacc','patrick.kenny','tap1000441@gmail.com','Patrick Kenny','63 Woodstock Ave<br>Apt 3','Brighton','MA','UNITED STATES','02135-7624','(617) 331-1316','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-15 16:51:11',0,NULL,3,1,1,1,NULL,'patrick.kenny'),(11514,686235482001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','globalweb','dbukworld@hotmail.com','David Brown','Heath Farm<br>Whites Lane','Weston','Crewe, Cheshire','UNITED KINGDOM','CW2 5NN','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 17:12:35',0,NULL,3,0,3,1,'RA117770439CN\r ','globalweb\rXXXL (已入库）'),(11515,727546164002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','danil163','dansbox@inbox.ru','Danil Khasianov','ul.Stara-Zagora<br>d.224 kv.89','Samara','Samarskaya obl','RUSSIAN FEDERATION','443095','+79277139662','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 17:45:50',0,NULL,3,0,3,1,'RA117770442CN\r ','danil163\rL （已入库）'),(11516,803425238015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','tosualdo','tomas.mandak@gmail.com','Tomas Mandak','Moskovska 29','Banska Bystrica','','SLOVAK REPUBLIC','97404','421-907-041594','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 17:49:50',0,NULL,3,1,3,1,'RA117770425CN\r ','tosualdo'),(11517,686266661001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nazmal','kamini1540@yahoo.ca','malek Hosany','176 clairfonds rd no1 vacoas<br>Mauritius','vacoas-phoenix','','MAURITIUS','40056','7745102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 18:30:31',0,NULL,3,1,3,1,'RA117774081CN\r ','nazmal'),(11518,683957834018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','11ron1960','ron.vdbosch@live.nl','Ron van den Bosch','Purmerweg 26','Amsterdam','','NETHERLANDS','1023BA','06-54207805','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-15 18:42:55',0,NULL,3,0,3,1,'RA117774064CN\r ','11ron1960'),(11519,803494058015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','norberg1990','angieskaniner@hotmail.com','Angelica Norberg','Nektarvägen 18','Skärplinge','Skärplinge','SWEDEN','81930','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 19:39:29',0,NULL,3,1,17,0,NULL,'norberg1990'),(11520,803495497015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',12.99,'hutongstore','norberg1990','angieskaniner@hotmail.com','Angelica Norberg','Nektarvägen 18','Skärplinge','Skärplinge','SWEDEN','81930','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 19:41:18',0,NULL,3,1,3,1,'RA117770371CN\r ','norberg1990\r圆形柔光棚 60cm    1\r圆形柔光棚 40cm    1'),(11521,686306961001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','tripwired25','p.elzinga01@chello.nl','Elzinga Peter','Lohmanlaan 27','Burgum','','NETHERLANDS','9251LB','+31511474941','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 19:45:24',0,NULL,3,1,3,1,'RA117774016CN\r ','tripwired25'),(11522,803529101015,250635196516,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',2.79,'hutongstore','yiannis3','yiannisaggelopoulos@gmail.com','ΓΙΑΝΝΗΣ ΑΓΓΕΛΟΠΟΥΛΟΣ','ΜΥΡΙΟΦΥΤΟΥ 12','ΠΕΙΡΑΙΑΣ','προεπιλογή','GREECE','18757','697 8475923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 20:42:54',0,NULL,3,1,2,1,NULL,'yiannis3'),(11523,803538870015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','charliechicken2','colever@aol.com','Colin Everitt','88 Lyndhurst Road','Corringham','Essex','UNITED KINGDOM','SS177SN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 20:54:07',0,NULL,3,1,2,1,NULL,'charliechicken2'),(11524,803537538015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','mahy77','mahy@eircom.net','David McMahon','Rath House','Danesfort','Kilkenny','IRELAND','default','872183334','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-15 20:57:54',0,NULL,3,1,2,1,NULL,'mahy77'),(11525,727634586002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','0r10ne67','fabio.301@gmail.com','Fabio Terzaghi','Largo Cav. di Malta, 8','Milano','MI','ITALY','20146','338-3760204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 21:00:52',0,NULL,3,1,2,1,NULL,'0r10ne67'),(11526,727637188002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','luxdigital_1982','topdigital2010@gmail.com','Carla karine Gomes da silva Moura','Loteamento Professor  Mario Bezerra Quadra 04 Nº 15<br>nº 15 Bairro: Jardim Ipiramga','vitória de santo antão','pernambuco','BRAZIL','55602-110','+558187356334','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-15 21:14:08',0,NULL,3,1,3,1,'RA117770456CN\r ','luxdigital_1982\rXL'),(11527,686355947001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',8,'AB3314',55.2,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 21:40:05',0,NULL,3,1,3,1,'RA117774872CN ','ryrvikryrvik'),(11528,803570497015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','jollybee4','onelostpoet@hotmail.co.uk','Geoff Stamp','2 Robins Grove Crescent','Yateley','Hampshire','UNITED KINGDOM','GU466PT','01252875223','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 22:02:47',0,NULL,3,1,2,1,NULL,'jollybee4'),(11529,727656661002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','shayshayhen','shay6280@gmail.com','shay machloof','alfasi 11','kfar yona','ID','ISRAEL','40300','054-446-4461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 22:02:53',0,NULL,3,1,3,1,'RA117774095CN\r ','shayshayhen'),(11530,685980349018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','rber1854','rb.tilll@hotmail.fr','régis bermudez','5 passage david belugou','montpellier','Languedoc-Roussillon','FRANCE','34000','0467583023','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-15 22:22:24',0,NULL,3,1,2,1,NULL,'rber1854'),(11531,685982703018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','blp2002','javery@bigpond.net.au','justin avery','39 calala dr','Strathpine','Queensland','AUSTRALIA','4500','0732055939','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-15 22:40:12',0,NULL,3,1,3,1,'RA117770385CN\r ','blp2002'),(11532,787087939016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','oraclefilms','willsmith1@live.com','Will Smith','Mitcheldene, Malvern Edge Court,<br>Areley Common','Stourport-on-Severn','Worcestershire','UNITED KINGDOM','DY13 0NP','01299825594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-15 23:22:53',0,NULL,3,1,2,1,NULL,'oraclefilms'),(11533,684682710018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','teegz2108','teegz_88@hotmail.com','Teegan Rush','40 Laurence Way','Tarneit','Victoria','AUSTRALIA','3029','0399743252','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-15 23:27:36',0,NULL,3,1,4,1,'YW864488900CN ','teegz2108\rbackground support $25'),(11534,727683438002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','6674.jose','jfgm1@sapo.pt','José Machado','Rua da Pica 52<br>Delães','Vila Nova de Famalicão','Braga','PORTUGAL','4765-649','00351962026674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-15 23:31:05',0,NULL,3,1,2,1,NULL,'6674.jose'),(11535,683676018018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','emilymcn1981','mcnaughton.emily@gmail.com','Emily McNaughton','70 Nepean Street','Watsonia','Victoria','AUSTRALIA','3085','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-15 23:31:06',0,NULL,3,1,2,1,NULL,'emilymcn1981'),(11536,686007947018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','stewhel129','stewart.hodgson@internode.on.net','Stewart Hodgson','12/129 Holt Avenue','Cremorne','New South Wales','AUSTRALIA','2090','0299044528','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-16 00:12:47',0,NULL,3,1,2,1,NULL,'stewhel129'),(11537,740055523017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',8.7,'photographyacc','lisan8504','winterrose@optusnet.com.au','Rob Nagel','1524 Riverdale Drive','Hope Island','Queensland','AUSTRALIA','4212','0755109650','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-16 00:43:09',0,NULL,3,1,2,1,NULL,'lisan8504\r带水平仪 热靴保护盖  3'),(11538,727705334002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','luiso_84','luisop_@hotmail.com','Luis Gonzalez Lopez','Av. Valladolid nº 45 (Pasteleria Lord)<br>C/San jose nº2 2E','Palencia','Castilla y León','SPAIN','34004','656545550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 01:10:07',0,NULL,3,1,4,1,'YW864488911CN','luiso_84\rtripod $18'),(11539,727720308002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','radsnet','ranieri.ambrosio@gmail.com','Ranieri Ambrosio','7971 NW 68th St','Miami','FL','UNITED STATES','33166-2793','(786) 208-4076','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 02:15:01',0,NULL,3,1,3,1,'RA117770408CN\r ','radsnet'),(11540,727310992002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','uv80','mrfigger@yahoo.com','Mike Figger','492 Martin Rd','New Berlin','NY','UNITED STATES','13411-2632','(941) 204-0764','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'uv80\r'),(11541,787140367016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','foochadude','spam_lubba@yahoo.com','Nick Wadsley','1/211 Church Street','Brighton','Victoria','AUSTRALIA','3186','0423169633','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-16 02:37:27',0,NULL,3,1,4,1,'YW864488885CN ','foochadude\r澳标\r----\r0629:补发1个 115w 220v 灯泡(已入库)\rRA117777595CN'),(11542,727678117002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adolphny16940','adolphny@hotmail.com','Adolfo Alzate','1409 131st St<br>Fl 2','college point','NY','UNITED STATES','11356-2425','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','2011-06-16 02:28:59',0,NULL,3,0,17,0,NULL,'adolphny16940'),(11543,727677953002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','adolphny16940','adolphny@hotmail.com','Adolfo Alzate','1409 131st St<br>Fl 2','college point','NY','UNITED STATES','11356-2425','','NoPaymentFailure','CheckoutIncomplete','StandardShippingFromOutsideUS','2011-06-16 02:28:58',0,NULL,3,0,1,1,NULL,'adolphny16940\rCANON 镜头盖  58mm  2(已入库）'),(11544,686054955018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',7.28,'photographyacc','a1965stang','witney@internode.on.net','Carolyn Jones','81 Streeton Way','Berwick','Victoria','AUSTRALIA','3806','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-16 03:55:34',0,NULL,3,1,2,1,NULL,'a1965stang'),(11545,803670134015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jensoleder','jmderby@sol.dk','jens ole mortensen','jens baggesens vej 80 st.tv','Aarhus','denmark','DENMARK','8210','26336096','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 03:59:53',0,NULL,3,1,2,1,NULL,'jensoleder'),(11546,727746389002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mjachisholm','marcjachisholm@eastlink.ca','Marc Chisholm','103 North Ave.','New Glasgow','NS','CANADA','B2H2E2','(902) 382-2322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 04:36:16',0,NULL,3,1,3,1,'RA117774149CN\r ','mjachisholm'),(11547,686449615001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5.2,'hermeshine','bridiejoy','andyjoepop2@yahoo.com','Louise Jinkens','560 Justin Dr','San Francisco','CA','UNITED STATES','94112-1140','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 05:27:58',0,NULL,3,1,1,1,NULL,'bridiejoy'),(11548,686454470001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','2006mrq','mike68quinn@gmail.com','Michael Quinn','89 Hammond St.','Bowmanville','ON','CANADA','l1c5e6','(905) 697-2945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-16 05:31:10',0,NULL,3,0,3,1,'RA117774458CN ','2006mrq\r（L） 已入库'),(11549,686455442001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','qwerty_steve','stephenleeis@gmail.com','Stephen Lee','8 Garfield Avenue<br>Bonnet Bay','Sydney','New South Wales','AUSTRALIA','2226','0402248336','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-16 05:35:04',0,NULL,3,1,4,1,'YW866011323CN ','qwerty_steve\r背景架2mx2m (+ 3个夹子)    1\r背景布 1.6x2.1m     2 (白+黑)'),(11550,686455507001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',90.82,'hermeshine','oc_wooddude','dave@davidtilson.com','David e Tilson','5752 Lime Ave','Cypress','CA','UNITED STATES','90630-3249','(714) 330-4786','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-16 06:31:41',0,NULL,3,1,4,1,'YW866011286CN ','oc_wooddude\ro-flash 155   1\r60cm 棚   1\rng128    1'),(11551,686465159001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','427gussys','lars.gustavsen@broadpark.no','Lars Gustavsen','Snorresgate 6','Sarpsborg','Ostfold','NORWAY','1723','69146714','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-16 06:36:16',0,NULL,3,1,4,1,'YW866011312CN ','427gussys\rtripod $22\r0630-0712YW系统显示已签收.'),(11552,802896973015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.25,'hutongstore','rolly125','meresidemono@tiscali.co.uk','wayne rollinson','everquip garage equipment,broad lane,gatewaybuissness park,<br>gilberdyke east riding of yorkshire','gilberdyke','hull','UNITED KINGDOM','hu152tb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 06:57:40',0,NULL,3,1,2,1,NULL,'rolly125'),(11553,727768129002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-16 07:00:40',0,NULL,3,1,3,1,'RA117774360CN ','vacarciucalexandru'),(11554,686074511018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',52,'photographyacc','patinya123','jawjing@hotmail.com','Mr. Patinya Taneiam','46,46/1-2 Soi Charansanitwongs 40<br>Charansanitwongs R. Bangyikhan','Bangphad','Bangkok','THAILAND','10700','081-3323470','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 07:40:43',0,NULL,3,0,3,1,'RA117774373CN ','patinya123\r60cm 圆棚   1\r反光板 110cm 5合1    1\r申报$10'),(11555,803718742015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','tbmod','tbmod.com@gmail.com','Thomas Bell','17 rte du Rostrenen','Plouguernevel','Bretagne','FRANCE','22110','0256436027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 07:49:23',0,NULL,3,1,2,1,NULL,'tbmod'),(11556,685233694018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','pcw72','whalepaulc@hotmail.com','paul whale','U38/13 BAILEY STREET<br>COLLINGWOOD PARK','Brisbane','Queensland','AUSTRALIA','4301','0403425785','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-06-16 07:55:54',0,NULL,3,1,2,1,NULL,'pcw72'),(11557,685667861018,280688709225,'New Studio Flash Strobe Lighting Set Carry Bag  75x15cm',1,'AD1128',25,'photographyacc','elpirey','danielpublic@hotmail.com','DANIEL PINEDO REYNA','Pza de Arteijo, 12 - 6º 1','Madrid','Madrid','SPAIN','28029','913785509','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 08:19:20',0,NULL,3,1,3,1,'RA117774501CN ','elpirey\r我后调的灯架包，厚的那个'),(11558,686485137001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vetals777','vitaliy.nechiporenko@gmail.com','Vitaliy Nechiporenko','pereulok SHTABNOY 6,<br>kvartira 220,','Dnepropetrovsk','','UKRAINE','49049','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 08:27:17',0,NULL,3,1,3,1,'RA117774413CN ','vetals777'),(11559,727776737002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102.6,'hermeshine','georgiyvylegzhanin','hmdfirm@yahoo.co.uk','Georgiy Vylegzhanin','apt. 32, building 200,<br>KOZHAMKULOV Street','Almaty','Almaty','KAZAKHSTAN','050012','727-21937713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 08:38:54',0,NULL,3,1,3,1,'RA117774546CN\r ','georgiyvylegzhanin'),(11560,686109463018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',7.8,'photographyacc','underpantsandy','mail@andrewmoroney.com','andrew moroney','19 Beattie St<br>West End','Brisbane','Queensland','AUSTRALIA','4101','0733999700','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-16 09:00:10',0,NULL,3,1,2,1,NULL,'underpantsandy'),(11561,686119935018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','thevintagepeacok','cooroo@bigpond.com','Deborah Cooke','3 Guise Road','Bradbury','New South Wales','AUSTRALIA','2560','0246253500','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-16 09:46:26',0,NULL,3,1,4,1,'YW866011275CN ','thevintagepeacok\rbackground support $25'),(11562,686516140001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','jhkampen','j.van.kampen10@kpnplanet.nl','Joan  van Kampen','Goudenregenlaan 1','Waalre','other','NETHERLANDS','5582BA','040-2215020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 10:53:52',0,NULL,3,1,2,1,NULL,'jhkampen'),(11563,787277691016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','technofobic','martindave@waitrose.com','david martin','17 augustus close<br>chandlers ford','eastleigh','Hampshire','UNITED KINGDOM','SO53 2BF','02380261899','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 12:11:29',0,NULL,3,1,2,1,NULL,'technofobic'),(11564,803793875015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','gde9965','gordon.elliott@blueyonder.co.uk','gordon elliott','110 stour close, strood','rochester','Kent','UNITED KINGDOM','ME23JZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-16 12:13:07',0,NULL,3,1,2,1,NULL,'gde9965'),(11565,803803019015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','cla**76','c.myers@st-vincents.ie','Clara Geraghty','114 Barton Rd East<br>Churchtown','Dublin','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 12:43:00',0,NULL,3,1,2,1,NULL,'cla**76'),(11566,803804960015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','amiroco77','amiroco@yahoo.com','amir cohen','hagefen 4<br>meona','moshav meona','galil maaravi','ISRAEL','24920','97249979951','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 12:45:47',0,NULL,3,1,3,1,'RA117774515CN\r ','amiroco77'),(11567,740219589017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','lozz184','nandlmitchell@bigpond.com','Laura Mitchell','PO Box 30','Lismore','Victoria','AUSTRALIA','3324','0448324331','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-16 12:58:05',0,NULL,3,1,2,1,NULL,'lozz184'),(11568,686171144018,280689694480,'New Continuous Lighting System umbrella with bulbs',1,'AD1134',110,'photographyacc','coding63','chookiat063@hotmail.com','chookiat lertsapsuree','43/2 Ranken Place','Belconnen','Australian Capital Territory','AUSTRALIA','2617','0423470285','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-16 13:03:59',0,NULL,3,1,4,1,'YW866011264CN ','coding63\r澳标  220v\rlighting kit\r灯泡换成4个45w的\r'),(11569,686562267001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','ninksninks','ninx77@yahoo.com','sinisa ninkovic','pavlovac 74a','banjaluka','','BOSNIA AND HERZEGOVINA','78000','051-274-130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 13:50:29',0,NULL,3,1,2,1,NULL,'ninksninks'),(11570,686177412018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','rber1854','rb.tilll@hotmail.fr','régis bermudez','5 passage david belugou','montpellier','Languedoc-Roussillon','FRANCE','34000','0467583023','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 14:04:23',0,NULL,3,1,2,1,NULL,'rber1854'),(11571,727871186002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','marcelogeriba','praseresdesign@bol.com.br','Marcelo Oliveira','Estrada Cafundá, 1757 - Bloco 10<br>Apto 507 - Taquara','Rio de Janeiro','Rio de Janeiro','BRAZIL','22725-030','552187776052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 14:31:35',0,NULL,3,1,3,1,'RA117774475CN\r ','marcelogeriba'),(11572,686582344001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','tau36','a.niflungar@gmail.com','Arseny Shtykin','Leninsky prospect 17-61','Voronezh','','RUSSIAN FEDERATION','394029','7 951 567 58 71','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 14:58:16',0,NULL,3,1,2,1,NULL,'tau36'),(11573,727667931002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',4,'AO0034',36,'hermeshine','edc-01e','qaz-01@m5.gyao.ne.jp','Akira Nakano','2-20-17 hasune<br>TOP hasune203','Itabashi-ku','Tokyo','JAPAN','174-0046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 15:29:27',0,NULL,3,1,3,1,'RA117774461CN\r ','edc-01e'),(11574,727893260002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','puertodigital','cfaune@live.cl','Cristian Faune','Borinquen 2, condominio Brisas del sur, Edf. Goleta, depto. 55<br>Recreo alto','Viña del mar','Valparaiso','CHILE','2581458','81364710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 15:41:08',0,NULL,3,1,5,1,'CP227125296CN ','puertodigital'),(11575,727926095002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pik0','andrew@javapathologist.com','Andrew McLaughlin','537 N Pageant Dr<br>Unit C','Orange','CA','UNITED STATES','92869','(714) 726-4030','NoPaymentFailure','CheckoutComplete','Other','2011-06-16 17:48:17',0,NULL,3,0,1,1,NULL,'pik0\r3XL(已入库)'),(11576,686281201018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','v.rom9','v.romeo09@gmail.com','Vincenzo Romeo','Via Gramsci 6','Sondrio','SO','ITALY','23100','338-7771258','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 18:14:46',0,NULL,3,1,2,1,NULL,'v.rom9'),(11577,727953289002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','yael585','yaels585@gmail.com','Yael Schweistein','Hapodim 27','Ramat Gan','','ISRAEL','52566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 18:19:39',0,NULL,3,1,2,1,NULL,'yael585'),(11578,727961029002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','dvvnnvladislav','dvv_nn@mail.ru','Vladislav Dovbysh','Maksima Gorkogo str. 144-44','Nizhny Novgorod','Nizhegorodskaya oblast','RUSSIAN FEDERATION','603000','+79200327896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 18:38:01',0,NULL,3,1,2,1,NULL,'dvvnnvladislav'),(11579,727962267002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','kosowar7','clirim@uskana.com','Clirim Ramadani','Rr. Bill Clinton SU5/8E Nr.41','Pristina','Kosovo','ALBANIA','10090','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 18:38:45',0,NULL,3,1,2,1,NULL,'kosowar7'),(11580,803983931015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',29,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','358456326520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 19:19:26',0,NULL,3,1,3,1,'RA117774550CN\r ','zuhmia'),(11581,686329622018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','matsonandco','observatoireaniane@free.fr','Mathias Groubert','observatoire<br>ch. du tunnel','ANIANE','Languedoc-Roussillon','FRANCE','34150','0622560108','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 19:54:29',0,NULL,3,1,2,1,NULL,'matsonandco'),(11582,686337760018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',7.99,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 20:11:11',0,NULL,3,1,17,0,NULL,'igrom78'),(11583,727084871002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sjmused','sjmusers@cox.net','jennifer y muse','14660 evening star dr','poway','CA','UNITED STATES','92064-3017','','NoPaymentFailure','CheckoutComplete','Other','2011-06-16 20:24:31',0,NULL,3,0,1,1,NULL,'sjmused\r背心 Canon  老款  2XL       1(已入库)'),(11584,740404698017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',3,'AA1301',57.46,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-16 20:26:09',0,NULL,3,1,3,1,'RA117774577CN\r ','igrom78      (已全部减库)\r58mm  Canon 镜头盖    3\rcanon 三角包  D3    1\rNikon 三角包  D3    1\rSony 三角包  D3    1\r永诺 nikon ttl 线  1m     1\r永诺 canon ttl 线  1m    1\r1.145\r'),(11585,686738223001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 21:26:19',0,NULL,3,1,2,1,' ','viong'),(11586,686374322018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','jamoundercover','jamoundercover@gmail.com','James Humphris','22 Doig St','Constitution Hill','New South Wales','AUSTRALIA','2145','0410838309','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-16 21:35:22',0,NULL,3,1,3,1,'RA117774532CN\r ','jamoundercover'),(11587,804069043015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',2,'AA1302',3.76,'hutongstore','ramirezthorne','luis_nicola@hotmail.com','Nicola Ramirez-Thorne','Family Hamura 102<br>Futabacho 2-11-6','Hamura','Tokyo','JAPAN','205-0022','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-16 22:10:35',0,NULL,3,1,2,1,' ','ramirezthorne'),(11588,740460505017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',2,'AO0005',33.98,'photographyacc','digitalebola','anthony@consultexcel.com.au','Kylie and Anthony Martin','20 mallee circuit','pakenham','Victoria','AUSTRALIA','3810','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-16 22:57:43',0,NULL,3,1,3,1,'RA117774603CN\r ','digitalebola\r背景布 1.6x3m    2 (白+黑)'),(11589,686399747018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','samellemby','sam@ellemby.com','Sam Reich','ELLEMBY RESOURCES<br>67 Bulwer Street','MAITLAND','New South Wales','AUSTRALIA','2320','0418402644','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-16 23:02:19',0,NULL,3,1,3,1,'RA117774492CN\r ','samellemby\r摄影背心 nikon 原厂  L    1(已入库)\r肩带 nikon     1'),(11590,740455591017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',7.28,'photographyacc','samellemby','sam@ellemby.com','Sam Reich','ELLEMBY RESOURCES<br>67 Bulwer Street','MAITLAND','New South Wales','AUSTRALIA','2320','0418402644','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-16 23:02:20',0,NULL,3,1,17,0,NULL,'samellemby'),(11591,728064950002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',5,'AC1302',37.5,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-16 23:10:39',0,NULL,3,1,3,1,'RA117774489CN\r ','mariomarques.com.br'),(11592,740471048017,270757382435,'Studio 1000W Continuous Lighting Complete Kit 3mx6m G',1,'AKT063',253,'photographyacc','slimixmaster','deckreck@gmail.com','Thomas Hansen','103/270 King St<br>CBD','Melbourne','Victoria','AUSTRALIA','3000','0415668128','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-16 23:39:50',0,NULL,3,1,4,1,'YW866011253CN ','slimixmaster\r澳标\rbackdrop support $40\r'),(11593,727780297002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 00:30:45',0,NULL,3,1,17,0,NULL,'saud-p'),(11594,727096915002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 00:30:45',0,NULL,3,1,8,1,'CP227125424CN ','saud-p\r反光板支架    1\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子     2'),(11595,685802230001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 00:30:47',0,NULL,3,1,17,0,NULL,'saud-p\r'),(11596,686787564001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','shalyn1127','shalyn1127@aol.com','Shanna Palenkas','12912 Brown Bark Trl','Clermont','FL','UNITED STATES','34711','(407) 947-2120','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-17 00:46:53',0,NULL,3,1,1,1,NULL,'shalyn1127'),(11597,686793314001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','esrods','esrods@tpg.com.au','Edward Shin','32 Munmorah Cct','Woodcroft','New South Wales','AUSTRALIA','2767','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 01:14:28',0,NULL,3,1,3,1,'RA117774529CN\r ','esrods'),(11598,728120336002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','davearguez','prominent16@hotmail.com','dave arguez','po box 504','margaretville','NY','UNITED STATES','12455','','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,5,0,18,1,NULL,'davearguez\r背心 Canon  老款 M    1'),(11599,686841777001,110591560700,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT054',4.87,'hermeshine','mur_mur_001','smurzinov@nursat.kz','Stanislav Murzinov','45 Bayseitova Str. appt. 24','Almaty','Almaty','KAZAKHSTAN','050013','+77011111609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 05:34:31',0,NULL,3,1,2,1,NULL,'mur_mur_001'),(11600,686167944018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','sheeka_bid','taniadotcom@hotmail.com','Tania Gonzalez','28 Brunswick Street','Granville','New South Wales','AUSTRALIA','2142','0288127700','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-17 05:41:18',0,NULL,3,1,2,1,NULL,'sheeka_bid'),(11601,686842102001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','alexandra*18','alexandradekuiper@hotmail.com','Alexandra de Kuiper','Overweg 183','OUDERKERK AAN DE AMSTEL','','NETHERLANDS','1191PZ','0204964794','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'alexandra*18'),(11602,804208901015,250599412421,'Green.L 67mm 67 Neutral Density ND8 Filter ND 8 New',1,'AE2312',4.3,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 08:03:28',0,NULL,3,1,17,0,NULL,'geflesa'),(11603,804207976015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 08:03:29',0,NULL,3,1,17,0,NULL,'geflesa\r'),(11604,804206775015,250599399183,'67mm 67 Close Up  Macro Close-Up +8 Filter New',1,'AE3226',4.2,'hutongstore','geflesa','ger-v@planet.nl','Ger Veugelers','Reinald van Gelrestraat 39','NIEUWSTADT','','NETHERLANDS','6118AD','0650257648','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 08:03:29',0,NULL,3,1,2,1,NULL,'geflesa\r橡胶遮光罩 58mm        1\r绿叶 ND8  67mm      1\r'),(11605,728165581002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','fredrikoslo','fredrigl@yahoo.com','Fredrik Glockner','Schweigaardsgate 63<br>335','OSLO','','NORWAY','N-0656','+4793480445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 08:16:42',0,NULL,3,1,2,1,NULL,'fredrikoslo'),(11609,740601856017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','s1c2o3o4t5e6r7','jrichards1116@gmail.com','john richards','3059 Madison Rd','cincinnati','OH','UNITED STATES','45209-1741','(513) 439-3713','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-17 10:04:32',0,NULL,3,1,1,1,NULL,'s1c2o3o4t5e6r7'),(11606,728174484002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','neighorn','neighorn@gmail.com','Patrick Neighorn','40A Orchard Road #07-01<br>The MacDonald House','default','','SINGAPORE','238838','(656) 825-8065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 09:02:00',0,NULL,3,1,11,1,NULL,'neighorn'),(11607,728175746002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',4,'AO0014',31.6,'hermeshine','muuujer','magpawlowicz@gmail.com','magdalena pawlowicz','mickiewicza 14','Twardogóra','dolno?l?skie','POLAND','56-416','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 09:08:05',0,NULL,3,1,2,1,' ','muuujer'),(11608,804190587015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','stephen.p.wharton','paulwharton1970@btinternet.com','Paul Wharton','73 Larkfield Meadows','Craigavon','Armagh','UNITED KINGDOM','BT65 5JD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-17 09:09:46',0,NULL,3,1,2,1,NULL,'stephen.p.wharton'),(11610,728187431002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','betterimagesnapper','marek.zalewski@hotmail.co.uk','Marek Zalewski','5 Priest Meadow Close<br>Astwood Bank','Redditch','Worcestershire','UNITED KINGDOM','B96 6HT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 10:04:48',0,NULL,3,1,2,1,NULL,'betterimagesnapper'),(11611,740603964017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','reelmacaw','imsprint@bigpond.com','Maxwell G Cox','P.O. Box 319','East Maitland','New South Wales','AUSTRALIA','2323','0249330410','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-17 10:13:19',0,NULL,3,1,3,1,'RA117774943CN\r ','reelmacaw'),(11612,686898789001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','visistudio','visi_photographer@hotmail.com','ERVIS BOSTANXHI','Ave Gjergj Kastrioti no.12<br>Lagja no 12','KORCA','AL','ALBANIA','7000','+355672065800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 10:36:15',0,NULL,3,1,5,1,'CP234126059CN ','visistudio'),(11613,686906694001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',18.19,'hermeshine','senorwafflez','john.gjertsen@gmail.com','John Gjertsen','Ørnahaugen 25','Fyllingsdalen','','NORWAY','5144','+4793097947','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 11:11:25',0,NULL,3,1,3,1,'RA117776105CN\r ','senorwafflez'),(11614,686908201001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 11:18:14',0,NULL,3,0,3,1,'RA117774926CN\r ','mariomarques.com.br (已入库)\r2x 52mm lens cap for Nikon\r2x 62mm lens cap for Nikon\r2x 67mm lens cap for Nikon\r2x 72mm lens cap for Nikon\r2x 77mm lens cap for Nikon '),(11615,686552442018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','rockbreath','rockbreath@yahoo.com','Rubai Huda, C/O Jasmine Zaman','26,  Second Avenue<br>Campsie','Campsie','New South Wales','AUSTRALIA','2194','0433273531','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-17 11:31:28',0,NULL,3,1,3,1,'RA117774930CN\r ','rockbreath'),(11616,728208762002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','giftson4u4ever','naveengiftson@yahoo.co.in','T.Sakunthalai','14/31, 1st street, thiruvalluvar nagar<br>kottur','chennai','TN','INDIA','600085','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 11:38:07',0,NULL,3,1,2,1,NULL,'giftson4u4ever'),(11617,728221253002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 12:29:03',0,NULL,3,1,4,1,'YW865717780CN ','gunners456\r反光伞    1\r2b柔   2\rlighting kit  $26\r-----\rB座坏了,补发一个,发前仔细检查一下.\rRA117777074CN\r'),(11618,686930958001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','kaelu65','dkalensky@gmx.net','Daniel Kalensky','Jurastrasse 26','Wangen an der Aare','','SWITZERLAND','3380','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 12:47:49',0,NULL,3,1,4,1,'YW865717776CN ','kaelu65\r2m背景架 （ 白  黑）   1\rbackground support  $25\r0630-0711-0725来信说收到了'),(11619,740646668017,270748510307,'NIB TianYa Gradual grey Color Filter for Cokin P series',1,'AA2322',7.29,'photographyacc','9532wilson','streamlinetrees@optusnet.com.au','don wilson','po box 100','marysville','victoria','AUSTRALIA','3779','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-17 12:50:35',0,NULL,3,1,2,1,NULL,'9532wilson'),(11620,740649174017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',1,'AB3314',6.69,'photographyacc','samellemby','sam@ellemby.com','Sam Reich','ELLEMBY RESOURCES<br>67 Bulwer Street','MAITLAND','New South Wales','AUSTRALIA','2320','0418402644','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-17 12:58:31',0,NULL,3,1,2,1,NULL,'samellemby'),(11621,686934181001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','d1mka2503','qwe250388@gmail.com','Dmitry Kemyashov','Bul`var Dmitrya Donskogo,9/1.apt 233<br>Бульвар Дмитрия Донского 9/1 кв 233','Moscow','','RUSSIAN FEDERATION','117216','(926)1279770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 12:58:51',0,NULL,3,1,2,1,NULL,'d1mka2503'),(11622,686578857018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','georgiap001','georgiaandmatthew@bigpond.com','Georgia Pearce','43 amesbury avenue','wantirna','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-17 13:03:58',0,NULL,3,1,3,1,'RA117776119CN\r ','georgiap001'),(11623,728238450002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102.6,'hermeshine','jorgengrytoyr','jorgen@grytoyr.no','Jørgen Grytøyr','Hertug Skules vei 6','GAMLE FREDRIKSTAD','','NORWAY','1639','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 13:30:50',0,NULL,3,1,4,1,'YW865717802CN ','jorgengrytoyr\rballhead  $20\r'),(11624,686941599001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 13:31:18',0,NULL,3,1,8,1,'CP234126062CN ','saud-p\r可以分几个小包发吗?\r2m 背景架 （ 白 黑）\r背景架2m x 3m + 3个夹子\r'),(11625,728009756002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','montxu00','montxu@gmail.com','Gaizka Montero Rivadulla','Aldapas nº 14 1ºD','algorta (getxo)','País Vasco','SPAIN','48991','666455813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 13:31:23',0,NULL,3,1,3,1,'RA117776153CN\r ','montxu00'),(11626,686947398001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','villemo1','villemo1@online.no','Linn Landmark','Vaagslia 24','Aagotnes','Ågotnes','NORWAY','5363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 13:48:29',0,NULL,3,1,2,1,NULL,'villemo1'),(11627,686955718001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','vladobro87','vladobro@mail.ru','Vladimir Dobromyslov','Olonetskaya st., 17A-7','Moscow','RU','RUSSIAN FEDERATION','127273','74954025574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 14:27:10',0,NULL,3,1,2,1,NULL,'vladobro87'),(11628,804340231015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','rudok09','rkisela@gmail.com','Rudolf Kiseľa','Popradská 5','Prešov','','SLOVAK REPUBLIC','080 01','+421 905 521750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 14:39:06',0,NULL,3,1,2,1,NULL,'rudok09'),(11629,787816492016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','nunofpedrosa','nuno.f.pedrosa@gmail.com','Nuno Pedrosa','Av. Conde de Valbom, 30, 3º Piso','Lisbon','Lisbon','PORTUGAL','1050-068','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 14:45:46',0,NULL,3,1,2,1,NULL,'nunofpedrosa'),(11630,686988741001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','eptcb1980','eptlc@hotmail.com','Moran Popovich','ilanot Street 4, Apt.9','Karmiel','','ISRAEL','21881','972528219196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 16:10:48',0,NULL,3,1,2,1,NULL,'eptcb1980'),(11631,804378927015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','skippy25-2008','skippy25@btinternet.com','Stephen Sweet','83 Church Lane<br>North Wingfield','Chesterfield','Derbyshire','UNITED KINGDOM','S42 5HR','01246857211','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-17 16:11:50',0,NULL,3,1,2,1,NULL,'skippy25-2008'),(11632,728302729002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','cantaroan','cantaroan@coqui.net','Erick Bermudez','HC 1 Box 8994','Vieques','PR','UNITED STATES','00765','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-17 16:57:39',0,NULL,3,1,1,1,NULL,'cantaroan'),(11633,687012543001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','lesa75lesa','sasa.prijic1@zg.t-com.hr','sasa prijic','vladimira ruzdjaka 12','zagreb','','CROATIA','10000','+0038516050522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 17:12:27',0,NULL,3,1,2,1,NULL,'lesa75lesa'),(11634,728309334002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5.2,'hermeshine','cairys_mom','chelej@mail.com','Michele Johnston','3019 Hetherton Dr','Aston','PA','UNITED STATES','19014','(610) 497-6309','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 17:23:09',0,NULL,3,1,1,1,NULL,'cairys_mom'),(11635,687018635001,110522773152,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',32,'hermeshine','flash0183','flash.gordon77@hotmail.co.uk','gordon pearson','174 gershwin road<br>brightonhill','basingstoke','Hampshire','UNITED KINGDOM','rg22 4hl','07776032705','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 17:28:55',0,NULL,3,1,3,1,'RA117775100CN\r ','flash0183'),(11636,728284360002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','sampatman','chum94555@yahoo.com','kiran sampat','33964 Frederick Ln','Fremont','CA','UNITED STATES','94555-2527','','NoPaymentFailure','CheckoutComplete','Other','2011-06-17 18:10:43',0,NULL,3,1,1,1,NULL,'sampatman'),(11637,728277851002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','lou847','lou209@me.com','Eloise Naylor','209 Hickory Ln','Moorestown','NJ','UNITED STATES','08057','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 19:47:01',0,NULL,3,1,1,1,NULL,'lou847'),(11638,728376314002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','musse63stefan','a10z24@hotmail.com','stefan wallström','silverstigen 6','södertälje','södertälje','SWEDEN','15148','4608-55035019','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-17 20:05:48',0,NULL,3,0,3,1,'RA117775039CN\r ','musse63stefan\rL (已入库）'),(11639,804497521015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','nordicimport','pridemman@yahoo.com','Eugene Glynn','Mollevn 7','Bjorkelangen','Akershus','NORWAY','N-1940','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-17 20:07:47',0,NULL,3,1,2,1,NULL,'nordicimport'),(11640,728382932002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','bizarren','baldomero007@yahoo.es','Cesar Iturbide','C/Marina 110 6 2','Barcelona','Cataluña','SPAIN','08018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 20:23:36',0,NULL,3,1,4,1,'YW865717791CN ','bizarren\rtripod  $18'),(11641,740825031017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',46.11,'photographyacc','wqmarx','william@tematecnica.com.br','william marques','rua dr quirino, 844','campinas','sao paulo','BRAZIL','13015-081','55-19-32327255','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-17 20:29:05',0,NULL,3,1,3,1,'RA117774912CN\r ','wqmarx\r大号内胆包  canon   4\r永诺 canon ttl 线  1m   1\r'),(11642,687094379001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','rajib_barua','rajib_barua@hotmail.com','Rajib Baruah','6824 Lincoln Dr','Macungie','PA','UNITED STATES','18062','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-17 20:51:07',0,NULL,3,1,1,1,NULL,'rajib_barua'),(11643,728414282002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jaramirezviera','jramirezviera@gmail.com','Jesús Ramírez Viera','c Joaquin Artiles Nº28','Agüimes','Canarias','SPAIN','35260','686545622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 21:57:55',0,NULL,3,1,4,1,'YW865717824CN ','jaramirezviera\rtripod $18\r0630-0712YW系统显示已签收.'),(11644,686790841018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',2,'AA2216',10,'photographyacc','phil-the-sparky-pty-ltd','phil@philthesparky.com.au','Phil the Sparky Pty Ltd','11 Holly Road','Victoria Point','Queensland','AUSTRALIA','4165','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-17 22:46:16',0,NULL,3,1,2,1,NULL,'phil-the-sparky-pty-ltd'),(11645,687135812001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','knuy4254','c.nuyten@home.nl','Kees Nuyten','Flintdijk 61','Roosendaal','','NETHERLANDS','4706JX','0031 41 46 2000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 23:06:44',0,NULL,3,1,2,1,NULL,'knuy4254'),(11646,728439834002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','rangefinder27','bill@imagingbc.com','Collins Web & Media Design','19780-Wildwood Crescent S.','Pitt Meadows','BC','CANADA','V3Y 1N1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 23:49:00',0,NULL,3,1,17,0,NULL,'rangefinder27'),(11647,728438881002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rangefinder27','bill@imagingbc.com','Collins Web & Media Design','19780-Wildwood Crescent S.','Pitt Meadows','BC','CANADA','V3Y 1N1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-17 23:49:00',0,NULL,3,1,2,1,NULL,'rangefinder27\r方形滤镜接口环 77mm   1\r方镜广角托架（ 一槽）   1\r'),(11648,686980422001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9.9,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 00:16:09',0,NULL,3,1,17,0,NULL,'gunners456'),(11649,686815169018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','ceedeem','ceedeem@bigpond.net.au','Colin Mellon','1 Snadden Street<br>Anula','Darwin','Northern Territory','AUSTRALIA','0812','0417873304','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-18 00:40:52',0,NULL,3,1,4,1,'YW865717813CN ','ceedeem\rtripod  $25'),(11650,686824420018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/49 DOLPHIN AVE','MERMAID BEACH','Queensland','AUSTRALIA','4218','0435010514','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-18 01:33:13',0,NULL,3,1,3,1,'RA117776207CN\r ','jobapro'),(11651,740913172017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/49 DOLPHIN AVE','MERMAID BEACH','Queensland','AUSTRALIA','4218','0435010514','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-18 01:46:15',0,NULL,3,1,17,0,NULL,'jobapro'),(11652,740914153017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','yamyabasha','bdkasher@yahoo.com.au','kasher B','2746 Old Coast road','Herron','Western Australia','AUSTRALIA','6211','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-18 01:49:42',0,NULL,3,1,2,1,NULL,'yamyabasha'),(11653,728466387002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','caponeint','capone_int@hotmail.com','HAKAN YENIDOGAN','5TELSIZ MH. SH.ERCAN UZER SK<br>NO.3 D.8','ISTANBUL','ZEYTINBURNU','TURKEY','34020','905053174196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 02:05:39',0,NULL,3,1,2,1,NULL,'caponeint'),(11654,686829858018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','7430mat','mp_build@bigpond.net.au','Pearce','35 Balook St','Lauderdale','Tasmania','AUSTRALIA','7021','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-18 02:05:50',0,NULL,3,1,3,1,'RA117776034CN\r ','7430mat'),(11655,740932018017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','sms*666','shane.symonds@gmail.com','shane symonds','15 Forbes Crt','Bundaberg','Queensland','AUSTRALIA','4670','41526202','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-18 03:18:40',0,NULL,3,1,2,1,NULL,'sms*666'),(11656,686845094018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','carlos4970','carlitus@three.com.au','Carlos Velasco','P.O. Box 7719<br>Bondi Beach','Sydney','New South Wales','AUSTRALIA','2026','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-18 03:21:35',0,NULL,3,1,2,1,' ','carlos4970\r只要一个'),(11657,686846351018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','tmcphreeky','simon@simtechmedia.com','Hoang Nguyen','UNIT 201<br>250 BARKLY STREET','FOOTSCRAY','Victoria','AUSTRALIA','3011','0424807813','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-18 03:28:21',0,NULL,3,1,3,1,'RA117775011CN\r ','tmcphreeky'),(11658,728485415002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','josarca123','jarielcamilo@yahoo.com','Jose Ariel Camilo Bencosme','7339 NW 54th St<br>RD # 52564','Miami','FL','UNITED STATES','33166','(829) 962-1507','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-18 03:56:44',0,NULL,3,1,1,1,NULL,'josarca123'),(11659,740965867017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','fullbottle!','payadvice@hotmail.com','Graham McClounan','8 Cristina Ave','Niagara Park','New South Wales','AUSTRALIA','2250','0243292280','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-18 06:44:09',0,NULL,3,1,2,1,NULL,'fullbottle!'),(11660,727639385002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','peto7211','nina.lozinsek@triera.net','David Lozinsek','Dalmatinska ul.43','maribor','','SLOVENIA','2000','040 699 617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 07:46:16',0,NULL,3,1,2,1,NULL,'peto7211'),(11661,740979576017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1114',12.99,'photographyacc','crocopk1','la_goran@yahoo.com','Goran Zeric','klepperdans 4','Capelle a/d Ijssel','','NETHERLANDS','2907rc','0627266858','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 07:49:25',0,NULL,3,1,2,1,NULL,'crocopk1'),(11662,686894527018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102,'photographyacc','bgoodie88','vishvag@hotmail.com','Vishva Gunasena','44 Edinburgh Cct','Cecil Hills','New South Wales','AUSTRALIA','2171','0401677236','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-18 08:10:55',0,NULL,3,1,4,1,'YW865717765CN ','bgoodie88\rballhead  $20'),(11663,687230544001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','taveja','juha.valtanen@netti.fi','Juha Valtanen','Paljakankatu 1 B 17','Nurmes','','FINLAND','75500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-18 08:19:22',0,NULL,3,0,3,1,'RA117774965CN\r ','taveja\rxxxl  (已入库）'),(11664,687241322001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','minuteaway','editmybid@yahoo.com','chung lau','803 Kamehameha Hwy<br>Ste 201','PEARL CITY','HI','UNITED STATES','96782-2638','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-18 09:09:59',0,NULL,3,1,1,1,NULL,'minuteaway'),(11665,740999545017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',13.8,'photographyacc','wrmwrm69','wayne@wrmcontracting.com.au','wayne mair','6 hannah avenue','kellyville','New South Wales','AUSTRALIA','2155','0418964895','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-18 09:11:05',0,NULL,3,1,2,1,NULL,'wrmwrm69'),(11666,686914053018,280674081169,'New 67mm Snap-on Front Lens Cap for Nikon 67 mm lenscap',1,'AA1307',2.5,'photographyacc','eftiyan','leventsolak@gmail.com','levent solak','eskiizmir cad.no 30 dr.2 güneşli mah. KONAK','İZMİR','konak','TURKEY','35170','905324814637','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 09:30:46',0,NULL,3,1,2,1,NULL,'eftiyan'),(11667,728544948002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','southwest_soil','fernandomazon@gmail.com','Fernando Mazón da Silva','calle Rosaleda, 4<br>Tentegorra','Cartagena','Murcia','SPAIN','30205','605231429','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-18 09:34:15',0,NULL,3,1,3,1,'RA117776025CN\r ','southwest_soil\rM'),(11668,686983623018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','michelp4176','michel_p@hotmail.com','michel piche','1275 rue Bousquet app2','laval','QC','CANADA','H7N 5A8','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 13:24:44',0,NULL,3,1,3,1,'RA117775056CN\r ','michelp4176'),(11669,686998923018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','londat2','londat2@gmail.com','Tomas Londa','23453 N Garden Ln','Lake Zurich','IL','UNITED STATES','60047-8832','(847) 903-5748','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 14:10:38',0,NULL,3,1,1,1,NULL,'londat2'),(11670,687003787018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',39.8,'photographyacc','caldicus','jacopo.martini@gmail.com','Jacopo Martini','Gammel Kongevej 72a','Frederiksberg C','','DENMARK','1850','0045-27430629','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 14:23:51',0,NULL,3,1,3,1,'RA117775087CN\r ','caldicust\r申报 shoulder pad  $15'),(11671,687343692001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','cibanezc','caribacal@gmail.com','Carlos J Ibañez Calleja','c/ Isla de Java, 76 Bajo C','Madrid','Madrid','SPAIN','28034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 15:02:46',0,NULL,3,1,4,1,'YW865717754CN ','cibanezc\rtripod  $22'),(11672,687381954001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','jcopeland64','jeffcopeland46@yahoo.com','jeff copeland','4321 Ball Camp Pike','knoxville','TN','UNITED STATES','37921-3313','(865) 455-5896','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-18 16:45:38',0,NULL,3,1,1,1,NULL,'jcopeland64'),(11673,687071180018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'',40,'photographyacc','korpen105','henrik@hovhag.se','Henrik Hovhag','Göteborgsvägen 14A','Uddevalla','none','SWEDEN','45142','+46 (0)70 9506204','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 17:18:49',0,NULL,3,0,3,1,'RA117775453CN\r ','korpen105\r新款 Canon 背心   3XL   1(!!!没入库)\r河北背心'),(11674,687073368018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',15.98,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-18 17:21:10',0,NULL,3,1,2,1,NULL,'igrom78'),(11675,687417317001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','hajekto','hajekto@seznam.cz','Tomas Hajek','Parikova 9/910','Praha','','CZECH REPUBLIC','19003','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-18 18:09:16',0,NULL,3,1,3,1,'RA117774988CN\r ','hajekto'),(11676,728720865002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','harryede','harry@westerman.nl.eu.org','Harry Westerman','Poelbos 44','Ede','','NETHERLANDS','6718 HV','(0318) 622150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 18:22:51',0,NULL,3,1,4,1,'YW864941585CN ','harryede\rlight stand  $25'),(11677,804952217015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','6674benn','ptr.benn@googlemail.com','Peter Benn','14 Charlie Street, Greenside','Ryton','Tyne and Wear','UNITED KINGDOM','NE40 4AQ','01914131374','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-18 18:43:08',0,NULL,3,1,2,1,NULL,'6674benn'),(11678,804954197015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','gianangelo4721','bassoemail@alice.it','Gian Angelo Basso','Viale risorgimento 53','Bra','CN','ITALY','12042','3488823181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-18 18:46:49',0,NULL,3,1,2,1,NULL,'gianangelo4721'),(11679,687441244001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','amir.liron','amirlir@gmail.com','Amir Liron','6 Egoz St.','Haifa','ISR','ISRAEL','34792','(972)54-2403514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 19:07:48',0,NULL,3,1,2,1,NULL,'amir.liron'),(11680,728739951002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jt5534','suejontillinghast@yahoo.com','Jonathan  Tillinghast','47 Gilead rd','Waterford','CT','UNITED STATES','06385','(860) 442-1353','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-18 19:08:03',0,NULL,3,1,1,1,NULL,'jt5534'),(11681,788419701016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','staticx','mat_taylor_75@yahoo.co.uk','Mat Taylor','20 Waverley<br>Great Hollands','Bracknell','Berkshire','UNITED KINGDOM','RG128UJ','07507604120','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-18 19:14:55',0,NULL,3,1,2,1,NULL,'staticx\r52mm 接口环  \r渐变灰   \r普通托架'),(11682,687447403001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','iwulmania','iwul_mania@yahoo.com','Iwan kurniawan','jl rajawali III no 9, kelurahan Garuda<br>kecamatan Cicendo','Bandung','West Java','INDONESIA','40115','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 19:50:23',0,NULL,3,1,2,1,NULL,'iwulmania'),(11683,687463351001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','twelve-88','sky-walker@list.ru','Ilya Kudisov','60 let VLKSM d.10 kv.94','Sochi','Krasnodarsky krai','RUSSIAN FEDERATION','354003','+7-963-164-6380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 20:04:00',0,NULL,3,1,2,1,NULL,'twelve-88'),(11684,728777265002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','kincete','suntzu_5@hotmail.com','Tania Palmeiro Sánchez','c/ Anxeriz nº7, 2ºE','Milladoiro - Ames','Galicia','SPAIN','15895','981938747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 20:52:48',0,NULL,3,1,17,0,NULL,'kincete'),(11685,687486981001,110658438313,'Remote Shutter Release Cord for Canon 40D 50D 5DII RE-A',1,'AA2219',4.68,'hermeshine','kincete','suntzu_5@hotmail.com','Tania Palmeiro Sánchez','c/ Anxeriz nº7, 2ºE','Milladoiro - Ames','Galicia','SPAIN','15895','981938747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-18 21:07:51',0,NULL,3,1,4,1,'YW864941574CN ','kincete\r三脚架  伟峰 WF-6662A     1\r优永佳快门线 A C3    1'),(11686,741288801017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','oddessavc','chesney@clearmail.com.au','Val Chesney','PO Box 6500','South Lismore','New South Wales','AUSTRALIA','2480','0266880238','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-18 22:05:34',0,NULL,3,1,3,1,'RA117774991CN\r ','oddessavc'),(11687,687217679018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','bluejesjus99','jemin84@bigpond.com','Justin O\'neill','10 Wingrove Gardens','Burnie','Tasmania','AUSTRALIA','7320','0438591076','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-19 00:02:40',0,NULL,3,1,3,1,'RA117775025CN\r ','bluejesjus99'),(11688,687539058001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','theabbd2','leventeleevi@gmail.com','Evgeny Yurov','pr-t. Stroiteley 18-136','Engels','Saratovskaya obl','RUSSIAN FEDERATION','413111','89173098817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 00:35:34',0,NULL,3,1,3,1,'RA117775095CN\r ','theabbd2'),(11689,728848409002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','pechblaende','ebay@trashstar.net','Joacim Nilsson','Mjölnarv 12','Växjö','','SWEDEN','35250','073-9877656','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 01:25:12',0,NULL,3,1,2,1,NULL,'pechblaende'),(11690,728868303002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','paulo_san_terros','paul.ryan4@gmail.com','Paul Ryan','32 Grattan Street<br>Carlton','Melbourne','Victoria','AUSTRALIA','3053','030468565248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 03:13:41',0,NULL,3,1,2,1,NULL,'paulo_san_terros'),(11691,687262574018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','ehwagon179','ehwagon@tpg.com.au','garry walsh','56 WOMRA CRESCENT<br>GLENMORE PARK','SYDNEY','New South Wales','AUSTRALIA','2745','0298346180','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-19 03:58:51',0,NULL,3,1,4,1,'YW865717743CN ','ehwagon179\rbackground support $25'),(11692,687584784001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','taz_ufrj','kiwi2free@yahoo.com','JULIO CORAL','9228 Lamont Ave.<br>Fl. 3','ELMHURST','NY','UNITED STATES','11373-2866','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-19 04:56:49',0,NULL,3,1,1,1,NULL,'taz_ufrj'),(11693,687276791018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','sergeynn52','volnmgk@mail.ru','Sergey Doronin','Vitebskay street, 46 - 121','Nizniy Novgorod','Nizegorodskay','RUSSIAN FEDERATION','603059','9103994323','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-19 05:51:35',0,NULL,3,1,5,1,'CP234126045CN ','sergeynn52\r欧标    220v'),(11694,728900369002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','dopeitskevin','dopeitskevin@yahoo.com','kevin baun','1640 Hilton Head Ct<br>Apt 2224','El Cajon','CA','UNITED STATES','92019-4523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 06:42:45',0,NULL,3,1,1,1,NULL,'dopeitskevin'),(11695,687291350018,280674081169,'New 67mm Snap-on Front Lens Cap for Nikon 67 mm lenscap',1,'AA1307',2.5,'photographyacc','timgasteen82','timgasteen@hotmail.com','TIMOTHY GASTEEN','U18-42 BEATTIE RD','COOMERA','Queensland','AUSTRALIA','4209','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-19 06:59:15',0,NULL,3,1,2,1,NULL,'timgasteen82'),(11696,741399233017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',1,'AB3314',6.69,'photographyacc','dolphin2319','cindykh@bigpond.net.au','Cindy Hitch','43 Third Street','Loxton','South Australia','AUSTRALIA','5333','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-19 07:33:25',0,NULL,3,1,17,0,NULL,'dolphin2319\r'),(11697,687291648018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','dolphin2319','cindykh@bigpond.net.au','Cindy Hitch','43 Third Street','Loxton','South Australia','AUSTRALIA','5333','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-19 07:33:27',0,NULL,3,1,17,0,NULL,'dolphin2319\r'),(11698,741399186017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','dolphin2319','cindykh@bigpond.net.au','Cindy Hitch','43 Third Street','Loxton','South Australia','AUSTRALIA','5333','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-19 07:33:26',0,NULL,3,1,3,1,'RA117776051CN\r ','dolphin2319\r带水平仪 热靴保护盖     1\r6片装的滤镜袋    2\r万用遮光罩        1'),(11699,728918551002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','chosencro','d0mbaa@gmail.com','Domagoj Buljan','Sjenjak 55','Osijek','Osiječko-Baranjska','CROATIA','31000','+385955532174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 08:04:56',0,NULL,3,1,3,1,'RA117776065CN\r ','chosencro\rgift $18'),(11700,728929569002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','polilla84','polilla25fb@yahoo.es','ALBERTO FLORES BECH','PASEO DELICIAS 7-9 BLQ2 3ºB<br>JEREZ DE LA FRONTERA','CADIZ','Andalucía Ceuta y Melilla','SPAIN','11406','639748212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 09:05:54',0,NULL,3,1,3,1,'RA117776122CN\r ','polilla84'),(11701,728940003002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','dialf1','filipovmail@yahoo.com','Filip Grzincic','Simonettieva 5','Rijeka','Croatia','CROATIA','51000','00385915297604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 09:21:13',0,NULL,3,1,3,1,'RA117776136CN\r ','dialf1'),(11702,687643799001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',2,'AB3307',99.98,'hermeshine','ballequin','ballequin@t-online.de','Elisabeth Hunger','Wurms Bichl 11','Durach','','GERMANY','87471','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-19 09:30:19',0,NULL,3,1,3,1,'RA117774974CN\r ','ballequin\r2个'),(11703,687343226018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','capturedbyjo','capturedbyjophotography@live.com.au','Joanne Camilleri','14 Jorgensen Avenue','St Clair','New South Wales','AUSTRALIA','2759','0298345766','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-19 09:54:37',0,NULL,3,1,3,1,'RA117776017CN\r ','capturedbyjo\r背景布 1.6x2.1m   2 (黑色)'),(11704,741468936017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',36,'photographyacc','arayrocamora','arayrocamora@yahoo.es','Aray Rocamora','Severna Ulica 84','Sokolce','Okr Komarno','SLOVAK REPUBLIC','94617','00421357780297','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-19 10:37:05',0,NULL,3,1,3,1,'RA117775317CN\r ','arayrocamora'),(11705,805266578015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','ozipenguin','pjcaudle@gmail.com','Phillip Caudle','Townhouse 4<br>147 Melville Parade','Como','Western Australia','AUSTRALIA','6152','0422992877','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 10:54:39',0,NULL,3,1,2,1,NULL,'ozipenguin'),(11706,728977413002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gdmopassan','cyber80@mail.ru','Eugene Kostromin','Belinskogo St.<br>180 - 24','Yekaterinburg','Sverdlovsk','RUSSIAN FEDERATION','620142','89022617761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 11:05:22',0,NULL,3,1,2,1,NULL,'gdmopassan'),(11707,687679369001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-19 11:17:03',0,NULL,3,1,17,0,NULL,'saud-p'),(11708,687371668018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',2,'AA3310',13.2,'photographyacc','elnino0408','markmcgregor@ymail.com','Jordan McGregor','17 Seapeak Rd<br>Ocean Reef','Perth','Western Australia','AUSTRALIA','6027','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-19 11:24:01',0,NULL,3,1,2,1,NULL,'elnino0408'),(11709,687378038018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','gwhitehead1982','greg@openhousetours.com.au','Greg Whitehead','4 Temora Rise','Berwick','Victoria','AUSTRALIA','3806','0425848878','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-19 11:26:20',0,NULL,3,1,2,1,NULL,'gwhitehead1982'),(11710,687378894018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','kenlyn54','kenlyno54@gmail.com','LYNETTE O\'TOOLE','9 WHYALLA PLACE','BURNSIDE','Victoria','AUSTRALIA','3023','0407864629','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-19 11:29:00',0,NULL,3,1,2,1,NULL,'kenlyn54'),(11711,805292027015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','glamshooter','info@glamshooter.co.uk','Allan Bridge','17, Clough acre<br>Astley village','Chorley','Lancashire','UNITED KINGDOM','PR7 1TU','01257231338','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 11:44:03',0,NULL,3,1,2,1,NULL,'glamshooter'),(11712,687705991001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','almearaj','aalmiraj5@gmail.com','Abdullah Jaffar Makki AlMearaj','P.O. Box 20028','Qateef','','SAUDI ARABIA','31911','00966503893668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 12:26:34',0,NULL,3,1,3,1,'RA117776082CN\r ','almearaj'),(11713,729015466002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','josepo.vender','ramon.nates@gmail.com','RAMON NATES CELIS','URBANIZACION SAN CIPRIANO CHALET A6','TRETO','Cantabria','SPAIN','39760','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 12:46:11',0,NULL,3,1,3,1,'RA117776140CN\r ','josepo.vender'),(11714,805325133015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','gazebow','gaz1@mac.com','Gaz de Vere','86 Southview Drive','Westcliff-on-Sea','Essex','UNITED KINGDOM','SS0 9QD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 12:53:52',0,NULL,3,1,2,1,NULL,'gazebow'),(11715,687455213018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','maxikes_777','maxikes777@gmail.com','Maxim Obolenskiу','Staropregol\'skaja naberezhnaja, 6-19','Kaliningrad','','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-19 14:33:40',0,NULL,3,1,2,1,NULL,'maxikes_777'),(11716,788834252016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','jaroslava4843','jaja1976@email.cz','Jaroslava Zigraiova','Severni 525','Otnice','','CZECH REPUBLIC','68354','+420777065000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 15:05:39',0,NULL,3,1,3,1,'RA117775042CN\r ','jaroslava4843'),(11717,687480305018,280678918166,'Neoprene Camera Cover Case for small Canon & semi slr S',1,'AC2303',6.6,'photographyacc','akuiperschan','kuota@netspace.net.au','Alan Kuipers-Chan','8 Statham Street<br>Glen Forrest','Perth','Western Australia','AUSTRALIA','6071','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-19 15:24:39',0,NULL,3,1,2,1,NULL,'akuiperschan'),(11718,805408084015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','japannerivo','ivo.hetty@ziggo.nl','Ivo Verboon','Aert van Neslaan 608','OEGSTGEEST','','NETHERLANDS','2341HV','(071) 5172784','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 15:29:45',0,NULL,3,1,2,1,NULL,'japannerivo'),(11719,805434954015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','pawhas123','mb-pl@wp.eu','Paul Joseph Has','8 Keogh Road','Stratford','London','UNITED KINGDOM','E15 4NR','02085347669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 16:03:55',0,NULL,3,1,2,1,NULL,'pawhas123'),(11720,687526240018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','gkoschar','gkoscharsky@dodo.com.au','George Koscharsky','5/11a Silex Rd','Mosman','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-19 16:43:15',0,NULL,3,1,2,1,NULL,'gkoschar'),(11721,687824053001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','rasmarkmagnus','magnusrasmark@gmail.com','magnus rasmark','Magnus Rasmark<br>Långgatan 26','Skellefteå','Västerbotten','SWEDEN','931 45','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 16:46:15',0,NULL,3,1,2,1,NULL,'rasmarkmagnus'),(11722,729165091002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','william-2004','wmchapman@rogers.com','William Chapman','PO Box 1658','Ogdensburg','NY','UNITED STATES','13669-6658','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-19 17:34:23',0,NULL,3,1,1,1,NULL,'william-2004'),(11723,805530959015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','apleaple78','apleaple@gmail.com','Dainis Birznieks','14 Broadleaf<br>Broad Street','Limerick','Limerick','IRELAND','default','0872844341','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 17:56:51',0,NULL,3,1,2,1,NULL,'apleaple78'),(11724,729228049002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','louzland','cdsaharanbazaar@yahoo.com','Carrie Skoog','1635 s wildrose','Mesa','AZ','UNITED STATES','85209-7793','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-19 18:51:51',0,NULL,3,1,1,1,NULL,'louzland'),(11725,789079405016,260660055455,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','furbally','furballyuk@yahoo.co.uk','James Nayler','Orwell Housing Association<br>Crane Hill Lodge, 325 London Rd','Ipswich','Suffolk','UNITED KINGDOM','IP2 0BE','07917565139','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-19 19:49:38',0,NULL,3,1,2,1,NULL,'furbally'),(11726,729272592002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','elaitorglez','elaitorglez@hotmail.com','Aitor Gonzalez','Avda. Camino de Santiago, 1, B, 2ºB','Madrid','Madrid','SPAIN','28050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 19:53:15',0,NULL,3,1,2,1,NULL,'elaitorglez'),(11727,687674760018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','trompik','polyana1@mail.ru','Pavel Kondrashin','13 Lubimova Street<br>Gornaya Polyana','Volgograd','Volgograd','RUSSIAN FEDERATION','400069','+7917-831-33-62','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-19 19:57:03',0,NULL,3,1,3,1,'RA117776096CN\r ','trompik'),(11728,729281496002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','tzvili','tsl999@gmail.com','tzvi lin','mevo dotan','mevo dotan ','dn tzfon hashomron','ISRAEL','44890','052-3115948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 20:07:30',0,NULL,3,1,3,1,'RA117775008CN\r ','tzvili'),(11729,687949605001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','hectorbaier','baierbar@gmail.com','Hector Baier','Regaim , Kenyoter , Hairusim 53<br>Regaim Shop','Ness Ziona','Ness Ziona','ISRAEL','74066','0544361091','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 20:12:36',0,NULL,3,1,2,1,NULL,'hectorbaier'),(11730,729286481002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','songoku3005','sijan.zoran@gmail.com','Zoran Sijan','Franje Rackog 3','Zadar','County of Zadar','CROATIA','23000','+385918854114','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-19 20:13:51',0,NULL,3,1,3,1,'RA117774869CN\r ','songoku3005'),(11731,687981012001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',3,'AA1308',7.8,'hermeshine','mhaskett','matthewhaskett@me.com','Matthew Haskett','2561 Jubilee DR','Turlock','CA','UNITED STATES','95380','(209) 634-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-19 20:21:25',0,NULL,3,1,1,1,NULL,'mhaskett'),(11732,687984978001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','beuh_dave','beuh.dave@gmail.com','David Ha','1909 - 219 Fort York Blvd.','Toronto','ON','CANADA','M5V 1B1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 20:29:14',0,NULL,3,1,3,1,'RA117774957CN\r ','beuh_dave'),(11733,729338514002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','mila.herink20','mila.herink@gmail.com','Milan Herink','1747 Fulton Avenue<br>West Vancouver','Vancouver','BC','CANADA','V7V1P5','(604) 360-5730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-19 22:04:55',0,NULL,3,1,3,1,'RA117776079CN\r ','mila.herink20'),(11734,805728154015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','085pauline','pchanratty@gmail.com','pauline hanratty','17 ardgleann<br>killygowan','monaghan','Monaghan','IRELAND','','4784943','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-19 22:27:21',0,NULL,3,1,2,1,NULL,'085pauline'),(11735,687772733018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','capturedbyjo','capturedbyjophotography@live.com.au','Joanne Camilleri','14 Jorgensen Avenue','St Clair','New South Wales','AUSTRALIA','2759','0298345766','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-20 00:00:47',0,NULL,3,1,17,0,NULL,'capturedbyjo'),(11736,741916976017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','tracic7182','tracicastle@gmail.com','traci castle','23 paget st','mooloolah valley','Queensland','AUSTRALIA','4553','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-20 00:57:57',0,NULL,3,1,2,1,NULL,'tracic7182'),(11737,729405636002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','loraelissmoda','loraeliss@hotmail.com','Larissa Elissavettchenko','387 Parramatta Road','Leichhardt','New South Wales','AUSTRALIA','2040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 02:41:46',0,NULL,3,1,3,1,'RA117775440CN\r ','loraelissmoda\r澳标'),(11738,688098274001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','syftju','yunfangsun@hotmail.com','Yunfang Sun','706 S Rodney French Blvd','New Bedford','MA','UNITED STATES','02744-1221','(508) 207-0854','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 03:05:50',0,NULL,3,1,1,1,NULL,'syftju'),(11739,687828356018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',15.99,'photographyacc','5107lmd','loisdickins@hotmail.com','LOIS DICKINS','14 WATTLE DRIVE<br>PO BOX 33','LAKE GRACE','Western Australia','AUSTRALIA','6353','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-20 03:45:33',0,NULL,3,1,2,1,' ','5107lmd'),(11740,688125100001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','mcguisso','rantoine_uy@hotmail.com','Maria Guisso Fernandez','Feliciano Rodriguez 3184 Ap. 1','Montevideo','Montevideo','URUGUAY','11600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 04:24:02',0,NULL,3,1,5,1,'CP234126031CN ','mcguisso'),(11741,741991852017,270750687158,'New Camera shoulder bag A1 for Canon Dslr 550D 500D',1,'AO0029',25.8,'photographyacc','9446melinda','melinm@optusnet.com.au','MELINDA MCDONELL','2 DONALD ST<br>ASHBURTON','ASHBURTON','Victoria','AUSTRALIA','3147','0398138108','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-20 06:25:34',0,NULL,3,1,3,1,'RA117775325CN\r ','9446melinda'),(11742,687869000018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',245,'photographyacc','ingenero01','alichoudaris@hotmail.com','Adam Lichoudaris','53 Alma Street','Lower Plenty','Victoria','AUSTRALIA','3093','0394448789','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-20 07:33:37',0,NULL,3,1,4,1,'YW866011290CN ','ingenero01'),(11743,741629204017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',2,'AA1206',5.8,'photographyacc','bennny69','benedict88@hotmail.com','benedetto cascelli','via delle benedettine 90','roma','Roma','ITALY','00135','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-20 08:17:15',0,NULL,3,1,2,1,NULL,'bennny69'),(11744,729483213002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mpepe20','mpepe1982@gmail.com','SzéP GyörGY','Jókai u. 22. fsz 2.','Budapest','Budapest','HUNGARY','1195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 08:19:49',0,NULL,3,1,3,1,'RA117775731CN\r ','mpepe20'),(11745,729489975002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','raniasulin','asulinrani@gmail.com','rani asulin','hamachtarot','atlit','israel','ISRAEL','30300','(972) 542-3397 ext.: 73','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-20 08:51:34',0,NULL,3,1,3,1,'RA117775745CN\r ','raniasulin'),(11746,688181260001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ibelov','photo-z@ya.ru','Ivan Belov','Frunze 21-68','Nizhny Novgorod','','RUSSIAN FEDERATION','603155','+7920 256 01 46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 09:28:43',0,NULL,3,1,2,1,NULL,'ibelov'),(11747,729502190002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','igor0109','oxygen91@mail.ru','Igor Kuzmenko','Punane 39-15','Tallinn','','ESTONIA','13611','+37258136580','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 09:44:01',0,NULL,3,1,2,1,NULL,'igor0109'),(11748,742049129017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','5moles','janetm01@optusnet.com.au','Janet Moloney','2 Butler street','Essendon','Victoria','AUSTRALIA','3040','0393700094','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-20 10:31:37',0,NULL,3,1,2,1,NULL,'5moles'),(11749,688200032001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','chris_aycin','trackash@gmail.com','Guy Mor','29b Hertzog St. APT. 11','Givatayim','PW','ISRAEL','53602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 10:46:44',0,NULL,3,1,2,1,NULL,'chris_aycin\r欧标\r'),(11750,789387459016,260660053578,'New Pro Photo Vest for all DSLR fans Size: XL',1,'AA1104',17.8,'hutongstore','schoolteacher2860','bjorn@matsen.dk','bjorn matsen','niels bohrs allé 15','soborg','','DENMARK','2860','+4539699675','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-20 11:12:06',0,NULL,3,1,3,1,'RA117775970CN ','schoolteacher2860'),(11751,729525543002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','mrtyler_durden','veresvl@yandex.ru','Vladimir Veres','176 Lenin Street Apartment № 74','Blagoveshensk','Amur Oblast','RUSSIAN FEDERATION','675006','+7 914 5563848','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:15:52',0,NULL,3,1,2,1,NULL,'mrtyler_durden'),(11752,729526737002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','nks152','jalamasurf@gmail.com','nicholas sprankles','CMR 416 Box 538','APO','AE','AA','09140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 11:18:12',0,NULL,3,1,17,0,NULL,'nks152'),(11753,688208827001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.87,'hermeshine','nks152','jalamasurf@gmail.com','nicholas sprankles','CMR 416 Box 538','APO','AE','AA','09140','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 11:20:27',0,NULL,3,1,1,1,NULL,'nks152\r77mm 转接环    1\r普通托架   1\r广角托架   1'),(11754,729529774002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','luboso87','lubos.svehla@gmail.com','Ladislav Švehla','V.Clementisa 26','Trnava','','SLOVAK REPUBLIC','91701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 11:29:01',0,NULL,3,1,2,1,NULL,'luboso87'),(11755,729536374002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','kwotti','katy.floc@gmail.com','Ekaterina Pisarenkova','Shishkanya<br>25/56','Vsevolozsk','Leningradskaya oblast','RUSSIAN FEDERATION','188643','+7 9111669481','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-20 11:51:04',0,NULL,3,1,3,1,'RA117775983CN ','kwotti\r近摄镜 +8 换成 +4的'),(11756,789401982016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','nevermind2310','jivkamm@yahoo.co.uk','zhivka MARINOVA','2 KIMBERLEY ROAD','LONDON','London','UNITED KINGDOM','NW67SG','07983640590','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 11:52:36',0,NULL,3,1,3,1,'RA117775918CN ','nevermind2310'),(11757,685754312018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','gregjrandall','gregory.randall@internode.on.net','Greg Randall','92 Main Road','SPEERS POINT','New South Wales','AUSTRALIA','2284','0249588246','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-20 12:21:46',0,NULL,3,1,2,1,NULL,'gregjrandall'),(11758,687985011018,280695078945,'Aluminium Lightweight 68\" Camera Monopod with ballhead ',1,'AE1604',38,'photographyacc','b-kubik','b-kubik@mail.ru','Kirill Baiguzin','Karbisheva 20-67','Novokuibyshevsk','Samarskaya Oblast','RUSSIAN FEDERATION','001','89608203434','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-20 14:38:17',0,NULL,3,1,3,1,'RA117775935CN ','b-kubik'),(11759,687988167018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','vsemjon10','v.semjon@yahoo.com','Simon Vedeneev','Sovetskaja 7/5 - 82','Ekaterinburg','Ekaterinburg','RUSSIAN FEDERATION','620049','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-20 14:48:36',0,NULL,3,1,3,1,'RA117775949CN ','vsemjon10'),(11760,688282147001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.3,'hermeshine','janjan86','janiceleigh68@yahoo.com','Janice Erickson','PO Box 2412','Bigfork','MT','UNITED STATES','59911-2412','(406) 210-5079','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 15:22:56',0,NULL,3,1,1,1,NULL,'janjan86'),(11761,729615353002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rolas1313','landocovi13@alice.it','rolando covini','via f. rè 10','cerro maggiore','MI','ITALY','20023','0331  421850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 15:57:17',0,NULL,3,1,2,1,NULL,'rolas1313'),(11762,789502491016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','pinred08','info@pinredstudio.com','Khipash Siriweerapat','120/20-21, 2 Soi Pramote 3, Mahesak Rd. Suriyawong, Bangrak<br>Suriyawong, Bangrak','default','BA','THAILAND','10500','0818552093','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-20 16:07:43',0,NULL,3,1,3,1,'RA117775921CN ','pinred08'),(11763,688303344001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','xchen8868','zhihuichn@cox.net','Xiaolun Chen','1400 Warbler Ter','Cantonment','FL','UNITED STATES','32533-5819','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 16:19:31',0,NULL,3,1,17,0,NULL,'xchen8868'),(11764,688303124001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','xchen8868','zhihuichn@cox.net','Xiaolun Chen','1400 Warbler Ter','Cantonment','FL','UNITED STATES','32533-5819','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 16:19:31',0,NULL,3,1,17,0,NULL,'xchen8868'),(11765,688302726001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','xchen8868','zhihuichn@cox.net','Xiaolun Chen','1400 Warbler Ter','Cantonment','FL','UNITED STATES','32533-5819','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 16:19:32',0,NULL,3,1,17,0,NULL,'xchen8868'),(11766,688299027001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',4.95,'hermeshine','xchen8868','zhihuichn@cox.net','Xiaolun Chen','1400 Warbler Ter','Cantonment','FL','UNITED STATES','32533-5819','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-20 16:19:32',0,NULL,3,1,1,1,NULL,'xchen8868\r绿叶 CPL  52mm      1\r绿叶 CPL  77mm      1\r绿叶 渐变灰  52mm      1\r绿叶 渐变灰  77mm      1'),(11767,742174391017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','baseballchook36','bigshow@adam.com.au','Glenn  Roebuck','16 Ian st Morphett Vale','Adelaide','South Australia','AUSTRALIA','5162','0883822032','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-20 16:39:53',0,NULL,3,1,3,1,'RA117720154CN\r ','baseballchook36'),(11768,729646707002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','csgyuri87','cs.gyorgy@index.hu','György Csaba','Csillag utca 35.','Budapest','Budapest','HUNGARY','1193','06205288945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 17:13:19',0,NULL,3,1,2,1,NULL,'csgyuri87'),(11769,688053331018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',15.98,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-20 17:28:35',0,NULL,3,1,2,1,NULL,'igrom78'),(11770,729673155002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',5,'AKT051',57.5,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-20 18:08:52',0,NULL,3,1,3,1,'RA117775966CN ','igrom78\r10只'),(11771,806178980015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',6.7,'hutongstore','123isme','mandy.ellis44@yahoo.com','Mandy ellis','16 East Ridge View','Bideford','Devon','UNITED KINGDOM','ex39 4rs','07858945869','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-20 19:03:20',0,NULL,3,1,2,1,NULL,'123isme'),(11772,740986457017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','houseofswank*','shop_fast@yahoo.com.au','Imogen Tame','2 Yarrah Street<br>KOORINGAL','WAGGA WAGGA','New South Wales','AUSTRALIA','2650','0420670889','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-20 21:52:44',0,NULL,3,0,3,1,'RA117776003CN ','houseofswank*\r1.6x3m  白色'),(11773,688174645018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','nikki355','nikkihaskell355@msn.com','Nicole Haskell','21 Bunker Ave','Nanango','Queensland','AUSTRALIA','4615','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-20 22:00:50',0,NULL,3,1,4,1,'YW864941644CN ','nikki355\r背景布换成\"黑色\"的'),(11774,804223381015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','marsalbeads','beadsmarsal@yahoo.com','Jeannette Speers','La Fregiere','MARSAL','Tarn','FRANCE','81430','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-20 22:54:15',0,NULL,3,1,2,1,NULL,'marsalbeads'),(11775,688200526018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','neolasman','contact@perez-nicolas.fr','Nicolas Perez','App. 2058<br>335 Rue des Gabares','Montpellier','Languedoc-Roussillon','FRANCE','34000','0675401413','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-20 23:04:35',0,NULL,3,1,2,1,NULL,'neolasman'),(11776,688477092001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','planetask','planetaskus@yahoo.com','Hossein Kazemi','3 Kings Rd','Sharon','MA','UNITED STATES','02067','(508) 565-1276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-20 23:06:27',0,NULL,3,1,3,1,'RA117775952CN ','planetask\r已收到好评'),(11777,739697579017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','fitzabroad','fitzabroad@aapt.net.au','John FitzGerald','27 Albert Road','Warrandyte','Victoria','AUSTRALIA','3113','0398442727','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-20 23:15:36',0,NULL,3,1,2,1,NULL,'fitzabroad'),(11778,742372692017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','btrindaderuiz','brunotruiz@gmail.com','Bruno Ruiz','Rua Santa Faustina, 110','São Paulo','São Paulo','BRAZIL','02541-060','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-21 00:09:25',0,NULL,3,1,2,1,' ','btrindaderuiz'),(11779,727310992002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','uv80','mrfigger@yahoo.com','Mike Figger','492 Martin Rd','New Berlin','NY','UNITED STATES','13411-2632','(941) 204-0764','NoPaymentFailure','CheckoutComplete','Other','2011-06-21 00:55:24',0,NULL,3,0,1,1,'LK060896925CN','uv80\r背心 Canon  老款    2XL    1(已入库)'),(11780,729830524002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','yodaddi','yodaddi@sc.rr.com','Jeff Gerald','397 Timbermill Dr','Lexington','SC','UNITED STATES','29073-7162','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 01:18:32',0,NULL,3,1,1,1,NULL,'yodaddi'),(11781,688247021018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','garvinwu','garvin@ricestudios.com.au','Garvin Wu','18 Strand Close','Glen Waverley','Victoria','AUSTRALIA','3150','0395608029','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-21 02:08:55',0,NULL,3,1,3,1,'RA117776175CN ','garvinwu'),(11782,742395083017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',37.67,'photographyacc','madmoofie','madmoofie@hotmail.com','E R Jolley','41 Stingaree Point Drive','Dora Creek','New South Wales','AUSTRALIA','2264','0249705301','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-21 02:32:04',0,NULL,3,1,3,1,'RA117775997CN ','madmoofie \r(已入库)\r绿叶 UV  58mm     1\r绿叶 58mm  近摄镜  +4    1\r绿叶 58mm  渐变灰   1\rMini 红外 Canon  1\r4片装滤镜袋    1\r气吹+布+笔      1\r\r'),(11783,688252527018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','tasae86','igetemail@hotmail.com','Vaughan Harvey','C- Jacksons Security<br>49 Wilmot St','Burnie','Tasmania','AUSTRALIA','7320','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-21 02:38:15',0,NULL,3,1,2,1,NULL,'tasae86'),(11784,688532052001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 03:15:51',0,NULL,3,1,8,1,'CP234126076CN ','saud-p\r要附上纸质发票; 还要在产品上贴身Made in China'),(11785,688270053018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',7.99,'photographyacc','drunknpon','tponz01@tpg.com.au','simonkun pathepsina','18 sutton street','chelsea heights','Victoria','AUSTRALIA','3196','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-21 04:00:34',0,NULL,3,1,2,1,NULL,'drunknpon'),(11786,688284527018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','crijeee','freestyle2@optusnet.com.au','Ken Free','90 Fitzroy Street','Sale','Victoria','AUSTRALIA','3850','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-21 05:24:48',0,NULL,3,1,4,1,'YW864941622CN ','crijeee\rbackground support $25\r0630-ebay系统显示已签收.'),(11787,688561002001,110583278219,'TianYa 62mm CPL filter New 62 Circular Polarizing C-PL',1,'AA2304',6.5,'hermeshine','koiyen','koiyen@hotmail.com','chin koiyen','blk 650 senja link #14-02 s670650','singapore','none','SINGAPORE','670650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 05:59:03',0,NULL,5,0,18,0,NULL,'koiyen'),(11788,688561187001,110583278181,'TianYa 55mm CPL filter New 55 Circular Polarizing C-PL',1,'AA2302',5.7,'hermeshine','koiyen','koiyen@hotmail.com','chin koiyen','blk 650 senja link #14-02 s670650','singapore','none','SINGAPORE','670650','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 06:00:08',0,NULL,3,1,11,1,' ','koiyen\r'),(11789,729886664002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','fito1986','fcruz_r@yahoo.com','Frank Cruz','6122 Pearce Ave','Lakewood','CA','UNITED STATES','90712-1311','(714) 396-3321','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 06:12:03',0,NULL,3,1,1,1,NULL,'fito1986'),(11790,729891441002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','newbrood1982','newbrood21@yahoo.com.sg','Tommy Lin','blk 21 joo seng rd #02-182','default','sg','SINGAPORE','360021','96576832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 06:43:12',0,NULL,3,1,11,1,NULL,'newbrood1982'),(11791,688300379018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','zhuravlev','andyzr@mail.ru','Andrey Zhuravlev','Bolotnikovskaya, 20-40','Moskow','','RUSSIAN FEDERATION','117149','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-21 06:56:02',0,NULL,3,1,2,1,NULL,'zhuravlev'),(11792,688576429001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',3.4,'hermeshine','greatapoc','petenewsome@gmail.com','Peter Newsome','Soul Communications<br>Level 2 11-17 Mosbri Cr','Newcastle','New South Wales','AUSTRALIA','2300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 07:28:20',0,NULL,3,1,2,1,NULL,'greatapoc'),(11793,742464644017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','impression_sky','solilo@mail.ru','Minaev Pavel','Bratskaya 15/1, app 65','Moscow','Moscow','RUSSIAN FEDERATION','111397','+79629537371','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-21 07:31:15',0,NULL,3,1,2,1,' ','impression_sky'),(11873,742985075017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','wal_ben','rac.reed@bigpond.com','Carolyn Reed','17 Hilma Street','Collaroy Plateau','New South Wales','AUSTRALIA','2097','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 13:08:57',0,NULL,3,1,2,1,NULL,'wal_ben'),(11794,806475820015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','maszine','sylwiusz@poczta.onet.pl','Sylwester Dziegielewski','31 Wodehouse Road','Leicester','Leicestershire','UNITED KINGDOM','LE3 1PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-21 10:41:44',0,NULL,3,1,2,1,NULL,'maszine'),(11795,688338319018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-21 10:51:04',0,NULL,3,1,2,1,NULL,'bfg27248937'),(11796,789904014016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','lauraposse','lcox@westberks.org','Laura Cox','87 Bathurst Road<br>Winnersh','Wokingham','Berkshire','UNITED KINGDOM','RG41 5JF','01189619914','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-21 10:57:24',0,NULL,3,1,3,1,'RA117776635CN\r ','lauraposse\r背景布 1.6x3m   1 (白)'),(11797,688621530001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3302',5.9,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 11:03:05',0,NULL,3,1,2,1,NULL,'aaivanov'),(11798,688622833001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','nerik1','jan.erik.sundoy@online.no','Jan Erik Sundøy','c/o Stjordalens Blad<br>postboks 163','Stjordal','','NORWAY','7501','+4790586311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 11:08:39',0,NULL,3,1,3,1,'RA117776697CN\r ','nerik1'),(11799,729952965002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','vadim_veter','wind999@mail.ru','Vadim Veter','Stahanovtsev street 16-20','Saint-Petersburg','','RUSSIAN FEDERATION','195196','(921)333-0219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 11:25:31',0,NULL,3,1,17,0,NULL,'vadim_veter'),(11800,688627594001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','vadim_veter','wind999@mail.ru','Vadim Veter','Stahanovtsev street 16-20','Saint-Petersburg','','RUSSIAN FEDERATION','195196','(921)333-0219','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 11:29:36',0,NULL,3,1,3,1,'RA117776706CN\r','vadim_veter\r防寒罩   1\r反光板支架    1'),(11801,688367421018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','boggles1985','bogglesmcb85@hotmail.com','rebekah bull','24 dalmor ave','ormond','Victoria','AUSTRALIA','3204','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-21 11:53:53',0,NULL,3,0,3,1,'RA117776670CN\r ','boggles1985\r1.6x2.1  3  （白 + 黑 + 粉）'),(11802,729965280002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','aleksandrwhite722','b_ar@mail.ru','Belyh Aleksandr (Белых Александр)','Oktyabr\'skaya str.13a - 19 (Октябрьская д.13а-кв.19)','VOLOGDA (Вологда)','','RUSSIAN FEDERATION','160000','89217227373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 12:10:54',0,NULL,3,1,2,1,NULL,'aleksandrwhite722'),(11803,688377589018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','solaris9uk','solaris9uk@yahoo.co.uk','Steve Brown','12 Sunset Place<br>Frenchs Forest','Sydney','New South Wales','AUSTRALIA','2086','0402584231','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-21 12:31:40',0,NULL,3,0,4,1,'YW864941611CN ','solaris9uk\rbackground support  $25\r0630-0701YW系统显示已签收'),(11804,729973207002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','davideibiza','info@davide.baraldi.name','davide baraldi','via Sacco, 66','Assemini','CA','ITALY','09032','3801376905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 12:41:46',0,NULL,3,1,2,1,NULL,'davideibiza'),(11805,688386296018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','pcwca','pcwca@hotmail.com','wu yuchang','van eyck van voorthuyzenweg # 2','CURACAO','Netherlands Antilles','NETHERLANDS ANTILLES','047','0059996790333','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-21 12:55:02',0,NULL,3,1,2,1,NULL,'pcwca'),(11806,729979062002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','doremigio','redore@aliceposta.it','REMIGIO DOREMI','SALARIA,29 C/O BNL','PAGLIARE DEL TRONTO','AP','ITALY','63036','39-073586296','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:02:57',0,NULL,3,1,2,1,NULL,'doremigio'),(11807,742552771017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','erinjlangford','erin_langford01@hotmail.com','Erin Langford, Thats Life Magazine','8 Central Avenue<br>Eveleigh','Sydney','New South Wales','AUSTRALIA','2015','0298342835','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-21 13:12:01',0,NULL,3,1,17,0,NULL,'erinjlangford'),(11808,688395513018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',2,'AKT056',110,'photographyacc','erinjlangford','erin_langford01@hotmail.com','Erin Langford, Thats Life Magazine','8 Central Avenue<br>Eveleigh','Sydney','New South Wales','AUSTRALIA','2015','0298342835','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-21 13:29:45',0,NULL,3,1,4,1,'YW865908003CN ','erinjlangford\r反光板支架    2\r2m  灯架    2\r肥皂盒 柔光罩   580EX     1\rreflector holder  $25\r'),(11809,688396752018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','yiyangyixuan','yiyangyyx@gmail.com','Dapeng LIU','8/35-37 Tramway st','West Ryde','New South Wales','AUSTRALIA','2114','0405271390','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-21 13:29:52',0,NULL,3,1,3,1,'RA117776683CN\r ','yiyangyixuan'),(11810,688661533001,110591560700,'82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT054',4.87,'hermeshine','hnoyleon','melnikoff1@mail.ru','Leonid Melnikov','st. Udarnaya d.31 kv.140','Biisk','Altai Territory','RUSSIAN FEDERATION','659305','89133603538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:33:49',0,NULL,3,1,2,1,NULL,'hnoyleon'),(11811,729988105002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','lihertxo','malek@kaixo.com','jabi saiz tolosa','beraun kalea 1 3.E','orereta','País Vasco','SPAIN','20100','943536058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:34:58',0,NULL,3,0,4,1,'YW865908121CN ','lihertxo\r三脚架  伟峰 WF-6662A  + 6160H    1(已入库)\r'),(11812,688662701001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','sartazbdt1','sartazbdt@yahoo.com','sartaz khan','238 high brook dr','richardson','TX','UNITED STATES','75080-2031','(512) 577-7229','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 13:39:28',0,NULL,3,1,1,1,NULL,'sartazbdt1'),(11813,729941772002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mrcavad','info@premier.net.az','Cavad Mamedov','Balabala Mecidov 56','Baku','','AZERBAIJAN','az1009','0707455565','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 13:42:55',0,NULL,3,1,2,1,NULL,'mrcavad'),(11814,730015999002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','webixe','webmaster@webixe.com','Pierre-Olivier Beaudry','1842 préfontaine','montreal','QC','CANADA','h1w2p1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-21 15:06:55',0,NULL,3,1,3,1,'RA117776578CN\r ','webixe'),(11815,688715235001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','budda1234738','pedesol@online.no','peder solås','store Elvegate 89','mandal, Vest Agder','mandal','NORWAY','4517','+4738264187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 16:22:54',0,NULL,3,1,3,1,'RA117720070CN\r ','budda1234738\r3*77mm  Canon  镜头盖\r3*72mm  Canon  镜头盖\r2*67mm  Canon  镜头盖\r2*58mm   Canon  镜头盖'),(11816,688716968001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','rowdy406','rowdygillen@yahoo.com','Crystal Gillen','911 5th Ave NW','Great Falls','MT','UNITED STATES','59404','(406) 761-8396','NoPaymentFailure','CheckoutComplete','Other','2011-06-21 16:27:42',0,NULL,3,1,1,1,NULL,'rowdy406\r背心 蓝色薄  3XL    1(已入库)'),(11817,688723658001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','pentasero','pandonet@gmail.com','Fernando Merelo Rodriguez','c/ Salamanca,10 Bajo B','Alcala de Henares','Madrid','SPAIN','28804','918814959','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-21 16:46:35',0,NULL,3,1,3,1,'RA117776618CN\r ','pentasero'),(11818,806626153015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','tonyk-1979','tony_g@mail.ru','Golovan Anton','Central Prospect 440-216','Zelenograd','MO','RUSSIAN FEDERATION','124498','79168113765','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-21 16:55:03',0,NULL,3,1,2,1,NULL,'tonyk-1979'),(11819,687281051001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','faun13_68','san775469@yandex.ru','Alexander Zaharevskiy','13 micro - district Uzniy, 219','Tambov','68','RUSSIAN FEDERATION','392525','74752775469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 16:56:16',0,NULL,3,1,2,1,NULL,'faun13_68'),(11820,685415959001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cfan6445','annfantauzzi@yahoo.com','CAROLYN FANTAUZZI','2 ASHLOR DR','MIDDLE GROVE','NY','UNITED STATES','12850-9517','(518) 584-1735','NoPaymentFailure','CheckoutComplete','Other','2011-06-21 17:10:34',0,NULL,3,1,1,1,NULL,'cfan6445\r背心 Nikon 老款  M   1(已入库)'),(11821,730065737002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','maxclementi','massimo.clementi@hotmail.com','Massimo Ing. Clementi','piazza Umberto I°, n.9','Soriano nel Cimino','VT','ITALY','01038','+393355786542','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-21 17:31:09',0,NULL,3,0,3,1,'RA117776581CN\r ','maxclementi\r背心 Canon  老款    L   1(已入库)\r申报： photo vest $15'),(11822,806712236015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','ttkacik','tomas@linuxos.sk','Tomas Tkacik','Bauerova 21','Kosice','','SLOVAK REPUBLIC','04023','00421904076477','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-21 19:27:18',0,NULL,3,1,2,1,NULL,'ttkacik'),(11823,688829662001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','sovenok1981','sovenok13@bk.ru','Sergey Morgunov','pr. Lenina dom 2, korpus 1, kvartira 23<br>Пр. Ленина д2 корп1 кв23','Elektrostal','','RUSSIAN FEDERATION','144006','8(926)255-32-05','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 20:45:29',0,NULL,3,1,17,0,NULL,'sovenok1981'),(11824,688830248001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','sovenok1981','sovenok13@bk.ru','Sergey Morgunov','pr. Lenina dom 2, korpus 1, kvartira 23<br>Пр. Ленина д2 корп1 кв23','Elektrostal','','RUSSIAN FEDERATION','144006','8(926)255-32-05','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 20:45:29',0,NULL,3,1,3,1,'RA117776564CN\r ','sovenok1981\r45w 5500k 灯泡 220v      4'),(11825,730160547002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE3102',23.67,'hermeshine','dgd9','icenyne@aol.com','David DiCarlo','5953 McNaughton','Kyle','TX','UNITED STATES','78640','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-21 20:51:20',0,NULL,3,1,1,1,NULL,'dgd9'),(11826,688473335001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','aglentzakis','aglentzakis2000@yahoo.gr','Andreas Glentzakis','KIFISIAS 4','ATHENS','AMPELOKIPI','GREECE','11526','6944940327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 21:12:44',0,NULL,3,1,2,1,NULL,'aglentzakis'),(11827,730167301002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','svemorte','smort@mimer.no','Svein Magne Mortensen','Ekornbakken 38','Molde','','NORWAY','6425','95812038','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 21:13:05',0,NULL,3,1,2,1,NULL,'svemorte'),(11828,730184514002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','realpress','gcampos@realphotos.com.br','Gladstone campos','Alameda Joaquim Eugenio de Lima, 1213 - Ap. 103<br>Jardim Paulista','Sao Paulo','SP','BRAZIL','01403-003','5511 81816711','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-21 21:59:50',0,NULL,3,1,3,1,'RA117776652CN\r ','realpress'),(11829,730190379002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',6.2,'hermeshine','i.petrofff','i.petroff@mail.bg','Ivelin Petrov','320 Crestone Lane - apartment 14 (Cheyenne Vista Apartments)','Colorado Springs','CO','UNITED STATES','80905','(719) 237-0967','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-21 22:13:58',0,NULL,3,1,1,1,NULL,'i.petrofff'),(11830,688889772001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','gawaltz','gwaltz000@gmail.com','GREGORY WALTZ','1650 Lonnie Watson Rd','Newton','AL','UNITED STATES','36352','','NoPaymentFailure','CheckoutComplete','Other','2011-06-22 00:13:10',0,NULL,3,1,1,1,NULL,'gawaltz'),(11831,730229590002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',5.5,'hermeshine','2010rickybaker','linchitat@gmail.com','Ricky lin','50-130 hyndman cres NW','Edmonton','AB','CANADA','t5a0e8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 00:56:18',0,NULL,3,1,2,1,NULL,'2010rickybaker\r'),(11832,688394690018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','aussie_squeak','aaronjade@dodo.com.au','Jade Tierney','8 Blue Jay Cres','Tarneit','Victoria','AUSTRALIA','3029','0397492702','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 01:05:45',0,NULL,3,1,3,1,'RA117776666CN\r ','aussie_squeak\r1.6x2.1 2   黑   白'),(11833,742826315017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',3,'AD1111',114,'photographyacc','aliasjq','achristianto83@gmail.com','Adrian Christianto','UCS Financial Services<br>Building G, Level 2, 1 Homebush Bay Drive','RHODES','New South Wales','AUSTRALIA','2138','0405267371','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-22 01:27:05',0,NULL,3,1,4,1,'YW865908040CN ','aliasjq\r1.24\rcamera strap  $15\r'),(11834,688644209018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','mishchenkov','victoria.mishchenko@gmail.com','Victoria','Level 1/ 1155 High street<br>Armadale','Melbourne','Victoria','AUSTRALIA','3143','0420946255','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-22 02:01:51',0,NULL,3,1,3,1,'RA117776649CN\r ','mishchenkov'),(11835,688919027001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','bader_dhaifallah','b1407@live.com','bader alomayri','74 Alexander Crescent otara<br>MIT Student village Gate 15','Manukau','Auckland','NEW ZEALAND','2023','0064211774593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 02:24:42',0,NULL,3,1,2,1,NULL,'bader_dhaifallah\r转接环换成77mm的'),(11836,742849721017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','iliodos','ebay275@kanastacorp.com','Valent Lau','Optiver<br>39 Hunter St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 03:02:57',0,NULL,3,1,2,1,' ','iliodos\r86'),(11837,730262184002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','christineb9577','christine.bordeleau@candsl.com','Christine Bordeleau','15 Parsons Ridge','Kanata','ON','CANADA','K2L 2M1','(613) 831-5652','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-22 03:18:32',0,NULL,3,1,3,1,'RA117776961CN ','christineb9577\rM'),(11838,688931424001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','mendibla','foto.carlosserrano@gmail.com','carlos serrano cubells','carretera portichol 89, local 1','javea','Alicante','SPAIN','03730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 03:28:26',0,NULL,3,0,17,0,NULL,'mendibla'),(11839,730264686002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',4,'AO0005',72,'hermeshine','mendibla','foto.carlosserrano@gmail.com','Carlos Serrano','portichol 89, local 1<br>n/a','javea','Alicante','SPAIN','0330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 03:33:07',0,NULL,3,1,4,1,'YW865908095CN','mendibla\r1.6x2.1m   背景布    2(黑)\r1.6x3m   背景布    4(红/粉/黄/蓝)\rCarlos Serrano Cubells\rcarretera portichol 89, local 1\rjavea Alicante 03730\rSPAIN\r'),(11840,688941575001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','newzealandgeoff','geoff.p@xtra.co.nz','Geoff Procter','66D Ararino Street<br>Trentham','Upper Hutt','','NEW ZEALAND','5018','0064 27 3085557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 04:26:16',0,NULL,3,1,2,1,NULL,'newzealandgeoff'),(11841,730274599002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','fred_star101','fred_star@intnet.mu','Foo shin Frederic','8 cook st','Port Louis','Port louis','MAURITIUS','000000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 04:31:56',0,NULL,3,1,2,1,NULL,'fred_star101'),(11842,688950791001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','buysellauctions','pmoallemian@operamail.com','Pedram Moallemian','8718 Cadillac Ave','Los angeles','CA','UNITED STATES','90034-2104','(310) 339-1155','NoPaymentFailure','CheckoutComplete','Other','2011-06-22 05:24:40',0,NULL,3,0,1,1,NULL,'buysellauctions\rXXXL  (已入库）'),(11843,742880192017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.88,'photographyacc','t-roy22','tamarkides@hotmail.com','Troy Markides','5 Sloans Road','warrandyte','Victoria','AUSTRALIA','3113','0398444736','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-22 05:54:00',0,NULL,3,1,17,0,NULL,'t-roy22'),(11844,688707579018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','t-roy22','tamarkides@hotmail.com','Troy Markides','5 Sloans Road','warrandyte','Victoria','AUSTRALIA','3113','0398444736','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-22 05:55:56',0,NULL,3,1,2,1,NULL,'t-roy22\r方形滤镜接口环 77mm   1\r方镜广角托架（ 一槽）    1'),(11845,688711204018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','spinfx_creations','spinfxtc@hotmail.com','David Sickerdick','Unit 1/2a Phillips Rd','Berri','South Australia','AUSTRALIA','5343','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-22 06:16:49',0,NULL,3,1,3,1,'RA117777057CN ','spinfx_creations'),(11846,730292769002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','loonatonk','biljana.aljinovic@gmail.com','Biljana Aljinovic','Zabrijeze 101','Babino Polje, Mljet','Dubrovacko-Neretvanska zupanija','CROATIA','20225','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 06:21:58',0,NULL,3,1,2,1,NULL,'loonatonk'),(11847,688965846001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','redandjen','mlee1970@bigpond.com','Michael Lee','3 Burt Street<br>Mt Clarence','Albany','Western Australia','AUSTRALIA','6330','0898418774','NoPaymentFailure','CheckoutComplete','AU_Express','2011-06-22 06:57:17',0,NULL,3,1,4,1,'YW865908036CN ','redandjen\r澳标\rLighting kit   $20\r已受到好评'),(11848,688720449018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',4,'AO0005',43.96,'photographyacc','mini.minge','nix.shutterbug@gmail.com','Nicole Miller','Unit 3<br>153 Government Road','LABRADOR','Queensland','AUSTRALIA','4215','0451109709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 07:06:44',0,NULL,3,0,4,1,'YW865908132CN','mini.minge\r1.6*2.1m    背景布    5(粉/红/黄/浅蓝)\r1.6x3m       背景布    2(灰/白)'),(11849,742894434017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','mini.minge','nix.shutterbug@gmail.com','Nicole Miller','Unit 3<br>153 Government Road','LABRADOR','Queensland','AUSTRALIA','4215','0451109709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 07:10:41',0,NULL,3,0,17,0,' ','mini.minge'),(11850,688685903001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',169.74,'hermeshine','chris_aycin','trackash@gmail.com','Guy Mor','29b Hertzog St. APT. 11','Givatayim','PW','ISRAEL','53602','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:50:13',0,NULL,3,1,12,1,'BJ8823301','chris_aycin\r欧标\r柔光箱 60-60cm  四灯头     1\r斜臂    1\r2m弹簧灯架     1\r'),(11851,688976145001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','peretanos','peretanos@hotmail.com','pedro jose roman','gomez oreña 15','santander','Cantabria','SPAIN','39003','626769333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:55:58',0,NULL,3,1,17,0,NULL,'peretanos'),(11852,730307595002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','peretanos','peretanos@hotmail.com','pedro jose roman','gomez oreña 15','santander','Cantabria','SPAIN','39003','626769333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:55:59',0,NULL,3,1,17,0,NULL,'peretanos'),(11853,730308466002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','peretanos','peretanos@hotmail.com','pedro jose roman','gomez oreña 15','santander','Cantabria','SPAIN','39003','626769333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:55:59',0,NULL,3,1,17,0,NULL,'peretanos'),(11854,730309027002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','peretanos','peretanos@hotmail.com','pedro jose roman','gomez oreña 15','santander','Cantabria','SPAIN','39003','626769333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:56:00',0,NULL,3,1,17,0,NULL,'peretanos'),(11855,730308295002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','peretanos','peretanos@hotmail.com','pedro jose roman','gomez oreña 15','santander','Cantabria','SPAIN','39003','626769333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 07:56:00',0,NULL,3,1,4,1,'YW865908025CN ','peretanos\rGGS 550D     1\r三脚架  伟峰 WF-6662A     1\r气吹 + 布    1\r绿叶 渐变镜 72mm    1\rlenspen     1\rtripod $25'),(11856,730288474002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','cdglider','cjdroadglide@att.net','chris dzierzewski','1406 Mulberry St','hartford','WI','UNITED STATES','53027-3113','(414) 915-5566','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-22 08:41:01',0,NULL,3,1,1,1,NULL,'cdglider'),(11857,806961717015,250692237021,'Green.L 72mm 72 Neutral Density ND8 Filter ND 8 New',1,'AE2313',4.3,'hutongstore','petrs4321','freedomphoto@email.cz','Petr Svoboda','Palachova 425/22<br>tel.: 608177730','Poděbrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-22 08:58:33',0,NULL,3,1,17,0,NULL,'petrs4321'),(11858,790367937016,260660050853,'Green.L 52mm 52 Neutral Density ND8 Filter ND 8 New',1,'AE2308',3.85,'hutongstore','petrs4321','freedomphoto@email.cz','Petr Svoboda','Palachova 425/22<br>tel.: 608177730','Poděbrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-22 08:58:34',0,NULL,3,1,2,1,NULL,'petrs4321\r绿叶 ND8 72mm    1\r绿叶 ND8  52mm    1'),(11859,730328910002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','kappy_88','don.kappa@gmail.com','Oleg Korobeynikov','yl. Krasnoarmeyskaya 74-79','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 09:33:25',0,NULL,3,1,17,0,NULL,'kappy_88'),(11860,730329955002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','kappy_88','don.kappa@gmail.com','Oleg Korobeynikov','yl. Krasnoarmeyskaya 74-79','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426077','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 09:38:38',0,NULL,3,1,2,1,NULL,'kappy_88\r方形滤镜接口环 77mm   1\r方镜广角托架（ 一槽）   1'),(11861,688718673001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',124.76,'hermeshine','hanhamberg','hhamberg@hotmail.com','Antro Han Hamberg','Meent 4<br>06 54 93 02 46','Leerdam','','NETHERLANDS','4141 AC','0654930246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 09:40:25',0,NULL,3,1,3,1,'RA117720239CN\r ','hanhamberg(已入库)\r58mm 橡胶遮光罩   1\r反光伞   1\r4螺丝井字扳手    1\r新式内胆包小号   1\r爵影红外 5 in 1    3\r镜头笔   1\r中号内胆包 nikon    1\r大号内胆包 nikon    2\r小号内胆包 canon    1\r爵影红外 Canon    1\rGGS D90    1\r爵影红外 Nikon    2\r1.45\r'),(11862,688767308018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','polyzostria','vbear@froggy.com.au','Virginia Bear','3/1 Porters Rd','Kenthurst','New South Wales','AUSTRALIA','2156','0296542346','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-22 10:40:59',0,NULL,3,1,3,1,'RA117720168CN\r ','polyzostria'),(11863,742944247017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','mini.minge','nix.shutterbug@gmail.com','Nicole Miller','Unit 3<br>153 Government Road','LABRADOR','Queensland','AUSTRALIA','4215','0451109709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 10:51:46',0,NULL,3,0,17,0,NULL,'mini.minge'),(11864,730351439002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-22 11:04:39',0,NULL,3,1,17,0,NULL,'p_pohjanjoki'),(11865,689017203001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','nico19870','nicoladeprato@hotmail.com','Nicola De Prato','Pal Piccolo 16','tolmezzo','UD','ITALY','33028','0433-2500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 11:05:45',0,NULL,3,1,3,1,'RA117720137CN\r ','nico19870\rshoulder support for DV $15'),(11866,730350523002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 11:05:52',0,NULL,3,1,4,1,'YW865908084CN ','p_pohjanjoki\r绿叶 CPL  77mm   1\r绿叶 ND8  77mm   1\r绿叶 渐变镜 77mm  1\r绿叶近摄镜 +4  77mm  1\r4片装的滤镜袋   1\r6662A   1\rtripod $18\r'),(11867,742960283017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','jsetiaw','jamessetiawan@gmail.com','Dr. James Setiawan','Whitfords Avenue Medical Center<br>Whitfords Ave (Cnr Dampier ave)','Kallaroo','Western Australia','AUSTRALIA','6025','0421338847','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 11:46:05',0,NULL,3,1,2,1,NULL,'jsetiaw'),(11868,742960237017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',8.88,'photographyacc','schliebs87','paulschliebs@gmail.com','Paul Schliebs','17a Pascoe Street','Glen Iris','Victoria','AUSTRALIA','3146','0413067614','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-22 11:48:32',0,NULL,3,1,2,1,NULL,'schliebs87\r方形滤镜接口环 77mm    1\r广角托架     1'),(11869,689029427001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','accessoriconsollepc','la-cometa@hotmail.it','Laura Valleriani','via cremona, 28','Ardea','Roma','ITALY','00040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-22 11:54:47',0,NULL,3,0,3,1,'RA117720242CN\r ','accessoriconsollepc\rXL(已入库)\rVest $10'),(11870,689035190001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mpshed','myrkopiche@gmail.com','Myrko Piché','803 Jean-Plouf','Boucherville','QC','CANADA','J4B 3G9','(514) 833-3969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 12:15:56',0,NULL,3,1,2,1,NULL,'mpshed'),(11871,730376660002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','b7seven7','dplockard@yahoo.com','David P Lockard','49 Dane Ct','Hampton','VA','UNITED STATES','23666','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-22 12:41:01',0,NULL,3,1,1,1,NULL,'b7seven7'),(11872,688641685018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','heni_berkoviz','info@henib.co.il','haim berkoviz','spinoza 12','petah tiqwa','petah tiqwa','ISRAEL','49532','0526311458','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-22 12:49:27',0,NULL,3,1,3,1,'RA117720145CN\r ','heni_berkoviz'),(11874,688828807018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','michaelmichael2010anthony','michael.anthony5@bigpond.com','Michael Anthony','8 Amos crt','Narre Warren South','Victoria','AUSTRALIA','3805','0397965867','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-22 14:12:14',0,NULL,3,1,2,1,NULL,'michaelmichael2010anthony\r背景布 1.6x2.1m      1(白)'),(11875,688836606018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','profotos','dreampetstar@gmail.com','Chris Falla','P O Box 104','Palm Cove','Queensland','AUSTRALIA','4879','0412769229','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-22 14:37:16',0,NULL,3,1,3,1,'RA117720185CN\r ','profotos'),(11876,807105700015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','poison9579','m.elliott950@btinternet.com','marie elliott','71 grasmere crescent<br>winton','eccles','Greater Manchester','UNITED KINGDOM','m30 8dg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 15:49:49',0,NULL,3,1,2,1,NULL,'poison9579'),(11877,730441515002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','2010millerman','mandrej@inbox.lv','Andrejs Mescerjakovs','Klaipedas 110-69','Liepaja','','LATVIA','LV-3416','(371)29137267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 16:06:29',0,NULL,3,1,2,1,NULL,'2010millerman'),(11878,790516918016,260660052658,'New Camera shoulder bag D1 for Canon body and 1-2 lens',1,'AO0031',13.9,'hutongstore','madhouze123','wendytalbot1967@hotmail.com','wendy talbot','4 kelsey avenue<br>southbourne','hampshire','Hampshire','UNITED KINGDOM','po10 8nf','01243389947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 16:12:29',0,NULL,3,1,3,1,'RA117720171CN\r ','madhouze123\r'),(11879,688879110018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','magicmago','rolf.horz@maxefecto.com','Rolf Peter Horz','C/ Rosario Sotomayor, Edif. Cruz del Pino, Portal 8,  1º b','Puerto de la Cruz','Tenerife / Canarias','SPAIN','38400','922370991','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-22 16:35:48',0,NULL,3,1,2,1,NULL,'magicmago'),(11880,807129425015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','wizmyster4183','wizmyster@live.com','Simon Jones','40 Avon crescent<br>Brockworth','Gloucester','Gloucestershire','UNITED KINGDOM','gl3 4lq','01452862393','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-22 16:45:06',0,NULL,3,1,2,1,NULL,'wizmyster4183'),(11881,689178903001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',4,'AB1204',68,'hermeshine','thetalgy1mc4','thetalgy@gte.net','james d moore','18820 116th Ave SE','renton','WA','UNITED STATES','98058-7155','(425) 228-1477','NoPaymentFailure','CheckoutComplete','Other','2011-06-22 19:14:35',0,NULL,3,1,1,1,NULL,'thetalgy1mc4'),(11882,743145061017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','ravivstein','mike1111114@walla.com','Raviv Stein','Haalon<br>mailbox 121','Ramat-Yishay','Emek-Izrael','ISRAEL','30095','04-9835602','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-22 19:42:35',0,NULL,3,1,3,1,'RA117720199CN\r ','ravivstein'),(11883,689206682001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','ex_shupkien','from_ebay@mail.ru','Viktor Shapkin','Efremova, 2-91','Nigny Novgorod','','RUSSIAN FEDERATION','603003','+7 8312 2732307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 20:08:10',0,NULL,3,1,2,1,NULL,'ex_shupkien'),(11884,730544906002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','vitpro','vitpro94@gmail.com','vitaly proshin','zalman shneor 20/19','natanya','','ISRAEL','42490','0546304381','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 20:23:08',0,NULL,3,1,2,1,NULL,'vitpro'),(11885,689229562001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',4,'AC3301',58.24,'hermeshine','mystery_ghosttrain','anders_1@ukr.net','Vitaliy Ivakin','b-r Perova 15b, kv.4','Kyiv','','UKRAINE','02125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 21:04:07',0,NULL,3,1,3,1,'RA117720123CN\r ','mystery_ghosttrain'),(11886,730574125002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','mbscorkers','mbsirimoglu@hotmail.com','GTT ISTANBUL / Mehmet Bulent Sirimoglu','Gazeteciler Sitesi Hikaye Sok.<br>No:7 Esentepe Mecidiyekoy','Istanbul','','TURKEY','34394','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-22 21:24:17',0,NULL,3,1,2,1,NULL,'mbscorkers'),(11887,728120336002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','davearguez','prominent16@hotmail.com','dave arguez','po box 504','margaretville','NY','UNITED STATES','12455','','NoPaymentFailure','CheckoutComplete','Other','2011-06-22 21:31:12',0,NULL,3,1,1,1,NULL,'davearguez\r背心 Canon  老款 M       1'),(11888,807286450015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','merahjambu','merahjambupictures@gmail.com','Zul Hilmi Hamdun','25, Jalan Teratai 2,<br>Taman Puchong Perdana','Puchong','Selangor','MALAYSIA','47100','0122900494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-22 21:32:40',0,NULL,3,1,2,1,NULL,'merahjambu'),(11889,790689987016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','jnse78','johan.stalnacke@gmail.com','Johan Stalnacke-Pesonen','Gamla vittangivagen 24','Svappavaara','Norrland','SWEDEN','98020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-22 21:51:51',0,NULL,3,1,2,1,NULL,'jnse78'),(11890,743226756017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','beckrocchi','beck_rocchi@hotmail.com','beck rocchi','200 Barkers Rd','Hawthorn','Victoria','AUSTRALIA','3122','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-22 23:09:51',0,NULL,3,1,2,1,NULL,'beckrocchi'),(11891,689046997018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','mr.schnack','nils@dicedchicken.com','Nils Bjelajac Schnack','17/230 Campbell Parade<br>Bondi Beach','Sydney','New South Wales','AUSTRALIA','2026','0420885876','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-22 23:35:16',0,NULL,3,1,3,1,'RA117720208CN\r ','mr.schnack'),(11892,730612602002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','newhouse23o','newhouse230@aol.com','charlie silverman','230 Babcock st<br>apt 2d','brookline','MA','UNITED STATES','02446-6785','(617) 731-5702','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-22 23:38:37',0,NULL,3,1,1,1,NULL,'newhouse23o'),(11893,743241201017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','joezac0','joezac1@gmail.com','Joe Calleja','PO Box 8023','Oakleigh East','Victoria','AUSTRALIA','3166','0411392523','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-23 00:10:48',0,NULL,3,1,2,1,NULL,'joezac0'),(11894,807340742015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','warner-0','warnermullen@hotmail.co.uk','warner mullen','15 camus park','strabane','Tyrone','UNITED KINGDOM','bt82 8pe','02881659009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 00:29:06',0,NULL,3,1,17,0,NULL,'warner-0'),(11895,807341972015,250804357708,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',1,'AA1306',1.87,'hutongstore','warner-0','warnermullen@hotmail.co.uk','warner mullen','15 camus park','strabane','Tyrone','UNITED KINGDOM','bt82 8pe','02881659009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 00:29:07',0,NULL,3,1,2,1,NULL,'warner-0\rNIKON 镜头盖 62mm     1\r肥皂盒 柔光罩   sb800 sb600      1'),(11896,688274256018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',31.28,'photographyacc','mininggirl81','debbie.stewart@live.com.au','Debbie Gibson','14 WENN ROAD','SINGLETON','Western Australia','AUSTRALIA','6175','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-23 00:35:58',0,NULL,3,1,3,1,'RA117720256CN\r ','mininggirl81 (已入库)\rsony 单肩包  A1      1\r爵影红外 sony         1'),(11897,743252343017,270753944377,'New Lambency Flash Diffuser for Nikon SB600 SB800 P1',1,'AB3306',21.5,'photographyacc','lecotelle','martincotella@gmail.com','Martin Jorge Cotella','Avenida Madrid, 172, 6to, 1ra','Barcelona','Cataluña','SPAIN','08028','657427642','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 01:02:49',0,NULL,3,1,3,1,'RA117720110CN\r ','lecotelle'),(11898,689081023018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','angelwings666','jennifer.goodenough@bigpond.com','Jennifer Goodenough','20 Redlynch Rd','Salisbury North','South Australia','AUSTRALIA','5108','0882580025','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-23 02:14:43',0,NULL,3,1,2,1,NULL,'angelwings666'),(11899,743272815017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',36,'photographyacc','catsof2008','dlmostumt4@bigpond.com','Carlo Margariti','21 Harvey Crt','Roxburgh Park','Victoria','AUSTRALIA','3064','0403024058','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-23 02:27:36',0,NULL,3,1,3,1,'RA117717155CN\r ','catsof2008\rRA117720211CN\r上次2个中坏了一个，\r补发一个给他 （已入库）'),(11900,743273010017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','tclaxton1','tclaxton_purch@hotmail.com','Tony Claxton','1709 Harvard Ave','Big Spring','TX','UNITED STATES','79720-3407','(432) 267-1036','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 02:28:54',0,NULL,3,1,1,1,NULL,'tclaxton1'),(11901,730653310002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','bytesnbooks','gobyte@dialup.cc','Lazaro Yi','19 Hillcrest Ave','Pittsburg','CA','UNITED STATES','94565-6501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-23 02:40:20',0,NULL,3,1,1,1,NULL,'bytesnbooks'),(11902,688749854018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',2,'AB1303',11.32,'photographyacc','budgyo1','big_budgy@hotmail.com','Brendon Newley','39 Atlantic drive','Brassall','Queensland','AUSTRALIA','4305','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-23 02:50:38',0,NULL,3,1,2,1,NULL,'budgyo1'),(11903,689103721018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',70,'photographyacc','2011fmd','david.batchelor@fmd.com.au','FMD Financial Pty Ltd','Level 31<br>367 Collins Street','Melbourne','Victoria','AUSTRALIA','3000','0396204633','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-23 04:09:41',0,NULL,3,1,4,1,'YW865908073CN ','2011fmd'),(11904,730670930002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','arseno777','g.iamartyom@gmail.com','Arsen Beglaryan','Martuni 8/18','Stepanakert','NKR','ARMENIA','375000','+37497255020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 04:17:40',0,NULL,3,1,2,1,NULL,'arseno777'),(11905,689334689001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','cayleigho','cpb_phd@yahoo.com','Cathleen O\'Hare','204 S Thurlow St','Hinsdale','IL','UNITED STATES','60521-3928','(630) 325-2387','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 04:52:41',0,NULL,3,1,3,1,'RA117720260CN\r ','cayleigho\r'),(11906,689337373001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','nuvii','xnavsinghx@hotmail.com','Navpreet Dhadwal','14 Daintree Croft<br>Stivichall','Coventry','West Midlands','UNITED KINGDOM','CV3 5DN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 05:10:03',0,NULL,3,1,2,1,NULL,'nuvii'),(11907,689114978018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',22,'photographyacc','jambostock2','admin@jambostock.com','Vladislav Lebedinski','Shadenko 90, kv.20','Taganrog','Rostovskaya obl','RUSSIAN FEDERATION','347924','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 05:28:16',0,NULL,3,1,3,1,'RA117720273CN\r ','jambostock2'),(11908,804667494015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','safeblad','jamesfountain23@hotmail.com','fyrvik','kjelleråssvingen 15','fagerstrand','','NORWAY','no-1454','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-06-23 06:21:13',0,NULL,3,1,4,1,'YW865908062CN ','safeblad\rtripod dolly  $25\r'),(11909,743321881017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','dizee-d','daniel.k.so@student.uts.edu.au','Peter Ilosvay','19 High Street, Gladesville','Sydney','New South Wales','AUSTRALIA','2111','0408740079','NoPaymentFailure','CheckoutComplete','AU_RegularParcelWithTracking','2011-06-23 07:03:19',0,NULL,3,1,4,1,'YW865908110CN ','dizee-d'),(11910,730700206002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','zisa2011','missbznz@msn.com','Zisa Zooz','House 168 road 4123 block 241','Arad','Arad','BAHRAIN','00000','0097339962012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 07:22:22',0,NULL,3,1,2,1,NULL,'zisa2011'),(11911,689354093001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 08:27:32',0,NULL,3,1,17,0,NULL,'saud-p'),(11912,688825732001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 08:27:33',0,NULL,3,1,17,0,' ','saud-p'),(11913,688777082001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-23 08:27:34',0,NULL,3,1,12,1,'BJ8823501 ','saud-p\r分小包还是够合成DHL?\r背景架2m x 3m + 3个夹子     2\r背景架2mx 1.6m   2\r背景布 1.6x2.1m   2(白)\r2m 灯架   4\r50-70cm 单灯头 柔光箱   4\r115w 5500k 220v 灯泡    4\r灯架包   2\r欧标\r申报:  lighting kit  $530'),(11914,689392440001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','luka7899','lucante79@gmail.com','LUCA  DURANTE','via BORGO 13','T R E V I G N A N O','TV','ITALY','31040','3393091065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 09:51:08',0,NULL,3,1,2,1,NULL,'luka7899'),(11915,689395136001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','rmaxlucy','rig888@alice.it','Massimo RIGOTTI','via dei Rododendri 15','CREAZZO','VI','ITALY','36051','+393482745900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 10:01:39',0,NULL,3,1,3,1,'RA117772222CN\r ','rmaxlucy\r申报： reflector holder  $15'),(11916,743377758017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','marg_hamwood','hamwood@internode.on.net','Margaret Hamwood','PO Box 10077','MT PLEASANT','Queensland','AUSTRALIA','4740','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-23 10:48:31',0,NULL,3,1,3,1,'RA117772165CN\r ','marg_hamwood'),(11917,689418483001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','kingyguyane','kingy@wanadoo.fr','Guillaume CAREME','App. 3B Bat. A Immeuble DANTON','SAINT-LAURENT DU MARONI','GUYANE FRANCAISE','FRANCE','97320','0694264944','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-23 11:31:56',0,NULL,3,1,4,1,'YW865908180CN ','kingyguyane\r背景架2mx2m  + 3个夹子    1\r背景布 1.6*2.1m      2(白+黑)\rbackground support $25\r'),(11918,689423844001,110531023243,'JJC Leather Hand Strap Grip for NIKON AH-4 D3x D90 D300',1,'AB1411',17.99,'hermeshine','bond2605','valeri_bond@mail.ru','Valeriy Bondarenko','Bolshaya<br>10a-55','Rybnoe','Ryazan','RUSSIAN FEDERATION','391110','+7-49137-5-17-16','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 11:48:51',0,NULL,3,1,2,1,NULL,'bond2605'),(11919,728615646002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','erikeiner','erik@fjelltopp.no','Erik Nilsen','Baneveien 65','Lier','Lier','NORWAY','3400','00 47 909 59 260','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-23 12:05:34',0,NULL,3,1,17,0,NULL,'erikeiner'),(11920,730774121002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','erikeiner','erik@fjelltopp.no','Erik Nilsen','Baneveien 65','Lier','Lier','NORWAY','3400','00 47 909 59 260','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-23 12:26:54',0,NULL,3,1,3,1,'RA117772236CN\rRA117717756CN\r ','erikeiner\r永诺 SF18- NIKON SB800    2\r-----\r0707(第一次发的2条中坏了一条)补发一条新的'),(11921,689222996018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','marcus273','mincev01@optusnet.com.au','Zlatko Mincev','83 Quarter Sessions Rd','Westleigh','New South Wales','AUSTRALIA','2120','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-23 12:51:02',0,NULL,3,1,3,1,'RA117772253CN\r ','marcus273'),(11922,689244506018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',78,'photographyacc','rod_tilbury','dylisachicken@hotmail.com','Rod Tilbury','85 Holland Street<br>Fremantle','Perth','Western Australia','AUSTRALIA','6160','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-23 13:59:20',0,NULL,3,1,4,1,'YW865908176CN ','rod_tilbury\r澳标 lighting kit  $25'),(11923,689467231001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',2,'AKT029',48,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 14:17:16',0,NULL,3,0,3,1,'RA117720358CN\r ','mariomarques.com.br（已入库）\r4x 52mm lens cap for Nikon\r4x 62mm lens cap for Nikon\r4x 67mm lens cap for Nikon\r4x 72mm lens cap for Nikon\r4x 77mm lens cap for Nikon \r\r'),(11924,687805338018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','snowy2204','snowy76@westnet.com.au','Anthony Longfield','3 Blue Mountain Circuit','Aubin Grove','Western Australia','AUSTRALIA','6164','0894993625','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-23 14:32:08',0,NULL,3,0,3,1,'RA117772240CN\r ','snowy2204\r1.6x2.1   2\r黑色+粉色'),(11925,689270600018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','ryan8yu','ryanyu@live.com.au','Yang  Yu','47 Narellan Street','ARANA HILLS','Queensland','AUSTRALIA','4054','0413505752','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-23 15:19:31',0,NULL,3,1,3,1,'RA117772307CN\r ','ryan8yu'),(11926,807604769015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','jediperry','mike@serensilver.co.uk','Mike Perry','1 Firsby Street','Manchester','Lancs','UNITED KINGDOM','M19 3FB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 15:29:14',0,NULL,3,1,2,1,NULL,'jediperry'),(11927,689278806018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','pitonowae','data.pitono@gmail.com','iwan pitono (METROTV)','jl. cendana 16','Yogyakarta','yogyakarta','INDONESIA','55166','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 15:39:26',0,NULL,3,1,2,1,NULL,'pitonowae'),(11928,742328280017,270757382435,'Studio 1000W Continuous Lighting Complete Kit 3mx6m G',1,'AKT063',256,'photographyacc','m_almatar','m_almattar@hotmail.com','Mohd Almatar','Salem bin sulatn','RAK','','UNITED ARAB EMIRATES','11225','00971508080074','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 15:51:57',0,NULL,3,1,8,1,'CP234126102CN ','m_almatar\r欧标\r9.5以内'),(11929,807630181015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','papadakisi','ipapadakis@hotmail.com','ioannis papadakis','KAYKASOU 35B','thessaloniki','kalamaria','GREECE','55133','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 16:23:55',0,NULL,3,1,2,1,NULL,'papadakisi'),(11930,730864677002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','blogartt','blogart89@gmail.com','pablo garcia gordo','torrecillas 14','Guevejar','Andalucía Ceuta y Melilla','SPAIN','18212','600759628','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 16:57:14',0,NULL,3,1,4,1,'YW865908165CN ','blogartt\rTripod $15\ryw系统现实已经签收.'),(11931,689534901001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','azhikin','azhikin@aol.com','Randy Goettsche','2128 W Wahalla Ln','Phoenix','AZ','UNITED STATES','85027','(623) 516-2134','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 17:26:11',0,NULL,3,1,1,1,' ','azhikin'),(11932,743536433017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','etclhm','etclhm@gmail.com','Ed Troop','15775 S Sunset Dr<br>Unit 3202','Olathe','KS','UNITED STATES','66062-7097','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 18:01:58',0,NULL,3,1,1,1,NULL,'etclhm'),(11933,807684176015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','djdavwardo','dave_rotundra.net@hotmail.com','David Roulston','3 Mullan Road','Ballymoney','Antrim','UNITED KINGDOM','BT537ED','02827664538','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-23 18:04:19',0,NULL,3,1,2,1,NULL,'djdavwardo'),(11934,689570287001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','casaluca2004','casaluca@hotmail.com','LUCA CASAGRANDE','VIALE S.MARCO 70 MESTRE','VENEZIA','VE','ITALY','30173','041-976292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 18:40:47',0,NULL,3,1,17,0,NULL,'casaluca2004'),(11935,730909942002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','casaluca2004','casaluca@hotmail.com','LUCA CASAGRANDE','VIALE S.MARCO 70 MESTRE','VENEZIA','VE','ITALY','30173','041-976292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 18:40:48',0,NULL,3,1,17,0,NULL,'casaluca2004'),(11936,730909585002,120536002412,'New Neoprene Camera Neck Strap for D80 D90 D300 D700',1,'AB1403',5.49,'hermeshine','casaluca2004','casaluca@hotmail.com','LUCA CASAGRANDE','VIALE S.MARCO 70 MESTRE','VENEZIA','VE','ITALY','30173','041-976292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 18:40:48',0,NULL,3,1,2,1,NULL,'casaluca2004\r麂皮     1\r中号内胆包 nikon     1\r肩带 nikon     1'),(11937,791113954016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','pipkato','roy.esmonde@gmail.com','Roy Esmonde','63 Kenilworth Square','Dublin 6','','IRELAND','','0035314967450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-23 19:19:32',0,NULL,3,1,3,1,'RA117772219CN\r ','pipkato'),(11938,689412013001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',81.34,'hermeshine','chi88oleg','chi8min@mail.ru','Oleg Zimin','st.Permskaya 2<br>village Pichuga','Volgograd','Volgogradskaya region, Dubovskii area, village Pichuga','RUSSIAN FEDERATION','404011','89093871141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-23 19:38:56',0,NULL,3,1,5,1,'CP234126093CN ','chi88oleg    (已入库)\r大力夹   1\r摄影背心 Canon  老款  M   1\r大号内胆包 无字   1\r灯架  2m      1\r2.042\r'),(11939,689633358001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','san-dz-tz','san-dz-tz@hotmail.com','Bruce Hughes','1878 Leclair Apt.102','Waterloo','QC','CANADA','J0E2N0','(450) 539-0905','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'san-dz-tz'),(11940,689434041018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','journey1au','journey1au1@dodo.com.au','Deborah Rigelsford','77 Taree Street','Tuncurry','New South Wales','AUSTRALIA','2428','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-23 21:23:58',0,NULL,3,1,4,1,'YW865908154CN ','journey1au\rbackground support $25\r'),(11941,689452597018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','ckffeng89','ckffeng@gmail.com','KaiFeng Chong','christoph-probst-str. 6/0002','Muenchen','','GERMANY','80805','49 176 59998296','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 22:09:42',0,NULL,3,1,2,1,NULL,'ckffeng89'),(11942,742389942017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','davidc1936','bugjuice1936@yahoo.com','david castleman','27440 County Road 13<br>Apt 211','Daphne','AL','UNITED STATES','36526-6222','(334) 624-8363','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-23 22:40:16',0,NULL,3,1,1,1,NULL,'davidc1936'),(11943,723870964002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',15.6,'hermeshine','dave3j42','dave@testrepair.com','David Andersen','3529 Old Conejo Rd<br>suite 122','Newbury Park','CA','UNITED STATES','91320-6155','(805) 499-7010','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-23 22:26:35',0,NULL,3,1,1,1,NULL,'dave3j42'),(11944,689669490001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fowler1618','fowlerarts@yahoo.com','Joe Fowler','1311 W Aloe St.<br>Apt 1407','Egg Harbor City','NJ','UNITED STATES','08215','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-23 22:57:00',0,NULL,3,1,1,1,NULL,'fowler1618'),(11945,689469354018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','cyndi.gow75','cinmatt.gow@bigpond.com','Mrs Cynthia Gow','12<br>gould walk','truganina','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-23 23:12:33',0,NULL,3,1,2,1,' ','cyndi.gow75\r新地址:\rMrs Cynthia Gow\r12 Skipper Road Tarneit\rMelbourne Victoria\r3029\rAUSTRALIA\r'),(11946,689503275018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',2,'AA3321',17.6,'photographyacc','ikev0423','duckno2@hotmail.com','Tsung-Han Lee','52 Ingluna Circuit<br>Eight Mile Plains','Brisbane','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-24 01:59:38',0,NULL,3,1,2,1,NULL,'ikev0423'),(11947,689520555018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','bede4106','bedebaby@hotmail.com','Bede Ramah','8 Fernshaw Street<br>Macgregor','Brisbane','Queensland','AUSTRALIA','4109','0421423299','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-24 03:08:14',0,NULL,3,1,3,1,'RA117720389CN ','bede4106'),(11948,731067930002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','momamae23','ednabu@yahoo.com','edna buttery','395 parker rd','london','KY','UNITED STATES','40741-8251','(606) 878-0946','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-24 03:09:16',0,NULL,3,1,1,1,NULL,'momamae23'),(11949,743738445017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','levontee','le.von.tee@gmail.com','Aleksey Zorin','Vavilova st. 2/55','Tomsk','RU','RUSSIAN FEDERATION','634055','+7(923)4015011','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 04:23:53',0,NULL,3,1,3,1,'RA117720335CN ','levontee'),(11950,689735917001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',29,'hermeshine','faby_1978','contato@clubecanino.com.br','Fabyola Beraldi Vilar Mamede','R. São Carlos do Pinhal, 608 apt 101','Sao Paulo','Sao Paulo','BRAZIL','01333-000','5511 78809910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 04:30:53',0,NULL,3,1,3,1,'RA117720344CN ','faby_1978'),(11951,689538044018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','pvm1602','menssink@gmail.com','Paul Menssink','27 Bella Vista Close','Macleod','Victoria','AUSTRALIA','3085','0407223260','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-24 04:48:46',0,NULL,3,1,2,1,NULL,'pvm1602'),(11952,731085949002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','aaivanov','aivanov@west-l.ru','Alexey Ivanov','Bogatyrsky prospekt<br>37-2-113','Saint-Petersburg','','RUSSIAN FEDERATION','197372','+7-921-975-55-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 04:55:07',0,NULL,3,1,2,1,' ','aaivanov'),(11953,689541372018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','davidw111','davidw@businesshorizons.com.au','David Winter','PO Box 5174','Rockingham Beach','Western Australia','AUSTRALIA','6969','0895281271','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-24 05:09:33',0,NULL,3,1,2,1,NULL,'davidw111'),(11954,689746992001,110566018317,'62mm 3-Stage Rubber Lens Hood for D80 D90 450D 500D',1,'AB1304',3.79,'hermeshine','ppoon418','peterandkathypoon@gmail.com','Peter Poon','1218 Hollands Close','Edmonton','AB','CANADA','T6R3N4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 06:02:04',0,NULL,3,1,17,0,NULL,'ppoon418'),(11955,689746862001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ppoon418','peterandkathypoon@gmail.com','Peter Poon','1218 Hollands Close','Edmonton','AB','CANADA','T6R3N4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 06:02:03',0,NULL,3,1,2,1,NULL,'ppoon418\r橡胶遮光罩 62mm   1\r橡胶遮光罩 52mm   1'),(11956,689758846001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','willemhen','w.groot7@upcmail.nl','Willem de Groot','Rivierenlaan 74','ROZENBURG ZH','','NETHERLANDS','3181DS','0181216476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 06:57:28',0,NULL,3,1,2,1,NULL,'willemhen'),(11957,689560775018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','tster75','tynathan1@hotmail.com','03ty lucas','15 Janna Place','Berwick','Victoria','AUSTRALIA','3806','0397026464','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-24 07:05:21',0,NULL,3,0,2,1,NULL,'tster75\r白色'),(11958,689573396018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','cu_ti_nho','kienmm@gmail.com','Lam Thu Kien','56F/57A Dao Duy Tu, P5 Q10','Ho Chi Minh','Ho Chi Minh','VIET NAM','70250','84903109125','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 08:16:13',0,NULL,3,1,2,1,NULL,'cu_ti_nho'),(11959,689575350018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','annettes_attic_store_au','apppsebay2@dodo.com.au','Annette Smith','PO Box 247','NOWRA','New South Wales','AUSTRALIA','2541','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-06-24 08:19:06',0,NULL,3,1,3,1,'RA117720450CN ','annettes_attic_store_au'),(11960,689775761001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-24 08:34:01',0,NULL,3,1,17,0,NULL,'saud-p'),(11961,743795208017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.88,'photographyacc','svaz000','black_sv_900@hotmail.com','Shayne Vaz','74 Essington St','Wentworthville','New South Wales','AUSTRALIA','2145','0296875243','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-24 09:15:43',0,NULL,3,1,2,1,NULL,'svaz000'),(11962,729905501002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','giurg','giurg.83@libero.it','Ag. \"COFANO\" di COFANO ANGELO','c.so NAZIONALE n° 161','FASANO - PEZZE DI GRECO','BR','ITALY','72010','3391093555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 10:19:42',0,NULL,3,1,2,1,NULL,'giurg'),(11963,743813822017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',70,'photographyacc','petepics555','peter.conway@doussis.com','AHMRC co Stello Doussis','Level 3, 66 Wentworth Ave<br>Surry Hills','Sydney','New South Wales','AUSTRALIA','2010','0425507236','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-24 10:46:41',0,NULL,3,1,3,1,'RA117777202CN\r ','petepics555\r摄影背心 黑色厚 无字   xl   1\r摄影背心 黑色厚 无字 xxxl   1'),(11964,689810655001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','robert83moto','bhandcuffs@yahoo.fr','Robert POLIDORI','213 route de la motte','le muy','Provence-Alpes-Côte d\'Azur','FRANCE','83490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 10:59:05',0,NULL,3,1,3,1,'RA117720477CN\r ','robert83moto'),(11965,731157345002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','nzcapri','luton_anderson@hotmail.com','Luton Anderson','34 Popes Lane<br>South Ealing','London 07912228491','London','UNITED KINGDOM','W5 4NU','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-24 11:03:49',0,NULL,3,0,3,1,'RA117720429CN\r ','nzcapri\r2XL(已入库)'),(11966,731162647002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','ramanius','ravlasenko@yahoo.ie','Ramunas Avlasenko','72 boroimhe birches','Swords','Dublin','IRELAND','0','0857724762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 11:23:29',0,NULL,3,1,2,1,NULL,'ramanius'),(11967,689829112001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','abwaterbury','aryehb@bezeqint.net','Aryeh Burnham','PO Box 43044<br>60 Shaulson, apt.1','Jerusalem','','ISRAEL','95400','+97226514923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 12:10:18',0,NULL,3,1,17,0,NULL,'abwaterbury'),(11968,689830221001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','abwaterbury','aryehb@bezeqint.net','Aryeh Burnham','PO Box 43044<br>60 Shaulson, apt.1','Jerusalem','','ISRAEL','95400','+97226514923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 12:13:59',0,NULL,3,1,3,1,'RA117720605CN\r ','abwaterbury\r圆形柔光棚 40cm   1\r背景架2mx 1.6m    1\r2.1x1.6m 背景布    1(白)\r2m 灯架   2\r50-70cm 单灯头 柔光箱    2\r115w 220v 5500k 灯泡     2\r灯架包   1\r分几个小包吧\r分5个\rRA117720517CN\rRA117720755CN\rRA117720653CN\rRA117720596CN\r\r\r'),(11969,731057736002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','nebularman','brianevansphotos@gmail.com','Brian Evans','38 4th Ave<br>Apt 1F','Nyack','NY','UNITED STATES','10960-2117','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-24 12:18:36',0,NULL,3,1,1,1,NULL,'nebularman'),(11970,743861753017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',52,'photographyacc','bengl123','ben@beng.com.au','ben glezer','1/240 Inkerman St. East St Kilda','Melb. Vic','Victoria','AUSTRALIA','3183','61395277500','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-24 13:20:39',0,NULL,3,1,3,1,'RA117720432CN\r ','bengl123'),(11971,731194173002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','selcukozen','salihselcuk.ozen@gmail.com','Salih Selcuk OZEN','PrintCenter Plaza Manolya sk. No:3 K:3<br>4.Levent','ISTANBUL','n/a','TURKEY','34416','905375717491','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-24 14:03:41',0,NULL,3,1,5,1,'CP234126120CN ','selcukozen\r欧标 220v\rlighting kit $20\r'),(11972,689862355001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','yrtour','yraccts@gmail.com','L Bowen','5 Alden St<br>Upstairs','Provincetown','MA','UNITED STATES','02657-1403','(617) 283-1003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-24 14:08:20',0,NULL,3,1,1,1,NULL,'yrtour'),(11973,808031116015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','jonkenrob2010','rober6381@yahoo.com','JOHN ROBERTSON','109 FOUNTAIN STREET','MORLEY, LEEDS','West Yorkshire','UNITED KINGDOM','LS27 0AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 14:11:15',0,NULL,3,1,2,1,NULL,'jonkenrob2010'),(11974,808105897015,250804358294,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',1,'AA1308',1.87,'hutongstore','nayporn','s.buaprathoom@surrey.ac.uk','somporn buaprathoom','Advanced Technology Institute<br>University of Surrey','Guildford','Surrey','UNITED KINGDOM','GU2 7XH','07576054194','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 15:06:14',0,NULL,3,1,2,1,NULL,'nayporn'),(11975,689698364018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','llukeknecht123','llukeknecht123@yahoo.com','Luke Knecht','2840 Eastlake Ave E<br>Apt 110','Seattle','WA','UNITED STATES','98102-3034','(253) 948-6648','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 15:44:30',0,NULL,3,1,4,1,'YW865908283CN ','llukeknecht123\rtripod  $35'),(11976,689896213001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','nesteam84','daadox@gmail.com','Davor Vešligaj','Lupinjak 9/1','Hum na Sutli','','CROATIA','49231','00385917643309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 15:50:00',0,NULL,3,1,2,1,NULL,'nesteam84'),(11977,743918189017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','isaacquah','isaacquah@yahoo.com','Chuan Jin Quah','1/18 Bauhinia Street','Boyne Island','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-24 16:04:27',0,NULL,3,1,17,0,NULL,'isaacquah'),(11978,743933147017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','isaacquah','isaacquah@yahoo.com','Chuan Jin Quah','1/18 Bauhinia Street','Boyne Island','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-24 16:43:44',0,NULL,3,1,17,0,NULL,'isaacquah'),(11979,689916599001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mihaisamoschi10','mihai_samoschi@yahoo.com','Mihai Samoschi','Via Englaro 46','Paluzza','UD','ITALY','33026','3771063797','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 16:48:06',0,NULL,3,1,3,1,'RA117720446CN\r ','mihaisamoschi10\rreflector holder  $15'),(11980,808182093015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',3,'AB3332',4.74,'hutongstore','lionheartgraphics','richard@lionheartgraphics.co.uk','Richard Budd','33 Holloway Road<br>Dorchester','Dorset','Dorset','UNITED KINGDOM','DT1 1LF','07767895205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 17:51:31',0,NULL,3,1,2,1,NULL,'lionheartgraphics\r注意是3个'),(11981,743979765017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','lmsg2009','miguel_s_gomes_@netcabo.pt','Luis Miguel Silva Gomes','Rua Chavinha de Agua, nº60 Rch','Canelas','Vila Nova de Gaia','PORTUGAL','4410-287','912510337','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 18:29:48',0,NULL,3,1,2,1,NULL,'lmsg2009'),(11982,808051968015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',23.9,'hutongstore','ghill1969','ghill1969@aol.com','Gary Hill','35 Copy Lane<br>Caton','Lancaster','Lancashire','UNITED KINGDOM','LA2 9QZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 19:33:24',0,NULL,3,1,3,1,'RA117720415CN\r ','ghill1969'),(11983,689960837001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','robertvangend','rvgend@tele2.nl','Robert van Gend','Spinhuispad 79','Schiedam','','NETHERLANDS','3111PX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 19:49:19',0,NULL,3,1,2,1,NULL,'robertvangend'),(11984,744018056017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',5.68,'photographyacc','mokachan99','crystaljoyfletcher@hotmail.com','Crystal Fletcher','71 Cowburn Crescent','Regina','SK','CANADA','S4S 5R8','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 20:29:00',0,NULL,3,1,2,1,NULL,'mokachan99'),(11985,690023803001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 21:09:10',0,NULL,3,1,3,1,'RA117720494CN\r ','mebuy2007'),(11986,731386065002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','jfrancois_62','alexhrys@free.fr','Alexandre Hryszkiewicz','12 rue Condorcet<br>Cité HBM','Libercourt','Nord-Pas-de-Calais','FRANCE','62820','0321370609','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-24 22:12:00',0,NULL,3,1,3,1,'RA117720463CN\r ','jfrancois_62'),(11987,689855312018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','artyeva','artyeva@yahoo.com','Gillian Golden','Attawalla<br>Bangor Erris','Via Ballina','Mayo','IRELAND','default','0860677220','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 22:14:15',0,NULL,3,1,17,0,NULL,'artyeva'),(11988,689855958018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','artyeva','artyeva@yahoo.com','Gillian Golden','Attawalla<br>Bangor Erris','Via Ballina','Mayo','IRELAND','default','0860677220','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-24 22:16:09',0,NULL,3,1,2,1,NULL,'artyeva\r6片装的滤镜袋     2'),(11989,686842102001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',5.37,'hermeshine','alexandra*18','alexandradekuiper@hotmail.com','Alexandra de Kuiper','Overweg 183','OUDERKERK AAN DE AMSTEL','','NETHERLANDS','1191PZ','0204964794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-21 01:41:54',0,NULL,3,1,2,1,NULL,'alexandra*18'),(11990,690046711001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','asubaru','alexg@garte.es','Alejandro Garcia Ciaurri','Prado viejo nº 39 (Garte turismos s,l)','Logroño','La Rioja','SPAIN','26006','629829437','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-24 22:22:29',0,NULL,3,1,2,1,NULL,'asubaru'),(11991,690053154001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','beautiful_collectibles','cecilialotter76@yahoo.com.ar','Hernan Siludakis','Ascasubi 117','Monte Grande','Bs As','ARGENTINA','1842','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-24 22:49:47',0,NULL,3,1,2,1,NULL,'beautiful_collectibles'),(11992,744086779017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','*rorschach*','ahighley@bigpond.com','Andrew Highley','7 Lyall Close','Riverhills','Queensland','AUSTRALIA','4074','0737120597','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-24 23:02:27',0,NULL,3,1,2,1,NULL,'*rorschach*'),(11993,689872450018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','isaacquah','isaacquah@yahoo.com','Chuan Jin Quah','1/18 Bauhinia Street','Boyne Island','Queensland','AUSTRALIA','4680','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-24 23:22:44',0,NULL,3,1,4,1,'YW865908261CN ','isaacquah\r反光板  80cm 5合1   1\r灯架  2m   1\r单灯头    1\r反光伞    1\r背景架 2mx3m 河北 + 1.6x2.1 黑色 +夹子   1（ 注意背景布的颜色）\rbackground support  $30'),(11994,808332989015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','goddess060','irenelim060@hotmail.com','youngeun lim','16 kingsclere close<br>roehampton','london','London','UNITED KINGDOM','sw15 4ey','07538645161','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-24 23:25:06',0,NULL,3,1,2,1,' ','goddess060'),(11995,808333279015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',25,'hutongstore','judazuk','peter.lennartsson@gmail.com','Peter J Lennartsson','Ronnebergavagen 8A','Eslov','Skane','SWEDEN','24134','+46763191343','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-24 23:29:22',0,NULL,3,1,3,1,'RA117720503CN\r ','judazuk\r欧标\r货被退回来了  无人领取'),(11996,731426951002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','sguardocarlos','kafkasamsa@ig.com.br','Carlos Machado','R; Julia Sales, 175','Fortaleza','Ceará','BRAZIL','60811010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 01:20:23',0,NULL,3,1,2,1,NULL,'sguardocarlos'),(11997,690091248001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','cdowns68','cdowns@aflac.com','Cheryl Downs','1920 38th Ct','Phenix City','AL','UNITED STATES','36870','(706) 580-9691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 02:04:00',0,NULL,3,1,1,1,NULL,'cdowns68'),(11998,689914380018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','vikki_from_oz','vkourbelis@hotmail.com','Vikki Kourbelis','8 Harcourt Avenue<br>Clovelly Park','Adelaide','South Australia','AUSTRALIA','5042','0413552219','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-25 03:02:02',0,NULL,3,1,4,1,'YW865908250CN ','vikki_from_oz\r白色\rbackdrop $18\r'),(11999,731446209002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','andrey**','mordvinovandrey@gmail.com','Andrey Mordvinov','st. Dmitriya Ulyanova 8 fl.40','Simferopol','UA','UKRAINE','95013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 03:06:50',0,NULL,3,1,2,1,NULL,'andrey**'),(12000,689916363018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','rt_122881','rebecca_tough@yahoo.com.au','Rebecca White','822 Glenferrie Rd<br>Hawthorn','Melbourne','Victoria','AUSTRALIA','3122','0398181866','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-25 03:12:54',0,NULL,3,1,4,1,'YW865908272CN ','rt_122881\rbackdrop  support   $25'),(12001,689922483018,280676579994,'Male 52mm-52mm 52-52 mm Macro Reverse Ring / reversing',1,'AA1211',3.8,'photographyacc','svaz000','black_sv_900@hotmail.com','Shayne Vaz','74 Essington St','Wentworthville','New South Wales','AUSTRALIA','2145','0296875243','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-25 03:49:22',0,NULL,3,1,2,1,NULL,'svaz000'),(12002,690112668001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','hermosacat','petdcat@yahoo.com','Bill Casey','65/9 Soi Intona wingping road<br>Changklan district','Chiang Mai','Thailand','THAILAND','50100','(085) 626-8933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 04:13:42',0,NULL,3,1,2,1,NULL,'hermosacat'),(12003,689956176018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','willskip_09','willskip@gmail.com','william pepito','15731 histy heath lane','Houston','TX','UNITED STATES','77084','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-25 07:13:01',0,NULL,3,1,1,1,NULL,'willskip_09'),(12004,690161448001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mika.seppa','mika.seppanen@gmail.com','Mika Seppänen','Käenpolku 12 as 5','Paltamo','','FINLAND','88300','+358401749889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 08:46:49',0,NULL,3,1,3,1,'RA117720525CN\r ','mika.seppa'),(12005,808461722015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','gillian101273','joedyingham@hotmail.co.uk','gillian tams','41 garth 25','newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','ne12 6dw','07791092460','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 08:47:20',0,NULL,3,1,3,1,'RA117720772CN\r ','gillian101273\r1.6x2.1m  背景布  2 (白+黑)'),(12006,689986234018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','bigbazza12','bigbazza@aussiebroadband.com.au','Barry Chivers','63 Harbour Line Drive','Goughs Bay','Victoria','AUSTRALIA','3723','0357773050','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-25 09:17:07',0,NULL,3,0,3,1,NULL,'bigbazza12\r1.6x2.1m  背景布   1 (黑)'),(12007,791841061016,260660053172,'New Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.52,'hutongstore','p-h-i-l-t-h-y','phillyt2k@hotmail.com','Phillip Tran','13 Greenfields Avenue','Bromborough','Wirral','UNITED KINGDOM','CH62 6DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 09:24:41',0,NULL,3,1,2,1,NULL,'p-h-i-l-t-h-y'),(12008,808475766015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','dianaowen4','diana.kelly@homecall.co.uk','diana kelly','22 dresser road<br>prestwood','great missenden','Buckinghamshire','UNITED KINGDOM','hp16 0na','01494862123','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 09:29:25',0,NULL,3,1,2,1,NULL,'dianaowen4'),(12009,690174668001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','happy24tome','yeshliyomuledet@gmail.com','Reuma Tabib','Hamarganit 34','Yokneam Elit','','ISRAEL','20692','0503554904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 09:41:50',0,NULL,3,1,2,1,NULL,'happy24tome'),(12010,689993934018,280666847645,'Nikon Original Photo Vest D3s D3x D300s D700 D90 XL',1,'AA2112',60,'photographyacc','hqe777','stevebakker777@gmail.com','Steve Bakker','44 Historic Drive','Highbury','South Australia','AUSTRALIA','5089','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-25 09:44:32',0,NULL,3,1,3,1,'RA117720640CN\r ','hqe777\rXL(已入库)'),(12011,690178066001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 10:07:02',0,NULL,3,1,3,1,'RA117720551CN\r ','buzzer_72\r(已入库)\r机身盖/镜头后盖  Canon     1\r橡胶罩口径：\r3 72 mm\r3 67 mm\r2 58 mm\r2 55 mm'),(12012,731524930002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 10:07:03',0,NULL,3,1,17,0,' ','buzzer_72'),(12013,690195137001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','awwong76','adrianandliz@iinet.net.au','adrian wong','1/395 Albany Highway<br>Victoria Park','Perth','Western Australia','AUSTRALIA','6100','0894726688','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 10:53:42',0,NULL,3,1,2,1,NULL,'awwong76'),(12014,744258395017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','colcam49','col.campbell@hotmail.com','Col Campbell','18 Brockman Street','Mango Hill','Queensland','AUSTRALIA','4509','0733850475','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-25 11:57:16',0,NULL,3,1,2,1,NULL,'colcam49'),(12015,690037936018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','cameron.c.g','cameron.c.gnade@hotmail.com','Cameron Gnade','19 Kurrimine crs','Mt Creek','Queensland','AUSTRALIA','4557','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-25 12:10:27',0,NULL,3,1,3,1,'RA117720548CN\r ','cameron.c.g'),(12016,690045418018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','albannexhipi2011','albannexhipi@yahoo.com','Alban Nexhipi','Rr. Isa Boletini Nr. 93/1','Tirane','','ALBANIA','12345','00355694152933','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-25 12:33:27',0,NULL,3,1,3,1,'RA117720534CN\r ','albannexhipi2011'),(12017,690225537001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','alex_nomaz','nomazely@gmail.com','Olexandr Chernomaz','Cheliabinska 11 str. 106 apt','Kiev','','UKRAINE','02002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 12:46:28',0,NULL,3,1,2,1,NULL,'alex_nomaz'),(12018,731586703002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','daggen69','dag.eliasson@comhem.se','Dag Eliasson','Södra Stallbacken 21','Gothenburg','Gothenburg','SWEDEN','42543','+4631575469','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 13:34:28',0,NULL,3,1,3,1,'RA117720741CN\r ','daggen69'),(12019,690244193001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','tomajda705','705@seznam.cz','Tomáš Batík','Husinecká 14','Prague','CZ','CZECH REPUBLIC','13000','605562573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 13:36:01',0,NULL,3,1,2,1,NULL,'tomajda705'),(12020,731602575002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','loxtethys','mail@lorenzocappella.it','Studio Photomania - Cappella Lorenzo','Via Toscanini, 7','Portorecanati','MC','ITALY','62017','3939719218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 14:17:18',0,NULL,3,1,2,1,' ','loxtethys\r新地址:\rStudio Photomania\rCappella Lorenzo Portorecanati (MC)\rVia Toscanini, 7\rCAP 62017 \rItaly'),(12021,744306672017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','danymoboon','dnamedos@aim.com','Dr. Daniel Sodemann','PMB1 Eyre Highway<br>Mundrabilla Roadhouse','Mundrabilla via Norseman','Western Australia','AUSTRALIA','6443','90393245','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-25 14:19:30',0,NULL,3,1,2,1,NULL,'danymoboon'),(12022,744314499017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','harrybaguio','harrybaguio@hotmail.com','harry baguio','1360 cantara st','colton','CA','UNITED STATES','92324-1970','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-25 14:38:40',0,NULL,3,1,1,1,NULL,'harrybaguio'),(12023,791962322016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ed-heritage','ed.heritage@btinternet.com','Edward Heritage','1 Chestnut Lane','Amersham','Buckinghamshire','UNITED KINGDOM','HP66EN','01494725165','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 14:48:08',0,NULL,3,1,3,1,'RA117720565CN\r ','ed-heritage'),(12024,690281859001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','farinatany','farinata@mindspring.com','Andrew Sciaulino','123 W 85th St<br>Apt 9','New York','NY','UNITED STATES','10024-4437','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 15:23:36',0,NULL,3,1,1,1,NULL,'farinatany'),(12025,690284323001,110566021477,'TianYa ND8 Filter for Cokin P Series Neutral Density',1,'AA2325',7.2,'hermeshine','luckydube777','david.brown.2007@hotmail.com','david brown','83 lake entrance rd oak flats','shellhabour','New South Wales','AUSTRALIA','2529','0242569543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 15:30:17',0,NULL,3,1,2,1,NULL,'luckydube777'),(12026,808642953015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',2.48,'hutongstore','pawhas123','mb-pl@wp.eu','Paul Joseph Has','8 Keogh Road','Stratford','London','UNITED KINGDOM','E15 4NR','02085347669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 16:17:09',0,NULL,3,1,2,1,NULL,'pawhas123'),(12027,730822069002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',299,'hermeshine','evgeniy_777','schamasch@gmail.com','Kovtun Evgeny','Gorkogo str. 7','Kurahovo','Donetskaj','UKRAINE','85612','+380665529364','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-25 16:30:47',0,NULL,3,1,5,1,'CP234126116CN ','evgeniy_777\r(已入库)\r800w  220v 灯泡    1\r800w 红头灯   1\r2m 弹簧灯架   1\r2m  灯架        2\r1.6x2.1m   背景架    1\r1.6x2.1m   背景布    1(白)\r反光伞   2\r双灯头   2    欧标\r115w  5500k  220v    4\r灯架包   1\r'),(12028,808669176015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','spudman444','cmpb495@aol.com','dave campbell campbell','54.CHURCHVIEW CLOSE  NEWRY ST.<br>N.IRELAND','kilkeel CO DOWN','Down','UNITED KINGDOM','BT34 4JE','02841769266','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 17:11:03',0,NULL,3,1,2,1,NULL,'spudman444'),(12029,808699505015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vasko9','vasko.chobanov@gmail.com','Vasil Chobanov','ul. Koliu Ficheto 3, et. 4','Plovdiv','Plovdiv','BULGARIA','4003','+359897059886','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-25 18:02:47',0,NULL,3,1,2,1,NULL,'vasko9'),(12030,744422147017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',2,'AA1206',5.8,'photographyacc','netauctiontraders','artie@accentfp.net.au','Robert Torresan','PO Box 1518','Griffith','New South Wales','AUSTRALIA','2680','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-25 18:37:42',0,NULL,3,1,2,1,NULL,'netauctiontraders'),(12031,808734068015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','eunhiyi','sopotterastel@yahoo.com','Katya Lofranco','16 Trinity court<br>Westhill','Aberdeen','Aberdeenshire','UNITED KINGDOM','AB32 6LS','01224379867','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-25 19:01:47',0,NULL,3,1,2,1,NULL,'eunhiyi'),(12032,690384951001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jonathan.m.s','jonathan.s.ch@hotmail.com','JONATHAN SANTANA','907 Ave San Carlos','AGUADILLA','PR','UNITED STATES','00603-4946','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 19:21:22',0,NULL,3,1,1,1,NULL,'jonathan.m.s'),(12033,808790111015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','einatik','einatik10@gmail.com','Berezin Einat','Hashoshanim 21/18','Karmiel','','ISRAEL','21764','972546415410','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-25 20:47:36',0,NULL,3,1,2,1,NULL,'einatik'),(12034,690422815001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','mcmacman2k','kmcgettigan0704@comcast.net','Kevin McGettigan','326 Biddle Dr','Exton','PA','UNITED STATES','19341-1711','(610) 425-8390','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 20:54:50',0,NULL,3,1,1,1,NULL,'mcmacman2k'),(12035,731788757002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','stanlipham','lipham@pldi.net','Stan Lipham','PO Box 483','Okeene','OK','UNITED STATES','73763','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-25 22:04:47',0,NULL,3,1,1,1,NULL,'stanlipham'),(12036,731795101002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','borman156','alboran156@gmail.com','Manuel Borrachero Juarez','Av. Roque Nublo 134','Pozuelo de Alarcon','Madrid','SPAIN','28223','636667748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-25 22:25:02',0,NULL,3,1,2,1,NULL,'borman156'),(12037,690465959001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','one01_rally','one01_ismael@hotmail.com','Ismael Bueno García','C/ Jardín de Daraja Nº 12-C','Granada','Andalucía Ceuta y Melilla','SPAIN','18008','619160279','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-25 23:21:50',0,NULL,3,1,4,1,'YW865908224CN ','one01_rally\rtripod  $22'),(12038,731816672002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','rmchahcky','mbahockey@kc.rr.com','Matthew Anderson','10504 North Forest Ave','Kansas City','MO','UNITED STATES','64155','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-25 23:51:02',0,NULL,3,1,1,1,NULL,'rmchahcky'),(12039,690305483018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',1,'',80,'photographyacc','tomspriv','tomspriv@online.no','Tom Antonsen','Kleivaveien 29C','BODOE','','NORWAY','8009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-25 23:51:51',0,NULL,3,1,3,1,'RA117777162CN ','tomspriv'),(12040,731821721002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 00:17:13',0,NULL,3,1,3,1,'RA117720724CN\r ','tawfeekmohammed\r分2个挂号小包发\rRA117720738CN\r'),(12041,744551113017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','ian_ranson','ianranson@live.com.au','Ian Ranson','16/540 North Road','Ormond','Victoria','AUSTRALIA','3204','0409790078','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-26 00:45:08',0,NULL,3,1,2,1,NULL,'ian_ranson'),(12042,731487850002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 01:16:51',0,NULL,3,1,2,1,NULL,'danieke2000'),(12043,731839286002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','mtello80','mtello80@hotmail.com','Maritza Tello','25330 Silver Aspen Way<br>Apt 933','Valencia','CA','UNITED STATES','91381-0726','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 01:45:10',0,NULL,3,1,1,1,NULL,'mtello80'),(12044,731846655002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','sanking','sanking@charter.net','S. Carl King','136 Stonegate Ct','Easley','SC','UNITED STATES','29642-8769','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-26 02:21:11',0,NULL,3,1,1,1,NULL,'sanking'),(12045,690502893001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',3.55,'hermeshine','brjostabina','k.agnars@simnet.is','Kristjana Agnarsdottir','Adalstraeti 34','Akureyri','','ICELAND','600','00354-461-1419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 02:26:45',0,NULL,3,1,2,1,NULL,'brjostabina'),(12046,690516766001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','cs663','csleung@shaw.ca','CHI SHING LEUNG','5881 ST. MARGARETS STREET','VANCOUVER','BC','CANADA','V5R3H6','(604) 431-7888','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-26 03:44:31',0,NULL,3,1,3,1,'RA117720707CN\r ','cs663\rL'),(12047,689022826001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','nikonwoman1947','nikonman@live.com.au','Dr R Johnson','5 Helena Street','Biggera Waters','Queensland','AUSTRALIA','4216','0412011140','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-26 04:47:57',0,NULL,3,0,3,1,'RA117720698CN\r ','nikonwoman1947\r2XL (已入库)'),(12048,731890952002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','narmushad','flyfishing@mail.ru','valeriy petrusha','Vjronejskaya ulica. dom14.korp 1<br>kvartira 108','moskow','ru','RUSSIAN FEDERATION','115583','+79163749582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 06:54:47',0,NULL,3,1,3,1,'RA117777091CN\r ','narmushad'),(12049,744632357017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','funny0907','jasonhong@hotmail.com','JASON HONG','61 MARKET ROAD','BROOKLYN','Victoria','AUSTRALIA','3012','0399336607','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-26 07:46:09',0,NULL,3,1,2,1,NULL,'funny0907'),(12050,808966584015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','spuncle','paulypaulo@hotmail.co.uk','Paul Mackay','41 richmond place<br>thornaby','stockton-on-tees','Cleveland','UNITED KINGDOM','ts17 9ej','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 07:55:02',0,NULL,3,1,2,1,NULL,'spuncle'),(12051,690396017018,280675004468,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop Blue/Green',1,'AC3304',68,'photographyacc','lappys1','ltsun@iprimus.com.au','Lap-Tin Tsun','Unit 603/2A Help St','Chatswood','New South Wales','AUSTRALIA','2067','0294195878','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-26 07:55:20',0,NULL,3,1,4,1,'YW865908246CN ','lappys1'),(12052,690397180018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',245,'photographyacc','marks_ute','mroy@westnet.com.au','Mark Roy','8 Pentas Crt Annandale','Townsville','Queensland','AUSTRALIA','4814','0747794353','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-26 08:01:13',0,NULL,3,1,4,1,'YW865908235CN ','marks_ute\rtripod $35'),(12053,792351204016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',4,'AA1310',15.12,'hutongstore','marsyanya','nickson2000@mail.ru','Vladimir Nikulenko','28 Kalarasha Street, Appartment 29','Tuapse','Krasnodarskiy kray','RUSSIAN FEDERATION','352803','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 09:10:25',0,NULL,3,1,2,1,NULL,'marsyanya'),(12054,744678009017,270747044999,'New 72mm Snap-on Front Lens Cap for Nikon 72 mm lenscap',1,'AA1308',2.5,'photographyacc','scrap4kids2010','dira@mellian.com','mella katriani','148 petersham road','leeton','New South Wales','AUSTRALIA','2705','0269533425','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-26 09:58:35',0,NULL,3,1,2,1,NULL,'scrap4kids2010'),(12055,731945263002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','abood103','abood5@hotmail.com','Abdullah Al-Maskeen','King Abdulaziz ST<br>P.O.Box 2229','Saihat','Eastrn region','SAUDI ARABIA','31972','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 09:59:28',0,NULL,3,1,17,0,NULL,'abood103'),(12056,809024066015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','jonno10','jonc@separatedout.com','Jonathan Collins','11 Quaker Row<br>Coates','Nr Cirencester','Gloucestershire','UNITED KINGDOM','GL7 6JX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 10:05:53',0,NULL,3,1,2,1,NULL,'jonno10'),(12057,731949144002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',87.8,'hermeshine','abood103','abood5@hotmail.com','Abdullah Al-Maskeen','King Abdulaziz ST<br>P.O.Box 2229','Saihat','Eastrn region','SAUDI ARABIA','31972','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-26 10:09:44',0,NULL,3,1,3,1,'RA117720579CN\r ','abood103\r分几个挂号小包发\r反光板 60cm 2合1     1\r2云柔     2\rRA117720582CN\r'),(12058,809038096015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','julianko001','marekkollar@hotmail.com','Marek Kollar','Lietavska 16','Bratislava','','SLOVAK REPUBLIC','85106','00421911208869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 10:35:52',0,NULL,3,1,2,1,NULL,'julianko001'),(12059,809039808015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','radboutradbout1','sargemj@btinternet.com','Tara Sargeant','9 Elm Grove<br>Wootton','Northampton','Northants','UNITED KINGDOM','NN4 6FB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 10:39:14',0,NULL,3,1,2,1,NULL,'radboutradbout1'),(12060,690455267018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',7.99,'photographyacc','natkazg','natka.zg@wp.pl','Natalia Halambiec','ul. Salomei 24/1','Zielona Góra','lubuskie','POLAND','65-831','792441074','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-26 10:41:37',0,NULL,3,1,2,1,NULL,'natkazg'),(12061,690642645001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sgyuri67','sgyuri@yahoo.com','Gyorgy Schaffer','Ady Endre u. 39.','Oroszlany','','HUNGARY','2840','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-26 11:50:31',0,NULL,3,1,5,1,'CP234126147CN ','sgyuri67\r白+黑\rbackdrop support   $18'),(12062,690483722018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',83,'photographyacc','ddimcea','ddimcea@free.fr','Dan Dimcea','51, rue des Vinaigriers','Paris','Île-de-France','FRANCE','75010','0144729435','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-26 11:57:10',0,NULL,3,1,4,1,'YW865908213CN ','ddimcea\r欧标\r$25  lighting kit'),(12063,690492840018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','giantvillain','benn.egan@three.com.au','Benn Egan','1/9 Watson Street','Macleod','Victoria','AUSTRALIA','3085','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-26 12:15:36',0,NULL,3,1,2,1,NULL,'giantvillain'),(12064,690494756018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','thecockandballs','js.190192@gmail.com','James  Smith','78-86 western avenue','Tullamarine','Victoria','AUSTRALIA','3043','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-26 12:20:37',0,NULL,3,1,2,1,NULL,'thecockandballs'),(12065,690658880001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','cocagigi','francesco.zen@tin.it','Francesco Zen','Via Marconi 39','Pove del Grappa','Vicenza','ITALY','36020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 12:32:52',0,NULL,3,1,2,1,NULL,'cocagigi'),(12066,792475609016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','steve.interstellar.nebula','interstellar.nebula@googlemail.com','Steven Openshaw','20 Pimpern Close<br>Canford Heath','Poole','Dorset','UNITED KINGDOM','BH17 9EB','01202693846','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 13:38:16',0,NULL,3,1,2,1,NULL,'steve.interstellar.nebula'),(12067,809050855015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','vespetilio','divin-marchese@hotmail.it','graziano casu','viale lombardia 9','buccinasco','Milano','ITALY','20090','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 14:43:20',0,NULL,3,1,2,1,NULL,'vespetilio'),(12068,690730569001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','pulverhuvve','owe.ramsby@soderhamn.com','Owe Ramsby','Villavagen 9','Ljusne','','SWEDEN','S82020','(46)27067646','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 15:19:27',0,NULL,3,1,3,1,'RA117720675CN\r ','pulverhuvve'),(12069,744823984017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','mushen8415','mu_shen@yahoo.com','Mu Shen','8415 rue Osaka','Brossard','QC','CANADA','J4Y 2Z6','(514) 585-7127','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-26 15:26:48',0,NULL,3,1,2,1,NULL,'mushen8415'),(12070,690619623018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','overstand2009','mhowe@silverpointcapital.com','Michele Howe','7000 Blvd E #45B','Guttenberg','NJ','UNITED STATES','07093','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-26 16:40:43',0,NULL,3,1,4,1,'YW865908202CN ','overstand2009\r美标   110v\rlighting kit   $35'),(12071,792665257016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','winboss2','matador464@yahoo.co.uk','David Rawlings','Casillero 175, Parcela 464<br>Urb. San Cristobal','Alberique','Valencia','SPAIN','46260','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 18:07:10',0,NULL,3,1,2,1,NULL,'winboss2'),(12072,690870983001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','roman-wolf','7157112@gmail.com','Roman Volkov','Corazin 5','Dimona','','ISRAEL','86094','972-523-212536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 18:46:07',0,NULL,3,1,3,1,'RA117720667CN\r ','roman-wolf'),(12073,690917419001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','10.kasper','kasper-repsak@mail.ru','Сергей Псарев','Stepnaja-64','Nizhnij Tagil','','RUSSIAN FEDERATION','622031','912 232 3826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 19:50:24',0,NULL,3,1,3,1,'RA117720485CN\r ','10.kasper'),(12074,690222857018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','mrsujg','style93@list.ru','Vadim Atroschenko','Andrekse tee 72/1','Tallinn','','ESTONIA','11912','37255534791','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-26 19:58:41',0,NULL,3,1,3,1,'RA183619826CN','mrsujg\r欧标CP234126133CN 上次灯泡坏了，再发一个给他，\r115w 220v   1'),(12075,732260984002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','alexey.camponotus','alex.camponotus@gmail.com','Alexey Vasilenko','ulitsa Akademika Kargina, dom 40, korpus 1, kvartira 152','Mytishy','Moskovskaya oblast','RUSSIAN FEDERATION','141007','+79099691337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 20:04:56',0,NULL,3,1,2,1,NULL,'alexey.camponotus'),(12076,792810900016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','kobebrain','filippocobelli@gmail.com','Filippo Cobelli','Via de Nicola 33','Concesio','BS','ITALY','25062','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-26 20:56:08',0,NULL,3,1,2,1,NULL,'kobebrain'),(12077,732306604002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','omerl10','hlv119@gmail.com','Chaim Lavy','119 Hatavor St.<br>POB 1570','Shoham','ISRAEL','ISRAEL','60850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-26 20:56:27',0,NULL,3,1,2,1,NULL,'omerl10\r欧标'),(12078,745083164017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','hunt_collect','hunt_collect@computing.net.au','Adam Patching and Suzie Bourne','5 Stanley Street','Footscray West','Victoria','AUSTRALIA','3012','0423769876','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-26 21:28:05',0,NULL,3,1,3,1,'RA117720619CN\r ','hunt_collect'),(12079,809500209015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','maszine','sylwiusz@poczta.onet.pl','Sylwester Dziegielewski','31 Wodehouse Road','Leicester','Leicestershire','UNITED KINGDOM','LE3 1PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-26 21:50:10',0,NULL,3,1,2,1,NULL,'maszine'),(12080,732087144002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','ebarioja','najerino@gmail.com','Jose Luis Martinez','C/ Capitán Gallarza, Nº 1 Entresuelo','Logroño','La Rioja','SPAIN','26001','669865104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-26 22:26:23',0,NULL,3,1,4,1,'YW865908294CN ','ebarioja\r欧标   220v\rlighting kit    $25'),(12081,691003243001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','firstarcangelm','firstarcangelm@aol.com','Michael Harrell','18320 Crawley Rd','Odessa','FL','UNITED STATES','33556-4821','(813) 928-1776','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-26 23:08:52',0,NULL,3,1,1,1,NULL,'firstarcangelm'),(12082,690868112018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','leon1058','l.bren@unimelb.edu.au','Leon Bren','604 Eyre St','Ballarat ','Victoria','AUSTRALIA','3350','0353214117','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-26 23:40:29',0,NULL,3,1,3,1,'RA117720684CN\r ','leon1058'),(12083,691026265001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','vrxs1','hfriend@bigpond.net.au','Howard Friend','16 Washington Place','Stretton','Queensland','AUSTRALIA','4116','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-27 00:38:38',0,NULL,3,1,3,1,'RA117720636CN\r ','vrxs1'),(12084,731739388002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',54.27,'hermeshine','evberk','beeberk@yahoo.com','BRUCE EVERETT','4630 Appian Way<br>Apt 204','EL SOBRANTE','CA','UNITED STATES','94803','(510) 621-8206','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-27 02:47:58',0,NULL,3,1,3,1,'RA117777026CN\r ','evberk\r肩带 无字    1\r100-150 5in1 反光板   1\r83cm 柔光伞    1\r'),(12085,691069402001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','christine9958','bonniescotland@shaw.ca','Christine Ritchie','267 Pineland Place<br>N.E.','Calgary','AB','CANADA','T1Y3L4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 03:22:25',0,NULL,3,1,2,1,NULL,'christine9958'),(12086,732442116002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','chrisecv','chris.collao@gmail.com','Christoffer Collao','Duble Almeyda #3341<br>Ñuñoa','Santiago','Region Metropolitana','CHILE','7760101','(056) 2 - 2059840','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 04:48:37',0,NULL,3,1,2,1,NULL,'chrisecv'),(12087,690947838018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','w73121','chris@loveatfirstbite.com.au','Chris Giannakis','29 Upland Rd','Strathmore','Victoria','AUSTRALIA','3041','0488332204','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-27 05:33:41',0,NULL,3,1,3,1,'RA117720790CN\r ','w73121'),(12088,691094010001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','thomfre','thomas@kaldpost.net','Thomas Fredriksen','Trondsvegen 12','Torvastad','','NORWAY','4260','48113594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 05:50:06',0,NULL,3,1,2,1,NULL,'thomfre'),(12089,690957102018,280675886664,'18% Gray Cards 8x6\"& 6x4\" for White balance exposure S',1,'AA2217',11,'photographyacc','ptp00','dave.ptp@bigpond.net.au','dave glover','775 Dalmore Road','Cardinia','Victoria','AUSTRALIA','3978','0359988342','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-27 06:30:51',0,NULL,3,1,2,1,NULL,'ptp00'),(12090,732457223002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','asibit','asibit@zahav.net.il','Asi Bitton','Hayasmin 14','Ganot Hadar','Israel','ISRAEL','42930','972548008456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 06:34:32',0,NULL,3,1,2,1,NULL,'asibit'),(12091,691100469001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','mickeylynne78','msims6146@charter.net','Michelle Sims','979 Harper Springs Rd<br>Lot 7','Sylacauga','AL','UNITED STATES','35150','(256) 245-6146','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-27 06:36:49',0,NULL,3,1,3,1,'RA117720786CN\r ','mickeylynne78\r1.6x2.1m   背景布   2(白+黑)\r'),(12092,690959488018,280680853908,'JYC-C1 Wireless Remote Control for Canon 60D 550D 450D',1,'AA3203',18,'photographyacc','techno_bot','gtaust@gmail.com','Nicholas Ho','Global Red<br>Level 5, 15 Blue St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-27 06:46:22',0,NULL,3,1,2,1,NULL,'techno_bot'),(12093,691129806001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','whatnamebetter','vincent161@sohu.com','Vincent Wen','Blk 161, Pasir Ris St. 13<br>#05-01','Singapore','Singapore','SINGAPORE','510161','65-68678025','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-27 09:11:33',0,NULL,3,1,3,1,'RA117777159CN\r ','whatnamebetter'),(12094,732492501002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',109.98,'hermeshine','fototigerfoto','viktorpalkin@gmail.com','Palkin Victor','D. Kovalchuk<br>252-68','Novosibirsk','NSO','RUSSIAN FEDERATION','630082','(923)244-1754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 09:34:57',0,NULL,3,1,5,1,'CP234126164CN ','fototigerfoto'),(12095,691135488001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','machino94','jplm94@hotmail.fr','jean-pascal le mevel','16 E rue de chennevieres','VILLIERS SUR MARNE','Île-de-France','FRANCE','94350','06 20 36 44 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 09:34:58',0,NULL,3,1,3,1,'RA117777088CN\r ','machino94'),(12096,690998505018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','veswelt','welta300@hotmail.com','ANDREW FLYNN','4 POYNTON AVE, RINGWOOD','MELBOURNE','Victoria','AUSTRALIA','3134','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-27 09:58:33',0,NULL,3,1,3,1,'RA117777131CN\r ','veswelt'),(12097,745272049017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','davo018','david_vig@hotmail.com','David Vig','2/85 King Street<br>Newtown','Sydney','New South Wales','AUSTRALIA','2042','0433971720','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-27 10:27:51',0,NULL,3,1,17,0,NULL,'davo018'),(12098,691006464018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','pookrook','chantaramas@hotmail.com','Natkamol Silpanaruji','89/222 Sussex St.','Sydney','New South Wales','AUSTRALIA','2000','0430869997','NoPaymentFailure','CheckoutComplete','AU_SmallParcels','2011-06-27 10:30:47',0,NULL,3,1,2,1,NULL,'pookrook'),(12099,691009403018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','robecaco','dennis17@tpg.com.au','Bev Dennis','9 Cashmere St','Rothwell','Queensland','AUSTRALIA','4022','0732030083','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-27 10:42:05',0,NULL,3,1,2,1,NULL,'robecaco'),(12100,745280332017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','goalkeeperdave','hern0011@gmail.com','David Hern','2/20 Windsor Street','Malvern','South Australia','AUSTRALIA','5061','0883341282','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-06-27 10:55:06',0,NULL,3,1,3,1,'RA117777043CN\r ','goalkeeperdave'),(12101,691025601018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','davo018','david_vig@hotmail.com','David Vig','Sensis Pty Ltd, Level 10, West Side<br>175 Liverpool Street','Sydney','New South Wales','AUSTRALIA','2000','0283123054','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-27 11:48:02',0,NULL,3,1,2,1,NULL,'davo018\rNG128 柔光罩    1\rCANON 镜头盖  58mm    1\r\r'),(12102,732442881002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','naseribrahim','i.naseribrahim@gmail.com','Mohd Khairul Naser Ibrahim','Perpustakaan UTHM<br>Universiti Tun Hussein Onn Malaysia','Parit Raja, Batu Pahat','Johor','MALAYSIA','86400','0197703066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 13:10:09',0,NULL,3,1,2,1,NULL,'naseribrahim'),(12103,732559087002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','shannydelic','ngshan@singnet.com.sg','Ng Shan','3A ONTARIO AVENUE #01-03','Singapore','','SINGAPORE','576192','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 14:03:57',0,NULL,3,1,11,1,NULL,'shannydelic'),(12104,691065159018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',83,'photographyacc','atjw62','tonin@welho.com','Toni Rantanen','Porslahdentie 26 C 21','Helsinki','Uusimaa','FINLAND','00980','358443101302','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-27 14:05:34',0,NULL,3,1,3,1,'RA183619300CN\r','atjw62\r欧标 220v\rlighting kit   $20\r----\r0713补发一个套装的包 + 115w 220v 给他，上一个灯泡坏了\rYW865908342CN '),(12105,809789652015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','tbmod','tbmod.com@gmail.com','Thomas Bell','17 rte du Rostrenen','Plouguernevel','Bretagne','FRANCE','22110','0256436027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-27 14:21:51',0,NULL,3,1,2,1,NULL,'tbmod'),(12106,745363026017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','nigelvera','craigwillford@vzw.blackberry.net','Craig Willford','326 Broadacre Ave','Clawson','MI','UNITED STATES','48017-1562','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-27 15:33:50',0,NULL,3,1,1,1,NULL,'nigelvera'),(12107,691245766001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','zebek001','zebek@msn.com','David Rogers','272 Heritage Park Dr','Napanee','ON','CANADA','K7R3Y1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 16:19:57',0,NULL,3,1,2,1,NULL,'zebek001'),(12108,691249884001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','artland70s','avizalam@gmail.com','Avraham Koloyarski','Ofir 8/8','Petach-Tikva','Gush Dan','ISRAEL','49238','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 16:31:30',0,NULL,3,1,3,1,'RA117777128CN\r ','artland70s'),(12109,691257789001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','ohohad','ohadoh@gmail.com','ohad ohana','Emek Haela 4/16','Modiin','','ISRAEL','71723','972506823905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 16:54:45',0,NULL,3,1,3,1,'RA117777030CN\r ','ohohad'),(12110,732630128002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','jerodesign','jerodesign@hotmail.com','Jeronimo Gomez','Avenida de Vigo,Nº9,1ºB','San Sebastian de los Reyes','Madrid','SPAIN','28702','685803781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 17:29:14',0,NULL,3,1,2,1,NULL,'jerodesign'),(12111,732649731002,120632124644,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',20.99,'hermeshine','annenuna_123','annenuna@hotmail.com','Anne Julie Luseter','Heggelund 4A','Otta','','NORWAY','2670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 18:12:55',0,NULL,3,1,3,1,'RA117777114CN\r ','annenuna_123'),(12112,691306812001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','plinio_1959','plinio.camaiti@gmail.com','Plinio Camaiti','Via Pecorini 4','Milano','MI','ITALY','20138','349-5375169','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-27 18:52:30',0,NULL,3,1,3,1,'RA117777105CN\r ','plinio_1959\rspanner   $8'),(12113,691315582001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','spadevilvg','luis.valledor@gmail.com','Luis Valledor González','La Cámara 73 Esc A, 1ºB','Aviles','Asturias','SPAIN','33401','985567709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 19:15:05',0,NULL,3,1,2,1,' ','spadevilvg'),(12114,809949048015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','kloppetzkij','ilpassatore.geo@yahoo.com','Massimo Bianconi','Voc. Colle 129','Nocera umbra','PG','ITALY','06025','3406078939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-27 19:40:33',0,NULL,3,1,2,1,NULL,'kloppetzkij'),(12115,809957459015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','studiocafaroshop*com','info@studiocafaroshop.com','Vincenza Gargano','Capotorti 30','Adelfia','BA','ITALY','70010','3491702090','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-27 19:53:00',0,NULL,3,1,2,1,NULL,'studiocafaroshop*com'),(12116,793271323016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',2,'AA1305',3.74,'hutongstore','tonjestorstrand','teia.89@gmail.com','Tonje Storstrand','Rønvikveien 32<br>leilighet 304','Bodø','Nordland','NORWAY','8009','93260595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-27 20:08:23',0,NULL,3,1,2,1,NULL,'tonjestorstrand'),(12117,691304975001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','mylenakhkh','kakona@ua.fm','Elena Moskalchuk','Lesja Kurbasa 7a flat,89','Kiev','','UKRAINE','03194','+380632137757','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 20:15:43',0,NULL,3,1,3,1,'RA117777012CN\r ','mylenakhkh'),(12118,691360283001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ketstolen','stolen@netcom.no','Kjetil Stølen','Alf Godagers vei 40','Sjetnemarka','Sør Trøndelag','NORWAY','N-7081','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-27 20:51:12',0,NULL,3,1,2,1,NULL,'ketstolen'),(12119,745553932017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','gallery4462','gallery7@inbox.com','HAMID ABDUL','GALLERY 7, UNIT 175<br>13450-102 Ave (Surrey Central City)','Surrey','BC','CANADA','V3T 5X3','(604) 582-5582','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-27 23:03:05',0,NULL,3,1,2,1,' ','gallery4462'),(12120,745564245017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',5.68,'photographyacc','exxcalibur73','benseldon@yahoo.com','Benjamin Seldon','15/14 Campbell Pde.<br>Manly Vale','Sydney','New South Wales','AUSTRALIA','2093','0299696546','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-27 23:42:56',0,NULL,3,1,2,1,NULL,'exxcalibur73'),(12121,732776269002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','natribeiro','luthier_good@hotmail.com','Ivan Ribeiro Filho','14930 Moorpark St<br>Apt 303','Sherman Oaks','CA','UNITED STATES','91403-2576','','NoPaymentFailure','CheckoutComplete','Other','2011-06-27 23:47:02',0,NULL,3,1,3,1,'RA117777145CN\r ','natribeiro\r'),(12122,691297190018,280687532335,'Studio Light 1000W Continuous Lighting Complete Kit  ',1,'AKT005',197,'photographyacc','kymbo15','alf_838@hotmail.com','amber farley','27 railway st','wyee point ','New South Wales','AUSTRALIA','2259','0243591880','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-28 00:40:26',0,NULL,3,1,4,1,'YW865908331CN ','kymbo15\r澳标\rlighting kit   $30\r'),(12123,691431547001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','sr-photo','ebayfv@gmail.com','Foto Venus','PO Box 324','Calexico','CA','UNITED STATES','92232-0324','','NoPaymentFailure','CheckoutComplete','Other','2011-06-28 01:14:41',0,NULL,3,0,3,1,'RA117777193CN ','sr-photo\r背心 黑色薄 canon 2XL(已入库)\r摄影背心 Canon  老款   XL   1\r'),(12124,691433321001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','taffpike','taffpike@hotmail.com','Alan Pike','13 Alma Court<br>Bramcote','Nuneaton','Warwickshire','UNITED KINGDOM','CV11 6QQ','01455220173','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-28 01:21:58',0,NULL,3,1,3,1,'RA117777065CN\r ','taffpike\r背心 黑色薄 canon XL    1(已入库)'),(12125,691434789001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','leo.sc','leonardo_blu@yahoo.com.br','Leonardo Pinto','Rua Bruno Zeretzke, 45<br>Bairro Itoupava Central','Blumenau','Santa Catarina','BRAZIL','89066210','047-91240822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 01:36:09',0,NULL,3,1,2,1,NULL,'leo.sc\r220v'),(12126,691316877018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',40,'photographyacc','sr-photo','ebayfv@gmail.com','Foto Venus','PO Box 324','Calexico','CA','UNITED STATES','92232-0324','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-28 01:49:48',0,NULL,3,1,1,1,NULL,'sr-photo\rXL \r'),(12127,745603613017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','shazzza16_123','shazzza16@yahoo.com','sharman urquhart','32 west church street','deloraine','Tasmania','AUSTRALIA','7304','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 02:19:36',0,NULL,3,1,2,1,NULL,'shazzza16_123'),(12128,691473157001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','mint102','mintanddeb@bigpond.com','Debbie Crothers','315 David Road','WAGGRAKINE','Western Australia','AUSTRALIA','6530','0899381217','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 04:46:14',0,NULL,3,1,2,1,NULL,'mint102'),(12129,691382204001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','turbo_quattro','david.crowo@hotmail.com','David Crowo','Fossumberget 34','Oslo','Oslo','NORWAY','0983','+4799791456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 05:07:11',0,NULL,3,0,3,1,'RA117777255CN ','turbo_quattro\r1.6x2.1 白色   2'),(12130,732844695002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','hobbit_mohnonog','hobbitmohnonog@gmail.com','Anton Kulakov','г.Москва, ул.Приречная, д.5, кв.70<br>Moscow, Prirechnaya st, 5-70','Москва','Москва','RUSSIAN FEDERATION','119633','+79262895273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 05:22:31',0,NULL,3,1,3,1,'RA117777176CN ','hobbit_mohnonog'),(12131,732845576002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sr-photo','ebayfv@gmail.com','Foto Venus','PO Box 324','Calexico','CA','UNITED STATES','92232-0324','','NoPaymentFailure','CheckoutComplete','Other','2011-06-28 05:25:11',0,NULL,3,0,17,0,NULL,'sr-photo\rxl'),(12132,732705489002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','merkandmerkand','veszpremizoltan@gmail.com','Zoltan Veszpremi','Egressy ut 27-29. B/7/7','Budapest','','HUNGARY','1149','+36 203416592','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 05:40:20',0,NULL,3,1,2,1,NULL,'merkandmerkand'),(12133,691373084018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','serkangenc1982','serkangencturk@yahoo.com','SERKAN GENÇTÜRK','ULUS İŞ HANI B-BLOK İKİNCİ KAT NO 207 YELKEN FEDERASYONU ULUS ANKARA','ANKARA','TC/ANKARA/ULUS','TURKEY','06030','05325225494','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-06-28 06:49:42',0,NULL,3,1,5,1,'CP234126249CN ','serkangenc1982\r2x1.6m 背景布   1(白)\r背景架2mx2m     1'),(12134,732858126002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gayanm','gayansm@gmail.com','Rasini Nimalaratne,','20/5, Galketiya Road,<br>Richmond Hill,','Galle','Southern Province,','SRI LANKA','10000,','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 06:53:33',0,NULL,3,1,2,1,NULL,'gayanm'),(12135,690428520018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','kimlester59','alexjplester@me.com','Kim Lester','176B Reynolds Road','Mount Pleasant','Western Australia','AUSTRALIA','6153','0893644090','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 06:57:24',0,NULL,3,0,3,1,'RA117777216CN ','kimlester59\r1.6x2.1   2  灰色  黑色   '),(12136,810169825015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','audiohitch','mhitchin@gmail.com','Mark Hitchin','69 Danube Road','Hull','East Yorkshire','UNITED KINGDOM','HU5 5UR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 07:23:54',0,NULL,3,1,2,1,NULL,'audiohitch'),(12137,732867447002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dvchunter','dave.hunter@live.nl','Dave Hunter','Hillekensacker 1028','Nijmegen','','NETHERLANDS','6546KC','0626785074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-28 07:36:50',0,NULL,3,0,3,1,'RA117777180CN ','dvchunter\r背心 Canon  老款  2XL   1(已入库)'),(12138,810026251015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','konharry','hazza1969@yahoo.co.uk','Stephen Harrison','14 Summerhill Green','Banbridge','Down','UNITED KINGDOM','BT32 3GY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 07:39:25',0,NULL,3,1,2,1,NULL,'konharry'),(12139,688689956001,110296333346,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',6.99,'hermeshine','hanhamberg','hhamberg@hotmail.com','Antro Han Hamberg','Meent 4<br>06 54 93 02 46','Leerdam','','NETHERLANDS','4141 AC','0654930246','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 08:05:58',0,NULL,3,1,2,1,NULL,'hanhamberg'),(12140,732874529002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','shayagnon','ima76@list.ru','Genady Gotsdiner','Shay Agnon 1/30','Tirat Carmel','','ISRAEL','39100','0747024123','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-28 08:14:35',0,NULL,3,1,3,1,'RA117777247CN ','shayagnon\r白色背景布 + 架子\r分两个小包发\rRA117777233CN'),(12141,809746204015,250599986868,'Large size Neoprene Lens Pouch Case 90mm x 220mm',1,'AC1203',9.78,'hutongstore','mafonso29','marcos@gestahead.com','Marcos Goncalves','R. Dr. Mário Soares<br>Lote 4, Edificio BES I - Tagus Park','Porto Salvo','','PORTUGAL','2780-920','+351914390640','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 08:25:00',0,NULL,3,1,2,1,NULL,'mafonso29\r大号镜头筒    1\r中号内胆包 canon   1'),(12142,810193779015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.92,'hutongstore','jumperswitchuk','jumper@pisem.net','Vlasdislav Korolev','Ilmarisentie 15 A d 37','Kuopio','Savo','FINLAND','70500','+358458776787','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 08:58:35',0,NULL,3,1,2,1,NULL,'jumperswitchuk'),(12143,732887125002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','nickevel','ebay@niklaslello.com','Niklas R. Lello','Enerhauggata 3<br>Leil. 1016','OSLO','Oslo','NORWAY','N-0651','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 09:16:24',0,NULL,3,1,3,1,'RA117777352CN\r ','nickevel'),(12144,732895446002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vizkeleti01','vizkeleti.janos@gmail.com','Vízkeleti János - Volkswagen','Kossuth u. 97.','Soltvadkert','','HUNGARY','6230','36305859872','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 09:54:42',0,NULL,3,1,2,1,NULL,'vizkeleti01'),(12145,793527149016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','c*h*a*r','c.h.a.r@hotmail.co.uk','Charlene Thompson','19 Tilehurst Point','Thamesmead','London','UNITED KINGDOM','SE2 9UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 09:55:43',0,NULL,3,0,3,1,'RA117777587CN ','c*h*a*r\r3mx3m  1  白色'),(12146,745704555017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','neetsberg','neetberg@gmail.com','Anita Talberg','42/34 Gosse st','KINGSTON','Australian Capital Territory','AUSTRALIA','2604','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 10:30:27',0,NULL,3,1,2,1,NULL,'neetsberg'),(12147,691542017001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','mikea2334','mcandhr@yahoo.com','Michael Ashurst','Apartado de Correos No 132','Arboleas','Almeria','SPAIN','04660','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 10:53:25',0,NULL,3,1,2,1,NULL,'mikea2334'),(12148,691435537018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','jemsley2','wilsoncrawley@gmail.com','Wilson Crawley','103 Tooth Avenue, Paddington','Brisbane','Queensland','AUSTRALIA','4064','0432919328','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 11:33:57',0,NULL,3,1,3,1,'RA117777281CN\r ','jemsley2'),(12149,745731399017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','closetncouture','tshung3381@yahoo.com','Hsiao Tshung WONG','806/488 Swanston street','Carlton','Victoria','AUSTRALIA','3053','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 12:19:55',0,NULL,3,1,3,1,'RA117777349CN\r ','closetncouture\r1.6x3m 白色'),(12150,732860870002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',3,'AB2301',29.85,'hermeshine','cue1978','kellycue6@msn.com','kelly','37 ceduna street','loganholme','Queensland','AUSTRALIA','4129','0733880233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 12:54:51',0,NULL,3,1,3,1,'RA117777321CN\r ','cue1978\r3个'),(12151,691577315001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',2,'AA1210',7.16,'hermeshine','cegato11','cegato11@yahoo.es','Antonio Devesa','Plaza de Andalucía 25','Montellano','Sevilla','SPAIN','41770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 13:08:45',0,NULL,3,1,17,0,NULL,'cegato11'),(12152,543401113003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','cegato11','cegato11@yahoo.es','Antonio Devesa','Plaza de Andalucía 25','Montellano','Sevilla','SPAIN','41770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 13:08:45',0,NULL,3,1,2,1,NULL,'cegato11\rnikon 反接环  52mm    2\r爵影红外 nikon    1\r'),(12153,691462278018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','david_groombridge','davidgroombridge@hotmail.com','David Groombridge','3/75 Dover Road<br>Scarborough','Perth','Western Australia','AUSTRALIA','6019','0893155695','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-28 13:11:34',0,NULL,3,1,17,0,NULL,'david_groombridge'),(12154,745746410017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','david_groombridge','davidgroombridge@hotmail.com','David Groombridge','3/75 Dover Road<br>Scarborough','Perth','Western Australia','AUSTRALIA','6019','0893155695','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 13:11:34',0,NULL,3,1,2,1,NULL,'david_groombridge\rMini 红外  nikon    1\r眼罩 D300    1'),(12155,810285619015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','foab22','georgewatson22@aol.com','George Watson','22 Knock avenue','Whitehills','Aberdeenshire','UNITED KINGDOM','AB452NZ','01261861281','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 13:51:28',0,NULL,3,1,2,1,NULL,'foab22'),(12156,691589385001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',35,'hermeshine','possumangelika','angelmark@optusnet.com.au','Angelika Minner','18 Royal Street','Paddington','Queensland','AUSTRALIA','4064','0733697209','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 13:53:18',0,NULL,3,1,3,1,'RA117777304CN\r ','possumangelika'),(12157,745763169017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','art5_effect','d_art5_effect@hotmail.com','Dennis Hernandez','Level 1<br>4-16 Montgomery Street','Kogarah','New South Wales','AUSTRALIA','2176','0299522208','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 13:54:41',0,NULL,3,1,2,1,NULL,'art5_effect'),(12158,691596427001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','aap240','wannadrift240@gmail.com','Evan Wetherell','255 Hillandale Dr','Stockbridge','GA','UNITED STATES','30281','(404) 219-9396','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 14:16:55',0,NULL,3,1,1,1,NULL,'aap240'),(12159,691626882001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',2,'AA1204',3.98,'hermeshine','714racer','hotrodes@earthlink.net','Eric Shields','7112 Starlight Cir','Huntington Beach','CA','UNITED STATES','92647-3543','(714) 841-5078','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-28 15:58:03',0,NULL,3,1,1,1,NULL,'714racer\r方形滤镜接口环 77mm    1\r广角托架    1\r热靴保护盖  普通   2'),(12160,732986564002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','714racer','hotrodes@earthlink.net','Eric Shields','7112 Starlight Cir','Huntington Beach','CA','UNITED STATES','92647-3543','(714) 841-5078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 15:58:04',0,NULL,3,1,17,0,NULL,'714racer'),(12161,732986436002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','714racer','hotrodes@earthlink.net','Eric Shields','7112 Starlight Cir','Huntington Beach','CA','UNITED STATES','92647-3543','(714) 841-5078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 15:58:04',0,NULL,3,1,17,0,NULL,'714racer'),(12162,810351157015,250599364553,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3302',2.18,'hutongstore','bebris19','kaspars.brivers@gmail.com','Kaspars Brivers','S.Eizensteina 71-96','Riga','','LATVIA','LV-1079','25557157','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-28 16:30:45',0,NULL,3,1,2,1,NULL,'bebris19'),(12163,691046066018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',49.6,'photographyacc','biiandcay','calebgrahamvideography@gmail.com','Caleb Graham','90 Melaleuca Drive','Yamba','New South Wales','AUSTRALIA','2464','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-28 17:49:40',0,NULL,3,1,3,1,'RA117777318CN\r ','biiandcay\r肩架  1\r60cm 2in1  反光板   1'),(12164,691547825001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-28 17:56:40',0,NULL,3,1,3,1,'RA117777278CN\r ','saud-p\r分2个小包发\r各申报 $25\rRA117777264CN\r'),(12165,810393293015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','marklatics','marandtay@googlemail.com','Mark Taylor','18 Salisbury Crescent','Ashton-Under-Lyne','Lancashire','UNITED KINGDOM','OL6 8DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 17:59:25',0,NULL,3,1,2,1,NULL,'marklatics'),(12166,810430933015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','devebm','dev78@o2.pl','Robert Krajewski','676 Holloway Rd','London','London','UNITED KINGDOM','N19 3NP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 19:02:40',0,NULL,3,1,2,1,NULL,'devebm'),(12167,745886717017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','pixie2345','frankkavanagh@yahoo.com','Frank Kavanagh','49 Thorn Chase,','Rush','Dublin','IRELAND','Dub','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-28 19:07:09',0,NULL,3,1,2,1,NULL,'pixie2345'),(12168,691701532001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','roman_guro','roman@guro.com.ua','Roman Gunyavy','9 Layosha Gavro Str., Apt.116','Kiev','','UKRAINE','04211','+38 050 1804748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 19:11:26',0,NULL,3,1,2,1,NULL,'roman_guro\r绿叶 CPL  77mm    1\r绿叶 渐变镜 77mm    1'),(12169,691701637001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','roman_guro','roman@guro.com.ua','Roman Gunyavy','9 Layosha Gavro Str., Apt.116','Kiev','','UKRAINE','04211','+38 050 1804748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 19:11:26',0,NULL,3,1,17,0,NULL,'roman_guro'),(12170,691715508001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','schivan21','moj.ebay@mac.com','Ivan Schalek','SUMRACNA 28','BRATISLAVA','','SLOVAK REPUBLIC','82102','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 19:38:21',0,NULL,3,1,2,1,NULL,'schivan21'),(12171,691614727018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','3201julien','deprezjulien@yahoo.fr','Julien Deprez','Avenue de la Nivéole, 44','Bruxelles','','BELGIUM','1020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-28 19:49:19',0,NULL,3,1,3,1,'RA117777406CN\r ','3201julien\r申报 ： tools  $10'),(12172,733121182002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','kinkycarebear69','duckylbt@hotmail.com','Kerrie Tress','708 Nicholson Frontage RD','Golden','BC','CANADA','V0A1H2','(250) 344-6828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 20:50:52',0,NULL,3,1,2,1,NULL,'kinkycarebear69'),(12173,733128338002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','heathcote66-2009','stuart_mackay@xtra.co.nz','Stuart Mackay','66A Heathcote Road<br>Milford','Auckland','Auckland','NEW ZEALAND','0620','649 410 8193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 21:12:05',0,NULL,3,1,2,1,NULL,'heathcote66-2009'),(12174,691760258001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','abnerssouza','abner.ss@hotmail.com','Abner Santos de Souza','Alameda Mamore, 911 - 18º Andar - BSA Brasil','Barueri','São Paulo','BRAZIL','06454040','55 11 83981530','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 21:24:35',0,NULL,3,1,5,1,'CP234126181CN ','abnerssouza\r申报成： tripod $30   '),(12175,745967371017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','mikakim73','michaelbeaufrere@hotmail.com','Michael BEAUFRERE','10 avenue Anatole France','clichy','Ile-de-France','FRANCE','92110','0661406986','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-28 22:00:47',0,NULL,3,1,2,1,NULL,'mikakim73\r欧标'),(12176,810511116015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','lockeye676','leonreynolds@hotmail.co.uk','Leon Reynolds','National Tyres and Autocare<br>Royal Well Place','cheltenham','Gloucestershire','UNITED KINGDOM','gl50 3dn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-28 22:02:11',0,NULL,3,1,2,1,NULL,'lockeye676'),(12177,733146802002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',21.96,'hermeshine','feeday81','holtma@whitman.edu','Martha Holt','345 Boyer Ave<br>Whitman College - Biology','Walla Walla','WA','UNITED STATES','99362','(509) 527-5306','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-28 22:03:52',0,NULL,3,1,1,1,NULL,'feeday81'),(12178,690940093018,280687532335,'Studio Light 1000W Continuous Lighting Complete Kit  ',1,'AKT005',275,'photographyacc','greenrust69','green_rust@hotmail.com','Zara Connell','113 Scott St.<br>BUNGALOW','Cairns','Queensland','AUSTRALIA','4870','0438666272','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-28 22:31:08',0,NULL,3,1,4,1,'YW865908364CN ','greenrust69（已入库）\r澳标\r除了C里的，再加上：\r2m 灯架  1\r斜臂   1\r50-70单灯头棚   1\r115w 220v   1\r包    1\rlighting kit  $40'),(12179,733156357002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','noldhernandez2011','noldhernandez@yahoo.ca','nold hernandez','491 mandalay','winnipeg','MB','CANADA','r2p1s3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 22:33:16',0,NULL,3,1,2,1,NULL,'noldhernandez2011'),(12180,691791049001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','9124208709','lpu@mail.ru','Sergey   Bunin','Sovetskiy  d. 9 k. 2 kv. 176','Novyy Urengoy','JNAO','RUSSIAN FEDERATION','629303','(912) 420-8709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-28 23:16:16',0,NULL,3,1,2,1,NULL,'9124208709'),(12181,691710587018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','hearts8085','nancy.caruso1@gmail.com','nancy caruso','52 The Strand','Mawson LAkes','South Australia','AUSTRALIA','5095','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-29 00:40:47',0,NULL,3,1,4,1,'YW865908353CN ','hearts8085\rbackground support  $25\r背景布是黑色的'),(12182,691821791001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','newsshooter2006','newsshooter@cox.net','John Farrell','5949 Round Castle St.','Las Vegas','NV','UNITED STATES','89130','(702) 204-3033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 01:35:47',0,NULL,3,1,3,1,'RA117777335CN\r ','newsshooter2006\r'),(12183,691734466018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','clintgando2010','clintgando@optusnet.com.au','clint ganderton','12 peppercorn place<br>kirrawee','sydney','New South Wales','AUSTRALIA','2232','0295217588','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 02:21:13',0,NULL,3,0,3,1,'RA117777383CN\r ','clintgando2010\r背景布 1.6x2.1m     2(白+黑)'),(12184,746040829017,270755020831,'800W Red Head for Studio Continuous Light Bulb x 5 220v',1,'AKT059',50,'photographyacc','whoismilky','whoismilky@hotmail.com','Nic Leggat','5/88 Greenway Circuit<br>Mt Ommaney','Brisbane','Queensland','AUSTRALIA','4074','0423423666','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 02:40:12',0,NULL,3,1,3,1,'RA117777366CN\r ','whoismilky'),(12186,691834336001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','rorrex1983','rorrex83@hotmail.com','Rodrigo Sanhueza','Pedro Nolasco 761, Villa Alfa','Temuco','Temuco/Temuco/de La Araucania (Novena)','CHILE','4810072','+56981397555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-29 02:43:10',0,NULL,3,1,5,1,'CP234126178CN\r ','rorrex1983'),(12189,733233936002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','aka_nobodyk','nobody-joker@yandex.ru','Vladimir Popov','Aviatorov<br>98-91','Novokuznetsk','Kemerovskaya','RUSSIAN FEDERATION','654054','+79515834788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 04:25:07',0,NULL,3,1,2,1,NULL,'aka_nobodyk'),(12190,691759257018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','schroederamos','luminiferousether@gmail.com','Adam Antonio','43 Yeramba St','Turramurra','New South Wales','AUSTRALIA','2074','0425290594','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 04:28:58',0,NULL,3,1,3,1,'RA117777370CN\r ','schroederamos'),(12191,691759489018,280680264184,'New Camera Bag Cover for Canon EOS 7D 18-135 / 18-200 ',1,'AD1115',15.99,'photographyacc','sopheakkit','he_sopheak@hotmail.com','eng sopheak hor Eng','2 cambridge drive springvale south victoria 3172','melbourne','Victoria','AUSTRALIA','3172','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 04:31:34',0,NULL,3,1,2,1,NULL,'sopheakkit'),(12192,733236603002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','venaraya','narayanaszone@gmail.com','Venkata Eepuri','15110 SW Millikan Way<br>Apt 1123','Beaverton','OR','UNITED STATES','97006-6624','(832) 704-7405','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 04:49:03',0,NULL,3,1,1,1,' ','venaraya'),(12193,733239425002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mridha','mridha0@yahoo.com','Muhammad Ridha','728 Clementi West St. 2<br>#04-406','default','','SINGAPORE','120728','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 05:00:11',0,NULL,3,1,11,1,NULL,'mridha'),(12194,691867685001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',75.9,'hermeshine','jws196868','jameson68@gmail.com','Jameson Serfontein','65 Olienhout Avenue<br>Birchleigh','Kemptonpark','Gauteng','SOUTH AFRICA','1621','+27113917354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 05:45:07',0,NULL,3,1,3,1,'RA117777397CN\r ','jws196868\r分两小包发\rRA117777454CN\r'),(12195,691867902001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','amir9129127','amirgoldshtein@gmail.com','amir goldshtein','morday agetaot 6/16','kiriat ata','','ISRAEL','28000','0509129127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 05:46:35',0,NULL,3,1,2,1,NULL,'amir9129127'),(12196,733234476002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','waynoedm','wayno@spookclub.org','Wayne Stevenson','9401-99A Ave','Morinville','AB','CANADA','T8R1J6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 05:49:49',0,NULL,3,1,2,1,NULL,'waynoedm'),(12197,691785976018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','sideshowsalon','snakaria23@gmail.com','john criscitello','1736 belmont ave','seattle','WA','UNITED STATES','98122-2166','(206) 366-5833','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-29 07:11:02',0,NULL,3,1,4,1,'YW865908386CN ','sideshowsalon\r灯泡110v   \rlighting kit  $30'),(12198,691890421001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','kmrhxlll','klaraholm@msn.com','Klara Holm','Fuglevangsvej 6A 4.th','Frederiksberg C','København','DENMARK','1962','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 07:53:39',0,NULL,3,1,2,1,NULL,'kmrhxlll'),(12199,793987724016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',36,'hutongstore','alex.hemery','alexander.hemery@gmail.com','Alexander Hemery','Foundation of the Hellenic world<br>Poulopoulou 38','Athens','','GREECE','11851','+306944817098','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 07:57:39',0,NULL,3,1,4,1,'YW865908375CN ','alex.hemery\rlight stand  $20\r'),(12200,691796475018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','stevethetenor','stephenfsmith@mac.com','Stephen Smith','4/55 King St','Wollstonecraft','New South Wales','AUSTRALIA','2065','0423266231','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 08:01:58',0,NULL,3,1,2,1,NULL,'stevethetenor'),(12201,810684856015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','rustysprinkles1','russchaplin@googlemail.com','Russell Chaplin','27 Dormington Road<br>Paulsgrove','Portsmouth','Hampshire','UNITED KINGDOM','PO6 4BT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 08:14:41',0,NULL,3,1,2,1,NULL,'rustysprinkles1'),(12202,733276237002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','marinateo88','chinkim54@hotmail.com','Jer Win Pui','36 Eldridge Grove','Cannington','Western Australia','AUSTRALIA','6107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 08:32:51',0,NULL,3,1,2,1,NULL,'marinateo88'),(12203,733279683002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','bloggenbay','pgiger@gmail.com','Peter Giger','Sörbyvägen 28','Ronneby','','SWEDEN','37231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 08:51:01',0,NULL,3,1,2,1,NULL,'bloggenbay'),(12204,810695358015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',48,'hutongstore','carlpetch','cpetch@yahoo.co.uk','carl petch','16 cranage road<br>levenshulme','manchester','Greater Manchester','UNITED KINGDOM','m19 3lg','07854391900','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-06-29 08:53:43',0,NULL,3,1,4,1,'YW865908390CN ','carlpetch\r白  黑  \rbackground support $25'),(12205,794006720016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','szityi63','szijjarto@multi-fragment.hu','Ferenc Szijjarto','Vereckei 37/b','Oroshaza','','HUNGARY','H-5900','+36 30 945-7878','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 09:14:24',0,NULL,3,1,2,1,NULL,'szityi63\r'),(12206,691908245001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','francisco2479','dontforgetfran@hotmail.com','Francisco Infante','500D Route de vesegnin<br>Prevessin Moens','Prevessin Moens','Rhône-Alpes','FRANCE','01280','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 09:25:14',0,NULL,3,1,2,1,NULL,'francisco2479'),(12207,746123564017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','kjb2006','kjbrook2006@gmail.com','Kelly  Brook','372 Marsh Avenue','North Rockhampton','Queensland','AUSTRALIA','4701','0749263720','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 09:35:13',0,NULL,3,1,3,1,'RA117777556CN\r ','kjb2006\r白色'),(12208,810709443015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.25,'hutongstore','f.faria.link','fernando.faria@link.pt','Fernando Faria','Av Duque Avila, 23','Lisboa','','PORTUGAL','1000-138','213100049','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 09:49:52',0,NULL,3,1,2,1,NULL,'f.faria.link'),(12209,745198849017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','c77ottway','made-in-australia@hotmail.com','Vittorio Dal Grande','PO Box 2232','Port Lincoln,','South Australia','AUSTRALIA','5606','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 09:57:54',0,NULL,3,1,2,1,NULL,'c77ottway'),(12210,691822168018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',6,'AE1201',26.4,'photographyacc','jrb2022','jblom@gto.net','James Blomfield','471 Laurel Gate Drive','Waterloo','ON','CANADA','N2T 2S1','(519) 885-3450','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-29 09:59:50',0,NULL,3,1,3,1,'RA117777471CN\r ','jrb2022\r6个'),(12211,691833010018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',29.5,'photographyacc','cineulas','grafimahir@hotmail.com','mahir baytore','Cumhuriyet mah. Libadiye cad. Haminne Cesme Sk. No:13 Baran is merkezi Uskudar','istanbul','Turkey/ istanbul/ uskudar','TURKEY','34696','0216 524 21 85','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-29 10:40:58',0,NULL,3,1,3,1,'RA117777437CN\r ','cineulas'),(12212,690375095018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','ziocuneo','ghl28@libero.it','luigi giujusa','via felici 14','cuneo','CN','ITALY','12100','346-7589819','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-29 10:49:27',0,NULL,3,1,2,1,NULL,'ziocuneo'),(12213,691838663018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',7.99,'photographyacc','ohms3186','omioa@yahoo.com.au','Omio Abedin','4/8 Water St.','Semaphore','South Australia','AUSTRALIA','5019','0403644265','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 11:02:31',0,NULL,3,1,2,1,' ','ohms3186'),(12214,732751768002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','lolo1125','25kin199@gadz.org','Laurent DADONE','970 chemin de Fontmerle<br>Res l\'Estagnol, Bat Les Marguerites, R2','Antibes','Provence-Alpes-Côte d\'Azur','FRANCE','06600','06.12.16.05.60','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 11:19:41',0,NULL,3,1,2,1,NULL,'lolo1125'),(12215,810751306015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','jeanutti','jeanet_glymov178@hotmail.com','Jeanet Glymov','Stationsvej 21A','Fredensborg','','DENMARK','3480','+4526222784','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 11:59:13',0,NULL,3,0,2,1,NULL,'jeanutti'),(12216,543672488003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','cegato11','cegato11@yahoo.es','Antonio  Devesa Seoane','Plaza de Andalucía 25','Montellano','Andalucía Ceuta y Melilla','SPAIN','41770','609338358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:04:02',0,NULL,3,1,17,0,NULL,'cegato11'),(12217,691945750001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','cegato11','cegato11@yahoo.es','Antonio  Devesa Seoane','Plaza de Andalucía 25','Montellano','Andalucía Ceuta y Melilla','SPAIN','41770','609338358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:04:03',0,NULL,3,1,2,1,NULL,'cegato11\r爵影红外 nikon  1\rnikon 反接环  52mm   1'),(12218,691959265001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','lynx09','b_cat@ukr.net','Evgenia Dzubenko','Heroyv Kosmosu st. 19a, 64ap.','Kyiv','Kyiv region','UKRAINE','03148','(+38097) 281-1939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:49:33',0,NULL,3,1,17,0,'','lynx09'),(12219,691959663001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','lynx09','b_cat@ukr.net','Evgenia Dzubenko','Heroyv Kosmosu st. 19a, 64ap.','Kyiv','Kyiv region','UKRAINE','03148','(+38097) 281-1939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:50:48',0,NULL,3,1,5,1,'CP234126221CN ','lynx09\r再加一个WT600'),(12220,691961523001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','vldiogo','vilaluzdiogo@gmail.com','Diogo Vila Luz','Rua João da Luz<br>Nº9','Riachos','Torres Novas','PORTUGAL','2350-366','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 12:57:31',0,NULL,3,1,2,1,NULL,'vldiogo'),(12221,733341386002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','tzvili','tsl999@gmail.com','amichay milo','T.D 1920','HASHMONAIM','ISRAEL','ISRAEL','73127','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:05:02',0,NULL,3,1,3,1,'RA117777468CN\r ','tzvili'),(12222,691754779001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',18.99,'hermeshine','abwaterbury','aryehb@bezeqint.net','Aryeh Burnham','PO Box 43044<br>60 Shaulson, apt.1','Jerusalem','','ISRAEL','95400','+97226514923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:10:29',0,NULL,3,0,3,1,'RA117777729CN ','abwaterbury\r1.6x2.1  2 黑色  绿色'),(12223,691862453001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',30,'hermeshine','bartolome82','emaitz.albizu@gmail.com','Emaitz Albizu','Plaza Elizondo<br>nº 3 5º C','Andoain','Guipuzcoa','SPAIN','20140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:17:08',0,NULL,3,1,3,1,'RA117777542CN\r ','bartolome82\r1.6m x 4m 背景布   2\r黑色   白色'),(12224,810779307015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',6.7,'hutongstore','soares197150','fsfotosoares@gmail.com','Francisco Soares','Rua das Flores nº22','Vilarandelo','Valpaços','PORTUGAL','5430-652','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 13:23:08',0,NULL,3,1,2,1,NULL,'soares197150'),(12225,691969330001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','egeorgekgk','georgekgk@gmail.com','Kostyakov Georgiy Konstantinovich','pr. Lenina 16/34','Nikolaev','Nikolaevskaya','UKRAINE','54029','+380688262020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:25:43',0,NULL,3,1,2,1,NULL,'egeorgekgk'),(12226,691967963001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:33:37',0,NULL,3,1,17,0,NULL,'galtamirgal'),(12227,733345672002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:33:37',0,NULL,3,1,3,1,'RA117777410CN\r ','galtamirgal\r倒影板（白黑）   1\r圆形柔光棚 50cm   1'),(12228,733349730002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:38:11',0,NULL,3,1,17,0,NULL,'keith10w1977'),(12229,691968779001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:38:12',0,NULL,3,1,17,0,NULL,'keith10w1977'),(12230,733345743002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.87,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 13:38:12',0,NULL,3,1,3,1,'RA117777499CN\r ','keith10w1977\rHB-7 花瓣      1\r天涯方形滤镜  ND8    1\r方形滤镜接口环 52mm    1\r方镜普通托架（三槽）     1\r'),(12231,793209793016,260661403326,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',5.2,'hutongstore','kruliko','krulik@bk.ru','Valentinas Krulikovskis','Architektu 89-30','Vilnius','','LITHUANIA','04207','+37067796547','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 13:40:43',0,NULL,3,1,2,1,NULL,'kruliko'),(12232,691888093018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','abovezer0','abovezero@sibmail.com','Boris Ushakov','Arhitektorov 5 - 29','Novokuznetsk','Kemerovskaya','RUSSIAN FEDERATION','654044','79234210000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-29 13:54:29',0,NULL,3,1,3,1,'RA117777508CN\r ','abovezer0'),(12233,691898210018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','jimbot22961','james_wallace@optusnet.com.au','James Wallace','17 Prunda Parade','Ipswich','Queensland','AUSTRALIA','4305','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-06-29 14:26:16',0,NULL,3,1,4,1,'YW865908401CN ','jimbot22961\rbackdrop support   $20'),(12234,746208379017,270757382435,'Studio 1000W Continuous Lighting Complete Kit 3mx6m G',1,'AKT063',319,'photographyacc','kilshaugen','roger@kilshaugen.no','Roger Mikalsen','Kil','Naustbukta','','NORWAY','7990','+4799113938','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-29 14:32:02',0,NULL,3,1,5,1,'CP234126235CN ','kilshaugen\r欧标\rbackdrop support  $25\rC++\r3x6m  背景布    1(白色)\r一共2块布\r'),(12235,691988473001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',4,'AE3301',55.92,'hermeshine','amperel2011','amperel1@017.net.il','Amperel ltd. (EB)','Shderot Jerusalem 168 Street','Holon','Israel','ISRAEL','58829','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 14:34:02',0,NULL,3,1,3,1,'RA117777423CN\r ','amperel2011\r欧标\r'),(12236,810807904015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','ristokae','chanaris@gmail.com','Risto Hedlund','Kristian II:S vag 14b','Engelholm','','SWEDEN','26234','+46736850936','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-29 14:35:51',0,NULL,3,1,2,1,NULL,'ristokae'),(12237,733373958002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','robertoricca74','rricca@hotmail.com','roberto ricca','Via Seminario 6/E','Botticino','BS','ITALY','25082','3397307160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 15:12:54',0,NULL,3,1,3,1,'RA117777485CN\r ','robertoricca74\rphotography boom arm'),(12238,733400487002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','quintanaderueda','quintanarueda@gmail.com','javier cebreros','oscar wilde<br>11','malaga','Andalucía Ceuta y Melilla','SPAIN','29010','952300508','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-29 16:27:23',0,NULL,3,1,3,1,'RA183614205CN','quintanaderueda\r---RA117777600CN \r新地址:\rFRANCISCO JAVIER CEBREROS \rMARQUEZ CALLE OSCAR WILDE 11 BLOQUE 2 7d\rMALAGA 29010 \rSPAIN\r952300508\r----\r0718了，按新地址补发一个给他'),(12239,692090287001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','450_millington','zone_invader@hotmail.com','Brtuce Millington','252 Larocque','Longueuil','QC','CANADA','J4G 2N1','(450) 442-4281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 19:04:58',0,NULL,3,1,2,1,NULL,'450_millington'),(12240,692015993018,280685221276,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm ',1,'AE3403',38,'photographyacc','trishaskyscape','trishhejda@bigpond.com','Trisha Hejda','11 ONSLOW RD','Kingsdale','New South Wales','AUSTRALIA','2580','0248226039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 19:18:48',0,NULL,3,1,3,1,'RA117717243CN\r ','trishaskyscape'),(12241,810843954015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','lindaalchin','lindaka@btinternet.com','linda alchin','16 castleton road','mitcham','Surrey','UNITED KINGDOM','cr4 1ny','02086792603','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 19:44:18',0,NULL,3,1,2,1,NULL,'lindaalchin'),(12242,733491680002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','clarobabu','dvillalbacano@gmail.com','david villalba cano','c loma de los riscos 73, n 54','torremolinos','Malaga','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 19:45:26',0,NULL,5,1,4,0,'','clarobabu\rtripod  $20\r---\r该订单截留北京的,然后由燕文欧洲转发一票'),(12243,733497532002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','lgparkes1','lgparkes@bell.net','Larry Parkes','25 John St. West<br>Apt. 506','Oshawa','ON','CANADA','L1H 8J5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 19:58:25',0,NULL,3,1,2,1,NULL,'lgparkes1'),(12244,691799848018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','stopforgettingyourusername','sapperpie@gmail.com','Peter Farmer','103 Streisand Drive<br>McDowall','Brisbane','Queensland','AUSTRALIA','4053','00422462484','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-29 21:03:34',0,NULL,3,1,2,1,' ','stopforgettingyourusername'),(12245,811011400015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','cooko22','cooko22@hotmail.com','Peter Cookson','35 Church Road','Lytham St Annes','Lancashire','UNITED KINGDOM','FY8 3TL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-29 21:09:23',0,NULL,3,1,2,1,NULL,'cooko22'),(12246,733541763002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','airglenners','glennjakobsen7@hotmail.com','Glenn Jakobsen','fagernesveien 3','Narvik','','NORWAY','8514','004795081710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 21:56:18',0,NULL,3,1,2,1,NULL,'airglenners'),(12247,733546000002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','malihonda','magnus_linstad91@hotmail.com','Magnus Linstad','Haugsbakkroken 18','jaren','jaren','NORWAY','2770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-29 22:07:34',0,NULL,3,1,4,1,'YW865908596CN ','malihonda\rtripod  $20'),(12248,692190808001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 00:01:25',0,NULL,3,1,17,0,NULL,'neno63'),(12249,733573611002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-30 00:05:46',0,NULL,3,1,17,0,NULL,'neno63'),(12250,692118839018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','joelsk78','joelisrad@gmail.com','Joel Sabadin','Factory 5<br>51 moreland rd','coburg','Victoria','AUSTRALIA','3058','0433227964','NoPaymentFailure','CheckoutComplete','AU_Other','2011-06-30 00:14:03',0,NULL,3,1,2,1,NULL,'joelsk78'),(12251,692192517001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 00:22:42',0,NULL,3,1,5,1,'CP234126218CN ','neno63\r欧标   \r背景架2m x 3m + 3个夹子    1\r2x1.6m      背景架    1\r1.6x2.1m   背景布    2(白+黑)\r3x6m          背景布     1(绿色)\r2m 灯架   4\r反光伞    4\r双灯头    4\r115w 220v     4\r45w   220v     4\r灯架包    2'),(12252,746455309017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','nnh97','njalnhansen@hotmail.com','Njál Hansen','Jákup Nolsøes gøta 20','Tórshavn','Færøerne','DENMARK','FO-100','+298 277944','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-30 01:16:29',0,NULL,3,1,2,1,NULL,'nnh97'),(12253,692090767018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','buddyman03','buddy2000@live.com.au','Daniel Mychajlyshyn','M2 Telecommunications<br>Level 10, 60 City Road','Southbank','Victoria','AUSTRALIA','3006','0396746565','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 03:06:56',0,NULL,3,1,2,1,NULL,'buddyman03'),(12254,733620112002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','stormeyetg','stormeye007@hotmail.com','antoine tremblay gendron','1406 fougere','prevost','QC','CANADA','j0r1t0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 03:49:20',0,NULL,3,1,2,1,NULL,'stormeyetg'),(12255,746489708017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',5.66,'photographyacc','sharjeel_hasan','sharjeel_hasan@hotmail.com','sharjeel hasan','4 Endeavour Avenue, Thomastown Vic 3074','Melbourne','Victoria','AUSTRALIA','3074','0469173181','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 03:53:19',0,NULL,3,1,2,1,NULL,'sharjeel_hasan'),(12256,733623355002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','stasili4','dsv2803@gmail.com','Dunda Stanislav','Amurskiy bulvar,st. 36-85','Khabarovsk','FAR EAST','RUSSIAN FEDERATION','680000','8 924 206 2252','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 04:09:17',0,NULL,3,1,2,1,NULL,'stasili4'),(12257,692244813001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','riendi','chochon@gmail.com','Marylise Devoyault','1066 Rang 1 Ouest','Sainte-Christine','QC','CANADA','J0H 1H0','(819) 858-9926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 04:52:35',0,NULL,3,1,2,1,NULL,'riendi'),(12258,692178989018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','danieljbae','smugfuzz@gmail.com','Daniel Bae','Level 23, 2 Park Street','Sydney','New South Wales','AUSTRALIA','2000','0282254659','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 05:28:56',0,NULL,3,1,3,1,'RA117777511CN','danieljbae'),(12259,733636047002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','lutfibajamal1206','lutfibajamal@gmail.com','lutfi bajamal','Jl. Galur Sari Barat No.23 , utan kayu selatan , matraman , jakarta timur.','jakarta timur','DKI JAKARTA','INDONESIA','13120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 05:30:44',0,NULL,3,1,2,1,NULL,'lutfibajamal1206'),(12260,746508853017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','bymblack','ebay@bymblack.com','Alana Black','91 Chestwood Crescent','Sippy Downs','Queensland','AUSTRALIA','4556','0754770171','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 05:46:54',0,NULL,3,1,2,1,NULL,'bymblack'),(12261,733429226002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','nadirerdir','nadir@erdir.com','nadir erdir','7407 sok no:15 pınarbası Bornova','Izmir','ege','TURKEY','35060','+902324793303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 06:16:26',0,NULL,3,1,2,1,NULL,'nadirerdir'),(12262,692264195001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','dbchillin40','dbchillin@gmail.com','Darvell Bowen','1722 W Beverly Glen Pkwy','Chicago','IL','UNITED STATES','60643','(773) 895-7126','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-30 06:57:27',0,NULL,3,1,1,1,NULL,'dbchillin40'),(12263,692196106018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','pallav_t','pallav.tiwari@gmail.com','Manjula Mishra','219/43 High Street<br>PRESTON','MELBOURNE','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 07:10:46',0,NULL,3,1,2,1,' ','pallav_t\r1.6x2.1m   背景布    1  \r（白色)'),(12264,746526630017,270750687158,'New Camera shoulder bag A1 for Canon Dslr 550D 500D',1,'AO0029',25.8,'photographyacc','kokom9','srdjan_nine@yahoo.com.au','Srdan Begic','14 Hopkins Street','Dandenong','Victoria','AUSTRALIA','3175','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 07:22:37',0,NULL,3,1,3,1,'RA117777525CN ','kokom9'),(12265,692205976018,280680857434,'New JYC-N3 Wireless Remote Control for Nikon D90 D7000',1,'AA3202',18,'photographyacc','buntoro','buntir@gmail.com','Buntoro Irawan','1C Hertford St','East Victoria Park','Western Australia','AUSTRALIA','6101','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 08:00:54',0,NULL,3,1,2,1,NULL,'buntoro'),(12266,692301485001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','f2048','warrenkj@cybernet.co.nz','Warren Jones','MBE P350<br>92 Franklin Road, Ponsonby','Auckland','','NEW ZEALAND','1002','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-30 10:09:28',0,NULL,3,0,3,1,'RA117777692CN\r ','f2048\rXXXL(已入库）'),(12267,692301475001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','aldak10','aldai@tvnet.lv','Alda Kanajeva','Ganu iela 6-5','Riga','','LATVIA','LV-1010','+371 26383636','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-30 10:13:44',0,NULL,3,1,5,1,'CP227125340CN ','aldak10'),(12268,811233763015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mihy.san','tomas.mihula@gmail.com','Tomas Mihula','K. Pokorneho 1402/26','Ostrava - Poruba','','CZECH REPUBLIC','70800','+420603515190','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-30 11:09:13',0,NULL,3,1,17,0,NULL,'mihy.san'),(12269,794525020016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','mihy.san','tomas.mihula@gmail.com','Tomas Mihula','K. Pokorneho 1402/26','Ostrava - Poruba','','CZECH REPUBLIC','70800','+420603515190','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-30 11:09:13',0,NULL,3,1,2,1,NULL,'mihy.san\r圆形柔光棚 50cm    1\rlenspen     1'),(12270,746581171017,270741930246,'QR Quick Release Plate Video Tripod Head 717 EI-717AH',1,'AB1204',18,'photographyacc','jayspotting','info@jayjohnson.com.au','Jay Johnson','257 great western highway','Emu Plains','New South Wales','AUSTRALIA','2750','0404155666','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 11:22:56',0,NULL,3,1,2,1,NULL,'jayspotting'),(12271,733706308002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ver17as','danielmoeller@email.de','Daniel Moeller','19 Burwood Road','Whitebridge','New South Wales','AUSTRALIA','2290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 11:36:53',0,NULL,3,1,4,1,'YW865908622CN ','ver17as'),(12272,692336956001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','tony2818','tonystanyer@optusnet.com.au','Tony Stanyer','14 Neasham Drive','Dandenong North','Victoria','AUSTRALIA','3175','0397956826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 12:40:19',0,NULL,3,1,3,1,'RA117777689CN\r ','tony2818'),(12273,794566227016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7.99,'hutongstore','sani_uk','sani_jatti@hotmail.com','Amandeep Nahal','36 Callaghan Road','Tividale','West Midlands','UNITED KINGDOM','B69 3NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 13:17:09',0,NULL,3,0,2,1,' ','sani_uk\r(已入库)\rND2     1\r62mm   转接环    1\r普通托架    1\r'),(12274,811278292015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','mohammadnamazi','omennmao@yahoo.com','Mohammad Namazi','43, Falmouth road<br>Borough','London','London','UNITED KINGDOM','SE1 4JN','07717283817','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 13:23:45',0,NULL,3,1,2,1,NULL,'mohammadnamazi'),(12275,733734477002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','nafikova','galiya.tenten@gmail.com','Ekaterina Nafikova','ul: Zorge/d: 66/kv: 51','Ufa','','RUSSIAN FEDERATION','450075','7(347)244-6018','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-06-30 13:25:48',0,NULL,3,1,3,1,'RA117777701CN\r ','nafikova'),(12276,794573550016,260768456440,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',6,'AA1309',11.22,'hutongstore','teamworkphoto','sales@teamworkphoto.com','Ty Wheatcroft','Teamwork - 41/42 Foley Street','London','London','UNITED KINGDOM','W1W7JN','02073236455','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-06-30 13:38:35',0,NULL,3,1,3,1,'RA117777658CN\r ','teamworkphoto'),(12277,692302668018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','bernadetteelothian','stackit83@gmail.com','Narvesh Prasad','2 Julius Avenue','North Ryde','New South Wales','AUSTRALIA','2113','0401872551','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-06-30 14:48:34',0,NULL,3,1,3,1,'RA117777635CN\r ','bernadetteelothian'),(12278,692385260001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:32:17',0,NULL,3,1,17,0,NULL,'juno01'),(12279,692385125001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:32:18',0,NULL,3,1,17,0,NULL,'juno01'),(12280,733772047002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:34:25',0,NULL,3,1,17,0,NULL,'juno01'),(12281,692387360001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:37:06',0,NULL,3,1,17,0,NULL,'juno01'),(12282,733773754002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:39:48',0,NULL,3,1,17,0,NULL,'juno01'),(12283,692391458001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 15:49:47',0,NULL,3,1,3,1,'RA117777750CN\r ','juno01\r新式内胆包小号    1\rcanon 三角包  D3    1\r橡胶遮光罩 58mm    1\rCANON 镜头盖  58mm    1\r热靴保护盖  普通     2\r372'),(12284,733788301002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','b4u86','sevastjanov@inbox.lv','Sevastjanovs Igors','Dzelzavas str. 71-25','Riga','','LATVIA','LV-1084','+371 29463995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 16:23:18',0,NULL,3,1,2,1,NULL,'b4u86'),(12285,811359268015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','zamzibar','brcalado@gmail.com','Marta Helena Rosa','Ladeira do Monte Seco','Loulé','Portugal','PORTUGAL','8100-311','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-06-30 16:53:44',0,NULL,3,1,3,1,'RA117777613CN\r ','zamzibar'),(12286,733798672002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','felipebatera22felipe','felipebatera22@hotmail.com','felipe feijo almeida','rua dr helio viana<br>1524','fortaleza','ceara','BRAZIL','60320240','55 85 32238538','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 16:56:39',0,NULL,3,1,3,1,'RA117777627CN\r ','felipebatera22felipe'),(12287,692364655018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','angelmm75','angelmm75@hotmail.com','Angel Moreno Moreno','Trafalgar nº 92 Local (Esfera peluqueros)','San juan de aznalfarache','Sevilla','SPAIN','41920','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-30 17:27:50',0,NULL,3,1,4,1,'YW865908611CN ','angelmm75\r背景布    黑色'),(12288,733845100002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','leevanu','leevu@rediffmail.com','Leevon Thomas','Crown Plaza Hotel<br>Near Sheikh Zayed Road','Dubai','Dubai','UNITED ARAB EMIRATES','564','00971503211459','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 18:51:23',0,NULL,3,1,2,1,'\r ','leevanu'),(12289,733851567002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','rojair','grondinphotog@myfairpoint.net','Roger Grondin','2 Bancroft Rd','Londonderry','NH','UNITED STATES','03053-2836','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-06-30 19:04:54',0,NULL,3,1,17,0,NULL,'rojair'),(12290,733850219002,120538959115,'NEW Flash Diffuser for Canon 580EX II',2,'AB3332',5.2,'hermeshine','rojair','grondinphotog@myfairpoint.net','Roger Grondin','2 Bancroft Rd','Londonderry','NH','UNITED STATES','03053-2836','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 19:04:54',0,NULL,3,1,17,0,NULL,'rojair'),(12291,733846648002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',54.99,'hermeshine','rojair','grondinphotog@myfairpoint.net','Roger Grondin','2 Bancroft Rd','Londonderry','NH','UNITED STATES','03053-2836','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 19:04:55',0,NULL,3,1,3,1,'RA117777746CN\r ','rojair\r闪光的柔光箱   60cm     1\r肥皂盒 柔光罩   580EX    2\r圆形柔光棚 50cm    1\r1.67\r'),(12292,733857058002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','arrakios','eolobox-paypal@yahoo.com','Roger Martinez','C/Carretera de Malilla nº 88 puerta 19','Valencia','Comunidad Valenciana','SPAIN','46026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 19:16:52',0,NULL,3,1,2,1,NULL,'arrakios\r欧标'),(12293,733880723002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','laszlo_foto1982','laszlo_foto@freemail.hu','Laszlo Kovacs','str. Partizanilor Bl. B9, Ap. 19','Salaj','','ROMANIA','455300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 20:09:55',0,NULL,3,1,2,1,NULL,'laszlo_foto1982'),(12294,733891638002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','sirpe2009','sirpe86@hotmail.com','Magnus Ohlsson','Brattensväg 6A<br>311 35','Falkenberg','Halland','SWEDEN','31135','+46702930395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 20:35:31',0,NULL,3,1,2,1,NULL,'sirpe2009'),(12295,733890051002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',15,'hermeshine','inabollo','izurutuza@euskalnet.net','Ignacio Zurutuza C/O Femy Pinto','NTFP-EP Cambodia<br>#10Eo, Street 420 Sangkat Boeung Trabek, Khan Chamkarmon','Phnom Penh','','CAMBODIA','20000','+85512514289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 20:39:16',0,NULL,3,1,2,1,NULL,'inabollo'),(12296,692457027018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','tobs_lucky','luciano.tobia@gmail.com','Cristina Altomare','Via sirio, 99','Terni','Terni','ITALY','05100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-06-30 20:57:20',0,NULL,3,1,2,1,NULL,'tobs_lucky'),(12297,733917343002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',2,'AC2304',12.48,'hermeshine','pelaohc','hcasacubertag@gmail.com','Humberto Casacuberta G','Berna 4680, Lo Barnechea','Santiago','Metropolitana','CHILE','770-0010','(562) 494-6873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 21:43:04',0,NULL,3,1,2,1,NULL,'pelaohc'),(12298,733916482002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','vacationvermont','kajukenbo@sbcglobal.net','Lisa Plourde','3038 Hillegass Ave','Berkeley','CA','UNITED STATES','94705','(510) 409-4223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-06-30 21:44:02',0,NULL,3,1,3,1,'RA117777644CN\r ','vacationvermont'),(12299,692553407001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','alberto298','bonialberto@hotmail.it','ALBERTO BONI','via Corletto, 15/A','Corlo di Formigine','MO','ITALY','41043','347-5545000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-06-30 23:10:27',0,NULL,3,1,2,1,NULL,'alberto298'),(12300,692511616018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','railboy18','lkantek@bigpond.net.au','John Kantek','205, 11th Ave','Austral','New South Wales','AUSTRALIA','2171','0296060719','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 00:46:07',0,NULL,3,1,3,1,'RA117777675CN\r ','railboy18'),(12301,794851028016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','igoryany4','ig-or@list.ru','Мартьянов Максим','ул.1Строителя, д.42, кв.94','Павлово','Нижегородская обл','RUSSIAN FEDERATION','606107','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-01 00:50:42',0,NULL,3,1,5,1,'CP227125336CN','igoryany4\r欧标\r'),(12302,811574489015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','1marowak9000','death9000@hotmail.co.uk','Tony Le Bourne','21 fairisle road','southampton','Hampshire','UNITED KINGDOM','so168by','07821599583','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 01:27:19',0,NULL,3,1,2,1,NULL,'1marowak9000'),(12303,811581770015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','dariopenadario','dariopena1@hotmail.com','Dario Duraes Ferreira Pena','Rua Emilio Pinheiro Barros, 239<br>Apt. 301','Belo Horizonte','Minas Gerais','BRAZIL','30360130','(31) 3297-5188','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 01:56:26',0,NULL,3,1,2,1,NULL,'dariopenadario'),(12304,733978122002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','alainmtech','gvc56k@hotmail.com','alain laforce','346 st-regis sud','st-isidore','QC','CANADA','j0l2a0','(450) 454-2157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 02:08:36',0,NULL,3,1,2,1,NULL,'alainmtech'),(12305,8881309486216506,111,'canon 10m ttl 线',1,'AB3326',0,'photographyacc','maxxxwinter','dr.winter@gmx.at','Milovan Malimarcov','VIDEO2BRAINIdlhofgasse 5','Graz','Graz','Austria','8020','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA117777732CN','是补发的\r地址：\rMilovan Malimarcov\rVIDEO2BRAIN\rIdlhofgasse 5\rGraz  8020\rAUSTRIA \r已发货'),(12318,8881309488812049,111,'10m ttl',1,'',0,'hermeshine','abc','12@asd,com','tes','teswd<br>asdf','beijing','','china','','',NULL,NULL,NULL,NULL,0,NULL,5,0,18,0,NULL,NULL),(12317,8881309488809529,111,'10m ttl',1,'',0,'hermeshine','abc','12@asd,com','tes','teswd<br>asdf','beijing','','china','','',NULL,NULL,NULL,NULL,0,NULL,5,0,18,0,NULL,NULL),(12316,8881309488805107,111,'10m ttl',1,'',0,'hermeshine','abc','12@asd,com','tes','teswd<br>asdf','beijing','','china','','',NULL,NULL,NULL,NULL,0,NULL,5,0,18,0,NULL,NULL),(12319,734002860002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mageprokia','goh_hong_jie@hotmail.com','Jared Goh Hong Wei','Block 90 Tanglin Halt Road #18-332','default','','SINGAPORE','141090','98375735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 04:21:53',0,NULL,3,1,11,1,NULL,'mageprokia'),(12320,689521217001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','mihalevx','mihalev-andrey@yandex.ru','Andrey Mihalev','Semirechenskaya st.  136/58','Omsk ','RU','RUSSIAN FEDERATION','644016','79620367711','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 06:06:13',0,NULL,3,1,5,1,'CP227125353CN ','mihalevx'),(12321,794920385016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',6.5,'hutongstore','alfieboy91','yuklanhowong@hotmail.com','Y.L. HO-WONG','PRINSES MARIJKESTRAAT 30','DIEMEN','','NETHERLANDS','1111 EK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 06:10:14',0,NULL,3,1,2,1,NULL,'alfieboy91'),(12322,746931005017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','prepress_gun','graphicx@westnet.com.au','Shane Davey','77 Esmond Road','Port Pirie','South Australia','AUSTRALIA','5540','0886325400','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 06:31:15',0,NULL,3,1,2,1,NULL,'prepress_gun'),(12323,734024358002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','speedyblueman','pcspecialist007@yahoo.com.au','Sai Wong','15 Rosemount Ave','Pennant Hills','New South Wales','AUSTRALIA','2120','0299808456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 06:39:53',0,NULL,3,1,17,0,NULL,'speedyblueman'),(12324,734024228002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','speedyblueman','pcspecialist007@yahoo.com.au','Sai Wong','15 Rosemount Ave','Pennant Hills','New South Wales','AUSTRALIA','2120','0299808456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 06:39:54',0,NULL,3,1,2,1,NULL,'speedyblueman\r绿叶 渐变镜 72mm    1\r绿叶 渐变镜 58mm    1'),(12325,691933401001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',43.79,'hermeshine','psvehv82','teunehv@kunen.nl','Ton Kunen','Boschdijk 275','EINDHOVEN','','NETHERLANDS','5612HD','0647312898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 07:25:39',0,NULL,3,1,3,1,'RA117777715CN ','psvehv82'),(12326,692592760018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','thatwinningfeeling','cgsprott@gmail.com','Chris Sprott','32 Cameron Street','Reservoir','Victoria','AUSTRALIA','3073','0394422386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 07:27:24',0,NULL,3,1,3,1,'RA117777803CN ','thatwinningfeeling'),(12327,692644244001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','hualunz','hualunlun@hotmail.com','chua hua lun','Jurong West Street65 Blk606 #15-586','default','','SINGAPORE','640606','+6592961413','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-01 07:37:38',0,NULL,3,1,3,1,'RA117777794CN ','hualunz'),(12328,811662622015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','markulous','markulousuk@yahoo.co.uk','Mark Cavendish','The Rock Cottage<br>Middleton-by-Youlgreave','BAKEWELL','Derbyshire','UNITED KINGDOM','DE45 1LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 08:18:00',0,NULL,3,1,17,0,NULL,'markulous'),(12329,794946015016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','markulous','markulousuk@yahoo.co.uk','Mark Cavendish','The Rock Cottage<br>Middleton-by-Youlgreave','BAKEWELL','Derbyshire','UNITED KINGDOM','DE45 1LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 08:18:01',0,NULL,3,1,17,0,NULL,'markulous'),(12330,794945810016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',2,'AD1110',21.3,'hutongstore','markulous','markulousuk@yahoo.co.uk','Mark Cavendish','The Rock Cottage<br>Middleton-by-Youlgreave','BAKEWELL','Derbyshire','UNITED KINGDOM','DE45 1LS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 08:18:01',0,NULL,3,1,3,1,'RA117777785CN ','markulous\r普通有线快门线C1    1\r机身盖/镜头后盖  Canon   1\r肩带 Q-strap 单   2'),(12331,692622671018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',6.6,'photographyacc','hagler666','martinlavtas@gmail.com','Martin Lavtas','PO Box 5441','East Victoria Park','Western Australia','AUSTRALIA','6981','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 09:50:33',0,NULL,3,1,2,1,NULL,'hagler666'),(12332,692624517018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','cayetanom2005','cayetano.maltese@three.com.au','cayetano maltese','98 grantham rd','seven hills','New South Wales','AUSTRALIA','2147','0296032673','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 10:14:24',0,NULL,3,1,3,1,'RA117777817CN ','cayetanom2005'),(12333,811719526015,250692237054,'Green.L 77mm 77 Neutral Density ND4 Filter ND 4 New',1,'AE2307',4.55,'hutongstore','redstudiosales2011','redstudiosales@gmail.com','Joakim Hasselgren','Skolgaa 32','Norrkoping','Ostergotland','SWEDEN','60225','0735-026095','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 11:49:05',0,NULL,3,1,2,1,NULL,'redstudiosales2011'),(12334,733049089002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','dropbear65','steven.jensen@optusnet.com.au','Steven Jensen','90 Fourth Avenue','MARSDEN','Queensland','AUSTRALIA','4132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 11:49:26',0,NULL,3,1,2,1,NULL,'dropbear65'),(12335,734094462002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','shahlesnoit101','shahlesnoit@hotmail.com','Shahridzuan Selamat','Block 24 Marsiling Drive #07-191','default','','SINGAPORE','730024','+65 90115111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 12:27:47',0,NULL,3,1,11,1,NULL,'shahlesnoit101'),(12336,692706312001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','valamalgame','amalgamephotographie@videotron.ca','Valérie Mathon','72 rue Valéri Paquin','St-Joseph-du-lac','QC','CANADA','j0n1m0','(450) 491-5163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 12:36:00',0,NULL,3,1,3,1,'RA117777936CN ','valamalgame\r注意是\"金属卡口\"'),(12337,692654720018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',6.2,'photographyacc','weavenr','n.weaver@optusnet.com.au','Neil R Weaver','5 Cotham Hill Road','Ocean Grove','Victoria','AUSTRALIA','3226','0352552374','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 12:06:02',0,NULL,3,1,2,1,NULL,'weavenr'),(12338,811742412015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'AA2203',2.75,'hutongstore','griffsmg','s.m.griffiths@liverpool.ac.uk','Susan Griffiths','8 Castle Drive, Formby','Liverpool','Merseyside','UNITED KINGDOM','L37 6EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 12:52:13',0,NULL,3,1,2,1,NULL,'griffsmg'),(12339,692711261001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','seldom1011','lotosam@yahoo.com','Arshak Torosyan','Zakian str.4','Yerevan','','ARMENIA','0010','091 49 83 86','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 12:53:51',0,NULL,3,1,2,1,NULL,'seldom1011'),(12340,692675473018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',21.5,'photographyacc','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-01 13:23:02',0,NULL,3,1,3,1,'RA183617290CN','emuexport81RA117777922CN \r\r再发两个盖给他，白色和橙色的(以后补发时帮忙把发货日期都写一下)'),(12341,811753441015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','clivew1045','clivewdunn@googlemail.com','Chris DUNN','14 MUNTJAC CLOSE<br>BRETTON','PETERBOROUGH','Cambridgeshire','UNITED KINGDOM','PE3 9FR','01733702081','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 13:25:46',0,NULL,3,1,2,1,NULL,'clivew1045'),(12342,734126653002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','joe_exit','joe_exit7@hotmail.com','Pablo Andres Giacobone','Remedios de escalada 2370<br>remedios de escalada 2356','Mar del Plata','Buenos Aires','ARGENTINA','7600','+542235275922','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-01 14:21:31',0,NULL,3,1,3,1,'RA117717098CN ','joe_exit'),(12343,734130315002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',5.99,'hermeshine','sequevillaros','kordovilla@gmail.com','Santos Cordovilla Rodriguez        ','Urb. Palmeiro Blo. 36 5º C','Xove','Galicia','SPAIN','27870','982592605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 14:36:22',0,NULL,3,1,2,1,NULL,'sequevillaros\r绿叶 ND4  72mm    1\r绿叶 CPL 72mm     1'),(12344,811781663015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.9,'hutongstore','dnb747','dnbeck@sky.com','Darren Beck','3 Brookfield Rd','Thornton','Lancashire','UNITED KINGDOM','FY5 4DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 14:44:17',0,NULL,3,1,11,1,' ','dnb747\r重量原因， 发小包不挂号'),(12345,692740906001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 14:47:21',0,NULL,3,1,3,1,'RA117777919CN ','lufox77\r注意,是金属卡口'),(12346,692741989001,110419738494,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',7.3,'hermeshine','sequevillaros','kordovilla@gmail.com','Santos Cordovilla Rodriguez        ','Urb. Palmeiro Blo. 36 5º C','Xove','Galicia','SPAIN','27870','982592605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 14:47:31',0,NULL,3,1,17,0,NULL,'sequevillaros'),(12347,734136577002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','bsvls','bsvls@centurytel.net','Debbie Biesheuvel','370 Bear Canyon Rd','Lakeside','MT','UNITED STATES','59922','(406) 844-0262','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-01 14:58:41',0,NULL,3,1,1,1,NULL,'bsvls'),(12348,692746772001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 15:03:12',0,NULL,3,1,2,1,NULL,'dvdguychatter2'),(12349,734156349002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','chossoun','bahaanadem@yahoo.com','bahaa nadem','38768 fairfield dr','sterling heights','MI','UNITED STATES','48310-3146','(586) 822-5693','NoPaymentFailure','CheckoutComplete','Other','2011-07-01 16:03:03',0,NULL,3,1,1,1,NULL,'chossoun\rXL'),(12350,747083121017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','senyxx','senyx@senyx.net','Jan Straka','Na Kavčí skále 1696-12','Říčany','','CZECH REPUBLIC','25101','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-01 16:20:26',0,NULL,3,1,2,1,NULL,'senyxx'),(12351,734170675002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','croosh_moose','mathewjglover@gmail.com','Mathew Glover','51 Corlette Street<br>Cooks Hill','Newcastle','New South Wales','AUSTRALIA','2300','0431343818','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-01 16:51:32',0,NULL,3,0,3,1,'RA117777975CN ','croosh_moose\r背心 Canon  老款   XL    1(已入库)'),(12352,734179308002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','fabiomberte','fmberte@hotmail.com','Fábio Müller Berté','Av. República Argentina, 3021<br>cj. 302','Curitiba','Paraná','BRAZIL','80610-260','(41) 3078-8989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 17:17:23',0,NULL,3,1,2,1,NULL,'fabiomberte'),(12353,795131624016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',3,'AD1110',31.95,'hutongstore','raumanni111','raumanni@glocalnet.net','Nils Raumanni','Institutsgatan 14','Göteborg','Västra Götaland','SWEDEN','41875','0704494606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-01 17:40:21',0,NULL,3,1,3,1,'RA117777984CN ','raumanni111'),(12354,734194080002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dodoberecz214','berecz@atknet.sk','Dodo Berecz','Rožňavská 3','Košice','','SLOVAK REPUBLIC','04011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 17:57:10',0,NULL,3,1,2,1,NULL,'dodoberecz214'),(12355,811863648015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','jambutty53','davidhartley91@gmail.com','David Hartley','5 Kilmory Drive<br>Breightmet','Bolton','Lancashire','UNITED KINGDOM','BL2 6UG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 17:59:02',0,NULL,3,1,2,1,' ','jambutty53'),(12356,0,250847620008,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.1,'hutongstore','camobat143','andy.smith@tiscali.co.uk','Andrew Smith','26 Tudor House Close<br>Newhall','Swadlincote','Derbyshire','UNITED KINGDOM','DE11 0LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 19:19:26',0,NULL,3,1,2,1,NULL,'camobat143\r眼罩 450D/500D     1\r眼罩 40D/50D          1'),(12357,0,260810745904,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',0.1,'hutongstore','camobat143','andy.smith@tiscali.co.uk','Andrew Smith','26 Tudor House Close<br>Newhall','Swadlincote','Derbyshire','UNITED KINGDOM','DE11 0LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 19:19:26',0,NULL,3,1,17,0,NULL,'camobat143'),(12358,692838426001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',38.5,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-01 19:37:39',0,NULL,3,1,3,1,'RA117777953CN ','krisvisual'),(12359,692850574001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','drivershell','saraeskanderr@gmail.com','Sara Eskander','1303 9th St apt. 1','north bergen','NJ','UNITED STATES','07047','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-01 20:07:27',0,NULL,3,1,1,1,' ','drivershell'),(12360,692871748001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','hubroen','jobrekk@online.no','Jan Olav Brekke','Hubroåsen 14','Sandefjord','Vestfold','NORWAY','3227','+4733471016','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 21:07:48',0,NULL,3,1,2,1,NULL,'hubroen'),(12361,734285812002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','raleighstraker','pyry.kurko@gmail.com','Pyry Kurko','Luistelijantie 2 C 18','Kuopio','Kuopio','FINLAND','70200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-01 22:23:44',0,NULL,3,1,4,1,'YW865908563CN ','raleighstraker\rtripod  $20\r'),(12362,795259106016,260660052658,'New Camera shoulder bag D1 for Canon body and 1-2 lens',1,'AO0031',13.9,'hutongstore','moali786','alimo@live.co.uk','T Ali','124 Harford Street','London','London','UNITED KINGDOM','E1 4QD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-01 22:33:15',0,NULL,3,1,3,1,'RA117777967CN ','moali786'),(12363,747232941017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','profo33','pjphotography1@live.com','Peter James','1 orrong place<br>craigieburn','melbourne','Victoria','AUSTRALIA','3064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-01 23:10:33',0,NULL,3,1,2,1,NULL,'profo33'),(12364,734312014002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',27.9,'hermeshine','guruggame','guruggamer@gmail.com','Olzhas Izmuratov','7microdistrict 24home 3ap.<br>7-24-3','Aktau','Mangistau','KAZAKHSTAN','130000','512897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 00:31:01',0,NULL,3,1,3,1,'RA117777905CN ','guruggame'),(12365,734312570002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',3,'AA1216',41.7,'hermeshine','foxtrotbangkok','foxtrot.bangkok@gmail.com','Artem Bogdanov','per. Grivtcova<br>26-32','Saint-Petersburg','','RUSSIAN FEDERATION','190031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 00:39:49',0,NULL,3,1,3,1,'RA117777896CN ','foxtrotbangkok'),(12366,747255883017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','sally_annep','sally_annep@hotmail.com','sally-anne stubbings','20 powell street','richmond','New South Wales','AUSTRALIA','2753','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 01:00:06',0,NULL,3,1,2,1,NULL,'sally_annep'),(12367,812028673015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','sadas_in','sarit.das@gmail.com','Sarit Das','117 Cubitt Way','Peterborough','Cambridgeshire','UNITED KINGDOM','PE2 9NF','7518814104','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-02 01:45:19',0,NULL,3,1,2,1,NULL,'sadas_in'),(12368,734339817002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','eternity0022','masood.mansoori@gmail.com','Masood Mansoori','20 - Powell Crescent, iLam','Christchurch 8041','','NEW ZEALAND','','0064220398870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 03:08:51',0,NULL,3,1,2,1,NULL,'eternity0022'),(12369,692945451001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',4,'AA2217',35.96,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 03:13:10',0,NULL,3,1,3,1,'RA117778004CN ','mariomarques.com.br\r4个'),(12370,747290967017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',6.98,'photographyacc','slees40','steve@completecs.com.au','Stephen Lees','2 Seaview Parade','Dromana','Victoria','AUSTRALIA','3936','0403752143','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 04:17:04',0,NULL,3,1,2,1,NULL,'slees40'),(12371,747306626017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','14melndal','mellababe@live.com','melissa hill','12 paul mclean place','dubbo','New South Wales','AUSTRALIA','2830','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 05:49:39',0,NULL,3,1,2,1,NULL,'14melndal'),(12372,734364242002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','rakkiatt4425','rakkiatt@yahoo.com','Rakkiat Thanakitleelacharoen','80/1559 Tippawan village Thaparak Rd.<br>Bangmoungmai','Moungsamutprakarn','Samutprakarn','THAILAND','10270','660894884425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 05:49:40',0,NULL,3,1,17,0,NULL,'rakkiatt4425'),(12373,692974691001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','rakkiatt4425','rakkiatt@yahoo.com','Rakkiat Thanakitleelacharoen','80/1559 Tippawan village Thaparak Rd.<br>Bangmoungmai','Moungsamutprakarn','Samutprakarn','THAILAND','10270','660894884425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 06:32:50',0,NULL,3,1,8,1,'CP227125375CN ','rakkiatt4425\r斜臂    1\r反光板支架   1\r1.819'),(12374,727794519002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','viganiaraane','anasnasheed@hotmail.com','Anas','Manaam Building, 2/1 Neeloafaru Magu','Male\'','Galholhu','MALDIVES','20129','9607788766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 06:47:02',0,NULL,3,1,2,1,NULL,'viganiaraane'),(12375,692985927001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',75,'hermeshine','binksjr45','johnbinks@yahoo.com.au','John Binks','10 Mcguire Mews','Rockingham','Western Australia','AUSTRALIA','6168','0895273184','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTrackingAndSignature','2011-07-02 07:32:26',0,NULL,3,1,4,1,'YW865908504CN ','binksjr45\rreflector holder   $25'),(12376,734386049002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','real_reach','kamaletdinovr@gmail.com','Rinat Kamaletdinov','Zorge 82-208','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630106','+79232429860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 07:58:06',0,NULL,3,1,2,1,NULL,'real_reach'),(12377,8881309596607152,111,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',0,'',0,'hermeshine','kasher B','bdkasher@yahoo.com.au','kasher B','2746 Old Coast road','Herron ','Western Australia','AUSTRALIA','','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA117777998CN ','补发 '),(12378,812134493015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','jumbo-jacko48','johnjackman@talktalk.net','John Jackman','6 Victoria Road','Coulsdon','Surrey','UNITED KINGDOM','CR5 2NN','02086450044','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-02 09:38:45',0,NULL,3,1,2,1,NULL,'jumbo-jacko48'),(12379,693015040001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','qwertynhours','informacion@dohana.com','francisco garcia laguna','pedro munoz seca, 3','alcala de henares','Madrid','SPAIN','28805','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-02 09:51:50',0,NULL,3,1,17,0,NULL,'qwertynhours'),(12380,693014515001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','qwertynhours','informacion@dohana.com','francisco garcia laguna','pedro munoz seca, 3','alcala de henares','Madrid','SPAIN','28805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 09:51:50',0,NULL,3,1,17,0,NULL,'qwertynhours'),(12381,693014324001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','qwertynhours','informacion@dohana.com','francisco garcia laguna','pedro munoz seca, 3','alcala de henares','Madrid','SPAIN','28805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 09:51:51',0,NULL,3,1,3,1,'RA117717107CN\r ','qwertynhours\r天涯方形滤镜  渐变橙   1\r天涯方形滤镜  渐变蓝  1\r天涯方形滤镜  渐变灰   1\r天涯方形滤镜  ND2    1\r天涯方形滤镜  ND4    1\r天涯方形滤镜  ND8     1\r6片装的滤镜袋    1\r天涯方形滤镜系列  星光镜  star8    1\r还有c里的52-77mm ring + 托架\rcpl    1\r\r\r\r'),(12382,747356082017,270748973692,'Male 52mm-58mm 52-58 mm Macro Reverse Ring / reversing',1,'AA1212',3.8,'photographyacc','fishdance99','aquaholic99@hotmail.com','Winston Woo','61 Malbon Street<br>Eight Mile Plains','Brisbane','Queensland','AUSTRALIA','4113','0423070214','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 09:59:05',0,NULL,3,1,2,1,NULL,'fishdance99'),(12383,8881309601048380,111,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',0,'hermeshine','psvehv82','teunehv@kunen.nl','Ton Kunen','Boschdijk 275','EINDHOVEN','','NETHERLANDS','5612HD','0647312898',NULL,NULL,NULL,NULL,0,NULL,3,1,2,1,NULL,' nikon 眼罩   1\r大力夹球台   1\r'),(12384,812154240015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','kadams60','keith@keithadamsphotography.co.uk','keith adams','106 cotswold crescent','billingham','Cleveland','UNITED KINGDOM','TS23 2QB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-02 10:47:23',0,NULL,3,0,2,1,NULL,'kadams60'),(12385,693034527001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','ronglixiang','donxiang@gmail.com','dong xiang  C/- Sharron Vercoe','N50_0.37 Nathan campus, Griffith University<br>170 Kessels Road, Nathan','Brisbane','Queensland','AUSTRALIA','4111','0737355311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 11:24:02',0,NULL,3,1,2,1,NULL,'ronglixiang'),(12386,8881309606340298,111,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1309',2.6,'hermeshine','aleksejvbns','aleksejbns@gmail.com','Aleksej Vasic','Borisa Kidrica 8<br>26314 Banatsko Novo Selo','Banatsko Novo Selo','','Serbia','26314','+381603030654',NULL,NULL,NULL,NULL,0,NULL,3,1,2,1,NULL,'77mm canon 镜头盖  1\r(已入库） \r新地址:\r--去掉原地址的第4行'),(12387,734433467002,120570270849,'YONGNUO WIRELESS REMOTE CORD FOR SONY RM-S1AM A700',1,'AA3214',25,'hermeshine','cortesino','eugeniomorcillo@gmail.com','Eugenio Morcillo Romero','C/ Villanueva, 100. 3º G','Don Benito','Extremadura','SPAIN','06400','652686088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 11:36:15',0,NULL,3,1,2,1,NULL,'cortesino'),(12388,812172460015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','boter1','boter.huis@scarlet.be','Wilfried Verzyck','Generaal Baron Jacquesstraat 45','Diksmuide','','BELGIUM','8600','+3251503614','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-02 11:46:39',0,NULL,3,1,3,1,'RA117717040CN ','boter1\rMonopod   $10'),(12389,747385723017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','robwtas','rob.white@utas.edu.au','Rob White','School of Zoology, University of Tasmania<br>Pvt Bag 5','Hobart','Tasmania','AUSTRALIA','7001','0402340744','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 11:49:11',0,NULL,3,1,2,1,' ','robwtas'),(12396,693057317001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','howard_munson','trupy@freenet.de','Thorsten Rupp','Neckarstr.12','Braunschweig','','GERMANY','38120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:44:15',0,NULL,3,1,2,1,NULL,'howard_munson'),(12391,8881309609338849,111,'32 \"5-in-1 Light Mulit Collapsible disc Reflector 80cm ',1,'AC3301',16,'hermeshine','goranchagoran','gvelemir@gmail.com','Goran Velemir','Dobrovoljačka 32','Veternik-Novi Sad','','SERBIA','21203','',NULL,NULL,NULL,NULL,0,NULL,3,1,2,1,NULL,NULL),(12397,747402363017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',76.16,'photographyacc','simplymjt','mjtenterprises@live.com','Marrisa Vitale Thomas','6 Callander Ave','Old Reynella','South Australia','AUSTRALIA','5161','(040) 999-7996','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 12:46:16',0,NULL,3,1,3,1,'RA183619579CN\r','simplymjt （已入库）\r2m 灯架   1\r单灯头 澳标   1\r反光伞   1\r110cm 柔光伞  1\r115w 220v   1\r橡胶遮光罩 52mm    1\rLighting Kit   $20\r2.418\rYW865908530CN \r-----\r上次伞发成反光伞了，0715重发一个\r110cm 柔光伞   1（已减库）\r'),(12398,692492702001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.3,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','Rua Sempre Viva 155/304<br>Privavera','Timoteo','Minas Gerais','BRAZIL','35182-446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 12:58:49',0,NULL,3,1,3,1,'RA117717053CN ','elizeucine'),(12399,693063229001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','ita_88','deenn30@hotmail.com','Khairudin Menon','2/136 Greenacre Drive<br>Parkwood','Gold Coast','Queensland','AUSTRALIA','4214','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 13:06:12',0,NULL,3,1,2,1,NULL,'ita_88'),(12400,734465235002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-02 13:37:24',0,NULL,3,1,3,1,'RA117717019CN ','leofotografias'),(12401,693083317001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','evilkenivel77','saloruud@gmail.com','Helge Salomonsen','Eiriks gate 17 A','Oslo','Oslo','NORWAY','0650','0047 93036605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 14:23:03',0,NULL,3,1,17,0,NULL,'evilkenivel77'),(12402,734478141002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','evilkenivel77','saloruud@gmail.com','Helge Salomonsen','Eiriks gate 17 A','Oslo','Oslo','NORWAY','0650','0047 93036605','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-02 14:23:04',0,NULL,3,1,3,1,'RA117717036CN ','evilkenivel77\r115w 5500k 灯泡  220v    2\r45w 5500k 灯泡  220v    2'),(12403,693074011018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-02 14:43:26',0,NULL,3,1,2,1,NULL,'bfg27248937'),(12404,693104815018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',27.98,'photographyacc','olilebuis','olilebuis@hotmail.com','olivier lebuis','876 app3, rue arsenault','sherbrooke','QC','CANADA','j1h3w7','(514) 250-7161','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-02 16:44:07',0,NULL,3,1,3,1,'RA117717084CN ','olilebuis\r1.6x2.1m     背景布  2 (白+黑)'),(12405,734532497002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','scrappingirl10','jessgray78@yahoo.com','Jess Gray','5514 Shady Lawn Dr','Hope Mills','NC','UNITED STATES','28348-5712','(910) 849-6861','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-02 17:03:27',0,NULL,3,1,1,1,NULL,'scrappingirl10'),(12406,812319373015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',2,'AE2201',54,'hutongstore','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 9 A 4','Tampere','','FINLAND','33100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-02 17:54:44',0,NULL,3,1,4,1,'YW865908574CN ','zuhmia\r欧标\rlight soft box   $20\r2.118\r'),(12407,795614133016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'',11.8,'hutongstore','mikakim73','michaelbeaufrere@hotmail.com','Michael BEAUFRERE','10 avenue Anatole France','clichy','Ile-de-France','FRANCE','92110','0661406986','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-02 18:47:54',0,NULL,3,1,2,1,NULL,'mikakim73\r大力夹   2（已入库）'),(12408,693192432001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','djoh9717','daron417@yahoo.com','Darren Johnson','61 Elmont Street','Dorchester','MA','UNITED STATES','02121','(617) 778-4820','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-02 19:27:46',0,NULL,3,1,3,1,'RA117777879CN ','djoh9717'),(12409,734601855002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','alexcantar','alexcan200@gmail.com','Alex Cantarovich','Har\'el 23<br>ap. 3','Haifa','Israel','ISRAEL','34555','+972-54-6092-720','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 20:10:13',0,NULL,3,1,2,1,NULL,'alexcantar'),(12410,734630215002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','eax53','eafloriza@yahoo.com','Erick Floriza','P.O. Box 1099','Al-Khobar','','SAUDI ARABIA','31952','00966561410172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 21:41:02',0,NULL,3,1,2,1,NULL,'eax53'),(12411,734644795002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','johnnyhawg','jkristalovich@gmail.com','john kristalovich','448 Bedson','Winnipeg','MB','CANADA','R3K1S1','(204) 999-4566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-02 22:38:31',0,NULL,3,1,2,1,NULL,'johnnyhawg'),(12412,812448324015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',9.15,'hutongstore','ggrbld','gabri.garibaldi@virgilio.it','Gabriele Garibaldi','Via della rosa, 37','Viareggio','LU','ITALY','55049','0584-942292','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-02 22:59:12',0,NULL,3,1,2,1,NULL,'ggrbld'),(12413,734664318002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','juliogranata5vha','juliogranata@yahoo.com','Julio Granata','Estrada 3287','Olivos','Buenos Aires','ARGENTINA','1636','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 00:04:44',0,NULL,3,1,2,1,NULL,'juliogranata5vha'),(12414,734665273002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','arickana','arickan@gmail.com','Erica Rollingson','1604 - 2445 Kingsland Rd SE','Airdrie','AB','CANADA','T4A 0B7','(403) 922-9849','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 00:09:47',0,NULL,3,1,2,1,NULL,'arickana'),(12415,693267202018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','realizador_cordobes','alvaromedina@hotmail.es','ALVARO MEDINA CANO','Calle Santa Isabel, 12, Piso 1,1<br>Piso 1,1','CÓRDOBA','Andalucía Ceuta y Melilla','SPAIN','14001','680341016','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 00:33:55',0,NULL,3,1,2,1,NULL,'realizador_cordobes'),(12416,747649297017,270748637112,'Capa Quick Double Shoulder Belt Strap for 2 DSLR camera',1,'AD1111',38,'photographyacc','llin6494','lancelind@gmail.com','Lance Lind','334/10 Holmead Road<br>Eight Mile Plains','Brisbane','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-07-03 01:08:12',0,NULL,3,1,3,1,'RA117777777CN ','llin6494'),(12417,747652863017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','jasonbutcher182','jbutcher@victeach.com.au','Jason Butcher','1/40 Albert Avenue','Boronia','Victoria','AUSTRALIA','3155','0392854170','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-03 01:36:05',0,NULL,3,1,4,1,'YW865908526CN ','jasonbutcher182\r澳标\rlighting kit $30'),(12418,734692647002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','denis_kulak','denkulak@gmail.com','Denis Kulak','Cheryomushki 79/69','Sayanogorsk','Khakasiya','RUSSIAN FEDERATION','655619','+79617400340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 02:40:18',0,NULL,3,1,2,1,NULL,'denis_kulak'),(12419,795769202016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','batetosho','tl@radio1.bg','Todor Lichev','7,Yantra St.','Plovdiv','','BULGARIA','4000','+359888452818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 02:57:52',0,NULL,3,1,17,0,NULL,'batetosho'),(12420,812502953015,250692240149,'Remote Control Cord For Canon 5D Mark II 50D 40D RS-80N',1,'AA2219',2.89,'hutongstore','batetosho','tl@radio1.bg','Todor Lichev','7,Yantra St.','Plovdiv','','BULGARIA','4000','+359888452818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 02:57:53',0,NULL,3,1,17,0,NULL,'batetosho'),(12421,693297711001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','93386855','fotogiorgio@yahoo.com','Jorge Gonzalez','Marchant Pereira 1921 torre f<br>Depto. 1207 providencia','Santiago','Region Metropolitana','CHILE','7501041','56 9 93386855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 03:35:22',0,NULL,3,1,3,1,'RA117777763CN ','93386855'),(12422,795779102016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','batetosho','tl@radio1.bg','Todor Lichev','7,Yantra St.','Plovdiv','','BULGARIA','4000','+359888452818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 03:41:42',0,NULL,3,1,2,1,' ','batetosho\rcanon 三角包  D3   1\r优永佳快门线 A C3   1\r方镜普通托架（三槽）   1\r方形滤镜接口环 58mm   1\r0.354'),(12423,747707450017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','kulbir2002','mrcoolcool2002@yahoo.com','kulbir singh','426 springvele rd<br>glen waverley','melbourne','Victoria','AUSTRALIA','3150','0430406255','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-03 06:57:38',0,NULL,3,1,17,0,NULL,'kulbir2002'),(12424,747710606017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','kulbir2002','mrcoolcool2002@yahoo.com','kulbir singh','426 springvele rd<br>glen waverley','melbourne','Victoria','AUSTRALIA','3150','0430406255','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-03 07:00:44',0,NULL,3,1,2,1,NULL,'kulbir2002\r眼罩 D300   2'),(12425,812572652015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','mouraonunes','mourao.nunes@gmail.com','Ricardo Mourão','Rua Drº João de Barros nº17 9º dtº','Lisboa','Portugal','PORTUGAL','1500-230','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-03 08:18:06',0,NULL,3,1,4,1,'YW865908493CN ','mouraonunes\rtripod $20\r'),(12426,812576433015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','kopite_matt','matthew.link@o2.co.uk','Matt Link','Towergate Financial, Pegasus Court<br>Olympus Avenue, Tachbrook Park','Warwick','Warwickshire','UNITED KINGDOM','CV34 6LW','07747443642','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 08:31:40',0,NULL,3,1,2,1,' ','kopite_matt'),(12427,693351036018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','mitch.mover','sander@vip-room.nl','sander van den berg','hermelijnweide 33','veghel','','NETHERLANDS','5467 kx','06-22502250','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 08:42:23',0,NULL,3,1,2,1,NULL,'mitch.mover'),(12428,734755699002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','yukajoan','fervenan@telefonica.net','JOAQUÍN GARCÍA LAÍN','PASEO DEL REY 30','MADRID','Madrid','SPAIN','28008','676517319','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 08:45:26',0,NULL,3,1,4,1,'YW865908552CN ','yukajoan\rTripod  $20'),(12429,812606452015,250847013703,'Quick double Shoulder Strap for 2 SLR DSLR Camera Nikon',1,'AD1111',21,'hutongstore','tohums','tormod.humstad@gmail.com','Tormod Humstad','Høgreina 290','Flatåsen','','NORWAY','7079','+4795994844','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 09:48:51',0,NULL,3,1,3,1,'RA117777851CN ','tohums'),(12430,693379480018,280680879798,'Camera Remote Shutter Release Cord RS-C3 Canon 40D 50D ',1,'AA3211',5.69,'photographyacc','nahbuts','benny.walpole@gmail.com','Ben Walpole','Tradelink Building, Group IM<br>2nd Floor 1051 Nudgee Rd','Banyo','Queensland','AUSTRALIA','4014','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-03 09:58:24',0,NULL,3,1,2,1,' ','nahbuts'),(12431,693382912018,280689694480,'New Continuous Lighting System umbrella with bulbs',1,'AKT068',110,'photographyacc','leisha2005','clwalker@bigpond.net.au','Leisha Walker','196 Parkview Crescent','CORNUBIA','Queensland','AUSTRALIA','4130','0732097916','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-03 10:11:26',0,NULL,3,1,4,1,'YW865908541CN ','leisha2005\r澳标\rlighting kit   $28'),(12432,693389755001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','rodrigoslater76','slater76@gmail.com','Rodrigo Souza','Av. Emb. Abelardo Bueno 3350<br>Bl 2 apt 503 Barra dda Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22775040','97030309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 10:16:59',0,NULL,3,1,3,1,'RA117777848CN ','rodrigoslater76'),(12433,693423717001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','thorvaldsdottir','o.thorvaldsdottir@hotmail.com','Ólöf Helga Þorvaldsd. Linnet','Reykás 43','Reykjavík','','ICELAND','110','(354) 770-3009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 12:00:42',0,NULL,3,1,17,0,NULL,'thorvaldsdottir'),(12434,693422385001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','thorvaldsdottir','o.thorvaldsdottir@hotmail.com','Ólöf Helga Þorvaldsd. Linnet','Reykás 43','Reykjavík','','ICELAND','110','(354) 770-3009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 12:00:43',0,NULL,3,1,17,0,NULL,'thorvaldsdottir'),(12435,734817685002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','thorvaldsdottir','o.thorvaldsdottir@hotmail.com','Ólöf Helga Þorvaldsd. Linnet','Reykás 43','Reykjavík','','ICELAND','110','(354) 770-3009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 12:00:43',0,NULL,3,1,5,0,'CP227125384CN ','thorvaldsdottir\r2B柔    1\r天涯方形滤镜  渐变棕     1\r反光板支架     1\r圆形柔光棚 60cm    1\r'),(12436,795947281016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','markwalkerliverpool','mwk@simcorp.com','Mark Walker','Hovedgaden 11D','Store Magleby','','DENMARK','2791','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 12:48:33',0,NULL,3,1,2,1,NULL,'markwalkerliverpool'),(12437,693439324018,280666919433,'New Neoprene Camera Cover for Canon 550D+18-55mm',1,'AC1305',9.99,'photographyacc','corduroyadventures','corduroycate@hotmail.com','C E Rann','4 Tebbutt Street','Leichhardt','New South Wales','AUSTRALIA','2040','0299815321','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-03 12:48:42',0,NULL,3,1,2,1,NULL,'corduroyadventures'),(12438,693440894001,110583278181,'TianYa 55mm CPL filter New 55 Circular Polarizing C-PL',1,'AA2302',5.7,'hermeshine','amund1958','jimhagan@buckeye-express.com','JAMES HAGAN','2618 WEALDSTONE ROAD','TOLEDO','OH','UNITED STATES','43617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 12:49:15',0,NULL,3,1,17,0,NULL,'amund1958'),(12439,734835179002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','amund1958','jimhagan@buckeye-express.com','JAMES HAGAN','2618 WEALDSTONE ROAD','TOLEDO','OH','UNITED STATES','43617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 12:52:21',0,NULL,3,1,17,0,NULL,'amund1958'),(12440,693438901001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.9,'hermeshine','amund1958','jimhagan@buckeye-express.com','JAMES HAGAN','2618 WEALDSTONE ROAD','TOLEDO','OH','UNITED STATES','43617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-03 12:52:21',0,NULL,3,1,1,1,NULL,'amund1958\r镜头筒 xl 大号     1\r爵影无线N1    1\r天涯 cpl 55mm     1'),(12441,693441504001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','jowi-fi','johannes.wilke@web.de','Johannes Wilke','Oststraße 53','Osnabrück','','GERMANY','49084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 12:54:50',0,NULL,3,1,2,1,NULL,'jowi-fi'),(12442,693476359001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',2,'AO0015',15.8,'hermeshine','tomamak','tomamak@hotmail.com','tom mamakos','chrisomallousis 31 b<br>chrisomallousis 31 b mytilene','Mitilini','lesvos','GREECE','81100','6942653752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:27:06',0,NULL,3,1,2,1,NULL,'tomamak'),(12443,812735664015,250847013703,'Quick double Shoulder Strap for 2 SLR DSLR Camera Nikon',1,'AD1111',21,'hutongstore','*tobio*','tobias.olbrich@gmx.de','Tobias Olbrich','Simonaue 2a','Essen','','GERMANY','45239','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 14:32:53',0,NULL,3,1,3,1,'RA117777834CN ','*tobio*'),(12444,692696531001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',3.66,'hermeshine','gmizo','ivars.gmizo@inbox.lv','Ivars Gmizo','Skolas iela 8a - 56','Rezekne','PW','LATVIA','LV-4601','(+371)27874403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:40:24',0,NULL,3,1,17,0,NULL,'gmizo'),(12445,734877686002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gmizo','ivars.gmizo@inbox.lv','Ivars Gmizo','Skolas iela 8a - 56','Rezekne','PW','LATVIA','LV-4601','(+371)27874403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 14:40:25',0,NULL,3,1,17,0,NULL,'gmizo'),(12446,693481232001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','gmizo','ivars.gmizo@inbox.lv','Ivars Gmizo','Skolas iela 8a - 56','Rezekne','PW','LATVIA','LV-4601','(+371)27874403','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 14:41:52',0,NULL,3,1,2,1,NULL,'gmizo\rEW-73B    1\rlenspen     1\r绿叶 UV  67mm    1'),(12447,734914013002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',5,'AA1310',27.45,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 16:00:25',0,NULL,3,1,3,1,'RA117777825CN ','bobi1330'),(12448,796046571016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','luttonnen','luttonnen@inbox.lv','Galina Lutonina','Hapsalas, 1/2 - 12','Riga','Latvia','LATVIA','LV1005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 16:03:59',0,NULL,3,1,17,0,NULL,'luttonnen'),(12449,747965823017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','joe_hunt888','joe_hunt888@yahoo.com','JOHAN','Jl. Veteran No.82<br>/office: Toko ACC Jl. Penghubung No. 15','BERASTAGI -','SUMATERA UTARA','INDONESIA','22156','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 17:27:04',0,NULL,3,1,2,1,NULL,'joe_hunt888'),(12450,747970755017,270742403077,'New IR Wireless Remote Control for Pentax Canon Nikon ',1,'AA2205',5.48,'photographyacc','peppies74','frohlich.josef@is.liberec.cz','Frohlich Josef','Jezkova 911/9','Liberec 6','Czech republic','CZECH REPUBLIC','46006','+420777133874','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 17:34:05',0,NULL,3,1,2,1,NULL,'peppies74'),(12451,735022365002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','1337x','hoop3r@gmail.com','Igor Danilov','Tihaya 33 217','Moscow','RU','RUSSIAN FEDERATION','109387','84953528063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 18:38:16',0,NULL,3,1,2,1,NULL,'1337x'),(12452,693636017018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','djz407','djz@cfl.rr.com','Anthony Zampella','1273 Blackwater Pond Dr','Orlando','FL','UNITED STATES','32828','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-03 18:43:55',0,NULL,3,1,1,1,NULL,'djz407'),(12453,693667143001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','scubacole20','zztop88@hotmail.com','Steven Cole','11 Redwood Green S.E.','Medcine Hat','AB','CANADA','T1B4A2','(403) 952-7046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 19:44:04',0,NULL,3,1,2,1,NULL,'scubacole20'),(12454,813025423015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','32yellowking','king-of-spades@hotmail.co.uk','Mark Brewster','43 Rowan Avenue','Hove','East Sussex','UNITED KINGDOM','BN3 7JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 20:39:14',0,NULL,3,1,17,0,NULL,'32yellowking'),(12455,813025424015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','32yellowking','king-of-spades@hotmail.co.uk','Mark Brewster','43 Rowan Avenue','Hove','East Sussex','UNITED KINGDOM','BN3 7JF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 20:39:15',0,NULL,3,1,2,1,NULL,'32yellowking\r橡胶遮光罩 67mm    1\r橡胶遮光罩 52mm    1'),(12456,813042718015,250692238780,'New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',20.9,'hutongstore','briankarran','brian.maureen@zen.co.uk','Brian Karran','78 Bedford Avenue<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7DW','01706846429','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 21:15:12',0,NULL,3,1,17,0,NULL,'briankarran'),(12457,813047930015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','briankarran','brian.maureen@zen.co.uk','Brian Karran','78 Bedford Avenue<br>Shaw','Oldham','Lancashire','UNITED KINGDOM','OL2 7DW','01706846429','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-03 21:19:26',0,NULL,3,1,3,1,'RA117777865CN ','briankarran\r45w 5500k 灯泡 220v     2\r灯架 38cm     1\r桌面灯灯头    1\r1.495'),(12458,813052583015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','fuharosok','hunyadiz@gmail.com','Zsolt Hunyadi','27 Szekeres u.','Szeged','Csongrád','HUNGARY','6725','+36703893807','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 21:27:36',0,NULL,3,1,2,1,NULL,'fuharosok'),(12459,693740982001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','vb_design','vdm012@bezeqint.net','Vadim Berestetsky','18 Natan St.','Ramat Gan','[select country/region]','ISRAEL','52450','0526212466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 22:34:23',0,NULL,3,1,11,1,NULL,'vb_design'),(12460,796334238016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','luttonnen','luttonnen@inbox.lv','Galina Lutonina','Hapsalas, 1/2 - 12','Riga','Latvia','LATVIA','LV1005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-03 22:56:35',0,NULL,3,1,2,1,NULL,'luttonnen\rlenspen    1\rcanon 三角包  D3     1'),(12461,735165427002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','klaasjan1986','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','+31610657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-03 23:59:49',0,NULL,3,1,2,1,NULL,'klaasjan1986'),(12462,735171031002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',148.6,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 00:25:11',0,NULL,3,1,3,1,'RA117777882CN ','tawfeekmohammed\rRA117717141CN\rRA117717124CN\rRA117717138CN\r'),(12463,748190156017,270753485077,'Remote Shutter Release Cord for Nikon D90 D7000 MC-DC2 ',1,'AA3209',5.69,'photographyacc','sjgaul','sjgaul@netspace.net.au','Stuart & Judy Gaul','16 March St','Newborough','Victoria','AUSTRALIA','3825','0351261603','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-04 00:40:41',0,NULL,3,1,2,1,NULL,'sjgaul'),(12464,735178353002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mpsonoma','mpsonoma@aei.ca','mario paillé','805 picotte','louiseville','QC','CANADA','J5V1B2','(819) 228-1129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 00:56:56',0,NULL,3,1,2,1,NULL,'mpsonoma'),(12465,735175820002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','forwardin','support@forwardin.com','Ovi Setiyadi','Jl. Kertanegara 1','Jember','Jawa Timur','INDONESIA','68131','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 00:57:01',0,NULL,3,1,2,1,NULL,'forwardin\r新地址:\r原地址加上这个电话\r(+6281336744344) '),(12466,748074720017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',35,'photographyacc','grwsimpson','gregsimpson@westnet.com.au','Greg Simpson','4 Lamarck Place Heathridge','Perth','Western Australia','AUSTRALIA','6027','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 01:13:26',0,NULL,3,0,3,1,'RA117717022CN ','grwsimpson\r摄影背心 黑色厚 无字 3XL     1(已入库)'),(12467,693780501001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','jcopeland64','jeffcopeland46@yahoo.com','jeff copeland','4321 Ball Camp Pike','knoxville','TN','UNITED STATES','37921-3313','(865) 455-5896','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-04 01:20:46',0,NULL,3,1,1,1,NULL,'jcopeland64'),(12468,693798543018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','chuck6345','chuckneely@juno.com','Chuck Neely','309 W Mission Dr','Chandler','AZ','UNITED STATES','85225-7186','(480) 892-5544','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-04 01:31:59',0,NULL,3,1,1,1,NULL,'chuck6345'),(12469,748203833017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','jemkuan','j_kuan91@hotmail.com','Zhong Yang Kuan','1104/58  Jeffcott  St','West Melbourne','Victoria','AUSTRALIA','3003','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 01:42:05',0,NULL,3,1,2,1,NULL,'jemkuan'),(12470,748228158017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','alammohan','alammohan@gmail.com','Alam Singh','507/339<br>Swanston Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 03:19:56',0,NULL,3,1,2,1,NULL,'alammohan'),(12471,735227355002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','gaunheda','phuongkimloan@hotmail.com','PHUONG LAM','25 VALLEYCREEK DR','BRAMPTON','ON','CANADA','L6P2E3','(647) 996-0543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 04:56:32',0,NULL,3,1,2,1,NULL,'gaunheda'),(12472,748262708017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',52,'photographyacc','7nicholson','darrell@jsj.com.au','Darrell Jones','28-30 Batman Ave','Hurstbridge','Victoria','AUSTRALIA','3099','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 06:36:50',0,NULL,3,1,3,1,'RA117717075CN\r ','7nicholson'),(12473,693417331018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','wikdman_01','juz_miller@hotmail.com','Justin Miller','PO BOX 9024<br>Norwood','Launceston','Tasmania','AUSTRALIA','7250','0449866040','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 07:40:51',0,NULL,3,0,2,1,NULL,'wikdman_01\r白色'),(12474,735255221002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','odinempire','odin81@chello.hu','Peter Nagy','Irinyi Janos ut 12','Salgotarjan','','HUNGARY','3100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 07:43:49',0,NULL,3,1,3,1,'RA117735692CN\r ','odinempire'),(12475,693871769018,280666888538,'New Green.L 55mm  Gradual Grey ND4 Filter 2-Stop 55 mm',1,'AA3316',6.2,'photographyacc','bravecrow77','bravecrow@azet.sk','Tomas Losonsky','Salezianska 6730/48','Trnava','','SLOVAK REPUBLIC','91701','00421949855077','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-04 08:10:54',0,NULL,3,1,2,1,NULL,'bravecrow77'),(12476,693423276001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','thorvaldsdottir','o.thorvaldsdottir@hotmail.com','Ólöf Helga Þorvaldsd. Linnet','Reykás 43','Reykjavík','','ICELAND','110','(354) 770-3009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 08:33:04',0,NULL,3,1,17,0,NULL,'thorvaldsdottir'),(12477,693882790018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 09:05:21',0,NULL,3,0,3,1,'RA117717067CN\r ','tan6111\r2.1x1.6m   背景布   2(黑+绿)'),(12478,693014664001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','qwertynhours','informacion@dohana.com','francisco garcia laguna','pedro munoz seca, 3','alcala de henares','Madrid','SPAIN','28805','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-04 10:27:36',0,NULL,3,1,17,0,NULL,'qwertynhours'),(12479,693890045018,280666783637,'Photo Video Light Stand Studio Photo Stand 6ft 2m x 2',1,'AKT031',49,'photographyacc','sunkissedgirls','hayley@thesunkissedgirls.com.au','Hayley Skinner','10 Moana Court<br>Mountain Creek','Sunshine Coast','Queensland','AUSTRALIA','4557','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 10:36:49',0,NULL,3,1,4,1,'YW865908482CN','sunkissedgirls'),(12480,748327110017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',100,'photographyacc','meetjoeblack_123','usma2006@free.fr','abdenour guenatri','18 impasse alfred nobel','BEZIERS','Languedoc-Roussillon','FRANCE','34500','0637018002','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-04 11:21:07',0,NULL,3,1,4,1,'YW865908434CN ','meetjoeblack_123\r3.855\r欧标\rlighting kit  $28\r'),(12481,735321369002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','mac.one','phil.marchessault@videotron.ca','Philippe Marchessault','308 S Main St','Richford','VT','UNITED STATES','05476-9622','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 12:43:33',0,NULL,3,1,3,1,'RA117717226CN\r ','mac.one'),(12482,813307176015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','darkowl08','ibravo@euskaltel.net','Imanol Bravo Durán','Isabel II, 14 - 8º A','San Sebastián','País Vasco','SPAIN','20011','606309099','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 12:48:13',0,NULL,3,1,2,1,NULL,'darkowl08'),(12483,693942300018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','kuffbot','kclearihan@zupps.com.au','Keith clearihan','12 Duror street','pacific pines','Queensland','AUSTRALIA','4211','0755143800','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 12:59:33',0,NULL,3,1,3,1,'RA117717257CN\r ','kuffbot'),(12484,693927264001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','lagaffe2008','fabiomcfonseca@yahoo.com.br','Fabio Fonseca','Rua Sylvio da Rocha Pollis<br>201 bloco04 apt.908','Rio de Janeiro','RJ - Barra da Tijuca','BRAZIL','22793-395','55-21-91915953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 13:21:34',0,NULL,3,1,3,1,'RA117717230CN\r ','lagaffe2008'),(12485,693952979018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','motorvation_feb_07','motorvation_d_a@hotmail.com','Richard Hall','28<br>Lucretia Street','Eaton','Western Australia','AUSTRALIA','6232','0897252620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-04 13:37:36',0,NULL,3,0,3,1,'RA117717169CN\r ','motorvation_feb_07\r摄影背心 nikon 原厂   XL    1(已入库)'),(12486,693883288018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','kimlester59','alexjplester@me.com','Kim Lester','176B Reynolds Road','Mount Pleasant','Western Australia','AUSTRALIA','6153','0893644090','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-04 14:32:26',0,NULL,3,1,4,1,'YW865908471CN ','kimlester59'),(12487,693952389001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','tokio69','tom@tokiogroup.com','Tom Knockaert','Engelenadalelaan 116','Brugge - Assebroek','','BELGIUM','B-8310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 14:53:53',0,NULL,3,1,2,1,NULL,'tokio69'),(12488,735359536002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','malajac','misamaric@gmail.com','Milivoje Misa Maric','21 Sorrell Hall<br>Ticknock Hill','Sandyford','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 14:58:02',0,NULL,3,1,3,1,'RA117717190CN\r ','malajac'),(12489,728743990002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','centrum222','penzionzita@gmail.com','Lubomir Pesko','Trnavska 33','Modra','','SLOVAK REPUBLIC','900 02','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 15:13:41',0,NULL,5,1,3,1,'RA117717209CN\r','centrum222\r已发货  改不了状态'),(12490,813387085015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','kazusolutions','sharonbk6@gmail.com','Sharon Ben Kessous','18 Hazav St.<br>p.o.b 321','Dimona','','ISRAEL','86000','0522969814','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 16:11:27',0,NULL,3,1,3,1,'RA117717172CN\r ','kazusolutions'),(12491,735386728002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','zeljko385','zeljkoo@gmail.com','Zeljko Drakulic','Dubrovacka 1','Rijeka','','CROATIA','51000','+385 95 8391246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 16:18:13',0,NULL,3,1,2,1,NULL,'zeljko385'),(12492,735384450002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','emiljano82','miliadhami@gmail.com','EMILJANO ADHAMI','RR. BAJRAM CURRI, PALL 440, SHK7, AP 70','TIRANA','TIRANA','ALBANIA','1001','+355683840630','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-04 16:35:10',0,NULL,3,1,3,1,'RA117717186CN\r ','emiljano82'),(12493,735394457002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vrovro','lo@srk.fer.hr','Lovro Seder','Krajiska 8','Zagreb','ZG','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 16:44:01',0,NULL,3,1,17,0,NULL,'vrovro'),(12494,735395827002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','vrovro','lo@srk.fer.hr','Lovro Seder','Krajiska 8','Zagreb','ZG','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 16:44:00',0,NULL,3,1,2,1,NULL,'vrovro\rlenspen    1\r气吹 + 布    1'),(12495,735400474002,120448751908,'Remote Shutter Release Cord for Nikon D70s D80 = MC-DC1',1,'AA3208',4.18,'hermeshine','henry7276','ywu@nrcan.gc.ca','Yinghai Wu','352 Laughlin Circle','Kanata','ON','CANADA','K2T0E3','(613) 943-7773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 16:55:51',0,NULL,3,1,2,1,NULL,'henry7276'),(12496,545196399003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','daarza','darnalz@yahoo.es','David Arnal Zaragoza','Passeig del Penyal d\'Ifach, nº 8 Pta. 16<br>Urbanización Casas Verdes Fase IV','Paterna','Comunidad Valenciana','SPAIN','46980','610024851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 17:56:39',0,NULL,3,1,4,1,'YW865908460CN ','daarza\r2.207\rtripod  $25'),(12497,735444210002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','chevy_fool','mooremt@gmail.com','Michael Moore','149 Rebecca Pines Dr','Madison','AL','UNITED STATES','35758-8297','(843) 879-8762','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-04 18:38:38',0,NULL,3,1,1,1,NULL,'chevy_fool\r----\r0718改个地址重发e邮宝(LK020854079CN)'),(12498,735465457002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','aminah.golamy','aminahg@intnet.mu','Bibi Aminah Golamy','26 Perimbe Street','Port Louis','','MAURITIUS','230','+2302531403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 19:35:35',0,NULL,3,1,2,1,NULL,'aminah.golamy'),(12499,813517963015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','asiaphoenix01','fudzi.eu@seznam.cz','Jan Peser','Manesova 638','Steti','','CZECH REPUBLIC','41108','420607901065','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-04 20:01:23',0,NULL,3,1,2,1,NULL,'asiaphoenix01'),(12500,735492722002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','psychosiss','erdem.shn@hotmail.com','erdem şahin','Milli park cad. Güzelcamevler sit. no:104<br>Guzelcamli-Kusadasi','Aydin','','TURKEY','09400','05446764826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 20:26:12',0,NULL,3,1,3,1,'RA117717115CN\r ','psychosiss'),(12501,694093093001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','michow2','michow@uniserve.com','Michael Chow','306-450 Bromley Street','Coquitlam','BC','CANADA','V3K6S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 20:36:33',0,NULL,3,1,17,0,NULL,'michow2'),(12502,735498934002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','michow2','michow@uniserve.com','Michael Chow','306-450 Bromley Street','Coquitlam','BC','CANADA','V3K6S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 20:36:33',0,NULL,3,1,2,1,NULL,'michow2\r绿叶 渐变镜 77mm     1\r方镜广角托架（ 一槽）    1'),(12503,694129253018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','gamer6655','krishartman@cox.net','Kris Hartman','1528 Turtle Lake Rd.','Moore','OK','UNITED STATES','73160','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-04 20:43:21',0,NULL,3,1,1,1,'LK013433226CN','gamer6655\r110v \r----\r摔坏了，0712补发一个110v 45w灯泡,'),(12504,735518632002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','xose_anxo','rosaanllo@hotmail.com','ROSA ANLLO','Estrada da Gandara<br>nº 29-31, 3ºH','Naron','Galicia','SPAIN','15570','629882294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-04 21:29:18',0,NULL,3,1,2,1,NULL,'xose_anxo'),(12505,735551378002,120578649319,'10 NEW UV filters Green.L 52mm - 77mm ',1,'AKT032',40,'hermeshine','andresc813','andrescab2003@yahoo.com','andres cabrera','6214 greenwich dr','tampa','FL','UNITED STATES','33647-1142','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-04 23:40:21',0,NULL,3,0,1,1,NULL,'andresc813\r绿叶 UV  58mm     10(已入库)\r-----\r0718改个地址重发e邮宝(LK016514683CN)'),(12506,735570370002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','909*2001','gospel_standards@yahoo.com','SONJA VALERIE','1365 HILLCREST DR','MORRO BAY','CA','UNITED STATES','93442-1831','(909) 213-2800','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-05 01:16:22',0,NULL,3,1,1,1,' ','909*2001\r----\r0718改个地址重发e邮宝(LK018181229CN)'),(12507,735586111002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','arezix','haziq.ruzaini.mazlan@vanderbilt.edu','Haziq Ruzaini Mazlan','169, Jalan BK 5/2,<br>Bandar Kinrara','Puchong','','MALAYSIA','47100','(019) 697-5811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 02:43:35',0,NULL,3,1,2,1,NULL,'arezix'),(12508,748640352017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','neighorn','neighorn@gmail.com','Patrick Neighorn','40A Orchard Road #07-01<br>The MacDonald House','default','','SINGAPORE','238838','(656) 825-8065','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 02:46:16',0,NULL,3,1,11,1,NULL,'neighorn'),(12509,693876756018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','stacz','sm.denning@hotmail.com','Stacey Denning','unit 4/9 Friar Road<br>Armadale','Perth','Western Australia','AUSTRALIA','6112','0400140282','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 02:52:49',0,NULL,3,0,3,1,'RA117717433CN ','stacz\r1.6x2.1m   背景布   3(黑白红)\r955'),(12510,694229403018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','bkcann','ebay@cann.id.au','Katie Cann','10 Palmer Crt','Clermont','Queensland','AUSTRALIA','4721','0401487856','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 03:57:48',0,NULL,3,1,2,1,' ','bkcann'),(12511,694191634001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',2,'AA3308',9.9,'hermeshine','almaz2010','xxxxxx1984@mail.ru','Almaz Makhmutov','ul. Bayazita Bikbaya 44, kv.279','Ufa','Respublika Bashkortostan','RUSSIAN FEDERATION','450073','+79174815808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 04:07:37',0,NULL,3,1,2,1,' ','almaz2010'),(12512,694195939001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','uipl2','uiplakh@gmail.com','Yuriy Plakhotnik','Ob\'edineniya, 98-36','Novosibirsk','','RUSSIAN FEDERATION','630027','73832729982','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 04:38:13',0,NULL,3,1,3,1,'RA117717447CN ','uipl2'),(12513,748663740017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','daffwind','medi77@inbox.ru','Davids Vetrovs','313 WHITEHILL PL NE','Calgary','AB','CANADA','T1Y 3G6','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 05:07:54',0,NULL,3,1,2,1,NULL,'daffwind'),(12514,694197354018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','janjan03_2008','jjaaa2003@yahoo.com','Antonio Aberin','Unit 34 / 6 -12 The Avenue','Mount Druitt','New South Wales','AUSTRALIA','2770','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 06:19:58',0,NULL,3,1,2,1,NULL,'janjan03_2008'),(12515,8881309846848202,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',14.8,'hermeshine','aliexpress','+55 41 85024177','Wagner Andrade','R. Dr. Muricy 839 Ap 154 Centro<br>Parana, Brazil','Curitiba','Parana','Brazil','80020040','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA117717455CN ','电话：\r+55 41 85024177'),(12516,693390747001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',25.7,'hermeshine','sambarumba.994','leyla.sadaltd@gmail.com','Leyla Aliyeva','115 Hasan Aliyev str., apt.17','Baku','Baki','AZERBAIJAN','AZ1110','5641101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 06:46:35',0,NULL,3,0,2,1,NULL,'sambarumba.994\r(已入库)\r绿叶  77mm  ND4    1\r绿叶  77mm   UV      1\r绿叶  77mm   渐灰    1\r优永佳快门线 A C3   1\r'),(12517,694215348001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','sigossman','sigossman@earthlink.net','Sanford Gossman','5 Golden Hinde Blvd<br>Apt 208','San Rafael','CA','UNITED STATES','94903','(415) 492-1030','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 06:46:40',0,NULL,3,1,3,1,'RA117717362CN ','sigossman'),(12518,694266095018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','xanzaq','tinytootsies@hotmail.com.au','Anastazia Gunnis','2/4 Manley Street','Caboolture','Queensland','AUSTRALIA','4510','0751590034','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 07:41:10',0,NULL,3,0,3,1,'RA117717495CN ','xanzaq\r1.6x2.1m   背景布   2 (白/黑)'),(12519,813717254015,250693977320,'NEW 72mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT047',19.9,'hutongstore','crvbranco','mario.carvalho@optimus.pt','Mário Albino Branco Carvalho','Edificio Sonaecom - Piso 3<br>Av. D.Joao II - lote 1.06.2.4','Lisboa','Lisboa','PORTUGAL','1990-095','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 08:08:59',0,NULL,3,1,3,1,'RA117717420CN ','crvbranco'),(12520,694229504001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','villemo1','villemo1@online.no','Linn Landmark','Vaagslia 24','Aagotnes','Ågotnes','NORWAY','5363','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 08:09:50',0,NULL,3,1,3,1,'RA117717416CN ','villemo1'),(12521,694295596018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','kennyandvo','kunii123@hotmail.com','kenny srun','3/36 South parade','Campsie','New South Wales','AUSTRALIA','2194','0404013164','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-05 10:03:42',0,NULL,3,1,4,1,'YW866127990CN ','kennyandvo\rbacksupport  $18\r'),(12522,694297368018,280680264184,'New Camera Bag Cover for Canon EOS 7D 18-135 / 18-200 ',1,'AD1115',15.99,'photographyacc','glen7077','gdepares@unwired.com.au','glen depares','45, farmingdale dr','blacktown','New South Wales','AUSTRALIA','2148','0418284289','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 10:12:46',0,NULL,3,1,2,1,NULL,'glen7077'),(12523,735661262002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','lasma_m','lasma.muceniece@gmail.com','Lasma Muceniece','Silmalas 19','Rigas raj.','Garkalnes nov','LATVIA','LV-1024','+37129195875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 10:14:00',0,NULL,3,1,3,1,'RA117717535CN\r ','lasma_m'),(12524,694295100018,280666916076,'New Fancier Complete Tripod 531BT with Ball head 531BH',1,'AE1102',295,'photographyacc','cornebb','cornelategan@gmail.com','Corne Lategan','54b Ridgevista Court','Reedy Creek','Queensland','AUSTRALIA','4227','0412152319','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-05 10:16:20',0,NULL,3,1,4,1,'YW866127975CN ','cornebb\r(已入库)\r三脚架 伟峰 EI-717  180    1\r三脚架 伟峰 WF-531B        1\rTripod  $35'),(12525,813754589015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',26,'hutongstore','marcosromay','marcoscas@gmail.com','José Ignacio Bretal Romay','Eirado da leña, plaza da leña nº3','Pontevedra','Galicia','SPAIN','36002','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-05 10:44:08',0,NULL,3,1,17,0,NULL,'marcosromay'),(12526,813754579015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','marcosromay','marcoscas@gmail.com','José Ignacio Bretal Romay','Eirado da leña, plaza da leña nº3','Pontevedra','Galicia','SPAIN','36002','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 10:54:19',0,NULL,3,1,4,1,'YW866127953CN ','marcosromay\r圆形柔光棚 60cm    1\r2B柔    1\r2.201'),(12527,735681590002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',26.8,'hermeshine','1411blue','ch_78654@yahoo.com','Clorinda J. Harbert','1411 Bluebonnet Dr','Marble Falls','TX','UNITED STATES','78654','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 11:41:58',0,NULL,3,1,1,1,'LK003664619CN','1411blue\r摄影背心 冬夏 XL    1'),(12528,694278533001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','hasszan80','maczolaci@gmail.com','Maczó László','Dandár utca<br>25. II. em, 211 a.','Budapest','Hungary','HUNGARY','1095','(0036)209848244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 12:06:46',0,NULL,3,1,2,1,NULL,'hasszan80'),(12529,694279183001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','s-lubow','sandrei@mail.ru','Liubov Sotnikova','Uralskaya 2-24','Ekaterinburg','Sverdlovskaya obl','RUSSIAN FEDERATION','620041','+7 902-26-12-268','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 12:08:39',0,NULL,3,1,3,1,'RA117717521CN\r ','s-lubow\r绿叶近摄镜 +8  58mm  换成+4的.'),(12530,813784839015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','kincaspt','kincas@mac.com','Joaquim Narciso','Rua Principal Nº5, 4ºDto<br>Casal Andrino','Leiria','Leiria','PORTUGAL','2410-014','00351917633996 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 12:11:14',0,NULL,3,1,2,1,NULL,'kincaspt'),(12531,813785460015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','tdulas76','tdulas@poczta.onet.pl','Tomasz Dulas','Sauter Automation Limited<br>Inova House','Crockford Lane, Chineham','Basingstoke, Hampshire','UNITED KINGDOM','RG24 8WH','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-05 12:12:17',0,NULL,3,1,4,1,'YW866127931CN ','tdulas76\r英标\rlighting kit   $25'),(12532,748760186017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','zannistefano','zanni94@gmail.com','Stefano Zanni','Via elio, 9','Montebelluna','TV','ITALY','31044','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 12:42:46',0,NULL,3,1,2,1,NULL,'zannistefano'),(12533,735697418002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','sonic-321','henning.ogx@gmail.com','Henning Müller','Georg-Schroeder-Str. 3c','Berlin','','GERMANY','13591','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 12:46:45',0,NULL,3,1,2,1,NULL,'sonic-321'),(12534,813798575015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','scaramangabongo','lumpy.gravy@hotmail.co.uk','Denis Coyle','10 Cherry Tree Avenue','Runcorn','Cheshire','UNITED KINGDOM','WA7 5JJ','01515242382','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 12:52:33',0,NULL,3,1,2,1,NULL,'scaramangabongo'),(12535,735700912002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','margaret465546','margaretcmay@yahoo.com','Margaret May','4008 Lazy K Dr','Castle Rock','CO','UNITED STATES','80104-7829','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 13:00:16',0,NULL,3,1,1,1,'LK007765241CN','margaret465546'),(12536,748768943017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',1,'AB2401',10.9,'photographyacc','ladislav_s','network.net@seznam.cz','Ladislav Stanke','Okrajova 25','Havirov-Podlesi','','CZECH REPUBLIC','73601','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 13:15:25',0,NULL,3,1,2,1,' ','ladislav_s'),(12537,735719484002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 14:11:58',0,NULL,3,1,17,0,NULL,'gunners456'),(12538,694309310001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 14:11:59',0,NULL,3,1,17,0,NULL,'gunners456'),(12539,694309363001,110569963962,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10 ft)',1,'AO0018',45,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 14:12:00',0,NULL,3,1,17,0,NULL,'gunners456'),(12540,735720654002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','edward72','edward88@tweedly.com','Edward A Tweedly','11 Rannoch Gardens<br>Linslade','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','LU7 2XQ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 14:15:28',0,NULL,3,1,2,1,NULL,'edward72'),(12541,797046465016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','lourynas','laurynaspffc@yahoo.com','Laurynas Aravicius','c.o/Niklas Reyman<br>Bymosevej 174','Hastle','Aarhus','DENMARK','8210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 14:19:24',0,NULL,3,1,17,0,NULL,'lourynas'),(12542,735720149002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',27.9,'hermeshine','ramesh.thokala','sriramramesh@yahoo.com','Ramesh Thokala','6045 Perimeter Lakes Dr','Dublin','OH','UNITED STATES','43017-5209','(469) 586-8371','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 14:20:32',0,NULL,3,1,1,1,NULL,'ramesh.thokala'),(12543,813833139015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','lourynas','laurynaspffc@yahoo.com','Laurynas Aravicius','c.o/Niklas Reyman<br>Bymosevej 174','Hastle','Aarhus','DENMARK','8210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 14:29:52',0,NULL,3,1,4,1,'YW866127964CN ','lourynas\r反光板支架   1\r灯架  2m    1'),(12544,735719336002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 14:11:59',0,NULL,3,1,4,1,'YW866128012CN ','gunners456\r反光板 60cm 2合1    1\r背景架2m x 3m + 3个夹子     1\r背景布 3x3 白色    1\r2B柔    1(B座挑个伞孔紧的)'),(12545,735733407002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','rivas_55','rivas_55@yahoo.com','Jose Rivas','Quintas Del Sur ST#10 L#4','PONCE','PR','PUERTO RICO','00728','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-05 15:02:02',0,NULL,3,1,1,1,NULL,'rivas_55'),(12546,693781429001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',158.89,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 15:40:21',0,NULL,3,1,8,1,'CP227125407CN ','saud-p\r背景架2mx2m  + 3个夹子     1\r背景架2mx3m  + 3个夹子     1\r背景布 1.6x2.1m     2(白+黑)\r申报 Backdrop support  $158.89'),(12547,694417927018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','twilightlink89','marco.rotini89@gmail.com','Marco Rotini','Via Delle Rose 14','Bologna','BO','ITALY','40136','051584114','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 17:05:10',0,NULL,3,1,2,1,NULL,'twilightlink89'),(12548,813903301015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','mouraonunes','mourao.nunes@gmail.com','Ricardo Mourão','Rua Drº João de Barros nº17 9º dtº','Lisboa','Portugal','PORTUGAL','1500-230','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-05 17:21:51',0,NULL,3,1,4,1,'YW866127942CN ','mouraonunes'),(12549,735782164002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','valeri3331','rex_pitbul@abv.bg','Valeri Radkov','hadji dimitar/53a/A/5/15','Sofia','','BULGARIA','1510','+359 888 608 196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 17:29:54',0,NULL,3,1,2,1,NULL,'valeri3331'),(12550,735783436002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','pnjacket','pnjacket@msn.com','hwoichul jung','5950 Glen Erin Dr.<br>Unit 45','Mississauga','ON','CANADA','L5M6J1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 17:33:24',0,NULL,3,1,2,1,NULL,'pnjacket'),(12551,813947724015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','b0002833','sexysunny009@gmail.com','Sarabjeet Saini','Rear of 215 house<br>Duke Street, Sheffield','Sheffield','South Yorkshire','UNITED KINGDOM','S2 5QP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 18:41:49',0,NULL,3,1,2,1,NULL,'b0002833'),(12552,694421641001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','kalsten','kalsten_planet@hotmail.com','Diego Giao Garcia','Plaza Sofia, portal 2 3ºB','Santiago de Compostela','Galicia','SPAIN','15707','696503579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 19:30:00',0,NULL,3,1,2,1,NULL,'kalsten'),(12553,694449247001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',3.4,'hermeshine','jtap2030','jttapley00@yahoo.com','joe tapley','7712 Grier Rd','wetumpka','AL','UNITED STATES','36092-6414','(334) 514-9430','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-05 20:33:37',0,NULL,3,1,1,1,NULL,'jtap2030'),(12554,694513074018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',7.28,'photographyacc','joelscrappy1226','jonaterdomingo@yahoo.com','joel domingo','1011 dundas st. east apt. 408 - A','mississauga','ON','CANADA','L4Y 4A5','(647) 835-9121','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 20:34:43',0,NULL,3,1,2,1,NULL,'joelscrappy1226'),(12555,814017058015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','pescevelocedelbaltico','omer.fisher@gmail.com','Omer Fisher','Tagore\'a 3 apt 22','Warsaw','mazowieckie','POLAND','02-647','663910028','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-05 20:42:21',0,NULL,3,1,2,1,NULL,'pescevelocedelbaltico'),(12556,735871696002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','jarrep','jaroslav.repta@gmail.com','Jaroslav Repta','Mierova 12','Bratislava','','SLOVAK REPUBLIC','82105','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 20:57:56',0,NULL,3,1,3,1,'RA117717518CN\r ','jarrep'),(12557,735876896002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','bogh_dan72','bogh_dan@yahoo.com','Bogdan Ciobanu','str. Calea Bucuresti nr. 250 bl.2 ap.5','Brasov','Brasov','ROMANIA','500301','0040744791823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 21:26:35',0,NULL,3,1,2,1,' ','bogh_dan72'),(12558,733611400002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','oparra2669305','oparra2669@yahoo.com','Olmer Parra','10874 sw 2dn st apt 110','miami','FL','UNITED STATES','33174','(305) 781-2441','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 22:03:01',0,NULL,3,1,1,1,NULL,'oparra2669305'),(12559,694485737001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','sanzco','sanzco.chiledigital@gmail.com','Patricio Sánchez Corral','Los Algarrobos 4335<br>Block H, Depto. 601 \"Altos del Dragón\"','Iquique','','CHILE','1100000','66580292','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-05 22:18:04',0,NULL,3,1,3,1,'RA117717552CN\r ','sanzco\rM'),(12560,797268727016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','garethb1708','gareth.beckett@ntlworld.com','Gareth Beckett','13, Stockton Close','Newport','Newport','UNITED KINGDOM','NP197HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 22:25:13',0,NULL,3,1,17,0,' ','garethb1708'),(12561,814058490015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','garethb1708','gareth.beckett@ntlworld.com','Gareth Beckett','13, Stockton Close','Newport','Newport','UNITED KINGDOM','NP197HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 22:25:14',0,NULL,3,1,17,0,NULL,'garethb1708'),(12562,814059201015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','garethb1708','gareth.beckett@ntlworld.com','Gareth Beckett','13, Stockton Close','Newport','Newport','UNITED KINGDOM','NP197HH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-05 22:25:15',0,NULL,3,1,2,1,' ','garethb1708\r机身盖/镜头后盖  Canon   1\r普通有线快门线C1   1\r热靴保护盖  普通    1'),(12563,735901485002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','edwinvanaalten','edwinvanaalten@gmail.com','Edwin van Aalten','Leenderweg 248','EINDHOVEN','','NETHERLANDS','5644AD','31630858190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 22:27:59',0,NULL,3,1,2,1,NULL,'edwinvanaalten'),(12564,748987797017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','fattai','giao09@yahoo.com','Giao Nguyen','2465 Ridgeglen Way','San Jose','CA','UNITED STATES','95133','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-05 22:42:44',0,NULL,3,1,1,1,' ','fattai'),(12565,735908367002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','hargen10','hargenart@yahoo.com','Harutyun Gentshoyan','1053 Western Ave<br>Apt 5','Glendale','CA','UNITED STATES','91201-1740','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-05 22:56:57',0,NULL,3,1,4,1,'YW866128023CN ','hargen10\r2m 灯架  红盒的   1\r红头灯  欧标转美标   1\r800w  110v     1 \rlighting kit    $25\r'),(12566,694173083001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','ctm13579','chuedmond@gmail.com','Edmond Chu','4725 Barker Crescent','Burnaby','BC','CANADA','V5G3G2','(604) 765-0035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 00:24:01',0,NULL,3,1,2,1,NULL,'ctm13579'),(12567,735934575002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gilberto9483','gilbertyuca@yahoo.com','gilberto rodriguez rivera','18 Calle Colibri','RINCON','PR','UNITED STATES','00677-2638','(787) 638-4438','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 00:54:35',0,NULL,3,1,4,1,'YW866128001CN ','gilberto9483'),(12568,694596803018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','s1972005','clintzirk@gmail.com','Clinton Zirk','8 Pecan Bay','Oakbank','MB','CANADA','R0E1J1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-06 01:28:58',0,NULL,3,1,2,1,NULL,'s1972005'),(12569,735951307002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','ricardo85x','ricardo85xhd@gmail.com','Ricardo Teixeira','Jose de Oliveira<br>36','Sao Paulo','SP','BRAZIL','05203205','55 11 9386 1536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 02:08:41',0,NULL,3,1,2,1,NULL,'ricardo85x'),(12570,8881309921744630,111,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','jennysjellybelly','weekdayproductions@yahoo.com','Jenny Green','184 Cobden View Road<br>Crookes','Sheffield S Yorks','','UNITED KINGDOM','S10 1HT','',NULL,NULL,NULL,NULL,0,NULL,3,1,2,1,NULL,NULL);
INSERT INTO `hmsh_ebay_transaction` VALUES (12571,694618603018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','goglik1983','goglik83@gmail.com','George Mdivanian','4/101A Bernard st','Cheltenham','Victoria','AUSTRALIA','3192','0412481891','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-06 03:10:48',0,NULL,3,1,4,1,'YW866127986CN ','goglik1983\r背景架 2mx3m 河北 + 1.6x2.1 白+夹子  1\rbackground support  $25\r'),(12572,735972620002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','714racer','hotrodes@earthlink.net','Eric Shields','7112 Starlight Cir','Huntington Beach','CA','UNITED STATES','92647-3543','(714) 841-5078','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 04:04:27',0,NULL,3,1,1,1,NULL,'714racer\r热靴保护盖  普通    1\r方镜广角托架（ 一槽）    1'),(12573,694559433001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','714racer','hotrodes@earthlink.net','Eric Shields','7112 Starlight Cir','Huntington Beach','CA','UNITED STATES','92647-3543','(714) 841-5078','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 04:08:14',0,NULL,3,1,17,0,NULL,'714racer'),(12574,694633424018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','coleman675','coleman1971@optusnet.com.au','David and Debra Coleman','15 Lapwing crt','Langwarrin','Victoria','AUSTRALIA','3910','0409142065','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 04:36:14',0,NULL,3,1,3,1,'RA117717597CN ','coleman675'),(12575,688155666001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','astroboy_aus','tangyang76@gmail.com','Yang Tang','11640 Chippenham Way','San Diego','CA','UNITED STATES','92128-4280','(858) 207-8896','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 04:38:20',0,NULL,3,1,1,1,NULL,'astroboy_aus'),(12576,749068275017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','hd_kid88','james.comino@gmail.com','Billy Comino','Shop 3/90 Aumuller St<br>Portsmith','Cairns','Queensland','AUSTRALIA','4870','0740351007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 04:54:03',0,NULL,3,1,2,1,NULL,'hd_kid88'),(12577,694574923001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','jennynie0','jennynieto15@msn.com','Genevieve Nieto','1726 Lawrence Pl','Pomona','CA','UNITED STATES','91766-5557','(909) 865-8674','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 05:54:13',0,NULL,3,1,1,1,NULL,'jennynie0'),(12578,735992109002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','emexso','ees65@hotmail.com','Emilio Exposito Soto','CL Enrique de Anaga, 7 - Bajo B','Santa Cruz de Tenerife','Canarias','SPAIN','38008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 06:11:31',0,NULL,3,1,3,1,'RA117717606CN ','emexso'),(12579,736000867002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','ain-tova','davidstein48@gmail.com','David Stein','habashan 5','Ramat Gan','','ISRAEL','52266','972459792771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 07:03:54',0,NULL,3,1,2,1,NULL,'ain-tova'),(12580,694588067001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','arientangerine','ch@christopher-holden.com','Christopher Holden','1675 Clay St<br>Apt 7','San Francisco','CA','UNITED STATES','94109-3722','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 07:15:41',0,NULL,3,1,1,1,NULL,'arientangerine\r\r\r'),(12581,694659759018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','jasongorospe','jkyd707@yahoo.com','Jason Gorospe','435 McKenna ct','Benicia','CA','UNITED STATES','94510-3979','(707) 567-2470','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-06 07:19:23',0,NULL,3,1,1,1,NULL,'jasongorospe'),(12582,814197360015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','asenpetrov','petrov@applebg.com','Asen Petrov','Hristo Botev 16','Dimitrovgrad','Haskovo','BULGARIA','6400','359899890534','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 07:36:03',0,NULL,3,1,2,1,NULL,'asenpetrov'),(12583,694513817001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','beautiful_collectibles','cecilialotter76@yahoo.com.ar','Hernan Siludakis','Ascasubi 117','Monte Grande','Bs As','ARGENTINA','1842','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 08:14:19',0,NULL,3,1,2,1,NULL,'beautiful_collectibles'),(12584,749106431017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','ksmolka','kurt.smolka@optus.com.au','Kurt Smolka','1 Lyonpark Rd','Macquarie Park','New South Wales','AUSTRALIA','2113','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 08:15:39',0,NULL,3,0,3,1,'RA117717566CN ','ksmolka\r1.6x3m  背景布    1(白)'),(12585,694603168001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AD1105',40.99,'hermeshine','timi_ppt','timi.wong-yut@mail.pf','Timi Wong Yut','41 rue du bon pasteur<br>Papeete - Island of Tahiti','PAPEETE','French Polynesia','FRENCH POLYNESIA','98714','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-06 08:37:31',0,NULL,3,1,3,1,'RA117717570CN ','timi_ppt'),(12586,736018086002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','dwc985','dwc995@uow.edu.au','Daniel Coleman','3/21 blacket st','North Wollongong','New South Wales','AUSTRALIA','2500','0408263139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 08:46:22',0,NULL,3,1,2,1,'、 ','dwc985'),(12587,694613293001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','andrzej6491','a.cyunelis@neostrada.pl','Andrzej Cyunelis','Jana Dlugosza 27','Wroclaw','','POLAND','51-162','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-06 09:33:55',0,NULL,3,1,3,1,'RA117717685CN ','andrzej6491'),(12588,694689956018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','martinasmart','smart-laura-virus@libero.it','Martina Cognolato','via Alfieri 8','Ponte San Nicolò','PD','ITALY','35020','049717798','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-06 09:39:24',0,NULL,3,1,2,1,NULL,'martinasmart'),(12589,814234746015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','065croninm','martinmaryc@eircom.net','Martin Cronin','Ballyhannon<br>Quin','Ennis','Clare','IRELAND','default','0656825750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 09:59:45',0,NULL,3,1,17,0,NULL,'065croninm'),(12590,814235841015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','065croninm','martinmaryc@eircom.net','Martin Cronin','Ballyhannon<br>Quin','Ennis','Clare','IRELAND','default','0656825750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 10:03:44',0,NULL,3,1,2,1,NULL,'065croninm\r橡胶遮光罩 52mm    1\r橡胶遮光罩 58mm    1'),(12591,694697632018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',12.1,'photographyacc','karcot','kumararcot@optusnet.com.au','Kumaravel Arcot','164 Goucester Road','Hurstville','New South Wales','AUSTRALIA','2220','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 10:13:40',0,NULL,3,1,2,1,NULL,'karcot\r绿叶 CPL  58mm    1\r6片装滤镜袋             1'),(12592,736037309002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','bira_68','loureiroubiratan@hotmail.com','Ubiratan Loureiro','Rua Jaburu n-19','Serra','Espírito Santo','BRAZIL','29171437','0312732410759','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 10:15:11',0,NULL,3,1,2,1,NULL,'bira_68'),(12593,797463865016,260661735101,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',20.8,'hutongstore','marcosromay','marcoscas@gmail.com','Marcos Antonio Romay Perez','Bretal - Olveira 13','Ribeira','Galicia','SPAIN','15969','655967311','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 11:17:04',0,NULL,3,1,3,1,'RA117717773CN ','marcosromay\r＋8近摄镜换成 +4的(已入库)'),(12594,749152507017,270751511455,'YongNuo 3m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3325',28.99,'photographyacc','seato72','greg.seaton@gmail.com','Greg Seaton','c/o AMP<br>L2, 2-12 Macquarie Street','Parramatta','New South Wales','AUSTRALIA','2150','0431054813','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 11:31:40',0,NULL,3,1,3,1,'RA117717668CN ','seato72'),(12595,694641161001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-06 11:46:06',0,NULL,3,1,3,1,'RA117717739CN \rRA117717787CN','saud-p\r两个小包各申报 $35\rbackground support\r可以分\r'),(12596,741950501017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',30.79,'photographyacc','goochnhooch','goocheshooch@hotmail.com','gooch\'n hooch danoustie','64 vistula circut springfield, 4300, qld','spingfield','Queensland','AUSTRALIA','4300','','NoPaymentFailure','CheckoutComplete','AU_RegisteredParcelPost','2011-07-06 11:57:10',0,NULL,3,1,3,1,'RA117717699CN ','goochnhooch\r反光板 80cm 2合1     1\r1.6x3m 背景布       1(白)\r\r886'),(12597,814269995015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','kontykonty','dofonju@yahoo.co.uk','Doreen Fonju','Voxafrica Television<br>80 Silverthorne Road','London','London','UNITED KINGDOM','SW8 3HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 12:11:08',0,NULL,3,1,2,1,NULL,'kontykonty'),(12598,736064423002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','bledixhafa','bledix@gmail.com','Bledar Xhafaj','Rruga: \"Vllazen Huta\" Nd:7 , H:11 , Ap:19 , Kodi Postar: 1017<br>Tirane','Tirane','Albania','ALBANIA','1017','+355694007155','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-06 12:11:49',0,NULL,3,1,3,1,'RA117717671CN ','bledixhafa'),(12599,749165318017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','rodells','rodelio.sayao@gmail.com','Rodelio Sayao','Level 2<br>4 Dawn Fraser Avenue','Sydney Olympic Park','New South Wales','AUSTRALIA','2127','0420833132','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 12:20:50',0,NULL,3,1,2,1,NULL,'rodells'),(12600,736078537002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','connfamilyof4','darrinconn@gmail.com','Darrin Conn','1303 Olive St','dexter','MO','UNITED STATES','63841-2333','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-06 13:06:46',0,NULL,3,1,1,1,NULL,'connfamilyof4'),(12601,694744099018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','slockrey','slockrey@ozemail.com.au','Scott Lockrey','PO Box 823','GYMEA','New South Wales','AUSTRALIA','2227','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-06 13:13:42',0,NULL,3,1,2,1,NULL,'slockrey'),(12602,814298935015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','docsoft','nigeldoherty@talk21.com','Nigel Doherty','17 Altnagelvin Park','Londonderry','Londonderry','UNITED KINGDOM','BT47 2LU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 13:21:47',0,NULL,3,1,2,1,NULL,'docsoft'),(12603,689633358001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','san-dz-tz','san-dz-tz@hotmail.com','Bruce Hughes','1878 Leclair Apt.102','Waterloo','QC','CANADA','J0E2N0','(450) 539-0905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-05 10:14:02',0,NULL,3,1,2,1,NULL,'san-dz-tz'),(12604,736108929002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 14:54:55',0,NULL,3,1,3,1,'RA117717800CN ','mellogabriel'),(12605,736112917002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','sogocara','sogocara@alice.it','Cara Vasile Sebastian','VIA ESASSETA, 13B','ABBADIA SAN SALVATORE','Siena','ITALY','53021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 15:08:37',0,NULL,3,1,3,1,'RA117717711CN ','sogocara\rlight stand $15'),(12606,694702609001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ertekmali','ertekmali@yahoo.com','MEHMET ALI ERTEK','Mustafa Mazharbey Cad. no 85 Da.14 FENERYOLU ISTANBUL','ISTANBUL','TURKEY','TURKEY','34724','(532) 350 - 9426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 15:21:58',0,NULL,3,1,3,1,'RA117717610CN ','ertekmali'),(12607,736144864002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-06 16:47:04',0,NULL,3,1,3,1,'RA117717623CN ','arnorolf10'),(12608,694733733001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','samelalocatelli','samelaoliveira@hotmail.com','Sâmela Tavares de Oliveira Locatelli','Rua do Camacuan, 819<br>Uberaba','Curitiba','Paraná','BRAZIL','81550-360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 17:05:05',0,NULL,3,1,17,0,NULL,'samelalocatelli'),(12609,797598645016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','zsoltmarik13','marikzsolt@gmail.com','Zsolt Marik','Haán Lajos tér 19.4/12.','Békéscsaba','alapértelmezés','HUNGARY','5600','+36309594676','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 17:21:48',0,NULL,3,1,2,1,NULL,'zsoltmarik13'),(12610,736182301002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','flx19','felixprincipe@yahoo.es','Felix Principe Fernandez','C/ Cuenca Nº 13 2ºB','Leganes (Madrid)','Madrid','SPAIN','28914','646324845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 18:23:09',0,NULL,3,1,2,1,NULL,'flx19'),(12611,694856711018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','casildagarreton2010','casilda.garreton@gmail.com','Maria Casilda Garreton Velasco','Avenida Apoquindo 5701 local 18<br>Las condes','Santiago','Metropolitana','CHILE','7550000','56-02-2244932','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-06 18:32:00',0,NULL,3,1,2,1,NULL,'casildagarreton2010'),(12612,736204734002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','bigeinc','eric.myles@thomson.net','Eric Myles','1700 Eglinton Ave East Ste 106','Toronto','ON','CANADA','M4A 2X4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:17:36',0,NULL,3,1,3,1,'RA117717725CN ','bigeinc\r110v 美标'),(12613,736210261002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','israel.benari2009','israel.benari@gmail.com','ISRAEL BEN ARI','6 HADOLEV','JERUSALEM','ISRAEL','ISRAEL','93855','972-2-6762532','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:27:23',0,NULL,3,1,3,1,'RA117717708CN ','israel.benari2009'),(12614,736218764002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',4,'AB1202',27.96,'hermeshine','ec9md','danieljsan@yahoo.es','DANIEL  SANCHEZ RAMIREZ','C/ JOSE Mª PANIAGUA SANTOS, 4, Esc. Dcha, 2ºA<br>52.005-MELILLA','MELILLA','Andalucía Ceuta y Melilla','SPAIN','52005','639717581','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 19:47:05',0,NULL,3,1,3,1,'RA117717742CN ','ec9md'),(12615,736232250002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',48.99,'hermeshine','2010calintwf','calintwf@yahoo.com','calin capraru','Godeanu No. 5/49','Cluj-Napoca','Cluj','ROMANIA','400414','0040264406383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 20:18:35',0,NULL,3,1,3,1,'RA117717645CN ','2010calintwf'),(12616,736241190002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','aglentzakis','aglentzakis2000@yahoo.gr','Andreas Glentzakis','KIFISIAS 4','ATHENS','AMPELOKIPI','GREECE','11526','6944940327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 20:39:20',0,NULL,3,1,2,1,NULL,'aglentzakis'),(12617,814518815015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',2,'AC1201',4.36,'hutongstore','mafonso29','marcos@gestahead.com','Marcos Goncalves','R. Dr. Mário Soares<br>Lote 4, Edificio BES I - Tagus Park','Porto Salvo','','PORTUGAL','2780-920','+351914390640','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-06 21:01:33',0,NULL,3,1,2,1,NULL,'mafonso29'),(12618,694845930001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','wala35','wala_35@hotmail.com','Walaa Atwi','2635 Langlois Ave','Windsor','ON','CANADA','N8X4V7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:28:41',0,NULL,3,1,2,1,NULL,'wala35'),(12619,694846272001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','lorddreturn','josebagarciaruiz@gmail.com','maria elena ruiz','iparraguirre 61b 2h','Santurce','País Vasco','SPAIN','48980','669143758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:37:37',0,NULL,3,1,4,1,'YW865589816CN ','lorddreturn\rTripod  $22'),(12620,797736293016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','jjmm1985','supbaby@gmail.com','Jon Mulhern','6C Stanford Avenue','Brighton','East Sussex','UNITED KINGDOM','BN1 6AA','07976208637','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-06 21:41:13',0,NULL,3,1,2,1,NULL,'jjmm1985'),(12621,736264068002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','jmchtizen','jmdamez@free.fr','jean marc damez','4 allée A av de la rhônelle','Aulnoy les Valenciennes','Nord-Pas-de-Calais','FRANCE','59300','09.52.42.47.65','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:46:19',0,NULL,3,1,17,0,NULL,'jmchtizen'),(12622,694850480001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','jmchtizen','jmdamez@free.fr','jean marc damez','4 allée A av de la rhônelle','Aulnoy les Valenciennes','Nord-Pas-de-Calais','FRANCE','59300','09.52.42.47.65','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-06 21:46:19',0,NULL,3,1,3,1,' RA117717654CN','jmchtizen\r背景布 1.6x3m     1(黑)\r反光板支架    1\r1.499\r'),(12623,694877656001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','machawsu','khinchawsuwin@sbcglobal.net','Khin Chaw Su Win Chan','1055 N Capitol Ave<br>Apt 120','San Jose','CA','UNITED STATES','95133-2724','(408) 347-0019','NoPaymentFailure','CheckoutComplete','Other','2011-07-06 23:28:37',0,NULL,3,1,1,1,' ','machawsu\r摄影背心 nikon 原厂 XL     1'),(12624,814576745015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','Île-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-06 23:40:03',0,NULL,3,1,3,1,'RA117717637CN ','dpssy42'),(12625,694881327001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','rernmoo','colorstreakimages@yahoo.com','Nickelaus Moore','1160 Seward St<br>Apt 415','Detroit','MI','UNITED STATES','48202-2328','(586) 222-4150','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-06 23:43:42',0,NULL,3,1,1,1,NULL,'rernmoo'),(12626,694886592001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ulomogahi','clarence_thw@hotmail.com','peida wu','1 west st','sydney','NS','CANADA','B1N 1R6','(902) 537-1567','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'ulomogahi'),(12627,694989432018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','tokperaih73','oslanaffandi@yahoo.com','Oslan Affandi Abdullah','Masjid Wilayah Persekutuan<br>Jalan Duta','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','50480','0133983822','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-07 01:03:51',0,NULL,3,1,2,1,NULL,'tokperaih73'),(12628,736313884002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','samelalocatelli','samelaoliveira@hotmail.com','Sâmela Tavares de Oliveira Locatelli','Rua do Camacuan, 819<br>Uberaba','Curitiba','Paraná','BRAZIL','81550-360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 01:09:26',0,NULL,3,1,17,0,NULL,'samelalocatelli'),(12629,694900614001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','samelalocatelli','samelaoliveira@hotmail.com','Sâmela Tavares de Oliveira Locatelli','Rua do Camacuan, 819<br>Uberaba','Curitiba','Paraná','BRAZIL','81550-360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 01:13:21',0,NULL,3,1,5,1,'CP227125398CN ','samelalocatelli\r斜臂     1\r反光板支架    1\r柔光箱 50-70cm 单灯头      1 \r欧标\r2.548'),(12630,8881310003173388,111,'New Hairlight photostudio boom arm and stand',1,'AKT030',52,'hermeshine','aliexpress','stewart@nzbestbuys.co.nz','stewart gill','87 beatson road<br>nzl, New Zealand','nelson','nzl','NEW ZEALAND','7011','0220201963',NULL,NULL,NULL,NULL,0,NULL,3,1,6,1,'EE495341255CN ',''),(12631,8881310003321539,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',50,'hermeshine','aliexpress','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,NULL,0,NULL,3,1,6,1,'EE495341241CN\r ',NULL),(12632,736323061002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','noojasmine','kinnare@hotmail.com','kritsana kinnares','3104 Tarpon Dr<br>Unit 201','las vegas','NV','UNITED STATES','89120-5162','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 01:51:43',0,NULL,3,1,1,1,NULL,'noojasmine'),(12633,749460247017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','rosemarble','dhoskins@connectgradd.net','Michael t Hoskins','1040 Lee Henderson Rd','Lewisport','KY','UNITED STATES','42351-6946','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-07 02:37:18',0,NULL,3,1,1,1,' ','rosemarble'),(12634,694729775018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',68,'photographyacc','snappy*sam*','sdmullan@gmail.com','Sam Mullan','9 Highett Road','Highton','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-07 03:13:32',0,NULL,3,1,4,1,'YW865589820CN ','snappy*sam*\rbackdrop $15'),(12635,695032221018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','top.7','ralph.fontelar@gmail.com','Ralph Fontelar','94 Bellaview Road<br>Flagstaff Hill','Adelaide','South Australia','AUSTRALIA','5159','0882702360','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 04:37:38',0,NULL,3,1,3,1,'RA117717795CN ','top.7'),(12636,694640900001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','8818ross','ross@fujifasteners.com.au','Ross Tidswell','c/- Fuji Fasteners Pty Ltd<br>5 Swift Way','Dandenong South','Victoria','AUSTRALIA','3175','0397066652','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 05:00:31',0,NULL,3,0,3,1,'RA117717858CN\r ','8818ross\r摄影背心 黑色薄 canon 2XL(已入库)'),(12637,694952933001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',59.99,'hermeshine','tondeptrai','ton.trieu2012@gmail.com','Ton Trieu','3241 S Wabash Ave','Chicago','IL','UNITED STATES','60616','(773) 691-1131','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,7,0,18,1,NULL,'tondeptrai\r0707eCheck付款未结清,0708提前发货'),(12638,694952892001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','evisser008','lizev007@gmail.com','Mitchell Baldwin','3 Myall Fairway','Clarkson','Western Australia','AUSTRALIA','6030','0435338293','NoPaymentFailure','CheckoutComplete','AU_Express','2011-07-07 05:58:49',0,NULL,3,1,17,0,NULL,'evisser008\r澳标\r再+ 45w 220v   4个\rlighting kit  $30\r'),(12639,695047550018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/49 DOLPHIN AVE','MERMAID BEACH','Queensland','AUSTRALIA','4218','0435010514','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 06:14:01',0,NULL,3,1,17,0,NULL,'jobapro'),(12640,749501990017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/49 DOLPHIN AVE','MERMAID BEACH','Queensland','AUSTRALIA','4218','0435010514','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-07 06:23:21',0,NULL,3,1,3,1,'RA117717760CN ','jobapro\r肥皂盒 柔光罩   sb800 sb600     1\r反光板 100*150 40*60 5合1       1'),(12641,694962231001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','aejustin1','ae.justin1@yahoo.com','Justin Love','5266 Newburgh Hts<br>Apt A','Newburgh','IN','UNITED STATES','47630-2180','(270) 903-8404','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-07 06:55:51',0,NULL,3,1,1,1,NULL,'aejustin1'),(12642,749515357017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','frcfed87','mylastemailsucked@gmail.com','Matthew Micallef','2/12 Walter Street','East Geelong','Victoria','AUSTRALIA','3219','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 07:34:14',0,NULL,3,1,2,1,NULL,'frcfed87\r澳标'),(12643,736386574002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 07:57:20',0,NULL,3,1,6,1,'EE495340983CN ','buyedv'),(12644,694974438001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','tahir_street','jucagra@gmail.com','Juan Carlos Calle','C/ Curie, 2','La Coruna','Galicia','SPAIN','15008','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 08:06:19',0,NULL,3,1,4,1,'YW865589794CN ','tahir_street\rTripod  $20'),(12645,694870283001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','maisonlumiere','info@maisonlumiere.eu','Serena Galantucci','Via B. Fazio 74','La Spezia','SP','ITALY','19121','3408887220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 08:21:36',0,NULL,3,1,2,1,NULL,'maisonlumiere'),(12646,736392584002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','daneli7011','s.jorhag@gmail.com','Samuel Jörhag','Dragarv 25','Garphyttan','Närke','SWEDEN','71940','072-7333733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 08:31:20',0,NULL,3,1,2,1,NULL,'daneli7011'),(12647,736400680002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',4,'AA1311',19.96,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:18:04',0,NULL,3,1,17,0,NULL,'budda001'),(12648,736400511002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',6,'AA2203',21,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:18:04',0,NULL,3,1,17,0,NULL,'budda001'),(12649,736400445002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',5,'AA1310',27.45,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:18:05',0,NULL,3,1,17,0,NULL,'budda001'),(12650,736400591002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',7,'AA1205',20.93,'hermeshine','budda001','isaev.foto@gmail.com','Alexandr Isaev','Plavnizky 10-18','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187112','+79218965113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:18:05',0,NULL,3,1,3,1,'RA117717950CN\r ','budda001\r气吹 + 布   4\r爵影红外 sony   6\rlenspen   5   \r热靴保护盖  sony    7\r\r'),(12651,749518765017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',165.38,'photographyacc','joanna4t4','joeasom@iinet.net.au','Joanna Easom','25 Bray Street','Plympton Park','South Australia','AUSTRALIA','5038','0429353615','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 09:20:23',0,NULL,3,1,3,1,'RA183615081CN\r ','joanna4t4YW865589702CN\r(已入库)\r倒影板（白黑）   1\r内胆包无字加大   1\r大号灰卡    1\r110cm 5in1 反光板    1\rC型夹    1\r带水平仪 热靴保护盖    1\r爵影N1  1 - (换成\"永诺159-N1\")\r大力夹    1\r反光板支架    1\rphtography reflector  $20\r2m 灯架         1\r\r客户说是没找到热靴水平仪， 给他再发一个 07、22\r'),(12652,797913148016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','nefba1978','nef-78@hotmail.com','NEFTALÍ BALUFO ÁVILA','CALLE FRAILES, 5','CORTEGANA','Andalucía Ceuta y Melilla','SPAIN','21230','652360257','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-07 09:26:01',0,NULL,3,1,4,1,'YW865589713CN ','nefba1978\r欧标\rlighting kit  $40'),(12653,736398019002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',15.9,'hermeshine','joyfungifts','nick.t.100@gmail.com','Syen Lea Koh','2, Lrg 14 Jln Wong King Huo','Sibu,','Sarawak','MALAYSIA','96000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:30:18',0,NULL,3,1,3,1,'RA117717946CN\r ','joyfungifts'),(12654,797918361016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','fabeix','xmail@stefanfabian.se','Stefan Fabian','Skiljemyntsgatan 6','Gothenburg','','SWEDEN','414 80','004631227274','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 09:46:56',0,NULL,3,1,2,1,NULL,'fabeix'),(12655,695089312018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',60,'photographyacc','ronatkinson13','ronno13@yahoo.com.au','Ronald W Atkinson','6 Paroo Close','St.Clair','New South Wales','AUSTRALIA','2759','0298342551','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-07 09:47:51',0,NULL,3,1,4,1,'YW865589724CN ','ronatkinson13\rbackground  $20'),(12656,694102595001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','maxingles','elcamajan@gmail.com','maxi ferrer fajardo','C/ LA PORRA, 18','ARRECIFE DE LANZAROTE','Canarias','SPAIN','35500','828085998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 09:58:25',0,NULL,3,1,2,1,NULL,'maxingles'),(12657,736408560002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','animaldefendersinternational','amritacharya@ad-international.org','Animal Defenders International','Millbank Tower<br>Millbank','London','London','UNITED KINGDOM','SW1P 4QP','02076303340','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 09:59:14',0,NULL,3,1,3,1,'RA117717827CN\r ','animaldefendersinternational\rM(已入库)\r注意是2件!'),(12658,736413436002,120701787289,'GGS Glass LCD Screen Protector for Nikon D90 ',1,'AB2212',7.6,'hermeshine','6subbass9','juraj.liska.lc@gmail.com','Juraj Liska','Trenc 83','Lucenec','','SLOVAK REPUBLIC','98532','00421915787389','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 10:15:18',0,NULL,3,1,2,1,NULL,'6subbass9'),(12659,695099537018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','channie1025','chann_p02@yahoo.com','CHANN PUNG (SAMSUNG, SPARE PARTS)','8 PARKVIEW DR','HOMEBUSH BAY','New South Wales','AUSTRALIA','2127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 10:30:42',0,NULL,3,1,2,1,NULL,'channie1025'),(12660,814743362015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','isittc','chris-isitt@hotmail.co.uk','CHRISTOPHER ISITT','25A WOOD STREET<br>WOLLASTON','STOURBRIDGE','West Midlands','UNITED KINGDOM','DY8 4NN','01384886115','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-07 10:51:20',0,NULL,3,1,2,1,NULL,'isittc'),(12661,695120049018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AO0009',84.5,'photographyacc','tim4641','tjmillar@gmail.com','Tim Millar','892 Riversdale Road','Camberwell','Victoria','AUSTRALIA','3124','0419337446','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 11:51:51',0,NULL,3,1,4,1,'YW865589735CN\r ','tim4641\r背景架2mx2m (+ 3个夹子)    1\r背景布 1.6x2.1m     2 (白+黑)\rbackground  $20'),(12662,814767337015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','blueremo42','rayfacc@yahoo.co.uk','raymond faccenda','107 newcraighall road','musselburgh','midlothian','UNITED KINGDOM','EH21 8QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-07 12:07:17',0,NULL,3,1,2,1,NULL,'blueremo42'),(12663,695127531018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','possumboots10','chuckbetty88@gmail.com','Rachael Cowan','33 Northampton st','East Victoria park','Western Australia','AUSTRALIA','6101','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-07 12:20:15',0,NULL,3,1,2,1,NULL,'possumboots10\r白色\r---\r新地址:\rRachael Cowan\r74 McCoy St\rMyaree Western Australia \r6154\rAUSTRALIA\r'),(12664,695031823001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','love9940','erclovett4@aol.com','Eric Lovett','994 Tamarack Trl','Forest Park','GA','UNITED STATES','30297','','NoPaymentFailure','CheckoutComplete','Other','2011-07-07 12:28:14',0,NULL,3,1,1,1,NULL,'love9940\rM(已入库)'),(12665,736439141002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 12:31:38',0,NULL,3,1,17,0,NULL,'nexus19841984'),(12666,736437246002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',3.99,'hermeshine','nexus19841984','ozfoto@telefonica.net','Javier Jiménez León','Aeronave 9 (Estudio Fotográfico)','Madrid','Madrid','SPAIN','28042','913058172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 12:31:38',0,NULL,3,1,2,1,NULL,'nexus19841984\r橡胶遮光罩 72mm    1\r绿叶 UV  72mm         1'),(12667,736458644002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','lkarabeg','lkarabeg@gmail.com','Leo Karabeg','Gunnar Schjelderups vei 13 C','Oslo','Oslo','NORWAY','0485','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 13:23:34',0,NULL,3,1,3,1,'RA117717835CN\r ','lkarabeg'),(12668,695047319001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.99,'hermeshine','neftabeats','nefta_beats@hotmail.com','Javier Romero Álvarez','Calle Camarada Montiel Pichardo nº 13','Huelva','Andalucía Ceuta y Melilla','SPAIN','21007','655610320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 13:26:06',0,NULL,3,1,2,1,NULL,'neftabeats'),(12669,736465755002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','peter48e','peter.toth12@chello.hu','Peter Toth','Juharfa u.33.','Sopron','Győr-Moson-Sopron','HUNGARY','9400','(03620) 7703265','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 13:48:26',0,NULL,3,1,3,1,'RA117717813CN\r ','peter48e'),(12670,695056612001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 14:15:47',0,NULL,3,1,3,1,'RA117717932CN\r\r\r ','saud-p\r分2个小包 各申报$40'),(12671,695061646001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',75.98,'hermeshine','extraterrestrial2910','acidflight@yandex.ru','Dmitriy Strukov','Srednay Lugovaya 24','Kursk','Kurskaya oblast','RUSSIAN FEDERATION','305003','9045212604','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 14:22:09',0,NULL,3,1,5,1,'CP227165508CN\r ','extraterrestrial2910'),(12672,695064345001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 14:32:59',0,NULL,3,1,8,1,' CP227165511CN\r','manoj11276\r欧标\r申报 $100 Gift'),(12673,694986733001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','2011vladimirlaus','vladimirlaus@gmail.com','Vladimir Lauš','Trnovac 36','Virje','NE','CROATIA','48326','0038548280482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 15:18:03',0,NULL,3,1,2,1,NULL,'2011vladimirlaus'),(12674,695082319001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','marcoweyne','m.weyne@uol.com.br','Marco Antonio Oliveira','Av. Prefeito Dulcídio cardoso, 444, Bloco 3000, apto 308','Rio de Janeiro','Rio de janeiro','BRAZIL','22620311','552122671657','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 15:32:40',0,NULL,3,1,2,1,NULL,'marcoweyne'),(12675,798032453016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','juliaspooner1956','jspooner1956@yahoo.co.uk','daniel spooner','11 wyvern close','weston super mare','north somerset','UNITED KINGDOM','bs23 3ls','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-07 15:37:18',0,NULL,3,1,3,1,'RA183615475CN\r\r ','juliaspooner1956\r英标\rBackdrop support  $40\rYW865589772CN\r7月25号， 再发一个单灯头棚给他（已减库）'),(12676,695086332001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','supersete','supersete@hotmail.com','Alfonso del Pozo Pérez','C/ Monseñor Espinosa 24-B','Orihuela','Alicante','SPAIN','03300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 15:47:25',0,NULL,3,1,4,1,'YW865589783CN\r ','supersete\rtripod $25\r显示地址有问题--0725来信说收到了'),(12677,798032168016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',2,'AD1110',21.3,'hutongstore','siomai_16','siomai_16@yahoo.com','Eric Basit','Philippine Charity Sweepstakes Office<br>Vinzons Ave','Daet','Daet,Camarines Norte','PHILIPPINES','4600','0544400549','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 16:32:33',0,NULL,3,1,17,0,NULL,'siomai_16'),(12678,814842571015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','siomai_16','siomai_16@yahoo.com','Eric Basit','Philippine Charity Sweepstakes Office<br>Vinzons Ave','Daet','Daet,Camarines Norte','PHILIPPINES','4600','0544400549','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 16:32:34',0,NULL,3,1,17,0,NULL,'siomai_16'),(12679,798035613016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','siomai_16','siomai_16@yahoo.com','Eric Basit','Philippine Charity Sweepstakes Office<br>Vinzons Ave','Daet','Daet,Camarines Norte','PHILIPPINES','4600','0544400549','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 16:32:34',0,NULL,3,1,3,1,'RA117717861CN\r ','siomai_16\r小号内胆包 无字   1\r肩带 Q-strap 单   2\r橡胶遮光罩 55mm     1'),(12680,695104960001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',3,'AB1303',10.02,'hermeshine','mgruichjr','movielighter@gmail.com','Mike Gruich','1 University Pl<br>C/O Microlab','Lamoni','IA','UNITED STATES','50140-1641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-07 16:40:31',0,NULL,3,1,1,1,NULL,'mgruichjr'),(12681,814871629015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','hay2k','hay_michael@yahoo.co.uk','michael hay','63 Craigmount Brae','Edinburgh','Edinburgh City','UNITED KINGDOM','EH12 8XE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-07 16:52:08',0,NULL,3,1,2,1,NULL,'hay2k'),(12682,814874926015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','jun1920','paulcathrussell@gmail.com','Paul Russell','Labaure<br>Lemouzy','Lafrancaise','','FRANCE','82130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 16:52:13',0,NULL,3,1,2,1,NULL,'jun1920'),(12683,695133073001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','xiudongtang','tangxiudong@gmail.com','Xiudong Tang','700 Health Sciences Dr<br>Chapin A2007A','Stony Brook','NY','UNITED STATES','11790-3337','(631) 721-3673','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-07 17:57:28',0,NULL,3,1,1,1,' ','xiudongtang'),(12684,695138205001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','szatek0000','szatek000@op.pl','MARCIN  SZATKOWSKI','76 THE OVAL<br>TULLYVALLE','CHEERYWOOD','Dublin','IRELAND','18','0857894980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 18:09:34',0,NULL,3,1,17,0,NULL,'szatek0000'),(12685,693920314018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',17.98,'photographyacc','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-07 18:27:55',0,NULL,3,1,2,1,NULL,'igrom78'),(12686,798127482016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','szatek0000','szatek000@op.pl','MARCIN  SZATKOWSKI','76 THE OVAL<br>TULLYVALLE','CHEERYWOOD','Dublin','IRELAND','18','0857894980','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-07 18:54:44',0,NULL,3,1,4,1,'YW865589676CN\r ','szatek0000\rBackdrop support  $20\r大力夹云台   3'),(12687,736578215002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 19:12:14',0,NULL,3,1,2,1,NULL,'mellogabriel'),(12688,695174237001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','stoc2903','fengflin@hotmail.com','feng lin','10 sprucewood crt','scarborough','ON','CANADA','m1w 2k3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 19:33:33',0,NULL,3,1,3,1,'RA117717875CN\r ','stoc2903'),(12689,749750506017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','trailerparktycoon','thatstickerguy@yahoo.com','Tony Bazidlo','1008 May St','East Liverpool','OH','UNITED STATES','43920-2462','(330) 386-6400','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-07 19:50:28',0,NULL,3,1,1,1,NULL,'trailerparktycoon'),(12690,736596734002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gen4o77','inxs_01@mail.bg','Gencho Ivanov','D-r Basanovich 8','Varna','Varna','BULGARIA','9010','00359888557959','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 20:00:38',0,NULL,3,1,2,1,NULL,'gen4o77'),(12691,736602691002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vrybin','vadko80@gmail.com','Vadim Rybin','20a Antonycha Str., Apt 19','Lviv','Lviv','UKRAINE','79000','+380676740230','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-07 20:09:47',0,NULL,3,1,3,1,'RA117717889CN\r ','vrybin'),(12692,814989274015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','coolrk1984','mischa_kojine@web.de','Michael Kojine','Randowstrasse 12','Hamburg','','GERMANY','22547','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-07-07 20:27:50',0,NULL,3,1,4,1,'YW865589680CN\r ','coolrk1984\r欧标\rLighting Kit  $20'),(12693,695202735001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','alexbechard','textalex@gmail.com','Alexandre Bechard','20 Avenue des Bonites<br>Morcellement Investors','Tamarin','Black River','MAURITIUS','MP100','2302546699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 20:41:44',0,NULL,3,1,2,1,' ','alexbechard'),(12694,695203256001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',29,'hermeshine','krendelidze','stepanov@10-strike.com','Dmitry Stepanov','Sozidateley ave, 44-121','Ulyanovsk','','RUSSIAN FEDERATION','432059','+7-902-355-83-16','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 20:42:12',0,NULL,3,1,3,1,'RA117717844CN\r ','krendelidze'),(12695,695207170001,110423294080,'Marco O Flash o-flash Ring Light For Nikon SB900  F179',1,'AO0026',38.49,'hermeshine','rider*pvs','vspirogov@yandex.ru','Vjacheslav Pirogov','Severnaya street 17-27','Nizhnevartovsk, Tjumenskaja oblast\'','RU','RUSSIAN FEDERATION','628616','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 20:53:49',0,NULL,3,1,3,1,'RA117717977CN\r ','rider*pvs\ro-flash 179 下午到'),(12696,695203913001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','viktorsmith56','viktorsmith56@yahoo.com','Sergej Bozhko','1st. Mirnaya st.<br>dom 19 kv 3','Lugansk','','UKRAINE','91011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 21:53:38',0,NULL,3,1,3,1,'RA117717901CN\r ','viktorsmith56'),(12697,736647494002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',9.6,'hermeshine','alguiennishioalguien','alguienalgoalguien@gmail.com','Felix Herrero de Gregorio','Garcia Goldaraz 3 - Bajo (Correos)','Hernani','País Vasco','SPAIN','20120','655726704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 22:09:53',0,NULL,3,1,2,1,NULL,'alguiennishioalguien'),(12698,695254257001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','luckysushi2011','xiaoyingwucctv@hotmail.com','Xiaoying Wu','Åhavnen 79st','Køge','DE','DENMARK','4600','31786668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 23:37:17',0,NULL,3,1,3,1,'RA183619392CN ','luckysushi2011\r----\r第一次的碎了一个，0714补发一个给他\r45w 220v    1'),(12699,736668232002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','luckysushi2011','xiaoyingwucctv@hotmail.com','Xiaoying Wu','Åhavnen 79st','Køge','DE','DENMARK','4600','31786668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 23:37:17',0,NULL,3,1,17,0,NULL,'luckysushi2011'),(12700,736668690002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.98,'hermeshine','luckysushi2011','xiaoyingwucctv@hotmail.com','Xiaoying Wu','Åhavnen 79st','Køge','DE','DENMARK','4600','31786668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 23:37:18',0,NULL,3,1,3,1,'RA183613046CN\r ','luckysushi2011\r欧标\r45w 5500k 灯泡 220v    4\r单灯头   1\r双灯头   1\r1.620\r'),(12701,695255452001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-07 23:41:59',0,NULL,3,1,2,1,NULL,'nixette_nixette'),(12702,749847208017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','pdav7653','phill_davo@hotmail.com','Philip Davison','63 Clarke st','Mt Isa','Queensland','AUSTRALIA','4825','610437429445','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 00:51:02',0,NULL,3,1,3,1,'RA117717892CN\r ','pdav7653\r转接环是72mm'),(12703,695274922001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','larrissey0','richard.bradley@sympatico.ca','richard bradley','838 Comber','Greenfield Park','QC','CANADA','j4v 3k4','(450) 678-0111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 01:16:37',0,NULL,3,1,2,1,NULL,'larrissey0'),(12704,8881310088836367,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20,'hermeshine','aliexpress','mtozoni@yahoo.com.br','Matheus Tozoni','Av. Rui Barbosa, 1904 Av. Rui Barbosa, 1904','Assis','Sao Paulo','BRAZIL','19815000','+055 18 1881184440',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183613134CN\r ',' '),(12705,695393123018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','bander-r','_bander_@mail.ru','Kolosvetov Petr','Frunze 16, kv. 19','Sochi','Krasnonarskiy kray','RUSSIAN FEDERATION','354341','(791) 840-7029 ext.: 9','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 01:55:56',0,NULL,3,1,2,1,NULL,'bander-r'),(12706,693924695018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','insane410','daemary@bigpond.com','Mrs.A.Emary','10 Manna Gum Drive','pakenham','Victoria','AUSTRALIA','3810','0359409877','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 02:39:06',0,NULL,3,0,2,1,' ','insane410\r1.6x2.1  黑色'),(12707,749887674017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','rein2000','bituchakma@hotmail.com','Bitu Chakma','1903- 9304 SALISH COURT','Burnaby','BC','CANADA','V3J 7C5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 03:39:57',0,NULL,3,1,2,1,NULL,'rein2000'),(12708,736632709002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','julesbr2010','juladeira@hotmail.com','Juliana Ladeira','Rua Maria Gonçalves Braga, 114','Belo Horizonte','Minas Gerais','BRAZIL','31555340','553132497333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 03:46:15',0,NULL,3,1,2,1,NULL,'julesbr2010'),(12709,695309711001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','evisser008','lizev007@gmail.com','Mitchell Baldwin','3 Myall Fairway','Clarkson','Western Australia','AUSTRALIA','6030','0435338293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 04:05:26',0,NULL,3,1,4,1,'YW865589691CN\r ','evisser008\r澳标\r45w 220v  灯泡    4\r2m 灯架   2\r双灯头    2\r反光伞    2\r灯架包    1\rlighting kit  $30'),(12710,736750447002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','oxanagera','oxanagera7599@mail.ru','Dmitry Adamchik','Zodinskaya, 7-14','Smolevichi','Minskaya oblast','BELARUS','222201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 06:44:21',0,NULL,3,1,3,1,'RA117717994CN\r ','oxanagera'),(12711,736751659002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ringi72','ring.attila@gmail.com','Ring Attila','Tövis utca 13/b.','Szigetszentmiklós','Hungary','HUNGARY','2310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 06:49:41',0,NULL,3,1,3,1,'RA117718005CN\r ','ringi72'),(12712,695336677001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','etsolakis','etsolakis@lycos.com','ELEFTHERIOS TSOLAKIS','IMVROU 5<br>VYRONAS','ATHENS','GREECE','GREECE','16231','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-08 07:00:57',0,NULL,3,1,3,1,'RA183613050CN\r ','etsolakis'),(12713,736757565002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','miguelfuente','varadi_norbert@hotmail.com','Norbert Váradi','19. Tauplitzalm','Tauplitz','','AUSTRIA','8982','436889442568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 07:23:23',0,NULL,3,1,2,1,NULL,'miguelfuente'),(12714,695452975018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','carva01','s.robust@hotmail.com','Khan and Sarah Robust','4 Blackwattle Circuit<br>Arundel','Gold Coast','Queensland','AUSTRALIA','4214','0406870036','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 07:38:08',0,NULL,3,1,2,1,NULL,'carva01'),(12715,695459231018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','stafineo','ernest.barac@gmail.com','Ernest Barač','tomažičeva 85','Ljubljana','Slovenia','SLOVENIA','1000','+38640209936','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 07:45:14',0,NULL,3,1,2,1,NULL,'stafineo'),(12716,736764246002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','lyuboslav.asenov','lyubo.asenov@gmail.com','Lyuboslav Asenov - GeoCon','Boris Hristov 2A / et.2 office GeoCon','Sofia','Sofia','BULGARIA','1111','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-08 08:00:25',0,NULL,3,1,3,1,'RA117717985CN\r ','lyuboslav.asenov'),(12717,695463718018,280685221276,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm ',1,'AE3403',38,'photographyacc','carla*y','carlamyamine@gmail.com','Carla Yamine','93 Chirnside Street<br>Kingsville','Melbourne','Victoria','AUSTRALIA','3012','0396896506','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 08:08:43',0,NULL,3,1,3,1,'RA117717915CN\r ','carla*y'),(12718,815196307015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',126,'hutongstore','pierrerasmusson','pr2010@live.dk','peter rasmussen','Amagerfalledvej 27.3.th','Copenhagen S','Denmark','DENMARK','2300','+4521998606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-08 08:28:20',0,NULL,3,1,4,1,'YW865589422CN ','pierrerasmusson\rTripod  $30\r'),(12719,695467874018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','eadamsjr-soleil','eddie@adamsforcongress.org','Eddie Adams Jr','9504 Woodland Ridge Dr','Temple Terrace','FL','UNITED STATES','33637-4951','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','eadamsjr-soleil\reCheck结清再发货'),(12720,749947042017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','berflow1247','domantay@bigpond.net.au','Florence Domantay','15 Argyle Way','Wantirna South','Victoria','AUSTRALIA','3152','0398872862','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 08:51:13',0,NULL,3,1,2,1,'\\ ','berflow1247'),(12721,736489432002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','sstruik','simonstruik@msn.com','Simon Struik','Via Airolo 33','MILANO','Milano','ITALY','20159','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-08 08:57:47',0,NULL,3,1,4,1,'YW865589444CN','sstruik\r欧标\rLighting Kit  $25\r'),(12722,695359896001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.8,'hermeshine','eldarkra','eldarkra@gmail.com','Eldar Kravetsky','Ha-Rakefet<br>15A / 5','Bney Aish','','ISRAEL','60860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 08:59:54',0,NULL,3,1,3,1,'RA117771862CN ','eldarkra\r欧标'),(12723,695337019001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','nicehotbath','garyanicholson@gmail.com','Gary A.Nicholson','12 Lanyon Place<br>Whitby','Wellington','Admiralty Cove','NEW ZEALAND','5024','0064274212289','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 09:48:56',0,NULL,3,1,2,1,NULL,'nicehotbath'),(12724,695517673018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','shxji','matthew@truckbodiessolutions.com.au','Matthew Yang','Unit 24<br>115  Woodpark Road','Smithfield','New South Wales','AUSTRALIA','2164','0296321933','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-08 12:03:06',0,NULL,3,1,17,0,NULL,'shxji'),(12725,695517612018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','shxji','matthew@truckbodiessolutions.com.au','Matthew Yang','Unit 24<br>115  Woodpark Road','Smithfield','New South Wales','AUSTRALIA','2164','0296321933','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 12:03:06',0,NULL,3,1,2,1,NULL,'shxji\rNG128 柔光罩  1\r绿叶 渐变镜 67mm    1'),(12726,695523860018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','anna_grin','gad195@yandex.ru','Anna Grinchenkova','140 Baklanovskiy Str. App. 73','Novocherkassk','Rostov Region','RUSSIAN FEDERATION','346421','8 (8635) 267325','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 12:15:59',0,NULL,3,1,3,1,'RA183613718CN\r ','anna_grin'),(12727,695409773001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','malbon094','paulmalbon@usa.net','Paul Malbon','103 Salt Landing Cir','Savannah','GA','UNITED STATES','31405-9471','(912) 313-5886','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-08 12:32:55',0,NULL,3,1,1,1,NULL,'malbon094'),(12728,798471856016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','handlingensmann','torebjorn@gmail.com','Tore Bjorn Stensrud','Disengrenda 26b','Oslo','Oslo','NORWAY','NO-0587','+4790286080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-08 13:37:28',0,NULL,3,1,2,1,NULL,'handlingensmann'),(12729,750027786017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','marcus273','mincev01@optusnet.com.au','Zlatko Mincev','83 Quarter Sessions Rd','Westleigh','New South Wales','AUSTRALIA','2120','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-08 13:56:07',0,NULL,3,1,3,1,'RA183613810CN\r ','marcus273\r澳标'),(12730,695449187001,110596720337,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',12.99,'hermeshine','jjoobrien','joa@swblaw.com','Jennifer Adams','411 W Home Ave','Hartsville','SC','UNITED STATES','29550','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-08 14:53:08',0,NULL,3,1,1,1,NULL,'jjoobrien'),(12731,750065893017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','emmashop55','graziaemma@email.it','grazia emma cali','via c. colombo, 11','roccalumera','ME','ITALY','98027','0942751268','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 15:50:15',0,NULL,3,1,2,1,NULL,'emmashop55'),(12732,736893906002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','yathias','athiasy1@zahav.net.il','Yakov Athias','Herzel 90<br>P.O.BOX 5010','Bat-Yam','','ISRAEL','59471','972 77 5064917','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-08 16:23:21',0,NULL,3,1,3,1,'RA183613956CN\r ','yathias'),(12733,736904670002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','dutik2007','alexdormadikhin@gmail.com','Alex Dormadikhin','Airport 11 ap. 30','Chisinau','','MOLDOVA, REPUBLIC OF','MD2026','37368033233','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 16:58:23',0,NULL,3,1,3,1,'RA183613823CN\r ','dutik2007'),(12734,798559897016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','mrofso','mrofsog@telefonica.net','MANUEL SANTIAGO ROFSO GARCIA','C/ POLVORANCA,74 ESC.D-2ºC','ALCORCON','Madrid','SPAIN','28923','679014016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-08 17:23:54',0,NULL,3,1,2,1,NULL,'mrofso'),(12735,695503569001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','joaoamericobrazil','joaoamericofotografia@gmail.com','João Américo M. Filippi','SQS 314 Bl. E Apto. 103','Brasília','DF','BRAZIL','70383-050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 17:34:52',0,NULL,3,1,3,1,'RA183613749CN\r ','joaoamericobrazil'),(12736,733509136002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','grazy_86','mikeed@live.it','Michele Lomartire','Falcone e Borsellino<br>18','Grottaglie','TA','ITALY','74023','3400544477','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 17:36:48',0,NULL,3,1,2,1,NULL,'grazy_86'),(12737,695632566018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','archangelckc311','christopherckc@gmail.com','Christopher Chung','White House Lane<br>Coromandel','Beau Bassin','','MAURITIUS','00230','+2307715505','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-08 17:46:48',0,NULL,3,1,2,1,NULL,'archangelckc311'),(12738,736960594002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mboiadjieva','mboiadjieva@gmail.com','Ognian Pelev','str. Shipka 34, floor 4, room 404, Global films','Sofia','','BULGARIA','1504','(359) 885-9890 ext.: 01','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-08 19:46:14',0,NULL,3,1,3,1,'RA183613868CN\r ','mboiadjieva'),(12739,695581599001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','roderick4012','roderick.shilling@gmail.com','Roderick Khan','1302 Exchange Dr<br>Ste 100','Richardson','TX','UNITED STATES','75081-2315','(469) 916-8318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-08 21:01:21',0,NULL,3,1,1,1,NULL,'roderick4012\r110v'),(12740,695584824001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.68,'hermeshine','einer-nervt','patrick@photostudio.ch','Patrick Geissmann','Foto Lüthard AG Seminarstrasse 91','Wettingen','','SWITZERLAND','5430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-08 21:10:54',0,NULL,3,1,2,1,NULL,'einer-nervt'),(12741,737048790002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','bubbabee4u','owenyou0406@yahoo.com.au','Owen you','25 Jamieson Drive ','parkwood','Queensland','AUSTRALIA','4214','0755746497','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-09 00:03:12',0,NULL,3,1,3,1,'RA183613735CN\r ','bubbabee4u'),(12742,737050453002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','mrt371','yousafdin@gmail.com','yousaf din','821 Kilkenny Drive','Winnipeg','MB','CANADA','R3T 4Y5','(204) 269-8272','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-09 00:12:06',0,NULL,3,1,3,1,'RA183613806CN\r ','mrt371'),(12743,737057138002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','minis22','conceptrol@yahoo.com','Dominique Bouchard','2369 Lacordaire','Montreal','QC','CANADA','H1N2M1','(514) 253-5727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 00:48:26',0,NULL,3,1,3,1,'RA183613854CN\r ','minis22'),(12744,695648829001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',36.5,'hermeshine','elkaholicid','mbatease22@msn.com','Michael Batease','9261 W Patina Dr','Boise','ID','UNITED STATES','83709-6673','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-09 01:52:54',0,NULL,3,1,16,0,'23080440000065757519 ','elkaholicid\rwww.usps.com'),(12745,737096822002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','kayleen7589','kayleenball27@yahoo.com','kayleen ball','po box 1107','round mountain','NV','UNITED STATES','89045','(775) 377-2795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 04:32:41',0,NULL,3,1,1,1,NULL,'kayleen7589'),(12746,695677858001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','daninkilldbill09','daninkilldbill@gmail.com','danin Jacquay','9741 sandy run dr','waynesville','OH','UNITED STATES','45068-8387','(937) 361-1076','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 04:43:19',0,NULL,3,1,4,1,'YW865589466CN ','daninkilldbill09\r美标  110v\rBackdrop support  $40'),(12747,695832748018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','majesticstudio','donnie@majesticstudio.com.au','Mos Mobiles - Att : Donnie','Kiosk 11<br>Crn Derrimut & Heaths Rd','Werribee','Victoria','AUSTRALIA','3030','0412102646','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-09 06:30:06',0,NULL,3,1,3,1,'RA183614007CN\r ','majesticstudio'),(12748,798010360016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','ursundtobias','daewue@gmx.ch','tobias wüthrich','eggrainweg 3','rüschlikon','','SWITZERLAND','8803','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-09 06:54:47',0,NULL,3,1,5,1,'CP227166653CN ','ursundtobias\r欧标  Lighting kit $40'),(12749,695754617001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','pgupdk','aholesen@gmail.com','Spartan Imports - Andreas Olesen','True Møllevej 11','Tilst','','DENMARK','8381','21441955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 11:20:05',0,NULL,3,1,4,1,'YW865589525CN ','pgupdk\r欧标   220v\rLighting Kit  $40'),(12750,815719036015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','stildem22','info@rv-studio.ee','Roman Vassiljev','K.Karberi 17-29 Tallinn','Tallinn','Harjumaa','ESTONIA','13918','+372 55 30 150','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-09 11:25:59',0,NULL,3,1,2,1,NULL,'stildem22'),(12751,695772919001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','howie1a','ihowie1a@yahoo.com','Howard  Intveld','6204 34th Ave N','Saint Petersburg','FL','UNITED STATES','33710','(727) 345-8356','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-09 12:25:02',0,NULL,3,1,1,1,NULL,'howie1a'),(12752,815742771015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','sanjeevan85','jeevan22@hotmail.com','sanjeevan ponnuthurai','grundtvigsvej 64,1 tv','herning','','DENMARK','7400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-09 12:43:57',0,NULL,3,1,3,1,'RA183613871CN\r ','sanjeevan85'),(12753,815744705015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.8,'hutongstore','cjwestmoreland','caestra2000-cjwebay@yahoo.co.uk','Chris Westmoreland','25 Hudson Way','Tadcaster','North Yorkshire','UNITED KINGDOM','LS24 8JF','01937836124','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 12:44:17',0,NULL,3,1,17,0,NULL,'cjwestmoreland'),(12754,815744814015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','cjwestmoreland','caestra2000-cjwebay@yahoo.co.uk','Chris Westmoreland','25 Hudson Way','Tadcaster','North Yorkshire','UNITED KINGDOM','LS24 8JF','01937836124','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 12:44:17',0,NULL,3,1,2,1,NULL,'cjwestmoreland\r绿叶 UV  67mm   1\r橡胶遮光罩 67mm   1'),(12755,737213144002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tigers101','cnguyen@hess.com','Chien Nguyen','9232 Old Veranda Rd','Plano','TX','UNITED STATES','75024-7082','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-09 13:38:57',0,NULL,3,1,1,1,NULL,'tigers101'),(12756,798942972016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','bertieblue33','pmcostello@hotmail.com','Paul M Costello','39 High Street','Belbroughton','West Midlands','UNITED KINGDOM','DY9 9ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 14:01:21',0,NULL,3,1,2,1,NULL,'bertieblue33'),(12757,695809254001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','marcmyoung','myoung@securenet.net','marc young','1762 place beauchesne','montreal','QC','CANADA','h1l 3g9','(514) 351-3024','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-09 14:30:53',0,NULL,3,0,3,1,'RA183613770CN\r ','marcmyoung\r摄影背心 黑色薄 canon     3XL    1(已入库)'),(12758,695773871001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',4.95,'hermeshine','techno.lodge','hsmeet@gmail.com','Harmeet Singh Sindhu','H. No. 2584<br>Phool Chakkar','ROPAR','PB','INDIA','140001','09814168951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 14:48:30',0,NULL,3,1,2,1,NULL,'techno.lodge'),(12759,798983708016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','marilenats','mtsoumeleka@gmail.com','George Tsoumelekas','Amiklon 28, Xalandri','Athens','Nomos Attikis','GREECE','15231','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-09 15:50:30',0,NULL,3,1,2,1,NULL,'marilenats'),(12760,750498167017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','danu_saputra54','danu_saputra@xtra.co.nz','Danu Djaja','54 Manuka Road<br>Glenfield','Auckland','','NEW ZEALAND','0629','64-9-4413018','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-09 17:02:24',0,NULL,3,1,2,1,NULL,'danu_saputra54'),(12761,695861808001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','temmi69','teemu.tiesto@gmail.com','Teemu Tiestö','Viipurintie 7 A 24','Lahti','','FINLAND','15150','+358400531905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 17:05:15',0,NULL,3,1,3,1,'RA183613783CN\r ','temmi69'),(12762,737309299002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','vodicka.gabriel','gabriel.vodicka@gmail.com','Gabriel Vodička','SLOBODY 237/18','Košice','SVK','SLOVAK REPUBLIC','04011','+421911938808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 18:12:34',0,NULL,3,1,3,1,'RA183613908CN\r ','vodicka.gabriel'),(12763,737310591002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','patino82_123','patino82@hotmail.com','Alexandro Johansen','Vinjevegen 115','Åmot','Telemark','NORWAY','3890','+4748522871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 18:17:59',0,NULL,3,1,17,0,NULL,'patino82_123'),(12764,737308079002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','patino82_123','patino82@hotmail.com','Alexandro Johansen','Vinjevegen 115','Åmot','Telemark','NORWAY','3890','+4748522871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 18:18:00',0,NULL,3,1,17,0,NULL,'patino82_123'),(12765,737309017002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','patino82_123','patino82@hotmail.com','Alexandro Johansen','Vinjevegen 115','Åmot','Telemark','NORWAY','3890','+4748522871','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 18:18:00',0,NULL,3,1,3,1,'RA183613721CN\r ','patino82_123\r爵影红外 sony      1\rsony 单肩包  A1      1\r气吹 + 布     1'),(12766,737324266002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','pcurban_eu','bojan@pcurban.com','Bojan Slavkovic','Dzona Kenedija 7/55','Kosovska Mitrovica','Srbija','SERBIA','38220','+381646419633','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-09 18:50:14',0,NULL,3,1,2,1,NULL,'pcurban_eu'),(12767,695926586001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','murrfdasurf1','76cruiser@gmail.com','Robert Murphy','2410 ne 8th ave','Wilton Manors','FL','UNITED STATES','33305','(954) 830-4076','NoPaymentFailure','CheckoutComplete','Other','2011-07-09 19:55:53',0,NULL,3,1,1,1,NULL,'murrfdasurf1\r摄影背心 nikon 原厂  L     1(已入库)'),(12768,696134876018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','paulsy123','tangbo@westnet.com.au','Paul Sue-Yek','P.O. Box 67','Flying Fish Point','Queensland','AUSTRALIA','4860','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-09 22:38:35',0,NULL,3,1,2,1,NULL,'paulsy123'),(12769,695948506001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','jmbelem','geral@momentosvideo.pt','João Coelho','Rua Natália Correia, nº6 4º-A','Lisboa','Lisboa','PORTUGAL','1170-270','00351210125934','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-09 23:16:37',0,NULL,3,1,3,1,'RA183613885CN\r ','jmbelem'),(12770,816022934015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','carpdon','carpdon@tiscali.co.uk','don mulrooney','75 lonsdale drive','rainham','Kent','UNITED KINGDOM','me8 9hy','0634361649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-09 23:37:47',0,NULL,3,1,2,1,NULL,'carpdon'),(12771,750647535017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',2,'AA1303',5,'photographyacc','bdaustralia','happy_lander2@hotmail.com','Bruce Meehan','Ernst & Young<br>8 Exhibition Street','Melbourne','Victoria','AUSTRALIA','3000','610419351042','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 00:06:08',0,NULL,3,1,2,1,NULL,'bdaustralia'),(12772,696156523018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','iamgod0202','taks0202@hotmail.com','Takamichi Gummow','86 Bridges Road','New Lambton','New South Wales','AUSTRALIA','2305','0419387743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 00:13:27',0,NULL,3,1,2,1,NULL,'iamgod0202'),(12773,750687398017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',2,'AA1303',5,'photographyacc','imjoshuaalexander','joshuaalexanderinbox@googlemail.com','Joshua Alexander','29 Confederate Street<br>Red Hill','Brisbane','Queensland','AUSTRALIA','4059','0427628214','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 03:08:04',0,NULL,3,1,2,1,NULL,'imjoshuaalexander'),(12774,737465947002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','lincocao','lincocao@yahoo.com.cn','YANJUN CAO','1311 E 27th Ave','VANCOUVER','BC','CANADA','V5V2L9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-10 03:48:08',0,NULL,3,0,3,1,'RA183619551CN\r ','lincocao\r近摄镜 +8  67mm缺货,\r客户宁愿等2周也想要+8不要+4'),(12775,737466411002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','the.aquitaine','the.aquitaine@yahoo.com','Jimmy McCelvey','1840 County Road 4545','Kennard','TX','UNITED STATES','75847','(972) 207-3924','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 03:55:00',0,NULL,3,1,3,1,'RA183613899CN\r ','the.aquitaine'),(12776,696042807001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','eschwarzmann','eschwarzmann@verizon.net','Elizabeth Schwarzmann','1426 Princeton St<br>Apt 1','Santa Monica','CA','UNITED STATES','90404','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 04:01:43',0,NULL,3,1,1,1,NULL,'eschwarzmann'),(12777,696210133018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','qinglinmeng','qinglinmeng@hotmail.com','Qing Lin Meng','14 Bridlewreath','Kitchener','ON','CANADA','N2E 3V5','(519) 579-5825','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-10 04:56:48',0,NULL,3,1,2,1,NULL,'qinglinmeng'),(12778,799280745016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','kenrontho','kenronny@gmail.com','Ken Ronny Thomassen','Herkulesveien 1b','Hvam','Nes, Akershus','NORWAY','2165','47650866','NoPaymentFailure','CheckoutComplete','NotSelected','2011-07-10 06:49:38',0,NULL,3,1,2,1,NULL,'kenrontho'),(12779,816120424015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',57,'hutongstore','leninsk2006','mer@takas.lt','Romualdas Medinskas','Naujakiemio 6-79','Klaipeda','Lithuania','LITHUANIA','94188','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 06:52:35',0,NULL,3,1,5,1,'CP227165525CN ','leninsk2006\r白+ 黑'),(12780,8881310283515873,111,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',3,'AA1314',8,'hermeshine','mal2829ron','ronho2829@yahoo.com','Ron Ho','24 Jalan 27/12B','Shah Alam','Selangor','MALAYSIA','40400','0123747730',NULL,NULL,NULL,NULL,0,NULL,3,1,17,0,NULL,NULL),(12781,8881310283536337,111,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',3,'AA1315',8,'hermeshine','mal2829ron','ronho2829@yahoo.com','Ron Ho','24 Jalan 27/12B','Shah Alam','Selangor','MALAYSIA','40400','0123747730',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183613797CN\r ','机身盖/镜头后盖  Nikon   3\r机身盖/镜头后盖  Canon  3\r '),(12782,696145705018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','lilmunchkinsbowtique','tanyaleighwotton@hotmail.com','Tanya Wotton','1/73 Blackett avenue','Young','New South Wales','AUSTRALIA','2594','0431622692','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 07:41:23',0,NULL,3,0,3,1,'RA183613845CN\r ','lilmunchkinsbowtique\r白+黑'),(12783,750738993017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1114',12.99,'photographyacc','sooinpark','emilypark@live.com','emily park','3-5 james street<br>bayswater','perth','Western Australia','AUSTRALIA','6053','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 07:44:25',0,NULL,3,1,2,1,NULL,'sooinpark'),(12784,816135402015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','ddv201010','dd0190@ya.ru','Dozinova Valentina M','Ordzhonikidze<br>d.2 kv.85','Balashov','Saratovskaya Obl','RUSSIAN FEDERATION','412300','79093383303','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 07:49:35',0,NULL,3,1,2,1,NULL,'ddv201010'),(12785,750743719017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','gafloss','gfairy@nsw.chariot.net.au','Geoffrey Fairy','Bldg W21, Geology Road<br>University of New England','Armidale','New South Wales','AUSTRALIA','2351','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 08:02:07',0,NULL,3,1,2,1,NULL,'gafloss'),(12786,799305544016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','paulajwatson','paulajwatson@btinternet.com','L Watson','2 Schoolhill Road<br>Portlethen','Aberdeen','Aberdeenshire','UNITED KINGDOM','AB12 4RE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 08:16:43',0,NULL,3,1,2,1,NULL,'paulajwatson'),(12787,750754745017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','princess_pinni','sarahrogers83@hotmail.com','Sarah Rogers','2/9 William St','Rose Bay','New South Wales','AUSTRALIA','2029','04093130800409313080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 08:39:45',0,NULL,3,1,2,1,NULL,'princess_pinni'),(12788,737532742002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','seryogka','sergey03s@yandex.ru','Sergey Karpov','Hertzfeld st. 8/13','Tel-Aviv','Tel-Aviv','ISRAEL','67530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 09:25:20',0,NULL,3,1,3,1,'RA183613911CN\r ','seryogka'),(12789,750769759017,270742430933,'New Green.L 72mm Macro Close-up Filter +4',1,'AE3220',6.75,'photographyacc','leohueb','lhu@tpg.com.au','Ping Wu','12/24 Warwick St','Hurstville','New South Wales','AUSTRALIA','2220','0295852289','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 09:26:52',0,NULL,3,1,2,1,NULL,'leohueb'),(12790,750771882017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','myong_h','myong_h@hotmail.com','Myong Hong (docomo pacific)','219 S Marine Corps Dr<br>Ste 206','Tamuning','GU','UNITED STATES','96913-3927','(671) 929-6905','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-10 09:31:51',0,NULL,3,1,1,1,NULL,'myong_h'),(12791,696280229018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',122.01,'photographyacc','ciresass','eric_stajuana2004@yahoo.com','ERIC STA. JUANA','United Design International Bldg.<br>Plot-II 17th Street Mussafah Industrial Area M-4','Abu Dhabi,','POBox','UNITED ARAB EMIRATES','53162 AUH','0097125550002','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-10 10:01:03',0,NULL,3,1,17,0,NULL,'ciresass\r\r\r\r'),(12792,750782880017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','llynx54','pelican_54@hotmail.com','Peter Matthews','85 Mooloolah Drive<br>Minyama','Sunshine Coast','Queensland','AUSTRALIA','4575','0754447914','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 10:17:05',0,NULL,3,1,2,1,NULL,'llynx54'),(12793,696129916001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','nikolaos-k','nk@trains.gr','NIKOLAOS KAPSIMALAKOS','74 THETIDOS str.<br>ILION','ATHENS','ATTIKI','GREECE','13122','(30)6973743869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 10:34:45',0,NULL,3,1,2,1,' ','nikolaos-k'),(12794,737554553002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','den-spb','denis@ikar-spb.com','Ekaterina Sadovnikova','Marshala Zakharova ul., d.16, korp. 2, kv. 73','St.-Petersburg','Russia','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 10:42:07',0,NULL,3,1,17,0,NULL,'den-spb'),(12795,737553958002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','den-spb','denis@ikar-spb.com','Ekaterina Sadovnikova','Marshala Zakharova ul., d.16, korp. 2, kv. 73','St.-Petersburg','Russia','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-10 10:42:07',0,NULL,3,0,17,0,NULL,'den-spb\r(已入库)'),(12796,696128689001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','den-spb','denis@ikar-spb.com','Ekaterina Sadovnikova','Marshala Zakharova ul., d.16, korp. 2, kv. 73','St.-Petersburg','Russia','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-10 10:42:08',0,NULL,3,1,17,0,NULL,'den-spb\r'),(12797,737554064002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',85,'hermeshine','den-spb','denis@ikar-spb.com','Ekaterina Sadovnikova','Marshala Zakharova ul., d.16, korp. 2, kv. 73','St.-Petersburg','Russia','RUSSIAN FEDERATION','198332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 10:42:09',0,NULL,3,1,5,1,'CP227165539CN ','den-spb\r欧标   220v\r2m 灯架   2\r双灯头      2\r反光伞      2\r灯架包      1\r背景架2mx2m  + 3个夹子    1\r1.6x2.1m    背景布    2(黑/白)\r摄影背心 Canon  老款     L    1(已入库)\r85cm 柔光伞    2'),(12798,816210159015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','nodge652348','lankyrose@hotmail.com','norman Hodkinson','Carrer Major 13A<br>ORCAU','TREMP','Cataluña','SPAIN','25655','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 11:03:43',0,NULL,3,1,2,1,NULL,'nodge652348'),(12799,696143779001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',82,'hermeshine','jacomin','la_pernia@hotmail.com','Jesus Miguel Torre Gutierrez','Ibaizabal 5-A  1º C','Durango','País Vasco','SPAIN','48200','685725710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 11:15:54',0,NULL,3,1,4,1,'YW865589536CN ','jacomin\rtripod $22'),(12800,750810909017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','sickfish.2007','theraviger@hotmail.com','Aaron Scicluna','7 courageous street Taylors Lakes','melbourne','Victoria','AUSTRALIA','3038','030409094172','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'sickfish.2007'),(12801,799382864016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','alcasvi','alcasvi@gmail.com','CASTOR VIDAL MARTINEZ','CARMEN CONDE, 44 6º D','CARTAGENA','Murcia','SPAIN','30204','609943347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 11:30:25',0,NULL,3,1,2,1,NULL,'alcasvi'),(12802,816225264015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','seananthonyjackson','seaniejax@gmail.com','Sean Jackson','108 New Cabra Road.','Dublin','Dublin','IRELAND','D7','0877702245','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 11:38:33',0,NULL,3,1,3,1,'RA183613942CN\r ','seananthonyjackson'),(12803,737566481002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','blanja','bulic.goran@gmail.com','Goran Bulic','Glavani<br>30','Barban','','CROATIA','52207','00385918861386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 11:58:22',0,NULL,3,1,2,1,' ','blanja'),(12804,696323719018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','goldfoot17','gdvideo@optusnet.com.au','George DAVID','17 Cluden Street','Brighton East','Victoria','AUSTRALIA','3187','61412744411','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 11:59:05',0,NULL,3,1,2,1,NULL,'goldfoot17'),(12805,696330075018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',54,'photographyacc','maurob123456','blakeborcich@bigpond.com','mauro borcich','17 Turner Avenue<br>Glenhuntly','Melbourne','Victoria','AUSTRALIA','3163','0386849606','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 12:15:37',0,NULL,3,1,3,1,'RA183613925CN\r ','maurob123456\r6个 220v'),(12806,737595141002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dragunov656','daryn_trueplaneguru@hotmail.com','Daryn Mason','23 McGrath Street<br>Norman Gardens','Rockhampton','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 12:31:54',0,NULL,3,1,2,1,NULL,'dragunov656'),(12807,750871614017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',17.6,'photographyacc','j8i8m8x8','ebebstuff2@optusnet.com.au','Sue Reid','Excel Technology, 18 Staple Street<br>Seventeen Mile Rocks','Brisbane','Queensland','AUSTRALIA','4073','0732794322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-10 14:07:37',0,NULL,3,1,2,1,NULL,'j8i8m8x8\r澳标\r单灯头  1\r反光伞 83cm   1'),(12808,696419891018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',29.5,'photographyacc','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÚMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-10 15:48:58',0,NULL,3,0,3,1,'RA183614191CN ','gerson0909\r摄影背心 冬夏  XL    1(已入库)'),(12809,737690563002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','minipro69','m1ura@hotmail.com','Emilio Rivas','Calle Real Alta 23','Ogijares','Andalucía Ceuta y Melilla','SPAIN','18151','644344003','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 16:17:52',0,NULL,3,1,4,1,'YW865589492CN ','minipro69\rtripod $20'),(12810,696271099001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','paynesbay60','chowbaycush@msn.com','Bert Cush','72 Saint Roberts Dr','stafford','VA','UNITED STATES','22556-3600','(540) 720-6919','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-10 16:36:47',0,NULL,3,1,1,1,NULL,'paynesbay60'),(12811,696332338001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','609milton','baraschmilton@yahoo.com','MILTON BARASCH','6 WARWICK CT','BARNEGAT','NJ','UNITED STATES','08005-3348','(609) 698-1756','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-10 18:07:09',0,NULL,3,1,1,1,NULL,'609milton'),(12812,816463779015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','pmangan1234','pmangan@oceanfree.net','Patrick Mangan','Berties Lane<br>The Glebe','Letterkenny','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 18:12:42',0,NULL,3,1,2,1,NULL,'pmangan1234\r白'),(12813,816503095015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','deamer881','kjdeamer@aol.com','karen deamer','80 greenaleigh road','birmingham','West Midlands','UNITED KINGDOM','B144JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 18:48:51',0,NULL,3,1,3,1,'RA183613837CN\r ','deamer881'),(12814,696347555001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',6.58,'hermeshine','costasymiak','symiakcos@gmail.com','COSTAS SYMIAKAKIS','3 TRYFITSOY STR','HERAKLION-CRETE','προεπιλογή','GREECE','71201','0306944777123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 18:20:59',0,NULL,3,1,2,1,NULL,'costasymiak'),(12815,799701754016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','karenb6328','jb@jbeng.net','Karen Bridges','Glen View House, Highbury Street','Coleford, Radstock','Somerset','UNITED KINGDOM','BA3 5NW','01373814613','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 19:38:21',0,NULL,3,1,2,1,NULL,'karenb6328'),(12816,799746580016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','watcher2007','robertwatcher@hotmail.com','Rob Watcher','Box 1277<br>31 Rattenbury Street E, Apt #1','Clinton','ON','CANADA','N0M1L0','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-10 20:39:47',0,NULL,3,1,2,1,NULL,'watcher2007'),(12817,696422598001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','creations_nb','nadia.beauvais@videotron.ca','Créations Nadia Beauvais','144 Blanchard','St-Jérôme','QC','CANADA','J7Y 0B5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-10 20:13:56',0,NULL,3,1,3,1,'RA183613766CN\r ','creations_nb\r1.6x2.1m  背景布  3 (黑/白/绿)'),(12818,695967239001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-10 21:32:15',0,NULL,3,1,17,0,NULL,'saud-p'),(12819,696622660018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',203,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-10 21:32:17',0,NULL,3,1,17,0,NULL,'saud-p\r\r\r'),(12820,696434640001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-10 21:32:19',0,NULL,3,1,17,0,' ','saud-p\r'),(12821,816631308015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','mabinternational','matthew_bird_9@hotmail.com','Matthew Bird','Askew Rigg, Troutbeck','Penrith','Cumbria','UNITED KINGDOM','CA110SZ','01768779794','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-10 21:51:46',0,NULL,3,1,2,1,NULL,'mabinternational'),(12822,696682797018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','nvr999','nvrana@gmail.com','Nishchal Rana','5775 Morehouse Dr','San Diego','CA','UNITED STATES','92121-1714','(530) 570-0068','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-10 23:44:30',0,NULL,3,1,1,1,NULL,'nvr999'),(12823,737959897002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','naseribrahim','i.naseribrahim@gmail.com','Mohd Khairul Naser Ibrahim','Perpustakaan UTHM<br>Universiti Tun Hussein Onn Malaysia','Parit Raja, Batu Pahat','Johor','MALAYSIA','86400','0197703066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 01:14:03',0,NULL,3,1,2,1,NULL,'naseribrahim'),(12824,816705975015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','bmrsilva','brrsilva@gmail.com','BRUNO SILVA','RUA CENTRO CICLISTA AZEITONENSE 9','AZEITÃO','SETUBAL','PORTUGAL','2925-416','969155787','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 01:16:45',0,NULL,3,1,3,1,'RA183613939CN\r ','bmrsilva'),(12825,696542896001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','cama1973','carmar73@aol.com','carlos marenco','13962 SW 278th St','homestead','FL','UNITED STATES','33032-8519','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 02:20:32',0,NULL,3,1,1,1,NULL,'cama1973'),(12826,737985094002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bcardibr','brunocardi@gmail.com','Bruno Cardi','R Joaquim Murtinho, 683','Cuiabá','MT','BRAZIL','78020290','65 33212074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 02:47:54',0,NULL,3,1,2,1,' ','bcardibr'),(12827,799891359016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',2,'AA1303',3.74,'hutongstore','1337olav','olav_m_@hotmail.com','Olav Mehlum','Husbybakkan','Trondheim','Skaun','NORWAY','7357','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 03:04:24',0,NULL,3,1,2,1,NULL,'1337olav'),(12828,696749357018,280667757804,'New Green.L 62mm Macro Close-up Filter +4',1,'AE3218',5.69,'photographyacc','ciresass','eric_stajuana2004@yahoo.com','ERIC STA. JUANA','United Design International Bldg.<br>Plot-II 17th Street Mussafah Industrial Area M-4','Abu Dhabi,','POBox','UNITED ARAB EMIRATES','53162 AUH','0097125550002','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 04:12:02',0,NULL,3,1,3,1,'RA183613681CN\rRA183613678CN\r\r ','ciresass\r分成2个挂号小包发, 申报$20/包\r绿叶近摄镜 +4  62mm       1\r河北黑色厚背心 nikon  xl   1\r77mm 橡胶罩   1\r77mm +4 近摄镜   1\r77mm 渐变灰   1\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子    1'),(12829,738008357002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','skatebummish','stolenfuturephotog@gmail.com','Stig Johnsen','Mårnes','Sandhornøy','Nordland','NORWAY','8130','+47 41513961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 04:30:42',0,NULL,3,1,3,1,'RA183619110CN\r ','skatebummish'),(12830,738011348002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.55,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 04:47:32',0,NULL,3,1,11,1,NULL,'keith10w1977'),(12831,738014245002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','zeller1556','zeiler56@gmx.de','Zeiler Nikolaus','Zollernstr 4','Loßburg','','GERMANY','72290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 05:04:38',0,NULL,3,1,17,0,NULL,'zeller1556'),(12832,751278000017,270742432772,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',33.9,'photographyacc','aussiecamtutte','gcgriffin@bigpond.com','Gordon Griffin','2/10 Georgina Ct.','Spring Gully','Victoria','AUSTRALIA','3550','0354435571','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 05:09:06',0,NULL,3,1,3,1,'RA183613752CN\r ','aussiecamtutte\r广角托架    2\r方形滤镜接口环 77mm     1\r方形滤镜接口环 72mm     1\r方形滤镜接口环 62mm     1\r方形滤镜接口环 58mm     1\r普通托架 + 接口环 62mm     1\r普通托架 + 接口环 72mm     1\r'),(12833,696763537018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','leicaflexone','leicaflex1@gmail.com','Francky','Shop 2/206 Alison Road','Randwick','New South Wales','AUSTRALIA','2031','61450500014','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 05:36:57',0,NULL,3,1,3,1,'RA183613664CN\r ','leicaflexone'),(12834,696588082001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','aperturef14','kenghuatlee@gmail.com','Keng Lee','5 Saxon Avenue','Wantirna','Victoria','AUSTRALIA','3152','0411382561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 06:21:36',0,NULL,3,1,2,1,NULL,'aperturef14'),(12835,816795836015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','smellsliketeensocks','loonylondonlad@hotmail.com','Tom Staples','47 Hyde Close','Chafford Hundred','Essex','UNITED KINGDOM','RM16 6RR','07527028260','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 07:06:44',0,NULL,3,1,2,1,NULL,'smellsliketeensocks'),(12836,738035145002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','coling45','coling7@me.com','Colin Garside','22/31 Langport Parade','Mudgeeraba','Queensland','AUSTRALIA','4213','0755306809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 07:11:09',0,NULL,3,1,17,0,NULL,'coling45'),(12837,738035029002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','coling45','coling7@me.com','Colin Garside','22/31 Langport Parade','Mudgeeraba','Queensland','AUSTRALIA','4213','0755306809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 07:11:09',0,NULL,3,1,2,1,NULL,'coling45\r3片装的滤镜袋     2'),(12838,738042195002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102.6,'hermeshine','georgiyvylegzhanin','hmdfirm@yahoo.co.uk','Georgiy Vylegzhanin','apt. 32, building 200,<br>KOZHAMKULOV Street','Almaty','Almaty','KAZAKHSTAN','050012','(727) 293-7713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 07:47:10',0,NULL,3,1,3,1,'RA183613253CN\r ','georgiyvylegzhanin'),(12839,696606136001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',3.55,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 08:04:54',0,NULL,3,1,17,0,NULL,'hinkebein13'),(12840,738045040002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 08:04:55',0,NULL,3,1,17,0,NULL,'hinkebein13'),(12841,738044963002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 08:04:55',0,NULL,3,1,17,0,NULL,'hinkebein13'),(12842,738044844002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 08:04:56',0,NULL,3,1,2,1,NULL,'hinkebein13\r方镜广角托架（ 一槽） 1\rNIKON 镜头盖 77mm    1\r绿叶 渐变镜 55mm         1\r方形滤镜接口环 55mm  1'),(12843,816824318015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',2,'AD1129',16,'hutongstore','eddyhuang','simply-eddy@hotmail.com','Eddy Huang','Block 233 Hougang Street 21 #04-340','default','','SINGAPORE','530233','96946444','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 09:00:07',0,NULL,3,1,11,1,NULL,'eddyhuang'),(12844,696806984018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','rsssd','rossdawe@hotmail.com','Ross Dawe','17 ridgeview street eltham','melbourne','Victoria','AUSTRALIA','3095','0407406828','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 09:21:24',0,NULL,3,1,2,1,NULL,'rsssd'),(12845,696619735001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-11 09:27:03',0,NULL,3,1,12,1,'BJ8823901 ','saud-p\r欧标 \r背景架2m x 3m + 3个夹子   2\r背景架2mx2m  + 3个夹子   1\r50-70cm 柔光箱 单灯头       3\r115w  220v 灯泡    3\r2m 灯架   3\r斜臂          1\r灯架包      1\r1.6x2.1m   背景布   4(黑/白/白/绿)\r16.4'),(12846,696626108001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','litakely2000','patrick.razanatsimba@gmail.com','Patrick RAZANATSIMBA','72 rue de l\'essonne<br>Interphone A46, Appartement 46, 2eme Etage','EVRY','Ile-de-France','FRANCE','91000','0621310377','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 09:38:51',0,NULL,3,1,3,1,'RA183613125CN\r ','litakely2000'),(12847,816842143015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',2,'AA2325',9.3,'hutongstore','romadan001','romadan@inbox.ru','Roman Danylych','r. da Electricidade,<br>7, 4-c','Setubal','Setubal','PORTUGAL','2910-724','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 10:00:34',0,NULL,3,1,2,1,' ','romadan001'),(12848,696641890001,110583709397,'NEW 52mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT042',22.9,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-11 10:46:15',0,NULL,3,1,17,0,NULL,'p_pohjanjoki'),(12849,800003014016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','artilhas','armanduar@gmail.com','Armando Duarte','Centro Hospitalar de Coimbra<br>Servico de Informatica','Qta dos Vales - S. Mart. Bispo','Coimbra','PORTUGAL','3040','+351914209094','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 10:49:35',0,NULL,3,1,3,1,'RA183619018CN\r ','artilhas'),(12850,738083060002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 10:56:43',0,NULL,3,1,17,0,NULL,'p_pohjanjoki'),(12851,738082829002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 10:56:43',0,NULL,3,1,3,1,'RA183619548CN\r ','p_pohjanjoki\r小号灰卡    1\r2B柔    1\r绿叶  52mm  CPL    1\r绿叶  52mm  ND8    1\r绿叶  52mm  近摄+8    1\r绿叶  52mm  渐变灰     1\r4片装滤镜袋    1'),(12852,696645979001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','greatscottd','greatscottd@yahoo.com','Scott Dorrofield','PO Box 12213<br>Mill Street','Cape Town','Western Cape','SOUTH AFRICA','8010','270762061194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 11:05:08',0,NULL,3,1,17,0,NULL,'greatscottd'),(12853,738086713002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','greatscottd','greatscottd@yahoo.com','Scott Dorrofield','PO Box 12213<br>Mill Street','Cape Town','Western Cape','SOUTH AFRICA','8010','270762061194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 11:12:10',0,NULL,3,1,3,1,'RA183619106CN\r ','greatscottd\r天涯方形滤镜  渐变灰    1\rND2 filter    1\rND4 filter    1\rND8 filter    1\r67mm 转接环    1\r方镜普通托架（三槽）    1'),(12854,738087988002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tecktim33','tecktim@pacific.net.sg','Tan Teck Tim','Blk 404 #04-10 Bt Batok West Ave 7<br>S650404','SG','Singapore','SINGAPORE','650404','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 11:16:36',0,NULL,3,1,11,1,NULL,'tecktim33'),(12855,751371480017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','whitsundayscubadiving','brett.robinson2@bigpond.com','Brett Robinson','10 Kenny Court ','Moranbah','Queensland','AUSTRALIA','4744','0749418041','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 12:09:09',0,NULL,3,1,2,1,NULL,'whitsundayscubadiving'),(12856,816876451015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.56,'hutongstore','mattchgc','matt@mattchristie.com','Matt Christie','21 Mulberry Court<br>School Mews, off Cable St','London','London','UNITED KINGDOM','E1 0EW','07590533049','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 12:11:26',0,NULL,3,1,3,1,'RA183613094CN\r ','mattchgc'),(12857,696662634001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:12:13',0,NULL,3,1,3,1,'RA183619049CN\r ','dmitriyla\r灯泡是4个 220v'),(12858,738104551002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','stoianbelchev_8800','stoian.belchev@gmail.com','Stoyan Belchev','str. Dunav 1-A-1','Sliven','Sliven','BULGARIA','8800','35944500408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 12:20:40',0,NULL,3,1,2,1,NULL,'stoianbelchev_8800'),(12859,816904355015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','pearson1986','turnersue@live.co.uk','Susan Turner','190 Chichester Road, North Bersted','Bognor Regis','West Sussex','UNITED KINGDOM','PO215BJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 13:06:54',0,NULL,3,1,2,1,NULL,'pearson1986'),(12860,738124329002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tracer_one','tracer_dick@hotmail.com','Girard Yuzon','8 Tilden St.','Plumpton','New South Wales','AUSTRALIA','2761','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:31:56',0,NULL,3,1,2,1,NULL,'tracer_one'),(12861,738125151002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','info_excalibur','nondas@videotron.ca','Nondas Roussakis','4338 Marlin','Pierrefonds','QC','CANADA','H9H 2K7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 13:35:01',0,NULL,3,1,3,1,'RA183619208CN\r ','info_excalibur'),(12862,696693139001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','sergey-breus','sergey_breus@mail.ru','Breus Sergey','Suvorova street<br>house 4 apartment 2','Shymkent','The South Kazakhstan area','KAZAKHSTAN','160019','+77773676664','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 14:06:38',0,NULL,3,1,8,1,'CP227165542CN ','sergey-breus\rWF-717,是135cm的'),(12863,696697530001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',99,'hermeshine','sarmed2005koala','sarmed_alsamerria@hotmail.com','sarmed alsamerria','120 Shillington  Way<br>Thronlie','perth','Western Australia','AUSTRALIA','6108','0892071177','NoPaymentFailure','CheckoutComplete','AU_Express','2011-07-11 14:18:32',0,NULL,3,1,4,1,'YW865589573CN ','sarmed2005koala\r澳标  220v\r申报: Lighting Kit  $25\r'),(12864,738161456002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-11 15:32:37',0,NULL,3,1,3,1,'RA183613085CN\r ','vacarciucalexandru'),(12865,696935069018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','ue_industries','uea@iinet.net.au','Eugene Apter','Ovum<br>Level 5, 459 Little Collins St','Melbourne','Victoria','AUSTRALIA','3000','0395294221','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 16:27:00',0,NULL,3,1,2,1,NULL,'ue_industries\r白色\r'),(12866,751465810017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',5.8,'photographyacc','martin_higgins','ebay@badlandz.com','Martin Higgins','2 Eagle Close<br>Cheslyn Hay','Staffordshire','Staffordshire','UNITED KINGDOM','WS6 7LA','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 16:46:43',0,NULL,3,1,2,1,NULL,'martin_higgins\r带水平仪 热靴保护盖   2'),(12867,738198700002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','marco65-2009','marcomigliore@hotmail.es','Marco Migliore','Calle Almagro 3, 4º izq.da<br>(BigBang Media)','Madrid','Madrid','SPAIN','28010','676127326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:17:21',0,NULL,3,1,4,1,'YW865589584CN ','marco65-2009\rtripod  $20'),(12868,751476433017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','yoavrom','yoav.rom@gmail.com','Yoav Rom','46 Golan st. apartment # 18','Alfe Menashe','','ISRAEL','44851','972-54-4545450','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 17:17:30',0,NULL,3,1,2,1,NULL,'yoavrom'),(12869,738207023002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ccheeken','ccheeken@yahoo.com','CHANG CHEE KEN','37， JALAN S 2 / 7,<br>TAMAN SAUJANA 2,','KAMUNTING','PERAK','MALAYSIA','34600','019-5708368','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:39:10',0,NULL,3,1,2,1,NULL,'ccheeken'),(12870,738209168002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','bigmavr_63','bigmavr@gmail.com','Alexandr Marinin','8-aya radialnaya d-9 kv-5','Samara','','RUSSIAN FEDERATION','443011','+79608324293','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 17:41:09',0,NULL,3,1,2,1,NULL,'bigmavr_63'),(12871,738229328002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','kanalla24','kanalla24@hotmail.com','Antonio Fernandez Almela','C/ Lorca  9    Bajo','Las Torres de Cotillas','Murcia','SPAIN','30565','617839655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 18:23:45',0,NULL,3,1,3,1,'RA183619097CN\r ','kanalla24\r356'),(12872,817055401015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','vaistininkasedvardas','ekazlaus@takas.lt','Edvardas Kazlauskis','P.O. Box 2058','Kaunas','','LITHUANIA','44008','8 686 45735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 18:33:50',0,NULL,3,1,2,1,NULL,'vaistininkasedvardas'),(12873,738240342002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','sgalindo1978','ssilvi21@hotmail.com','Silviano Sanchez','916 E Old Willow Rd<br>Apt 101','Prospect Heights','IL','UNITED STATES','60070-2411','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-11 18:48:24',0,NULL,3,1,3,1,'RA183613103CN\r ','sgalindo1978'),(12874,751552272017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',3,'AB2401',32.7,'photographyacc','norwayimportcom','norgesimportcom@hotmail.com','Cato Elvik','Myrlandskroken 1','Sandnes','Sandnes','NORWAY','4308','90666502','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 19:42:40',0,NULL,3,1,3,1,'RA183619358CN\r ','norwayimportcom'),(12875,696837063001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','donovanhenry','d.henry@chesterhouse.co.za','Donovan Henry','58 Disa crescent<br>Sandrift','Cape Town','Cape Town','SOUTH AFRICA','7441','0824958115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 20:09:39',0,NULL,3,1,2,1,NULL,'donovanhenry'),(12876,696846181001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',2,'AA1201',5.98,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 20:29:41',0,NULL,3,1,2,1,NULL,'manoj11276'),(12877,691914268018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','kylamie','jamie10277@aapt.net.au','kylie jeffery','1773 the lakes way','rainbow flat','New South Wales','AUSTRALIA','2430','0412788976','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-11 20:43:09',0,NULL,3,1,2,1,NULL,'kylamie\r白色'),(12878,817146125015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',2,'AA1206',5.8,'hutongstore','g.collins','itsalive@star.co.uk','Gordon Collins','51b Casella Road New Cross Gate','London','London','UNITED KINGDOM','SE14 5QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 21:01:36',0,NULL,3,1,2,1,NULL,'g.collins'),(12879,738312508002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','viktoralmqvist','viktor.almqvist@gmail.com','Viktor Almqvist','Kronåsvägen 70','Uppsala','Uppsala','SWEDEN','75651','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-11 21:26:33',0,NULL,3,1,3,1,'RA183613015CN\r ','viktoralmqvist\r摄影背心 黑色厚 sony   XL     1(已入库)'),(12880,817159934015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','winton2408','winton2000@hotmail.co.uk','Seagal Investigations Ltd','The Studio<br>23a Southcote Road','Bournemouth','Dorset','UNITED KINGDOM','BH1 3SH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 21:30:26',0,NULL,3,1,3,1,'RA183619035CN\r ','winton2408'),(12881,800303329016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','sinokuzi','sinokuzi@yahoo.es','Roberto Gonzalez Martin','C.La Via N.7 Portal.3 Bajo.A','Castro Urdiales','CANTABRIA','SPAIN','39700','675709025','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 21:51:16',0,NULL,3,1,2,1,' ','sinokuzi'),(12882,738321666002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','andachoktay','andacoktay@gmail.com','ANDAÇ KELEKÇİ','Bahçelievler 6.cadde 34/5 36.Sokak<br>Çankaya/ANKARA','ANKARA-TURKEY','Turkey/ANKARA/ÇANKAYA','TURKEY','06490','(90) 532 462 85 44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 21:58:13',0,NULL,3,1,3,1,'RA183619083CN\r\r ','andachoktay\r美标  110v\r申报: Gift, $10\r这3票不合并!'),(12883,738324946002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','andachoktay','andacoktay@gmail.com','ERDAL KELEKCİ','Özçelik iş merkezi Kat:3 No:59 /Başkent bulvarı<br>OSTİM','Ankara','Turkey','TURKEY','06374','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:01:06',0,NULL,3,1,3,1,'RA184571325CN\r换成RA157512353cn\r\r ','andachoktay\r美标  110v\r申报: Gift, $10\r这3票不合并!\rRA183619066CN\r方波\r'),(12884,738325860002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','andachoktay','andacoktay@gmail.com','ANDAÇ KELEKÇİ','Bahçelievler 6.cadde 34/5 36.Sokak<br>Çankaya/ANKARA','ANKARA-TURKEY','Turkey/ANKARA/ÇANKAYA','TURKEY','06490','(90) 532 462 85 44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:03:04',0,NULL,3,1,3,1,'RA183617785CN\r\r ','andachoktay\r美标  110v\r申报: Gift, $10\r这3票不合并!RA183619070CN\r灯泡是220v的，\r800w 220v    2（已减库）\r新地址：\randaç oktay kelekçi\rmesakoru sitesi kavakli sokak bina no: 11 daire no:30 kamelya blok\rYenimahalle/ koru mahallesi/Ankara\r06170\rTurkey\r90 05324628544\r\r\r\r\r\r'),(12885,696576570001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','zeller1556','zeiler56@gmx.de','Zeiler Nikolaus','Zollernstr 4','Loßburg','','GERMANY','72290','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-11 22:10:58',0,NULL,3,1,2,1,NULL,'zeller1556\r绿叶 渐变镜 67mm    1\r天涯 ND8 67mm    1'),(12886,817186655015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','371ember','vpelns@gmail.com','Valters Pelns','Jūrmalas iela<br>8','Liepāja','','LATVIA','LV-3401','(371) 26755220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-11 22:33:21',0,NULL,3,1,3,1,'RA183619021CN\r ','371ember'),(12887,817200197015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','thismodernlove','sophielant.89@gmail.com','Sophie Lant','2 Southacre Close','Cambridge','Cambridgeshire','UNITED KINGDOM','CB2 7TT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-11 23:13:41',0,NULL,3,1,2,1,NULL,'thismodernlove'),(12888,751639251017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',196.82,'photographyacc','salvarec','salvarec@yahoo.it','Michele Carrara','Via Colugna 127/11','Udine','UD','ITALY','33100','0432-478627','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-11 23:33:22',0,NULL,3,1,4,1,'YW865589654CN ','salvarec（已入库）\r77mm 绿叶可调 ND镜    1\rCanon -52mm 反接环    1\rcanon 3m ttl 线      1\r60cm 闪光灯棚      1\r2m 弹簧灯架         1\rlenspen    1\r气吹     1\r布     1\rphotography accessories  $20\r3.640\r'),(12889,738365727002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ovexi','ovidiu_irimia@yahoo.com','Ovidiu Irimia','3309 Gumwood Rd','MISSISSAUGA','ON','CANADA','L5N 8A5','(905) 828-2037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 00:41:47',0,NULL,3,1,2,1,NULL,'ovexi'),(12890,697125371018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','wiseimp','c_boulton@bigpond.com','chris boulton','25 clifton st<br>hawthorn','Adelaide South Austrlia','South Australia','AUSTRALIA','5062','6143660483','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 00:59:16',0,NULL,3,1,2,1,NULL,'wiseimp'),(12893,8881310434849813,111,'2m 灯架 上 的第一个螺丝',1,'',0,'hermeshine','aliexpress补货','terst@test.com','Alexandre Padovani','Rua Joao Luso 320 - Apto 2','Santo Andre','Sao Paulo','BRAZIL','09130 150','+55 11 44572197',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183613148CN\r ',NULL),(12894,697138915018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','rkonanki','rkonanki@gmail.com','Rajkumar Konanki','level 25, 35 collins street<br>Amdocs','Melbourne','Victoria','AUSTRALIA','3000','0488775016','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 02:17:27',0,NULL,3,1,2,1,NULL,'rkonanki'),(12895,696941751001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','olafbonsai','abg@bedinialejandro.com','Alejandro Bedini','Nexus<br>ENRIQUE MAC IVER - 440 piso 15','Santiago','RM','CHILE','8320123','0057-2-4208504','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 02:18:16',0,NULL,3,0,3,1,'RA183613029CN\r ','olafbonsai\r摄影背心 黑色薄 canon     2XL     1(已入库)'),(12896,738379209002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 02:46:42',0,NULL,3,0,3,1,'RA183613077CN\r\r ','leofotografias'),(12897,696955266001,110320728338,'New Timer Remote Control For Nikon MC-36 D3 D700 D300',1,'AA3218',48.9,'hermeshine','josemartindelcampo','el_santos85@hotmail.com','Jose Martin del Campo Cruz','Fransisco I Madero 28<br>Centro','Casimiro Castillo','Jalisco','MEXICO','48930','3573880935','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 03:29:47',0,NULL,3,1,3,1,'RA183619260CN\r ','josemartindelcampo'),(12898,8881310441800042,111,'WT600 + 麦克风',1,'AO0027',20,'hermeshine','mieki1973','pmiekina@gmail.com','PIOTR MIEKINA','4824 N Damen Ave<br>Apt 404','CHICAGO IL ','','UNITED STATES','60625-1477','(773) 742-9314',NULL,NULL,NULL,NULL,0,NULL,3,1,4,1,'YW865589595CN ','wt600    1\r麦克风    1 \rtripod dolly  $30'),(12899,817290306015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','davidzaneguy974','davidzaneguy@live.fr','david zaneguy','310 A   route du bois de nèfles','sainte clotilde','Réunion','FRANCE','97490','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-12 04:47:06',0,NULL,3,1,5,1,'CP227166698CN \r','davidzaneguy974\rlight stand $20\rYW865589610CN '),(12900,697180138018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',78,'photographyacc','samhq308','samzilla1@gmail.com','Sam  Clarke','36 Caroline St','Hawthorne East','Victoria','AUSTRALIA','3123','0488315019','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-12 05:05:26',0,NULL,3,1,4,1,'YW865589606CN ','samhq308\rtripod $25\r'),(12901,697182464018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','ruzzell14','ruzzellwafu@yahoo.com','Ruzzell Ian Bondoc','20 stamford tce ','port lincoln','South Australia','AUSTRALIA','5606','0886822178','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 05:17:12',0,NULL,3,1,2,1,NULL,'ruzzell14'),(12902,697183215018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','jaroslawkurek','jaroslaw.kurek@poczta.neostrada.pl','Jarosław Kurek','Kalinowa 1<br>skr.poczt. 84','Nadarzyn','mazowieckie','POLAND','05-830','22 7398568','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-12 05:21:57',0,NULL,3,1,3,1,'RA183619137CN\r ','jaroslawkurek'),(12903,696769930018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',24.6,'photographyacc','kokom9','srdjan_nine@yahoo.com.au','Srdan Begic','14 Hopkins Street','Dandenong','Victoria','AUSTRALIA','3175','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 05:22:11',0,NULL,3,1,3,1,'RA183619145CN\r ','kokom9\r爵影无线 C1    1\r58mm  ND4    1'),(12904,751706730017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','dragonmaster51','rwillett29@hotmail.com','Robert Willett','5/10 Canton St<br>Canterbury','Sydney','New South Wales','AUSTRALIA','2193','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 05:37:05',0,NULL,3,1,2,1,NULL,'dragonmaster51'),(12905,738426159002,120633814466,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','nadia20819725','nadia2081@yahoo.com','Nadya Katsnelson','Rosh Pina 19 b, 3','Holon','-','ISRAEL','58401','+972528896048','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 05:51:02',0,NULL,3,1,3,1,'RA183619123CN\r ','nadia20819725'),(12906,697189744018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','melanimaxic','melani.max@gmail.com','Melani Majdandzic','Hanamanova 15','Zagreb','Zagreb','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-12 06:01:45',0,NULL,3,1,2,1,NULL,'melanimaxic'),(12907,751729166017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','dirtbox67','chauvelcarlsson@bigpond.com','Richard E Carlsson','PO Box 1298','Toowoomba','Queensland','AUSTRALIA','4350','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 06:23:40',0,NULL,3,1,2,1,NULL,'dirtbox67'),(12908,751753029017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','kayboo123','katieb333@iinet.net.au','K Booth','201 Madagascar Drive','Kings Park','New South Wales','AUSTRALIA','2148','0296728271','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 08:21:51',0,NULL,3,1,2,1,NULL,'kayboo123'),(12909,751753048017,270777970641,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k',1,'',295,'photographyacc','wodzimperium','cyberpaker@mac.com','Tony Montana','820 Trotter Cir','Las Vegas','NV','UNITED STATES','89107-4501','(702) 461-9355','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-12 08:23:06',0,NULL,3,1,4,1,'YW865589665CN ','wodzimperium\rphotography accessory\r'),(12910,697007350001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','chuckyq1','chucky_q1@yahoo.com','Cacuci Cristian','Str. Sovata, nr.51, bl.D32-33, et.4, ap.54','Oradea','BIHOR','ROMANIA','410298','(004) 0723-722222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 08:38:19',0,NULL,3,1,3,1,' RA183619154CN\r','chuckyq1'),(12911,697227691018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',40,'photographyacc','wlong1664','wlong@optusnet.com.au','William Long','162 West Av','Wynnum','Queensland','AUSTRALIA','4178','0738934007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 09:17:09',0,NULL,3,0,3,1,'RA183619199CN\r ','wlong1664\r摄影背心（河北，厚）canon 2XL    1(已入库) '),(12912,817357179015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','saimodem','sai.modem@gmail.com','Sai Kumar Modem','Sri Venkateswara Agencies Pvt. Ltd.<br>47-3-11/1, Dwarakanagar','Visakhapatnam','Andhra Pradesh','INDIA','530016','9959911227','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-12 09:40:20',0,NULL,3,1,2,1,NULL,'saimodem'),(12913,697233204018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','worksperfect','aeroelectronics@hotmail.com','Ziyad Moussa','100 Canberra st','St Marys','New South Wales','AUSTRALIA','2760','0410740004','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 09:42:34',0,NULL,3,1,3,1,'RA183619185CN\r ','worksperfect'),(12914,697195739018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',22,'photographyacc','the_tech_master','arrygunt@djpk.com.au','Philip Tyme','6 Rocklea Cresent','Skye','Victoria','AUSTRALIA','3977','0397826647','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 09:49:53',0,NULL,3,1,2,1,NULL,'the_tech_master'),(12915,697018679001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','alipapi','otticadoc@fastwebnet.it','luciano bresciani','via cutigliano, 31','Roma','RM','ITALY','00146','0645477791','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 10:02:25',0,NULL,3,1,3,1,'RA183619171CN\r ','alipapi\rShoulder Support    $15'),(12916,738483742002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','herigcosig','herrero_i@yahoo.es','Ignacio Herrero','Rivera del Loira 26-24','Madrid','Madrid','SPAIN','28042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 10:56:28',0,NULL,3,1,4,1,'YW865589632CN ','herigcosig\rtripod $20'),(12917,800513024016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'AC1303',5.5,'hutongstore','bluefoxypup','davegrundy@aol.com','David J Grundy','7 Briar Mead','Yatton','Bristol','UNITED KINGDOM','BS49 4RE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 11:26:33',0,NULL,3,1,2,1,NULL,'bluefoxypup'),(12918,800530934016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','theroyalquest','theroyalquest@yahoo.com','Paul Farnham','Linden Lea<br>Cliff Lane','New Polzeath','Cornwall','UNITED KINGDOM','PL27 6UE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 12:25:32',0,NULL,3,1,3,1,'RA183619256CN\r ','theroyalquest'),(12919,738506915002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',50,'AA1310',274.5,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 12:32:37',0,NULL,3,1,3,1,'RA183619344CN\r ','pinchukov\r1.914'),(12920,697279585018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','phobss','phob2p@gmail.com','Somphob Wongwaichumnikitkun','723/99 Jones street','Ultimo','New South Wales','AUSTRALIA','2007','0422959747','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 12:43:01',0,NULL,3,1,2,1,NULL,'phobss'),(12921,697064781001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 12:49:16',0,NULL,3,1,2,1,NULL,'bobi1330'),(12922,817422794015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.92,'hutongstore','aterhes-niko','aterhes@freemail.hu','Árpád Terhes','István út 101. 4/14.','Debrecen','Hajdú-Bihar','HUNGARY','H-4031','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-12 13:03:37',0,NULL,3,1,2,1,NULL,'aterhes-niko'),(12923,697074733001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',69.99,'hermeshine','jruipere','jorge.rpz@gmail.com','Jorge Ruiperez Sanchez','C/ General Rodrigo, 6 5ª Planta','Madrid','Madrid','SPAIN','28003','635903166','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 13:27:47',0,NULL,3,1,4,1,'YW865589643CN ','jruipere\rtripod $22'),(12924,8881310479044013,111,'MC',50,'',1800,'hermeshine','Pierro Astro','pierro@pierro-astro.com','PIERRO ASTRO - Pierre FRANQUET','Lot 26 Le Clos de Naïs<br>6 Rue du Chardonnay','LIEURAN LES BEZIERS','','FRANCE','34290','+33 6 09 57 47 38',NULL,NULL,NULL,NULL,0,NULL,3,0,12,1,'BJ8824101\r\r5589072845','MC-C1   45\rMC-C3    5 \r10.256\r\r'),(12925,694952933001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',59.99,'hermeshine','tondeptrai','ton.trieu2012@gmail.com','Ton Trieu','3241 S Wabash Ave','Chicago','IL','UNITED STATES','60616','(773) 691-1131','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 14:39:50',0,NULL,3,1,1,1,NULL,'tondeptrai\r0712-eCheck到账,0708已经提前发货'),(12926,738544192002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 14:44:02',0,NULL,3,1,3,1,'RA183619273CN\r RA183619327CN\r','bmonye\r分两个小包发\r欧标'),(12927,751855930017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',69.85,'photographyacc','drallimdesigns3','taniam729@optusnet.com.au','Tania Millard','PO BOX 204','Millicent','South Australia','AUSTRALIA','5280','0409381056','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-12 14:44:30',0,NULL,3,1,17,0,NULL,'drallimdesigns3'),(12928,697309771018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','drallimdesigns3','taniam729@optusnet.com.au','Tania Millard','PO BOX 204','Millicent','South Australia','AUSTRALIA','5280','0409381056','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-12 14:44:31',0,NULL,3,1,4,1,'YW866476015CN ','drallimdesigns3\r80cm 5in1 反光板   1\r反光板支架  1\r2m 灯架   1\rMini 红外  nikon    1\rreflector holder   $25\r\r'),(12929,817400462015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','stalinzbrna','trinactazona@seznam.cz','petr vacek','Tyrsova 329','Rosice','','CZECH REPUBLIC','66501','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-12 14:50:15',0,NULL,3,1,5,1,'CP227165556CN ','stalinzbrna\r欧标'),(12952,697570478018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',22,'photographyacc','kocobananas','mumseewumsy@hotmail.com','Katherine McQuillen','10 Church Hill Road','Echunga','South Australia','AUSTRALIA','5153','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 03:25:15',0,NULL,3,1,2,1,NULL,'kocobananas'),(12930,697128689001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','mech-60','gkphotog@optonline.net','George Kravis','125 Cockonoe Ave','Babylon','NY','UNITED STATES','11702-1903','(631) 669-6791','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 16:25:48',0,NULL,3,1,1,1,NULL,'mech-60'),(12931,817517131015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','mishmashvintage','missmichanestor@live.co.uk','Micha Nestor','Flat 4<br>10 Tudor Road','London','London','UNITED KINGDOM','SE19 2UH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 17:00:05',0,NULL,3,0,17,0,NULL,'mishmashvintage'),(12932,817516804015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','mishmashvintage','missmichanestor@live.co.uk','Micha Nestor','Flat 4<br>10 Tudor Road','London','London','UNITED KINGDOM','SE19 2UH','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-07-12 17:00:07',0,NULL,3,1,4,1,'YW866476026CN ','mishmashvintage\r英标  \r2m 灯架   2\r50-70cm 单灯头 柔光箱   2\r115w 220v 灯泡  2\r灯架包   1\r1.6x2.1m    背景布    1 (白)\rLighting Kit  $20'),(12933,738597909002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','fralac455','fralac@videotron.ca','FRANCOIS LACROIX','455 CARON','ST JOSEPH DU LAC','QC','CANADA','J0N1M0','(450) 472-6042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-12 17:22:27',0,NULL,3,0,3,1,'RA183619239CN\r ','fralac455\r摄影背心 Canon  老款    L (已入库)'),(12934,697149676001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','michael.bini','breakid@gmail.com','Michael  Biniashvili','Harey Golan 5/35','Ashdod','Israel','ISRAEL','77716','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 17:25:59',0,NULL,3,1,8,1,'CP227165560CN ','michael.bini\r欧标 220v\r申报: $60 Lighting Kit '),(12935,696189873001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','bigcomposer','kusche-tomasini@libero.it','Ingeborg Endl','Bassano di Sutri, 19<br>la via si trova tra Vicarello e Trevignano','Bracciano','RM','ITALY','00062','3334846448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 17:34:05',0,NULL,3,1,3,1,'RA183619242CN\r ','bigcomposer\rlight stand $10'),(12936,738503581002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',49.59,'hermeshine','xylocain','gr_lim@web.de','Ingenieurbüro Pickel','Herbsttal 2','Happurg','','GERMANY','91230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 17:44:03',0,NULL,3,0,17,0,NULL,'xylocain'),(12937,738605303002,120538959115,'NEW Flash Diffuser for Canon 580EX II',2,'AB3332',5.2,'hermeshine','xylocain','gr_lim@web.de','Joerg Pickel','Herbsttal 2','Happurg','','GERMANY','91230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 17:45:33',0,NULL,3,1,3,1,'RA184562080CN\r ','xylocain\r40cm 闪光灯的柔光棚      1\r肥皂盒 柔光罩   580EX     3\r货退回来了  无人领取\r重发0928\r新地址：\rMusicTrace GmbH\rJoerg Pickel\rAm Weichselgarten 3\r91058 Erlangen\rGermany\r特殊要求：\r申报实值，放一张“纸质发票”\r'),(12938,800677757016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','idok24','royimnor75@gmail.com','royi manor','harazim 11','Kiryat Bialik','israel','ISRAEL','27063','0542234809','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-12 18:31:23',0,NULL,3,1,3,1,'RA183619225CN\r ','idok24'),(12939,800702543016,260661735101,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',20.8,'hutongstore','maryilena','laurafmariana@yahoo.com','Laura Fismaister','1 Spruce Grove','Kirkby-In-Ashfield','Nottinghamshire','UNITED KINGDOM','NG17 7QB','07707566638','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 19:14:21',0,NULL,5,0,18,0,' ','maryilena\r绿叶  77mm    CPL    1\r绿叶  77mm    ND8    1\r绿叶  77mm    近摄镜 +8    1(有+4吗?)\r绿叶  77mm     渐变镜   1\r4片装滤镜袋     1'),(12940,697442290018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','masmor71','masmero@vodafone.it','massimo morabito presso Bravo Centro Servizi','Via Gustavo Cacini 15<br>tel. 3339317003 orari 9:45/13:00  16:00/20:00','roma','RM','ITALY','00125','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-12 19:57:55',0,NULL,3,1,2,1,NULL,'masmor71'),(12941,817631894015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','beserker0','timmaidens@bulldoghome.com','Timothy Maidens','11 Sherwood Place','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP26PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 20:23:22',0,NULL,3,1,2,1,NULL,'beserker0'),(12942,817664641015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','mani0200','mranamug@yahoo.com','Manjula Ranamuggedara','No. 33<br>Orton Grove','Enfield','London','UNITED KINGDOM','EN1 4UE','02083639342','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 21:27:44',0,NULL,3,1,2,1,NULL,'mani0200'),(12943,738708446002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','ifinderlaposte','ifinder@laposte.net','GALERIE ESTAMPE MODERNE ET SPORTIVE','P-A JULLIEN - 16 rue CHORON<br>16 rue CHORON','PARIS','Ile-de-France','FRANCE','75009','06 30 84 19 86','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 21:41:38',0,NULL,3,1,2,1,NULL,'ifinderlaposte'),(12944,697272588001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','pjblackbirdus','pjansen@pjblackbird.de','Peter Jansen','16201 E Main St<br>Edison Chouest Offshore','Cut Off','LA','UNITED STATES','70345-3804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-12 22:31:31',0,NULL,3,1,1,1,NULL,'pjblackbirdus'),(12945,697275750001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.99,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 23:11:31',0,NULL,3,1,3,1,'RA183619168CN\r ','ciafquito'),(12946,817705393015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','moodz_photography','dave@moodzphotography.co.uk','Dave Haysom','36a Tollardown Road','Weymouth','Dorset','UNITED KINGDOM','DT4 0SQ','01305773876','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-12 23:18:37',0,NULL,3,1,2,1,' ','moodz_photography'),(12947,697048242001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',5.98,'hermeshine','j0rg1','post@j0rg1.no','Jørgen Aschim Forsell','Postboks 2817','Trondheim','','NORWAY','7432','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-12 23:38:44',0,NULL,3,1,2,1,' ','j0rg1'),(12948,697299827001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','maskcol','jbrooks202@yahoo.com','Jack Brooks','1827 Greenfield Ave<br>Apt 202','Los Angeles','CA','UNITED STATES','90025','(310) 312-1299','NoPaymentFailure','CheckoutComplete','Other','2011-07-13 00:28:02',0,NULL,3,1,1,1,NULL,'maskcol'),(12949,8881310521651229,111,'717AH， 手柄 ， 肩带',1,'',133,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines <br>del Ajusco','México Distrito Federal ','','MEXICO','14200','',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183619287CN\r ','717AH   1\r717 手柄   1   (算上717ah里的，一共2个手柄）\r无字肩带    1\r '),(12950,752105648017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','dmaksan1','dmaksan@fastmail.com.au','Damir Maksan','15B Chapman Street','Braddon','Australian Capital Territory','AUSTRALIA','2612','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 02:11:54',0,NULL,3,1,2,1,NULL,'dmaksan1'),(12951,697335864001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','arientangerine','ch@christopher-holden.com','Christopher Holden','1675 Clay St<br>Apt 7','San Francisco','CA','UNITED STATES','94109-3722','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-13 03:10:18',0,NULL,3,1,1,1,NULL,'arientangerine\r'),(12953,697572808018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','crawley1987','steve_c1234@hotmail.com','Stephen Crawley','11 Wigens Ave Como West','Sydney','New South Wales','AUSTRALIA','2226','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 03:39:55',0,NULL,3,0,3,1,'RA183619335CN\r ','crawley1987\r1.6x2.1m     背景布    2(白/黑)'),(12954,697498421018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','interactive*info','t.denny@ssgllc.org','Teresa McGuigan','1323 Flaxwood Ave','Brandon','FL','UNITED STATES','33511','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-07-13 03:41:27',0,NULL,3,1,1,1,'','interactive*info\rYW866475993CN \r灯泡是110v\rLighting Kit  $28\r灯架换成2m弹簧吧\r灯泡碎了，再发一个灯泡给他     0720\r115w 110v    1\rLK011615518CN   \r'),(12955,697588747018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','rambakeramx','salesramblerparts@senet.com.au','Robert Freeman','po box 105','para hills','South Australia','AUSTRALIA','5096','0882621848','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-13 05:12:46',0,NULL,3,1,4,1,'YW866476004CN ','rambakeramx\rbackdrop   $20\r'),(12956,738812103002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','cromwell*2005','cromwell2005@yandex.ru','Alexander Trofimtsev','Lomonosova, 92 - 9','Arkhangelsk','','RUSSIAN FEDERATION','163000','7 (911) 870-7755','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 05:34:10',0,NULL,3,1,2,1,NULL,'cromwell*2005\r申报: camera cleaning accessory  $5'),(12957,800905199016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',54,'hutongstore','putinirl','ussr@eircom.net','Yuliya Verbytska','40 Orpen green<br>Stillorgan grove','Blackrock','Dublin','IRELAND','18','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 05:39:35',0,NULL,3,0,4,1,'YW866475982CN ','putinirl\r英标  220v\rLighting Kit  $20'),(12958,738814747002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','josepr2288','josepr22@hotmail.com','jose  g santiago','PO Box 375004','cayey','PR','PUERTO RICO','00737-5004','7875689144','PayPalPaymentInProcess','CheckoutComplete','Other','0000-00-00 00:00:00',0,NULL,7,0,18,1,NULL,'josepr2288\reCheck结清再发!\r'),(12959,800918396016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',6.5,'hutongstore','rubikqueen7','miniyoenunmini@hotmail.com','Juan Manuel Hernandez Villegas','C/ Fuentecilla<br>nº13   2ºA','Pozuelo de Alarcon','Madrid','SPAIN','28223','686354194','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 06:41:54',0,NULL,3,1,2,1,NULL,'rubikqueen7'),(12960,800943370016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','x-ecutioner-2012','x-ecutioner@mail.ru','Sergey Khlopenkov','Krasnyh zor\', d. 3, kv. 4','Obninsk','Kaluzhskaja oblast\'','RUSSIAN FEDERATION','249030','+79533229685','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-13 08:29:39',0,NULL,3,1,5,1,'CP227165573CN ','x-ecutioner-2012\r欧标\rlighting kit $30'),(12961,817851303015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','masmediauk','shahara@masmediauk.com','MAS Media UK','6 Grange Street','Rawtenstall','Lancashire','UNITED KINGDOM','BB4 7RT','08009101716','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-13 08:53:59',0,NULL,3,1,4,1,'YW866475956CN ','masmediauk\r英标\rlighting kit   $25'),(12962,697399856001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','nanouk104','vasilis104@gmail.com','VASILIS SAKKAS','K.PAPADAKH 66','THESSALONIKH','','GREECE','54248','2310564120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 09:13:32',0,NULL,3,1,4,1,'YW866475960CN ','nanouk104\r欧标\rlighting kit $25\r'),(12963,817858768015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',5,'AA1314',11,'hutongstore','frederickw6026','f.wallace@virgin.net','Frederick Wallace','9 High Elms Road<br>Hullbridge','Hockley','Essex','UNITED KINGDOM','SS5 6HB','01702230733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 09:23:22',0,NULL,3,1,3,1,'RA183619313CN ','frederickw6026'),(12964,738854961002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','future_music','synthdemos@gmail.com','Patricio Dobeson Montejo','Urb. La Chopera 59','Collado-Villalba','Madrid','SPAIN','28400','626543917','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 09:42:05',0,NULL,3,1,2,1,NULL,'future_music'),(12965,697401378001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','afrosergio','afro_20@hotmail.com','sergio mª dolores corral','C/ Pedro Diaz, nº 18, 7º J','Cartagena','Murcia','SPAIN','30300','622321120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 09:25:35',0,NULL,3,1,17,0,NULL,'afrosergio\r\r'),(12966,697406350001,110419741932,'Green.L 55mm Neutral Density ND8 Filter ND 8 55',1,'AE2309',6.5,'hermeshine','sergeich-2010','sergeich-2014@yandex.ru','Сергей Черепанов','Морская 82 кв.29','Волгодонск','Ростовская область','RUSSIAN FEDERATION','347360','(928)1879024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 09:46:16',0,NULL,3,1,2,1,NULL,'sergeich-2010'),(12967,738854577002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',36,'hermeshine','afrosergio','afro_20@hotmail.com','sergio mª dolores corral','C/ Pedro Diaz, nº 18, 7º J','Cartagena','Murcia','SPAIN','30300','622321120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 09:25:34',0,NULL,3,0,3,1,'RA183619375CN ','afrosergio\r1.6x3m 背景布   2 （ 白  黑）\r机身盖/镜头后盖  Nikon   1'),(12968,800969633016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','castropereira','castro@netcabo.pt','Joao Castro Pereira','AV DO RESTELO N35','LISBOA','LISBON','PORTUGAL','1400-314','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 10:15:22',0,NULL,3,1,2,1,NULL,'castropereira'),(12969,817875351015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.88,'hutongstore','raymond.muizhulis','raimondino007@gmail.com','Raimonds Muizulis','Matisa iela 41 - 12','Riga','Latvia','LATVIA','LV-1009','0037122102570','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 10:16:01',0,NULL,3,1,2,1,NULL,'raymond.muizhulis'),(12970,817881587015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','alexsz888','szecsialex@gmail.com','Alex Szécsi','Lehár Ferenc köz 19','Veresegyház','','HUNGARY','2112','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 10:36:23',0,NULL,3,1,3,1,'RA183619446CN ','alexsz888'),(12971,697422863001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-13 11:02:14',0,NULL,3,0,3,1,'RA183619389CN \rRA183619429CN\r','saud-p\r两个小包\r分别申报background support  $35\r背景布  黑   白  1.6 *2.1\rRA183619415CN\r'),(12972,738602470002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','amengual734','amengualh@yahoo.es','rafael amengual henry','miquel massuti num 2-1B','palma de mallorca','Baleares','SPAIN','07610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 11:04:35',0,NULL,3,1,17,0,NULL,'amengual734'),(12973,697423510001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','amengual734','amengualh@yahoo.es','rafael amengual henry','miquel massuti num 2-1B','palma de mallorca','Baleares','SPAIN','07610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 11:04:35',0,NULL,3,1,3,1,'RA183619432CN ','amengual734\rHB-7 花瓣    1\r天涯方形滤镜  ND2  1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  ND8   1\r77mm 接口环   1\r普通托架    1\r'),(12974,817899165015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.12,'hutongstore','jezjester','scott@scengoid.co.uk','Scott English','18 Luscombe Close','Ivybridge','Devon','UNITED KINGDOM','PL21 9TT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 11:31:06',0,NULL,3,1,2,1,NULL,'jezjester'),(12975,817913005015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.9,'hutongstore','asiaphoenix01','fudzi.eu@seznam.cz','Jan Peser','Manesova 638','Steti','','CZECH REPUBLIC','41108','420607901065','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 12:12:23',0,NULL,3,1,2,1,NULL,'asiaphoenix01'),(12976,697448224001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','howtosee','how_to_see@mail.ru','Maxim Lapunka','Abylai Khan str. the old 28, the new 36a. apartment 85.','Astana','Akmolinskaya','KAZAKHSTAN','010000','+ 7 702 480 54 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 12:37:38',0,NULL,3,1,5,1,'CP227165587CN ','howtosee'),(12977,697693764018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','woulfe.2009','p.woulfe@hotmail.com','judith woulfe','30 barley court','delahey','Victoria','AUSTRALIA','3037','0432286155','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 12:59:07',0,NULL,3,1,2,1,NULL,'woulfe.2009'),(12978,817930817015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','trixie_vix','trixie_vix@hotmail.com','Vicki Nicholas','31 Sumerlin Drive','Clevedon','Somerset','UNITED KINGDOM','BS21 6YW','01275876691','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 13:01:23',0,NULL,3,1,2,1,NULL,'trixie_vix'),(12979,752257259017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','dingalydong','cassmcbride@mac.com','Cassie McBride','58 Cowper St','Braidwood','New South Wales','AUSTRALIA','2622','0420220199','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-13 13:25:57',0,NULL,3,1,17,0,NULL,'dingalydong'),(12980,752259998017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','dingalydong','cassmcbride@mac.com','Cassie McBride','58 Cowper St','Braidwood','New South Wales','AUSTRALIA','2622','0420220199','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 13:25:58',0,NULL,3,1,17,0,NULL,'dingalydong'),(12981,801018267016,260810153479,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',1,'AD1110',10.65,'hutongstore','amornphoto','amorn_photo@yahoo.com','Amorn Amponpittayanant','1589/1 Theod-thai Rd. Talardpuu Thonburi','Bangkok','','THAILAND','10600','(662)466-3112','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 13:27:34',0,NULL,3,1,2,1,NULL,'amornphoto'),(12982,697697078018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','dingalydong','cassmcbride@mac.com','Cassie McBride','58 Cowper St','Braidwood','New South Wales','AUSTRALIA','2622','0420220199','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-13 13:28:30',0,NULL,3,1,4,1,'YW866475934CN ','dingalydong\r2m 背景架   1\r1.6x2.1  背景布  2  （ 白 黑）\r1.6x3m 背景布   1 （灰）\r2m 灯架   2\r50-70 棚  澳标   2\r115w 220v   2\r包    1\rlighting kit  $30\r'),(12983,817947072015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','ksiazek','biopaul@london.com','Jaroslaw Ksiazek','7  Hares Green','South Molton','Devon','UNITED KINGDOM','EX36 4SF','01769574065','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-13 13:47:42',0,NULL,3,1,17,0,NULL,'ksiazek'),(12984,801039848016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','ksiazek','biopaul@london.com','Jaroslaw Ksiazek','7  Hares Green','South Molton','Devon','UNITED KINGDOM','EX36 4SF','01769574065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 13:47:42',0,NULL,3,1,17,0,NULL,'ksiazek'),(12985,801039558016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','ksiazek','biopaul@london.com','Jaroslaw Ksiazek','7  Hares Green','South Molton','Devon','UNITED KINGDOM','EX36 4SF','01769574065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 13:47:43',0,NULL,3,1,4,1,'YW866475945CN ','ksiazek\r2m 灯架   2\r斜臂         1\r50-70 单灯头棚  英标   1\r包   1\r80cm  5in1   反光板   1\r反光板支架   1\rlighting kit  $25\r\r'),(12986,738922828002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','damass13','andrissekacis@inbox.lv','Andris Sekacis','Bygdoy alle 76, Oslo 0268<br>PB 3163 Elisenberg','OSLO','','NORWAY','0208','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 13:55:45',0,NULL,3,1,2,1,NULL,'damass13'),(12987,817959674015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','mad-q','me@iaingwynn.co.uk','Mr Iain Gwynn','Draganfly Motorcycles<br>Broad Street','BUNGAY','Suffolk','UNITED KINGDOM','NR35 1EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 14:19:07',0,NULL,3,1,2,1,NULL,'mad-q'),(12988,697721737018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','fozz100','donnaef83@hotmail.com','Melanie Foster','corner of George and Hunter Street','Singleton','New South Wales','AUSTRALIA','2330','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-13 14:33:16',0,NULL,3,1,4,1,'YW866475912CN ','fozz100\rbackgrond support $25\r'),(12989,696968618001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-13 15:15:08',0,NULL,3,1,17,0,NULL,'roseyranger'),(12990,697500977001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-13 15:38:30',0,NULL,3,1,17,0,NULL,'roseyranger'),(12991,817994981015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','mavic888','civam_perampalam@hotmail.com','Civam Perampalam','24 Webbs Wood','Swindon','Wiltshire','UNITED KINGDOM','SN55AW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 15:43:46',0,NULL,3,1,2,1,NULL,'mavic888'),(12992,697505044001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','roseyranger','roseyranger@yahoo.com','Roosevelt','623 Pope Dr<br>Apt A','Vallejo','CA','UNITED STATES','94591','(707) 552-5254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-13 15:52:23',0,NULL,3,1,1,1,NULL,'roseyranger\rnikon 反接环  52mm    1\r橡胶遮光罩     52mm    2'),(12993,697513468001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','bargains_no1','yanal923@gmail.com','Yana Lusher','280 Ocean Parkway 1R','Brooklyn','NY','UNITED STATES','11218','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 16:13:34',0,NULL,3,1,3,1,'RA183619401CN ','bargains_no1'),(12994,752333874017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',6.98,'photographyacc','ehssanzargar','zargar.ehssan@gmail.com','+61ehssan zargar','40 Archdeacon street, Nedlands<br>WA 6009','Perth','Western Australia','AUSTRALIA','6009','0421151142','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 16:46:39',0,NULL,3,1,2,1,NULL,'ehssanzargar'),(12995,818027097015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',2,'AB3304',11.6,'hutongstore','gvardakis','gvardakis@hotmail.com','GEORGE VARDAKIS','34 HANDAKOS str.','HERAKLION','CRETE','GREECE','71202','+306944555431','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 16:53:41',0,NULL,3,1,2,1,NULL,'gvardakis'),(12996,697773646018,280676109058,'New Capa Quick Neck Shoulder Strap for Canon Nikon Sony',1,'AD1110',20,'photographyacc','steenarnth','spam@arnth.dk','Steen Jorgensen','Lindevej 8','Sorø','','DENMARK','4180','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-13 17:01:37',0,NULL,3,1,2,1,NULL,'steenarnth'),(12997,801129611016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38,'hutongstore','realizador_cordobes','alvaromedina@hotmail.es','ALVARO MEDINA CANO','Calle Santa Isabel, 12, Piso 1,1<br>Piso 1,1','CÓRDOBA','Andalucía Ceuta y Melilla','SPAIN','14001','680341016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-13 17:19:37',0,NULL,3,1,4,1,'YW866475923CN ','realizador_cordobes\rLighting Kit   $25'),(12998,738597151002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',4,'AO0034',36,'hermeshine','edc-01e','qaz-01@m5.gyao.ne.jp','Akira Nakano','2-20-17 hasune<br>TOP hasune203','Itabashi-ku','Tokyo','JAPAN','174-0046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 18:03:12',0,NULL,3,1,3,1,'RA183619485CN\r ','edc-01e\r4个包都仔细检查所有的拉链\r'),(12999,739015486002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','tracey0412262603','tracey@thurmer.org','Tracey Ford','Landstadsgate 28','SANDEFJORD','','NORWAY','3210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 18:18:04',0,NULL,3,1,2,1,NULL,'tracey0412262603'),(13000,739018247002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','chivra','rogerholifield@hotmail.com','Roger Holifield','319 Southbrook St','Liberty','MO','UNITED STATES','64068-9393','(816) 835-1632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-13 18:24:13',0,NULL,3,1,1,1,NULL,'chivra'),(13001,695467874018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','eadamsjr-soleil','eddie@adamsforcongress.org','Eddie Adams Jr','9504 Woodland Ridge Dr','Temple Terrace','FL','UNITED STATES','33637-4951','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-13 18:57:59',0,NULL,3,1,4,1,'YW866475971CN ','eadamsjr-soleil\rTripod   $45'),(13002,739040661002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','marketing-index','uberweb@ymail.com','Jeremy Wong','Blk 77 Marine Drive #14-46','default','','SINGAPORE','440077','(+65) 9795 2075','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 19:12:57',0,NULL,3,1,11,1,NULL,'marketing-index'),(13003,818105599015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','sani_uk','sani_jatti@hotmail.com','Sandeep Sandhu','5 Walnut Drive<br>Smethwick','West Midlands','Birmingham','UNITED KINGDOM','B66 3RS','07852219579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 19:13:29',0,NULL,3,1,2,1,NULL,'sani_uk'),(13004,739046826002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','antonio9543','barry2000@alice.it','Antonio DI TOMMASO','Via Bellegra 11','Guidonia Montecelio','RM','ITALY','00012','3313736662','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 19:27:28',0,NULL,3,1,2,1,NULL,'antonio9543'),(13005,739044399002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','pac45ers','skallmedianaranja@hotmail.com','paco salcedo cobo','las eras 3 artasona de el grado','huesca','Aragón','SPAIN','22390','974304118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 19:30:20',0,NULL,3,1,2,1,NULL,'pac45ers'),(13006,818171111015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','billxen','billxenakis@yahoo.com','Basilios Xenakis','126 SMINARXIA MAXHS / MSB','NEA ALIKARNASOS','HRAKLEIO','GREECE','71601','6983510680','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-13 21:05:03',0,NULL,3,1,3,1,'RA183619450CN ','billxen'),(13007,813728132015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','christianhang10','stringerh10@hotmail.com','Christian Stringer','Ground Floor Flat<br>69 Glendower Road','Plymouth','Devon','UNITED KINGDOM','PL3 4LB','07866088716','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-13 22:00:26',0,NULL,3,1,2,1,' ','christianhang10'),(13008,813934380015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',70,'hutongstore','andrepferreira','andrepintoferreira@gmail.com','Andre Ferreira','Rua 19 nº1434 1ºEsq','Espinho','','PORTUGAL','4500-251','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-13 22:52:40',0,NULL,3,0,4,1,'YW866475816CN ','andrepferreira(已入库)\r2B柔   1\r3x1.6m   背景布   1 (灰色)\r58mm cpl   2\r58mm ND8   2\r58mm 渐变灰   2\r58mm 近摄+4  2\r4片装的滤镜袋   2\r2.380\rphoto accessories  $25\r\r'),(13009,750810909017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','sickfish.2007','theraviger@hotmail.com','Aaron Scicluna','7 courageous street Taylors Lakes','melbourne','Victoria','AUSTRALIA','3038','030409094172','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-13 23:42:57',0,NULL,3,1,2,1,NULL,'sickfish.2007'),(13010,697678392001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','dejaba2009','adrianionutpaul@yahoo.com','Adrian Ionut Paul','Negoiu nr. 4, ap. 11','Cluj-Napoca','Cluj','ROMANIA','400676','+40721608456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-13 23:46:20',0,NULL,3,1,2,1,NULL,'dejaba2009'),(13011,752507688017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','mefromacrosstheditch','steven.hall@xnet.co.nz','Steven Hall','25 Bligh St','Te Anau','Southland','NEW ZEALAND','9600','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-13 23:59:21',0,NULL,3,1,2,1,NULL,'mefromacrosstheditch'),(13012,697681740001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','gualcorecuador','gualcor@gmail.com','Walter Córdova','Bellavista Mz. 16 villa 14','Guayaquil','Guayas','ECUADOR','11371','042-202568','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 00:01:51',0,NULL,3,1,2,1,NULL,'gualcorecuador'),(13013,697682066001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',34,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 00:16:04',0,NULL,3,1,3,1,'RA183619361CN ','diretordecriacao\r欧标'),(13014,695839905001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',59.99,'hermeshine','ridersigns','doit@shaw.ca','Darren J. Wong','13410 68th Ave.','Surrey','BC','CANADA','V3W 2E9','(604) 595-1561','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-14 01:19:47',0,NULL,3,1,3,1,'RA183619463CN\r ','ridersigns'),(13015,818266312015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','drewands','drew_ands@yahoo.com','Alejandre Madali','47<br>Prospect Road','Leicester','Leicestershire','UNITED KINGDOM','LE5 3RR','07889733463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 01:47:53',0,NULL,3,1,2,1,NULL,'drewands'),(13016,697969964018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','robert8482','rob3ann3mcgregor@bigpond.com','Robert McGregor','Oasis Tourist Park<br>PO Box 1061','Howard Springs','Northern Territory','AUSTRALIA','0835','0428765313','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 02:31:06',0,NULL,3,1,2,1,NULL,'robert8482'),(13017,739178340002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','2006mrq','mike68quinn@gmail.com','Michael Quinn','89 Hammond St.','Bowmanville','ON','CANADA','l1c5e6','(905) 697-2945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-14 03:02:39',0,NULL,3,0,3,1,'RA183619503CN\r ','2006mrq\rxxxl   1 （已入库）'),(13018,8881310612709271,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20,'hermeshine','Niklas Eklund','no@email','Niklas Eklund','Skomakaregatan 6','Gothenburg','','SWEDEN','41129','+046 031 164751',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183619494CN\r ',NULL),(13019,739193044002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',12,'AA3408',119.88,'hermeshine','arphotovideo','ra1612@gmail.com','AR Photo','2901 Nostrand Ave','Brooklyn','NY','UNITED STATES','11229-1817','(718) 998-1688','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-14 04:21:57',0,NULL,3,1,1,1,NULL,'arphotovideo'),(13020,739198264002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','hapairaikh','kenhapairai@yahoo.fr','Ken Hapairai','Chemin Hart, Hamuta<br>BP 50219','Pirae','Tahiti','FRENCH POLYNESIA','98716','(689) 795-641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 04:59:02',0,NULL,3,1,17,0,' ','hapairaikh'),(13021,697739244001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',14.56,'hermeshine','hapairaikh','kenhapairai@yahoo.fr','Ken Hapairai','Chemin Hart, Hamuta<br>BP 50219','Pirae','Tahiti','FRENCH POLYNESIA','98716','(689) 795-641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 04:59:02',0,NULL,3,1,2,1,' ','hapairaikh\r反光板  80cm 5合1     1\r反光板 60cm 2合1      1\r732'),(13022,698009171018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','may16478','shellmay@hotmail.com','Shelley Akers','204 Broughton Street','Tumut','New South Wales','AUSTRALIA','2720','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-14 06:05:23',0,NULL,3,1,4,1,'YW866475901CN ','may16478\rBackdrop support  $20\r'),(13023,752589025017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','dizz60','gdisneys@optusnet.com.au','Gary Disney-Smith','6 Sierra Street<br>Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','0732693847','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 06:19:40',0,NULL,3,1,2,1,NULL,'dizz60'),(13024,739212461002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','ketilmolde','keva@online.no','Ketil Valle','Blokkebaervegen 36','MOLDE','','NORWAY','N-6429','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 06:41:39',0,NULL,3,1,17,0,NULL,'ketilmolde'),(13025,697753737001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.87,'hermeshine','ketilmolde','keva@online.no','Ketil Valle','Blokkebaervegen 36','MOLDE','','NORWAY','N-6429','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 06:41:39',0,NULL,3,1,2,1,NULL,'ketilmolde\r方形滤镜接口环 67mm    1\r方镜普通托架（三槽）     1\r方镜广角托架（ 一槽）    1'),(13026,698018974018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','tsg_shop','shop@scholz.com.au','The Scholz Group','103 Tarcutta St','Wagga Wagga','New South Wales','AUSTRALIA','2650','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 07:01:26',0,NULL,3,1,2,1,' ','tsg_shop'),(13027,698024470018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','h.b.engineering','mwallace1990@gmail.com','Matt Wallace','P.O Box 46','seville','Victoria','AUSTRALIA','3139','0402043789','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 07:30:33',0,NULL,3,1,2,1,NULL,'h.b.engineering'),(13028,801421895016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','flh801978','ianpark1@aol.com','Ian Parkin','69 Crescent Road<br>Nether Edge','Sheffield','South Yorkshire','UNITED KINGDOM','S7 1HN','01142584561','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 07:57:03',0,NULL,3,1,2,1,NULL,'flh801978'),(13029,739232933002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','le_khan','del.ireland@gmail.com','Dmitriy Lekhanov','Stroiteley st. 26 - 94','Perm','Permskiy Kray','RUSSIAN FEDERATION','614097','89028386326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 08:19:40',0,NULL,3,1,3,1,'RA183619738CN\r ','le_khan\r申报: Timer Control for Camera  $8'),(13030,818357324015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','pukis_mikitukas','bmorkunas@gmail.com','Bernardas Morkunas','Smalines 17-6','Vilnius','','LITHUANIA','LT-06206','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-14 08:23:57',0,NULL,3,1,2,1,NULL,'pukis_mikitukas'),(13031,818356910015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','sm1thson','sm1thson@hotmail.com','Andrew Smithson','22 Beamish Road,','Billingham','Cleveland','UNITED KINGDOM','TS23 3DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 08:25:48',0,NULL,3,1,2,1,NULL,'sm1thson'),(13032,818365065015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',61,'hutongstore','todd4456','info@hallfarmreproductions.com','james nunn','hall farm reproductions<br>hall farm','ipswich','Suffolk','UNITED KINGDOM','ip13 6jj','01473735195','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-14 08:55:36',0,NULL,3,1,4,1,'YW866475853CN ','todd4456\rLighting Kit  $20\r英标'),(13033,698045903018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','raywahadie','rayhan_s_wahadie@yahoo.com','Ray Wahadie','11/65-67 Forsyth Street','Sydney','New South Wales','AUSTRALIA','2032','02414203664','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 09:16:02',0,NULL,3,1,2,1,NULL,'raywahadie'),(13034,739247556002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','musse63stefan','a10z24@hotmail.com','stefan wallström','silverstigen 6','södertälje','södertälje','SWEDEN','15148','4608-55035019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 09:31:20',0,NULL,3,1,2,1,NULL,'musse63stefan'),(13035,752632574017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','yimsmith1','yimsmith@hotmail.com','Mr S A Smith','10 / 72 Patterson Street<br>Middle Park','Melbourne','Victoria','AUSTRALIA','3206','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 09:47:02',0,NULL,3,1,2,1,NULL,'yimsmith1'),(13036,801453709016,260817869837,'2nd Edition!! NEW Black Quick Rapid Camera Sling Strap',2,'AD1110',21.6,'hutongstore','suebroddle58','sexylincoln@hotmail.com','Lincoln Giles','12 the russets upwell','wisbech','Norfolk','UNITED KINGDOM','pe149aj','01945773190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 10:04:10',0,NULL,5,1,3,1,'RA183619715CN\r ','suebroddle58\r404\r已经发货了   但是点不了  '),(13037,697799146001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','vtors','vladkovr@mail.ru','Vladimir Kovriga','50 let SSSR str.<br>h 4, f. 17','Kolchugino','Vladimir area','RUSSIAN FEDERATION','601785','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 10:23:01',0,NULL,3,1,2,1,' ','vtors'),(13038,739261208002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','pepo*2011','menachem.papo@nice.com','Menachem Papo','Hashdera 52<br>P.O.4','Zofit','','ISRAEL','44925','+972-54-5442112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 10:34:58',0,NULL,3,1,2,1,NULL,'pepo*2011'),(13039,698062914018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','shirleysantini','shirleynietzsche@gmail.com','Adela Hrivnáková','Janouškova 15','Brno','','CZECH REPUBLIC','61300','775-608-372','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 10:41:53',0,NULL,3,1,2,1,NULL,'shirleysantini'),(13040,739263833002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','russetsprint','auctionsrus@btinternet.com','Michael Groom','Old Garage House<br>Thame Road','Blackthorn','Oxfordshire','UNITED KINGDOM','OX251TE','07773547607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 10:46:53',0,NULL,3,1,2,1,NULL,'russetsprint'),(13041,738608053002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','aspasia1310','aspasia@fastwebnet.it','Federica Cioccoloni','via Casale Radicelli, 67','Roma','Roma','ITALY','00134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 11:10:42',0,NULL,3,1,3,1,'RA183619636CN\r ','aspasia1310\rlight stand $15'),(13042,698072855018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','michf1977','michelle.f.schofield@gmail.com','Michelle Schofield','306 Canterbury Road','St Kilda West','Victoria','AUSTRALIA','3182','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-14 11:13:37',0,NULL,3,1,4,1,'YW866475864CN ','michf1977\rbackground support $20\r'),(13043,739275914002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','john_imagczar','info@onthespotphotography.com','On The Spot, Inc. Photography','PO Box 1268<br>4 Mad River Road','Campton','NH','UNITED STATES','03223-1268','(603) 726-8879','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-14 11:39:01',0,NULL,3,1,1,1,NULL,'john_imagczar'),(13044,698091174018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','rayya21','la_ela21@yahoo.com','laela nurbatra','1/ 32 Harbourne road','kingsford','New South Wales','AUSTRALIA','2032','0430292177','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 12:21:36',0,NULL,3,1,2,1,NULL,'rayya21'),(13045,752674026017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','envkhoatv','nvkhoatv@gmail.com','Vinh Khoa Nguyen','603/361 Sussex street','Sydney','New South Wales','AUSTRALIA','2000','610423325352','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 12:25:37',0,NULL,3,1,2,1,NULL,'envkhoatv'),(13046,698094099018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',255,'photographyacc','fede-p','federicopacini@hotmail.it','Federico Pacini','Via del ginepro 13<br>Monteriggioni','Siena','SI','ITALY','53035','338 9589900','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 12:31:34',0,NULL,3,1,4,1,'YW866475875CN ','fede-p\r2m灯架   3\r反光板支架   1\r50-70 单灯头棚   2  欧标\r115w 220v   2\r包  1\r1.6m 宽 背景架   1\r1.6x2.1 背景布  白色    1\rlighting kit  $35\r\r'),(13047,739292029002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','crescenttrader','reubenpinkney@mac.com','Reuben Pinkney','7 Stevens Crescent','Bristol','Avon','UNITED KINGDOM','BS3 4UL','01179830222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:42:08',0,NULL,3,1,3,1,'RA183619622CN\r ','crescenttrader'),(13048,739259599002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','xbs53','muranag@virgilio.it','giuseppe murana','cortile valentino 18','mussomeli','Caltanissetta','ITALY','93014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:44:56',0,NULL,3,1,17,0,NULL,'xbs53'),(13049,739258051002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','xbs53','muranag@virgilio.it','giuseppe murana','cortile valentino 18','mussomeli','Caltanissetta','ITALY','93014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:44:57',0,NULL,3,1,17,0,NULL,'xbs53'),(13050,697798150001,110414160576,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',5.67,'hermeshine','xbs53','muranag@virgilio.it','giuseppe murana','cortile valentino 18','mussomeli','Caltanissetta','ITALY','93014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:44:59',0,NULL,3,1,17,0,NULL,'xbs53'),(13051,697799915001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','xbs53','muranag@virgilio.it','giuseppe murana','cortile valentino 18','mussomeli','Caltanissetta','ITALY','93014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:44:58',0,NULL,3,1,3,1,'RA183619565CN\r ','xbs53\r大号内胆包 无字   1\r绿叶 CPL  67mm    1\r绿叶 CPL  62mm    1\r橡胶遮光罩 58mm   1\rphoto accessories  $15'),(13052,739294256002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','ramsayfawell','ramsayfawell@yahoo.co.uk','drf photographic','45 Thornleigh Gardens','bangor','Down','UNITED KINGDOM','BT20 4NW','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-14 12:51:05',0,NULL,3,0,3,1,'RA183619653CN\r ','ramsayfawell\rXL  (已入库）'),(13053,697835992001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',2,'AA3222',91.8,'hermeshine','fgm230309','fgmbarrancs@hotmail.com','FRANC GIMENEZ MUÑOZ','CALLE TEIXIDOR , 13 (POL.INDUSTRIAL HORTES DEL CAMI RAL)','MATARO','Cataluña','SPAIN','08302','696372063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 12:54:27',0,NULL,3,1,3,1,'RA183619755CN\r ','fgm230309\r注意是2个'),(13054,697844196001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','4rcizio','digitaldiviso@gmail.com','Fabrizio Amici co FER','san donato 25','bologna','BO','ITALY','40127','3357320470','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-14 13:23:14',0,NULL,3,0,3,1,'RA183615152CN ','4rcizio\r发货后通知一下他tracking#.'),(13055,739314622002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','vhsmnd','vhsmendonca@gmail.com','Vitor Mendonça','Caminho Santo Amaro Apartamentos Santo Amaro Bloco L nº5','Funchal','Madeira','PORTUGAL','9020-121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 14:04:29',0,NULL,3,1,4,1,'YW866475886CN ','vhsmnd\rtripod $22'),(13056,818466436015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.4,'hutongstore','klausbach1684','mail@klausbach.com','Klaus Bach Web and Graphics','Kongensgade 68, 1.','Odense C','Syddanmark','DENMARK','5000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-14 14:18:58',0,NULL,3,1,2,1,NULL,'klausbach1684'),(13057,696226707018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','2007coia','roar5@bigpond.com','Robert Coia','45 Hobbs stree<br>Seddon','Melbourne','Victoria','AUSTRALIA','3011','030408257754','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 14:22:53',0,NULL,3,1,2,1,' ','2007coia\r新款的类似b座的那个，找不到我来吧'),(13058,698139596018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','rider_86','elkineb@mail.ru','Evgeny Elkin','14-15-25','Nefteugansk','HMAO-UGRA','RUSSIAN FEDERATION','628311','89129056629','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 15:06:45',0,NULL,3,1,3,1,'RA183619640CN\r ','rider_86\rReflector  $8'),(13059,739334435002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','agneaa','dimf@inbox.lv','Evita Dansone','Baznicas street 7-1','Tukums','','LATVIA','3101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 15:24:49',0,NULL,3,1,2,1,NULL,'agneaa'),(13060,739343674002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','nabeelbilo','nabilbilo2004@hotmail.com','Nabil Kasir','Cilicon Oasis','Dubai','Dubai','UNITED ARAB EMIRATES','55320','050 843 76 83','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 15:41:35',0,NULL,3,1,2,1,NULL,'nabeelbilo'),(13061,818524195015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','tomhstewart','thomastewart@btopenworld.com','thomas stewart','7 Walker street','burton on trent','Staffordshire','UNITED KINGDOM','DE14 3PZ','01283563432','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 16:41:07',0,NULL,3,1,2,1,NULL,'tomhstewart'),(13062,739380994002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','joao_guarapari','srjoao@terra.com.br','João Batista Assis de Oliveira','Rua Cachoeiro de Itapemirim, nº 243<br>Belo Horizonte (Meaipe)','Guarapari','Espirito Santo','BRAZIL','29208-230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 17:27:25',0,NULL,3,1,3,1,'RA183619698CN\r ','joao_guarapari\r110v'),(13063,698205375018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',6.6,'photographyacc','joerierave','joerie@duzl.com','Joerie Rave','schoolmeesterstraat 72','Amsterdam','','NETHERLANDS','1053 MC','0641035443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 18:02:58',0,NULL,3,1,2,1,NULL,'joerierave'),(13064,801633800016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',6.5,'hutongstore','alcasvi','alcasvi@gmail.com','CASTOR VIDAL MARTINEZ','CARMEN CONDE, 44 6º D','CARTAGENA','Murcia','SPAIN','30204','609943347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-14 18:12:02',0,NULL,3,1,2,1,NULL,'alcasvi'),(13065,739385057002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','dima_kovalevskiy','dkov@mail.ru','Kovalevskiy Dmitriy','Istomina 29-1a','Sevastopol','Krymea','UKRAINE','99012','+380684681444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 18:31:37',0,NULL,3,1,2,1,NULL,'dima_kovalevskiy'),(13066,739412944002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','garik1002_70','evg.gusin@gmail.com','gregori gusin','a.h.silver 12 /4','haifa','','ISRAEL','32694','0526077923','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 18:43:57',0,NULL,3,1,2,1,NULL,'garik1002_70'),(13067,697952949001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',28.95,'hermeshine','satyricaa','satyrica_@hotmail.com','Malin Brady','Flaten 15','Stord','Hordaland','NORWAY','5412','004790083198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 18:49:17',0,NULL,3,1,3,1,'RA183619619CN\r ','satyricaa'),(13068,752822248017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','roger6535','wairog@hotmail.com','Roger Wainohu','PO Box 416<br>Beechboro','Perth','Western Australia','AUSTRALIA','6063','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 19:07:38',0,NULL,3,1,2,1,NULL,'roger6535'),(13069,697974300001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','forgeronio','big.tauren@gmail.com','Anton Kovalenko','Geroev Stalingrada str.  14b,  apt.57','Kiev','','UKRAINE','04210','+380632324363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 19:36:38',0,NULL,3,1,2,1,NULL,'forgeronio'),(13070,697975364001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',8.9,'hermeshine','yarostpost-i','verach@yandex.ru','Alexey Cheremisin','building № 16<br>flat №53','Naro-Fominsky district, Kievskiy City','RU','RUSSIAN FEDERATION','143381','79262168801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 19:39:01',0,NULL,3,1,2,1,NULL,'yarostpost-i'),(13071,698252598018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','mantas90','m90trash@gmail.com','Mantas Kilius','Eitkunu 7 - 17','Kaunas','','LITHUANIA','48188','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-14 19:44:58',0,NULL,3,1,2,1,NULL,'mantas90'),(13072,697992673001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','snorrebd','snober@me.com','Snorre Berg-Domaas','Myrstubben 11','Ski','Akershus','NORWAY','1406','+4797696905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 20:18:10',0,NULL,3,1,2,1,NULL,'snorrebd'),(13073,698008076001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',2,'AO0015',15.8,'hermeshine','zanmorogr','zanmoro@yahoo.gr','GIANNIS EGGLEZOS','GRIGORIOU E\' 48','MAROUSI','ATTIKI','GREECE','151 22','210 6141637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 20:58:18',0,NULL,3,1,2,1,NULL,'zanmorogr'),(13074,698010996001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','ferroff','osip@lipetsk.ru','Ogryzkov Pavel Sergeevich','ul. Tolstogo, d. 40, office 114','Lipetsk','Lipetskaya obl','RUSSIAN FEDERATION','398001','(910) 739 - 7000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-14 21:08:01',0,NULL,3,1,2,1,NULL,'ferroff'),(13075,698311163018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','justletgo_1','urbanmedia_83@hotmail.com','Troy Meehan','21 green Tce','Windsor','Queensland','AUSTRALIA','4030','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 22:11:58',0,NULL,3,1,3,1,'RA183619684CN\r ','justletgo_1'),(13076,818697448015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','lyceumleary','kleary@blueyonder.co.uk','k leary','106 Clerwood Park','Edinburgh','Edinburgh City','UNITED KINGDOM','EH12 8PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-14 22:23:57',0,NULL,3,1,2,1,NULL,'lyceumleary'),(13077,698284539018,280680844025,'YongNuo Studio Flash Trigger CTR-301P Two Receivers',1,'AKT001',48,'photographyacc','zmago1','zmago@optusnet.com.au','David Mohorko','ACMI - Federation Square Loading Dock<br>Batman Ave','Melbourne','Victoria','AUSTRALIA','3000','0421214667','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-14 23:21:01',0,NULL,3,1,3,1,'RA183619667CN\r ','zmago1'),(13078,698047103001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','img4508','beautifulmarci@yahoo.com','Marci Gebhardt','304 Abingdon Ct','O Fallon','MO','UNITED STATES','63368-6781','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-14 23:31:33',0,NULL,3,1,1,1,NULL,'img4508'),(13079,752927793017,270767170462,'100% Cotton Photo Vest for Sony a200 a300 a700 a900user',1,'AA2113',40,'photographyacc','mmarufo1974','mmarufo@fibertel.com.ar','Martin Marufo','Murature 5326','Capital Federal','Buenos Aires','ARGENTINA','1407','46836985','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 01:08:48',0,NULL,3,0,3,1,'RA183619741CN\r ','mmarufo1974\r摄影背心 黑色厚 sony     3XL     1(已入库)'),(13080,697526439001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','450_trudeau','alaintrudeau07@videotron.ca','alain trudeau','790 rue beauvais','contrecoeur','QC','CANADA','j0L 1C0','(450) 573-0522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 02:04:25',0,NULL,3,1,2,1,' ','450_trudeau'),(13081,739559013002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','mohfotos1o1','mohfotos@gmail.com','Mohammed Al Rabaan','3030 Dunvale Rd<br>Apt 4107','Houston','TX','UNITED STATES','77063-4459','(541) 908-5046','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 02:36:32',0,NULL,3,1,3,1,'RA183619707CN\r ','mohfotos1o1'),(13082,698092186001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','ngedik','nurettingedik@gmail.com','Nurettin Gedik','Hamidiye Mh.Anadolu Cd. Kafkas Sk. Göksu Blokları<br>D blok Daire 4 ','Istanbul','Kagithane','TURKEY','34408','+905359271827','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 02:40:54',0,NULL,3,1,5,1,'CP227165729CN ','ngedik\r背景布 颜色: 白 / 黑'),(13083,698379404018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',2,'AC2401',44,'photographyacc','myebony','s.willis56@bigpond.com','Sharyn Willis','CatholicCare     Level 2<br>45 - 47 Scott Street','Liverpool','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 03:09:46',0,NULL,3,1,3,1,'RA183619675CN\r ','myebony'),(13084,698115181001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','tblainaz','tblainaz@aol.com','Steve Blain','33360 N Windmill Run','Queen Creek','AZ','UNITED STATES','85142-4606','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 04:53:22',0,NULL,3,1,1,1,NULL,'tblainaz'),(13085,739586440002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','blowry11','brittanyd.curry@gmail.com','brittany lowry','1526 st george rd','lethbridge','AB','CANADA','t1h 5a1','(403) 715-2324','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 05:16:38',0,NULL,3,1,2,1,NULL,'blowry11'),(13086,753009830017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',1,'AB2401',10.9,'photographyacc','an66k','kal6@freemail.hu','Aniko Meszaros','702 Old Cleveland rd East','Wellington Point','Queensland','AUSTRALIA','4160','0738224020','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 06:08:03',0,NULL,3,1,2,1,NULL,'an66k'),(13087,698415762018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','evets','s_t_e_v_e_h@hotmail.com','Stephen Hurne','203 Park St','South Melbourne','Victoria','AUSTRALIA','3205','0431600170','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 06:38:41',0,NULL,3,1,2,1,NULL,'evets'),(13088,698133665001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','alientrueogre','massimo.gasperini@tin.it','Massimo Gasperini presso Fondiaria-SAI Assicurazioni','Via Lorenzo il Magnifico, 1','Firenze','FI','ITALY','50129','3357706743','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 06:47:17',0,NULL,3,1,2,1,NULL,'alientrueogre'),(13089,698134209001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',38.5,'hermeshine','apavmeruna','apav66@yahoo.com','Helen Pavlova','str. She`erit Haplita 1<br>box 55907','Haifa','Israel','ISRAEL','34987','(972) 544 408991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 06:50:27',0,NULL,3,1,3,1,'RA183619809CN\r ','apavmeruna'),(13090,739605325002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','deck_uk','r_decoy@yahoo.com','Dexter Ramos','3663 Crowley Drive<br>Unit 416','Vancouver','BC','CANADA','V5R 6H4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 07:03:14',0,NULL,3,1,2,1,NULL,'deck_uk'),(13091,693389866001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','kykypy3a','og_go@mail.ru','Artyom Komsyukov','Gnarovskoi 8/1-17','Tyumen','Tyumen region','RUSSIAN FEDERATION','625000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 08:05:56',0,NULL,3,1,2,1,NULL,'kykypy3a'),(13092,818844988015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','winserselling','webwinser@gmail.com','Mr.Chaiwat Phanas','899/90 Punnawithi46 Soi. Sukhumvit101 Rd. Bangjak. Prakanong.','Bangkok','TX','THAILAND','10260','66877035035','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 08:14:02',0,NULL,3,1,11,1,NULL,'winserselling'),(13093,698437747018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','cannonbar61','rufies@bigpond.net.au','Stuart Rufus','PO Box 20','Nyngan','New South Wales','AUSTRALIA','2825','0268321159','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-15 08:27:36',0,NULL,3,1,4,1,'YW866475842CN ','cannonbar61\rbackground support $25\r'),(13094,697631668001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','tolokonov','asenna@mail.ru','Dmytro Tolokonov','4A Onore de Balzak Str., app. 146','Kiev','','UKRAINE','02225','380675097827','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 08:39:31',0,NULL,3,1,3,1,'RA183619772CN ','tolokonov'),(13095,739631529002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','alejinad','danijela@studioblacknwhite.com','Danijela Micanovic','Agiou Demetriou 5, flat 401<br>1035 Paluriotisa','Nicosia','Cyprus','CYPRUS','1035','+ 357 99 645 220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 09:15:35',0,NULL,3,1,3,1,'RA183619980CN\r ','alejinad'),(13096,747860124017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','illusivekahlia','illusivebeauty@live.com.au','Kahlia Vrbatovic','0ffice 3, 80 sturt street','adelaide','South Australia','AUSTRALIA','5000','0882945004','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-15 10:41:50',0,NULL,3,1,4,1,'YW866475820CN ','illusivekahlia\r澳标\r'),(13097,698474535018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',54,'photographyacc','retro_cloud','jim@retrocloud.com.au','Jim Kourkoulakos','160 Elm Street','Northcote','Victoria','AUSTRALIA','3070','0403495619','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 11:03:59',0,NULL,3,1,3,1,'RA183619812CN\r ','retro_cloud\r6个'),(13098,698199090001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','buffypetita','arkanusradio@gmail.com','Daniel Ruiz Torra','C/ Doctor Robert 1, A1','Santa Coloma de Farners','Cataluña','SPAIN','17430','656836816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 11:56:52',0,NULL,3,1,2,1,NULL,'buffypetita'),(13099,753091013017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',40.7,'photographyacc','berndkorteling','bkorteling@gmail.com','Bernd Korteling','Oude Langendijk 8','Delft','','NETHERLANDS','2611GK','0652350443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 12:08:30',0,NULL,3,1,3,1,'RA183619905CN\r ','berndkorteling\r天涯方形滤镜系列  CPL   1\r49, 52, 55, 58, 62, 67, 72, 77, 82 接口环   1套\r普通滤镜托架  1   \r广角滤镜托架  1\r\r'),(13100,739674470002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',64,'hermeshine','fredodf','snowflakeandmc@hotmail.com','L Alfredo Gayou Perez','Amsterdam 55 - 501<br>col Hipodromo Condesa','Mexico','Distrito Federal','MEXICO','06100','52-86-91-39','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 12:24:21',0,NULL,3,0,3,1,'RA183619891CN\r ','fredodf\r灯泡是110v的'),(13101,698071369018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',3,'AA3315',38.4,'photographyacc','petrs4321','freedomphoto@email.cz','Petr Svoboda','Palachova 425/22<br>tel.: 608177730','Poděbrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 12:33:53',0,NULL,3,1,3,1,'RA183619888CN ','petrs4321\r58mm  渐变镜   3\r52mm 渐变镜    3'),(13102,698506546018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',39.8,'photographyacc','adamtyp1','giant@epf.pl','Adam  Kolodziej','Kanonierow 6/1 , Krakow, Poland','krakow, poland','małopolskie','POLAND','31-432','507 251615','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 13:03:15',0,NULL,3,1,3,1,'RA183614090CN ','adamtyp1\r-----\r新地址:\rADAM KOLODZIEJ\rKANONIEROW 6/1 31-432 \rKRAKOW \rPOLAND\r507 251615'),(13103,801866763016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','krotosz3630','krotosz@citromail.hu','Racz Gabor','Banyasz ter 3. 4/1.','Putnok','','HUNGARY','3630','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 13:04:13',0,NULL,3,1,2,1,NULL,'krotosz3630'),(13104,698216836001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jay11j11','j11jay@hotmail.com','Johnson Gabriel','132 Child St','Hyde Park','MA','UNITED STATES','02136-1717','(617) 407-1329','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 13:06:18',0,NULL,3,0,1,1,' ','jay11j11\r1.6x2.1  黑色'),(13105,694886592001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ulomogahi','clarence_thw@hotmail.com','peida wu','1 west st','sydney','NS','CANADA','B1N 1R6','(902) 537-1567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 13:36:41',0,NULL,3,1,2,1,NULL,'ulomogahi'),(13106,818949064015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','efegete','sapi3ns@yahoo.es','Fernando Gago','Pablo Ruiz Picasso, local 2<br>Laboratorio dental','Esplugues de Llobregat (Barcelona)','Cataluña','SPAIN','08840','663050890','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-15 13:46:39',0,NULL,3,1,3,1,'RA183619914CN\r ','efegete'),(13107,818958325015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','missymisk','mn79@msn.com','Mrs Michelle Nolan','12 Meteor Way','Wallington','Surrey','UNITED KINGDOM','SM6 9JH','07702106946','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 14:15:12',0,NULL,3,1,2,1,NULL,'missymisk'),(13108,753132063017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',2,'AB2401',21.8,'photographyacc','jnrfic','biggestwog@hotmail.com','Daniel Ficco','18 Hazel Drive','Templestowe Lower','Victoria','AUSTRALIA','3107','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 14:22:02',0,NULL,5,0,18,0,NULL,'jnrfic\r----------\r新地址:\rDaniel Ficco\r11 Lawsons Court Templestowe 3106 \rMelbourne Victoria\rAUSTRALIA\r'),(13109,739709024002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',22.9,'hermeshine','gustavasco','pkleffmann@web.de','Peter Kleffmann','Friedensallee 30','Birkenwerder','','GERMANY','16547','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 14:22:17',0,NULL,3,1,3,1,'RA183619843CN ','gustavasco'),(13110,698242149001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','maad1346','ma-aad@hotmail.com','Ma aad Mohamed','Conrad Maldives Rangali Island<br>PO BOX 2034','South Ari Atoll','Rangali Island','MALDIVES','2034','(960) 778 1653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-15 14:37:28',0,NULL,5,0,18,0,NULL,'maad1346'),(13111,818984455015,250693977228,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',16.8,'hutongstore','prolinebike','jp.gudgeon@hotmail.co.uk','paul gudgeon','25 burns avenue','muirkirk','East Ayrshire','UNITED KINGDOM','ka183rh','01290660324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 15:17:01',0,NULL,3,0,3,1,'RA183614395CN ','prolinebike\r发货后通知他tracking#!'),(13112,698576370018,280675916322,'TianYa Gradual Brown tobacco Colour Filter for Cokin P',1,'AA2321',7.29,'photographyacc','kgurner70','trevor5057@hotmail.com','katreina gurner','38 nelson street','Nambucca Heads','New South Wales','AUSTRALIA','2448','0265685162','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 16:35:22',0,NULL,3,0,17,0,NULL,'kgurner70'),(13113,698280884001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','paltro1965','paltro2@infinito.it','ALESSANDRO PALTRINIERI','VIA COLAGRANDE 35','FERRARA','FE','ITALY','44100','333-3609600','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 16:40:17',0,NULL,3,0,3,1,'RA183619865CN\r ','paltro1965\rXXXL  (已入库）\r申报: Vest, $15'),(13114,753181112017,270748510647,'NIB TianYa Gradual Blue Color Filter for Cokin P series',1,'AA2320',7.29,'photographyacc','kgurner70','trevor5057@hotmail.com','katreina gurner','38 nelson street','Nambucca Heads','New South Wales','AUSTRALIA','2448','0265685162','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 16:40:31',0,NULL,3,1,2,1,NULL,'kgurner70\r天涯方形滤镜  渐变蓝   1\r天涯方形滤镜  渐变棕   1'),(13115,753187143017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',5.66,'photographyacc','adonaz01','adolfo_nazario@hotmail.com','Adolfo Nazario','5/6 Hale road Mosman','Sydney','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 16:56:30',0,NULL,3,1,17,0,NULL,'adonaz01'),(13116,698585558018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','adonaz01','adolfo_nazario@hotmail.com','Adolfo Nazario','5/6 Hale road Mosman','Sydney','New South Wales','AUSTRALIA','2088','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-15 17:00:09',0,NULL,3,1,2,1,NULL,'adonaz01\r橡胶遮光罩 52mm   1\rMini 红外  canon    1'),(13117,739773773002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 17:37:34',0,NULL,3,1,3,1,'RA183619993CN\r ','mariomarques.com.br'),(13118,819101474015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','igonine29','igonine@gmail.com','João Ferreira','Rua Aldeia do Ribatejo, º29','Riachos','Santarem','PORTUGAL','2350-333','913026044','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 19:26:48',0,NULL,3,1,2,1,NULL,'igonine29'),(13119,819103360015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','williamsj3011972','jason1972_uk@yahoo.co.uk','jason schrompf','9 willow garth close','leeds','West Yorkshire','UNITED KINGDOM','ls14 2eb','01132323304','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 19:29:49',0,NULL,3,1,2,1,' ','williamsj3011972'),(13120,739827374002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','infinateliz','hotshotzphotography@gmail.com','Brendan Power','No 6 Leonards Court<br>dunnamaggan','kilkenny','Kilkenny','IRELAND','','0876846095','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-15 20:05:30',0,NULL,3,1,3,1,'RA183619830CN\r ','infinateliz\rm'),(13121,698661966018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','mantferv','mantferv@yahoo.com.br','Marcos Ferreira Vital','Neptunstrasse 42','Zürich','','SWITZERLAND','8032','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-15 20:11:35',0,NULL,3,1,3,1,'RA183617842CN\r','mantferv\r欧标\rlighting kit  $35\rYW866475794CN    CP227166738CN\r有一个灯泡不亮，再发一个\r115w 220v   1  （已减库）'),(13122,698681652018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','dor0910','dornevo1@gmail.com','dor nevo','rupin 32 b<br>32 b','tel aviv','tel aviv','ISRAEL','63457','00972544792330','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-15 20:58:57',0,NULL,3,1,2,1,NULL,'dor0910'),(13123,739874848002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','romagnamia','bunkrossi@earthlink.net','Alessandro Rossi','5875 Lorraine Ct','Sacramento','CA','UNITED STATES','95817-1755','(916) 736-1902','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-15 22:08:49',0,NULL,3,1,3,1,'RA183619976CN ','romagnamia'),(13124,819186147015,250627432317,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',16.99,'hutongstore','jennysjellybelly','jennygreenphotography@gmail.com','Jenny Green','184 Cobden View Road<br>Crookes','Sheffield','S Yorks','UNITED KINGDOM','S10 1HT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-15 22:44:04',0,NULL,3,1,2,1,NULL,'jennysjellybelly'),(13125,819200029015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','bricaral','bricaral@hotmail.com','brian carmona alberca','el girones num.20 bajos primera','S\'Agaró','Girona','SPAIN','17248','666093823','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-15 23:31:30',0,NULL,3,1,2,1,NULL,'bricaral'),(13126,698430338001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','ridinfaster','drvnfast@gmail.com','Brian Rose','1311 Town Colony Dr','Middletown','CT','UNITED STATES','06457-5935','(303) 503-3472','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-16 00:31:01',0,NULL,3,1,1,1,NULL,'ridinfaster'),(13127,698753925018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','drenty1','iandrent@virginbroadband.com.au','Ian Drent','18 Tilanus St','Heatley','Queensland','AUSTRALIA','4814','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 01:50:48',0,NULL,3,1,2,1,NULL,'drenty1'),(13128,753369846017,270744174175,'62mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT021',4.19,'photographyacc','evxaya888','bettymatt@iprimus.com.au','matthew cardinal','11 creekview way','wyndhamvale- west melbourne','Victoria','AUSTRALIA','3024','0397311841','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 02:15:24',0,NULL,3,1,2,1,NULL,'evxaya888'),(13129,698771181018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',6.6,'photographyacc','hg102','russdarr@msn.com','Russ Darr','1618 EVERGREEN PARK LN SW','OLYMPIA','WA','UNITED STATES','98502','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 03:23:04',0,NULL,3,1,1,1,NULL,'hg102'),(13130,753386458017,270750669406,'Brand New Original Pro Nikon 90th Anniversary Lens case',1,'AB2401',10.9,'photographyacc','coling45','coling7@me.com','Colin Garside','22/31 Langport Parade','Mudgeeraba','Queensland','AUSTRALIA','4213','0755306809','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 03:40:49',0,NULL,5,1,18,1,' ','coling45'),(13131,753394466017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','ijchua','ivan.j.chua@gmail.com','Ivan Chua','Level 28<br>275 Kent Street','Sydney','New South Wales','AUSTRALIA','2000','0422868118','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 04:26:57',0,NULL,3,1,2,1,NULL,'ijchua'),(13132,753350330017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',2,'AA1306',10.8,'photographyacc','kynansdad','sod382@hotmail.com','SGT S. Davies','Invst Trg Sect, PTW, DPTC<br>Lamia Bks, Greenhills Rd','Holsworthy','New South Wales','AUSTRALIA','2173','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 06:41:45',0,NULL,3,1,2,1,NULL,'kynansdad\r热靴水平仪   2\rNIKON 镜头盖 62mm   2\r'),(13133,698807411018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',6.6,'photographyacc','helwa2','sylvass@iprimus.com.au','Sylvana Vassallo','c/- Unit 1, 5-9 Ricketty St','Mascot','New South Wales','AUSTRALIA','2020','0297598992','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 07:02:47',0,NULL,3,1,2,1,NULL,'helwa2'),(13134,698810269018,280683088500,'Mini IR Wireless Remote Control for Pentax 200D 10D 20D',1,'AD1118',4.5,'photographyacc','rmercs','rmercs@optusnet.com.au','Rodolfo Mercado','18 Ferguson Circuit','Ngunnawal','Australian Capital Territory','AUSTRALIA','2913','0413388420','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-16 07:17:08',0,NULL,3,1,2,1,NULL,'rmercs'),(13135,698810494018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','imadazmat','imad_hunter@hotmail.com','Imad Azmat','2/56<br>Middle Street','Kingsford','New South Wales','AUSTRALIA','2032','0415507818','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-16 07:18:19',0,NULL,3,1,2,1,NULL,'imadazmat'),(13136,819318986015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.48,'hutongstore','langemand69','langem@live.dk','michael bentsen','jyllingevej 23 3 tv','kopenhagen','vanløse','DENMARK','2720','+4540511784','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-16 08:18:39',0,NULL,3,1,2,1,NULL,'langemand69'),(13137,753440195017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','zmago1','zmago@optusnet.com.au','David Mohorko','ACMI - Federation Square Loading Dock<br>Batman Ave','Melbourne','Victoria','AUSTRALIA','3000','0421214667','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 08:31:36',0,NULL,3,1,2,1,NULL,'zmago1'),(13138,819323251015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','greenlittlealien','tomasz_wwa@wp.pl','Pawel Tomaszewicz','35 Hamilton Road - Flat 1<br>Boscombe','Bournemouth','Dorset','UNITED KINGDOM','BH1 4EQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-16 08:37:00',0,NULL,3,1,3,1,'RA183620002CN\r ','greenlittlealien'),(13139,698829954018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','donovanhenry','d.henry@chesterhouse.co.za','Donovan Henry','58 Disa crescent<br>Sandrift','Cape Town','Cape Town','SOUTH AFRICA','7441','0824958115','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 08:44:43',0,NULL,3,1,3,1,'RA183614109CN\r ','donovanhenry'),(13140,819335504015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','george42310','galord2004@yahoo.com','Georgios Lordos','5,Karaiskaki str.<br>Strovolos','Nicosia','NIC','CYPRUS','2012','35722498010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-16 09:21:52',0,NULL,3,1,2,1,NULL,'george42310'),(13141,698533701001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',22.8,'hermeshine','joe_bermejales','jose_inesta@hotmail.com','Jose Inesta Vaquera','Avalos, 15','Llerena','Extremadura','SPAIN','06900','620180736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:14:08',0,NULL,3,1,17,0,NULL,'joe_bermejales'),(13142,698533719001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','joe_bermejales','jose_inesta@hotmail.com','Jose Inesta Vaquera','Avalos, 15','Llerena','Extremadura','SPAIN','06900','620180736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:14:09',0,NULL,3,1,17,0,NULL,'joe_bermejales'),(13143,740013609002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','joe_bermejales','jose_inesta@hotmail.com','Jose Inesta Vaquera','Avalos, 15','Llerena','Extremadura','SPAIN','06900','620180736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:14:08',0,NULL,3,1,3,1,'RA183619874CN ','joe_bermejales\rEW-73B    1\r天涯方形滤镜   ND2      1\r天涯方形滤镜   ND4      1\r天涯方形滤镜   ND8      1\r天涯方形渐变灰    1\r67mm转接环   1\r77mm转接环   1\r普通托架       2\r'),(13144,740018287002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',5.99,'hermeshine','caddybaron','caddy@cadillac.cz','Radek Benes','Lonkova 490','Pardubice','Europe','CZECH REPUBLIC','530 09','(00420) 777 - 236699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:17:07',0,NULL,3,1,2,1,NULL,'caddybaron'),(13145,698855025018,280670190865,'Green.L Premium Quality 72mm CPL Circular Polarizer New',1,'AA3313',7.2,'photographyacc','hbkiran44','hbkiran@hotmail.com','Ahmet Ünver','Fuzuli cad.Budak Apt.No:51','Malatya','','TURKEY','44000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 10:22:08',0,NULL,3,1,2,1,NULL,'hbkiran44'),(13146,819357357015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',3,'AKT049',72,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-16 10:28:11',0,NULL,3,1,4,1,'YW866475805CN ','leifs123\r申报:　￡18\r燕文告诉这个没人领取   要我们联系客户或者打点好查询81000710    \r查询以收到'),(13147,740021317002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','aksenovks93','kit23rus@mail.ru','Kirill Aksenov','Яна-Полуяна 15/41<br>Yana-Poluyana 15/41','Krasnodar','Krasnodar region','RUSSIAN FEDERATION','350062','(918) 2171955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:28:42',0,NULL,3,1,2,1,NULL,'aksenovks93'),(13148,698215904001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.35,'hermeshine','aasa_bergem','aasa.bergem@gmail.com','Åsa bergem','Rathkesgate 9','Oslo','Oslo','NORWAY','0558','0047 40455770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 10:45:07',0,NULL,3,1,2,1,NULL,'aasa_bergem'),(13149,819379845015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','paulivarelius','pauli.varelius@gmail.com','Pauli Varelius','Takojantie 1L','Espoo','Uusimaa','FINLAND','02130','+358407383157','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-16 11:36:54',0,NULL,3,1,3,1,'RA183619962CN ','paulivarelius'),(13150,698878623018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','gezat','gtacovsky@gmail.com','Gerry Tacovsky','12 Clontarf Street','Seaforth','New South Wales','AUSTRALIA','2092','61299487377','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-16 11:47:48',0,NULL,3,1,4,1,'YW866475013CN','gezat\rBackdrop support  $25'),(13151,698566076001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','balx25','harald.balke@t-online.de','Harald Balke','am vechteufer 7','Nordhorn','','GERMANY','48529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 12:01:53',0,NULL,3,1,2,1,NULL,'balx25'),(13152,698891737018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','sanzco','sanzco.chiledigital@gmail.com','Patricio Sánchez Corral','Los Algarrobos 4335<br>Block H, Depto. 601 \"Altos del Dragón\"','Iquique','','CHILE','1100000','66580292','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 12:32:12',0,NULL,3,1,3,1,'RA183614015CN ','sanzco'),(13153,698573732001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',3.4,'hermeshine','mesjamam','rimvydui@gmail.com','Rimvydas J','Lauku 10-28','Palanga','Palanga','LITHUANIA','00108','37067281559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 12:55:50',0,NULL,3,1,2,1,NULL,'mesjamam'),(13154,697366694001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','vetrinista','angelocampeotto@tele2.it','Photo Fly  Fabrizio Campeotto','Centro Comm.EMISFERO   Via Pocar 1<br>34075','Monfalcone','Gorizia','ITALY','34075','0481-43123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 13:13:08',0,NULL,3,1,2,1,NULL,'vetrinista'),(13155,698589278001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',6.9,'hermeshine','chali_pilot','xali@netvisao.pt','João Chalaça','Rua Crónica Eborense, nº 25','Évora','Alentejo, Évora','PORTUGAL','7000-691','00351 962056216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 13:22:06',0,NULL,3,1,2,1,NULL,'chali_pilot'),(13156,698930843018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','may16478','shellmay@hotmail.com','Shelley Akers','204 Broughton Street','Tumut','New South Wales','AUSTRALIA','2720','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 14:32:06',0,NULL,3,1,3,1,'RA183619928CN\r ','may16478'),(13157,740104923002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dvchunter','dave.hunter@live.nl','Dave Hunter','Hillekensacker 1028','Nijmegen','','NETHERLANDS','6546KC','0626785074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-16 15:12:33',0,NULL,3,0,3,1,'RA183619959CN\r ','dvchunter\r3XL (已入库)'),(13158,819483385015,250615143331,'YongNuo Flash Battery Pack SF-17 for Nikon Flash SB800',1,'AB3315',28.99,'hutongstore','vpaiagua','fotoq.vpaiagua@gmail.com','Vitor Paiágua','Av. Ceuta C.C.Alsol loja 4','Quarteira','Algarve','PORTUGAL','8125-116','351289313489','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-16 15:54:50',0,NULL,3,1,3,1,'RA183619769CN ','vpaiagua'),(13159,819494165015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','delicious63r','gpacion@aol.com','mr g pacion','11 penyfan view','merthyr tydfil','merthyr tydfil','UNITED KINGDOM','cf47 9bx','01685386539','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-16 16:17:36',0,NULL,3,1,2,1,NULL,'delicious63r'),(13160,698974317018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','robertmason59','robertmasonthegreat@hotmail.com','Robert Mason','4/1 Acre Place','Malvern','Victoria','AUSTRALIA','3144','0439380444','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-16 16:42:42',0,NULL,3,1,2,1,NULL,'robertmason59'),(13161,802549288016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','vladek123','vladek@neti.ee','Wladek  Saar','Jarveotsa tee 13 - 93','Tallinn','Estonia','ESTONIA','13520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-16 17:06:16',0,NULL,3,1,2,1,NULL,'vladek123'),(13162,740191381002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','chaostensai','k.santrou@gmail.com','Kristian Santrou','Taygetou 22','Neo Irakleio','Athens','GREECE','14122','+306997055190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 18:52:45',0,NULL,3,1,2,1,NULL,'chaostensai'),(13163,740224328002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','sdthunder001','dr.steelhead@yahoo.com','David Burger','119 E Silver St','Reading','MI','UNITED STATES','49274-9102','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-16 20:13:05',0,NULL,3,1,1,1,NULL,'sdthunder001'),(13164,740227220002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','7777ewj','ewjohnson@clearwire.net','Eugene Johnson','556 Sunshine Acres Dr','Eugene','OR','UNITED STATES','97401-5707','(541) 510-7925','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-16 20:21:43',0,NULL,3,1,1,1,NULL,'7777ewj'),(13165,698746931001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','m7m77','mhmd.hirz@gmail.com','Mohammad Hirzallah','Dahiyat al Rasheed, Awzai St.<br>P.O. Box: 13651','Amman','Amman','JORDAN','11942','0788855715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 20:57:47',0,NULL,3,1,2,1,NULL,'m7m77'),(13166,699092009018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','izhak801izhak','izhak801@hotmail.com','izhak haime','aharoov 212/8','atlit','','ISRAEL','30300','00972506829988','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-16 21:15:07',0,NULL,3,1,2,1,' ','izhak801izhak'),(13167,802701586016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','grahamhi2009','higgins.graham@gmail.com','Graham Higgins','290b Burdett Road','Limehouse','London','UNITED KINGDOM','E14 7DQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-16 22:38:03',0,NULL,3,1,4,1,'YW866475024CN','grahamhi2009'),(13168,740285216002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','eyaluba','eyalaft@walla.com','eyal aftabi','moshe kahiri 352','beer seva','city beer seva','ISRAEL','48000','972502184826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-16 23:34:12',0,NULL,3,1,2,1,NULL,'eyaluba'),(13169,740289552002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','leogomes','leonardo@oficinadaimagem.com.br','Leonardo Gomes','Av. Erico Verissimo 730 / 103 - Barra da Tijuca','Rio de Janeiro','RJ','BRAZIL','22621-180','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-16 23:52:30',0,NULL,3,1,3,1,'RA183614041CN\r ','leogomes'),(13170,753789446017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','blacki_03','blacki_03@hotmail.com','Olivier  Blackburn','487 rue calvados','quebec','QC','CANADA','G2N 2B4','(604) 902-2542','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-17 01:58:58',0,NULL,3,1,2,1,NULL,'blacki_03'),(13171,698833336001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','cuwillia51','caw5115@hotmail.com','Curtis Williams','220 W 7th Ave<br>C/O Ottlite Technologies, Inc Ste 100','Tampa','FL','UNITED STATES','33602-2012','(813) 454-9691','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-17 02:24:12',0,NULL,3,1,3,1,'RA183619931CN\r ','cuwillia51'),(13172,698834618001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','debhub905','debanddavem@hotmail.com','Debbie Maglothin','905 1/2 S Madison St','Ludington','MI','UNITED STATES','49431-2531','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-17 02:31:10',0,NULL,3,1,1,1,NULL,'debhub905'),(13173,698843783001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','darkzero0914','darkzero5007@hotmail.com','Joseph Hernandez','9717 El Tepeyac Ave','El Paso','TX','UNITED STATES','79927','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-17 03:17:39',0,NULL,3,1,1,1,NULL,'darkzero0914'),(13174,753806079017,270744174175,'62mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT021',4.19,'photographyacc','shaung717','shaungoodall@bigpond.com','Shaun Goodall','29 Four Lanterns<br>1481 Camden Valley Way','Leppington','New South Wales','AUSTRALIA','2179','0417408012','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 03:20:48',0,NULL,3,1,2,1,NULL,'shaung717'),(13175,698859688001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mihaylovmihael','mishmu@gmail.com','Mihael Mihaylov','626 de l\'eglise','montreal','QC','CANADA','H4G 2M8','(514) 451-4508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 04:51:16',0,NULL,3,1,2,1,NULL,'mihaylovmihael'),(13176,740354770002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','hbaulderstone','hugh_baulderstone@hotmail.com','hugh baulderstone','23 pindari ave<br>mosman','syndey','New South Wales','AUSTRALIA','2088','0299698806','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 05:35:03',0,NULL,3,1,2,1,' ','hbaulderstone'),(13177,753832337017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','thepitt666','martinlange@gmail.com','Martin Lange','6/9 Bergin Street','Milton','Queensland','AUSTRALIA','4064','0430217621','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 05:48:14',0,NULL,3,1,2,1,' ','thepitt666\r-----\r新地址:\rMartin Lange\r153 boundary st.\rWest end.\r4101 Qld\rAUSTRALIA\r'),(13178,699208527018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','felix3154','fstaub@activ8.net.au','Felix Staub','71 Foreshore Road','Kelso','Tasmania','AUSTRALIA','7270','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 06:10:54',0,NULL,3,1,2,1,NULL,'felix3154'),(13179,740388002002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','lishakov','adrageron@gmail.com','Andrey Lishakov','Varnenskaya st. 13-35','Chelyabinsk','','RUSSIAN FEDERATION','454020','+7 (912) 779 - 6660','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 08:20:41',0,NULL,3,1,2,1,NULL,'lishakov'),(13180,819847773015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',2,'AA1306',3.76,'hutongstore','kohoa','kohoantti@gmail.com','Antti Koho','Kätönkuja 34','Kajaani','Kajaani','FINLAND','87250','+358456716268','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-17 09:29:04',0,NULL,3,1,2,1,NULL,'kohoa'),(13181,753909509017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','magentacrustacean','henry.cp.ellis@gmail.com','Henry Ellis','Level 2, 66 Rundle Street','Kent Town','South Australia','AUSTRALIA','5067','0422813582','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 10:30:01',0,NULL,3,1,2,1,NULL,'magentacrustacean'),(13182,753919917017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','jambostock2','admin@jambostock.com','Boris Lips  (+79222307330)','ul. Uralskaya, 17-20','OZERSK','Chelabinskaya obl','RUSSIAN FEDERATION','456780','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-17 10:53:24',0,NULL,3,1,2,1,NULL,'jambostock2'),(13183,740453877002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','alcasvi','alcasvi@gmail.com','CASTOR VIDAL MARTINEZ','CARMEN CONDE, 44 6º D','CARTAGENA','Murcia','SPAIN','30204','609943347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 11:31:14',0,NULL,3,1,2,1,NULL,'alcasvi'),(13184,819909606015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','toukatouka561','m4tehrani@gmail.com','Mansour S.Tehrani','24 Robinsone Road Mapperley Nottingham','Nottingham','Nottinghamshire','UNITED KINGDOM','NG3 6BB','01159605672','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 11:42:59',0,NULL,3,1,2,1,NULL,'toukatouka561'),(13185,699314112018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',6.6,'photographyacc','scottasmith_230','scottasmith230@ymail.com','Scott Smith','401 Highters Heath Lane<br>Maypole','Birmingham','West Midlands','UNITED KINGDOM','B14 4TR','01214307926','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-17 11:53:07',0,NULL,3,1,2,1,NULL,'scottasmith_230'),(13186,695806437001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','kellenartist','kathi170@aol.com','kathi weiss','3817 Sunbreeze Cir<br>Apt 326','roanoke','VA','UNITED STATES','24018-3171','(570) 406-2420','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-17 12:11:38',0,NULL,3,1,1,1,NULL,'kellenartist\r110v   '),(13187,753465812017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',2,'AB3321',33.98,'photographyacc','lizner','noodle_snacks@yahoo.com.au','JJ Harrison','12 Harbinger Lane Austins Ferry','Glenorchy','Tasmania','AUSTRALIA','7011','0362492352','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 12:18:28',0,NULL,3,1,3,1,'RA183619857CN ','lizner'),(13188,697864461001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','shlomidavid1962','sd2004@012.net.il','Shlomi David','19a Harakafot st.','Karmiel','IL','ISRAEL','20100','972546771485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 12:30:52',0,NULL,3,1,8,1,'CP227165715CN ','shlomidavid1962\r欧标 220v\r申报: $60 Lighting Kit '),(13189,698996857001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','intellica_ajp','anton@intellica.com.au','Anton Prange','35 Eric Road','Holland Park','Queensland','AUSTRALIA','4121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 12:58:27',0,NULL,3,1,4,1,'YW866475735CN ','intellica_ajp\r澳标\r反光伞 都换成 \"柔光伞\"!\rLighting Kit  $28'),(13190,819957509015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','geografas','julius.kielaitis@gmail.com','Julius Kielaitis','16 GLAMORGAN PLACE','MANCHESTER','Lancashire','UNITED KINGDOM','OL97ST','07586817530','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 13:18:08',0,NULL,3,1,2,1,NULL,'geografas'),(13191,740419734002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','be-grizzly01','roger_meyer@bluemail.ch','Roger Meyer','Postfach 643','Bern','','SWITZERLAND','CH - 3018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-17 13:30:47',0,NULL,3,0,17,0,' ','be-grizzly01'),(13192,698992942001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-17 13:46:42',0,NULL,3,1,17,0,NULL,'saud-p'),(13193,802994891016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','dolo1200','lisaladolo@hotmail.com','Lisala Dolo','27 Garnier Park<br>Wickham','Fareham','Hampshire','UNITED KINGDOM','PO17 5LD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 14:03:37',0,NULL,3,1,2,1,NULL,'dolo1200'),(13194,699025590001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',1,'AA3222',45.9,'hermeshine','isiman74','ismayilhk@gmail.com','Ismayil Kerimov','Tbilisi ave.1054','Baku','','AZERBAIJAN','Az-1122','+994503443351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 14:07:59',0,NULL,3,1,3,1,'RA183614381CN ','isiman74'),(13195,740518300002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','carvalho_ian','carvalho.i@gmail.com','Ian Carvalho','Rua Saldanha Marinho, 131, ap 1206<br>Centro','Niterói','Rio de Janeiro','BRAZIL','24030040','+552184444604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 14:11:16',0,NULL,3,1,2,1,NULL,'carvalho_ian'),(13196,740524584002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',2.75,'hermeshine','katrine280389','petrulius@hotmail.com','Katrine Immerstein Gilje','Sørlibakken 7b','Randaberg','Randaberg','NORWAY','4070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 14:25:20',0,NULL,3,1,2,1,NULL,'katrine280389'),(13197,753443343017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','vielmantech','mvielman@gmail.com','Melvin Vielman','10 Kingsgrove Ave','Kingsgrove','New South Wales','AUSTRALIA','2208','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 15:02:11',0,NULL,3,1,2,1,NULL,'vielmantech'),(13198,740561592002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cmiccarlos','cmic@idecnet.com','carlos dominguez santana','C/ camino de la cruz, 89 duplex E','Arucas','Canarias','SPAIN','35400','928603788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 15:39:47',0,NULL,3,1,2,1,NULL,'cmiccarlos'),(13199,820044331015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','xunetu70','xunetu@gmail.com','Julio Alvarez German','C/Emilio Alfaro Lapuerta Nº 7 3ºDcha.','Zaragoza','Aragón','SPAIN','50017','651976555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-17 15:42:03',0,NULL,3,1,2,1,NULL,'xunetu70'),(13200,698925677001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',2,'AC1204',15.8,'hermeshine','be-grizzly01','roger_meyer@bluemail.ch','Roger Meyer','Postfach 643','Bern','','SWITZERLAND','CH - 3018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 17:38:53',0,NULL,3,1,17,0,NULL,'be-grizzly01'),(13201,698924801001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',2,'AO0033',13.98,'hermeshine','be-grizzly01','roger_meyer@bluemail.ch','Roger Meyer','Postfach 643','Bern','','SWITZERLAND','CH - 3018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-17 17:42:18',0,NULL,3,1,3,1,'RA183614086CN ','be-grizzly01\rCanon 单肩包 小包 D2    2\r镜头筒 xl 大号    2\r摄影背心 Canon  老款    XL   1(已入库)\r'),(13202,802718165016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','larskristianskjetne','larserns@gmail.com','lars kristian skjetne','Industrigata 65 a','oslo','Norway','NORWAY','0357','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-17 17:56:55',0,NULL,3,1,3,1,'RA183619945CN\r ','larskristianskjetne'),(13203,740682872002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','css903','dfm@sscom.org','Daniel F. Morris','12203 11th PL NE','Lake Stevens','WA','UNITED STATES','98258','','NoPaymentFailure','CheckoutComplete','Other','2011-07-17 18:25:45',0,NULL,3,0,1,1,NULL,'css903\r摄影背心 Canon  老款    XL     1(已入库)'),(13204,699190100001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','alejo4d','alejandro_corona@hotmail.com','Hugo Alejandro Coronado','Rio Cachan # 12<br>Col. Melchor Ocampo','La Piedad','Michoacan','MEXICO','59375','+523525220093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 18:28:47',0,NULL,3,1,3,1,'RA183614024CN\r ','alejo4d'),(13205,740710725002,120593461312,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',55.99,'hermeshine','irfan88','irfaan_17@hotmail.com','Khodabukus Muhamed Irfaan','Middle Road','Plaine des Papayes','Indian Ocean','MAURITIUS','MU230','(230)2666380','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-17 19:01:07',0,NULL,3,1,3,1,'RA183614038CN ','irfan88'),(13206,740746645002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','rmshort1958','rmshortmd@hotmail.com','Ronald Mark Short','616 W Forest Ave','Jackson','TN','UNITED STATES','38301-3902','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-17 19:50:02',0,NULL,3,1,1,1,NULL,'rmshort1958'),(13207,699638615018,280680267419,'New Neoprene Camera Cover for Nikon D80 D5000 +18-55mm',1,'AC1305',9.99,'photographyacc','alim33','andrewlim333@gmail.com','Andrew Lim','12 Casson Place','Markham','ON','CANADA','L3R 0G2','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-17 20:31:35',0,NULL,3,1,2,1,NULL,'alim33'),(13208,699639095018,280666892339,'New Green.L 62mm  Gradual Grey ND4 Filter 2-Stop 62 mm',1,'AA3318',6.6,'photographyacc','taavos','taavo23@gmail.com','Taavo Soodla','Meeliku 24/4-253','Tallinn','Harjumaa','ESTONIA','13915','53024233','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-17 20:32:32',0,NULL,3,1,2,1,NULL,'taavos\r------\r新地址:\rTaavo Soodla\rHansu 34-5, 13523\rTallinn\rHarjumaa\rEstonia\r53024233'),(13209,740801195002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','georgino12345','juraj.steviar@centrum.sk','Filip Strnisko','Čulenova 88','Nitra','Svk','SLOVAK REPUBLIC','949 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 21:34:14',0,NULL,3,1,3,1,'RA183614055CN\r ','georgino12345\r欧标'),(13210,699313916001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-17 22:07:08',0,NULL,3,1,12,1,' BJ8824301','saud-p\r2mx3m 背景架   1 （夹子）\r2mx2m 背景架   1 （ 1.6x2.1 白色+ 黑色背景布） 夹子\r多发配件: 2m 灯架 底座     5\r再加两块1.6x2.1m  背景布, （白色+黑色）\r背景架2m x 3m + 3个夹子           1\r背景布 3x6黑色                   1\r灯架  2m             2 \r柔光箱 50-70cm 单灯头        2\r115w 5500k 灯泡  220v        2\r灯架包           1\r需要在灯架上贴made in china  包括背景架上的灯架\r3个 2m 灯架   \r3个 50-70 柔光棚  欧标   \r3个115w 220v \r1个斜臂\r包  1\rlighting kit   $350\r'),(13211,820361782015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','zirac','ariscanson@yahoo.com','Aristotle Canson','19 Balleigh Mews','Ramsey','Isle of Man','UNITED KINGDOM','IM8 3NW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-17 22:16:43',0,NULL,3,1,2,1,' ','zirac'),(13212,699331155001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','cibanezc','caribacal@gmail.com','Carlos J Ibañez Calleja','c/ Isla de Java, 76 Bajo C','Madrid','Madrid','SPAIN','28034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-17 22:54:23',0,NULL,3,1,2,1,NULL,'cibanezc'),(13213,754357601017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','elizabethrdl','elardl@hotmail.com','Elizabeth Sady','89 Arcadian Cct','Carlingford','New South Wales','AUSTRALIA','2118','02989039950298903995','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-17 23:44:10',0,NULL,3,1,2,1,' ','elizabethrdl'),(13214,699745110018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','borgs73','teamendeavor@yahoo.com.au','Peter Borgese','66 Jaffa Rd','Dural','New South Wales','AUSTRALIA','2158','0421566018','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 01:40:42',0,NULL,3,1,2,1,NULL,'borgs73'),(13215,699759652018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','picturethis!photography','picturethisphoto@attbi.com','John H. Havener, Jr.','2542 Clark Ave','Billings','MT','UNITED STATES','59102-3829','(406) 591-1641','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-18 02:32:02',0,NULL,3,1,1,1,NULL,'picturethis!photography'),(13216,699760621018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','bswhisson','b.whisson@labwest.net','Brad Whisson','28 Boulder Rd','Malaga','Western Australia','AUSTRALIA','6090','0892489321','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 02:35:19',0,NULL,3,1,2,1,NULL,'bswhisson'),(13217,699763026018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','leannejs81','leanne_smith81@hotmail.com','Leanne Smith','29 Filante Street','Kellyville Ridge','New South Wales','AUSTRALIA','2155','0412240410','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-18 02:45:24',0,NULL,3,1,4,1,'YW866475746CN ','leannejs81\r背景布 换成\"黑色\"的\rBackdrop support  $25\r2.938'),(13218,699400653001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',70,'hermeshine','ampfiler','bakken.hl@gmail.com','Haavard Bakken','Kastanjeveien 50','Drammen','europe','NORWAY','3026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 03:10:41',0,NULL,3,1,17,0,NULL,'ampfiler\r申报: Gift $25'),(13219,740919134002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',3,'AC2304',18.72,'hermeshine','sabri211277','sabrinalauracastro@hotmail.com','SABRINA CASTRO','HONDURAS 4059 dto 4','CIUDAD AUTONOMA DE BS AS','CAPITAL FEDERAL','ARGENTINA','1180','5411-4864-1145','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 04:23:18',0,NULL,3,1,2,1,' ','sabri211277'),(13220,740925042002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alexeyalexsor','aleks-sor@mail.ru','Sorokin Aleksey','Tryda prospekt  d.21,kv.31','Voronezh','','RUSSIAN FEDERATION','394061','+79081408919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 04:59:47',0,NULL,3,1,17,0,NULL,'alexeyalexsor'),(13221,740926326002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.15,'hermeshine','alexeyalexsor','aleks-sor@mail.ru','Sorokin Aleksey','Tryda prospekt  d.21,kv.31','Voronezh','','RUSSIAN FEDERATION','394061','+79081408919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 05:08:03',0,NULL,3,1,5,1,'CP227165701CN ','alexeyalexsor\r2B柔    2'),(13222,699796581018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sophiewhite*123','sporty_soph09@hotmail.com','Sophie White','PO box 261','Mossman','Queensland','AUSTRALIA','4873','0488786203','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-18 05:40:41',0,NULL,3,1,4,1,'YW866475750CN ','sophiewhite*123\r背景布换成\"黑色\"的\rBackdrop support  $25\r燕文告诉无人领取   需要写信给客户'),(13223,740931767002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','ampfiler','bakken.hl@gmail.com','Haavard Bakken','Kastanjeveien 50','Drammen','europe','NORWAY','3026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 05:44:06',0,NULL,3,1,17,0,NULL,'ampfiler'),(13224,740930863002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','ampfiler','bakken.hl@gmail.com','Haavard Bakken','Kastanjeveien 50','Drammen','europe','NORWAY','3026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 05:44:06',0,NULL,3,1,5,1,'CP227165595CN ','ampfiler\r球台 伟峰 WF-717AH      1\r三脚架  伟峰 WF-6662A  1\rWT600                               1\r申报: Gift   $25'),(13225,699430006001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','ayaw28','wind2aya@gmail.com','Aya Windmuller','Ahad ha Am ST 120<br>APT 9','Tel Aviv','AL','ISRAEL','65208','972525323617','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-18 05:58:10',0,NULL,3,1,3,1,'RA183614126CN\rRA183614112CN ','ayaw28\r背景架2mx2m  + 3个夹子     1\r背景布 1.6x2.1m      2   (白,  黑)\r申报: Sample(样品), 每个小包申报$15'),(13226,697707149018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',2,'AKT064',166,'photographyacc','bougsy','bougsy1@hotmail.com','Andrew Bogan','52 Cedar Street<br>Greenslopes','Brisbane','Queensland','AUSTRALIA','4120','0732752622','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-18 06:00:57',0,NULL,3,1,4,1,'YW866475761CN ','bougsy\r澳标\rlighting kit $30'),(13227,699375684018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','samellemby','sam@ellemby.com','Sam Reich','ELLEMBY RESOURCES<br>67 Bulwer Street','MAITLAND','New South Wales','AUSTRALIA','2320','0418402644','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 07:16:11',0,NULL,3,1,3,1,'RA183614143CN ','samellemby'),(13228,8881310974191498,111,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','dmitryder','dmitry_der@mail.ru','Дмитрий Дереза','Строкубанская, дом 14','Краснодар, Краснодарский край','','RUSSIAN FEDERATION','350011','+79618534224',NULL,NULL,NULL,NULL,0,NULL,3,1,2,1,NULL,NULL),(13229,740950695002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',74.3,'hermeshine','hussain3331','h2@live.ca','Hussain Salman Alalawi','Villa 2, Gate 717<br>Road 2821, Barbar 528','Budaiya','BH','BAHRAIN','973','+973 38447445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 07:33:58',0,NULL,3,1,3,1,'RA183614157CN\rRA183614069CN ','hussain3331\r2个小包'),(13230,820528445015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','matiashalme','orders@halme.info','Matias Halme','Onkimiehenpolku 3','Valkeakoski','','FINLAND','37600','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-18 07:51:09',0,NULL,3,1,3,1,'RA183614072CN ','matiashalme'),(13231,754481935017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','charmy870','jve@kooee.com.au','James Van Eynde','2/6 Lochend Place','Bolton Point','New South Wales','AUSTRALIA','2283','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 08:34:24',0,NULL,3,1,3,1,'RA1836171255CN','charmy870\r------\r第一次错发了55mm的,0728重发一个52mm的'),(13232,740966321002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',3,'AE3104',29.04,'hermeshine','tamiro2008','studio.hod@gmail.com','Tamir Orbaum','Dolev 36','Dolev','Dolev','ISRAEL','71935','972-29972490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 08:52:36',0,NULL,3,1,3,1,'RA183614130CN ','tamiro2008'),(13233,699463590001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','wlld1','wild1@nm.ru','Evgeny Bystrov','Amosova st. 77/1, ap. 7','Novosibirsk','','RUSSIAN FEDERATION','630095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 08:52:46',0,NULL,3,1,2,1,NULL,'wlld1\r白色'),(13234,740967246002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',148.6,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 08:56:38',0,NULL,3,1,3,1,'RA183614316CN\r\r\r ','tawfeekmohammed\rRA183614404CN\rRA183614355CN\rRA183614320CN\r'),(13238,754497596017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','nozawa02','marchan@optusnet.com.au','M Mueller','10 Boundary rd','North Epping','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 09:38:52',0,NULL,3,1,2,1,NULL,'nozawa02\r澳标'),(13235,740970477002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','iuc88','fde88@mail.ru','Dmitry Fedorov','Energetikov 58<br>19','Kirishi','Leningrad region','RUSSIAN FEDERATION','187114','8-813-68-586-41','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 09:12:03',0,NULL,3,1,17,0,NULL,'iuc88'),(13236,740971267002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','iuc88','fde88@mail.ru','Dmitry Fedorov','Energetikov 58<br>19','Kirishi','Leningrad region','RUSSIAN FEDERATION','187114','8-813-68-586-41','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 09:14:26',0,NULL,3,1,2,1,NULL,'iuc88\rlenspen   1\r反光板 80cm 2合1'),(13237,740457808002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','luckyxman','pavolkert@gmail.com','Pavol KERTESZ','Nam.priatelstva 2172/28','Dunajska Streda','','SLOVAK REPUBLIC','92901','+421903427399','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-18 09:33:53',0,NULL,3,0,3,1,'RA183614188CN\r ','luckyxman\r摄影背心 Canon  老款 XL    1(已入库)'),(13239,699477866001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','clwvanzyl','clwvanzyl@gmail.com','Louis van Zyl','24 Ditton road<br>Auclandpark','Johannesburg','South Africa','SOUTH AFRICA','2006','(+27) 83 592 8562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 10:01:31',0,NULL,3,1,2,1,NULL,'clwvanzyl'),(13240,699849479018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',3,'AB3331',8.7,'photographyacc','karenather59','ather59@bigpond.com','Karen Gould','1 Redwood Close<br>Forest Lake','Forest Lake','Queensland','AUSTRALIA','4078','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-18 10:07:50',0,NULL,3,1,2,1,NULL,'karenather59'),(13241,740985906002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vanechkaisovl','iso-vl@yandex.ru','Ivan Osadchuk','Tuktarova 8-3','Zelenodolsk','Tatarstan','RUSSIAN FEDERATION','422540','+79274123747','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-18 10:19:17',0,NULL,3,1,3,1,'RA183614259CN\r ','vanechkaisovl'),(13242,740987960002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','dimyusha','vetervideo@gmail.com','Dmitriy Yusha','Krasniy prospect 175b-2','Novosibirsk','','RUSSIAN FEDERATION','630049','79138905142','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-18 10:25:51',0,NULL,3,1,3,1,'RA183614276CN\r ','dimyusha\rshoulder pad $10'),(13243,803567455016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','emmshah','mohemmed.shah@gmail.com','Mohamed Shah','Snow white-6<br>Kurikeela Magu','Male\'','','MALDIVES','20174','+9609621900','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 10:33:30',0,NULL,3,1,2,1,NULL,'emmshah'),(13244,699861324018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',2,'AO0018',120,'photographyacc','kerry08041987','kerryannepascoe@hotmail.com','Kerryanne Milne','282 Newcastle Road','Lambton','New South Wales','AUSTRALIA','2299','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-18 10:44:24',0,NULL,3,1,4,1,'YW866475713CN ','kerry08041987\r3m x 6m 背景布   2\r 白   黑\rbackground $30'),(13245,754518511017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','modge07','bommble@hotmail.com','Ryannan Mathieson','1/16 Peppertree Grove','Strathdale','Victoria','AUSTRALIA','3550','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 10:56:45',0,NULL,3,1,2,1,NULL,'modge07\r澳标'),(13246,698623476001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',21.49,'hermeshine','us-r-h','r-h.mobil@home.se','Roland Holst','Trangränd 18','Vellinge','Skåne','SWEDEN','23534','+46739997027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 11:30:25',0,NULL,3,1,2,1,NULL,'us-r-h\rCANON   肩带   1\r430肥皂盒    1  \rEW-73B      1  '),(13247,754541806017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',11.64,'photographyacc','bigmumplum','kellyra@westnet.com.au','Rachel Pether','53 Terence Avenue','Lake Munmorah','New South Wales','AUSTRALIA','2259','0243582668','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-18 12:24:15',0,NULL,3,1,2,1,NULL,'bigmumplum\rlenspen    1\r普通快门线 rs-c1    1'),(13248,699891959018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mums2angels','allie_phil@optusnet.com.au','Allison Kelly','20 ILLALONG CRES<br>MUNNO PARA','ADELAIDE','South Australia','AUSTRALIA','5115','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-18 12:27:07',0,NULL,3,1,4,1,'YW866475724CN ','mums2angels\rbackground support   $30'),(13249,820121982015,250599997523,'JJC JN-23 Neoprene Lens Case 100x180mm for 70-210 Lens',1,'AC2203',22.2,'hutongstore','vag-bitz','steve.shepherd1971@gmail.com','Steve Shepherd','73 Berry Way','Andover','Hampshire','UNITED KINGDOM','SP10 3RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 13:20:41',0,NULL,3,0,3,1,'RA183614228CN\r','vag-bitz\rJJC 镜头筒 JN23        1\rJJC 镜头筒 JN22         1\rJJC 镜头筒 JN24         1\r（已入库）'),(13250,699532925001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',3,'AA1204',5.97,'hermeshine','kenobe1','abinuya11@gmail.com','Arnold Binuya','6741 Sea Swallow St','North Las Vegas','NV','UNITED STATES','89084-3107','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 13:23:28',0,NULL,3,1,1,1,NULL,'kenobe1'),(13251,741046430002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','ansleadams','larryrmoore@yahoo.com','Lawrence Moore','30 Apollo Rd SE','Carrollton','OH','UNITED STATES','44615-9116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-18 13:54:44',0,NULL,3,1,1,1,' ','ansleadams\r'),(13252,699548054001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',2,'AA2115',64,'hermeshine','sbyrdsell','stan_byrdsell@yahoo.com','Stanley Byrdsell','10317 Chorlton Cir','Orlando','FL','UNITED STATES','32832','','NoPaymentFailure','CheckoutComplete','Other','2011-07-18 14:14:32',0,NULL,3,0,3,1,'RA183614449CN ','sbyrdsell\r摄影背心 黑色薄 canon 3XL    2(已入库)\r0.902'),(13253,740090026002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','marcoslash91','principino91@hotmail.it','marco tucciarelli','via G.F Verghetti 31','fiuggi','FR','ITALY','03014','0775505260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 14:24:36',0,NULL,3,1,3,1,'RA183614231CN\r\r ','marcoslash91\r申报: camera bag(摄影包) $20\r\r'),(13254,819020422015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','handsomelok','o_0.hello@hotmail.com','TIN LOK LEE','80 Glamorgan Street<br>Canton','Cardiff','Cardiff','UNITED KINGDOM','CF5 1QT','07817239451','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 14:51:13',0,NULL,3,1,3,1,'RA183614347CN\r ','handsomelok'),(13255,741083947002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','darcygomide2011','darcygomide@hotmail.com','darcy gomide','3750, 117 ap 202','Balneário Camboriu','SC','BRAZIL','88330-194','554784441967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 15:46:43',0,NULL,3,1,3,1,'RA183614280CN\r','darcygomide2011'),(13256,803682478016,260768456440,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',2,'AA1309',3.74,'hutongstore','cicconf','cicconf@tiscali.it','Francesco Conforti','Via Nicola Serra 68','Cosenza','Cosenza','ITALY','87100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-18 15:47:30',0,NULL,3,1,2,1,NULL,'cicconf'),(13257,699614244001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ebuyassistant','ebaybancher@gmail.com','Anton Roshonok','12 microdistrict, Shalapyna 3, apart. 12','Almaty','','KAZAKHSTAN','050036','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 17:17:36',0,NULL,3,1,3,1,'RA183614262CN\r ','ebuyassistant'),(13258,803734271016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','fort_baxter','scannermobs@gmail.com','Ben Crossman','58 Pullman Haul<br>39 New England Street','Brighton','East Sussex','UNITED KINGDOM','BN14LS','07779572440','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-18 17:32:03',0,NULL,3,1,2,1,NULL,'fort_baxter'),(13259,699659595001,110566020073,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',2.18,'hermeshine','alektsoy','xopo.sii@mail.ru','Oleg Tsoy','Baitursinova 24/73','Shymkent','Uzno-Kazakhstanskaya oblast','KAZAKHSTAN','160021','8(725)222-3573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 18:56:40',0,NULL,3,1,2,1,NULL,'alektsoy'),(13260,699665184001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','kulcsar.balazs','kulcsarb@gmail.com','Kulcsár Balázs','Téglavető utca 24. fsz/1','Budapest','Budapest','HUNGARY','1105','36703129054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 19:05:36',0,NULL,3,1,3,1,'RA183614245CN\r ','kulcsar.balazs\r环换成52 的   '),(13261,741227286002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','mlpix0','mlpix@comhem.se','Michael Levin','Kumminvägen 2','Lerum','Gråbo','SWEDEN','443 70','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 21:07:10',0,NULL,3,1,3,1,'RA183614174CN\r ','mlpix0'),(13262,741248622002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','cameronrbrown','cameron@cameronbrown.ca','Cameron Brown','3549 West 4th Avenue','Vancouver','BC','CANADA','V6R1N8','(778) 389-7253','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:06:34',0,NULL,3,1,3,1,'RA183614165CN\r ','cameronrbrown'),(13263,699749154001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','francisnzv','ventasfrancis@gmail.com','FRANCISCO JOSE NUÑEZ VEGAS','C./ SPITERI Nº 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','657908697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:25:37',0,NULL,3,1,17,0,NULL,'francisnzv'),(13264,741252739002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT034',9.9,'hermeshine','francisnzv','ventasfrancis@gmail.com','FRANCISCO JOSE NUÑEZ VEGAS','C./ SPITERI Nº 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','657908697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:25:37',0,NULL,3,0,17,0,NULL,'francisnzv'),(13265,699747550001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','francisnzv','ventasfrancis@gmail.com','FRANCISCO JOSE NUÑEZ VEGAS','C./ SPITERI Nº 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','657908697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:25:38',0,NULL,3,1,17,0,NULL,'francisnzv'),(13266,699748438001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.95,'hermeshine','francisnzv','ventasfrancis@gmail.com','FRANCISCO JOSE NUÑEZ VEGAS','C./ SPITERI Nº 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','657908697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:25:38',0,NULL,3,0,17,0,NULL,'francisnzv'),(13267,549437629003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','francisnzv','ventasfrancis@gmail.com','FRANCISCO JOSE NUÑEZ VEGAS','C./ SPITERI Nº 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','657908697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 22:25:39',0,NULL,3,1,4,1,'YW866475702CN ','francisnzv\r三脚架 伟峰 WF-6663A    1\r气吹+布     1\r笔      1\r橡胶遮光罩 52mm     1\r绿叶 CPL  52mm    1\r爵影红外 nikon     1\rtripod     $22'),(13268,699764016001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','elempleadodelmes','sebasmac.foto@gmail.com','Sebastian Maciel','CC853<br>J.D. Peron 242','Correo Central','Buenos Aires','ARGENTINA','1000','005411-48566250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 23:21:03',0,NULL,3,1,2,1,NULL,'elempleadodelmes'),(13269,699770961001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',3,'AKT029',72,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-18 23:52:43',0,NULL,3,0,3,1,'RA183614214CN\r ','mariomarques.com.br\rcanon 67  镜头盖         10\rcanon 72 镜头盖         10\rcanon 77 镜头盖        10\r已入库'),(13270,738814747002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','josepr2288','josepr22@hotmail.com','jose  g santiago','PO Box 375004','cayey','PR','PUERTO RICO','00737-5004','7875689144','NoPaymentFailure','CheckoutComplete','Other','2011-07-19 00:35:20',0,NULL,3,0,1,1,NULL,'josepr2288\r摄影背心 Canon  老款     L  (已入库)\r\r\r'),(13271,741293712002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','ddb16','donkey.db@ntlworld.com','Mike Thrower','2 Ewell Way, Totton','Southampton','Hampshire','UNITED KINGDOM','SO403PP','02380861563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 01:03:50',0,NULL,3,1,2,1,NULL,'ddb16'),(13272,741309694002,120539340436,'New 77mm ring adapter replacement for cokin P series',2,'AA2214',4.36,'hermeshine','eduardo.gontijo','edgontijo@hotmail.com','Eduardo Dias Gontijo','Rua Francisco Deslandes 780/ apto 602<br>Bloco 1','Belo Horizonte','Minas Gerais','BRAZIL','30310530','(031)32840913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 02:07:42',0,NULL,3,1,2,1,NULL,'eduardo.gontijo'),(13273,700197727018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',6.6,'photographyacc','mazza4216','m_morini@hotmail.com','Maryline Morini','PO Box 1066<br>Toombul','Brisbane','Queensland','AUSTRALIA','4012','0402454187','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 02:10:02',0,NULL,3,1,2,1,NULL,'mazza4216'),(13274,697690987018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','vanilla2401','suzi-q-88@hotmail.com','Rebecca Atkinson','69 Bougainvillea Forrestfield','Perth','Western Australia','AUSTRALIA','6058','0412035030','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 04:18:30',0,NULL,3,1,2,1,NULL,'vanilla2401'),(13275,754897201017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','postrp1','ecamera@bigpond.com','Rolf Probst','2/20 West St. Corner Carter Rd.<br>Brookvale','Sydney','New South Wales','AUSTRALIA','2100','0299054044','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 04:32:17',0,NULL,3,1,2,1,' ','postrp1\r澳标'),(13276,699833229001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','erfanmoerfan','erfan.iskandar@yahoo.co.id','Mochamad Iskandar','Jl. Raya Semarang KM.5<br>MESS. PT. TPPI Block E/1','Tuban','Jawa Timur','INDONESIA','62352','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 04:47:10',0,NULL,3,1,3,1,'RA183614364CN ','erfanmoerfan'),(13277,700242692018,280680857434,'New JYC-N3 Wireless Remote Control for Nikon D90 D7000',1,'AA3202',18,'photographyacc','vk06011978','veylen.kownden@sensis.com.au','Veylen Kownden','22 Como Avenue','Burnside Heights','Victoria','AUSTRALIA','3023','0386536838','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 06:03:01',0,NULL,3,1,2,1,' ','vk06011978'),(13278,821044045015,250599400336,'72mm 72 Close Up  Macro Close-Up +8 Filter New',1,'AE3227',4.2,'hutongstore','ligab456','zuzelb@inbox.lv','Liga Blome','V.KRESLERA 1/5-2','Riga','','LATVIA','LV1007','0037129172526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 06:03:14',0,NULL,3,1,2,1,NULL,'ligab456'),(13279,741353998002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',13.5,'hermeshine','advocatusdiabbli','octavianisac@gmail.com','Octavian Isac','A. Lapusneanu 28','Chisinau','','MOLDOVA, REPUBLIC OF','2004','+37369323877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 06:16:47',0,NULL,3,1,3,1,'RA183614452CN ','advocatusdiabbli'),(13280,741361038002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','sesafin','huayhuash7@hotmail.com','SERAFIN SANCHEZ MARIN','urb.doña casilda blo.7 portal 1  6ºizq','algeciras','Andalucía Ceuta y Melilla','SPAIN','11204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 06:50:52',0,NULL,3,1,3,1,'RA183614378CN ','sesafin'),(13281,754928657017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','ntbirder','mccrie@gmail.com','Niven McCrie','Po Box 41382','Casuarina','Northern Territory','AUSTRALIA','0811','0889451130','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 07:22:41',0,NULL,3,0,2,1,NULL,'ntbirder\r澳标'),(13282,741378563002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','oleg_n_karpov','techman@rambler.ru','Oleg Karpov','Julius Fuchick street, 10/4-54','Nizhny Novgorod','Nizhegorodskaya','RUSSIAN FEDERATION','603147','+79534150970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 08:38:39',0,NULL,3,1,2,1,NULL,'oleg_n_karpov'),(13283,741391481002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bolosan_chris','christinebolosan@yahoo.com','christine bolosan','2121 Turnhouse Ln','SAN JOSE','CA','UNITED STATES','95121-1378','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 09:30:41',0,NULL,3,1,1,1,'','bolosan_chris\r客户想要在28号之前收到货  王'),(13284,741394129002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.82,'hermeshine','xc6.tiger','yonex@ua.fm','ILYA GELFER','Plehanov street,16/44','DNEPROPETROVSK','','UKRAINE','49000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 09:43:40',0,NULL,3,1,5,1,'CP227165600CN ','xc6.tiger'),(13285,699909528001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','zandermatt','risto.piiroinen@gmail.com','Risto Piiroinen','Norkkokuja 3 A 5','Vantaa','','FINLAND','01360','+358400618504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 11:20:06',0,NULL,3,1,3,1,'RA183614510CN\r ','zandermatt'),(13286,821132149015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0022',149,'hutongstore','ajg1410','stagecamuk@gmail.com','Andy Grant','13 Ferney Road','Byfleet','Surrey','UNITED KINGDOM','KT14 7AL','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-19 11:34:55',0,NULL,3,1,4,1,'YW866475676CN ','ajg1410\rtripod    $30\r已收到'),(13287,754999964017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','margre1987','maren_gresdal@hotmail.com','Maren Græsdal','Sonningveien 11','Manstad','Fredrikstad','NORWAY','1626','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 12:13:10',0,NULL,3,1,2,1,NULL,'margre1987'),(13288,755003604017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','thehalps','u_talking_2_me_punk@hotmail.com','Alan Halpin','9 Clarence Road','ST CLAIR','New South Wales','AUSTRALIA','2759','0296701997','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 12:25:06',0,NULL,3,1,2,1,' ','thehalps'),(13289,700202394018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','gowenmates','wendex1@bigpond.com','Marie Wendy Turnbull','47 Gladstone Street','West Kempsey','New South Wales','AUSTRALIA','2440','0265625735','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 12:41:07',0,NULL,3,0,2,1,NULL,'gowenmates\r1.6 *2.1    白色      1'),(13290,821155904015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','westcoast8dk','lisbethfrost@gmail.com','Lisbeth Frost','Soekaervej 8','Pandrup','Denmark','DENMARK','9490','(45)40872364','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 12:45:19',0,NULL,3,1,3,1,'RA183614608CN\r ','westcoast8dk'),(13291,700326224018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',6.2,'photographyacc','ssive90','ssive@bigpond.com','Andrew Cummins','20 Wauhop Circle<br>Beeliar','Perth','Western Australia','AUSTRALIA','6164','0894376340','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 13:18:08',0,NULL,3,1,2,1,NULL,'ssive90'),(13292,699946339001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','milkduds1985','michellerowatt@gmail.com','Michelle Rowatt','Po Box 6024','Mitchelton','Queensland','AUSTRALIA','4053','0423840784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 13:38:59',0,NULL,3,1,2,1,NULL,'milkduds1985'),(13293,700344519018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','mykolaj94','jparniak@sympatico.ca','John Parniak','11 Highland Court','Sault Ste. Marie','ON','CANADA','P6C5X9','(705) 945-9927','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 13:51:44',0,NULL,3,1,3,1,'RA183614523CN\r ','mykolaj94'),(13294,699970330001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','klamottenklara','ralf.kohlrausch@web.de','Katharina Seiler','Körtingstraße 1','Hannover','','GERMANY','30161','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 15:00:33',0,NULL,3,1,3,1,'RA183614545CN\r ','klamottenklara'),(13295,699982499001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','techster007','louiswhite32@aol.com','louis white','4850 Natomas Blvd<br>Apt 1317','Sacramento','CA','UNITED STATES','95835-1293','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 15:37:43',0,NULL,3,1,3,1,'RA183614537CN\r ','techster007'),(13296,821063906015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','argeusko2009','argeusko@yahoo.com.ar','Roberto Azagra','Olazabal 2120, 5th. floor','Buenos Aires','Buenos Aires','ARGENTINA','C1428DHQ','54-11-47818087','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 15:43:04',0,NULL,3,1,2,1,NULL,'argeusko2009'),(13297,699992844001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','getridofstuffs','recstudios8888@hotmail.com','Ken Chiu','206 W Shelbourne Dr<br>Apt C','Normal','IL','UNITED STATES','61761-1342','(309) 660-3300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-19 16:07:58',0,NULL,3,1,1,1,NULL,'getridofstuffs\r环换成77的   '),(13298,700407008018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','anafashion2000','anafashion20002000@yahoo.es','francisco jimenez perez','calvo sotelo 12','huetor tajar ( granada )','Andalucía Ceuta y Melilla','SPAIN','18360','958332561','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 16:25:36',0,NULL,3,1,4,1,'YW866475654CN ','anafashion2000\r白色背景布\r已收到'),(13299,700410910018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','acrux-fomalhaut','alcyon2012@gmail.com','JUAN CARLOS REYES','Calle Santa Barbara 9<br>Piso 1-B','Palamos','Gerona','SPAIN','17230','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 16:35:57',0,NULL,3,1,2,1,NULL,'acrux-fomalhaut'),(13300,700416627018,280687534735,'Studio 1000W Continuous Lighting Complete Kit 3mx6m W',1,'AKT050',256,'photographyacc','joannebertrand','famille_rochon@hotmail.com','Joanne Bertrand','154 Bertrand','Gatineau','QC','CANADA','J8L2Z2','(819) 281-5561','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 16:50:10',0,NULL,3,1,5,1,'CP227165613CN ','joannebertrand\r灯泡是110v 的'),(13301,741514423002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','manayraseabra','manayra@gmail.com','manayra seabra de mingo','Avenida Rio Branco nº 1151, apto 301, ed. Olho Dagua<br>Bairro Praia do Canto','Vitória','Espirito Santo','BRAZIL','29055643','(027)33158622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 16:54:01',0,NULL,3,1,2,1,NULL,'manayraseabra'),(13302,700441814018,280675886664,'18% Gray Cards 8x6\"& 6x4\" for White balance exposure S',1,'AA2217',11,'photographyacc','berndkorteling','bkorteling@gmail.com','Rene Korteling','Diamantring 66','eindhoven','Noord-Brabant','NETHERLANDS','5629gs','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-19 17:50:05',0,NULL,3,1,2,1,NULL,'berndkorteling'),(13303,741540413002,120598267593,'New Camera shoulder bag nova 4 with raincover 4 7D 5Dii',1,'AD1105',40.99,'hermeshine','davide.agata','davide.torrisi@email.it','Davide Torrisi','Via Lombardia, 59','Acireale','CT','ITALY','95024','3477376891','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 17:52:27',0,NULL,3,1,3,1,'RA183614656CN ','davide.agata\r申报  camera bag     $20'),(13304,741382507002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','oleginkazan','olegnkr@gmail.com','Oleg Nekrashevich','41 Kosmonavtov street, flat 51','Kazan','Tatarstan','RUSSIAN FEDERATION','420061','+7 9033 88 73 88','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 18:05:31',0,NULL,3,1,3,1,'RA183614497CN\r ','oleginkazan\r申报  reflector     $10'),(13305,804312072016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','lee99nicholls','icon.art@hotmail.co.uk','Lee Nicholls','90 Briar Road','Watford','Hertfordshire','UNITED KINGDOM','WD25 0HP','07739535055','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-19 19:47:03',0,NULL,3,1,4,1,'YW866475632CN ','lee99nicholls\rbackground  plate    $20'),(13306,699667944001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',99,'hermeshine','egovital','vitalforte@yahoo.ie','Michael Cristea','Copacabana 38/31','Kalsdorf bei Graz','','AUSTRIA','8401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 20:37:53',0,NULL,3,1,3,1,'RA183614554CN\r ','egovital\r欧标'),(13307,700112828001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',2,'AC2401',39.78,'hermeshine','della661','dellatax@aol.com','Della Sehm','8223 Essex Ct','Bakersfield','CA','UNITED STATES','93311','(661) 665-9166','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,7,0,18,1,'','della661\r0.688'),(13308,803550076016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','tothacka','toth.attila07@gmail.com','Attila Tóth','Úzka 26','Želiezovce','','SLOVAK REPUBLIC','93701','421910235121','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 20:52:42',0,NULL,3,0,3,1,'RA183614466CN\r ','tothacka\r1.6 乘以3    灰色            1'),(13309,700115592001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','nsfurlan','furlan9000@gmail.com','Nivaldo dos Santos Furlan','R. Candido Marciano Leite, 48, ap. 33<br>Vila Betania','São José dos Campos','SP','BRAZIL','12.245-486','55 12 32060277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 20:58:08',0,NULL,3,1,2,1,' ','nsfurlan'),(13310,741625621002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','galang6','hannu.holmberg@gmail.com','Hannu holmberg','Kurkisuontie 16 G 45','Helsinki 94','Oletus','FINLAND','00940','040 8471906','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 21:02:15',0,NULL,3,1,2,1,NULL,'galang6'),(13311,804365365016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','5879paolo','paolo.togni.79@gmail.com','Paolo Togni','Mijnsherenlaan 111B','Rotterdam','','NETHERLANDS','3081GJ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 21:54:09',0,NULL,3,1,17,0,NULL,'5879paolo'),(13312,821414711015,250599945149,'New EyeCup for Nikon Af D80 D90 D200',1,'AA1203',1.85,'hutongstore','5879paolo','paolo.togni.79@gmail.com','Paolo Togni','Mijnsherenlaan 111B','Rotterdam','','NETHERLANDS','3081GJ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 21:54:09',0,NULL,3,1,17,0,NULL,'5879paolo'),(13313,804366261016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','5879paolo','paolo.togni.79@gmail.com','Paolo Togni','Mijnsherenlaan 111B','Rotterdam','','NETHERLANDS','3081GJ','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-19 21:54:08',0,NULL,3,1,2,1,NULL,'5879paolo\r方镜普通托架（三槽）    1\r方形滤镜接口环 67mm      1\r眼罩 D300    1\r肥皂盒 柔光罩   sb800 sb600    1 \r'),(13314,741656383002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 22:34:23',0,NULL,3,1,17,0,NULL,'leifs123'),(13315,741656184002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',95,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 22:34:23',0,NULL,3,1,5,1,'CP235617995CN','leifs123 YW866475643CN \r除c以外再加两个灯泡\r115w 5500k 灯泡  220v   2\r申报 $28      lighting kit'),(13316,700151843001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','medtagen74','aingemansson@hotmail.com','Andreas Ingemansson','Regeringsgatan 8','Karlshamn','','SWEDEN','37434','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 22:57:05',0,NULL,3,1,17,0,NULL,'medtagen74'),(13317,741660099002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','medtagen74','aingemansson@hotmail.com','Andreas Ingemansson','Regeringsgatan 8','Karlshamn','','SWEDEN','37434','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-19 22:57:05',0,NULL,3,1,4,1,'YW866475606CN ','medtagen74\r反光板 110cm 5合1        1\r反光板 100*150 40*60 5合1          1\r申报$20     reflector\r已收到'),(13318,700135310001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-19 23:11:55',0,NULL,3,1,17,0,NULL,'saud-p'),(13319,755263539017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','diudiudiu','laicoppel3@hotmail.com','Tat Wing Coppel Lai','Unit 1417 Oaks Goldsbrough Apt<br>243 Pyrmont Street','Pyrmont','New South Wales','AUSTRALIA','2009','0415415294','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-19 23:22:34',0,NULL,3,1,2,1,NULL,'diudiudiu'),(13320,700592742018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','gdeb4551','gourab_spiky@yahoo.co.in','Gourab Deb','2A Darley Street','Newtown','New South Wales','AUSTRALIA','2042','0295191621','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 00:09:21',0,NULL,3,1,4,1,'YW866475621CN ','gdeb4551'),(13321,755278400017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','8ternity','stephanerobert@foxelldesign.net','Stephane Robert','1168 Boul. Ste-Foy','Longueil','QC','CANADA','J4K 1W9','(450) 646-3335 ext.: 225','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 00:22:30',0,NULL,3,1,2,1,NULL,'8ternity'),(13322,741684291002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','giovannicj','jovanotti_07@hotmail.com','Giovanni Carrillo Jimenez','C/ Servando Camuñez, 8 - 1D','San Fernando','Cadiz','SPAIN','11100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 00:32:33',0,NULL,3,1,4,1,'YW866475610CN ','giovannicj\r已收到'),(13323,741697955002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','syncrophaser','daveturner@flightline.com','David Turner','175 Sycamore LN','Westminster','SC','UNITED STATES','29693','(864) 647-5157','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-20 01:29:01',0,NULL,3,1,1,1,' ','syncrophaser'),(13324,741700967002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','yossinitza','yossinitza@gmail.com','wurmbrand yossi','12018 Montrose Park Pl','rockville','MD','UNITED STATES','20852-4157','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-20 01:39:41',0,NULL,3,1,1,1,NULL,'yossinitza'),(13325,700189198001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','bknightsb','bknightsb@hotmail.com','Simon Briere','1886 Jeanne-Sauvé','Sherbrooke','QC','CANADA','J1H 6L6','(819) 791-1796','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 01:42:25',0,NULL,3,1,2,1,NULL,'bknightsb'),(13326,700193123001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',10,'AA1204',19.9,'hermeshine','petterdamlien','petter@damlien.net','petter damlien','Bergløkka 2','drøbak','','NORWAY','1440','40044900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 01:58:59',0,NULL,3,1,3,1,'RA183614483CN\r ','petterdamlien'),(13327,741716605002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','s4632','sanma@telus.net','San Ma','125 Willowmere Way','Chestermere','AB','CANADA','T1X 0E1','(403) 272-4632','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 02:48:20',0,NULL,3,1,2,1,NULL,'s4632'),(13328,700629830018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','1984_mammino','kate_22f_aries@hotmail.com','kate mammino','6 Lake Wivenhoe Court','Logan Reserve','Queensland','AUSTRALIA','4133','0738052349','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 02:52:20',0,NULL,3,1,2,1,NULL,'1984_mammino'),(13329,700205816001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',2,'AO0011',159.98,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 03:01:51',0,NULL,3,1,3,1,'RA183614625CN ','fatimahali23\rRA183614639CN\rRA183614642CN'),(13330,741719884002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','eorl_the_young','sensfan@gmail.com','Derek Kind','391 Route 200','Russell','ON','CANADA','K4R 1E5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 03:03:54',0,NULL,3,1,17,0,NULL,'eorl_the_young'),(13331,741719744002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','eorl_the_young','sensfan@gmail.com','Derek Kind','391 Route 200','Russell','ON','CANADA','K4R 1E5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 03:03:55',0,NULL,3,1,2,1,NULL,'eorl_the_young\r方形滤镜接口环 77mm    1\r方镜广角托架（ 一槽）    1'),(13332,700209638001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','torher16','torherskedal@yahoo.no','Tor Kristian Herskedal','Torsgate 13','Kristiansand','Kristiansand','NORWAY','4631','(047) 45872441','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 03:28:44',0,NULL,3,1,3,1,'RA183614470CN\r ','torher16'),(13333,700663588018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','drandrewc','mail@andrewcorbett.com','Andrew N Corbett','PO Box 1143','Legana','Tasmania','AUSTRALIA','7277','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 05:54:22',0,NULL,3,1,2,1,NULL,'drandrewc'),(13334,755358004017,270744174175,'62mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT021',4.19,'photographyacc','cdhayles','cdhayles@gmail.com','Cameron Hayles','Unit 2 / 23 Woodland Gve','Montmorency','Victoria','AUSTRALIA','3094','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 06:27:29',0,NULL,3,1,2,1,NULL,'cdhayles'),(13335,741761978002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','aviclooud','avicloud@gmail.com','Vjacheslav Kalinin','ul. Voronova, d. 12/1 kv. 47','Verhnjaja Salda','RU','RUSSIAN FEDERATION','624766','+7-906-800-44-51','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 07:10:06',0,NULL,3,1,2,1,NULL,'aviclooud'),(13336,700678499018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','ikev0423','duckno2@hotmail.com','Tsung-Han Lee','52 Ingluna Circuit<br>Eight Mile Plains','Brisbane','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 07:27:58',0,NULL,3,0,2,1,NULL,'ikev0423'),(13337,700252118001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',38.5,'hermeshine','ffotila','kotovo@list.ru','Alexey Kazachkov','Pobeda  26 - 54','Kotovo','Volgograd region','RUSSIAN FEDERATION','403805','+79053317550','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 07:29:34',0,NULL,3,1,3,1,'RA183614571CN ','ffotila'),(13338,700681307018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','toomastitov','toomas.titov@enter.ee','Toomas Titov','Lootuse 20-1','Tartu','Tartumaa','ESTONIA','50108','+37255650762','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 07:31:40',0,NULL,3,1,2,1,' ','toomastitov'),(13339,700705168018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',203,'photographyacc','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-20 09:28:24',0,NULL,3,0,17,0,' ','saud-p'),(13340,741797100002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','ertekmali','ertekmali@yahoo.com','MEHMET ALI ERTEK','Mustafa Mazharbey Cad. no 85 Da.14 FENERYOLU ISTANBUL','ISTANBUL','TURKEY','TURKEY','34724','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 10:02:33',0,NULL,3,1,3,1,'RA183614775CN ','ertekmali'),(13341,700284215001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','azzerik','azzerik3a@yahoo.es','Daniel Cañamares Ullan','Calle Villa de Marin Nº3','Madrid','Madrid','SPAIN','28029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 10:06:35',0,NULL,3,1,4,1,'YW866127076CN ','azzerik\rTripod   $22\r已收到'),(13342,741553193002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','alberto298','bonialberto@hotmail.it','ALBERTO BONI','via Corletto, 15/A','Corlo di Formigine','MO','ITALY','41043','347-5545000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 10:16:41',0,NULL,3,1,2,1,NULL,'alberto298'),(13343,700287957001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','barina8883','bbrucech@bigpond.net.au','edward  chong','12 birdwood avenue<br>killara','sydney','New South Wales','AUSTRALIA','2071','61422163916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 10:20:59',0,NULL,3,1,3,1,'RA183614789CN ','barina8883'),(13344,741810289002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','stesmith01','smith.stephengeorge@gmail.com','steve smith','59 Cardinal Avenue<br>Beecroft','Sydney','New South Wales','AUSTRALIA','2119','6142566882461425668824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 10:58:16',0,NULL,3,1,4,1,'YW866127065CN ','stesmith01\rlight stand    $25'),(13345,700729662018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','rfjbikini','rfj@ono.com','Asociació fotogràfica Bocairent (Jose Bernat Bacete)','C/Palleter 10, 3','Bocairent','Comunidad Valenciana','SPAIN','46880','658240417','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 11:10:59',0,NULL,3,1,5,1,'CP227168172CN ','rfjbikini\r客户要发票'),(13346,821641903015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','freddiefringie','freddie@fringie.com','Freddie Johansson','Fiskodlaregränd 9','Kristinehamn','Varmland','SWEDEN','68138','0550411216','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 11:19:52',0,NULL,3,1,2,1,NULL,'freddiefringie'),(13347,741819377002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','rembucis','ordercar@gmail.com','Armands Zavadskis','Cālīšpurva str. 15','Baloži','','LATVIA','LV2128','+37129555222','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 11:30:29',0,NULL,3,1,3,1,'RA183614801CN ','rembucis'),(13348,700740900018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sjaenke','sjaenke@bigpond.net.au','Suzanne Jaenke','232a Boyer Rd<br>Dromedary','Hobart','Tasmania','AUSTRALIA','7030','0362637161','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-20 11:43:55',0,NULL,3,1,4,1,'YW866127054CN ','sjaenke\r Background Support    $25'),(13349,741828030002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','andulicka37','ahatapkova@seznam.cz','Anna Simaliakova','Nadrazni<br>37/9','Cesky Tesin','czech republic','CZECH REPUBLIC','73701','(004) 206-0837 ext.: 7493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 12:04:23',0,NULL,3,1,2,1,NULL,'andulicka37'),(13350,821660997015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'AA3212',2.98,'hutongstore','god9ps','paulo_a_m_serrano@hotmail.com','Paulo António Magalhães Serrano','Rua de Moçambique, nº 20','Campo Maior','Portalegre','PORTUGAL','7370-124','961546227','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 12:11:14',0,NULL,3,1,2,1,NULL,'god9ps'),(13351,755447782017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','bassplayermiles','blackfxholden@hotmail.com','Chris Miles','57 Worrell Avenue<br>High Wycombe','Perth','Western Australia','AUSTRALIA','6057','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 12:33:57',0,NULL,3,1,2,1,NULL,'bassplayermiles\r澳标'),(13352,821674161015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','hariboos','nagyesfia@freemail.hu','Zsolt Nagy','Remete u. 55-57','Szekszárd','Tolna megye','HUNGARY','7100','(3630)588-3318','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-20 12:47:08',0,NULL,3,1,3,1,'RA183614713CN ','hariboos'),(13353,700763324018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','bojing4ever','nfue3881@bigpond.net.au','Nicanor Fuertes','52 Aquilina Drive, Plumpton','Sydney','New South Wales','AUSTRALIA','2761','0430402681','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 12:54:52',0,NULL,3,1,17,0,NULL,'bojing4ever'),(13354,755458568017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','bojing4ever','nfue3881@bigpond.net.au','Nicanor Fuertes','52 Aquilina Drive, Plumpton','Sydney','New South Wales','AUSTRALIA','2761','0430402681','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 13:02:15',0,NULL,3,1,17,0,NULL,'bojing4ever'),(13355,700769503018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','bojing4ever','nfue3881@bigpond.net.au','Nicanor Fuertes','52 Aquilina Drive, Plumpton','Sydney','New South Wales','AUSTRALIA','2761','0430402681','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 13:14:16',0,NULL,3,1,3,1,'RA183614727CN ','bojing4ever\r独脚架  伟峰 WT-1003    1\r绿叶 UV  58mm        1\rcanon 反接环  58mm         1'),(13356,700334436001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','vr_aveiro','evfiliperito@gmail.com','Verónica Rito','Rua Feira de Março, nº4 5º Dto','Aveiro','Aveiro','PORTUGAL','3800-182','351-234-042137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 13:16:39',0,NULL,3,1,2,1,NULL,'vr_aveiro'),(13357,700057737001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',7.2,'hermeshine','hitrovan','sekochet@narod.ru','Vladimir Cherkasov','Pionerskaya street 22-18','Sarov','Nizhegorodskaya obl','RUSSIAN FEDERATION','607186','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 13:16:55',0,NULL,3,1,2,1,NULL,'hitrovan'),(13358,700773052018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','sterling1575','lukechristie2@bigpond.com','Luke Christie','98 Karoola Road','Lindisfarne','Tasmania','AUSTRALIA','7015','0362342894','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 13:25:27',0,NULL,3,1,4,1,'YW866127043CN ','sterling1575\r Tripod   $22'),(13359,821694294015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','paulo_fig','pfigueira@gmail.com','Paulo Figueira','Estrada Coelho Prazeres, 120<br>Maxieira','Fatima','Fatima','PORTUGAL','2495-641','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 13:40:03',0,NULL,3,1,3,1,'RA183614735CN ','paulo_fig\r0.450'),(13360,700783014018,280666919433,'New Neoprene Camera Cover for Canon 550D+18-55mm',1,'AC1305',9.99,'photographyacc','martika.m','teexcheex@hotmail.com','Martika Morcom','6 Stokes Court<br>Spalding','Geraldton','Western Australia','AUSTRALIA','6530','0437805188','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 13:57:56',0,NULL,3,1,2,1,NULL,'martika.m'),(13361,700784406018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','michaelm7978','maclean3@bigpond.net.au','michael maclean','17 koellner rd., cumbalum heights.<br>cumbalum','ballina','New South Wales','AUSTRALIA','2478','0266815935','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 14:11:35',0,NULL,3,1,17,0,NULL,'michaelm7978'),(13362,700789525018,280685224536,'50x70cm 20\"x28\" Folding Easy Soft box  E27 Bulb Socket',1,'AE2401',35,'photographyacc','michaelm7978','maclean3@bigpond.net.au','michael maclean','17 koellner rd., cumbalum heights.<br>cumbalum','ballina','New South Wales','AUSTRALIA','2478','0266815935','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 14:22:39',0,NULL,3,1,3,1,'RA183614744CN ','michaelm7978\r斜臂       1\r柔光箱 50-70cm 单灯头  澳标     1\r'),(13363,741870081002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','georgilambov','glambov@gmail.com','Georgi Lambov','1B Business Park Sofia Str., Mladost 4 Globul-MSC3','Sofia','','BULGARIA','1766','0898400815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 14:31:37',0,NULL,3,1,2,1,NULL,'georgilambov'),(13364,821735572015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','ornousa','ornousa@msn.com','ornousa panwattanasakul','389/22 m.6 nakorntonggrandvill nakdee praksa','maung','samutprakarn','THAILAND','10280','0859699960','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 15:21:15',0,NULL,3,1,2,1,NULL,'ornousa'),(13365,741886678002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',3,'AA3312',19.5,'hermeshine','maswino','w_1_no@yahoo.com','Winantu Rahardja','Jl. Gedong Kuning Selatan No. 17A','Yogyakarta','Daerah Istimewa Yogyakarta','INDONESIA','55198','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 15:22:03',0,NULL,3,1,2,1,NULL,'maswino'),(13366,804695025016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','ilh','ianhewi@hotmail.com','Ian Hewitson','20 Coverdale Road','Stockton-on-Tees','Cleveland','UNITED KINGDOM','TS197EA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 16:12:37',0,NULL,3,1,3,1,'RA183614758CN ','ilh'),(13367,741914966002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','goranavalon','g.ugresic@gmail.com','Goran Ugresic','Borislava Stankovica 5','Gradiska','RS','BOSNIA AND HERZEGOVINA','78400','+387 65 569 189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 16:39:33',0,NULL,3,1,5,1,'CP227168190CN ','goranavalon\r欧标\r5.8'),(13368,700403819001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','septimiunemes','septimiu_nemes@yahoo.com','Nemes Septimiu-Sever','Neptun 26 A , sc B , ap 8 , et 1','Brasov','','ROMANIA','500352','+400761335441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 16:45:32',0,NULL,3,1,2,1,NULL,'septimiunemes'),(13369,700848892018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','mutexx','alxpin@gmail.com','Alexey Pinchuk','Revolutionnaya 20<br>apt 41','Tokmak','Zaporozhye','UKRAINE','71700','+380972660330','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 16:59:37',0,NULL,3,1,2,1,NULL,'mutexx'),(13370,821778578015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','ns798','natspenc@yahoo.co.uk','Natalie Spencer','32 Sunnymead Road','London','London','UNITED KINGDOM','SW15 5HY','07803615355','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-20 17:08:53',0,NULL,3,1,2,1,NULL,'ns798'),(13371,700857326018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','egul1043','e.gulley@yahoo.com','Ethan Gulley','24956 Bubba Trail','Athens','AL','UNITED STATES','35613','(256) 874-5368','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 17:18:34',0,NULL,3,1,3,1,'RA183614660CN ','egul1043'),(13372,741931368002,120644812085,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',27.9,'hermeshine','talgat_sk','talgatsk@gmail.com','Talgat Seidigaliyev','Kabanbai batyr 6,. poselok Algabas','Karasaiskii rayon,','Almaty region','KAZAKHSTAN','040908','+7(700)449-9787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 17:21:15',0,NULL,3,1,3,1,'RA183614611CN ','talgat_sk'),(13373,700423149001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','guhav55','gunnar.havrevold@lyse.net','Gunnar Havrevold','Mellarvegen 5','Jørpeland','Rogaland','NORWAY','4100','51747814','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 17:35:56',0,NULL,3,1,3,1,'RA183614846CN ','guhav55\rxl '),(13374,741937885002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','nut-ster','nutsterr@msn.com','Matthew L. Madorin','4313 Daisy Dr','Mountain Green','UT','UNITED STATES','84050-9768','(801) 558-1389','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-07-20 17:36:51',0,NULL,3,1,4,1,'YW866127032CN ','nut-ster\r Tripod   $20'),(13375,741571697002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',31.78,'hermeshine','chutakawa','seniorita26@rambler.ru','Tatiana Chushenkova','10 str. Sokolinoy Gory, d. 6, k1, kv. 123','Moscow','Moscow','RUSSIAN FEDERATION','105118','89036766534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 17:54:12',0,NULL,3,1,3,1,'RA183614673CN ','chutakawa\r60cm2和1        1\r圆形柔光棚 50cm   1'),(13376,821843940015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','deimis61','deimarasim@gmail.com','Deimantas Rasimavicius','Zirgo 91','Vilnius','Antakalnis','LITHUANIA','10221','+37068607458','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-20 18:45:51',0,NULL,3,1,2,1,NULL,'deimis61'),(13377,700452945001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','maskedrolla','maskedrolla@gmail.com','Nia Bennison','851 Ioco Road','Port Moody','BC','CANADA','v3h2w7','(604) 349-0318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 18:46:25',0,NULL,3,1,2,1,NULL,'maskedrolla'),(13378,700488870001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','haddadsara','sarafhaddad@gmail.com','Sara Haddad','2230 George C Marshall Dr<br>Apt 215','Falls Church','VA','UNITED STATES','22043-2571','(703) 677-0687','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-20 19:58:31',0,NULL,3,1,1,1,NULL,'haddadsara'),(13379,742013157002,120449759461,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',34,'AA1310',186.66,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:19:39',0,NULL,3,1,3,1,'RA183614792CN ','blinker-182'),(13380,700503763001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','amateurul','nipol@web.de','Nikolai Poljuchow','Schemppstr. 54','Stuttgart','','GERMANY','70619','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:33:39',0,NULL,3,1,17,0,NULL,'amateurul'),(13381,700504240001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',3,'AKT007',56.97,'hermeshine','voodoohill','dario.m@tin.it','Dario Mollo','Via Alba, 30','BORDIGHERA','IM','ITALY','18012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:34:48',0,NULL,3,1,3,1,'RA183614761CN ','voodoohill\r注意是6个     \r申报Light Bulb      $20'),(13382,700505521001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',2.18,'hermeshine','amateurul','nipol@web.de','Nikolai Poljuchow','Schemppstr. 54','Stuttgart','','GERMANY','70619','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:37:36',0,NULL,3,1,17,0,NULL,'amateurul'),(13383,742019691002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','petermolino','molino@rubicom.hu','Peter Molcsanyi','Attila u. 44.','Sződliget','','HUNGARY','2133','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:37:56',0,NULL,3,1,3,1,'RA183614850CN ','petermolino'),(13384,742015970002,120582352724,'New 49mm ring adapter replacement for cokin P series',2,'AA2207',4.36,'hermeshine','amateurul','nipol@web.de','Nikolai Poljuchow','Schemppstr. 54','Stuttgart','','GERMANY','70619','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 20:43:53',0,NULL,3,1,2,1,NULL,'amateurul\r方形滤镜接口环 52mm    1\r方形滤镜接口环 55mm      1\r方形滤镜接口环 49mm          2'),(13385,755675208017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',73,'photographyacc','assideal','assioz@gmail.com','Assi Oz','Ha`imahot 11 appartment 9','Nes Tziona','','ISRAEL','74025','0528549314','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 21:20:50',0,NULL,3,1,3,1,'RA183614829CN\r ','assideal\r分开发   两个加起来申报总值要超过$30\rRA183614832CN '),(13386,755678275017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','zeusch001','scott-and-candice@exemail.com.au','Scott Zeuschner','108 Tamar Street','Launceston','Tasmania','AUSTRALIA','7250','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-20 21:26:12',0,NULL,3,1,4,1,'YW866127010CN ','zeusch001\rTripod     $22'),(13387,700974987018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','ciobanuvlad','studio_cmc@yahoo.com','Ciobanu Vlad','Str. Magazinului, nr. 509, Sc. A, Ap.6 Loc. Prejmer, Jud. Brasov','Brasov','Prejmer','ROMANIA','507165','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-20 21:30:06',0,NULL,3,1,5,1,'CP227168186CN ','ciobanuvlad'),(13388,700531450001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','fireflyatdawn','mystic_i9@yahoo.com','Chris Miller','3637 Snell Ave<br>Spc 336','San Jose','CA','UNITED STATES','95136-1330','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-20 21:47:28',0,NULL,3,1,1,1,NULL,'fireflyatdawn'),(13389,700541207001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-20 22:21:02',0,NULL,3,1,3,1,'RA183614695CN ','fatimahali23\r1.6*2.1    黑色背景布    1\r1.6*2.1   白色背景布     1    \rRA183614687CN'),(13390,700554806001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',9.99,'hermeshine','roscellin','roscellin00@hotmail.com','Keir Davis','63 Balmara Place','Coomera Waters','Queensland','AUSTRALIA','4209','0410534702','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-20 23:13:53',0,NULL,3,1,2,1,NULL,'roscellin'),(13391,700559916001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','genlk','gkell@ns.sympatico.ca','Genny L. Kell','307 Beech Hill Road','Antigonish','NS','CANADA','B2G 0B4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-20 23:36:56',0,NULL,3,0,2,1,NULL,'genlk\r1.6m×2.1m    黑色背景布     1'),(13392,742085949002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','belluzzf','belluzz@gmail.com','Francesco Belluzzi','Viale Verdi 196','Modena','Modena','ITALY','41121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 00:18:48',0,NULL,3,1,17,0,NULL,'belluzzf'),(13393,742085787002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','belluzzf','belluzz@gmail.com','Francesco Belluzzi','Viale Verdi 196','Modena','Modena','ITALY','41121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 00:18:48',0,NULL,3,1,2,1,NULL,'belluzzf\r方镜广角托架（ 一槽）    1\r方形滤镜接口环 77mm      1'),(13394,700585872001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','ortazo','hortazo@yahoo.es','David  Ortiz Nieto','calle moreras 11 2ºD','salamanca','Castilla y León','SPAIN','37004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 01:35:43',0,NULL,3,1,3,1,'RA183614700CN ','ortazo'),(13395,742119993002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bariskadioglu','baris54@rogers.com','Baris kadioglu','336 Goldenwood Rd','Toronto','ON','CANADA','M2M2Z5','(416) 730-8493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 02:47:51',0,NULL,3,1,17,0,NULL,'bariskadioglu'),(13396,700601523001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.2,'hermeshine','bariskadioglu','baris54@rogers.com','Baris kadioglu','336 Goldenwood Rd','Toronto','ON','CANADA','M2M2Z5','(416) 730-8493','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 02:49:30',0,NULL,3,1,2,1,NULL,'bariskadioglu\rHB-7 花瓣    1\r镜头筒 xl 大号    1'),(13397,700604224001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','riendi','chochon@gmail.com','Luc Lamontagne','201-2280 De La Salle','Montreal','QC','CANADA','H1V 2L1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 03:04:31',0,NULL,3,1,2,1,NULL,'riendi'),(13398,8881311220191738,111,'套装',1,'',490,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,NULL,0,NULL,3,1,12,1,' BJ8824401','2m 灯架   5\r斜臂     1\r单灯头棚    1\r4灯头棚    4\r115w 110v    1\r45w 110v    16\r包    3\r80CM 5 IN 1 反光板   1\r'),(13399,701093495018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','michael_jade','michaelandjade@dodo.com.au','Michael Hoad','75 Medcalf Street','Warners Bay','New South Wales','AUSTRALIA','2282','0249581140','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 06:23:43',0,NULL,3,1,3,1,'RA183614903CN ','michael_jade\rc里的不太对，\r是从49mm 到82mm所有的环，还有一槽，三槽两种托架。'),(13400,822079344015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','fenboy1969','carl.allen@virgin.net','Carl Allen','April Cottage, Beach Road<br>Happisburgh','Norwich','Norfolk','UNITED KINGDOM','NR12 0PP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-21 06:29:13',0,NULL,3,1,2,1,NULL,'fenboy1969'),(13401,755814893017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',19.6,'photographyacc','mikakim73','michaelbeaufrere@hotmail.com','Michael BEAUFRERE','10 avenue Anatole France','clichy','Ile-de-France','FRANCE','92110','0661406986','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-21 07:01:48',0,NULL,3,1,2,1,NULL,'mikakim73\r两个单灯头\r欧标'),(13402,755817971017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','unclelegend','scottcornish@optusnet.com.au','Scott Cornish','PO Box 141<br>Dunwich','Brisbane','Queensland','AUSTRALIA','4183','','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,1,'','unclelegend\r'),(13403,822092998015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','rupert_bear','doobie_hempire@hotmail.com','Richard Gritton','76 Swanley Road','Welling','Kent','UNITED KINGDOM','DA16 1LJ','07828993930','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-21 07:44:03',0,NULL,3,1,2,1,NULL,'rupert_bear'),(13404,700664150001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','avnertzur','avner.zur@gmail.com','Avner Tzur','Halehi 10/91','Rehovot','Israel','ISRAEL','76217','972-8-9352299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 08:53:51',0,NULL,3,1,2,1,NULL,'avnertzur'),(13405,742188461002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','galsplace','galsplace@hotmail.com','Gal Baraf','Hey Beiyar 36/6','Rosh Haayin','','ISRAEL','48056','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 09:16:19',0,NULL,3,1,2,1,NULL,'galsplace'),(13406,701130067018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','daturian','rkfenech@ymail.com','Roy Fenech','9 Haverbrack Crescent','Churchill','Victoria','AUSTRALIA','3842','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-21 09:24:22',0,NULL,3,1,2,1,NULL,'daturian'),(13407,700678348001,110665009924,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',9,'hermeshine','craigedwin1965','craigstahl@yahoo.com','Craig Stahl','14298 Russ Wilcox Way','Oregon City','OR','UNITED STATES','97045','(503) 789-8871','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 10:01:17',0,NULL,3,1,1,1,NULL,'craigedwin1965'),(13408,701139983018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','liamojnsn','liamoj97@live.com.au','liam johnson','92 Flora street<br>kirrawee','sydney','New South Wales','AUSTRALIA','2232','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 10:10:31',0,NULL,3,1,2,1,NULL,'liamojnsn'),(13409,742213501002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','079844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 11:06:15',0,NULL,3,1,2,1,NULL,'junglistic_maxim\r新地址：\rMogildea Maxim \rChisinau, str. A.Xenopol 11 MD-2051, \rMOLDOVA \r+37379844160'),(13410,700679804001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 11:40:14',0,NULL,3,1,3,1,'RA183614934CN ','saud-p\r申报高值\rRA183614925CN\rRA183614917CN\rRA183614948CN'),(13411,700715898001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','alex.shkurko','shkurko.alex@gmail.com','Aleksey Shkurko','Shopena 4/6a','Lviv','L\'vivs\'ka Oblast\'','UKRAINE','79007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 12:36:24',0,NULL,3,1,2,1,NULL,'alex.shkurko'),(13412,754543023017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','thornydevilboy','mortimer@rsc.anu.edu.au','A Mortimer','1/43-47 Hutchison Cct','Queanbeyan','New South Wales','AUSTRALIA','2620','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 12:43:44',0,NULL,3,1,2,1,NULL,'thornydevilboy'),(13413,805111026016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','joaquim.pires','joaquim.pires@vodafone.pt','joaquim Pires','Edifício Vodafone<br>Avenida D. Joao II  lote 1.04.04  piso 3 Norte','Lisboa','Expo','PORTUGAL','1990-093','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 12:51:35',0,NULL,3,1,2,1,NULL,'joaquim.pires'),(13414,701186509018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','cheekyninjaboy','michael.bond@swinton.co.uk','Michael Bond','15 Hardman Lane<br>Failsworth','Manchester','Lancashire','UNITED KINGDOM','M35 0DL','01616826020','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-21 12:57:43',0,NULL,3,1,2,1,' ','cheekyninjaboy'),(13415,742243263002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','tapachai','f-k-s@mail.ru','Konstantin Fedotov','Krasniy pereulok, dom 14, kv.93','Alexandrov','Vladimirskaya oblast','RUSSIAN FEDERATION','601655','+7(919)0252570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:01:51',0,NULL,3,1,17,0,NULL,'tapachai'),(13416,700722723001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','tapachai','f-k-s@mail.ru','Konstantin Fedotov','Krasniy pereulok, dom 14, kv.93','Alexandrov','Vladimirskaya oblast','RUSSIAN FEDERATION','601655','+7(919)0252570','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 13:01:52',0,NULL,3,1,5,1,'CP227168169CN ','tapachai\r反光板支架    1\r灯架  2m       2\r斜臂         1'),(13417,755897302017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',12.78,'photographyacc','princess*teare*','teare69@hotmail.com','Teare O\'Brien','1/7 mason street<br>southport','Gold Coast','Queensland','AUSTRALIA','4215','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 13:07:59',0,NULL,3,1,2,1,' ','princess*teare*\r中号内胆包 nikon   1\rd300眼罩    2'),(13418,700730647001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',2,'AC2401',39.78,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:33:16',0,NULL,3,1,17,0,NULL,'nixette_nixette'),(13419,700731277001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 13:34:58',0,NULL,3,1,5,1,'CP227168138CN','nixette_nixette\r圆形柔光棚 40cm      2\r圆形柔光棚 60cm     1\r反光板  80cm 5合1       2'),(13420,742261919002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','westcoaster2501','yourkitchencompany@gmail.com','Richard Sulzinger','3607 Lavista Rd','Decatur','GA','UNITED STATES','30033-1003','(404) 550-4517','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 14:10:38',0,NULL,3,1,1,1,NULL,'westcoaster2501'),(13421,700753620001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','carlafrancesetti','ncondeza@gmail.com','carla francesetti','Larrain Alcalde 1153','la serena','chile coquimbo cuarta','CHILE','1700000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 14:56:45',0,NULL,3,1,3,1,'RA183614885CN ','carlafrancesetti'),(13422,755956444017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','holipet','peter.holian@telstra.com','Peter Holian','6 Royston Court','Brookfield','Victoria','AUSTRALIA','3338','0397478339','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 15:35:12',0,NULL,3,1,2,1,NULL,'holipet'),(13423,700766814001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','apinheirinho','pinheirinho1986@gmail.com','Augusto Pinheirinho','Rua João Martins n.º 41','Setúbal','Setúbal','PORTUGAL','2910-160','(+351)913933701','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 15:35:26',0,NULL,3,1,3,1,'RA183614894CN ','apinheirinho'),(13424,755921549017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','kwzaki','kawazakia@yahoo.com.au','Brad Grauls','14319 Pacific Hwy,<br>Nabiac Caravan Park Site 29','Nabiac','New South Wales','AUSTRALIA','2312','0265541112','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 15:48:41',0,NULL,3,1,2,1,NULL,'kwzaki'),(13425,700783113001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','greatscottd','greatscottd@yahoo.com','Scott Dorrofield','PO Box 12213<br>Mill Street','Cape Town','Western Cape','SOUTH AFRICA','8010','270762061194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 16:27:04',0,NULL,5,1,18,0,NULL,'greatscottd\rlenspen     1\r三脚架 伟峰 EI-717     1'),(13426,700785964001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 16:31:12',0,NULL,3,1,17,0,NULL,'gifou'),(13427,742309047002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 16:33:47',0,NULL,3,1,17,0,NULL,'gifou'),(13428,700787677001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3302',6.5,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 16:33:48',0,NULL,3,1,5,1,'CP227168141CN ','gifou\r独脚架  伟峰 WT-1005    1\r三脚架  伟峰 WF-6662A      1\r绿叶 UV  55mm          2'),(13429,755979955017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',29.85,'photographyacc','joshnich0603','ebay@joshuanicholson.com.au','Joshua Nicholson','PO Box 229','Hornsby','New South Wales','AUSTRALIA','2077','0294771052','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 16:43:40',0,NULL,3,1,3,1,'RA183615104CN ','joshnich0603\rCANON  58   反接环     1\r圆形柔光棚 50cm        1\r我算过挂号比递四方贵3元钱'),(13430,742312770002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','greatscottd','greatscottd@yahoo.com','Scott Dorrofield','PO Box 12213<br>Mill Street','Cape Town','Western Cape','SOUTH AFRICA','8010','270762061194','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 16:44:59',0,NULL,3,1,17,0,NULL,'greatscottd'),(13431,700799165001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','eshop_masenka','masenka@masenka.eu','Miroslav Horák','Jiřího Wolkera 1888<br>eshop.masenka@masenka.eu','Nymburk','ČR','CZECH REPUBLIC','28802','+420606204980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 17:07:03',0,NULL,3,0,2,1,NULL,'eshop_masenka\r1.6*2.1 白色背景布   1'),(13432,742331186002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','tt9001','schreib.doch.mal@gmx.de','Holger Blaschke','Fledermausweg 6','Garbsen','','GERMANY','30823','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 17:32:12',0,NULL,3,1,3,1,'RA183615078CN ','tt9001\r绿叶近摄镜 +8  67mm  换成 +4的'),(13433,756002809017,270755015673,'New 800W Red Head Continuous Light Lighting 1 x Bulb',1,'AKT055',75.8,'photographyacc','85shaiky','shaiky85@gmail.com','sadiq hassan mirza','house:1397 raod:3139<br>block:231 dair','Muharraq','Bahrain','BAHRAIN','973','0097339444501','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-21 17:49:41',0,NULL,3,1,3,1,'RA183614877CN ','85shaiky\r发一个欧转英标头'),(13434,742354859002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','erasure153','se4m_2u@hotmail.com','SALEH ALGHASHAM','WADI ALSHOARA 4069<br>heten.er','RIYADH','riyadh','SAUDI ARABIA','11322','00966548888303','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 18:33:27',0,NULL,3,0,3,1,'RA183614951CN ','erasure153\rXXXL     \r（已入库）\r新地址：\rSALEH ALGHASHAM\rWADI ALSHOARA 4069\rheten.er\rp.o.box 242191\rRIYADH riyadh 11322\rSAUDI ARABIA\r00966548888303'),(13435,700837900001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','virproduction','wmbrecords@gmail.com','Rikky Baynes','3400 Veterans Dr<br>Ste 2','St Thomas','STTHOMAS','VIRGIN ISLANDS (U.S.)','00802-5748','3402447643','NoPaymentFailure','CheckoutComplete','Other','2011-07-21 18:42:33',0,NULL,3,1,1,1,NULL,'virproduction'),(13436,700840747001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','*backyard_dog*','ohkulungele@gmail.com','Francisco Díaz Pérez','Av. Primo de Rivera 3 Cafeteria Las Vegas','A Coruña','Galicia','SPAIN','15006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 18:50:01',0,NULL,3,1,3,1,'RA183614996CN ','*backyard_dog*'),(13437,822401928015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','jjbstolk','jjbstolk@famstolk.nl','JJB Stolk','Schoolkade 11','Musselkanaal','','NETHERLANDS','9581HA','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 20:19:32',0,NULL,3,1,3,1,'RA183614979CN ','jjbstolk'),(13438,742405598002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',108,'hermeshine','escolamel','madmasterz@hotmail.com','Meelis Eskola','Õismäe tee 120-11','Tallinn','','ESTONIA','13513','+3725573405','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-21 20:24:40',0,NULL,3,1,3,1,'RA183615016CN ','escolamel'),(13439,700896603001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','rhodzlan','allray15@yahoo.com','Allan Vallada','Dubai Internet City, Building no. 6 Siemens Building<br>United Arab Emirates.PO Box 2154','Dubai','Dubai','UNITED ARAB EMIRATES','2154','00971552001309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 20:49:57',0,NULL,3,1,2,1,' ','rhodzlan'),(13440,742419738002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tricomdex','sillyrabbitz@hotmail.com','Simon Lee','86 Withrow ave','Toronto','ON','CANADA','M4K1C9','(416) 984-1599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 20:58:40',0,NULL,3,1,2,1,NULL,'tricomdex'),(13441,742419962002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',3,'AA3408',29.97,'hermeshine','rlajos','rlajos@r-med.com','Lajos Rozsavolgyi','Brasso Str. 83-85.','Budapest','','HUNGARY','H1112','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 21:05:13',0,NULL,3,1,2,1,NULL,'rlajos'),(13442,742432126002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','mary919green','swillowness@gmail.com','Sara Baucom','5741 Windward Ct NW','Concord','NC','UNITED STATES','28027-9027','(704) 784-4299','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-21 21:32:51',0,NULL,3,1,1,1,NULL,'mary919green'),(13443,701390992018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','sunshine_daisies_07','pdmk10@gmail.com','Cake DeZines','21 Dunheved circle','Dubbo','New South Wales','AUSTRALIA','2830','0268829662','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-21 21:39:14',0,NULL,3,0,2,1,NULL,'sunshine_daisies_07\r1.6*2.1   白色背景布    1'),(13444,742439062002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','avento0106','steve_lodewyke@hotmail.com','Steve Lodewyke','501/2 First Lane, Mahabage','Ragama','Western Province','SRI LANKA','GQ 11010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-21 21:54:48',0,NULL,3,1,2,1,NULL,'avento0106'),(13445,822452713015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','allvol','allvol09@gmail.com','Alexander Volkov','Lobachevskogo st.,  d.4, kv. 5','Penza','','RUSSIAN FEDERATION','440034','89631092816','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-21 22:06:37',0,NULL,3,1,2,1,NULL,'allvol'),(13446,701438602018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','cjpurcell','steve@selectindustries.com.au','Stephen Greenlees','85 Barnetts Road<br>Winston Hills','Sydney','New South Wales','AUSTRALIA','2153','0296393532','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 00:28:13',0,NULL,3,1,3,1,'RA183614982CN ','cjpurcell'),(13447,756170519017,270755015673,'New 800W Red Head Continuous Light Lighting 1 x Bulb',1,'AKT055',75.8,'photographyacc','majesticstudio','donnie@majesticstudio.com.au','Mos Mobiles - Att : Donnie','Kiosk 11<br>Crn Derrimut & Heaths Rd','Werribee','Victoria','AUSTRALIA','3030','0412102646','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-22 00:32:45',0,NULL,3,1,4,1,'YW866127080CN ','majesticstudio\r放一个欧转澳标头\r▲  已经发信 '),(13448,700956051001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','msst9118','tlee91@ec.rr.com','tina lee','102 Britlee ct','Rocky point','NC','UNITED STATES','28457','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 00:37:00',0,NULL,3,1,1,1,NULL,'msst9118\r环换成52的'),(13449,701445069018,280683088500,'Mini IR Wireless Remote Control for Pentax 200D 10D 20D',1,'AD1118',4.5,'photographyacc','kweegeebo','jamesmac@optusnet.com.au','James McDonell','42A Admiral Dr','Dolphin Heads','Queensland','AUSTRALIA','4740','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-22 00:44:54',0,NULL,3,1,2,1,NULL,'kweegeebo'),(13450,742484953002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','herhummmm','kneissshad@aol.com','Patricia Kneiss','5315 Highway 33 S','New Tazewell','TN','UNITED STATES','37825-2537','(865) 235-5444','NoPaymentFailure','CheckoutComplete','Other','2011-07-22 01:03:03',0,NULL,3,0,1,1,NULL,'herhummmm\rXXL   \r(已入库）'),(13451,8881311298518818,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',21.05,'hermeshine','Ali Express','vt683946@base.be','Peters of Knoben','Heuvelsvenlaan 6 ,Lanklaar','Limburg','','BELGIUM','3650','+0032 89 412451',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183614965CN ','申报: Light box $15'),(13452,756190161017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','dsahay09','dsahay@gmail.com','Dhananjay  Sahay','903<br>91B Bridge Road','Westmead','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 01:53:43',0,NULL,3,1,2,1,NULL,'dsahay09'),(13453,742507126002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','crazyboiz64','atlblaz3@netzero.com','thong nguyen','2375 una antioch pike','antioch','TN','UNITED STATES','37013','(615) 585-0313','NoPaymentFailure','CheckoutComplete','Other','2011-07-22 02:38:27',0,NULL,3,1,17,0,NULL,'crazyboiz64'),(13454,700983254001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','crazyboiz64','atlblaz3@netzero.com','thong nguyen','2375 una antioch pike','antioch','TN','UNITED STATES','37013','(615) 585-0313','NoPaymentFailure','CheckoutComplete','Other','2011-07-22 02:41:03',0,NULL,3,1,3,1,'RA183615020CN ','crazyboiz64\r Canon  老款  M         1  \r Nikon 老款  M          1'),(13455,756202664017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','frcfed87','mylastemailsucked@gmail.com','Matthew Micallef','2/12 Walter Street','East Geelong','Victoria','AUSTRALIA','3219','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 02:47:53',0,NULL,3,1,3,1,'RA183615055CN ','frcfed87\r澳标'),(13456,701479082018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','2005tameaka','bradandtamdarby@hotmail.com','Tameaka J Darby','Po Box 73','Mallala','South Australia','AUSTRALIA','5502','0439847756','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 03:42:46',0,NULL,3,0,2,1,NULL,'2005tameaka\r1.6 *2.1  白色背景布    1'),(13457,701011249001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 05:24:00',0,NULL,3,0,17,0,NULL,'nixette_nixette'),(13458,756246486017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',91.8,'photographyacc','diemonmw','diemon2005@rambler.ru','Dmitriy Kozlov','Post Box 4/21','Khabarovsk','Khabarovski krai','RUSSIAN FEDERATION','680000','79145464944','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 06:29:56',0,NULL,3,1,3,1,'RA183615095CN \r','diemonmw\r肩架   1\r永诺 SF18- CANON   1\r'),(13459,756261654017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','monashian85','garyliang.corporate@gmail.com','JinHao Gary Liang','unit 2306/288 Spencer Street','Melbourne CBD','Victoria','AUSTRALIA','3000','0401391349','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-22 07:43:05',0,NULL,3,0,4,1,'YW866127021CN','monashian85\rtripod $20'),(13460,742573705002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','istokka','admoccia@alice.it','antonio chiacchio','via gramsci 55','frattaminore','NA','ITALY','80020','3382570193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 08:49:47',0,NULL,3,1,3,1,'RA183615064CN ','istokka\rflash accessory $12'),(13461,822648224015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','jimmykeys','jim.miller@btconnect.com','Jim Miller','7 Wilfrids Wood Close<br>Flackwell Heath','High Wycombe','Buckinghamshire','UNITED KINGDOM','HP10 9LJ','7505136279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 10:31:05',0,NULL,3,1,3,1,'RA183615427CN\r ','jimmykeys'),(13462,742599853002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','zoharbartuv','zoharbt@gmail.com','zohar bartuv','kvutzat yavne','kvutzat yavne','','ISRAEL','79233','97288548235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 10:55:22',0,NULL,3,1,17,0,NULL,'zoharbartuv'),(13463,742595704002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','zoharbartuv','zoharbt@gmail.com','zohar bartuv','kvutzat yavne','kvutzat yavne','','ISRAEL','79233','97288548235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 10:55:22',0,NULL,3,1,3,1,'RA183615515CN ','zoharbartuv\r灯架包薄        1\r2B柔         1  '),(13464,805566324016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','paulrs431','paulrs@gotadsl.co.uk','singh paul','528 kingsway<br>didsbury','manchester','Greater Manchester','UNITED KINGDOM','m191gw','01614315100','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 11:11:12',0,NULL,3,1,3,1,'RA183615223CN\r ','paulrs431'),(13465,742566432002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sirbaffo','casusbelli80@gmail.com','Fabio Mariggiò','Via Lea Padovani 11 b/c','Roma','RM','ITALY','00138','3480841945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-22 11:31:16',0,NULL,3,0,3,1,'RA183615373CN\r ','sirbaffo\rL     (已入库）\rPhoto Vest       $15'),(13466,822668493015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','jun1920','paulcathrussell@gmail.com','Paul Russell','Labaure<br>Lemouzy','Lafrancaise','','FRANCE','82130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 11:31:39',0,NULL,3,1,2,1,NULL,'jun1920'),(13467,701593247018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',6.6,'photographyacc','roodychan','lmrchan@hotmail.com','Raymond Chan','Advanced Medical Institute<br>Level 4, 80 William Street','East Sydney','New South Wales','AUSTRALIA','2011','0410870718','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 12:11:48',0,NULL,3,1,2,1,NULL,'roodychan'),(13468,701099108001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','dmei72','dmeier@tm.uka.de','Detlev Meier','Universität Karlsruhe, Institut für Telematik<br>Zirkel 2','Karlsruhe','','GERMANY','76131','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-22 12:25:15',0,NULL,3,1,3,1,'RA183615308CN\r ','dmei72'),(13469,805594594016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','pianorealm','pianorealm@aol.com','Howard Smith','41 Shaw Hall Bank road','Greenfield Saddleworth','Oldham','UNITED KINGDOM','OL3 7LD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 12:39:13',0,NULL,3,1,3,1,'RA183615210CN\r ','pianorealm'),(13470,700714375001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','stayfun290771','stephanschreiner@gmx.at','Stephan Schreiner','Gmundnerstrasse 104','Vöcklabruck','','AUSTRIA','4840','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 13:49:56',0,NULL,3,1,2,1,NULL,'stayfun290771'),(13471,701625082018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','justo79','killdog981@hotmail.com','Olivier Plusquellec','37 rue Desnouettes','Paris','Ile-de-France','FRANCE','75015','0684106502','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 13:57:26',0,NULL,3,1,2,1,NULL,'justo79'),(13472,742667001002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','stanislausk','staskalinin@mail.ru','Stanislav Kalinin','ul. im. 8-oi Vozdushnoy Armii<br>dom 31 kv 101','Volgograd','','RUSSIAN FEDERATION','400117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 14:52:55',0,NULL,3,1,17,0,NULL,'stanislausk'),(13473,742675042002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','limadanilo','email.danilo@gmail.com','DANILO LIMA','RUA ANA ORTEGA TRABALLI, 30 - CASA 22','SAO JOSE DOS CAMPOS','SAO PAULO','BRAZIL','12213-215','+55 12 91317964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 15:13:00',0,NULL,3,1,2,1,NULL,'limadanilo'),(13474,701654165018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','tan6111','picky@iinet.com.au','paul pickthorn','8 hunter drive','lesmurdie','Western Australia','AUSTRALIA','6076','0892913096','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-22 15:25:14',0,NULL,3,1,2,1,NULL,'tan6111'),(13475,700112828001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',2,'AC2401',39.78,'hermeshine','della661','dellatax@aol.com','Della Sehm','8223 Essex Ct','Bakersfield','CA','UNITED STATES','93311','(661) 665-9166','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 15:49:27',0,NULL,3,1,3,1,'RA183614585CN  ','della661'),(13476,742692478002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',35,'hermeshine','mrerictbrown','vash_mk2434@yahoo.com','eric brown','103 forsythia dr n','levittown','PA','UNITED STATES','19056-1935','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-22 16:07:02',0,NULL,3,1,1,1,NULL,'mrerictbrown'),(13477,742701200002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','stanislausk','staskalinin@mail.ru','Stanislav Kalinin','ul. im. 8-oi Vozdushnoy Armii<br>dom 31 kv 101','Volgograd','','RUSSIAN FEDERATION','400117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 16:27:34',0,NULL,3,1,5,1,'CP227168075CN ','stanislausk\r2B柔      2\r灯架包薄       1'),(13478,805685491016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','timurxan377','tmrxan@rambler.ru','Timur Galyamov','pr.mira 93v, 5kv.<br>22/03 - 5kv.','Naberezhnye Chelny','Respublika Tatarstan','RUSSIAN FEDERATION','423821','(927)0435776','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 16:30:49',0,NULL,3,1,2,1,NULL,'timurxan377'),(13479,742720747002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','tiga79','tom.bonroy@skynet.be','tom bonroy','mortelbroekstraat 58','Averbode','','BELGIUM','3271','013777169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:22:03',0,NULL,3,1,17,0,NULL,'tiga79'),(13480,701194866001,110587046983,'New Camera shoulder bag N2 for Canon with raincover',1,'AD1104',25.99,'hermeshine','luckyxman','pavolkert@gmail.com','Pavol KERTESZ','Nam.priatelstva 2172/28','Dunajska Streda','','SLOVAK REPUBLIC','92901','+421903427399','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-22 17:24:24',0,NULL,3,1,3,1,'RA183615529CN ','luckyxman'),(13481,742722001002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','tiga79','tom.bonroy@skynet.be','tom bonroy','mortelbroekstraat 58','Averbode','','BELGIUM','3271','013777169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:24:53',0,NULL,3,1,17,0,NULL,'tiga79'),(13482,701195853001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','tiga79','tom.bonroy@skynet.be','tom bonroy','mortelbroekstraat 58','Averbode','','BELGIUM','3271','013777169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:26:58',0,NULL,3,1,17,0,NULL,'tiga79'),(13483,742723848002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','tiga79','tom.bonroy@skynet.be','tom bonroy','mortelbroekstraat 58','Averbode','','BELGIUM','3271','013777169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:29:14',0,NULL,3,0,17,0,NULL,'tiga79'),(13484,701198980001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',2.18,'hermeshine','tiga79','tom.bonroy@skynet.be','tom bonroy','mortelbroekstraat 58','Averbode','','BELGIUM','3271','013777169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:36:00',0,NULL,3,1,3,1,'RA183615166CN\r ','tiga79\r方镜广角托架（ 一槽）     1\r天涯方形滤镜  渐变蓝      1\r方形滤镜接口环 77mm     1\r方镜普通托架（三槽）    1\r方形滤镜接口环 55mm    1\r天涯方形滤镜   渐变橙     1'),(13485,701200301001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','kate12789','pdd_polina@yahoo.com','Ian Onica','str. Fintinilor 34/1','Chisinau','','MOLDOVA, REPUBLIC OF','2038','079595573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 17:39:14',0,NULL,3,1,3,1,'RA183615183CN\r ','kate12789'),(13486,805739582016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gr8stuff247','angelerediauwa@yahoo.com','angel iguehide erediauwa','FLAT 15, TRAFALGAR COURT<br>Marine Drive','Barking','Essex','UNITED KINGDOM','IG11 0GN','07572075677','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'gr8stuff247\r需要等echeck清了再发货\r'),(13487,701737267018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',3,'AE1201',13.2,'photographyacc','jrb2022','jblom@gto.net','James Blomfield','471 Laurel Gate Drive','Waterloo','ON','CANADA','N2T 2S1','(519) 885-3450','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 18:55:58',0,NULL,3,1,2,1,NULL,'jrb2022'),(13488,701232393001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',3,'AA2101',107,'hermeshine','prolific_hasbeen','scheuerv@nucleus.com','Vic Scheuerman','103 Beaconsfield Rd NW','Calgary','AB','CANADA','T3K 1X8','(403) 275-2622','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-22 18:58:56',0,NULL,3,1,3,1,'RA183615413CN\r ','prolific_hasbeen\r已入库\r3个'),(13489,701233300001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','ausainais','saveejais@gmail.com','Arnis Usackis','44 streatham vale','London','London','UNITED KINGDOM','sw16 5td','07403127195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 19:00:35',0,NULL,3,1,3,1,'RA183615299CN\r ','ausainais'),(13490,805773778016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',2,'AKT051',15.04,'hutongstore','goodboy332','goodboy332@yahoo.com','Eleftherios Milothridis','Salaminas 3','Kavala','Greece','GREECE','65403','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 19:30:11',0,NULL,3,1,2,1,NULL,'goodboy332\r注意是4只'),(13491,756510509017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','egut7992','edwardsphotography@live.com','Edward Gutierrez','5658 N 6th St','Fresno','CA','UNITED STATES','93710-6348','(559) 367-9673','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-07-22 20:15:50',0,NULL,5,0,18,0,NULL,'egut7992\r灯泡是45w 110v  的\r Lighting Kit       $28'),(13492,822910926015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','0138nan43','kenneth.day@sky.com','Kenneth Day','7 Newtown<br>Brierley Hill','Dudley','West Midlands','UNITED KINGDOM','DY5 3XU','0138474199','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-22 20:41:09',0,NULL,3,1,2,1,NULL,'0138nan43'),(13493,742822537002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','ofiri','ofir.itz@gmail.com','Ofir Itzhaki','Alon 6/2','Yoqneam','','ISRAEL','20692','972542630265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 21:41:02',0,NULL,3,1,11,1,NULL,'ofiri'),(13494,701297579001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 21:55:15',0,NULL,3,1,2,1,NULL,'m.petrosyan'),(13495,822947435015,250615144668,'YongNuo Flash Battery Pack 8*AA Canon Flash 580EXII 550',1,'AB3307',32.99,'hutongstore','anderssonbros','nisse@anderssonbros.com','Thomas Andersson','Barnstensvagen 1','LODDEKOPINGE','Skane','SWEDEN','24634','+4646705751','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 22:07:49',0,NULL,3,1,3,1,'RA183615271CN\r ','anderssonbros'),(13496,701303569001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','costasymiak','symiakcos@gmail.com','COSTAS SYMIAKAKIS','3 TRYFITSOY STR','HERAKLION-CRETE','προεπιλογή','GREECE','71201','0306944777123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 22:15:41',0,NULL,3,1,2,1,' ','costasymiak'),(13497,756572453017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','paciaruch','paruchadam@gmail.com','Adam Paruch','Aleja Pokoju<br>30/26','Kraków','małopolskie','POLAND','31564','12 4110604','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 22:40:34',0,NULL,3,1,2,1,NULL,'paciaruch'),(13498,822971111015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-22 23:27:26',0,NULL,3,1,17,0,NULL,'donald1970'),(13499,805855312016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 23:27:26',0,NULL,3,1,17,0,NULL,'donald1970'),(13500,822969829015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',3,'AD1402',16.2,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 23:27:27',0,NULL,3,1,17,0,NULL,'donald1970'),(13501,822969268015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',15.5,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 23:27:27',0,NULL,3,1,17,0,NULL,'donald1970\r'),(13502,822968142015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 23:27:28',0,NULL,3,1,17,0,NULL,'donald1970'),(13503,822968306015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-22 23:27:28',0,NULL,3,1,4,1,'YW866127091CN ','donald1970\r115w 5500k 灯泡  220v   2\r反光板支架     1\r柔光伞     3 \r单灯头 欧标      2\r灯架  2m       3\rlighting kit     $25\r'),(13504,742852593002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','wyeekhai','wyeekhai2000@yahoo.com.sg','Wang Yee Khai','Blk 291C, Bukit Batok St 24<br>#14-33, Singapore 652291','default','','SINGAPORE','652291','(65)90170508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-22 23:44:16',0,NULL,3,1,11,1,NULL,'wyeekhai'),(13505,756591864017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',7.28,'photographyacc','javiersevilla','jimenez150@ono.com','JAVIER JIMENEZ GONZALEZ','FERNANDO VILLALON 1,7A','SEVILLA','SEVILLA','SPAIN','41004','637753050','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-22 23:57:35',0,NULL,3,1,2,1,NULL,'javiersevilla'),(13506,756612823017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','drax57-2010','clarkedg@rogers.com','Dana G. Clarke','5825 Gladewoods Pl','Orleans','ON','CANADA','K1W 1G5','(613) 841-3621','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-23 01:33:10',0,NULL,3,1,2,1,NULL,'drax57-2010'),(13507,756618356017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','cromptj','crommos@optushome.com.au','Jeff Crompton','5 Inkerman Rd','Emu Heights','New South Wales','AUSTRALIA','2750','0423020225','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 01:59:05',0,NULL,3,1,2,1,NULL,'cromptj'),(13508,701351369001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','natali90000','sagitarius74@comcast.net','natalia nayda','3046 vine ave','millville','NJ','UNITED STATES','08332-3034','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-23 02:13:06',0,NULL,3,1,1,1,NULL,'natali90000'),(13509,701746362018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',183.5,'photographyacc','vetals777','vitaliy.nechiporenko@gmail.com','Vitaliy Nechiporenko','pereulok SHTABNOY 6,<br>kvartira 220,','Dnepropetrovsk','','UKRAINE','49049','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-23 03:41:43',0,NULL,3,1,5,1,'CP227168067CN ','vetals777\r60*90 通用金属卡口棚     1\r70*100通用金属卡口棚     1\r背景架2mx2m  + 3个夹子      1\r背景布 1.6 *2.1    黑色       1\r背景布 1.6 *2.1   白色       1'),(13510,701896106018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','chef.gandhi','alok.h.gandhi@gmail.com','alok gandhi','22/146-152 parramatta road','homebush','New South Wales','AUSTRALIA','2140','0425425427','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 04:46:56',0,NULL,3,1,2,1,NULL,'chef.gandhi'),(13511,701374446001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','andyisdead','andyisdead.81@gmail.com','Andrea Cosentino','Salita Viarno 38','Viganello','','SWITZERLAND','6962','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 04:49:51',0,NULL,3,1,17,0,NULL,'andyisdead'),(13512,742909047002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','andyisdead','andyisdead.81@gmail.com','Andrea Cosentino','Salita Viarno 38','Viganello','','SWITZERLAND','6962','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 04:49:51',0,NULL,3,1,3,1,'RA183615268CN\r ','andyisdead\r永诺 Canon ttl线  3m     1\r闪光灯B座     1'),(13513,701914070018,280663394249,'Photo Studio Background Support + Free Backdrop (white)',1,'AO0009',74,'photographyacc','ddv201010','dd0190@ya.ru','Dozinova Valentina M','Ordzhonikidze<br>d.2 kv.85','Balashov','Saratovskaya Obl','RUSSIAN FEDERATION','412300','+78454521638','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-23 06:40:08',0,NULL,3,1,5,1,'CP227168053CN ','ddv201010\r应该是有一块白布    王  是白布\r1.6*2.1  白色背景布   1'),(13514,701928444018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',7.28,'photographyacc','dhae2','dpc_85@hotmail.com','Daniel Pérez Chamorro','C/ Can mainou nº30 Los Manantiales. Bigues i Riells','Barcelona','Cataluña','SPAIN','08415','620703392','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-23 07:53:07',0,NULL,3,1,2,1,NULL,'dhae2'),(13515,823090160015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',5.5,'hutongstore','chgfan','chank2000@hotmail.com','Kevin Chan','140 Roma<br>Victoria Wharf','Cardiff','Cardiff','UNITED KINGDOM','CF110SH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 08:00:42',0,NULL,3,1,2,1,NULL,'chgfan'),(13516,756700215017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','desnov2006','cithavagha_81@hotmail.com','Novi Sugiyanty','Lighting Design Partnership (LDP)<br>213-217 Palmer Street','Darlinghurst','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 09:00:10',0,NULL,3,1,2,1,' ','desnov2006'),(13517,742960273002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.78,'hermeshine','rcwtan','rcwtan@ausdoctors.net','Roger Tan','20 Bernier Road','Shelley','Western Australia','AUSTRALIA','6148','610434407113','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-07-23 09:11:59',0,NULL,3,1,3,1,'RA183615461CN\r ','rcwtan\r澳标'),(13518,701958882018,280666783637,'Photo Video Light Stand Studio Photo Stand 6ft 2m x 2',1,'AKT031',49,'photographyacc','ripperjerome','troyrodgers@bigpond.com','Troy Rodgers','26 Sixth Avenue','South Townsville','Queensland','AUSTRALIA','4810','0747210709','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 10:08:18',0,NULL,3,1,17,0,NULL,'ripperjerome'),(13519,701958560018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','ripperjerome','troyrodgers@bigpond.com','Troy Rodgers','26 Sixth Avenue','South Townsville','Queensland','AUSTRALIA','4810','0747210709','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-23 10:08:19',0,NULL,3,1,4,1,'YW866127150CN ','ripperjerome\r灯架  2m     2\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子    1\rbackground support  $35'),(13520,700685476001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','robcowing89','robincow89@hotmail.it','ROBERTO VACCA','VIA BRINDISI 5','LATIANO','BR','ITALY','72022','3201114053','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-23 11:56:34',0,NULL,3,1,3,1,'RA183615325CN\r ','robcowing89\r已入库\rPhoto Vest    $15\rxl'),(13521,756755389017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','motopro111','dajwhite@optusnet.com.au','David white c/- Apromo Trading','92A Reserve Road<br>Artarmon','Sydney','New South Wales','AUSTRALIA','2064','0299061389','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 12:06:27',0,NULL,3,1,2,1,NULL,'motopro111'),(13522,702003029018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-23 12:31:13',0,NULL,3,1,6,1,'EE495341003CN ','wikran'),(13523,701482693001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','olexter','olexandr.tereshchenko@gmail.com','Olexandr Tereshchenko','271, 4/15 Pryluzhna str.','Kyiv','','UKRAINE','03179','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 12:44:13',0,NULL,3,1,2,1,NULL,'olexter'),(13524,756786451017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','grumpyis66','masterpiece131@gmail.com','Peter Tomkins','PO Box 417','Elizabeth','South Australia','AUSTRALIA','5112','0882527336','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-23 13:40:03',0,NULL,3,1,2,1,NULL,'grumpyis66'),(13525,743037051002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ddcii','clarkdonald@hotmail.com','Donald D Clark','601 Blackwood Street','Sacramento','CA','UNITED STATES','95815','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-23 13:52:43',0,NULL,3,1,1,1,NULL,'ddcii'),(13526,743043816002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','r.dmitriy','r.dmitriy@yahoo.co.uk','Dmitriy Ryabchenko','Sarayevo str.20, apt.192','Baku','Ahmedli','AZERBAIJAN','AZ1149','994556358845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 14:14:17',0,NULL,3,1,2,1,NULL,'r.dmitriy'),(13527,823228818015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28.9,'hutongstore','hyperx159','mavric.said@gmail.com','Mavric Said','74 Redeemer house<br>Guze Duca Street','Qormi','Malta','MALTA','QRM 9088','(356) 21 448033','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-23 14:34:31',0,NULL,5,1,3,1,'RA183615197CN\r ','hyperx159\r已经发货了  但是点不了'),(13528,823239133015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',2,'AC1201',4.36,'hutongstore','sadgom1950','sfj100@btinternet.com','Stephen Jones','Old School, Snods Edge<br>Shotley Bridge','Consett','Durham','UNITED KINGDOM','DH8 9LE','01207255437','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 14:58:49',0,NULL,3,1,17,0,NULL,'sadgom1950'),(13529,823238714015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','sadgom1950','sfj100@btinternet.com','Stephen Jones','Old School, Snods Edge<br>Shotley Bridge','Consett','Durham','UNITED KINGDOM','DH8 9LE','01207255437','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 14:58:50',0,NULL,3,1,2,1,NULL,'sadgom1950\r镜头筒 小号         2\r3片装的滤镜袋      1'),(13530,823252509015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','amanda270583','afreeman63@googlemail.com','a.freeman','57 new parks boulevard','leicester','leicestershire','UNITED KINGDOM','le39pu','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 15:27:38',0,NULL,3,1,2,1,NULL,'amanda270583'),(13531,700380863018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','delphine411','l.dore@online.fr','DORE DELPHINE','7 RUE LE MEUNIER','BATILLY','other','FRANCE','54980','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-23 15:54:45',0,NULL,3,1,4,1,'YW866127146CN ','delphine411\rLighting Kit    $28\r▲ 已发信'),(13532,702086908018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','pakarry','gpvelilla@hotmail.com','GERMAN CARRICONDO LOPEZ','C/DE LA ACACIA Nº13 2ºA','VELILLA DE SAN ANTONIO','Madrid','SPAIN','28891','676212458','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-23 16:22:58',0,NULL,3,1,3,1,'RA183615532CN\r ','pakarry'),(13533,701599418001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','annaarevik','anna@nfsat.am','Anna Baghramyan','16block<br>House 47, apt.31','Yerevan','Armenia','ARMENIA','0097','+37491365440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-23 18:08:22',0,NULL,3,1,3,1,'RA183615311CN\r ','annaarevik\r   M    已入库'),(13534,743140390002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rufititu','rufititu@hotmail.com','ivan tornel sala','virgen del rocio 2 bloke 11 1-b','alicante','alicante','SPAIN','03009','629244930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 18:25:47',0,NULL,3,1,17,0,NULL,'rufititu'),(13535,701607247001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','rufititu','rufititu@hotmail.com','ivan tornel sala','virgen del rocio 2 bloke 11 1-b','alicante','alicante','SPAIN','03009','629244930','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-23 18:27:29',0,NULL,3,1,3,1,'RA183615550CN\r ','rufititu\rlenspen   1\r独脚架  伟峰 WT-1005    1'),(13536,701608594001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','juliangv','jgamon2@gmail.com','Julian Gamon','calle el roble nº33','Burguillos, Sevilla','Andalucía Ceuta y Melilla','SPAIN','41220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 18:28:09',0,NULL,3,1,2,1,NULL,'juliangv'),(13537,806244383016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','winni_l','winfried.loer@gmx.net','Winfried Loer','Taunusstr. 16','Flacht','','GERMANY','65558','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-23 19:00:06',0,NULL,3,1,2,1,NULL,'winni_l\r新款的闪光灯座，和B座很像的白色盒子里'),(13538,701628401001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','mosszen','mosszengb@gmail.com','Edward Chan','89 Moss Creek Boulevard','Markham','ON','CANADA','L6C 2J2','(416) 720-3212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 19:14:10',0,NULL,3,1,3,1,'RA183615254CN\r ','mosszen'),(13539,701676373001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','frohnhofer','tomfrohnhofer@me.com','Tom Frohnhofer','21 Elgar Close','London','London','UNITED KINGDOM','E13 9EW','07789433441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 21:20:24',0,NULL,3,1,2,1,NULL,'frohnhofer'),(13540,743212744002,120752153194,'Photo Studio Background Support Carrying Carry Bag',2,'AD1129',19.8,'hermeshine','borborhick','jill@parentsworld.com','Jill Lassaline','216 Queen Anne Place SE','Calgary','AB','CANADA','T2J4S3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 21:27:48',0,NULL,3,1,2,1,NULL,'borborhick'),(13541,743214487002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',151.6,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 21:40:00',0,NULL,3,1,17,0,NULL,'fatimahali23'),(13542,743214767002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 21:40:00',0,NULL,3,1,3,1,'RA183615435CN\r','fatimahali23\r2b柔    4套 \r反光板支架   1\r2m 灯架    1\rRA183615339CN\rRA183615444CN\rRA183615458CN\rRA183615360CN\r\r\r\r'),(13543,701696528001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','msolbiondi','verde_manzana140205@hotmail.com','maria sol biondi','rivadavia<br>18100','moron','BUENOS AIRES','ARGENTINA','1708','0111534384334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 22:27:41',0,NULL,3,1,2,1,NULL,'msolbiondi'),(13544,743234301002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','jabollo','stundex@hotmail.com','Martin Jablonski','Dreieichstr. 21','Dietzenbach','','GERMANY','63128','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-23 22:40:04',0,NULL,3,1,3,1,'RA183615170CN\r ','jabollo'),(13545,701706977001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','trenguinho','hugoandrealves@gmail.com','Hugo Alves','Rua dos Prados, n. 44, 1 ESQ','Tenões','Braga','PORTUGAL','4715-595','(351) 91 9007028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 23:08:49',0,NULL,3,1,3,1,'RA183615546CN\r ','trenguinho'),(13546,743241835002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',25.99,'hermeshine','fmhmmbi','mbifmhm@nus.edu.sg','Feroz Musthafa','16 Jalan Lempeng #02-01','default','','SINGAPORE','128800','6596424290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-23 23:11:24',0,NULL,3,1,3,1,'RA183615356CN\r ','fmhmmbi'),(13547,823476840015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','jashamk1','jasha@lineone.net','Jenifer Shaw','11, Ryton Way<br>Stirchley','Telford','Shropshire','UNITED KINGDOM','TF3 1EP','01952596629','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-23 23:28:01',0,NULL,3,1,2,1,NULL,'jashamk1'),(13548,743249469002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','pozo012','pozojorge@hotmail.com','Jorge Pozo Estrella','Ramon Mas 21, 2º 2ª','Sant Cugat del Valles','Barcelona','SPAIN','08174','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-23 23:42:25',0,NULL,3,1,3,1,'RA183615206CN\r ','pozo012'),(13549,806375991016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','danny09121959','dmmbrown@slingshot.co.nz','Danny Brown','34 Rhinevale Close<br>Henderson','Auckland','Auckland','NEW ZEALAND','0612','+64 9 8368223','NoPaymentFailure','CheckoutComplete','NotSelected','2011-07-24 00:48:19',0,NULL,3,1,6,1,'EE495341184CN ','danny09121959'),(13550,743271271002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','pxthree','focus203@aol.com','Mark  A Carey','1513 Kennewick Rd','Baltimore','MD','UNITED STATES','21218','','NoPaymentFailure','CheckoutComplete','Other','2011-07-24 01:23:38',0,NULL,3,1,3,1,'RA183615603CN ','pxthree\r110v  的'),(13551,701739212001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','grizzlay47','grizzlay47@comcast.net','Carl E. Deater Jr.','5805 Meadow Dr','Frederick','MD','UNITED STATES','21702','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-24 01:41:19',0,NULL,3,1,1,1,NULL,'grizzlay47'),(13552,743283501002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','roger_awright','roger.b8@hotmail.com','Roger Becker','Nossa senhoras das Graças, 95','porto alegre','Rio Grande do sul','BRAZIL','90660-170','55-51-33078878','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 02:18:55',0,NULL,3,0,3,1,'RA183615400CN\r ','roger_awright\r3XL   '),(13553,743285740002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','netseller207','netseller207@yahoo.com','LEO MAKSYMCHOCK','4314 41st St','BRENTWOOD','MD','UNITED STATES','20722','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-24 02:30:39',0,NULL,3,1,1,1,NULL,'netseller207'),(13554,757090422017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',6.98,'photographyacc','kme52','spoonbill@westnet.com.au','Karen Ellis','Calibre Constructions<br>PO Box 1005','Wangara','Western Australia','AUSTRALIA','6947','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 04:35:57',0,NULL,3,1,2,1,NULL,'kme52'),(13555,757091381017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','luke.gharris','lukegharris@gmail.com','Benjamin Harris','11/27 Cadell St','Toowong','Queensland','AUSTRALIA','4066','0731031012','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 04:46:27',0,NULL,3,1,2,1,NULL,'luke.gharris'),(13556,742354188002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',30,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 05:29:51',0,NULL,3,1,3,1,'RA183615387CN\r ','bmonye\r已入库'),(13557,743318401002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','dima_rus_85','dima_rus@bk.ru','Dima Zanin','602 Hardenberg Ave','Point Pleasant Boro','NJ','UNITED STATES','08742-2829','(732) 581-8585','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 05:35:34',0,NULL,3,1,1,1,NULL,'dima_rus_85\r近摄镜换成 +4'),(13558,701777129001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','toddjobenchelsea','toddjochapman@bigpond.com','Todd Chapman','29 Wymah Cres','Berowra Heights','New South Wales','AUSTRALIA','2082','0294562501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 05:36:07',0,NULL,3,1,4,1,'YW866127135CN ','toddjobenchelsea\rLighting Kit   $40\r澳标'),(13559,701781336001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','dvk73','d.kolyadko@gmail.com','Dzmitry Kalyadka','kalinina 15 / 57','Dzerginsk','Minsk dstr','BELARUS','222720','+375297764361','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 05:41:36',0,NULL,3,1,5,1,'CP227168040CN ','dvk73'),(13560,743313201002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 05:57:54',0,NULL,3,1,3,1,'RA183615118CN\r ','franznawrath\r'),(13561,743323145002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','(819) 239-3099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 06:04:50',0,NULL,3,1,3,1,'RA183615489CN\r ','mickflag'),(13562,804466433016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','kagne1','kagneta1@gmail.com','AGNETA KARVELIENE','14 FORD ROAD','DAGENHAM','Essex','UNITED KINGDOM','rm10 9jt','07795964454','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-24 06:35:30',0,NULL,3,1,2,1,NULL,'kagne1'),(13563,701824155001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jianye.chen','jianye.chen@gmail.com','Jianye Chen','29316 Richardson CT','Highland','CA','UNITED STATES','92346','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-24 08:56:58',0,NULL,3,0,1,1,NULL,'jianye.chen\r1.6*2.1   蓝色背景布     1\r最好是天蓝的颜色'),(13564,757151112017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','dt3186','daren.trewin@telstra.com','Daren Trewin','5 Champion St.','Brighton','Victoria','AUSTRALIA','3186','0395921814','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 09:04:26',0,NULL,3,1,2,1,NULL,'dt3186'),(13565,702376435018,280667759489,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.88,'photographyacc','iamgod0202','taks0202@hotmail.com','Takamichi Gummow','86 Bridges Road','New Lambton','New South Wales','AUSTRALIA','2305','0419387743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 09:29:09',0,NULL,3,1,2,1,NULL,'iamgod0202'),(13566,701835274001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','vtors','vladkovr@mail.ru','Vladimir Kovriga','50 let SSSR str.<br>h 4, f. 17','Kolchugino','Vladimir area','RUSSIAN FEDERATION','601785','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 09:29:53',0,NULL,3,1,2,1,NULL,'vtors'),(13567,757163636017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','k4155','kengaun.chen@gmail.com','Keng Chen','27, Linden Way','Bella Vista','New South Wales','AUSTRALIA','2153','6145550098','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 09:37:50',0,NULL,3,1,2,1,NULL,'k4155'),(13568,701838590001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','lipsy*2011','c.lynch04@hotmail.com','Craig Wilson','12 Frome St','Glenorchy','Tasmania','AUSTRALIA','7010','0401234534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 09:39:17',0,NULL,3,1,2,1,' ','lipsy*2011'),(13569,757219666017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',7.28,'photographyacc','unclelegend','scottcornish@optusnet.com.au','Scott Cornish','PO Box 141<br>Dunwich','Brisbane','Queensland','AUSTRALIA','4183','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 11:59:07',0,NULL,3,1,2,1,NULL,'unclelegend'),(13570,702437754018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','even*par72','edgardopacia@yahoo.com','EDGARDO G PACIA','35658 Dulock Rd','Wildomar','CA','UNITED STATES','92595-7115','(714) 272-5868','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-24 12:16:32',0,NULL,3,1,1,1,NULL,'even*par72\r49-82mm  9个 接口环   \r普通托架  + 广角托架  （ 已入库）'),(13571,757264336017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','ch0455','chad@northnet.org.au','Chad Henderson','37 Hague Street','Rutherford','New South Wales','AUSTRALIA','2320','0425227842','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 13:42:19',0,NULL,3,1,2,1,NULL,'ch0455'),(13572,8881311515513444,111,'一堆',1,'',240,'photographyacc','medgtal','alanoir@free.fr','Arnaud LANOIR','12B, route de Feydit<br>Saint Médard en ','Jalles ','','FRANCE','33160','',NULL,NULL,NULL,NULL,0,NULL,3,0,4,1,'YW866127124CN ','301P 一拖三    1\rSF18 for canon   1\r2云柔    2\r反光伞   2\r反光板支架   1\r（已入库）\rphoto kit  $25\r'),(13573,701973727001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','ritmasbay','ritmas@ro.ru','Ivan Mazur','Tadzhycka<br>7-18','L\'viv','','UKRAINE','79038','+380677283390','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 15:22:08',0,NULL,3,0,3,1,'RA183615395CN\r ','ritmasbay\rcanon   黑色薄无字背心\rXXXL (已入库）'),(13574,702025201001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','luftchef','ischacht@me.com','Sylke Schacht','Breslauerstr. 18','Helmstedt','','GERMANY','38350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 16:42:39',0,NULL,3,1,2,1,NULL,'luftchef'),(13575,743607557002,120619188583,'NEW 72mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT047',32,'hermeshine','artem_kharkov','artem.bogomyagkov@gmail.com','Artem Bogomyagkov','Geroev Truda st, 48a, flat 87','Kharkov','Kharkov','UKRAINE','61135','380667485654','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 17:41:59',0,NULL,3,1,3,1,'RA183615245CN\r ','artem_kharkov\r绿叶近摄镜 +8  72mm 换成\"72mm ND4\"'),(13576,702098946001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ycrpdm','yocarpediem@gmail.com','JUAN DE DIOS MAESTRE QUINTERO','C/ MARE DE DEU DE LORDA 28 SOBREATICO','BARCELONA','Cataluña','SPAIN','08033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 18:20:01',0,NULL,3,1,3,1,'RA183615492CN\r ','ycrpdm'),(13577,702102649001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','hitechcellcomm','letriquang@gmail.com','Quang T Le','2903 S 62nd St','philadelphia','PA','UNITED STATES','19142-3405','(215) 726-1606','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-24 18:24:26',0,NULL,3,1,1,1,' ','hitechcellcomm'),(13578,702146448001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:22:03',0,NULL,3,1,17,0,NULL,'hinkebein13'),(13579,743675928002,120571007530,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:22:04',0,NULL,3,1,17,0,NULL,'hinkebein13'),(13580,743676338002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:22:05',0,NULL,3,0,17,0,NULL,'hinkebein13'),(13581,743677247002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','hinkebein13','underline@gmx.net','Matthias Grossauer','Schulgass 10','Irenental','','AUSTRIA','3011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 19:22:05',0,NULL,3,1,2,1,NULL,'hinkebein13\r6片装的滤镜袋    1\r天涯方形滤镜  渐变蓝    1\r天涯方形滤镜  渐变棕     1\r天涯方形滤镜  渐变橙       1\r\r   '),(13582,702161417001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','makabeo77','lumon1705@gmail.com','Luis Monje Arenas','Calle Adoratrices 14. chalet Nº 47','Guadalajara','Castilla-La Mancha','SPAIN','19002','949231099','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 19:48:54',0,NULL,3,0,3,1,'RA183615285CN\r ','makabeo77\rL  已入库'),(13583,702183968001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','manur2009','manuelrivasfresno@yahoo.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-24 20:20:36',0,NULL,3,1,3,1,'RA183615135CN\r ','manur2009'),(13584,824113541015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','leila6684','leila.bentley@btinternet.com','Leila Moody','3 Brook Close, Quarndon','Derby','Derbyshire','UNITED KINGDOM','DE225JG','01332553414','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-24 21:16:00',0,NULL,3,1,2,1,NULL,'leila6684'),(13585,702212885001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','pbrito55','pedro.j.n.brito@gmail.com','Pedro Brito','Ericsson T.<br>Ed. Infante D. Henrique','Quinta da Fonte','Paço de Arcos','PORTUGAL','2770192','00351934466350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 21:19:59',0,NULL,3,1,2,1,NULL,'pbrito55'),(13586,702233040001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','adrians.m','adrianm1984@gmail.com','Adrian Miloszewicz','114 Westend Gate<br>Belgard Square, Tallaght','Dublin','Dublin','IRELAND','24','0834270972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-24 22:11:50',0,NULL,3,1,3,1,'RA183615501CN\r ','adrians.m'),(13587,702799280018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',2,'AA3314',14.4,'photographyacc','sabrinaraven','travtravtrav@hotmail.com','Matthew Reid','46 Donna Avenue<br>Rochedale South','Brisbane','Queensland','AUSTRALIA','4123','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-24 22:30:12',0,NULL,3,1,2,1,NULL,'sabrinaraven'),(13588,702820278018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','09franni','serenityjane@live.com','Serenity Caldwell','167 Patchs bch Rd','Patchs Beach','New South Wales','AUSTRALIA','2478','0432664164','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,'\r ','09franni'),(13589,702832973018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','helyl51','h.land@mailbox.uq.edu.au','Helmut Land','6 Reigate Place','The Gap','Queensland','AUSTRALIA','4061','0404808946','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 00:10:46',0,NULL,3,1,2,1,NULL,'helyl51'),(13590,702268988001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','smartshopping2012','smartshopping@hotmail.it','Anita Dylag C/O Castro','Wiesenweg, 12','Brunico','BZ','ITALY','39031','389-8908149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 00:20:48',0,NULL,3,1,2,1,NULL,'smartshopping2012'),(13591,756202485017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',16.47,'photographyacc','liangmice','xl_steve@yahoo.com.au','Liang (Steve) XU','15/35 Collins St','Melbourne','Victoria','AUSTRALIA','3000','0386613436','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 01:22:31',0,NULL,3,1,2,1,NULL,'liangmice\r笔      1\r气吹+布     1\r爵影红外 canon      1\r'),(13592,807080667016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','aegorov67','andrew.egorov@yahoo.co.uk','Andrew Egorov','404/20 Paradise Street<br>Highgate Hill','Brisbane','Queensland','AUSTRALIA','4101','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-25 02:01:45',0,NULL,3,1,4,1,'YW866127102CN ','aegorov67'),(13593,757667449017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','laudz2000','melhem_l@yahoo.com','LAUDY MELHEM','40/1-5 COLLAROY ST','COLLAROY','New South Wales','AUSTRALIA','2097','0424807676','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 02:04:10',0,NULL,3,1,2,1,NULL,'laudz2000'),(13594,757671082017,270753944377,'New Lambency Flash Diffuser for Nikon SB600 SB800 P1',1,'AB3306',21.5,'photographyacc','shibumi_oz','bob@shibumioz.com','shibumiOz','18 McCauley Cres','Glenbrook','New South Wales','AUSTRALIA','2773','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-25 02:15:04',0,NULL,3,1,3,1,'RA183615237CN\r ','shibumi_oz'),(13595,702876162018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','jonwalker_auction','wibbs@bigpond.com','Jonathan Walker','2/39 Milson St','South Perth','Western Australia','AUSTRALIA','6151','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-25 02:41:21',0,NULL,3,1,17,0,NULL,'jonwalker_auction'),(13596,757678340017,270777060056,'Studio Continuous Light Kit 23\' SoftBox 4 output 45w x8',1,'AKT039',223,'photographyacc','jonwalker_auction','wibbs@bigpond.com','Jonathan Walker','2/39 Milson St','South Perth','Western Australia','AUSTRALIA','6151','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 02:43:02',0,NULL,3,1,4,1,'YW866127113CN ','jonwalker_auction\r灯架  2m            4\r斜臂        1  \r柔光箱 50-70cm 单灯头 澳标     1\r115w 5500k 灯泡  220v      1\r反光板支架          1 \r柔光箱 60-60cm  四灯头 澳标     2\r45w 5500k 灯泡 220v        8\r灯架包           1\r申报: Lighting Kit  $35'),(13597,702311435001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','margem1701d','margem3816@aol.com','Margaret Morales','127 Brittany Ter','rock tavern','NY','UNITED STATES','12575-5552','(914) 443-7018','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 02:49:45',0,NULL,3,1,1,1,NULL,'margem1701d'),(13598,757691998017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','chintan1977','chintan18@gmail.com','Chintan G Ribadia','Shop 9B-Subway Corio Shopping Centre<br>Cnr. Purnell Road & BacchusMarsh Road','Corio','Victoria','AUSTRALIA','3214','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 03:32:36',0,NULL,3,1,2,1,NULL,'chintan1977'),(13599,8881311564837804,111,'2m 灯架',1,'AE3401',24,'hermeshine','apinheirinho','pinheirinho1986@gmail.com','Augusto Pinheirinho','Rua João Martins n.º 41','Setúbal Setúbal ','','PORTUGAL','2910-160','(+351)913933701',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183615909CN\r ','RA183615149CN \r再发一个给他'),(13600,824274243015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',132,'hutongstore','gladkovmaxim','maksimk@list.ru','Gladkov Maxim','K.Sutyusheva 47-3','Petropavlovsk','SKO','KAZAKHSTAN','150000','87152527469','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 05:11:26',0,NULL,3,1,5,1,'CP227168036CN ','gladkovmaxim'),(13601,757725834017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','egut7992','edwardsphotography@live.com','Edward Gutierrez','5658 N 6th St','Fresno','CA','UNITED STATES','93710-6348','(559) 367-9673','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-07-25 06:36:30',0,NULL,3,1,4,1,'YW866127161CN ','egut7992\r灯泡是110v 的\r Lighting Kit       $28'),(13602,702353243001,110718725568,'New Soft Camera Bag Case Cover Nikon D700 + 24-70mm',1,'AD1112',7.8,'hermeshine','frank132_92','dufrenoy@noos.fr','François DUFRENOY','40 rue du Mont Valerien','Saint Cloud','Île-de-France','FRANCE','92210','06-61-10-17-68','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 06:54:35',0,NULL,3,1,2,1,NULL,'frank132_92'),(13603,743918099002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','c000cris','katerinavonshtirlitz@gmail.com','Cristina Popa','4283 Express Ln<br>Ste V1228','Sarasota','FL','UNITED STATES','34238-2602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 07:44:54',0,NULL,3,1,17,0,NULL,'c000cris'),(13604,743918510002,120619188583,'NEW 72mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT047',32,'hermeshine','c000cris','katerinavonshtirlitz@gmail.com','Cristina Popa','4283 Express Ln<br>Ste V1228','Sarasota','FL','UNITED STATES','34238-2602','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 07:46:53',0,NULL,3,1,1,1,NULL,'c000cris\r77mm ND4+ CPL + 渐变灰 + +4 近摄镜 + 4片装滤镜包   1\r72mm ND4+ CPL + 渐变灰 + +4 近摄镜 + 4片装滤镜包   1\r近摄镜 已入库'),(13605,743922646002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','mzencir','mehmetimer14@gmail.com','Mehmet IMER','Koc University Sariyer Campuss / Suna Kirac Library','Istanbul','Sariyer','TURKEY','34450','00905064315622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 08:08:01',0,NULL,3,0,3,1,'RA183615696CN ','mzencir\r1.6*3  黑色背景布     1'),(13606,807172083016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','ccc23444','jesper@frehr.dk','jesper frehr','Svalevej 16','kolding','','DENMARK','6000','60619596','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','0000-00-00 00:00:00',0,NULL,3,1,4,1,'YW866475035CN ','ccc23444\rbackground broad  $20'),(13607,743924556002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 08:17:20',0,NULL,3,1,3,1,'RA183615625CN ','tawfeekmohammed'),(13608,743924394002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','guytekoa','guy.tekoa@gmail.com','Guy Tekoa','Yeoshua Ben Nun 3/14','Sederot','Israel','ISRAEL','80100','0526450815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 08:53:46',0,NULL,3,1,3,1,'RA183615563CN ','guytekoa'),(13609,698847954018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',40,'photographyacc','maromd','dani.marom@gmail.com','Daniel Marom (Suite # SN29116)','471 Mundet Pl','Hillside','NJ','UNITED STATES','07205-1115','973 253 3800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 09:01:22',0,NULL,3,0,1,1,NULL,'maromd\rxxl  (已入库）'),(13610,807191610016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',54,'hutongstore','dandelion_garden','dandelion_garden@btinternet.com','M. Suzy','40 Hutchcomb Road','Oxford','Oxfordshire','UNITED KINGDOM','OX2 9HL','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-25 09:43:50',0,NULL,3,1,4,1,'YW866475046CN ','dandelion_garden\r英标\rlighting kit  $20'),(13611,743905929002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','satisha.ru','zooma1@yandex.ru','Olga Chernikova','generala Pavlova, d.38, kv.36','Kaliningrad','Kaliningradskaya oblast','RUSSIAN FEDERATION','236006','+79114842255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 10:36:53',0,NULL,3,1,2,1,NULL,'satisha.ru'),(13612,824364064015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','kingsin71','terryking@hot-shot.com','Terry King','9 Appleton Mews','Colchester','Essex','UNITED KINGDOM','CO4 5ZQ','01206854638','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 10:59:15',0,NULL,3,1,3,1,'RA183615634CN ','kingsin71'),(13613,702981761018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','john530_1','jgavel@exemail.com.au','John Gavel','8 Melgaard Court','Wodonga','Victoria','AUSTRALIA','3690','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 11:04:38',0,NULL,3,1,2,1,NULL,'john530_1'),(13614,824368281015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',2,'AA2208',4.5,'hutongstore','mcdowall247','jim.mcdowall2@btinternet.com','Jim McDowall','28 Middlemuir Park<br>Tarbolton','Mauchline','East Ayrshire','UNITED KINGDOM','KA5 5NR','01292540774','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 11:14:53',0,NULL,3,1,2,1,NULL,'mcdowall247\r方形滤镜接口环 52mm     1\r方形滤镜接口环 67mm       1(已入库）'),(13615,757790798017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','cheryljcon','chezcon@bigpond.com','Cheryl Connell','3/8 Harker Street','Sunbury','Victoria','AUSTRALIA','3429','0397407210','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 11:17:17',0,NULL,3,1,2,1,NULL,'cheryljcon'),(13616,743971705002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cherkes82','cherkes@mail.ru','Andrey Konarev','76 kvartal d25 kv3','Kurganinsk','krasnodarskiy kray','RUSSIAN FEDERATION','352430','+7 918 4412891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 11:33:12',0,NULL,3,1,2,1,NULL,'cherkes82'),(13617,757804459017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','unclelegend','scottscornish@bigpond.com','Scott Cornish','PO Box 141<br>Dunwich','Brisbane','Queensland','AUSTRALIA','4183','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 12:03:25',0,NULL,3,1,2,1,NULL,'unclelegend'),(13618,702432233001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','87caos','oscar.carnevale@gmail.com','Oscar Carnevale','Via Nettunense, 64','Marino','RM','ITALY','00047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 12:18:38',0,NULL,3,1,2,1,NULL,'87caos'),(13619,824394948015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','alnilaneboukie','souverin@hotmail.com','cheick bienaime','121 A westwood park','london','London','UNITED KINGDOM','SE233qq','02086999913','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 12:28:34',0,NULL,3,1,2,1,NULL,'alnilaneboukie'),(13620,824395680015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','museumratboze','boze.kokan@st.t-com.hr','Tonko Bartulovic','Sukoisanska 29','21000 Split','Croatia','CROATIA','385','++385989042292','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 12:33:59',0,NULL,3,1,3,1,'RA183615651CN ','museumratboze'),(13621,743986975002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','yana_misha','yana_ger@walla.com','Yana Gershfeld','Vilonski 22/10','Hadera','Hadera','ISRAEL','38496','972 52 837311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 12:34:07',0,NULL,3,1,3,1,'RA183615648CN ','yana_misha'),(13622,743994726002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mosszen','mosszengb@gmail.com','Edward Chan','89 Moss Creek Boulevard','Markham','ON','CANADA','L6C 2J2','(416) 720-3212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 12:58:48',0,NULL,3,1,3,1,'RA183615585CN ','mosszen'),(13623,824438554015,250692237371,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',6.8,'hutongstore','littona123','alanlitton@hotmail.co.uk','Alan Litton','21 Winchester Close, Lower Stratton,','Swindon','Wiltshire','UNITED KINGDOM','SN3 4HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 14:26:17',0,NULL,3,1,17,0,NULL,'littona123'),(13624,824439838015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','littona123','alanlitton@hotmail.co.uk','Alan Litton','21 Winchester Close, Lower Stratton,','Swindon','Wiltshire','UNITED KINGDOM','SN3 4HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 14:29:08',0,NULL,3,1,2,1,NULL,'littona123\rJJC 镜头筒 JN22    1\r镜头筒 小号        1'),(13625,703045006018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','apinheirinho','pinheirinho1986@gmail.com','Augusto Pinheirinho','Rua João Martins n.º 41','Setúbal','Setúbal','PORTUGAL','2910-160','(+351)913933701','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 14:39:44',0,NULL,3,1,4,1,'YW866475072CN ','apinheirinho'),(13626,701114489018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','karstcon','karstcon@gmx.de','KArsten Rudloff','Dorfstr. 104','Adendorf','','GERMANY','21365','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 15:00:25',0,NULL,3,1,3,1,'RA183615705CN ','karstcon'),(13627,743486718002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','mateosmida','mateo.smida@gmail.com','Mateo Smida','Meduliceva 18 a/1','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 15:25:00',0,NULL,3,1,2,1,' ','mateosmida'),(13628,744072108002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','fotkam','keeper_idc@mail.ru','Kubanov Dmitriy Romanovich','pr. Mira, d.34, kv. 94','Naberezhnye Chelny','Tatarstan','RUSSIAN FEDERATION','423812','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 16:52:56',0,NULL,3,1,3,1,'RA183615740CN ','fotkam\r新进的84cm两用伞'),(13629,703098897018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',39.8,'photographyacc','comoffbayer','comoff@nm.ru','Natalya Zvykova','Kropotkina 127 - 19<br>Galushaka 11 - 220','Novosibirsk','Novosibirskaya oblast','RUSSIAN FEDERATION','630105','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 17:08:59',0,NULL,3,1,3,1,'RA183615617CN ','comoffbayer'),(13630,744129305002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','chubbyandy712','andyh712@gmail.com','Andy Huang','654 47th st','Brooklyn','NY','UNITED STATES','11220-1415','(718) 436-5302','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-25 18:57:01',0,NULL,3,1,1,1,NULL,'chubbyandy712'),(13631,757976347017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',13.89,'photographyacc','ergoproxy11','vidan.ristevski@gmail.com','Vidan Ristevski','23 Nowland Crescent','Tamworth','New South Wales','AUSTRALIA','2340','0267607969','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-25 19:14:18',0,NULL,3,1,2,1,NULL,'ergoproxy11\r再加一个nikon  D300 眼罩（已入库）'),(13632,703167051018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',2,'AD1120',36,'photographyacc','casildagarreton2010','casilda.garreton@gmail.com','Maria Casilda Garreton Velasco','Avenida Apoquindo 5701 local 18<br>Las condes','Santiago','Metropolitana','CHILE','7550000','56-02-2244932','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 19:16:05',0,NULL,3,1,3,1,'RA183615682CN\r ','casildagarreton2010'),(13633,702592797001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:33:32',0,NULL,3,1,3,1,'RA183615577CN ','ramitetro'),(13634,703176434018,280680857434,'New JYC-N3 Wireless Remote Control for Nikon D90 D7000',1,'AA3202',18,'photographyacc','docray55','rgwhitmire@hotmail.com','Raymond Whitmire','3501 Royal Crest Dr E','The Dalles','OR','UNITED STATES','97058-9711','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 19:35:12',0,NULL,3,1,1,1,NULL,'docray55'),(13635,824605912015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',2.25,'hutongstore','madog55leslie','norman.davies55@gmail.com','leslie davies','55 pretoria rd.','tonyrefail','Rhondda Cynon Taff','UNITED KINGDOM','cf38 8pw','01443675523','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 19:41:58',0,NULL,3,1,2,1,NULL,'madog55leslie'),(13636,744155812002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:49:12',0,NULL,3,1,17,0,NULL,'denisyana'),(13637,744159405002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 19:56:03',0,NULL,3,1,17,0,NULL,'denisyana'),(13638,702606409001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',2,'AE2204',49.98,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 20:00:55',0,NULL,3,1,17,0,NULL,'denisyana'),(13639,551527483003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 20:07:07',0,NULL,3,1,17,0,NULL,'denisyana'),(13640,744175405002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','steffenrf','steffenr@vt.edu','Robert F Steffen','7015 Bleak Ridge Rd','Hiwassee','VA','UNITED STATES','24347-2839','(540) 639-3745','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-25 20:29:17',0,NULL,3,1,1,1,NULL,'steffenrf'),(13641,702625808001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-25 20:43:35',0,NULL,5,1,18,0,' ','denisyana\r斜臂      1\r4灯头 灯头 孔  欧标     1\r50-70柔光棚 通用金属卡口    2\r手动升降背景架     1\r背景架2m x 3m + 3个夹子    1\r11.4'),(13642,703243307018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','heinerseiner','e.buechner@gmx.de','Erhard Buechner','Muehlenstrasse 53 B','Pinneberg','','GERMANY','25421','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-25 22:03:49',0,NULL,3,1,2,1,NULL,'heinerseiner'),(13643,824684776015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','albatros-38','patrick.nic@voila.fr','Patrick NICOLAS','196 rte de Vienne','PENOL','Rhône-Alpes','FRANCE','38260','0675244191','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 22:12:35',0,NULL,3,1,2,1,NULL,'albatros-38'),(13644,807539262016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','roncella','sergio@technomend.com','sergio roncella','112 lea street','kidderminster','Worcestershire','UNITED KINGDOM','dy101sn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-25 22:45:38',0,NULL,3,1,2,1,NULL,'roncella'),(13645,807538872016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','niallpurcell','nialljpurcell@gmail.com','Niall Purcell','135 Rathfarnham Road','Dublin','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 22:56:50',0,NULL,3,1,17,0,NULL,'niallpurcell'),(13646,824694532015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','niallpurcell','nialljpurcell@gmail.com','Niall Purcell','135 Rathfarnham Road','Dublin','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 22:56:50',0,NULL,3,1,17,0,NULL,'niallpurcell'),(13647,807538090016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','niallpurcell','nialljpurcell@gmail.com','Niall Purcell','135 Rathfarnham Road','Dublin','Dublin','IRELAND','14','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-25 22:56:51',0,NULL,3,1,3,1,'RA183615679CN\r ','niallpurcell\rlenspen     1 \r圆形柔光棚 50cm    1\r肥皂盒 柔光罩   sb800 sb600      1'),(13648,744239298002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rednrj74','vladimirpaypal@mail.ru','Vladimir Dubrovskiy','st. kaslinskaya d.21a kv.173','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454084','+79617950508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-25 23:40:06',0,NULL,3,1,2,1,NULL,'rednrj74'),(13649,757679717017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','wagg4649','wggore@bigpond.net.au','Walter  Gore','5 Irving Court','Bundoora','Victoria','AUSTRALIA','3083','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 00:48:01',0,NULL,3,1,2,1,' ','wagg4649'),(13650,703286966018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','arturo584','artvalle@msn.com','arturo valle','4155 Case St<br>Apt D3','elmhurst','NY','UNITED STATES','11373-2293','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-07-26 00:49:38',0,NULL,3,1,4,1,'YW866475083CN ','arturo584'),(13651,702703114001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','majormilo','captmac77@yahoo.com','Dr. Michael McCosh','PO Box 459','Dodge City','KS','UNITED STATES','67801-0459','(202) 997-4703','NoPaymentFailure','CheckoutComplete','Other','2011-07-26 01:29:39',0,NULL,3,0,1,1,NULL,'majormilo\r3xl     （已入库）'),(13652,758118119017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','pap306','peterpap63@optusnet.com.au','Peter Pap c/o RMWilliams','Level 11<br>52 Alfred Street','Milsons Point','New South Wales','AUSTRALIA','2061','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 01:34:35',0,NULL,3,1,2,1,NULL,'pap306'),(13653,8881311644528284,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',15.58,'hermeshine','aliexpress-1003711430','000@xxx.com','Andrey Dyachenko','Druzba Narodov 20 86','Ust-Ilimsk	','The Irkutsk region	','RUSSIAN FEDERATION	','666679','+7 983 4168668',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183615665CN\r ',NULL),(13654,703297297018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','whiskeywoo1','dsheehan83@gmail.com','Danielle Sheehan','7 / 276-278 Woronora Road','Engadine','New South Wales','AUSTRALIA','2233','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-26 01:42:14',0,NULL,3,1,4,1,'YW866475094CN ','whiskeywoo1\r1.6*2.1 黑色背景布  1'),(13655,703313668018,280675886664,'18% Gray Cards 8x6\"& 6x4\" for White balance exposure S',1,'AA2217',11,'photographyacc','suemchats','mchats@optusnet.com.au','sue mchats','14 Loombah Road','Dover Heights','New South Wales','AUSTRALIA','2030','0293430194','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 02:38:57',0,NULL,3,1,17,0,NULL,'suemchats'),(13656,758133825017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','suemchats','mchats@optusnet.com.au','sue mchats','14 Loombah Road','Dover Heights','New South Wales','AUSTRALIA','2030','0293430194','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-26 02:38:56',0,NULL,3,1,4,1,'YW866475105CN','suemchats\r小号灰卡     1\r三脚架  伟峰 WF-6662A       1'),(13657,744288703002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',3,'AO0009',212.7,'hermeshine','ryrvikryrvik','medolaonas@hotmail.se','magnus ryrvik kjäll','hjortmossegatan 32','trollhättan','västra götaland','SWEDEN','46151','0520203000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 02:56:15',0,NULL,3,0,5,1,'CP227168005CN ','ryrvikryrvik\rC++\r2m灯架的底座  x 3\r1.6*2.1m  背景布 x 3 (白色)\r2m灯架   x 1\r----\r发货要求:\r3套并成1票发,但每套都保留原来的完整包装; 申报实值; 外包装上贴上我们的ebay ID'),(13658,702729834001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','gxero','delta_forces@yahoo.com','Wilson KH Luk','Nerd Corps Entertainment Inc.<br>Level 3 - 1256 East 6th Ave','Vancouver','BC','CANADA','V5T 1E7','(778) 386-7388','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 03:12:12',0,NULL,3,1,3,1,'RA183615722CN ','gxero'),(13659,702729876001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','ashrafelghamry','lifeless_ash@yahoo.com','Ashraf Elghamry','16 Hamlet St','somerville','MA','UNITED STATES','02143-1909','(617) 628-6746','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 03:13:08',0,NULL,3,1,1,1,NULL,'ashrafelghamry'),(13660,744297788002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dispronet','nucnatal@hotmail.com','Jean Carlo Figueiredo de Mendonça','R. clara camarão, 1988<br>Bairro: Candelária','Natal','Rio Grande do Norte','BRAZIL','59065-030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 03:38:54',0,NULL,3,0,3,1,'RA183615736CN\r ','dispronet\r3XL    (已入库）'),(13661,758150266017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','ageless1-2010','d_k@bigpond.net.au','David Kelly','4 Tucuma Court','Warnbro','Western Australia','AUSTRALIA','6169','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 03:43:09',0,NULL,3,1,3,1,'RA183615753CN\r ','ageless1-2010'),(13662,744308048002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','lher7449','lher84@yahoo.com','Louchee Her','202 Mission Park Dr','Stockton','CA','UNITED STATES','95207-2041','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 04:34:29',0,NULL,3,1,4,1,'YW866475595CN ','YWlher7449'),(13663,758161264017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','hayleykn','hayleykn@yahoo.com.au','hayley dickfos','7 Stevens Close<br>Kawungan','Hervey Bay','Queensland','AUSTRALIA','4655','0741940293','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 04:40:26',0,NULL,3,1,2,1,NULL,'hayleykn'),(13664,702751242001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','arusakov','andryrus@mail.ru','Andrey Rusakov','Ryabinovaya 20 flat 51','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','197375','+79219830654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 05:15:41',0,NULL,3,1,2,1,NULL,'arusakov'),(13665,703346821018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','11.09.1980','nikkiford256@msn.com','Nikki Short','162 Del Monte Place','Copacabana','New South Wales','AUSTRALIA','2251','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 05:29:05',0,NULL,3,1,3,1,'RA183615775CN\r ','11.09.1980'),(13666,702752732001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','hightech.surplus','tms@hightechsurplus.com','TMS','3043 South Laredo Circle','Aurora','CO','UNITED STATES','80013','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 05:40:42',0,NULL,3,1,1,1,' ','hightech.surplus'),(13667,701597957018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','brookeysfotos','photographybybrooke@live.com.au','BROOKE ANDREWS','15<br>CABARITA WAY','NTH YUNDERUP','Western Australia','AUSTRALIA','6208','0429694609','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 05:56:31',0,NULL,3,0,2,1,NULL,'brookeysfotos\r黑色'),(13668,8881311661185504,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',15.58,'hermeshine','aliexpres-1003718906','vendascomph@yahoo.com.br','Wagner Andrade	','R. Dr. Muricy 839 Ap 154 Centro','Curitiba','Parana','BRAZIL','80020040','+55 41 85024177',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183615798CN\r ',NULL),(13669,744329006002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','uraken2000','luca.uraken@gmail.com','ALI Spa - Filiale di Prato - att.ne Niccoli Sara','VIA CURTATONE<br>87/89','Prato','PO','ITALY','59100','3346653275','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 06:43:36',0,NULL,3,1,3,1,'RA183615784CN\r ','uraken2000\rL  库里没有\rPhoto Vest     $12'),(13670,758186287017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','alzy_14','lunn@iprimus.com.au','John Lunn','33 Corbusier Drive, St Agnes','Adelaide','South Australia','AUSTRALIA','5097','0882653795','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 07:02:42',0,NULL,3,1,2,1,NULL,'alzy_14'),(13671,703364700018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','ercuserdar','ercumentserdar@hotmail.com','ercument serdar emek','t.c. merkez bankasi<br>izmit subesi','izmit','kocaeli','TURKEY','41100','5334267260','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-26 07:11:50',0,NULL,3,1,5,1,'CP235618050CN ','ercuserdar\rRA183615767CN\r '),(13672,744334574002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','pophist','pophist@lsn.se','Bjorn Andersson','Karl XII gatan 7','Lund','','SWEDEN','22220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 07:20:31',0,NULL,3,1,2,1,' ','pophist'),(13673,702782647001,110533631467,'CTR-301P Wireless Flash Trigger 3 Receivers 5DII 40D',1,'AKT002',59.99,'hermeshine','veraokean','stop-this-madness@tut.by','Vera Kavaleuskaja','Ukrainki 8-2-293','Minsk','','BELARUS','220020','+375293504496','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 08:15:36',0,NULL,3,1,3,1,'RA183615855CN\r ','veraokean\r1托3   '),(13674,702787213001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','sasithachris','christyliccarian@yahoo.no','christy liccarian arumainathan','ulsholt vei 38','oslo','','NORWAY','1053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 08:39:00',0,NULL,3,1,5,1,'CP227167999CN ','sasithachris'),(13675,702789845001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','focalfocal','tommyf@zonnet.nl','Tom Flipse','Jacob Paffstraat 22','AMSTERDAM','','NETHERLANDS','1069PJ','0624645325','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,17,0,NULL,'focalfocal'),(13676,744366136002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','i_fes','anabioz@list.ru','Igor Fesenko','Orangeva, 66','Dnipropetrovsk','','UKRAINE','49007','067-742-7256','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 09:46:54',0,NULL,3,1,2,1,NULL,'i_fes'),(13677,807711847016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','enfra57','steenjeberg@gmail.com','Steen Jeberg','Ellegårdspark 12','Farum','','DENMARK','3520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 09:52:37',0,NULL,3,1,3,1,'RA183617153CN\r ','enfra57'),(13678,807711568016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','5katte2010','tbardorf4@gmail.com','Tom Bardorf','Skriverhusene 54','Albertslund','','DENMARK','2620','(0045) 22434890','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 09:52:49',0,NULL,3,1,2,1,NULL,'5katte2010'),(13679,824879947015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','pipkato','roy.esmonde@gmail.com','Roy Esmonde','63 Kenilworth Square','Dublin 6','','IRELAND','','0035314967450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 10:19:19',0,NULL,3,1,3,1,'RA183615838CN ','pipkato\r英标'),(13680,703407904018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','blancbistro','vintage1973@live.com.au','Sam  Blanc','31/81 O\'Connell Street<br>North Adelaide Village','North Adelaide','South Australia','AUSTRALIA','5006','0883618988','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 10:28:15',0,NULL,3,1,2,1,NULL,'blancbistro'),(13681,824888703015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','brandypooch150','davidjd@talktalk.net','David Daynes','150 Ashlawn Road','Rugby','Warwickshire','UNITED KINGDOM','CV225EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-26 10:45:00',0,NULL,3,1,2,1,NULL,'brandypooch150'),(13682,702816571001,110426879616,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',2,'AC2202',17.98,'hermeshine','chali_pilot','xali@netvisao.pt','João Chalaça','Rua Crónica Eborense, nº 25','Évora','Alentejo, Évora','PORTUGAL','7000-691','00351 962056216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 10:47:40',0,NULL,3,1,2,1,NULL,'chali_pilot'),(13683,744381465002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','robo.guy','shawn.zik@gmail.com','Shawn Zik','1 Eva Road<br>Suite 317','Toronto','ON','CANADA','M9C4Z5','(416) 622-9449 ext.: 116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 10:53:29',0,NULL,3,1,2,1,NULL,'robo.guy'),(13684,744382843002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','sviske','mafo_712@hotmail.com','Marit Fossdal','Brattvoll Terrasse 11','Tveit','','NORWAY','4658','+4791703266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 10:58:24',0,NULL,3,1,3,1,'RA183615824CN ','sviske\r申报： gift  $20'),(13685,744385609002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 11:09:34',0,NULL,3,1,3,1,'RA183618318CN','af_133'),(13686,702822502001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-26 11:12:00',0,NULL,3,1,17,0,NULL,'af_133'),(13687,744390512002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 11:29:21',0,NULL,3,1,3,1,'RA183616008CN ','af_133\r1.6m x 3m  背景布   白色   1\r2mx 3m 背景架    1\r4灯头 灯头 孔    1  欧标\r3片装的滤镜袋    1\r分几个小包发， 另外，他还有一个2m 灯架+反光板支架，我没合并过来，如果重量差一点，可以和那个试试。\rRA183615991CN\rRA183617051CN\r'),(13688,758251638017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','mox2ya','parkgrace2@hanmail.net','Grace Park','7 The Esplanade','North Shore','Victoria','AUSTRALIA','3214','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 11:40:29',0,NULL,3,1,2,1,NULL,'mox2ya'),(13689,744394719002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','graemeh3344','graeme@haycraft.com','Braden Haycraft','5 Patton Lane','Hoppers Crossing','Victoria','AUSTRALIA','3029','0417543466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 11:49:29',0,NULL,3,0,4,1,'YW866475116CN ','graemeh3344\rtripod  $30'),(13690,744397975002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:05:04',0,NULL,3,1,17,0,NULL,'af_133'),(13691,744403639002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','do.mestos','s.cronier@gmail.com','Sebastien CRONIER','4 rue PATCH - BP789','NOUMEA cedex','','NEW CALEDONIA','98845','00687874073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:18:40',0,NULL,3,1,3,1,'RA183615890CN ','do.mestos'),(13692,744403739002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:25:13',0,NULL,3,1,17,0,NULL,'af_133'),(13693,824926810015,250801607283,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',2,'AKT031',68,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 12:41:59',0,NULL,3,1,17,0,NULL,'leifs123'),(13694,824926261015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',4,'AD1401',22,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 12:41:59',0,NULL,3,1,5,1,'CP227168107CN ','leifs123\r2m 灯架   4\r反光伞   4\r包完了和燕文沟通一下看是否可以发燕文， 体积应该不大，燕文有个规定是4kg以上必须申报高值，而挪威又不可以申报高值。看看这票有没有可能不申报高值。如果不行就发SAL,如果可以发燕文，就别申报成£21， sal的话申报 £21\r申报： lighting stand  £21\r4.953'),(13695,744413475002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',197,'hermeshine','gaehwilerhans','hagae@freesurf.ch','Hans Gähwiler','Jonschwilerstrasse 20','Schwarzenbach','','SWITZERLAND','9536','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 12:56:10',0,NULL,3,1,5,1,'CP235618125CN','gaehwilerhans\r欧标\r另外，背景架是1.6m宽的，不用放背景架的袋子\r燕文告之不能申报低值    改了sal 了'),(13696,758276819017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',187,'photographyacc','ground1999','zeethan@hotmail.com','Ahmed Bari','38 Alice Street<br>Auburn','sydney','New South Wales','AUSTRALIA','2144','610433636083','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-26 13:08:06',0,NULL,3,1,4,1,'YW866475131CN ','ground1999\r49mm -  82mm  9个接口环   \r普通托架   1\r广角托架   1\r717  1.33m 三脚架   1\r如果这些环和三脚架包在一起不超一个重量级的话，\r就和三脚架发，否则和反光板一起发\r燕文告诉现在货在邮局   无人领取    需要联系买家\r'),(13697,703448477018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',62.9,'photographyacc','ground1999','zeethan@hotmail.com','Ahmed Bari','38 Alice Street<br>Auburn','sydney','New South Wales','AUSTRALIA','2144','610433636083','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 13:08:06',0,NULL,3,1,3,1,'RA183615841CN ','ground1999\r另外，在确认一下澳大利亚到底可以一票两件吗？\r我问过了  不能发一票两件'),(13698,744443038002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','colemanlaw','colemanlaw@earthlink.net','Curtis Coleman','6601 Center Dr W<br>Ste 500','Los Angeles','CA','UNITED STATES','90045','(310) 348-8186','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 14:34:47',0,NULL,3,1,1,1,NULL,'colemanlaw'),(13699,744445666002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','rcares','rodolfo.cares@gmail.com','Rodolfo Cares Moreno','Pasaje Dos 2862','Independencia','Metropolitana','CHILE','8380730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 14:42:34',0,NULL,3,1,3,1,'RA183615886CN ','rcares\r多发一个斜臂里的袋子给他'),(13700,744473940002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',6,'AA1310',32.94,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 16:08:39',0,NULL,3,1,3,1,'RA183615988CN ','bobi1330\r申报在$15之内'),(13701,702943259001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','erwin_m27bc','erwin.m@ghc.org','Morgan Erwin','10305 SE 190TH PL','Renton','WA','UNITED STATES','98055','','NoPaymentFailure','CheckoutComplete','Other','2011-07-26 17:41:26',0,NULL,3,1,1,1,' ','erwin_m27bc\rxl  (已入库）'),(13702,744515681002,120752324312,'Protect Soft Camera Bag Case Skin Cover Canon EOS 7D',1,'AD1115',16.9,'hermeshine','michael.photomatic','photomatic.michael@gmail.com','Michael Straube','Heerlenerweg 45','Sittard','','NETHERLANDS','6132 CL','06 22570699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 17:54:38',0,NULL,3,1,2,1,NULL,'michael.photomatic'),(13703,703552500018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','leevanu','leevu@rediffmail.com','Leevon Thomas','Crown Plaza Hotel<br>Near Sheikh Zayed Road','Dubai','Dubai','UNITED ARAB EMIRATES','564','00971503211459','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-26 17:59:09',0,NULL,3,1,3,1,'RA183615926CN ','leevanu\r分开几个小包发    都申报高值\rRA183615912CN\rRA183615930CN'),(13704,807913249016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','esbenras','esben72@gmail.com','Esben Rasmussen','Fuglefængervej 7, 4. th','Kbh NV','copenhagen','DENMARK','2400',')45= 60651972','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-26 18:30:20',0,NULL,3,1,2,1,NULL,'esbenras'),(13705,702967908001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','poole113','gcpoole2000@yahoo.com','Cynthia Poole','559 Beachums Blf','Birmingham','AL','UNITED STATES','35226-2409','(205) 332-3471','NoPaymentFailure','CheckoutComplete','Other','2011-07-26 18:37:41',0,NULL,3,1,1,1,' ','poole113'),(13706,702975326001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','tiper3x','lesny.jozef@gmail.com','Dagmar Semanová','Sokoľany 19','Haniska','','SLOVAK REPUBLIC','04457','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 18:54:09',0,NULL,3,1,2,1,NULL,'tiper3x'),(13707,702978594001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','joseyner','nereidadelcarmen@hotmail.com','Jose ANTON DIAZ','c/ RIO TORMES 18 PUERTA 4','Telde','Canarias','SPAIN','35218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 19:00:04',0,NULL,3,1,4,1,'YW866475142CN ','joseyner\r Tripod   $22'),(13708,744545985002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','buttershug','buttershug3@yahoo.com','John Beaver','853 Vinyard Ave NE','Salem','OR','UNITED STATES','97301-2850','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-26 19:00:10',0,NULL,3,1,1,1,NULL,'buttershug'),(13709,744548258002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','nareks7','wildekstudio@gmail.com','Narek Safaryan','Shirazi 8 str. 8 apt.','Yerevan','Yerevan','ARMENIA','0088','(374) 55 777 448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 19:04:23',0,NULL,3,1,5,1,'CP227168098CN ','nareks7'),(13710,743536254002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','olgakondroeva','olya_125_@mail.ru','Olga Kondroeva','Kutuzova, 43-6','Petrozavodsk','','RUSSIAN FEDERATION','185006','+79116620834','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 19:41:02',0,NULL,3,1,2,1,NULL,'olgakondroeva'),(13711,758475852017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','bcl485','bcl@satlink.com.au','Brett Lind','485 Warrandyte rd','Langwarrin sth','Victoria','AUSTRALIA','3911','0359715679','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-26 20:54:07',0,NULL,3,1,2,1,NULL,'bcl485'),(13712,744632223002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','jgastr','jgastrell@gmail.com','Javier Gastrell','av. rivadavia 5012 pb4','Capital Federal','buenos aires','ARGENTINA','1424','01149040140','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:25:03',0,NULL,3,1,3,1,'RA183615815CN ','jgastr'),(13713,744636603002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','svvintus','ivan@varyukhin.ru','Ivan Varyukhin','ul. Pobratimov, 20-181','Lyubertsy','MO','RUSSIAN FEDERATION','140009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:51:37',0,NULL,3,1,17,0,NULL,'svvintus'),(13714,703065994001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','svvintus','ivan@varyukhin.ru','Ivan Varyukhin','ul. Pobratimov, 20-181','Lyubertsy','MO','RUSSIAN FEDERATION','140009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 22:51:38',0,NULL,3,1,3,1,'RA183615869CN ','svvintus\r反光板支架    1\r灯架  2m    1\r镜头筒 小号      1\rReflector  Holder  $15\r'),(13715,703070301001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',41.94,'hermeshine','theplanroom','mark@inprotrans.com','Mark O\'Malley','Inprotrans Pty Ltd<br>320 Churchill Road','Kilburn','South Australia','AUSTRALIA','5084','0417846008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 23:06:58',0,NULL,3,1,3,1,'RA183615957CN ','theplanroom'),(13716,703075613001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','michaeld0_7','michael.devereux@gmail.com','Michael Devereux','A2015 Department of Maths and Stats<br>University of Limerick','Castletroy','Limerick','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-26 23:29:16',0,NULL,3,0,2,1,' ','michaeld0_7'),(13717,703078125001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','katherineshechic','kthrn_cayabyab@yahoo.com','Katherine  Cayabyab','3835 Carleton Ave<br>Apt 4','Anchorage','AK','UNITED STATES','99517-1551','(907) 248-6794','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-26 23:40:08',0,NULL,3,1,1,1,NULL,'katherineshechic'),(13718,755817971017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','unclelegend','scottscornish@bigpond.com','Scott Cornish','PO Box 141<br>Dunwich','Brisbane','Queensland','AUSTRALIA','4183','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 00:01:27',0,NULL,3,0,3,1,'RA183614815CN  ','unclelegend\r77mm 接口环   1\r广角托架     1'),(13719,703104411001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.9,'hermeshine','rram56','rram56@sbcglobal.net','Richard Mc Donald','2553 Tamworthy Cir N.W.','North Canton','OH','UNITED STATES','44720','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-27 01:34:02',0,NULL,3,1,3,1,'RA183615974CN ','rram56'),(13815,808703572016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','arturbaikov','baikovartur@yandex.ru','Artur Baikov','Kyivskaya 25-29','Zhytomyr','','UKRAINE','10014','380412471753','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 09:23:48',0,NULL,3,1,2,1,NULL,'arturbaikov'),(13720,703110023001,110718725568,'New Soft Camera Bag Case Cover Nikon D700 + 24-70mm',1,'AD1112',7.8,'hermeshine','uuganbayar1987','uuganbayar.1987@yahoo.com','uuganbayar enkhbat','13648 Bent Tree Cirlce Apt201','Centreville','VA','UNITED STATES','20121','(703) 678-7993','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 01:56:48',0,NULL,3,1,1,1,NULL,'uuganbayar1987'),(13721,744695607002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',16.99,'hermeshine','postrp1','ecamera@bigpond.com','Rolf Probst','2/20 West St. Corner Carter Rd.<br>Brookvale','Sydney','New South Wales','AUSTRALIA','2100','0299054044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 02:33:17',0,NULL,3,1,2,1,NULL,'postrp1\r澳标'),(13722,703119543001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','aoluz2008','aoluz@bol.com.br','Almir Oliveira da Luz','Rua Rubens Calasans Camargo,270<br>Residencial Planalto','São José dos Campos','São Paulo','BRAZIL','12220-030','055411281124151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 02:37:29',0,NULL,3,1,17,0,NULL,'aoluz2008\r'),(13723,703736920018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',2,'AC2301',13.2,'photographyacc','baudmania','naomi_fennell@hotmail.com','Cory Boardman','1 Childers St','Kensington','Victoria','AUSTRALIA','3031','0409959397','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 02:54:25',0,NULL,3,1,2,1,' ','baudmania'),(13724,703443776018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','charlie.1964','charlienbubblz@y7mail.com','fiona odell','71 bingara road','warialda rail','New South Wales','AUSTRALIA','2402','0267291966','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-27 03:02:13',0,NULL,3,1,4,1,'YW866475584CN ','charlie.1964'),(13725,703740060018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',7.8,'photographyacc','sphinxsharon','sharon277@bigpond.com','Sharon Smith','608 Cross Road','South Plympton','South Australia','AUSTRALIA','5038','0882938913','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 03:08:51',0,NULL,3,1,2,1,NULL,'sphinxsharon'),(13726,758587856017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',50,'AA1310',297.5,'photographyacc','finny_123','brian.finn1@bigpond.com','Brian Finn','6 Glider Court','Charlestown','New South Wales','AUSTRALIA','2290','0404888744','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 03:19:40',0,NULL,3,1,3,1,'RA183617048CN\r ','finny_123'),(13727,758593865017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','sulzie1','joannes@clubtelco.com','joanne sulzberger','3 catherine st','stanthorpe','Queensland','AUSTRALIA','4380','0746813436','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 03:51:23',0,NULL,3,0,3,1,'RA183617034CN\r ','sulzie1\r1.6x3m 白色  '),(13728,758598184017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',5,'AA3210',28.45,'photographyacc','daffwind','medi77@inbox.ru','Davids Vetrovs','313 WHITEHILL PL NE','Calgary','AB','CANADA','T1Y 3G6','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 04:07:26',0,NULL,3,1,3,1,'RA183617025CN\r ','daffwind'),(13729,744721139002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','css903','dfm@sscom.org','Daniel F. Morris','12203 11th PL NE','Lake Stevens','WA','UNITED STATES','98258','','NoPaymentFailure','CheckoutComplete','Other','2011-07-27 04:41:47',0,NULL,3,0,1,1,NULL,'css903\r3XL (已入库）\r客户说发货后告诉他  并且要tracking number'),(13730,703144437001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','visualsky77','scottyzer@gmail.com','Scott Yzer','958 Inkster Blvd.','Winnipeg','MB','CANADA','R2X 1N8','(204) 589-4837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 04:52:01',0,NULL,3,1,2,1,NULL,'visualsky77'),(13731,703170645001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:06',0,NULL,3,1,17,0,NULL,'tim-vl'),(13732,744748672002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:06',0,NULL,3,1,17,0,NULL,'tim-vl'),(13733,703170519001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:07',0,NULL,3,1,17,0,NULL,'tim-vl'),(13734,744748900002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 07:32:07',0,NULL,3,1,17,0,NULL,'tim-vl'),(13735,744748494002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:08',0,NULL,3,1,17,0,NULL,'tim-vl'),(13736,703167941001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 07:32:08',0,NULL,3,1,17,0,NULL,'tim-vl'),(13737,744748611002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:09',0,NULL,3,1,17,0,NULL,'tim-vl'),(13738,744749040002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:09',0,NULL,3,1,17,0,NULL,'tim-vl'),(13739,703170290001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.8,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:32:10',0,NULL,3,1,3,1,'RA183617122CN ','tim-vl\r绿叶 UV  58mm      1\r麂皮       2\r天涯方形滤镜系列  CPL    1\r爵影碗罩P4      1\r方形滤镜接口环 77mm        1\r方形滤镜接口环 72mm           1\r天涯方形滤镜  渐变蓝             1\r方镜普通托架（三槽）      1\r3片装的滤镜袋                      2\r肩架              1\r申报Shoulder Support     $15'),(13740,703787807018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','koenhermsen','koenhermsen@gmail.com','Koen Hermsen','Weverstraat 64','ENSCHEDE','','NETHERLANDS','7545TL','0649945323','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 07:33:21',0,NULL,3,1,2,1,NULL,'koenhermsen'),(13741,758636730017,270777043723,'Video 2400w Red Head Continuous Lighting Kit 800w x 3',1,'AKT072',299,'photographyacc','stevos77','s.gardiner@ecu.edu.au','Steve Gardiner - Edith Cowan University','2 Bradford Street','Mount Lawley','Western Australia','AUSTRALIA','6050','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-27 07:36:21',0,NULL,3,1,4,1,'YW866475234CN ','stevos77\r10.326'),(13742,703174213001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','thomas0404jovy','borjajovy@yahoo.com','JOVY BORJA','5807 KNIGHT STREET','VANCOUVER','BC','CANADA','V5P2B4','(604) 726-2237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:44:43',0,NULL,3,1,2,1,NULL,'thomas0404jovy'),(13743,744755156002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','saan75','saan.cat@gmail.com','Alexander Telin','Kadykova street, 21-190','Cheboksary','Chuvashia','RUSSIAN FEDERATION','428037','+79278410101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 07:59:40',0,NULL,3,1,3,1,'RA183617184CN ','saan75'),(13744,8881311753873123,111,'一堆,见notes',1,'',48,'hermeshine','nithin_dara','nithinkumary2k@gmail.com','Nithin Dara','Flat No. A201, Solitaire Apartments, JublieGardens, ','Kothaguda Hyderabad','Andhra Pradesh','INDIA','500084','+91-9052100598',NULL,NULL,NULL,NULL,0,NULL,3,0,3,1,'RA183617105CN ','nithin_dara\r斜臂 x 1\r62mm UV  x 1\r52mm UV  x 2\r72mm UV  x 2\r申报: Gift $18'),(13745,703180373001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','2011siarhei','mr_sergey@ro.ru','Siarhei Kalatsei','MZHK \"SOLNECHNY\", 1-154','Gomel','','BELARUS','246046','(37529) 239-7773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 08:23:25',0,NULL,3,1,5,1,'CP227167985CN ','2011siarhei'),(13746,8881311755592424,111,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New * 5',5,'AA1310',26.3,'hermeshine','Aliexpress-1003724060','point@netvision.com.br','Moacir Giacomozzi	','AV. JUSCELINO KUBITSCHECK 410','JOINVILLE','SANTA CATARINA	','BRAZIL','89201-100','+55 47 30276310',NULL,NULL,NULL,NULL,0,NULL,3,1,3,1,'RA183617017CN\r ',NULL),(13747,808193158016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','adam_lofty','adaml_192@hotmail.co.uk','Adam Lofthouse','15 Cheviot Road<br>Long Eaton','Nottingham','Nottinghamshire','UNITED KINGDOM','NG10 4FU','01159721246','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 08:51:38',0,NULL,3,1,2,1,NULL,'adam_lofty'),(13748,703814132018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','becz-t1991','becz.thomson@hotmail.com','Rebekah Thomson','61 Hunter Circuit','Petrie','Queensland','AUSTRALIA','4502','0732856719','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 09:32:40',0,NULL,3,1,4,1,'YW866475256CN ','becz-t1991\r1.6*2.1黑布     1\r1.6*2.1白布      1\r发新的那个折叠背景架    '),(13749,744778921002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','mcfl83','assistantdevie83@orange.fr','muriel carer','resid st roch<br>28 ave foch','st tropez','Provence-Alpes-Côte d\'Azur','FRANCE','83990','0494796094','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 09:48:42',0,NULL,3,1,3,1,'RA183617238CN ','mcfl83\r(已入库）'),(13750,703201697001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','solncokot','zheniagorobec@mail.ru','Yevgeniya Gorobets','abay st. 80/1, 22','Astana','Astana','KAZAKHSTAN','010000','+77023844847','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 09:56:15',0,NULL,3,1,2,1,' ','solncokot'),(13751,703202204001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','pantelis51','gmadarakis@gmail.com','MADARAKIS YORGOS / NIKOS','AIK. BARELA 6, NOMOS PELLAS','GIANNITSA','','GREECE','58100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 09:56:48',0,NULL,3,0,17,0,NULL,'pantelis51'),(13752,8881311761792401,111,'Non Woven Fabric Backdrop 4m long 1.6m width ',1,'',12,'hermeshine','ezipman','yapls2002@yahoo.com.sg','William Yap','Blk 662 Choa Chu Kang Crescent #16-271 Singapore 680662','Singapore','Singapore','SINGAPORE','680662','+6591808647',NULL,NULL,NULL,NULL,0,NULL,3,0,3,1,'RA183617140CN ',' 1.6x4m 背景布 黑色  x  1\r(注意是4米)'),(13753,703825322018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','sin_v','sin_v@internode.on.net','Volodymyr Sinkov','SAGE Automation 34 Bennet Avenue','MELROSE PARK','South Australia','AUSTRALIA','5039','0415248070','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 10:24:22',0,NULL,3,1,3,1,'RA183617136CN ','sin_v'),(13754,703210342001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','iproblem','tamaramammadova@yahoo.com','Farah Gasimzada','Euroasian Cargo, Building 75, Ste. 230<br>Cargo Area D JFK Intl., Airport','Jamaica','NY','UNITED STATES','11430','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-27 10:34:46',0,NULL,3,1,1,1,NULL,'iproblem'),(13755,703366648018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','kawake567','karenwakeling@yahoo.com.au','Karen Wakeling','24 Marlowe Rd','Bateau Bay','New South Wales','AUSTRALIA','2261','0243324146','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-27 10:52:58',0,NULL,3,1,4,1,'YW866475153CN ','kawake567'),(13756,703217719001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','pantelis51','gmadarakis@gmail.com','MADARAKIS YORGOS / NIKOS','AIK. BARELA 6, NOMOS PELLAS','GIANNITSA','','GREECE','58100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:01:42',0,NULL,3,0,3,1,'RA183617207CN\r ','pantelis51\r1.6*2.1    黑色背景布      1\r1.6*2.1    白色背景布          1'),(13757,758694062017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','malatratinchica','martinagyofi@gmail.com','Martina Gyofi','M.Kovaca 32<br>Strahoninec','Cakovec','Croatia','CROATIA','40000','+385989875749','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 11:27:04',0,NULL,3,1,2,1,NULL,'malatratinchica'),(13758,703845421018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','geekay7211','gotchatalents@hotmail.com','Gracie Kostner','2 Lancely Green','Caroline Springs','Victoria','AUSTRALIA','3032','0304570934','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-27 11:34:25',0,NULL,3,1,4,1,'YW866475164CN ','geekay7211'),(13759,744805581002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:37:53',0,NULL,3,1,3,1,'RA183617119CN ','boyadjy'),(13760,744699423002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','aoluz2008','aoluz@bol.com.br','Almir Oliveira da Luz','Rua Rubens Calasans Camargo,270<br>Residencial Planalto','São José dos Campos','São Paulo','BRAZIL','12220-030','055411281124151','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 11:49:07',0,NULL,3,1,2,1,NULL,'aoluz2008\rNIKON 镜头盖 67mm        1 \r绿叶 CPL  67mm                 1'),(13761,703850094018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','silo8844','silas.wan@gmail.com','Silas Wan','Level 16, 570 George St<br>(Enter from Bathurst St)','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 11:54:39',0,NULL,3,1,2,1,NULL,'silo8844'),(13762,744814192002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','el_duddles','alfonsodominguezlavin@gmail.com','ALFONSO DOMINGUEZ LAVIN','CALLE LAS TERCIAS 10,2A','LAGUNA DE DUERO','Castilla y León','SPAIN','47140','647834485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:16:27',0,NULL,3,1,2,1,NULL,'el_duddles'),(13763,825439718015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','apocalyptica1304','c.rosier@hotmail.fr','Chloé Rosier','Chaussée d\'Alsemberg,645','Bruxelles','','BELGIUM','1180','0472382503','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 12:30:15',0,NULL,3,1,2,1,NULL,'apocalyptica1304'),(13764,703244705001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','antoshka8877','a.n.t.o.s.h.k.a@mail.ru','Антон Джавадян','ул. Набережная, д.59','Пятигорск','Ставропольский край','RUSSIAN FEDERATION','357560','79286514471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:44:47',0,NULL,3,1,3,1,'RA183617167CN ','antoshka8877'),(13765,744825915002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','jcrldo','charly_1987_19@msn.com','Carlos Ruiz','francisco pizarro<br>Nº 1','lebrija','Andalucía Ceuta y Melilla','SPAIN','41740','955971975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 12:52:45',0,NULL,3,1,2,1,' ','jcrldo\r'),(13766,825452092015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','vzkm','vitorvmii@yahoo.com.br','Vitor Masaktsu','Av. Miguel Estefano, 1973 bl. 7 ap. 82<br>Agua Funda','Sao Paulo','Brazil','BRAZIL','04301012','1193513250','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-27 13:05:10',0,NULL,3,1,2,1,' ','vzkm'),(13767,703255127001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','aleyer_s','aleyer@yandex.ru','Aleksey Sukhonosov','11 Romana Karmena street, flat 26','Odessa','','UKRAINE','65044','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 13:22:10',0,NULL,3,1,3,1,'RA183617241CN\r ','aleyer_s'),(13768,703255657001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','jbvdbos','jessebeau@me.com','Jesse Beau van den Bos','Hortensialaan 1','Groningen','','NETHERLANDS','9713 KG','0642475960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 13:23:43',0,NULL,3,1,4,1,'YW866475212CN ','jbvdbos'),(13769,703268254001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','runudu','ruinunoduarte@gmail.com','Rui Duarte','Rua Assis Vaz, 113','Porto','Porto','PORTUGAL','4200-096','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:07:15',0,NULL,3,1,2,1,NULL,'runudu'),(13770,744852260002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','dr-luk','luca.favero@fastwebnet.it','Dr.Luca Favero','Policlinico S.Orsola - uff RGV (Pad3)<br>via Albertoni 15','Bologna','BO','ITALY','40138','349-3787740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:22:07',0,NULL,3,1,17,0,NULL,'dr-luk'),(13771,744851797002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','dr-luk','luca.favero@fastwebnet.it','Dr.Luca Favero','Policlinico S.Orsola - uff RGV (Pad3)<br>via Albertoni 15','Bologna','BO','ITALY','40138','349-3787740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:22:08',0,NULL,3,0,17,0,NULL,'dr-luk'),(13772,744852042002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','dr-luk','luca.favero@fastwebnet.it','Dr.Luca Favero','Policlinico S.Orsola - uff RGV (Pad3)<br>via Albertoni 15','Bologna','BO','ITALY','40138','349-3787740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:22:09',0,NULL,3,1,3,1,'RA183617286CN\r ','dr-luk\r小号灰卡     1\r大号内胆包 nikon      2\r新地址  \rFLAVIO TAMBURRIELLO\rVIALE LENIN 11, int. 9\r40139 BOLOGNA \rITALY\r432\rcamera cover  $10\r\r'),(13773,758750195017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','rudolpheredy','jjrr1280@hotmail.com','J.J Rudolphe Redy','20 anemone avenue, Debarcadere,<br>Pte-aux-sables','Port-louis','Mauritius','MAURITIUS','nil','2307674269','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 14:29:00',0,NULL,3,1,8,1,'CP227167923CN ','rudolpheredy\r0819来信说收到货了'),(13774,744771234002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','denismilea','mileadenis@gmail.com','Lutik Ratu','Mircea cel batran-23 kv.100','Kishineov','Lutic Radu','MOLDOVA, REPUBLIC OF','MD_2075','068128098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 14:29:58',0,NULL,3,1,5,1,'CP227168115CN ','denismilea\r欧标'),(13775,825487919015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','yewboy42','richardjvernon@yahoo.co.uk','Richard Vernon','3 The Street<br>Uley','Dursley','GLOS','UNITED KINGDOM','GL11 5AG','07775722065','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-27 14:42:04',0,NULL,3,1,2,1,NULL,'yewboy42'),(13776,703479408018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','fede-p','federicopacini@hotmail.it','Federico Pacini','Via del ginepro 13<br>Monteriggioni','Siena','SI','ITALY','53035','338 9589900','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-27 15:38:58',0,NULL,3,1,4,1,'YW866475223CN ','fede-p\r欧标\rlighting kit  $35'),(13777,703321194001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','mundoreflex','info@mundoreflex.es','Eduardo Barcellona','San Lorenzo 1, 3A','AZUQUECA HRES.(GUADALAJARA)','Castilla-La Mancha','SPAIN','19200','687946586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 16:44:40',0,NULL,3,1,2,1,NULL,'mundoreflex'),(13778,744910870002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','regalos-boda','pedidos@regalos-boda.com','www.regalos-boda.com','AVDA. UNIÓN EUROPEA 11 NAVE E<br>POL. IND. EL CASTILLO','Sax','Comunidad Valenciana','SPAIN','03630','692174290','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 17:10:43',0,NULL,3,1,17,0,NULL,'regalos-boda'),(13779,744911223002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','regalos-boda','pedidos@regalos-boda.com','www.regalos-boda.com','AVDA. UNIÓN EUROPEA 11 NAVE E<br>POL. IND. EL CASTILLO','Sax','Comunidad Valenciana','SPAIN','03630','692174290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 17:10:44',0,NULL,3,1,4,1,'YW866475190CN ','regalos-boda\r灯架  2m      2\r柔光箱 50-70cm 单灯头   欧标      2\r115w 5500k 灯泡  220v      2\r灯架包           1\r圆形柔光棚 50cm         1'),(13780,744918119002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','mogly73','etienneducharme@videotron.ca','Etienne Ducharme','1027, Rue Ronsard','Deux-Montagnes','QC','CANADA','j7r6n2','(450) 974-2526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 17:26:25',0,NULL,3,1,2,1,NULL,'mogly73'),(13781,703349470001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','capiche_capiche','eva.grilletto@gmx.de','Eva Grilletto','Paulinenstr.27','Villingen-Schwenningen','','GERMANY','78054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 18:03:18',0,NULL,5,0,18,0,NULL,'capiche_capiche'),(13782,758843328017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','ibnomer','nihlawi.m@gmail.com','Mohammad Nihlawi','sharjah alriqqa<br>v21b','sharjah','sharjah','UNITED ARAB EMIRATES','22531','00971505972267','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-27 18:17:50',0,NULL,3,1,3,1,'RA183617096CN ','ibnomer\r英标 \r4票\rRA183617082CN\rRA183617079CN\rRA183617065CN'),(13783,703302229001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',2,'AKT029',48,'hermeshine','kq','d29501@gmail.com','Dan Hicks','137 S Coit St','Florence','SC','UNITED STATES','29501','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-27 19:16:05',0,NULL,3,1,17,0,NULL,'kq'),(13784,703385909001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','estatikieti','emidecai@gmail.com','Emilio Delgado Rubio','Plaza Jaen 3 Escalera derecha 1ºA','San Fernando','Cadiz','SPAIN','11100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 19:17:34',0,NULL,3,1,4,1,'YW866475201CN ','estatikieti\rTripod   $ 22\r'),(13785,758830510017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',122.8,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 19:22:35',0,NULL,3,1,4,1,'YW866475175CN ','brunos_92\r反光板支架             1\r100*150的5和1         1\r45w 220v      灯泡       4\r反光板 80cm 2合1          1\r已入库\r燕文一票两件    \r已发信 已收到'),(13786,758643629017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','vladmototolea2009','vladmototolea@yahoo.com','Vlad Mototolea','posta Veche, 36','Galati','Galati','ROMANIA','800115','745375308','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 19:22:56',0,NULL,3,1,3,1,'RA183617175CN ','vladmototolea2009'),(13787,744975588002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',29.98,'hermeshine','garciapablo38-2008','garciapablo38@hotmail.com','PABLO ENRIQUE GARCIA INTERIAN','49 # 510-B X 62 Y 64 CENTRO','MERIDA','YUCATAN','MEXICO','97000','9999239171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 19:32:24',0,NULL,3,1,17,0,NULL,'garciapablo38-2008'),(13788,744970495002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',29.98,'hermeshine','garciapablo38-2008','garciapablo38@hotmail.com','PABLO ENRIQUE GARCIA INTERIAN','49 # 510-B X 62 Y 64 CENTRO','MERIDA','YUCATAN','MEXICO','97000','9999239171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-27 19:32:25',0,NULL,3,1,17,0,NULL,'garciapablo38-2008'),(13789,703391946001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','garciapablo38-2008','garciapablo38@hotmail.com','PABLO ENRIQUE GARCIA INTERIAN','49 # 510-B X 62 Y 64 CENTRO','MERIDA','YUCATAN','MEXICO','97000','9999239171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 19:32:25',0,NULL,3,1,3,1,'RA183617215CN ','garciapablo38-2008\r柔光伞110cm      4\r永诺 canon ttl 线  1m        1'),(13790,744881910002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',10,'AA1301',26,'hermeshine','kq','d29501@gmail.com','Dan Hicks','137 S Coit St','Florence','SC','UNITED STATES','29501','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 19:16:04',0,NULL,3,1,1,1,NULL,'kq\r---\r52mm 镜头盖 尼康 x 2\r62mm 镜头盖 尼康 x 2\r67mm 镜头盖 尼康 x 2\r72mm 镜头盖 尼康 x 2\r77mm 镜头盖 尼康 x 2\r\r58mm 镜头盖 佳能 x 12\r67mm 镜头盖 佳能 x 2\r72mm 镜头盖 佳能 x 2\r77mm 镜头盖 佳能 x 4'),(13791,744977240002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','mamahannes','hannes.francke@web.de','Hannes Francke','Kochhannstr.21','Berlin','','GERMANY','10249','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 19:36:51',0,NULL,3,1,4,1,'YW866475186CN ','mamahannes\r本身就是欧标   不需要放标了'),(13792,758903296017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','gaprovideostudio','alexstudio81@mail.ru','Алексей Галютин','Голубятникова 13-96','Казань','Республика Татарстан','RUSSIAN FEDERATION','420094','+79600481638','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-27 20:16:51',0,NULL,3,1,5,1,'CP227168124CN ','gaprovideostudio\r欧标'),(13793,758904480017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','kirbybuffe43','kirby_buffe43@yahoo.com','Kirby Buffe','5790 sw 42nd ter','miami','FL','UNITED STATES','33155-5314','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-27 20:18:31',0,NULL,3,1,1,1,' ','kirbybuffe43'),(13794,703465044001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',193,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 22:55:11',0,NULL,3,1,17,0,NULL,'saud-p'),(13795,703248069001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',193,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-27 22:55:12',0,NULL,3,1,17,0,NULL,'saud-p\r'),(13796,745064916002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',2,'AO0034',18,'hermeshine','pacorabanne12','joco_zoro12@hotmail.com','Jovica Markovski','1269 Millstone Road','Brewster','MA','UNITED STATES','02631','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-27 23:39:29',0,NULL,3,1,1,1,NULL,'pacorabanne12'),(13797,702820278018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','09franni','serenityjane@live.com','Serenity Caldwell','167 Patchs bch Rd','Patchs Beach','New South Wales','AUSTRALIA','2478','0432664164','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-27 23:56:00',0,NULL,3,0,3,1,'RA183615121CN','09franni\r'),(13798,825761428015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','painterakos','zwgrafos_a@hotmail.com','asterios zwgrafos','pappanastasiou 6A','thermi / thessalonikis','','GREECE','57001','+0306944665367','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 00:31:02',0,NULL,3,1,2,1,NULL,'painterakos'),(13799,702419053001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',86.05,'hermeshine','miginium','mel@migin.net','Melvin Migin','G 10, Lorong Kenari 3,<br>Taman Likas Jaya,','Kota Kinabalu','Sabah','MALAYSIA','88400','0168103500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 02:09:12',0,NULL,3,0,3,1,'RA183617224CN ','miginium\rC里的转接环要 67mm的\r广角托架    1\r转接环  77       1\r转接环    52      1\r天涯方形CPL       1\r（已入库）\r'),(13800,704155499018,280680264573,'New Camera Bag Cover for Canon 40D/50D 18-135 / 18-200',1,'AD1115',15.99,'photographyacc','marcelosebastianf','marcelofariashome@gmail.com','marcelo farias','las heras 2147 4to b','ciudad autonoma de buenos aires','buenos aires','ARGENTINA','C1127AAD','(+54 11) 38112142','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-28 02:38:10',0,NULL,3,1,2,1,NULL,'marcelosebastianf'),(13801,8881311822195378,111,'New Photo Studio Light Stand Umbrella Flash Mount set * 5',5,'AKT014',209.5,'hermeshine','caczerny','carlos.czerny@gmail.com','Carlos Victor Czerny','Peru 160 Piso 5to sistemas (int. 4145)','Ciudad autonoma de Buenos Aires','','ARGENTINA','C1067AAD','+5491150193614',NULL,NULL,NULL,NULL,0,NULL,3,1,5,1,'CP227167954CN ',' '),(13802,703533716001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','siubobo95','siubobo95@cox.net','Gary Lee','25 Pavona','Newport Coast','CA','UNITED STATES','92657','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 03:52:52',0,NULL,3,1,17,0,NULL,'siubobo95'),(13803,745124955002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','siubobo95','siubobo95@cox.net','Gary Lee','25 Pavona','Newport Coast','CA','UNITED STATES','92657','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 03:55:44',0,NULL,3,1,1,1,NULL,'siubobo95\r方形滤镜接口环 77mm   1\r方镜普通托架（三槽）    1\r方镜广角托架（ 一槽）    1\r'),(13804,704181059018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',225,'photographyacc','chap1969','chap_reb@bigpond.com','shane chapman','PO Box 173','Brewarrina','New South Wales','AUSTRALIA','2839','0268392034','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-28 04:38:04',0,NULL,3,1,4,1,'YW866475573CN ','chap1969\r澳标\rlighting kit $40'),(13805,704189271018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',6.6,'photographyacc','jcaligiore','jesscaligiore@gmail.com','Jessica Caligiore','54 wellbank st<br>concord','sydney','New South Wales','AUSTRALIA','2137','0297442347','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 05:26:28',0,NULL,3,1,2,1,NULL,'jcaligiore'),(13806,759053889017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',58.99,'photographyacc','tradeyjess','jessicajh@bigpond.com','Jessica Hogan','15 Allanbi Circle<br>Carramar','Perth','Western Australia','AUSTRALIA','6031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 05:27:40',0,NULL,3,1,3,1,'RA183617405CN\r ','tradeyjess\r60cm 柔光棚  1\rlenspen   1\r气吹 + 布   1\r45w  220v    2'),(13807,704189617018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','hasselblad_kid','dhphotographie@live.ca','Denis Hamel','923 Montarville','Laval','QC','CANADA','H7R5H7','(450) 627-6304','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-28 05:29:31',0,NULL,3,1,2,1,NULL,'hasselblad_kid'),(13808,703513880001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','ajalilian','antonio.jalilian@gmail.com','Antonio Siavash Jalilian','2 - 6 John Jennings Drive<br>Albany','Auckland','North Shore','NEW ZEALAND','0623','006421717680','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:03:25',0,NULL,3,1,6,1,'EE495341034CN ','ajalilian\r澳标'),(13809,744563099002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',2,'AA1103',60,'hermeshine','bmonye','bjmonye@mobileemail.vodafonesa.co.za','Bonolo Monye','31 Sunesis Greenhills Estate<br>corner Pine and Robina road','Greenhills','Gauteng','SOUTH AFRICA','1759','+27829552527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:27:47',0,NULL,3,1,3,1,'RA183617309CN ','bmonye'),(13810,745154366002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','myrkg','buchkg@gmail.com','Pavel Kuznetsov','Chui 61a #1','Bishkek','','KYRGYZSTAN','720065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:57:11',0,NULL,3,1,17,0,NULL,'myrkg'),(13811,703560991001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','myrkg','buchkg@gmail.com','Pavel Kuznetsov','Chui 61a #1','Bishkek','','KYRGYZSTAN','720065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:57:12',0,NULL,3,1,17,0,NULL,'myrkg'),(13812,745151719002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','myrkg','buchkg@gmail.com','Pavel Kuznetsov','Chui 61a #1','Bishkek','','KYRGYZSTAN','720065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 06:57:12',0,NULL,3,0,8,1,'CP227167971CN ','myrkg\r1.6x3m 背景布   1  棕色\r50-70 金属卡口棚   1\r2m 灯架   1\r单灯头  欧标   1\r反光伞    1\r2.721'),(13813,703578335001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','rappange','rappange2@hotmail.com','Roy Rappange','Vijftigbunder 74','Breda','','NETHERLANDS','4823BG','+31767074159','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 08:15:16',0,NULL,3,1,2,1,NULL,'rappange'),(13814,704222349018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','mangrovedutch','j.vaneck@gotalk.net.au','Jorgen van Eck','470 Teviot Road','North Maclean','Queensland','AUSTRALIA','4280','0410690316','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 08:21:09',0,NULL,3,1,2,1,NULL,'mangrovedutch'),(13816,702409023018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',21.5,'photographyacc','xdimxvideo','xdimx@land.ru','DMITRY PONOMARENKO','Lenina St. 83A-56','Chelyabinsk','','RUSSIAN FEDERATION','454080','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-28 09:57:31',0,NULL,3,1,3,1,'RA183617326CN\r ','xdimxvideo'),(13817,703597076001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','bluecity2010','36hotdog@gmail.com','Balazs Attila Szabo','Bocskai 15 C/2 3/10','Puspokladany','Hajdu Bihar','HUNGARY','4150','(0036) 034 - 6738','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:00:58',0,NULL,3,1,2,1,NULL,'bluecity2010\r换成M号的'),(13818,759115114017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','merbel','merrick@wn.com.au','Merrick Belyea','152 South Street<br>White Gum Valley','Fremantle','Western Australia','AUSTRALIA','6162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 10:09:21',0,NULL,3,1,17,0,NULL,'merbel'),(13819,704247504018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','merbel','merrick@wn.com.au','Merrick Belyea','152 South Street<br>White Gum Valley','Fremantle','Western Australia','AUSTRALIA','6162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 10:17:50',0,NULL,3,1,2,1,NULL,'merbel\r绿叶 UV  58mm    1\r绿叶 渐变镜 58mm     1'),(13820,759122762017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','vivian7250','vivi.amos123@gmail.com','Vivian Amos','9 Glendower Court','Mooroolbark','Victoria','AUSTRALIA','3138','0397268256','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 10:40:50',0,NULL,3,1,2,1,NULL,'vivian7250'),(13821,703598480001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','tartac','chaiyut_c@yahoo.com','Charoenchaikorn Chaiyut','PTT Public company / Phrakhanong Office Floor 2<br>555 Ardnarong Rd. Klongtoey','default','BA','THAILAND','10260','026444544','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 10:54:16',0,NULL,3,1,3,1,'RA183617670CN\r ','tartac\r环换成72的'),(13822,704259259018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','enk097','tanja.lakic@gmail.com','Tanja Lakic','Zvonimirova 63','Zagreb','Zagreb','CROATIA','10 000','+385 91 560 61 93','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-28 11:04:22',0,NULL,3,1,2,1,NULL,'enk097'),(13823,703618127001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',4.96,'hermeshine','stardustdk2','stardustdk@gmail.com','John Poulsen','Steen  Billes  Gade 9, 1. th.','Aalborg','','DENMARK','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 11:21:06',0,NULL,3,1,2,1,' ','stardustdk2'),(13824,745222383002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','fibromick','mprusa@ozemail.com.au','Michael Prusa','42 Archdall ST.','Macgregor','Australian Capital Territory','AUSTRALIA','2615','0262548202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 12:07:47',0,NULL,3,1,2,1,NULL,'fibromick'),(13825,745226359002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 12:22:34',0,NULL,3,1,2,1,NULL,'bobi1330'),(13826,825971357015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.8,'hutongstore','alfirev74','galfirev@vip.hr','Goran Alfirevic','put vrila 9','omis','CROATIA','CROATIA','21310','00385911864305','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 13:25:30',0,NULL,3,1,2,1,NULL,'alfirev74'),(13827,825812727015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','coy2s','francis_abcede@yahoo.com','francis abcede','4/f BPI GLOBE BANKO CENTER ORTIGAS AVE. NORTH GREENHILLS,','SAN JUAN','METRO MANILA','PHILIPPINES','1502','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 13:35:59',0,NULL,3,1,2,1,NULL,'coy2s'),(13828,703655876001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',84.96,'hermeshine','thijulio','thijulio@gmail.com','Thiago Valença','Rua Moacir Miguel da Silva, 765','São paulo','São Paulo','BRAZIL','05595000','1185273017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:39:06',0,NULL,3,1,5,1,'CP227167804CN ','thijulio--AbnerSSouza介绍的新客户\r申报 tripod  $30'),(13829,745247869002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',5.9,'hermeshine','ainha1234','diogo_pereira7@hotmail.com','Diogo Pereira','Rua Carmen Miranda nº20 5ºA 2840-424 Seixal','Torre da Marinha','Seixal','PORTUGAL','2840-424','924441133','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 13:40:18',0,NULL,3,1,2,1,NULL,'ainha1234'),(13830,703663186001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','expert2102','janaphoto@yandex.ru','Yana Danilova','Stepana Razina st. 60/167','Izhevsk','RU','RUSSIAN FEDERATION','426032','7-919-901-79-52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 14:05:45',0,NULL,3,1,3,1,'RA183617388CN\r ','expert2102'),(13831,745271473002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','debjenrob','debjenrob@hotmail.com','JEROME STEINER','62 Spencer Dr','JACKSON','NJ','UNITED STATES','08527','(732) 928-3297','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 14:57:12',0,NULL,3,1,1,1,NULL,'debjenrob'),(13832,826023379015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','tom_the_pr0','tom4u@hotmail.co.uk','Tom Murphy','Turfhouse<br>Luppitt','Honiton','Devon','UNITED KINGDOM','EX144sa','01404891685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 15:44:35',0,NULL,3,1,2,1,NULL,'tom_the_pr0'),(13833,745289210002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 15:52:13',0,NULL,3,1,5,1,'CP227167968CN ','zonagrib\r欧标'),(13834,703679422001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-28 15:59:38',0,NULL,3,1,17,0,NULL,'saud-p'),(13835,703698553001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','johannenb','jnyb_1994@hotmail.com','Inge Johan Sylta','Berle','Bremanger','','NORWAY','6727','57795395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 16:01:11',0,NULL,3,1,2,1,' ','johannenb'),(13836,704350188018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','puffy1281','puffywuffywoo@hotmail.com','Benjamin Collins','29 scott street<br>koongamia','perth','Western Australia','AUSTRALIA','6056','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-28 16:10:08',0,NULL,3,1,4,1,'YW866475536CN ','puffy1281\rBackground Support    $25'),(13837,703712979001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 16:41:28',0,NULL,3,1,3,1,'RA183617365CN\r ','m.petrosyan'),(13838,703715405001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','robertogreg','roberto@topnet.it','roberto   gregori','419/ma, 2','ascoli piceno','AP','ITALY','63100','3926041866','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-28 16:48:24',0,NULL,3,0,3,1,'RA183617269CN\r ','robertogreg\rxl    的   （已入库）\rphoto vert  $12'),(13839,826054276015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','druckz22','druckerf@yahoo.com','Drucker Fanged','8 Grovehill Road','Redhill','Surrey','UNITED KINGDOM','RH1 6PJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-28 16:54:54',0,NULL,3,1,2,1,NULL,'druckz22'),(13840,703718680001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','roderick4012','roderick.shilling@gmail.com','Roderick Khan','1302 Exchange Dr<br>Ste 100','Richardson','TX','UNITED STATES','75081-2315','(469) 916-8318','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 16:57:26',0,NULL,3,1,3,1,'RA183617357CN\r ','roderick4012\r110 v    的     \r注意是8个'),(13841,745314646002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','dbolight','beaulightfoot@hotmail.com','Beau Lightfoot','9020 Bartonsville Woods Road','Stroudsburg','PA','UNITED STATES','18360','6464681311','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 17:02:13',0,NULL,3,1,1,1,NULL,'dbolight'),(13842,745315340002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',75.8,'hermeshine','fmaeda','fabianomaeda@gmail.com','Fabiano Maeda','Av Guedner, 1137 - Ap 709','Maringa','Parana','BRAZIL','87050390','55 (44) 9919-9823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:03:12',0,NULL,3,1,5,1,'CP227167937CN ','fmaeda'),(13843,703722766001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','pracan.uy','elojonet@gmail.com','Prado Federico','Ituzaingo 133','Mercedes','Soriano','URUGUAY','75000','099529248','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 17:07:58',0,NULL,3,1,3,1,'RA183617391CN\r ','pracan.uy'),(13844,826064313015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','tigertec','deanqxl@hotmail.com','DEAN BYFORD','155 FROBISHER ROAD','ERITH','Kent','UNITED KINGDOM','DA8 2PU','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-28 17:32:47',0,NULL,3,1,4,1,'YW866475540CN ','tigertec\r英标\rLighting Kit  $28'),(13845,826088625015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-28 18:04:34',0,NULL,3,1,2,1,NULL,'af_133'),(13846,742410280002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','sacco_1993','sacco1993@hotmail.com','Doreen Sacco','28 Fl B Monaco<br>Parades Street','St.Paul\'s Bay','StPaul\'s Bay','MALTA','SPB02','27016595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 18:15:04',0,NULL,3,1,3,1,'RA183617330CN\r ','sacco_1993'),(13847,745367813002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','sus_hau','sus_ha@hotmail.com','susanne haukanes','hummelsund','steinsland','steinsland','NORWAY','5379','97172729','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 19:09:26',0,NULL,3,1,3,1,'RA183617343CN\r ','sus_hau'),(13848,703796670001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','benzar6500','rene@duelund-holm.dk','René Holm','Odinsvej 53','Vojens','','DENMARK','6500','+4530405055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 20:08:14',0,NULL,3,1,17,0,' ','benzar6500'),(13849,745390460002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','benzar6500','rene@duelund-holm.dk','René Holm','Odinsvej 53','Vojens','','DENMARK','6500','+4530405055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 20:08:15',0,NULL,3,1,17,0,NULL,'benzar6500'),(13850,745395381002,120619188563,'NEW 67mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT046',30,'hermeshine','benzar6500','rene@duelund-holm.dk','René Holm','Odinsvej 53','Vojens','','DENMARK','6500','+4530405055','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-28 20:09:32',0,NULL,3,1,3,1,'RA183617459CN ','benzar6500\r除了C里面的再加上(+8近摄镜换成+4的)\r天涯方形滤镜系列  星光镜  star8     1\r气吹 + 布      1\r近摄镜+8 换成 +4  的  （已入库）'),(13851,703835289001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mikepfs1','mikepfs1@yahoo.com','Mike Perez','4900 N Grand Ave<br>Apt 331','COVINA','CA','UNITED STATES','91724-1096','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-28 21:39:06',0,NULL,3,1,1,1,NULL,'mikepfs1'),(13852,759379840017,270777043723,'Video 2400w Red Head Continuous Lighting Kit 800w x 3',2,'AKT072',598,'photographyacc','tuska03','davepickford75@hotmail.com','Dave','4 Bowerbird Place<br>Burleigh Waters','Gold Coast','Queensland','AUSTRALIA','4220','0412607716','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-28 22:00:36',0,NULL,3,1,17,0,NULL,'tuska03'),(13853,759382412017,270759687007,'New soft box photography studio continue lighting Set ',2,'AKT016',190,'photographyacc','tuska03','davepickford75@hotmail.com','Dave','4 Bowerbird Place<br>Burleigh Waters','Gold Coast','Queensland','AUSTRALIA','4220','0412607716','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-28 22:06:53',0,NULL,3,1,6,1,'EE406974195CN','tuska03\rYW866475551CN\r灯架  2m     10\r800w红头灯   澳标      6\r800w  220v 灯泡      12\r红边套装包          2\r柔光箱 50-70cm 单灯头   澳标     4\r灯架包         2\r27.072'),(13854,759397194017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','00llr00','lachlanryan@ymail.com','Lachlan Ryan','10 Palla Street','Griffith','New South Wales','AUSTRALIA','2680','0269644870','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-28 22:54:39',0,NULL,3,1,2,1,NULL,'00llr00'),(13855,703860007001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','stas-keld','stas.keld@gmail.com','Stanislav Borisov','Avrora, 183-6','Samara','Samara Region','RUSSIAN FEDERATION','443045','7 (846) 223-51-63','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-28 23:08:07',0,NULL,3,1,3,1,'RA183617374CN\r ','stas-keld'),(13856,703690287001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-29 00:08:28',0,NULL,3,1,12,1,'BJ8824501 ','saud-p\r背景架2m x 3m + 3个夹子     2\r背景架2mx 1.6m        2 \r背景布 1.6  *2.1   白的      1\r1.6x2.1 背景布   （白 黑）      2\r灯架  2m         4\r柔光箱 50-70cm 单灯头欧标       4\r115w 5500k 灯泡  220v          4\r灯架包          2\r再加一块3米*6米 黑色背景布    他说上一块撕了   \r在灯架和背景架上都贴上made in china\r申报实值'),(13857,704534092018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',2,'AKT069',140,'photographyacc','theplanroom','mark@inprotrans.com','Mark O\'Malley','Inprotrans Pty Ltd<br>320 Churchill Road','Kilburn','South Australia','AUSTRALIA','5084','0417846008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 00:09:03',0,NULL,3,1,4,1,'YW866475562CN ','theplanroom\r注意是8个\rPhotograph​y  Bulb    $22'),(13858,745472652002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',33.98,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','8333661044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 00:15:18',0,NULL,3,1,3,1,'RA183617272CN\r ','goinha2011\r欧标\r新地址\rGLORIA MARIA MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r申报 gift \r\r\r'),(13859,552462953003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','juanibarra79','algabba@hotmail.com','Juan Alberto Ibarra','ituzaingò 265','Lujan','Buenos Aires','ARGENTINA','6700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:37',0,NULL,3,1,5,1,'CP227167945CN ','juanibarra79'),(13860,703888657001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:50',0,NULL,3,1,17,0,NULL,'dr20616'),(13861,703885985001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.2,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:51',0,NULL,3,1,17,0,NULL,'dr20616'),(13862,703886476001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:51',0,NULL,3,1,17,0,NULL,'dr20616'),(13863,703886292001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:52',0,NULL,3,0,17,0,NULL,'dr20616'),(13864,703887847001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',2,'AC1303',15,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:52',0,NULL,3,1,17,0,NULL,'dr20616'),(13865,703888385001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','dr20616','shantha.ambrose@gmail.com','Shantha Ambrose','Newell Rubbermaid<br>500, Princess Highway','Noble Park','Victoria','AUSTRALIA','3174','0432249260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 01:19:53',0,NULL,3,1,3,1,'RA183617312CN\r ','dr20616\r6片装的滤镜袋    1\r镜头筒 xl 大号      1\r镜头筒 小号       1\r镜头筒 中号      1\r大号内胆包 nikon           2\r橡胶遮光罩 52mm      1'),(13866,703901388001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',4,'AA1312',6,'hermeshine','danaudi','dan.iancu@hotmail.com','Dan Iancu','775 Main St<br>Apt 602','Buffalo','NY','UNITED STATES','14203-1327','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 02:12:53',0,NULL,3,1,1,1,NULL,'danaudi'),(13867,745515295002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','kaya.yer','mochit@hotmail.com','Vichit Natthipanya','3755/6 Rama 4 Rd.<br>Phrakanong','Klongtoei','Bangkok','THAILAND','10110','+6689-479-1299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 03:16:07',0,NULL,3,1,17,0,NULL,'kaya.yer'),(13868,745515296002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','kaya.yer','mochit@hotmail.com','Vichit Natthipanya','3755/6 Rama 4 Rd.<br>Phrakanong','Klongtoei','Bangkok','THAILAND','10110','+6689-479-1299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 03:16:08',0,NULL,3,1,2,1,NULL,'kaya.yer\r方形滤镜接口环 77mm      1\r方镜广角托架（ 一槽）     1'),(13869,699147746001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',119.9,'hermeshine','petrus1971peter','petermeyer@vodamail.co.za','Peter Meyer','22 Minnesota<br>Emily Hobhouse Road','Honeydew Ridge','Gauteng','SOUTH AFRICA','1736','027791473257','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-29 03:49:19',0,NULL,3,1,3,1,'RA183617961CN\r ','petrus1971peter\r背景架  2m x 2m （新的3节的）  1\r1.6x2.1 背景布   3\r白 黑 绿\r两票\rRA183622082CN\r'),(13870,702702566018,280683075819,'Stereo Microphone for DC DV Camcorder 60D 5D II 7D 550D',1,'AA1215',42.99,'photographyacc','prasadsanj','klsanjeewa@gmail.com','prasad perera','|No : 377D<br>church road,wella','marawila','NWP','SRI LANKA','61210','0094777872351','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-29 04:34:54',0,NULL,3,1,3,1,'RA183617445CN ','prasadsanj'),(13871,745531444002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jackalex79','jackal79@yandex.ru','Aleksey Obukhov','Lomonosova 20-41','Abakan','Khakassia','RUSSIAN FEDERATION','655011','+79135477595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 04:53:25',0,NULL,3,1,2,1,' ','jackalex79'),(13872,704597642018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','evxaya888','bettymatt@iprimus.com.au','matthew cardinal','11 creekview way','wyndhamvale- west melbourne','Victoria','AUSTRALIA','3024','0397311841','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 05:10:26',0,NULL,3,1,17,0,NULL,'evxaya888'),(13873,704599796018,280680264573,'New Camera Bag Cover for Canon 40D/50D 18-135 / 18-200',1,'AD1115',15.99,'photographyacc','evxaya888','bettymatt@iprimus.com.au','matthew cardinal','11 creekview way','wyndhamvale- west melbourne','Victoria','AUSTRALIA','3024','0397311841','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 05:20:37',0,NULL,3,1,2,1,NULL,'evxaya888\r方形滤镜接口环 77mm     1\r方镜普通托架（三槽）    1\r新款内胆包 大号 canon logo      1'),(13874,704611622018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','123-princess74','melmander@hotmail.com','Melanie Mander','5 Gardinia Place','Mullaloo','Western Australia','AUSTRALIA','6027','0893078309','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 06:32:08',0,NULL,3,1,3,1,'RA183617431CN ','123-princess74'),(13875,703951065001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','mitacheclaudiu','viduou@yahoo.com','Mitache Claudiu','Str.Nicolae Balcescu, Bl.1, Sc.2, Ap.17','Targu-Jiu','Romania','ROMANIA','210160','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 06:55:29',0,NULL,3,1,2,1,' ','mitacheclaudiu'),(13876,745565495002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dovbush01','alessiv@sbcglobal.net','Andrei Lesiv','347 Palomar Dr','Palomar Park','CA','UNITED STATES','94062','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 08:02:50',0,NULL,3,1,1,1,NULL,'dovbush01'),(13877,826387689015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','jesper.thomasen','mail@jesperthomasen.dk','Jesper Thomasen','Reberbansgade 1, 3,th','Aalborg','','DENMARK','9000','+4561715060','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-29 09:07:54',0,NULL,3,1,3,1,'RA183617428CN ','jesper.thomasen'),(13878,704652353018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','strawmonkies','lainyhead@gmail.com','Elaina Berry','1170 Oakey Flat Road','Narangba','Queensland','AUSTRALIA','4504','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 09:42:35',0,NULL,3,1,2,1,NULL,'strawmonkies'),(13879,745588804002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','grzes1965','gdutkiew@amu.edu.pl','Grzegorz Dutkiewicz','Matejki<br>3/14','Poznań','wielkopolskie','POLAND','60766','605 268697','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 09:54:56',0,NULL,3,1,2,1,NULL,'grzes1965'),(13880,704660868018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',10,'AC2403',300,'photographyacc','lianajustin-2008','lianajustin@virginbroadband.com.au','Liana Tarr','4 Opal Court','Caboolture','Queensland','AUSTRALIA','4510','0754951145','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 10:19:17',0,NULL,3,1,4,1,'YW866475330CN ','lianajustin-2008\rSoft Box     $25'),(13881,745594136002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',75.82,'hermeshine','xc6.tiger','yonex@ua.fm','ILYA GELFER','Plehanov street,16/44','DNEPROPETROVSK','','UKRAINE','49000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-29 10:20:29',0,NULL,3,1,5,1,'CP227167375CN ','xc6.tiger'),(13882,745598151002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','sesafin','huayhuash7@hotmail.com','SERAFIN SANCHEZ MARIN','urb.doña casilda blo.7 portal 1  6ºizq','algeciras','Andalucía Ceuta y Melilla','SPAIN','11204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 10:37:07',0,NULL,3,1,3,1,'RA183617520CN\r ','sesafin'),(13883,745603050002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','newpee1957','newpee@btinternet.com','John Newport','21 Kiln Ride','Wokingham','Berkshire','UNITED KINGDOM','RG40 3PN','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-29 10:58:19',0,NULL,3,0,3,1,'RA183617799CN\r ','newpee1957\rXL（已入库）\r\r'),(13884,745210496002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','xbpex','g.oldini@tiscali.it','giuseppe oldini','via roma 13','cervignano d\'adda','LO','ITALY','26832','3391017334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 11:02:47',0,NULL,3,1,2,1,NULL,'xbpex'),(13885,704674818018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','obmac_57','chilim57@tpg.com.au','CHI LIM','12 Margitich Street','Croydon Park,','South Australia','AUSTRALIA','5008','0883465434','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-29 11:12:45',0,NULL,3,1,3,1,'RA183617516CN\r ','obmac_57'),(13886,704010331001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','teva47','eric.fretillere@wanadoo.fr','Dr FRETILLERE Eric','CLINIQUE SAINT HILAIRE    2 Rue du Docteur et Madame DELMAS','AGEN','FRANCE','FRANCE','47000','033682294406','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 11:40:58',0,NULL,3,1,2,1,NULL,'teva47'),(13887,745613803002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','77613076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 11:41:57',0,NULL,3,1,2,1,NULL,'jfossb'),(13888,704683782018,280663394108,'1000W Pro Photo Studio Soft Box Continuous Light Kit',1,'AKT017',120,'photographyacc','iditnis','idit_nis@walla.com','Idit Nissenbaum','7 Sadot St.','Rishon Lezion','','ISRAEL','75679','0523777572','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-29 11:50:25',0,NULL,3,1,3,1,'RA183617839CN\r ','iditnis\r欧标\rRA183617825CN\rRA183617771CN\r'),(13889,704016429001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','mkhitar73','gel73@mail.ru','Mkhitar Hovhannisyan','Lernagorcner st. 16/30<br>Lernagorcner st. 15/14','Qajaran','Syunik','ARMENIA','3309','+37491223355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 12:01:07',0,NULL,3,0,5,1,'CP227167897CN ','mkhitar73'),(13890,809251017016,260817943832,'Wireless Remote Shutter Release for Canon 7D 50D 5Dii',1,'AD1120',12.47,'hutongstore','mayocoral','tenhine@hotmail.com','Julian Jimenez Cambronero','C/ La Costera nº 2 16b','Torrente','Comunidad Valenciana','SPAIN','46900','961555609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 12:28:55',0,NULL,3,1,17,0,NULL,'mayocoral'),(13891,809248627016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','mayocoral','tenhine@hotmail.com','Julian Jimenez Cambronero','C/ La Costera nº 2 16b','Torrente','Comunidad Valenciana','SPAIN','46900','961555609','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-07-29 12:28:56',0,NULL,3,1,17,0,NULL,'mayocoral'),(13892,826446976015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.5,'hutongstore','mayocoral','tenhine@hotmail.com','Julian Jimenez Cambronero','C/ La Costera nº 2 16b','Torrente','Comunidad Valenciana','SPAIN','46900','961555609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 12:28:56',0,NULL,3,1,17,0,NULL,'mayocoral'),(13893,826447013015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5.5,'hutongstore','mayocoral','tenhine@hotmail.com','Julian Jimenez Cambronero','C/ La Costera nº 2 16b','Torrente','Comunidad Valenciana','SPAIN','46900','961555609','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-29 12:28:57',0,NULL,3,1,4,1,'YW866475341CN ','mayocoral\ryongnuo无线 YN159-C3        1\r2mx1.5m 背景板（黑，白）       1\r柔光伞   85 cm         1\r闪光灯B座            1\rbackground  plate   $25'),(13894,744789889002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','batelkana','elkanasulin@hotmail.com','Elkana Asulin','Wadgewood Ave\'  38/2','Haifa','','ISRAEL','34636','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 13:08:12',0,NULL,3,1,2,1,NULL,'batelkana'),(13895,745637018002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','forrestaldk','christian@forrestal.dk','Christian Forrestal','YouGov Zapera<br>Ryesgade 3a, 1tv','Copenhagen N','','DENMARK','2200','+4526209092','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 13:12:25',0,NULL,3,1,3,1,'RA183617547CN\r ','forrestaldk'),(13896,704038491001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','chazhi47','chazhi47@yahoo.com','Dr. Joseph Stephen','505 Pratham Apartments','Manipal','KA','INDIA','576104','(966) 355-8330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 13:23:36',0,NULL,3,1,2,1,NULL,'chazhi47\r欧标'),(13897,805739582016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gr8stuff247','angelerediauwa@yahoo.com','angel iguehide erediauwa','FLAT 15, TRAFALGAR COURT<br>Marine Drive','Barking','Essex','UNITED KINGDOM','IG11 0GN','07572075677','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-07-29 14:40:17',0,NULL,3,1,4,1,'YW866475315CN ','gr8stuff247\r英标\rLighting Kit    $40   '),(13898,704748783018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',40,'photographyacc','vincentnini','philippe.bouque@skynet.be','BOUQUE Philippe','rue de Cartier 44','MARCHIENNE AU PONT','','BELGIUM','6030','071561327','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-29 15:17:03',0,NULL,3,0,3,1,'RA183617723CN\r ','vincentnini\rXXXL\r（已入库）'),(13899,704771055018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','kassiopeyaxxx','kassiopeya-m@mail.ru','Yuliya Astapenka','Chaiko st, 8-51','Polotsk','BR','BELARUS','211408','+375259739427','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-29 16:18:26',0,NULL,3,1,3,1,'RA183617652CN\r ','kassiopeyaxxx'),(13900,745699982002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','n0ch','abarlit@mail.ru','Alexander Barlit','Schaffhauserstrasse 198','Zurich','','SWITZERLAND','8057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 16:22:40',0,NULL,3,1,2,1,NULL,'n0ch'),(13901,745704400002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','barcode.guy','ebaysales@barcodeguy.net','Phong Vo','313 Granite Way','Newnan','GA','UNITED STATES','30265-6065','(678) 485-7514','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 16:35:29',0,NULL,3,1,17,0,NULL,'barcode.guy'),(13902,745706418002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','danathera2','theradana@hotmail.com','ofelia amores gonzalez','C/ Borea, Haza Bonilla nº1, la teinada<br>Rincón de la Victoria','Málaga','Andalucía Ceuta y Melilla','SPAIN','29730','637509916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 16:46:32',0,NULL,3,1,3,1,'RA183617462CN\r ','danathera2'),(13903,745709064002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','mipro83','prilepokm@gmail.com','Miroslav Prilepok','Prievozska 1','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','+421905616600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 16:49:10',0,NULL,3,1,3,1,'RA183617493CN\r ','mipro83'),(13904,745717160002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','farnirfan','niichiipaan.234@gmail.com','Muhd Adi Farhan','Barek 321 \'A\' Jalan Setia Negara','Kuala Belait','Kuala Belait','BRUNEI DARUSSALAM','KA1931','+6738902590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 17:11:50',0,NULL,3,1,2,1,NULL,'farnirfan'),(13905,826568982015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','nicklausgolfer','mark@thestansfieldfamily.com','Mark stansfield','Lancashire Bathrooms ltd<br>56-60 Eastbank Street','Southport','Merseyside','UNITED KINGDOM','Pr8 1es','07984042568','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-29 17:24:59',0,NULL,3,1,3,1,'RA183617555CN\r ','nicklausgolfer'),(13906,745728784002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','tom09-2009','seyryutom@hotmail.it','Tommaso Fucile','via matteotti 51/B','Arcisate','VA','ITALY','21051','3338471032','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-29 17:41:53',0,NULL,3,1,4,1,'YW866475326CN ','tom09-2009\r柔光箱 60-60cm  四灯头 欧标        2   \r申报： photo light $20'),(13907,759709771017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',3,'AA1301',7.5,'photographyacc','electro_stalin','mrproz@yandex.ru','Alexandr Legotin','Novoizmailovsky pr.16, 11 k., 91 room','Saint-Petersburg','','RUSSIAN FEDERATION','196128','+79118360699','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-29 18:05:01',0,NULL,3,1,2,1,NULL,'electro_stalin'),(13908,704137489001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','knevgen','knev@bk.ru','Evgeny Knyazev','30 let Pobedy 4V- 45','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426033','+7 9124446637','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 18:15:56',0,NULL,3,1,2,1,NULL,'knevgen'),(13909,704878356018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',145,'photographyacc','sabanah86_123','sabanah86@hotmail.com','Armando Huerta','calle Quetzal #1239 int-13<br>colonia Morelos','Guadalajara','Jalisco','MEXICO','44910','33312225','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-29 20:46:34',0,NULL,5,1,18,0,NULL,'sabanah86_123\r3m*6m  白的背景布   1\r背景架2m x 3m + 3个夹子      1'),(13910,745776483002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','cubcake76','cjbeltowski@hotmail.com','Chester J Beltowski','2102 S 38th St','Grand Forks','ND','UNITED STATES','58201-8830','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-29 21:03:53',0,NULL,3,1,1,1,NULL,'cubcake76'),(13911,704239937001,110533632347,'Super heavy clamp photography all metal capacity15kg',1,'AD1148',27.5,'hermeshine','gitanabudd','gjbudd@attglobal.net','Graham Budd','90 Trig Road<br>Whitford','Auckland','','NEW ZEALAND','2571','(09)5308891','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:13:25',0,NULL,3,1,3,1,'RA183617958CN\r ','gitanabudd'),(13912,704241867001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','juanmisgjuanmisg','juanmasgsg@gmail.com','juanma sanchez garcia','archidona 13 3ºc','san pedro de alcantara','Malaga','SPAIN','29670','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:24:20',0,NULL,3,1,2,1,NULL,'juanmisgjuanmisg'),(13913,704243057001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','a1rwav3','jonathan.porta@gmail.com','Jonathan Porta','chemin des Semailles 36','Grand-Lancy (GE)','','SWITZERLAND','1212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:27:33',0,NULL,3,1,2,1,' ','a1rwav3'),(13914,745848983002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','lluis_kas','lluis_kas@hotmail.com','Lluís Casals Pedragosa','C/ de la pau 86','Navàs','Cataluña','SPAIN','08670','680684056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-29 23:28:56',0,NULL,3,1,4,1,'YW866475352CN ','lluis_kas\rTripod     $28'),(13915,745868102002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','8333661044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 00:50:14',0,NULL,3,1,3,1,'RA183617860CN\r ','goinha2011\r新地址\rGLORIA MARIA MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r申报  gift     \r\r'),(13916,704261152001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','kemala99','kemalaydin99@hotmail.com','Kemal AYDIN','LOGO BUSINESS SOLUTIONS<br>GOSB TEKNOPARK NO:609 GEBZE','KOCAELİ','','TURKEY','41480','+902626798000','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-30 01:01:13',0,NULL,3,1,5,1,'CP227167384CN ','kemala99\r申报 gift'),(13917,745876888002,120539340436,'New 77mm ring adapter replacement for cokin P series',7,'AA2214',15.26,'hermeshine','weedlips','info@peninsulacamera.com.au','Anthony Burns','32-34<br>Ross Smith Ave','Frankston','Victoria','AUSTRALIA','3199','0397814677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 01:29:27',0,NULL,3,1,17,0,NULL,'weedlips'),(13918,704961094018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','thomasang88','thomasang88@gmail.com','Thomas Ang','22/22 Herbert St','West Ryde','New South Wales','AUSTRALIA','2114','61406510234','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 01:54:00',0,NULL,3,1,2,1,NULL,'thomasang88'),(13919,745882349002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','stremaus','ivan_stremaus@mail.ru','Ivan Stremaus','Volkhovstroya 88-110','Omsk','','RUSSIAN FEDERATION','644033','(908)119-9245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 01:56:26',0,NULL,3,1,2,1,NULL,'stremaus'),(13920,704964148018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','abraaojr','abraao.junior@yahoo.com.br','Abraão Gomes Soares Jr','R. Conselheiro Lafaiete, 1977<br>apto: 1202, Sagrada Família','Belo Horizonte','Minas Gerais','BRAZIL','31035-560','+55 31 3327-8275','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-30 02:02:05',0,NULL,3,1,3,1,'RA183617581CN\r ','abraaojr'),(13921,704268633001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',3,'AB3331',7.8,'hermeshine','weedlips','info@peninsulacamera.com.au','Anthony Burns','32-34<br>Ross Smith Ave','Frankston','Victoria','AUSTRALIA','3199','0397814677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 02:02:44',0,NULL,3,1,3,1,'RA183622737CN ','weedlips\r方形滤镜接口环 77mm       7\r肥皂盒 柔光罩  430EX      3'),(13922,826774600015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','georgieboy501','carroll2121@yahoo.co.uk','George Carroll','6 Glenfarg Street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G20 7QF','01413311238','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 02:04:17',0,NULL,3,1,2,1,NULL,'georgieboy501'),(13923,809576202016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','iambluebrowny','iambluebrowny@hotmail.com','Phil Brown','26 Myrtle Close','Sheffield','South Yorkshire','UNITED KINGDOM','s23hw','01132259543','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 02:51:15',0,NULL,3,1,2,1,NULL,'iambluebrowny'),(13924,704313211001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','barcode.guy','ebaysales@barcodeguy.net','Phong Vo','313 Granite Way','Newnan','GA','UNITED STATES','30265-6065','(678) 485-7514','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-30 05:49:23',0,NULL,3,1,17,0,NULL,'barcode.guy'),(13925,704308572001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','barcode.guy','ebaysales@barcodeguy.net','Phong Vo','313 Granite Way','Newnan','GA','UNITED STATES','30265-6065','(678) 485-7514','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-30 05:49:24',0,NULL,3,1,1,1,NULL,'barcode.guy\r方形滤镜接口环 72mm     1\r方镜普通托架（三槽）      1\r天涯方形滤镜系列  星光镜  star8         1\r方形滤镜接口环 52mm          1'),(13926,745942444002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sweetlorraine24','sweetlorraine24@hotmail.com','Lorraine Janice','119a Basinghall St<br>East Victoria Park','Perth','Western Australia','AUSTRALIA','6101','0894701472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 07:42:13',0,NULL,3,1,2,1,NULL,'sweetlorraine24'),(13927,745952039002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Tawfeek Al-Subaa','gnaral street<br>Tarout','Qatif','Tarout','SAUDI ARABIA','31911','966503381168','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-30 08:28:20',0,NULL,3,1,3,1,'RA183622017CN ','tawfeekmohammed\r河北背景架  + 1.6x2.1 白色\rRA183622025CN\r'),(13928,826873749015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','johnjh0','johndavila@talktalk.net','John D\'Avila','25 The Mall','Swindon','Wiltshire','UNITED KINGDOM','SN14JA','01793486552','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 09:12:27',0,NULL,3,1,2,1,NULL,'johnjh0'),(13929,809663213016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','focalpointa','arwalls@btinternet.com','Tony Walls','82 CARLETON ROAD','CHORLEY','Lancashire','UNITED KINGDOM','PR68UB','01257278505','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 09:22:27',0,NULL,3,1,2,1,NULL,'focalpointa'),(13930,705054685018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','ayyouy','ayahamdar@yahoo.com','aya hamdar','unit 2<br>3-5 atkinson street','liverpool','New South Wales','AUSTRALIA','2170','0415570557','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 09:49:53',0,NULL,3,1,17,0,NULL,'ayyouy'),(13931,759969240017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','ayyouy','ayahamdar@yahoo.com','aya hamdar','unit 2<br>3-5 atkinson street','liverpool','New South Wales','AUSTRALIA','2170','0415570557','NoPaymentFailure','CheckoutComplete','AU_Other','2011-07-30 09:51:57',0,NULL,3,1,3,1,'RA183622343CN ','ayyouy\r2b 柔        1\r爵影碗罩P4        1 '),(13932,759972565017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','vitabella68','vitatalmont@gmail.com','Vita Talmont','12 Ferris St','Ermington','New South Wales','AUSTRALIA','2115','0288108136','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-30 10:13:17',0,NULL,3,1,17,0,NULL,'vitabella68'),(13933,759972857017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',49.58,'photographyacc','vitabella68','vitatalmont@gmail.com','Vita Talmont','12 Ferris St','Ermington','New South Wales','AUSTRALIA','2115','0288108136','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 10:13:16',0,NULL,3,1,4,1,'YW866475363CN ','vitabella68\r灯架  2m      2\r柔光箱 50-70cm 单灯头  澳标       2\r115w 5500k 灯泡  220v          2\r灯架包             1\r眼罩 450D/500D        1\rRS--C1   有线快门线     1\r110的5和1            1\rcanon  新款内胆包大号    1\r(已入库）\rLighting  Kit       $30\r'),(13934,759981892017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','pmk2004','patrickmkenny@yahoo.com.au','Pat Kenny','2 Marril Road','Narara','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 10:41:10',0,NULL,3,1,2,1,NULL,'pmk2004'),(13935,826910419015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','flpicuser072009','flfonseca.pro@gmail.com','Fernando Fonseca','970 Cumbernauld Road','Riddrie','Glasgow (City of)','UNITED KINGDOM','G33 2QR','01417701651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 11:06:38',0,NULL,3,1,2,1,NULL,'flpicuser072009'),(13936,745991713002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','pantelis51','gmadarakis@gmail.com','MADARAKIS YORGOS / NIKOS','AIK. BARELA 6, NOMOS PELLAS','GIANNITSA','','GREECE','58100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 11:08:11',0,NULL,3,1,3,1,'RA183617737CN\r ','pantelis51'),(13937,826898765015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.79,'hutongstore','eric_clapp','mail@nicbaldwin.co.uk','Nic Baldwin','82 Millbrook Street','Gloucester','Gloucestershire','UNITED KINGDOM','GL1 4BW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 11:44:56',0,NULL,3,1,2,1,NULL,'eric_clapp'),(13938,760014079017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','hdetje','holger@detje.info','Holger Detje','480A Beach Road<br>Murrays Bay','North Shore City','Auckland','NEW ZEALAND','0630','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-30 12:31:02',0,NULL,3,1,3,1,'RA183617564CN\r ','hdetje\r澳标'),(13939,826967492015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','michaeljhealy','mjhealy@gmail.com','Michael Healy','41 Marlborough Way','Billericay','Essex','UNITED KINGDOM','CM12 0YJ','07506441710','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 13:44:10',0,NULL,3,1,2,1,NULL,'michaeljhealy'),(13940,760054160017,270758475500,'Photo Studio translucent white umbrella soft 85cm /33\" ',1,'AD1402',7.8,'photographyacc','gadisierra','gadisi@netvision.net.il','gadi sierra','halon 80','tel mond','','ISRAEL','40600','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-30 14:30:46',0,NULL,3,1,11,1,NULL,'gadisierra'),(13941,704458509001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.1,'hermeshine','techster007','louiswhite32@aol.com','louis white','4850 Natomas Blvd<br>Apt 1317','Sacramento','CA','UNITED STATES','95835-1293','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-30 15:52:47',0,NULL,3,1,1,1,NULL,'techster007'),(13942,704478361001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',5.49,'hermeshine','spanky11simon','atichargr@gmail.com','simon magrath','12605 Kavanaugh Ln','bowie','MD','UNITED STATES','20715-2816','(301) 809-3920','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-30 16:30:01',0,NULL,3,1,1,1,NULL,'spanky11simon'),(13943,760103755017,270750677827,'New Camera shoulder bag D1 for Nikon D5000 D7000 D80',1,'AO0032',19.99,'photographyacc','irfan_zaman','need2mail@gmail.com','Munshi Shamsuzzaman Irfan','Apartment 3106, 57-59 Queen Street,','Auburn, Sydney,','New South Wales','AUSTRALIA','2144','61426276622','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-30 16:39:05',0,NULL,3,1,3,1,'RA183617618CN\r ','irfan_zaman'),(13944,743188615002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','paul-i-wog','gotpaul@gmail.com','Paul Martin','165 1st Ave NW<br>Apt 302','Issaquah','WA','UNITED STATES','98027-3270','(425) 941-2935','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-30 17:08:22',0,NULL,3,1,1,1,NULL,'paul-i-wog'),(13945,704480158001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','qeeqaig','macdonnellma@msn.com','Mark MacDonnell','4132 Quitman St.','Denver','CO','UNITED STATES','80212','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-30 17:21:40',0,NULL,3,1,3,1,'RA183617604CN\r ','qeeqaig\r'),(13946,746125829002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','joaquim19580','lavradoutor@clix.pt','joaquim lavrador','COLÉGIO DE CALVÃO, RUA PADRE BATISTA,Nº100','CALVÃO','VAGOS','PORTUGAL','3840-053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 17:55:32',0,NULL,3,1,2,1,NULL,'joaquim19580'),(13947,746124704002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-30 18:16:49',0,NULL,3,1,3,1,'RA183617480CN\r ','leofotografias'),(13948,746180981002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','peamlap','te_peamlap@hotmail.com','Peamlap Jareonrattanawat','1/156 Happyland Grandville, Ladprao 101,<br>Klongjun, Bangkapi','Bangkok','','THAILAND','10240','+66804405575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 20:17:02',0,NULL,3,1,17,0,NULL,'peamlap'),(13949,746181933002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','peamlap','te_peamlap@hotmail.com','Peamlap Jareonrattanawat','1/156 Happyland Grandville, Ladprao 101,<br>Klongjun, Bangkapi','Bangkok','','THAILAND','10240','+66804405575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-30 20:17:02',0,NULL,3,1,3,1,'RA183617706CN\r ','peamlap\rHB-7 花瓣      1\rlenspen      1'),(13950,760221549017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','adriano_haze','adriano@specchi.net','Adriano Susca','Corso Repubblica 24','TULA','SS','ITALY','07010','3477044367','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-30 21:14:21',0,NULL,3,1,2,1,NULL,'adriano_haze'),(13951,827195338015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','jez1300','gamma@ntlworld.com','Jeremy Davies','30 Bolingbroke rd<br>Moredon','Swindon','Wiltshire','UNITED KINGDOM','SN2 2JZ','01793338875','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-30 21:50:10',0,NULL,3,1,2,1,NULL,'jez1300'),(13952,746230844002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','piovab','m.lapkovskis@gmail.com','Michal Lapkovskis','Vasaros 17-29','Nemenčinė','Vilniaus rajonas','LITHUANIA','15176','37060060499','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-30 22:55:13',0,NULL,3,1,5,1,'CP227167398CN ','piovab\r欧标\rLighting Kit    $28'),(13953,827219185015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','ge6ka','e.bay@inbox.lv','Daina Gensirovska','Maskavas 268/2-39','Riga','','LATVIA','LV-1063','00371','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-30 22:57:06',0,NULL,3,1,2,1,NULL,'ge6ka'),(13954,742500530002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','neshenie2010','neshenie@hotmail.com','VANESA TORRES','COOP EL ALCAZAR APT 4-I','SAN JUAN','puerto rico','PUERTO RICO','00923','787-7587652','NoPaymentFailure','CheckoutComplete','Other','2011-07-30 23:20:15',0,NULL,3,1,3,1,'RA183617649CN\r','neshenie2010'),(13955,746251374002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','altego999','rlashley@pacbell.net','Robert Lashley','5931 Amapola Dr','San Jose','CA','UNITED STATES','95129-3058','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 00:03:45',0,NULL,3,1,3,1,'RA183617476CN\r ','altego999'),(13956,760272469017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',2,'AA1206',5.8,'photographyacc','kpethsierra','kim@coastalbrokers.com.au','Kim Petherbridge','PO Box 43','Geebung','Queensland','AUSTRALIA','4034','0738654291','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 00:10:02',0,NULL,3,1,2,1,NULL,'kpethsierra'),(13957,704614078001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 01:16:52',0,NULL,3,1,3,1,'RA183622754CN\r ','saud-p\rRA183617873CN\r'),(13958,760289611017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','verity.sanders','i_dunno___@hotmail.com','Verity Sanders','55 Tuggerawong Road','Wyongah','New South Wales','AUSTRALIA','2259','6143924720','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 01:27:43',0,NULL,3,1,2,1,NULL,'verity.sanders'),(13959,746276205002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','megatlon','rsaslavsky@hotmail.com','Gustavo Badino','1350 S Dixie Hwy<br>Lan Argentina # US1','Coral Gables','FL','UNITED STATES','33146-2904','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-07-31 02:00:17',0,NULL,3,1,1,1,NULL,'megatlon'),(13960,705384175018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','khankara','nabihaharabians@aapt.net.au','krystal lewis','po box 44<br>koo wee rup','melbourne','victoria','AUSTRALIA','3981','0359983828','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-31 03:17:04',0,NULL,3,1,4,1,'YW866475293CN ','khankara\r背景布是1.6*2.1蓝色的    \rBackground Support    $25'),(13961,705392198018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 04:00:16',0,NULL,3,1,3,1,'RA183617754CN\r ','colinds888'),(13962,704693779001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','verasitmanava','boyanon83@hotmail.com','verasit manava','43/49 Youngthongthani village[MOO 6] Bangpood','Pak Kret','Nonthaburi','THAILAND','11120','+66849025723','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 05:28:48',0,NULL,3,1,2,1,NULL,'verasitmanava'),(13963,705407822018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',2.5,'photographyacc','csmithy08','clive-in-oz@hotmail.com','Clive Smith','2/161 Blues Point Road<br>McMahons Point','Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 05:38:24',0,NULL,3,1,2,1,NULL,'csmithy08'),(13964,705410112018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','chr!s64','grotto@dodo.com.au','Chr!s Hurst','C/-   Australia  Post<br>21  Wishart   St','Gwelup','Western Australia','AUSTRALIA','6018','0412366832','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 05:53:34',0,NULL,3,1,3,1,'RA183617635CN\r ','chr!s64'),(13965,760359052017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',52,'photographyacc','rew276','rohanew@gmail.com','Rohan Edmonds-Wilson','3/20-22 Wingate Ave','Mt Waverley','Victoria','AUSTRALIA','3149','61417862580','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 07:26:28',0,NULL,3,1,3,1,'RA183617697CN\r ','rew276'),(13966,704715652001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','oshiba22','garganshul2001@yahoo.com','Anshul Garg','76 Vassar Aisle','Irvine','CA','UNITED STATES','92612-4142','(949) 567-7041','NoPaymentFailure','CheckoutComplete','Other','2011-07-31 07:31:31',0,NULL,3,1,1,1,NULL,'oshiba22'),(13967,810158428016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','london_bike_groover','chris.lemay@laing.com','Chris Le May','John Laing<br>Allingon House','150 Victoria Street','London','UNITED KINGDOM','SW1E 5LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 09:47:50',0,NULL,3,1,2,1,NULL,'london_bike_groover'),(13968,827391835015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','deva_caesar','mark.pilling@lineone.net','Mark A Pilling','5 Toft Close','Chester','Cheshire','UNITED KINGDOM','CH4 8PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 09:48:05',0,NULL,3,1,2,1,NULL,'deva_caesar'),(13969,743971228002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',47.9,'hermeshine','downtown132','downtown132@yahoo.com.au','scott brown','23 Wollybutt Road','Engadine','New South Wales','AUSTRALIA','2233','0418206185','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 10:01:43',0,NULL,3,1,3,1,'RA183617533CN\r ','downtown132\r柔光伞换成110cm的 （已减库）'),(13970,704769969001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','zecapalma','marcos@cannalz.com.br','Marcos Palma','Av. Lucio Costa 9550/113<br>Barra da Tijuca','Rio de Janeiro','RJ','BRAZIL','22795006','55 21 2431 3050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 10:30:13',0,NULL,3,1,3,1,'RA183617595CN\r ','zecapalma'),(13971,760416424017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','jataylor_aust','jataylor@ozemail.com.au','James Taylor','2 Doncaster Road','Balwyn North','Victoria','AUSTRALIA','3104','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-07-31 10:36:10',0,NULL,3,1,2,1,NULL,'jataylor_aust'),(13972,746396797002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','zaraxxxtustra','benefist5@yahoo.com','Ayhan  I. Mehmedov','ul. Baba Tonka 11 vh. A ap.12','Silistra','','BULGARIA','7500','0879056558','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 10:54:00',0,NULL,3,1,3,1,'RA183617808CN\r ','zaraxxxtustra\rxl'),(13973,827465557015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','paul-3585','paul.nicho@virgin.net','paul nicholls','16 grove street','newark','Nottinghamshire','UNITED KINGDOM','ng243az','01636683585','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 12:27:24',0,NULL,3,1,2,1,NULL,'paul-3585'),(13974,810244278016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','asefmohammad','pygham@hotmail.com','Asef Mohammad','219/A, WOODHOUSE ROAD<br>LONDON','London','London','UNITED KINGDOM','N12 9BD','07917466935','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-07-31 13:02:58',0,NULL,3,1,2,1,NULL,'asefmohammad'),(13975,704818650001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:11',0,NULL,3,1,17,0,NULL,'texwiller348'),(13976,746439169002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:12',0,NULL,3,1,17,0,NULL,'texwiller348'),(13977,704822538001,110426247717,'Gray card for White balance exposure flash meter 18%(L)',1,'AA2218',12.68,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:13',0,NULL,3,1,17,0,NULL,'texwiller348'),(13978,746443392002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:13',0,NULL,3,1,17,0,NULL,'texwiller348'),(13979,746442963002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:14',0,NULL,3,1,17,0,NULL,'texwiller348'),(13980,704819063001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',2,'AC1201',9.8,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:14',0,NULL,3,1,17,0,NULL,'texwiller348'),(13981,704824804001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:15',0,NULL,3,1,17,0,NULL,'texwiller348'),(13982,704824253001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:16',0,NULL,3,1,17,0,NULL,'texwiller348'),(13983,746439791002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','texwiller348','carlo.milesi@gmail.com','Carlo Pietro Milesi','Via Sauli 12/22','Sori','GE','ITALY','16031','348 7443190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:07:15',0,NULL,3,1,3,1,'RA183617927CN ','texwiller348\r镜头筒 中号        1\r中号内胆包 canon      1\r大号灰卡    1\r3片装的滤镜袋     1\r带水平仪 热靴保护盖     1\r镜头筒 小号    2\r麂皮    2\r品胜3.0‘      1\rlenspen    1\r气吹  + 布    1\rphoto accessories $20\r\r\r\r'),(13984,705553751018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','ellexirisxblue','elle.fg.irvine@gmail.com','Elle Irvine','Unit 416, 9-19 Castlebar St','Kangaroo point','Queensland','AUSTRALIA','4169','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-31 13:26:52',0,NULL,3,1,4,1,'YW866475433CN ','ellexirisxblue\rbackground support $25'),(13985,704835520001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',90,'hermeshine','electronicsandmotors','bas1crodeo@gmail.com','Mark Smyth','17 Harmer Road','Hallam','Victoria','AUSTRALIA','3803','','NoPaymentFailure','CheckoutComplete','AU_Express','2011-07-31 13:37:01',0,NULL,3,1,4,1,'YW866475304CN ','electronicsandmotors\r澳标\rlighting kit  $25'),(13986,704843167001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','asgaarding','aseroso@gmail.com','David Luis Garcia','Alcarria 76 - 5ºA','Leganes','Madrid','SPAIN','28915','686744468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:53:05',0,NULL,3,1,17,0,NULL,'asgaarding'),(13987,746463327002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','asgaarding','aseroso@gmail.com','David Luis Garcia','Alcarria 76 - 5ºA','Leganes','Madrid','SPAIN','28915','686744468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:53:06',0,NULL,3,1,17,0,NULL,'asgaarding'),(13988,746462373002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','asgaarding','aseroso@gmail.com','David Luis Garcia','Alcarria 76 - 5ºA','Leganes','Madrid','SPAIN','28915','686744468','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 13:53:07',0,NULL,3,1,17,0,NULL,'asgaarding'),(13989,746462986002,120581410942,'16chan Wireless Remote Control Cord for Nikon D90 D5000',1,'AA3202',18.5,'hermeshine','asgaarding','aseroso@gmail.com','David Luis Garcia','Alcarria 76 - 5ºA','Leganes','Madrid','SPAIN','28915','686744468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:53:06',0,NULL,3,1,4,1,'YW866475271CN ','asgaarding\r热靴保护盖  普通    1\rlenspen      1\r爵影无线N3      1\r三脚架  伟峰 WF-6662A     1\rTripod    $25\r\r\r'),(13990,704843949001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','lucianamuniz2010','cianemuniz2010@hotmail.com','LUCIANA MUNIZ DE LIMA','Rua José Tomé de Souza, 173 a<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 33661044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 13:54:17',0,NULL,3,1,17,0,NULL,'lucianamuniz2010\r\r'),(13991,704840380001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','lucianamuniz2010','cianemuniz2010@hotmail.com','LUCIANA MUNIZ DE LIMA','Rua José Tomé de Souza, 173 a<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 33661044','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 13:54:18',0,NULL,3,1,3,1,'RA183617895CN\r ','lucianamuniz2010\r单灯头    1   欧标\r肩架       1\r新地址\rLUCIANA MUNIZ DE LIMA\rRua Jos� Tom� de Souza, 173 a\rcentro\rLagoa Seca  - PARA�BA\r58117-000\rBrazil\rTELEFONE  83  3366-1044\r\r '),(13992,704846453001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83  9999-9296','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 14:00:47',0,NULL,3,1,3,1,'RA183617811CN\r ','paulolagoaseca2010\r新地址：\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(13993,704820819001,110513729693,'Remote Control Wireless Shutter Release Canon 40D 5DII ',1,'AA3228',32,'hermeshine','gr8mci9','rtantonio@comcast.net','Ray Antonio','215 Union Mill Rd','Mount Laurel','NJ','UNITED STATES','08054','(856) 304-0432','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-07-31 14:23:08',0,NULL,3,1,1,1,NULL,'gr8mci9'),(13994,704859343001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','wyemeng','wyemeng@hotmail.com','Jason Ho','30 Tingkat Bukit Kecil Dua<br>Taman Sri Nibong','Bayan Lepas','Penang','MALAYSIA','11900','0125365267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 14:47:01',0,NULL,3,1,2,1,NULL,'wyemeng'),(14001,746601047002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','gabeghost','gabrieltvs@gmail.com','Gabriel Tavares Vianna Stella','Rua Sebastião Laurentino da Silva, 126<br>Apto. 902','Florianópolis','SC','BRAZIL','88037-400','(+55)48 96271706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 17:58:25',0,NULL,3,1,2,1,NULL,'gabeghost'),(13998,705606372018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','ridux76','bhormo@hotmail.com','Bjørn-Henrik Ormo','Rosslyngveien 16B','Bronnoysund','','NORWAY','8900','+4795703065','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-31 15:20:51',0,NULL,3,1,3,1,'RA183617900CN\r ','ridux76\rSoft Box   $15'),(13999,704881607001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','ewokie','ewokie@gmail.com','Jordan Oppy','10/181 Edinburgh Street','Coffs Harbour','New South Wales','AUSTRALIA','2450','0266511179','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-31 15:22:05',0,NULL,3,1,2,1,NULL,'ewokie'),(14000,810383493016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','kylle1988','gaffi_88@hotmail.com','Katja Dehn','Tustrupvej 2a, 1tv','Vanløse','standard','DENMARK','2720','28302534','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-07-31 16:58:35',0,NULL,3,1,2,1,NULL,'kylle1988'),(14005,705005889001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','l8000_nl','johare62@hotmail.com','LOEYD JOHARE','Pijperring 306','Delft','ZH','NETHERLANDS','2625EW','031-15-2563412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 18:31:24',0,NULL,3,1,3,1,'RA183617887CN\r ','l8000_nl'),(14007,746665446002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','samba_cicloaventura','sambero@gmail.com','Felipe Salazar','El Alba 2 - Condominio Chicureo I, Casa 10','Santiago de Chile','Chicureo/Colina/Metropolitana','CHILE','sin numero','09 8378107','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 19:23:45',0,NULL,3,1,3,1,'RA183617666CN\r ','samba_cicloaventura\r（已入库）'),(14008,705803877018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',40,'photographyacc','toukoboe','tuomoh@saunalahti.fi','Tuomo Heiniö','Lintukallionrinne 3 C 41','Vantaa','','FINLAND','01620','358-40-524-3681','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-31 20:07:59',0,NULL,3,1,3,1,'RA183617745CN\r ','toukoboe\r(已入库）'),(14009,760756093017,270743754927,'Pro Photo Studio Soft Box Continuous Light Kit 4 output',1,'AKT039',165,'photographyacc','papucibg','k_rasta@abv.bg','Radoslav Georgiev','Mladost 1 bl.1 fl.11 ap.65<br>Mladost 1 bl.1 fl.11 ap.65','Sofia','Sofia','BULGARIA','1784','546565464','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-07-31 20:22:30',0,NULL,3,1,5,1,'CP227167407CN ','papucibg\r欧标\r'),(14010,705078338001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',2,'AO0005',42,'hermeshine','4731roy','mareebacleaning@gmail.com','peter roy','29 iluka st','mareeba','Queensland','AUSTRALIA','4880','0417746140','NoPaymentFailure','CheckoutComplete','NotSelected','2011-07-31 20:25:07',0,NULL,3,0,3,1,'RA183617975CN\r ','4731roy\r1.6*3  白色背景布     1\r1.6*3  黑色背景布       1'),(14011,760785225017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',65,'photographyacc','prw2010','paulroger2010@gmail.com','PAUL WINN','21 ALFRED ST<br>NEWCSTLE EAST','NEWCASTLE','New South Wales','AUSTRALIA','2300','0409993438','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-31 21:16:01',0,NULL,3,1,4,1,'YW866475282CN ','prw2010\rTripod   $25'),(14012,705106058001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','canadahockeyplace','chadwick@contax.ca','Chadwick Chan','#425 5880 Dover Crescent<br>(Buzzer #1176)','Richmond','BC','CANADA','V7C5P5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-07-31 21:21:10',0,NULL,3,1,3,1,'RA183617710CN\r ','canadahockeyplace'),(14013,705847012018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','magilla98','craigafp@bigpond.net.au','Craig Roberts','6 Stewart Crescent','Melba','Australian Capital Territory','AUSTRALIA','2615','0262593390','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-07-31 21:31:54',0,NULL,3,1,4,1,'YW866475385CN ','magilla98\rBackground Support $25'),(14014,705855082018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','rabianchini2007','richbianchini1@gmail.com','Richard Bianchini','933 San Remo','Irvine','CA','UNITED STATES','92606-8214','(949) 751-8090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-07-31 21:51:49',0,NULL,3,1,1,1,NULL,'rabianchini2007'),(14015,705139596001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','stapfacker','hansreichenbach@bluewin.ch','Hans Reichenbach','Rue des Vollandes 7','Genève','','SWITZERLAND','1207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-07-31 22:59:19',0,NULL,3,1,5,1,'CP227167910CN ','stapfacker'),(14016,705910928018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','greels','mgreels@yahoo.com','MATTHEW GREELEY','320 16th St NE','MENOMONIE','WI','UNITED STATES','54751-2062','(715) 233-3059','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-01 00:51:33',0,NULL,3,1,3,1,'RA183617578CN\r ','greels'),(14017,746808291002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','a.marrero45','amarrero63@libertypr.net','Alexander Marrero','P.O. Box 366395','San Juan','PR','UNITED STATES','00936-6395','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 00:55:11',0,NULL,3,1,3,1,'RA183617856CN\r ','a.marrero45'),(14018,705182514001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','dnewman24v4','dnewman@avc.edu','David A.Newman','3228 Voyager St','Rosamond','CA','UNITED STATES','93560-6207','(661) 256-6359','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 01:26:36',0,NULL,3,1,1,1,NULL,'dnewman24v4'),(14019,705202531001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','thespokebroke','thespokebroke@hotmail.com','danny stepanek','5428 NE 21 Terr','fort lauderdale','FL','UNITED STATES','33308','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-01 02:31:10',0,NULL,3,1,1,1,NULL,'thespokebroke'),(14020,760902453017,270750677827,'New Camera shoulder bag D1 for Nikon D5000 D7000 D80',1,'AO0032',19.99,'photographyacc','ruht03','ruht6@optusnet.com.au','Richard Thai','10 Northcote Street','Auburn','New South Wales','AUSTRALIA','2144','0404980323','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 03:07:58',0,NULL,3,1,3,1,'RA183617683CN\r ','ruht03'),(14021,705977939018,280675886404,'18% Gray Cards 10x8\"& 8x6\" for White balance exposure L',1,'AA2218',13.9,'photographyacc','sdcbmac','sdcb@iinet.net.au','Sean McKibbin','217 Argyle St','Moss Vale','New South Wales','AUSTRALIA','2577','0422000044','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 05:23:38',0,NULL,3,1,2,1,NULL,'sdcbmac'),(14022,705241290001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','berniedehonor2010','berniedehonor@yahoo.com','bernardo gonzales jr','golden neon llc. p.o. box 31072 al qouz 2, dubai<br>united arab emirates','dubai','','UNITED ARAB EMIRATES','n/a','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 05:56:15',0,NULL,3,1,17,0,NULL,'berniedehonor2010'),(14023,746879662002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','berniedehonor2010','berniedehonor@yahoo.com','bernardo gonzales jr','golden neon llc. p.o. box 31072 al qouz 2, dubai<br>united arab emirates','dubai','','UNITED ARAB EMIRATES','n/a','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 05:56:16',0,NULL,3,1,17,0,NULL,'berniedehonor2010'),(14024,704757253001,110658438313,'Remote Shutter Release Cord for Canon 40D 50D 5DII RE-A',1,'AA2219',17.66,'hermeshine','berniedehonor2010','berniedehonor@yahoo.com','bernardo gonzales jr','golden neon llc. p.o. box 31072 al qouz 2, dubai<br>united arab emirates','dubai','','UNITED ARAB EMIRATES','n/a','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 05:56:17',0,NULL,3,1,3,1,'RA183617944CN ','berniedehonor2010\r中号内胆包 无字     1\rcanon 三角包  D3     1\r优永佳快门线 A C3    1\rcanon  机身后盖    1\rEW-73B         1\r（已入库）'),(14025,705990368018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','waterholes','alessandracirri@hotmail.com','alessandra cirri','2/3 langford crt','moranbah','Queensland','AUSTRALIA','4744','0458545822','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-01 06:35:48',0,NULL,3,1,2,1,NULL,'waterholes'),(14026,706001390018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','kalle$$$','lojikboy@gmail.com','Kalle Retsas','2/79 Hardy Road<br>Ashfield','Perth','Western Australia','AUSTRALIA','6054','0439377887','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 07:39:53',0,NULL,3,1,2,1,NULL,'kalle$$$'),(14027,706007083018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','bmcollis','bcollis@bigpond.net.au','Brad Collis','43 O\'Connell Street','North Melbourne','Victoria','AUSTRALIA','3051','0396701168','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 08:04:18',0,NULL,3,1,3,1,'RA183617935CN\r ','bmcollis'),(14028,706007615018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',225,'photographyacc','2006shareena','shareena.waru@hotmail.com','Shareena Waru','11 Monfarville Street','St Marys','New South Wales','AUSTRALIA','2760','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'2006shareena\rlighting kit $40'),(14029,706008139018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',245,'photographyacc','chapman.tj','chapman.tj@gmail.com','Tom Chapman','91 Blyth St<br>Brunswick','Melbourne','Victoria','AUSTRALIA','3056','0410758207','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-01 08:07:58',0,NULL,3,1,4,1,'YW866475374CN ','chapman.tj\rtripod $30'),(14030,828056917015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','fiscaldeira','fsc2k5@gmail.com','Krijn van der Kaay','Rua das Condominhas 696 - 1 - hab3','Lordelo do Ouro','','PORTUGAL','4150-221','916504630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 08:50:36',0,NULL,3,1,2,1,NULL,'fiscaldeira'),(14031,746913787002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','normin65','bir-th@online.no','Birger Thomassen','Plommeveien 3B','Kristiansand','','NORWAY','4635','+4792087030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 08:53:07',0,NULL,5,1,18,0,NULL,'normin65'),(14032,705283109001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','deisanti2011','deisanti@optusnet.com.au','Neville Bull','24 Dalmor Ave.,','Ormond','Victoria','AUSTRALIA','3204','0395780471','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-01 09:36:11',0,NULL,3,1,4,1,'YW866475503CN ','deisanti2011\r Reflector  Holder    $  22'),(14033,828087857015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',5.5,'hutongstore','jskorupa80','jakub.skorupa@yahoo.pl','Jakub Skorupa','Flat A, Chiswick Court, 1A, Silver Crescent','LONDON','LONDON','UNITED KINGDOM','W4 5SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 10:30:43',0,NULL,3,1,2,1,NULL,'jskorupa80'),(14034,706043038018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',40,'photographyacc','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 10:37:12',0,NULL,3,0,3,1,'RA183622034CN\r ','colinds888\rXXXL   （已入库）'),(14035,746939844002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','allioli','deeplobe@hotmail.com','Adrián Navarro Grossón','C/ Maximiliano Thous Nº15, Pª4','Valencia','Comunidad Valenciana','SPAIN','46009','635694355','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 10:40:40',0,NULL,3,1,3,1,'RA183622184CN','allioli\r'),(14036,706045517018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','pirotta1990','mf.pirotta@gmail.com','Matthew Pirotta','22 Melaleuca drive','Melbourne','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 10:46:37',0,NULL,3,1,2,1,NULL,'pirotta1990\r1.6*2.1 白的背景布      1'),(14037,706048197018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','andrewkidd63','andrewkidd0666@dodo.com.au','Andrew Charles Kidd','Box 663','Stanthorpe','Queensland','AUSTRALIA','4380','0746848030','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 10:58:42',0,NULL,3,1,3,1,'RA183622105CN\r ','andrewkidd63\r除了c 里的再加上49的环和82的环 \r广角托架   \r已入库'),(14038,746947467002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','zaraxxxtustra','benefist5@yahoo.com','Ayhan  I. Mehmedov','ul. Baba Tonka 11 vh. A ap.12','Silistra','','BULGARIA','7500','0879056558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 11:10:19',0,NULL,3,0,17,0,NULL,'zaraxxxtustra'),(14039,746948304002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','zaraxxxtustra','benefist5@yahoo.com','Ayhan  I. Mehmedov','ul. Baba Tonka 11 vh. A ap.12','Silistra','','BULGARIA','7500','0879056558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 11:15:05',0,NULL,3,1,3,1,'RA183622096CN\r ','zaraxxxtustra\r1.6*3  白的背景布        1\r爵影红外 canon      1'),(14040,706060243018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','clintgando2010','clintgando@optusnet.com.au','clint ganderton','12 peppercorn place<br>kirrawee','sydney','New South Wales','AUSTRALIA','2232','0295217588','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-01 11:37:44',0,NULL,3,1,4,1,'YW866475481CN ','clintgando2010\rBackground Support   $25\r燕文告知货在当地邮局  无人领取 \r需邮件告诉客户\r▲  已发信'),(14041,828115545015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','oslpag','philgartell@me.com','Philip Gartell','Fageruddsgrand 11','Tyreso','','SWEDEN','13561','0700384337','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 11:53:56',0,NULL,3,1,3,1,'RA183617913CN\r ','oslpag'),(14042,828122108015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','woolshed0','jakki@zeriba.co.uk','Mrs J Ayres','2 Hill View<br>Lew','Nr Bampton','Oxon','UNITED KINGDOM','OX18 2BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 12:11:48',0,NULL,3,1,17,0,NULL,'woolshed0'),(14043,810867868016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','woolshed0','jakki@zeriba.co.uk','Mrs J Ayres','2 Hill View<br>Lew','Nr Bampton','Oxon','UNITED KINGDOM','OX18 2BA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 12:11:49',0,NULL,3,1,3,1,'RA183617992CN\r ','woolshed0\r圆形柔光棚 40cm    1\r反光板 100*150 40*60 5合1       1'),(14044,706082668018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','alan.nan.wu','rac131111@yahoo.com.au','Alan Wu','Level 1, 502 Hay Street','Subiaco','Western Australia','AUSTRALIA','6008','0433136183','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-01 12:55:54',0,NULL,3,1,2,1,NULL,'alan.nan.wu'),(14045,828152340015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.96,'hutongstore','kiltedwilly','twr@riddellthoms.co.uk','THOMAS RIDDELL','Riddell Thoms & Company<br>46 Gordon Street','GLASGOW','GLASGOW','UNITED KINGDOM','G1 3PU','01412262284','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 13:36:44',0,NULL,3,1,2,1,NULL,'kiltedwilly'),(14046,828153341015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',1.87,'hutongstore','blubludd','blu_bludd@yahoo.co.uk','Stefan Busby','207 The Queensway','Hull','Humberside','UNITED KINGDOM','HU69BJ','01482802233','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 13:39:18',0,NULL,3,1,2,1,NULL,'blubludd'),(14047,828169360015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','adyjay1','adrian.jones01@btinternet.com','Adrian Jones','77 Whalleys Way<br>Acrefair','Wrexham','Wrexham','UNITED KINGDOM','LL14 3UL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 14:22:19',0,NULL,5,1,3,1,'RA183617989CN\r ','adyjay1\r英标\r已发货  点不了'),(14048,747022037002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','2011simcro','simon.croisetiere@gmail.com','Simon Croisetiere','2000, av McGill Collège #800','Montréal','QC','CANADA','h3a3h3','(514) 526-1518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 15:24:35',0,NULL,3,1,2,1,NULL,'2011simcro'),(14049,761084163017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',17.97,'photographyacc','autumn-tree','ozdenakkulah@gmail.com','ozden akkulah','13 rocklands rise<br>meadow heights','melbourne','victoria','AUSTRALIA','3048','0393086529','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 15:47:00',0,NULL,3,1,2,1,NULL,'autumn-tree\rcanon  中号内胆包      1\rlenspen        1\r气吹 + 布            1\r（已入库）'),(14050,761096637017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','amperel2011','amperel1@017.net.il','Amperel ltd. (EB)','Shderot Jerusalem 168 Street','Holon','Israel','ISRAEL','58829','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-01 15:47:07',0,NULL,3,1,2,1,NULL,'amperel2011'),(14051,705309027001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','xaviturbo10','xavigtturbo@gmail.com','xavier romaguera luengo','jacint verdaguer nº9 2º2ª','premia de mar','Cataluña','SPAIN','08330','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 15:53:14',0,NULL,3,0,3,1,'RA183622051CN\r ','xaviturbo10\r3xl    (已入库）'),(14052,705389915001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','muzikantus','ileaveyou@gmail.com','Liviu Ailincai','Stefan cel mare nr. 14<br>bl. 19 sc.A et.2 ap. 4 sect. 2','Bucharest','bucharest','ROMANIA','020141','0040763669179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:00:23',0,NULL,3,1,17,0,NULL,'muzikantus'),(14053,747036257002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','muzikantus','ileaveyou@gmail.com','Liviu Ailincai','Stefan cel mare nr. 14<br>bl. 19 sc.A et.2 ap. 4 sect. 2','Bucharest','bucharest','ROMANIA','020141','0040763669179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-01 16:03:13',0,NULL,3,0,2,1,NULL,'muzikantus\r方形滤镜接口环 82mm     1\r方镜广角托架（ 一槽）      1'),(14054,705424900001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','tradergeorge','george@tradergeorge.com','George Hilbert','2232 Joyce Ave','Newport','KY','UNITED STATES','41071','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-01 17:32:04',0,NULL,3,1,1,1,NULL,'tradergeorge'),(14055,705430963001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','marekpargy','marekmolnar76@gmail.com','Marek Molnár','Družstevná 1','Halič','','SLOVAK REPUBLIC','98511','0907658360','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 17:46:33',0,NULL,3,1,3,1,'RA183618009CN ','marekpargy'),(14056,705458584001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','eugenepowers','gene007@powersandpowers.com','Eugene Powers','5764 Chicopee Ave','Encino','CA','UNITED STATES','91316-1305','','NoPaymentFailure','CheckoutComplete','Other','2011-08-01 18:56:53',0,NULL,3,0,1,1,NULL,'eugenepowers\r3xl   (已入库）'),(14057,811062134016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','malcolmparsons','malcolm.parson@tab.ac.uk','malcolm parsons','285 stamford road','dagenham','Essex','UNITED KINGDOM','rm94ed','02085920757','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 19:27:33',0,NULL,3,1,4,1,'YW866475470CN ','malcolmparsons\rbackground  plate  $20'),(14058,811081063016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',54,'hutongstore','jetxl2000','wlemein@gmail.com','Wouter Lemein','Kastanjehof 22','WINSCHOTEN','','NETHERLANDS','9674CM','0000000000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 19:58:56',0,NULL,3,1,4,1,'YW866475466CN ','jetxl2000\r欧标  Lighting Kit   $25'),(14059,761220101017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','veikon2011','vekemail@gmail.com','veikko stöckel','Tiilitie 11 B 43','Oulu','Oulu','FINLAND','90650','+358 44 916 8888','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-01 20:07:44',0,NULL,3,1,2,1,NULL,'veikon2011'),(14060,811093701016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','crabtree944','aholliday@btopenworld.com','Anthony Holliday','4 Jasper Avenue<br>Greenside','Ryton','Tyne and Wear','UNITED KINGDOM','NE404RS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-01 20:20:37',0,NULL,3,1,2,1,NULL,'crabtree944'),(14061,705512798001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',75.98,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83  9999-9296','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 20:51:24',0,NULL,3,1,5,1,'CP227167849CN ','paulolagoaseca2010\r新地址\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(14062,705519706001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',75.98,'hermeshine','marisete10','marisetemuniz2010@hotmail.com','marisete muniz de lima','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','Paraíba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 21:02:15',0,NULL,3,1,5,1,'CP227167835CN ','marisete10\r新地址\rMARISETE MUNIZ DE LIMA\rRua Jo�o Francisco de Oliveira, 233\rcentro\rLagoa Seca  - Para�ba\r58117-000\rBrazil\rtelephone 83 3366-1044\r\r'),(14063,705521349001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',75.98,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','8333661044','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 21:06:23',0,NULL,3,1,5,1,'CP227167883CN ','goinha2011\r新地址\rGL�RIA MARIA MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(14064,828417187015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','schoolteacher2860','bjorn@matsen.dk','bjorn matsen','niels bohrs allé 15','soborg','','DENMARK','2860','+4539699675','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-01 22:32:59',0,NULL,3,1,2,1,NULL,'schoolteacher2860'),(14065,828414509015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','ricardo.bou','bous026@yahoo.es','Ricardo Fco. Bou Sebastián','C/Benimaclet nº 39 - pta 25','Alboraya','Comunidad Valenciana','SPAIN','46120','678446985','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-01 22:34:06',0,NULL,3,1,4,1,'YW866475455CN ','ricardo.bou\rTripod  $22'),(14066,706322418018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','faifai85','meduseman@neuf.fr','Philippe Bouchet','U11/19-23 Glyde Street','Mosman Park','Western Australia','AUSTRALIA','6012','0061 406811113','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-01 22:53:19',0,NULL,3,1,2,1,NULL,'faifai85'),(14067,705566128001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',2,'AO0011',159.98,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 23:37:12',0,NULL,3,1,17,0,NULL,'fatimahali23'),(14068,747217547002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 23:37:13',0,NULL,3,1,17,0,NULL,'fatimahali23'),(14069,747217745002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',2,'AO0010',140,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-01 23:37:14',0,NULL,3,1,8,1,'CP227167821CN','fatimahali23\r背景架2m x 3m + 3个夹子    2\r背景架2mx2m  + 3个夹子 (新的三节背景架）     1\r背景架 2mx3m 河北      2\r1.6x2.1 白       3\r夹子    6\r13.417'),(14070,747217365002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','clout20','mlbeasley42@hotmail.com','Melissa Beasley','1235 Cottontown Rd','lynchburg','VA','UNITED STATES','24503','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-01 23:42:21',0,NULL,3,1,4,1,'YW866475444CN ','clout20\rTripod   $22'),(14071,747225915002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','niemalshier','wirwarenniemalshier@yahoo.es','Raquel Leton','Av. Monforte de Lemos 165, 11-1','Madrid','Madrid','SPAIN','28029','913863684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 00:04:43',0,NULL,3,1,2,1,NULL,'niemalshier'),(14072,705574159001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',3,'AC1201',14.7,'hermeshine','oryx52','jan.blackie@gmail.com','J.A.  Blackie','P.O.Box 893<br>Rooihuiskraal','Centurion','Gauteng','SOUTH AFRICA','0154','0829407542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 00:11:30',0,NULL,3,1,2,1,NULL,'oryx52'),(14073,747232870002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','robertop3449','ropiald@mundo-r.com','Roberto Piñeiro Aldir','c/ Lopez Mora 62 1ºE','Vigo','Galicia','SPAIN','36211','617477663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 00:32:02',0,NULL,3,1,3,1,'RA183622048CN\r ','robertop3449'),(14074,705599446001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','georgiaferguson','g-ferg@live.com','jacob munro','2 pilkington st<br>maori hill','dunedin','otago','NEW ZEALAND','9010','0214226153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 01:56:37',0,NULL,3,1,6,1,'EE495341065CN ','georgiaferguson'),(14080,8881312267018114,111,'lenspen * 2',1,'AKT051',0,'hermeshine','rodrigoslater76','slater76@gmail.com','Rodrigo Souza','Av. Emb. Abelardo Bueno 3350<br>Bl 2 apt 503 Barra dda Tijuca','Rio de Janeiro','Rio de Janeiro','BRAZIL','22775040','97030309',NULL,NULL,NULL,'2011-08-02 06:36:58',0,NULL,3,1,3,1,'RA183622207CN',NULL),(14076,747288575002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','angelkitten717','soheila703@gmail.com','Jessica Pierce','530 Los Angeles Ave.<br>#115-268','Moorpark','CA','UNITED STATES','93021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 04:33:46',0,NULL,3,1,1,1,NULL,'angelkitten717'),(14077,760923292017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',35.2,'photographyacc','j8i8m8x8','ebebstuff2@optusnet.com.au','Sue Reid','Excel Technology, 18 Staple Street<br>Seventeen Mile Rocks','Brisbane','Queensland','AUSTRALIA','4073','0732794322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-02 04:51:05',0,NULL,3,1,3,1,'RA183622079CN ','j8i8m8x8\r单灯头   澳标      2\r反光伞      2\r（已入库）'),(14078,761381592017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','paulbgreen77','paulbgreen@gmail.com','Paul  Green','7 Chalmers Place','North Ipswich','Queensland','AUSTRALIA','4305','0435927389','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-02 05:25:03',0,NULL,3,1,4,1,'YW866475422CN','paulbgreen77'),(14079,8881312266097825,111,'斜臂里的袋子',1,'',0,'hutongstore','handsomelok','o_0.hello@hotmail.com','TIN LOK LEE','80 Glamorgan Street<br>Canton','Cardiff','Cardiff','UNITED KINGDOM','CF5 1QT','07817239451',NULL,NULL,NULL,'2011-08-02 06:21:37',0,NULL,3,0,3,1,' RA183622119CN',NULL),(14081,704800437001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','morgan_hot','5657778@gmail.com','Ruslan Desakulov','ulica Kairatskaya, dom 1','Uralsk','KZ','KAZAKHSTAN','090005','7775657778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 06:41:20',0,NULL,3,1,3,1,'RA183622198CN ','morgan_hot'),(14082,747317987002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',19.9,'hermeshine','andyisdead','andyisdead.81@gmail.com','Andrea Cosentino','Salita Viarno 38','Viganello','','SWITZERLAND','6962','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 07:36:28',0,NULL,3,1,2,1,NULL,'andyisdead'),(14083,747068089002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',79.99,'hermeshine','yazoo1312','pllorente@terra.es','Pedro Llorente','Gaspar Aguilar, 24 - 4','Valencia','Comunidad Valenciana','SPAIN','46007','616121253','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 08:02:50',0,NULL,3,0,4,1,'YW866475396CN ','yazoo1312\r客户要6160H\r（已入库）'),(14084,703318400018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','rays_rx','rawya.zaylaa@slatergordon.com.au','ray zaylaa','145 acacia ave greenacre','sydney','New South Wales','AUSTRALIA','2190','0415745530','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-02 08:49:18',0,NULL,3,1,4,1,'YW866475400CN ','rays_rx\rbackgrond support $25'),(14085,747334469002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','arcobright','arco.witter@gmail.com','Arco Witter','Dwerggras 3','Houten','','NETHERLANDS','3994 MR','06-22900357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 08:56:26',0,NULL,3,1,3,1,'RA183622175CN','arcobright'),(14086,747337137002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','viper.hr','viper.dbk@gmail.com','Igor Brautovic','Kuparska 1','Dubrovnik','Hrvatska','CROATIA','20000','+385921331326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 09:10:23',0,NULL,3,1,17,0,NULL,'viper.hr'),(14087,747338496002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','monikaimarko','asicmarko@gmail.com','Marko Asic','Janjinska 18','Dubrovnik','Croatia','CROATIA','20000','00385 98 329 110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 09:15:05',0,NULL,3,1,2,1,NULL,'monikaimarko'),(14088,705681791001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','viper.hr','viper.dbk@gmail.com','Igor Brautovic','Kuparska 1','Dubrovnik','Hrvatska','CROATIA','20000','+385921331326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 09:15:27',0,NULL,3,1,2,1,NULL,'viper.hr\r方镜广角托架（ 一槽）    1\rCANON 镜头盖  77mm      1'),(14089,828591512015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','ttkacik','tomas.tkacik@gmail.com','Tomas Tkacik','Bauerova 21','Kosice','','SLOVAK REPUBLIC','04023','00421904076477','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-02 09:32:39',0,NULL,3,1,2,1,NULL,'ttkacik'),(14090,747347359002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','mykolavelychko','velkol@list.ru','Golubnichaya Ekaterina','Kamyanetska, 68, kv.79','Khmelnitskiy','Khmelnitskiy','UKRAINE','29000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 10:02:29',0,NULL,3,1,2,1,NULL,'mykolavelychko'),(14091,705696262001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','kioto22','tedioso@gmail.com','Eduardo Muñoz Trujillo','Avda. del Prado, Portal 2, 2º C','Mérida','Extremadura','SPAIN','06800','607967254','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 10:27:45',0,NULL,3,0,3,1,'RA183622357CN ','kioto22\r2xl   (已入库）'),(14092,828610611015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','shaun117','shaunscottuk@yahoo.co.uk','Shaun Scott','48 Newnham Street','Ely','Cambridgeshire','UNITED KINGDOM','CB7 4PE','01353615275','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 10:35:24',0,NULL,3,1,2,1,NULL,'shaun117'),(14093,828621271015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','coaltester1','ian@ian997.wanadoo.co.uk','IAN ARCHER','108 WILMOT ROAD','SWADLINCOTE','Derbyshire','UNITED KINGDOM','DE119BJ','01283551614','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 11:10:17',0,NULL,3,1,2,1,NULL,'coaltester1'),(14094,747344471002,120752248934,'33\" double layers reflective and translucent umbrella',2,'AD1156',41.98,'hermeshine','hoang_dang89','little_tiger1989@hotmail.com','Hoang Thanh Dang','Skorvatjörno 30','Hagavik','','NORWAY','5217','+47 95891437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 11:35:36',0,NULL,3,0,3,1,'RA183622167CN ','hoang_dang89\r两用伞\r新地址\rHoang Thanh Dang\rSkorvatj\Zrno 30\r Hagavik 5217 \rNorway  \r申报gift  $30'),(14095,761471337017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','baom2002','poisongass@yahoo.com','Nguyen Minh Bao LY','3 Cunningham Court','Melbourne','Victoria','AUSTRALIA','3032','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-02 12:06:20',0,NULL,3,1,2,1,NULL,'baom2002'),(14096,828630813015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','hpvc','hpvc@netmadeira.com','Henrique Castro','Top Atlantico Madeira<br>Avenida das Comunidades Madeirenses, 15','Funchal','Madeira','PORTUGAL','9000-054','(+351) 969785555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-02 12:42:10',0,NULL,3,1,3,1,'RA183622290CN ','hpvc'),(14097,761485270017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','nikolayeroshkin','kolunja07@mail.ru','Nikolay Nikolay','pgt Bogorodskoe d58 -1','pgt Bogorodskoe','Moskow oblast  Sergiev-posadsky region','RUSSIAN FEDERATION','141342','+7-929-701-44-91','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-02 12:49:19',0,NULL,3,1,2,1,NULL,'nikolayeroshkin'),(14098,747404098002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','p_visser','patrick@driftingmedia.com','patrick visser','fideliolaan 398','amstelveen','Noord-Holland','NETHERLANDS','1183px','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 13:35:59',0,NULL,3,0,3,1,'RA183622255CN ','p_visser\r2xl   (已入库）'),(14099,706525255018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','zoomnclick','feroz.k.khan@gmail.com','Feroz Khan','Emirates Group Technology Centre<br>4th Floor, Area 14','Dubai','Dubai','UNITED ARAB EMIRATES','686','971507284913','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-02 13:37:38',0,NULL,3,1,2,1,NULL,'zoomnclick'),(14100,761511107017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','ilya-narizniy','narizniy@ukr.net','dmitro naryzhnyi','Gritsevca st., 11-a, 22','Kharkiv','','UKRAINE','61172','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-02 14:23:05',0,NULL,3,1,2,1,NULL,'ilya-narizniy'),(14101,705761046001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','carl1645','carlwalters@class1uk.com','carl walters','2, Rossendale Close','Chesterfield','Derbyshire','UNITED KINGDOM','S40 3EL','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 14:29:55',0,NULL,3,0,3,1,'RA183622215CN\r ','carl1645\r3xl   (已入库）'),(14102,705769630001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','keironski','keironski@aol.com','KEIRON TREBILCOE','15 Bryanston Road','Tilbury','Essex','UNITED KINGDOM','RM18 8DD','07960926800','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 15:02:05',0,NULL,3,0,3,1,'RA183622309CN ','keironski\r3xl  （已入库）'),(14103,811434890016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',54,'hutongstore','seasidekez','kezzy90@btinternet.com','Kerri Hart','Wyverne House<br>Carlton Road,','Louth','Lincolnshire','UNITED KINGDOM','LN11 8HH','01507610710','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-02 15:16:06',0,NULL,3,1,4,1,'YW866475411CN ','seasidekez\r英标\r Lighting Kit      $25'),(14104,706565312018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','flimbs','jas.chau@gmail.com','Jason Chau','59 Charlton Blvd','North York','ON','CANADA','M2M 1C1','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-02 15:39:56',0,NULL,3,1,2,1,NULL,'flimbs'),(14105,811450243016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','rocifoto01','rocifoto@citromail.hu','Roland Balogh','Előre<br>utca 2','Dunapataj','Bács-kiskun megye','HUNGARY','6328','+36703385385','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-02 15:53:26',0,NULL,3,1,2,1,NULL,'rocifoto01'),(14106,761545906017,270777970641,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k',1,'',290,'photographyacc','flying_cns','o1205@hotmail.com','Takahiro Maruyama','5/284Lake st','CAIRNS','Queensland','AUSTRALIA','4870','0401630679','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-02 15:55:56',0,NULL,3,1,4,1,'YW866127194CN\r ','flying_cns'),(14107,747449989002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-02 16:01:02',0,NULL,3,1,3,1,'RA183622224CN ','elizeucine'),(14108,553872340003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','aapo.rossi85','aapo.rossi1@gmail.com','Aapo Rossi','Muurainkuja 6 as24','Jyvaskyla','Jyvaskyla','FINLAND','40340','0407679501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 16:15:15',0,NULL,3,1,2,1,NULL,'aapo.rossi85'),(14109,747486092002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','graubarr','imut@llucmajor.org','Ignasi Mut Nicolau','C/ Major, 229','Llucmajor','Baleares','SPAIN','07620','679442663','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 17:37:11',0,NULL,3,1,2,1,NULL,'graubarr'),(14110,743247190002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','robert_douser','kyojutsu@yahoo.com','Roger D\'Souza','1111 Arlington Blvd<br>Apt 920','Arlington','VA','UNITED STATES','22209-3207','(845) 380-7951','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 17:29:54',0,NULL,3,1,1,1,NULL,'robert_douser'),(14111,747508725002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','torleiflie','torleifrov@yahoo.no','Torleif Lie','Nadlandsknausene 15','Stavanger','Rogaland','NORWAY','4034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 18:30:38',0,NULL,3,1,2,1,NULL,'torleiflie'),(14112,747538539002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','rustyreliks','randb@san.rr.com','Betty Gehm','5023 Hilda Rd','San Diego','CA','UNITED STATES','92110','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-02 19:32:15',0,NULL,3,1,1,1,NULL,'rustyreliks'),(14113,828845540015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'AA2203',2.75,'hutongstore','gorgonred1','mikeapike2@tiscali.co.uk','Michael Paton','Energlyn farm house Ael Y Bryn Energlyn','Caerphilly','Caerphilly','UNITED KINGDOM','CF83 2QX','02920851972','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-02 19:39:14',0,NULL,3,1,2,1,NULL,'gorgonred1'),(14114,747592951002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','p_pohjanjoki','pohjanjoki@gmail.com','Petri Pohjanjoki','Turunmaankatu 2 A 1','Turku','','FINLAND','20740','+358509115918','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 21:40:29',0,NULL,3,1,2,1,NULL,'p_pohjanjoki'),(14115,761711005017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',5,'AA1203',14.5,'photographyacc','edw_1','f16camera@digisurf.net.au','Alan Robertson','P.O. Box 247  or<br>243 Victoria Avenue','Margate','Queensland','AUSTRALIA','4019','0732841588','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-02 22:02:28',0,NULL,3,1,3,1,'RA183622286CN\r ','edw_1'),(14116,705942593001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 22:16:46',0,NULL,3,1,17,0,NULL,'manoj11276'),(14117,747608242002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 22:16:46',0,NULL,3,1,2,1,NULL,'manoj11276\r天涯方形滤镜  ND8     1\r方形滤镜接口环 72mm     1\r方镜普通托架（三槽）    1\r申报gift  $11.3'),(14118,702789845001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','focalfocal','tommyf@zonnet.nl','Tom Flipse','Jacob Paffstraat 22','AMSTERDAM','','NETHERLANDS','1069PJ','0624645325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 22:22:20',0,NULL,3,1,2,1,NULL,'focalfocal'),(14119,747614569002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','michaelq66','michael.quinlivan@irishbroadband.net','Michael Quinlivan','329 O\'Malley Park<br>Southill','Limerick City','Limerick','IRELAND','default','0872311815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 22:37:06',0,NULL,3,1,2,1,NULL,'michaelq66'),(14120,705962766001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','miguel_out','miguelin.moya@gmail.com','Miguel Moya Ramos','Arriero 6','Alcala de Guadaira','Andalucía Ceuta y Melilla','SPAIN','41500','651907808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 23:31:59',0,NULL,3,1,3,1,'RA183622238CN ','miguel_out'),(14121,705964155001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','stalin2015','moscow2015@hotmail.com','Patrick Albano','1108 Allegheny Dr','Blakeslee','PA','UNITED STATES','18610-2003','(570) 646-5015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-02 23:37:04',0,NULL,3,1,3,1,'RA183622330CN\r ','stalin2015'),(14122,747633493002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','andrew.serre','andrew.serre@gmail.com','Andrew Serre','1568 Blohm Drive','Ottawa','ON','CANADA','K1G4R7','(613) 355-9250','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-02 23:43:32',0,NULL,3,1,2,1,NULL,'andrew.serre'),(14123,761725263017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',45.48,'photographyacc','nufaiemohamed','mnufaie@gmail.com','Mohammad AlOtaibi','3912 Dirab, Al Haba St.<br>Mobile:0555185205','Riyadh','CP','SAUDI ARABIA','14969-7363','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 00:01:57',0,NULL,3,1,3,1,'RA183622272CN ','nufaiemohamed\r笔    1\r气吹+布    1\r普通有线快门线RS--C1     1\r58mm  CPL       1\r绿叶 UV  52mm       1\r绿叶 渐变镜    52mm      1\r绿叶   CPL    52mm       1\r绿叶 渐变镜   58mm      1\r(已入库）\r'),(14124,747556814002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','2010grimbergsheila','grimbergsheila@gmail.com','Adriana  Grimberg','Ecuador 318 1Piso Departamento A','Capital Federal ','Buenos Aires','ARGENTINA','C1214ACD','1148657042','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-03 00:30:01',0,NULL,3,1,3,1,'RA183622241CN ','2010grimbergsheila\r申报  $15'),(14125,705710368018,280688523982,'High Quality Umbrella Softbox Reflector Studio 35\" 90cm',1,'AD1127',22.9,'photographyacc','joe_exit','joe_exit7@hotmail.com','Pablo Andres Giacobone','Remedios de escalada 2370<br>remedios de escalada 2356','Mar del Plata','Buenos Aires','ARGENTINA','7600','+542235275922','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 00:35:15',0,NULL,3,1,3,1,'RA183622269CN ','joe_exit'),(14126,706792215018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',2.5,'photographyacc','cpperky2','mcperkins1@aol.com','Carol Perkins','3613 Randolph Rd','Janesville','WI','UNITED STATES','53546-1404','(608) 754-0861','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 01:55:35',0,NULL,3,1,1,1,NULL,'cpperky2'),(14127,829013919015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','vladek123','vladek@neti.ee','Wladek  Saar','Jarveotsa tee 13 - 93','Tallinn','Estonia','ESTONIA','13520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 02:46:46',0,NULL,3,1,2,1,NULL,'vladek123'),(14128,8881312340504461,111,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',0,'hermeshine','jianye.chen','jianye.chen@gmail.com','Jianye Chen','29316 Richardson CT','Highland','CA','UNITED STATES','92346','',NULL,NULL,NULL,'2011-08-03 03:01:44',0,NULL,3,0,1,1,NULL,'jianye.chen\r(第一次发的蓝色的,收到后说有个洞,这次补发个灰色的)\r1.6*2.1   灰色背景布     1\rLK003286038CN     08-03\r'),(14129,746801977002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',80,'hermeshine','ilovemydolls79','kablackeby@gmail.com','Kristy-Anne Gill','36 Gregory Street','Port Elliot','South Australia','AUSTRALIA','5212','0432991428','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-03 03:25:58',0,NULL,3,1,3,1,'RA183622326CN\r ','ilovemydolls79\r摄影背心 黑色厚 sony  XL    1\r摄影背心 黑色厚 sony XXL    1\r（已入库）'),(14130,706817167018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','dba2k1','allred12@comcast.net','David Allred','760 NW Datewood Dr','Issaquah','WA','UNITED STATES','98027','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 03:45:44',0,NULL,3,1,1,1,NULL,'dba2k1\r除了c 里的再加上49 环    1   \r82的环       1\r还有广角托架      1\r已入库'),(14131,706821494018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','siubobo95','siubobo95@cox.net','Gary Lee','25 Pavona','Newport Coast','CA','UNITED STATES','92657','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 04:06:29',0,NULL,3,1,1,1,NULL,'siubobo95'),(14132,706823150018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','mitchellracing_89','speedwayroxz_32_27_89@hotmail.com','Felicia Forknall-Mitchell','15  Bourke  Street<br>15','Waterford West','Queensland','AUSTRALIA','4133','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 04:13:41',0,NULL,3,0,2,1,NULL,'mitchellracing_89\r1.6*2.1  白的背景布    1'),(14133,829055687015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','domohugo','chanhugo@gmail.com','Hugo Chan','5-83 Rameau Drive','Toronto','ON','CANADA','M2H 1T6','(416) 493-6322','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 05:44:56',0,NULL,3,1,5,1,'CP227167415CN ','domohugo'),(14134,706044686001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','darynthe1','fmsyv@yahoo.com','tania vargas','2580 Dickson','Montreal','QC','CANADA','h1n 2j3','(514) 966-7065','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 05:49:52',0,NULL,3,1,3,1,'RA183622405CN ','darynthe1'),(14135,761836022017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','bejnym','batoustachikoma@yahoo.com.au','Ben Large','49 Phillips st, Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','0738691200','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 06:27:48',0,NULL,3,1,2,1,NULL,'bejnym'),(14136,761842531017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','ssballoch','ssballoch@gmail.com','Scott Balloch','5 Arno Cres','Attadale','Western Australia','AUSTRALIA','6156','0893302590','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 07:01:02',0,NULL,3,1,2,1,NULL,'ssballoch'),(14137,706059003001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','frankedisson','heyaaaa@inbox.lv','Aleksandrs Puzijs','Balta 24-70','Riga','','LATVIA','LV 1055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 07:14:49',0,NULL,3,0,3,1,'RA183622388CN ','frankedisson\r52cm 遮光罩     1\r55cm 遮光罩     1\r58cm 遮光罩     2\r62cm 遮光罩     1\r67cm 遮光罩     3\r72cm 遮光罩     1\r77cm 遮光罩     1\r申报$12\r（已入库）'),(14138,747733776002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',43.9,'hermeshine','victorphotography','spcglez@hotmail.com','Victor Gonzalez','Urb.Villa Universitaria<br>Calle 12 E26','Humacao','PR','UNITED STATES','00791','(787) 360-5848','NoPaymentFailure','CheckoutComplete','Other','2011-08-03 07:22:14',0,NULL,3,1,3,1,'RA183622391CN ','victorphotography'),(14139,829099075015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','yukie_br','holli_de_rossi@yahoo.co.uk','Holli de Rossi','5A oaktree gardens','Whitley Bay','Tyne and Wear','UNITED KINGDOM','NE25 8XF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 08:45:06',0,NULL,3,1,17,0,NULL,'yukie_br\r'),(14140,706875594018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','ricdemeric','edelosange@modulonet.fr','ERIC  DE LOS ANGELES','1 rue raoul ponchon Rés les Tourelles Apt 52 Tour 7','MERIGNAC','Aquitaine','FRANCE','33700','05.56.12.06.75','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 08:56:09',0,NULL,3,1,17,0,NULL,'ricdemeric\r'),(14141,706876637018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','ricdemeric','edelosange@modulonet.fr','ERIC  DE LOS ANGELES','1 rue raoul ponchon Rés les Tourelles Apt 52 Tour 7','MERIGNAC','Aquitaine','FRANCE','33700','05.56.12.06.75','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 08:58:32',0,NULL,3,1,4,1,'YW866127920CN','ricdemeric\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1\r独脚架  伟峰 WT-1005      1\rBackground Support    $25\r'),(14142,747753381002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',37.9,'hermeshine','cyclon_cyclon','cycloness@mail.ru','Stan Belobrov','Maklakova str. 27 - 53','Murmansk','','RUSSIAN FEDERATION','183071','+79062860192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 08:59:30',0,NULL,3,1,17,0,NULL,'cyclon_cyclon'),(14143,747753674002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','cyclon_cyclon','cycloness@mail.ru','Stan Belobrov','Maklakova str. 27 - 53','Murmansk','','RUSSIAN FEDERATION','183071','+79062860192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 09:00:46',0,NULL,3,1,3,1,'RA183622555CN','cyclon_cyclon\r2b 柔       1\r大力夹     1'),(14144,8881312362436735,111,'115w 220v x 1',1,'AE3601',0,'photographyacc','delphine411','l.dore@online.fr','DORE DELPHINE','7 RUE LE MEUNIER','BATILLY','other','FRANCE','54980','',NULL,NULL,NULL,'2011-08-03 09:07:16',0,NULL,3,1,3,1,'RA183622516CN\r ',NULL),(14145,706882514018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','035bronson','lynmcconnell@westvic.com.au','Lynette McConnell','802 Penshurst Road','Kirkstall','Victoria','AUSTRALIA','3283','0355658701','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,1,'\r ','035bronson\r除了c 里面的再发\r49cm  接口环   1\r82cm   接口环    1\r广角托架   1\r（已入库）'),(14146,747759886002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','minkof3799','minkof@gmail.com','Ivan Minkov','zk. Tolstoi bl. 54 ent. V ap.65','Sofia','Sofia','BULGARIA','1220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 09:29:01',0,NULL,3,1,2,1,NULL,'minkof3799'),(14147,829126571015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',12.99,'hutongstore','yukie_br','holli_de_rossi@yahoo.co.uk','Holli de Rossi','5A oaktree gardens','Whitley Bay','Tyne and Wear','UNITED KINGDOM','NE25 8XF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 10:22:39',0,NULL,3,1,3,1,'RA183622502CN\r ','yukie_br\r柔光箱 50-70cm 单灯头  英标     1\r115w 5500k 灯泡  220v     1'),(14148,811839228016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','f_poulus','frank_poulus@hotmail.com','Frank Poulus','Schapenmeent<br>148','Almere','','NETHERLANDS','1357GN','0031652018253','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 10:29:57',0,NULL,3,1,3,1,'RA183622652CN ','f_poulus'),(14149,706101171001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cuciaciq','cuciacik@stonline.sk','Rastislav Petras','699','Koseca','SC','SLOVAK REPUBLIC','018 64','0907418885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 10:36:09',0,NULL,3,0,2,1,NULL,'cuciaciq\r1.6*2.1 黑色背景布    1'),(14150,829124139015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','paterson7602','michael.paterson@strath.ac.uk','Michael Paterson','ERS Ltd<br>Westerhill Road','Bishopbriggs','Glasgow','UNITED KINGDOM','G64 2QH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 10:37:26',0,NULL,3,1,2,1,NULL,'paterson7602'),(14151,747772422002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','bsecilmis','bsecilmis@hotmail.com','Baris Secilmis','Istinye Mah. Darussafaka Cad. No: 45 Kat :2 ISTINYE<br>SARIYER','ISTANBUL','ISTANBUL','TURKEY','34460','05326934543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 10:41:04',0,NULL,3,1,2,1,NULL,'bsecilmis'),(14152,706104214001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',82,'hermeshine','chuhrandmitry','chuhran@gmail.com','Dmitry Chuhran','prospekt Gvardeisky d.59, korp.B, kvartira 120','Severodonetsk','Luganskaya oblast','UKRAINE','93400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 10:49:55',0,NULL,3,1,5,1,'CP227167818CN ','chuhrandmitry'),(14153,706107302001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','robert83moto','bhandcuffs@yahoo.fr','Robert POLIDORI','213 route de la motte','le muy','Provence-Alpes-Côte d\'Azur','FRANCE','83490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 11:22:45',0,NULL,3,1,2,1,NULL,'robert83moto'),(14154,829149825015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','kuniva7','cjns@ymail.com','chris sanders','Trident Garages (Honda)<br>30 Queens Rd','Weybridge','Surrey','UNITED KINGDOM','Kt13 9uz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 11:35:46',0,NULL,3,1,2,1,NULL,'kuniva7'),(14155,706116118001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','filipbundalo','filip.bundalo@fsb.hr','Filip Bundalo','Otona Zupancica 14','Velika Gorica','','CROATIA','10410','++385915173684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 11:40:02',0,NULL,3,1,3,1,'RA183622520CN\r ','filipbundalo'),(14156,761914176017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','bobbyald141','robert.aldridge@yahoo.com.au','Robert Aldridge','269 New Line Road','Dural','New South Wales','AUSTRALIA','2158','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 11:53:52',0,NULL,3,1,2,1,NULL,'bobbyald141'),(14157,811871490016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','vbalkanov','shivers_design@yahoo.com','Vladimir Balkanov','43, Cherni Vrah Blvd<br>StangaOne1 World Group','Sofia','','BULGARIA','1407','+359878796037','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 12:12:28',0,NULL,3,1,2,1,NULL,'vbalkanov'),(14158,761933152017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','maksest','mks@hot.ee','Maxim Krasnov','Mahtra 21- 56','Tallinn','Harjuma','ESTONIA','13811','37256453277','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 12:57:32',0,NULL,3,1,3,1,'RA183622365CN ','maksest'),(14159,706939819018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','lerych66','valeriyvn@gmail.com','Valeriy Nazarov','Aralskaya 212-21','Chelyabinsk','','RUSSIAN FEDERATION','454025','+73519096587','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 13:00:37',0,NULL,3,1,2,1,NULL,'lerych66'),(14160,706093727001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','eekseye','no-clowns@mail.ru','Igor Kolbin','Lenin prospect 81-4','Barnaul','Altai region','RUSSIAN FEDERATION','656000','+7-913-084-5653','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-03 13:26:45',0,NULL,3,1,17,0,NULL,'eekseye'),(14161,706094306001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','eekseye','no-clowns@mail.ru','Igor Kolbin','Lenin prospect 81-4','Barnaul','Altai region','RUSSIAN FEDERATION','656000','+7-913-084-5653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 13:26:46',0,NULL,3,1,17,0,NULL,'eekseye'),(14162,747768030002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','eekseye','no-clowns@mail.ru','Igor Kolbin','Lenin prospect 81-4','Barnaul','Altai region','RUSSIAN FEDERATION','656000','+7-913-084-5653','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 13:26:47',0,NULL,3,1,5,1,'CP227167424CN ','eekseye\r背景架2mx2m  + 3个夹子    1（新的那个背景架）\r背景布 1.6*2.1   黑色+白色\r独脚架  伟峰 WT-1007       1\rlenspen       1\r气吹 + 布       1'),(14163,761950438017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',60,'photographyacc','alexmyst69','alexmansour@iinet.net.au','Alex Mansour','19 Norbertine Close','Perth','Western Australia','AUSTRALIA','6107','0433338150','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 13:55:21',0,NULL,3,1,4,1,'YW866127916CN ','alexmyst69\rLighting stand $25'),(14164,747841321002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','mauroishikawa','ishikawamau@gmail.com','mauro ishikawa','al. Pelotas, 159<br>cond. 18 do Forte','Santana Parnaiba','Sao Paulo','BRAZIL','06543210','551191077617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 14:36:13',0,NULL,3,1,2,1,NULL,'mauroishikawa'),(14165,747852885002,120555973963,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',44,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','(819) 239-3099','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 15:11:02',0,NULL,3,1,3,1,'RA183622431CN\r ','mickflag'),(14166,706174424001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','syrielle_2007','capchat2000@hotmail.com','Kim Deslauriers','8675 rue Romain','Laval','QC','CANADA','H7A3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 15:18:08',0,NULL,3,1,17,0,NULL,'syrielle_2007'),(14167,706177207001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','syrielle_2007','capchat2000@hotmail.com','Kim Deslauriers','8675 rue Romain','Laval','QC','CANADA','H7A3K3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 15:18:09',0,NULL,3,1,2,1,NULL,'syrielle_2007\r麂皮       2'),(14168,706092629001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','oc-gae','beltzung.gaetan@wanadoo.fr','Gaetan Beltzung','4 Route de They','Breurey les Sorans','Franche-Comté','FRANCE','70190','+33384917035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 15:20:14',0,NULL,3,1,3,1,'RA183622533CN\r ','oc-gae'),(14169,747855733002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','+79129394361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-03 15:22:21',0,NULL,3,1,3,1,'RA183622445CN\r ','motorfoto'),(14170,829244622015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','hunter352','john.hunter2@btinternet.com','John Hunter','22 Gibson Close,Holdingham','Sleaford','Lincolnshire','UNITED KINGDOM','NG348BB','01529306615','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 15:50:16',0,NULL,3,1,3,1,'RA183622459CN ','hunter352'),(14171,706193050001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','expert2102','janaphoto@yandex.ru','Yana Danilova','Stepana Razina st. 60/167','Izhevsk','RU','RUSSIAN FEDERATION','426032','7-919-901-79-52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 16:07:27',0,NULL,3,1,17,0,NULL,'expert2102'),(14172,706200122001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','expert2102','janaphoto@yandex.ru','Yana Danilova','Stepana Razina st. 60/167','Izhevsk','RU','RUSSIAN FEDERATION','426032','7-919-901-79-52','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 16:27:36',0,NULL,3,1,2,1,NULL,'expert2102\r6片装的滤镜袋    1\r橡胶遮光罩 52mm     1'),(14173,706201467001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',53.9,'hermeshine','orilovenoriloven','oriloven@gmail.com','Ori Loven','palg\'ey ma\'em 31<br>Galil Elion','She\'ar Yeshuv','','ISRAEL','12240','0547906157','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 16:32:16',0,NULL,3,1,3,1,'RA183622697CN ','orilovenoriloven\r注意是两个\r分开发因为包在一起会超重\rRA183622635CN'),(14174,706205600001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.95,'hermeshine','jfernandezg','jfergon@gmail.com','Javier Fernandez Gonzalez','6, Sta Cecilia','Jerez','Andalucía Ceuta y Melilla','SPAIN','11403','635428995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 16:43:18',0,NULL,3,1,3,1,'RA183622581CN ','jfernandezg'),(14175,811989885016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','hansebsen','hans_esbjerg@hotmail.com','Hans Ebsen','Skoleparken 15 2 tv.','Esbjerg V','','DENMARK','DK6705','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 17:20:53',0,NULL,3,1,2,1,NULL,'hansebsen'),(14176,706221909001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','billvialyn','billvialyn@tiscali.co.uk','linda groombridge','31 burch ave','sandwich','Kent','UNITED KINGDOM','ct130al','01304615363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:26:51',0,NULL,3,1,2,1,NULL,'billvialyn'),(14177,706222664001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','tonyfelgueiras','tonyfelgueiras@yahoo.ca','Tony Felgueiras','24 Mabelle Ave. Apt 408','Etobicoke','ON','CANADA','M9A4X7','(416) 735-6993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:27:45',0,NULL,3,1,2,1,NULL,'tonyfelgueiras'),(14178,706228514001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','usmcvetcpl','dominguez_memo@yahoo.com','Guillermo Dominguez','1818 Hendricks Ave','Laredo','TX','UNITED STATES','78040-6515','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-03 17:44:00',0,NULL,3,1,1,1,NULL,'usmcvetcpl'),(14179,706228859001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.8,'hermeshine','harry-willhaben','harald.jelenc@inode.at','Johanna Jelenc','Simonygasse 6','GRAZ','','AUSTRIA','8054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:44:15',0,NULL,3,1,2,1,NULL,'harry-willhaben'),(14180,707040576018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',1,'AKT064',83,'photographyacc','petiesreverie','thestarsbetweenus@yahoo.com','Peter Doucette','2120 N Courtland Dr','Green Bay','WI','UNITED STATES','54313-9359','','NoPaymentFailure','CheckoutComplete','USPSParcel','2011-08-03 17:53:52',0,NULL,3,1,4,1,'YW866127905CN ','petiesreverie\r灯泡是110v  的   \r'),(14181,705359853001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','y.krasnov','y.krasnov.ebay@gmail.com','Jyri Krasnov','Barrikadnyi 36','Bishkek','Kyrgyzstan','KYRGYZSTAN','720007','996700524029','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 17:55:46',0,NULL,3,1,2,1,NULL,'y.krasnov'),(14182,706246531001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sophiec1981','vincent.car@hotmail.com','Sophie Couture','103 rue de l\'Iris','St-Henri','QC','CANADA','G0R 3E0','(418) 895-0244','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-03 18:26:47',0,NULL,3,1,5,1,'CP227167438CN ','sophiec1981\r背景布1.6*2.1  白+黑'),(14183,829324945015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','jenots07','agnis21@apollo.lv','Agnis Namikis','Daugavas 15','Madona','Madonas raj','LATVIA','LV-4801','26282569','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 18:34:28',0,NULL,3,1,3,1,'RA183622476CN ','jenots07'),(14184,706139520018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','dmcnamara7c3t','dennis.mcnamara@sigmatronintl.com','dennis mcnamara','413 enchanted way','del rio','TX','UNITED STATES','78840','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-03 18:37:56',0,NULL,3,1,1,1,NULL,'dmcnamara7c3t'),(14185,706262824001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','drossrussia','dross2004@list.ru','Misha Petrov','Startovaja str. 7 - 69','Moscow','','RUSSIAN FEDERATION','129336','79031038527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 19:04:19',0,NULL,3,1,2,1,NULL,'drossrussia'),(14186,706141777001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','jordangodsbeloved','hobocheese88@gmail.com','Jordan Franck','525 Old 81 Street','Palmerston','ON','CANADA','N0G2p0','(519) 343-3676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 19:17:53',0,NULL,3,1,2,1,NULL,'jordangodsbeloved'),(14187,747953527002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',5,'AKT051',57.5,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+78137650467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 19:19:28',0,NULL,3,1,3,1,'RA183622547CN\r ','igrom78\r注意是10只'),(14188,706312580001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','schnipor','kontakt@schleifartikel.com','Markus Schrägle','Fuchsweg 2','Kirchheim unter Teck','','GERMANY','73230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 21:04:09',0,NULL,3,1,17,0,NULL,'schnipor'),(14189,706311469001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','schnipor','kontakt@schleifartikel.com','Markus Schrägle','Fuchsweg 2','Kirchheim unter Teck','','GERMANY','73230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 21:05:21',0,NULL,3,0,17,0,NULL,'schnipor'),(14190,706310404001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','schnipor','kontakt@schleifartikel.com','Markus Schrägle','Fuchsweg 2','Kirchheim unter Teck','','GERMANY','73230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 21:06:22',0,NULL,3,1,2,1,NULL,'schnipor\r58-58mm 双阳环    1\rcanon 反接环  58mm     1\r52-58mm 双阳环       1'),(14191,762131884017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','fastlowrex','hursty@netspace.net.au','Dwayne Hurst','13 Beechcraft Court','Toowoomba','Queensland','AUSTRALIA','4350','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-03 21:10:24',0,NULL,3,1,2,1,NULL,'fastlowrex'),(14192,706324171001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','dealsapproved','icelily5@hotmail.com','DIANA TRAN','PO BOX 2581','LOS ALAMITOS','CA','UNITED STATES','90720','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-03 21:35:51',0,NULL,3,1,1,1,NULL,'dealsapproved'),(14193,706736538018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','itsvenusenvyvintage','judavdi@hotmail.com','Arrlann Christie','1548 Windsor St<br>North West','Calgary','AB','CANADA','T2N 3X3','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-03 21:40:40',0,NULL,3,1,5,1,'CP227167441CN ','itsvenusenvyvintage\r已收到'),(14194,812128374016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','alf_skull','alf_skull@hotmail.it','Pannullo Alfonso','Via Pasquale Di Domenico. 14/a<br>Santa Lucia','Cava de\' Tirreni','SA','ITALY','84013','3298246336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-03 21:50:58',0,NULL,3,1,2,1,NULL,'alf_skull'),(14195,748020492002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','pacorr0','pacorr0@hotmail.com','francisco jose ebri gomez','salavert nº 1 pta 16','valencia','valencia','SPAIN','46018','654149320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-03 22:06:22',0,NULL,3,1,2,1,NULL,'pacorr0'),(14196,829452576015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',20,'hutongstore','ermdata8937','ermdata@yahoo.co.uk','erm data','FLAT 6 ELLIS COURT<br>25 JAMES VOLLER WAY','London','London','UNITED KINGDOM','E1 2PF','07932630402','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 22:52:53',0,NULL,3,1,3,1,'RA183622595CN ','ermdata8937\r英标'),(14197,706346826001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','tomingram-iow','tom92uk@gmail.com','Tom Ingram','Brickwell House<br>Kemming Road','Whitwell','Isle of Wight','UNITED KINGDOM','PO38 2QX','07976686078','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-03 22:55:39',0,NULL,3,1,2,1,NULL,'tomingram-iow'),(14198,706356703001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','farhadomar','mohammadfarhad.omar@gmail.com','Burns IT Services','27 Boynton Gardens','Iluka','Western Australia','AUSTRALIA','6028','','NoPaymentFailure','CheckoutComplete','AU_Express','2011-08-03 23:37:51',0,NULL,3,1,4,1,'YW866127894CN ','farhadomar\r澳标\rLighting Kit   $28'),(14199,706373164001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','marisete10','marisetemuniz2010@hotmail.com','marisete muniz de lima','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','Paraíba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 00:52:19',0,NULL,3,1,17,0,NULL,'marisete10'),(14200,706372773001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','marisete10','marisetemuniz2010@hotmail.com','marisete muniz de lima','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','Paraíba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 00:52:20',0,NULL,3,1,3,1,'RA183622462CN\r ','marisete10\r单灯头  欧标    1\r肩架        1\r新地址:\rMARISETE MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rcentro\rLagoa Seca  - Paraiba\r58117-000\rBrazil\rtelephone 83 3366-1044'),(14201,829490394015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','hamlen88','benjaminhamlen@hotmail.co.uk','Benjamin Hamlen','21 Acresbrook road<br>Higham','Burnley','Lancashire','UNITED KINGDOM','BB12 9BY','01282778961','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 01:00:59',0,NULL,3,1,2,1,NULL,'hamlen88'),(14202,706381463001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','fatimahali23','tsts1394@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','Tarout','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 01:26:14',0,NULL,3,1,3,1,'RA183622414CN ','fatimahali23\r背景布 1.6*2.1   黑色+白色\rRA183622428CN'),(14203,748084870002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','wayneo247','groutw@gmail.com','Wayne Grout','178 Shute St','Everett','MA','UNITED STATES','02149-3134','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 02:25:52',0,NULL,3,1,3,1,'RA183622493CN ','wayneo247'),(14204,748094338002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','binzhang16888','binzhang66@gmail.com','Bin Zhang','5814 Greensboro Drive','Mississauga','ON','CANADA','L5M 5T1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 03:10:59',0,NULL,3,1,3,1,'RA183622683CN ','binzhang16888'),(14205,706408016001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','vikarx7','rx-7@inbox.ru','Viktoria Syrenshchikova','Lenina 314-10','Yuzhno-Sakhalinsk','Sakhalin region','RUSSIAN FEDERATION','693000','+7 963 289 7424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 03:30:15',0,NULL,3,1,2,1,NULL,'vikarx7'),(14206,762238464017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','dansurf09','d_hewitt889@hotmail.com','dan ridgley hewitt','31 Beachcomber Drive','byron bay','New South Wales','AUSTRALIA','2481','0642342343','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 03:38:34',0,NULL,3,1,2,1,NULL,'dansurf09'),(14207,8881312429542900,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',15.58,'aliexpress','1003837418 ','pantin@mail.ru','PANTIN VLADIMIR	','POSHEHONSKOE SHOSSE, 22-402','VOLOGDA','VOLOGDA','RUSSIAN FEDERATION	','160022','+7 921 7224666',NULL,NULL,NULL,'2011-08-04 03:45:42',0,NULL,3,1,3,1,'RA183622706CN ',NULL),(14208,706383789001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',32.97,'hermeshine','1weim','andrea_autery@sbcglobal.net','Andrea Autery','1036 Armada Ct','Florissant','MO','UNITED STATES','63031','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 03:59:41',0,NULL,3,0,3,1,'RA183622618CN ','1weim\r1.6x2.1 背景布   3\r灰， 浅蓝， 粉色'),(14209,8881312430395615,111,'渐变灰+ 77mm 环架',1,'AKT028',0,'hermeshine','nikolaos-k','nk@trains.gr','NIKOLAOS KAPSIMALAKOS','74 THETIDOS str.<br>ILION','ATHENS','ATTIKI','GREECE','13122','(30)6973743869',NULL,NULL,NULL,'2011-08-04 03:59:55',0,NULL,3,1,2,1,NULL,NULL),(14210,762241937017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','floody93','sam_flood@hotmail.com','Sam Flood','10 The Strand','George Town','Tasmania','AUSTRALIA','7253','0363823251','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 03:59:58',0,NULL,3,1,2,1,NULL,'floody93'),(14211,748107181002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','lukel112','lukel1280@yahoo.com','luke lovrek','3015 N. Frederick Ave','Milwaukee','WI','UNITED STATES','53211','(414) 640-7709','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 04:18:46',0,NULL,3,1,3,1,'RA183622621CN ','lukel112'),(14212,706085343001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','athula_wijerathna','athulawijerathna@gmail.com','Athula Wijerathna','Homagama, Kelanigama,','Ginigathhena','Central Province','SRI LANKA','20688','094776552944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 04:23:43',0,NULL,3,1,2,1,NULL,'athula_wijerathna'),(14213,8881312432704730,111,'45w 110v x  2',1,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-08-04 04:38:24',0,NULL,3,0,3,1,'RA183622578CN ',' 是\r45w 110v x 8'),(14214,706421403001,110504251528,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','seinafolava','sanele.chadwick@gmail.com','Sanele Chadwick','4/1 Cross Street<br>Phillipstown','Christchurch','Canterbury','NEW ZEALAND','8011','+64274237847','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 04:48:23',0,NULL,3,1,3,1,'RA183622649CN ','seinafolava'),(14215,706423335001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1308',7.8,'hermeshine','truth2boricubano','boricubano2000@gmail.com','Karim Lopez','461 54th St','Brooklyn','NY','UNITED STATES','11220-3104','(347) 203-6157','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-04 05:01:06',0,NULL,3,1,1,1,NULL,'truth2boricubano'),(14216,748115151002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','kenthughes','khughes@ihug.com.au','Kent  Hughes','Unit 4<br>105-109 Lagoon Street','Narrabeen','New South Wales','AUSTRALIA','2101','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 05:10:44',0,NULL,3,1,2,1,NULL,'kenthughes'),(14217,707209767018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','fuzzballify','nick_fuzzball@hotmail.com','Nicholas Robinson','12 Berry Close','Mornington','Victoria','AUSTRALIA','3931','6159759072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 05:27:44',0,NULL,3,1,2,1,NULL,'fuzzballify'),(14218,812260316016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',2,'AD1122',13,'hutongstore','leshkinkoshkin','master@win-media.com','Alexei Borodin','Zaharova 45, 7','Krasnodar','','RUSSIAN FEDERATION','350007','9184696030','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 06:07:05',0,NULL,3,1,2,1,NULL,'leshkinkoshkin'),(14219,707266161018,280688523982,'High Quality Umbrella Softbox Reflector Studio 35\" 90cm',1,'AD1127',22.9,'photographyacc','dearlizer','elisamcdonald@bigpond.com','Elisa McDonald','1/17 Miami Shore Pde','Miami','Queensland','AUSTRALIA','4220','0417893962','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 07:11:12',0,NULL,3,1,3,1,'RA183622670CN ','dearlizer'),(14220,762278587017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','rick.helen418','rho96436@bigpond.net.au','Rick Hoult','12 Darnum St','Drouin','Victoria','AUSTRALIA','3818','0356252142','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,'','rick.helen418\rbackground support  $20'),(14221,707276351018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','carassiusproductions','jon.mather@carassiusproductions.com.au','Jon Mather','C/- Pocketphone<br>2/12 Kewdale Rd','Welshpool','Western Australia','AUSTRALIA','6056','0893653911','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 08:02:53',0,NULL,3,1,2,1,NULL,'carassiusproductions'),(14222,748144986002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','af_133','fedorov.isr@gmail.com','Alexander Fedorov','Batya Makov<br>7/3','Rehovot','','ISRAEL','76481','+972-52-2402789','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 08:06:29',0,NULL,3,1,3,1,'RA183622666CN ','af_133'),(14223,706454642001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','apgv10','vgor@i.ua','Victor Gorban','per. Ostrovskogo, 13','pgt. Pokrovske','obl Dnipropetrovska','UKRAINE','53600','5638-5-00-77','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 08:07:15',0,NULL,3,1,2,1,' ','apgv10'),(14224,748145829002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','p.petkow','plamen.petkow@gmail.com','Plamen Dyanov Petkov','24, Dimitar Spisarevski Str.','Sofia','Sofia','BULGARIA','1592','+359883320220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 08:10:14',0,NULL,3,1,3,1,'RA183622745CN ','p.petkow'),(14225,829604933015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',2,'AD1402',11,'hutongstore','cweeniebelnco','leedawson19@yahoo.co.uk','Lee Dawson','16 Brecon Avenue<br>Oswaldtwistle','Accrington','Lancashire','UNITED KINGDOM','BB5 4QS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 09:00:03',0,NULL,3,1,3,1,'RA183622723CN\r ','cweeniebelnco'),(14226,707303417018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','ryan_100','ryan282@hotmail.com','Ryan Watson','8 Hellcat Close','Mareeba','Queensland','AUSTRALIA','4880','0439157979','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 09:59:11',0,NULL,3,1,2,1,NULL,'ryan_100'),(14227,748193759002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','laisspol','laisspol@laposte.net','CHAMMING\'S GREGORY','Maison Iroumia, Appartement 1','AINHICE MONGELOS','Aquitaine','FRANCE','64220','06.16.99.65.90','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 11:42:45',0,NULL,3,1,3,1,'RA183622799CN\r ','laisspol'),(14228,707336241018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','vladimirzeonmaster','zeonmaster@yandex.ru','vladimir morgunov','kiev-32<br>post office box  №278','Kiev','ua','UKRAINE','01032','(050) 387  0299','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-04 12:05:50',0,NULL,3,1,3,1,'RA183622785CN ','vladimirzeonmaster'),(14229,762363347017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',35,'photographyacc','f_poulus','frank_poulus@hotmail.com','Frank Poulus','Schapenmeent<br>148','Almere','','NETHERLANDS','1357GN','0031652018253','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-04 12:49:05',0,NULL,3,0,3,1,'RA183622808CN ','f_poulus\rxxxl   （已入库）'),(14230,829691953015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','da-kin-fly','thefly@nildram.co.uk','Dan Pluck','Beazley, 9th Floor, Plantation Place South<br>60 Great Tower Street','London','London','UNITED KINGDOM','EC3R 5AD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 13:33:41',0,NULL,3,1,3,1,'RA183622710CN\r ','da-kin-fly\r英标'),(14231,748221696002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',2.48,'hermeshine','mik3427','info.janin@gmail.com','Mikael Janin','Via Roveglio 23','Salò','BS','ITALY','25087','3296732769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:39:28',0,NULL,3,1,17,0,NULL,'mik3427'),(14232,748223493002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','mik3427','info.janin@gmail.com','Mikael Janin','Via Roveglio 23','Salò','BS','ITALY','25087','3296732769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:39:27',0,NULL,3,1,17,0,NULL,'mik3427'),(14233,706530287001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','mik3427','info.janin@gmail.com','Mikael Janin','Via Roveglio 23','Salò','BS','ITALY','25087','3296732769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:39:28',0,NULL,3,1,17,0,NULL,'mik3427'),(14234,706530748001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','mik3427','info.janin@gmail.com','Mikael Janin','Via Roveglio 23','Salò','BS','ITALY','25087','3296732769','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 13:39:29',0,NULL,3,0,17,0,NULL,'mik3427'),(14235,748222063002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','mik3427','info.janin@gmail.com','Mikael Janin','Via Roveglio 23','Salò','BS','ITALY','25087','3296732769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:39:29',0,NULL,3,1,4,1,'YW866127846CN ','mik3427\r眼罩 D300      1\r3片装的滤镜袋     1\r天涯方形滤镜系列  星光镜  star8     1\r天涯方形滤镜系列  CPL      1\r背景架2mx2m  + 3个夹子      1\r1.6*2.1  黑色+白色背景布    2\r燕文告知无人领取  需要联系客户\r已发信'),(14236,706537854001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','man11021','manula@oi.com.br','gleicy kelly amaro de assis','rua fernando pessoa<br>560 itauna','sao gonçalo','rio de janeiro','BRAZIL','24473160','021 3605-8325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 13:56:05',0,NULL,3,0,2,1,NULL,'man11021\r欧标   '),(14237,748233572002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','a.buragohain','aburagohain@gmail.com','Apratim Buragohain','Samsung India Software Operations, JP Techno Park, 3/1 Miller\'s Road','Bangalore','Karnataka','INDIA','560052','9008127000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 14:08:18',0,NULL,3,1,3,1,'RA183622860CN ','a.buragohain\r客户要发票'),(14238,829705665015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','wbsdave_scuby','ebay@scuby.co.uk','David Walker','9 Burt Close','Fareham','Hampshire','UNITED KINGDOM','PO15 6FD','07843667518','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 14:10:41',0,NULL,3,1,2,1,NULL,'wbsdave_scuby'),(14239,762273046017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','nashy140957','nashy57@optusnet.com.au','Mrs V Nash','9 Avoca Crt<br>Werribee','Melbourne','Victoria','AUSTRALIA','3030','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 14:14:38',0,NULL,3,1,2,1,NULL,'nashy140957'),(14240,748258571002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','(+373) 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 15:24:50',0,NULL,3,1,3,1,'RA183622768CN ','vacarciucalexandru'),(14241,707397951018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','andreyk4564','fotokaj@gmail.com','Andrej Korenc','Cesta talcev 5/a','Logatec','','SLOVENIA','1370','0038641345187','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-04 15:25:17',0,NULL,3,1,2,1,NULL,'andreyk4564'),(14242,706596975001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','tizcar57','tcarmina@interfree.it','TIZIANO CARMINATI','VIA SAN LORENZO,1','ZOGNO','BG','ITALY','24019','0345 91154','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 16:59:48',0,NULL,3,1,3,1,'RA183622811CN ','tizcar57\rrepair tool   $12'),(14243,706631669001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 18:29:51',0,NULL,3,1,6,1,'EE495341207CN ','wikran'),(14244,706640259001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','i_gioielli_del_mare','info@igioiellidelmare.net','Gianmarco Cataldo','via Sabaudia 136','San Felice Circeo','LT','ITALY','04017','3389853782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 18:49:55',0,NULL,3,1,17,0,NULL,'i_gioielli_del_mare'),(14245,706643119001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','chrismwak','chris@mwakasisi.com','Chris Mwakasisi','PO Box 1655','Portage','MI','UNITED STATES','49081-1655','(734) 681-0195','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 18:56:59',0,NULL,3,1,17,0,NULL,'chrismwak'),(14246,706644652001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','chrismwak','chris@mwakasisi.com','Chris Mwakasisi','PO Box 1655','Portage','MI','UNITED STATES','49081-1655','(734) 681-0195','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-04 19:00:01',0,NULL,3,1,1,1,NULL,'chrismwak\r单灯头     1\r一转四 灯头     1'),(14247,706664861001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','rh-salty','salty1@gmail.com','Mike Penny','7621 Canvas Art Ter','Raleigh','NC','UNITED STATES','27617-8317','','NoPaymentFailure','CheckoutComplete','Other','2011-08-04 19:46:45',0,NULL,3,1,4,1,'YW866127850CN ','rh-salty\r灯泡是110v  的\r Lighting Kit   $28'),(14248,706665013001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','i_gioielli_del_mare','info@igioiellidelmare.net','Gianmarco Cataldo','via Sabaudia 136','San Felice Circeo','LT','ITALY','04017','3389853782','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-04 19:46:51',0,NULL,3,1,4,1,'YW866127861CN ','i_gioielli_del_mare\r圆形柔光棚 40cm     1\r三脚架 伟峰 wf-6662A+ 6160H 球台    1'),(14249,748375856002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',2,'AA1309',5.2,'hermeshine','pegasovidal','marcvida@gmail.com','Marcelo Vidal','Myrsnipeveien 53<br>7082 Kattem','Trodnheim','trondheim','NORWAY','7082','99630869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 20:23:49',0,NULL,3,1,2,1,NULL,'pegasovidal'),(14250,829914375015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','markusl524','markus@drinklist.org','Markus Linden','Solbacken 1','Gyttorp','','SWEDEN','713 72','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-04 21:28:22',0,NULL,3,1,3,1,'RA183622771CN ','markusl524'),(14251,829923919015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',7.75,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 21:41:36',0,NULL,3,1,17,0,NULL,'donald1970'),(14252,829922966015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','donald1970','vuorisellepostia@gmail.com','Marko Vuorinen','Öölanninkatu 4B 13','Turku','','FINLAND','20240','0415053945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 21:41:37',0,NULL,3,1,3,1,'RA183622895CN\r ','donald1970\r单灯头   欧标    1\r灯架  2m      1\r'),(14253,762592793017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','janet7824','jmdampney@bigpond.com','Janet Dampney','Junefield','Narrabri','New South Wales','AUSTRALIA','2390','0267933134','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-04 22:21:59',0,NULL,3,1,3,1,'RA183622900CN ','janet7824'),(14254,829944661015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','leeroberts07731','leeroberts1980@live.co.uk','Mr Lee Roberts','36 Watkin street','Rochdale','Lancashire','UNITED KINGDOM','ol16 4uh','07731321117','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-04 22:35:45',0,NULL,3,1,2,1,NULL,'leeroberts07731'),(14255,707584054018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','global_ebayer','global.ebayer@gmail.com','Eduardo Oliveros Martin','C/ Juan de Juanes 10, 2C Centro','Mostoles','Madrid','SPAIN','28933','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-04 23:19:10',0,NULL,3,1,4,1,'YW866127883CN ','global_ebayer'),(14256,748437933002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','vichyblanca','buriarte2@gmail.com','Patricia Herrero','C/ Porto Lagos Nº7, Bajo C, Escalera Centro','Alcorcón','Madrid','SPAIN','28924','650759897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-04 23:27:12',0,NULL,3,1,2,1,NULL,'vichyblanca'),(14257,829968228015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',27,'hutongstore','mcys42','mohamed.khennoussi@hotmail.fr','Mohamed Khennoussi','9 rue des myrtilles','Le chambon feugerolles','Rhône-Alpes','FRANCE','42500','04.77.61.61.85.','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 23:55:16',0,NULL,3,1,17,0,NULL,'mcys42'),(14258,829949849015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','mcys42','mohamed.khennoussi@hotmail.fr','Mohamed Khennoussi','9 rue des myrtilles','Le chambon feugerolles','Rhône-Alpes','FRANCE','42500','04.77.61.61.85.','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-04 23:55:17',0,NULL,3,1,3,1,'RA183622842CN ','mcys42\r柔光箱 60-60cm  四灯头   欧标    1\r柔光箱 50-70cm 单灯头    欧标    1'),(14259,706752107001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','cesherr','c.herradura@hotmail.com','Cesar Herradura de la Cruz','C/Empecinado 35 5ºA','Móstoles','Madrid','SPAIN','28937','687012911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 00:34:57',0,NULL,3,1,4,1,'YW866127872CN ','cesherr\r Tripod   $22'),(14260,748454182002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','emref541','ferme@fibertel.com.ar','Alberto Ferme','Juan Francisco Segui 3900 3P','Capital Federal','Buenos Aires','ARGENTINA','1425','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 00:39:51',0,NULL,3,1,2,1,NULL,'emref541'),(14261,8881312507966972,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',21.05,'aliexpress','1003862896','gal@variance.co.il','Gal Obercyger	','P.O BOX 10962','RAMAT GAN	','ISRAEL','ISRAEL','52009','+972 54 5960959',NULL,NULL,NULL,'2011-08-05 01:32:46',0,NULL,3,1,3,1,'RA183622935CN\r ',''),(14262,8881312508193704,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',15.58,'aliexpress','1003861827','12ee12@gmail.com','Roman Lutskin ','Novomihalkovsky 3rd Avenue, 1 - 4','Moscow','','RUSSIAN FEDERATION','125008','+7 495 9099992153',NULL,NULL,NULL,'2011-08-05 01:36:33',0,NULL,3,1,3,1,'RA183622944CN\r ',''),(14282,812824559016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',1.5,'hutongstore','lokassfr','raphael.voye@orange.fr','VOYE Raphael','10 rue du moulin','FAUVERNEY','Bourgogne','FRANCE','21110','0380638864','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 11:09:33',0,NULL,3,1,2,1,' ','lokassfr'),(14263,8881312509726872,111,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',0,'AA3221',0,'hermeshine','le_khan','del.ireland@gmail.com','Dmitriy Lekhanov','Stroiteley st. 26 - 94','Perm','Permskiy Kray','RUSSIAN FEDERATION','614097','89028386326',NULL,NULL,NULL,'2011-08-05 02:02:06',0,NULL,3,1,3,1,'RA183622825CN ','补发,(第一次发的坏了,让他退回来)'),(14264,8881312510252095,111,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',0,'hermeshine','egovital','vitalforte@yahoo.ie','Michael Cristea','Copacabana 38/31','Kalsdorf bei Graz','','AUSTRIA','8401','',NULL,NULL,NULL,'2011-08-05 02:10:52',0,NULL,3,1,3,1,'RA183622856CN ','补发,(第一次少发了) '),(14265,8881312512689822,111,'50-70cm 单灯头 柔光箱  上的白色柔光罩',0,'',0,'hutongstore','coolrk1984','mischa_kojine@web.de','Michael Kojine','Randowstrasse 12','Hamburg','','GERMANY','22547','',NULL,NULL,NULL,'2011-08-05 02:51:29',0,NULL,3,0,3,1,'RA183622839CN ','补发(前一次的里面少了这个东西) '),(14266,748490386002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','myniftybooks','chuck@camroux.com','Chuck Camroux','PO Box 2006','Niagara Falls','NY','UNITED STATES','14302','(905) 356-7336','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 03:15:11',0,NULL,3,1,1,1,NULL,'myniftybooks'),(14267,8881312515882686,111,'普通柔光伞x1; 301p接收器x2',0,'',0,'cnfaner','medgtal','alanoir@free.fr','Arnaud LANOIR','12B, route de Feydit<br>Saint Médard en ','Jalles ','','FRANCE','33160','',NULL,NULL,NULL,'2011-08-05 03:44:42',0,NULL,3,1,3,1,'RA183622873CN\r ','补发(前一次的伞脏了,接收器少发了2套)'),(14268,706801957001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','+7 912 939 43 61','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 04:42:34',0,NULL,3,0,3,1,'RA183622887CN\r ','motorfoto\r55 rubber       2\r58 rubber       1\r62 rubber       1\r67 rubber       2\r72 rubber       2\r77  rubber       2\r（已入库）'),(14269,762684028017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','zzrmags','info@canvasmegoria.com','Magda Socha','ul. Hanki Sawickiej 1/1','Tulowice','opolskie','POLAND','49-130','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-05 04:43:18',0,NULL,3,1,2,1,NULL,'zzrmags'),(14270,707656801018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',4,'AKT014',156,'photographyacc','kiss_my_aesthetics','philasophigas@gmail.com','Philip Griffiths','54 Railway Avenue','Austinmer','New South Wales','AUSTRALIA','2515','0422996038','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 04:52:57',0,NULL,3,1,4,1,'YW866127824CN ','kiss_my_aesthetics'),(14271,707656885018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',10.51,'photographyacc','frankh_2007','frankhiggins@bigpond.com','Frank Higgins','74 Main Street','Gordon','Victoria','AUSTRALIA','3345','0353689959','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 04:53:08',0,NULL,3,1,2,1,NULL,'frankh_2007\r再发一个canon 58 反接环（已入库）'),(14272,706807198001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ntbirder','mccrie@gmail.com','Niven McCrie','Po Box 41382','Casuarina','Northern Territory','AUSTRALIA','0811','0889451130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 05:12:54',0,NULL,3,0,2,1,NULL,'ntbirder\r1.6*2.1 黑色背景布    1'),(14273,8881312528022635,0,'New JYC-N3 Wireless Remote Control for Nikon D90 D7000',0,'',0,'photographyacc','docray55','rgwhitmire@hotmail.com','Raymond Whitmire','3501 Royal Crest Dr E','The Dalles','OR','UNITED STATES','97058-9711','',NULL,NULL,NULL,'2011-08-05 07:07:02',0,NULL,5,1,1,1,NULL,'补发, 爵影无线N3的接收器(第一次发的坏了)\r(爵影缺货,改发永诺的)\r08-09\rLK031644646CN\r已经发货了  但是点不了'),(14274,748523389002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','trinitron_sony','konstantinosgikas@hotmail.com','KONSTANTINOS GIKAS','MARATHONOS 6','AHARNAI','ATTIKH','GREECE','13671','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 07:33:30',0,NULL,3,1,3,1,'RA183622958CN ','trinitron_sony'),(14275,748536830002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dk5ax','markus_hammelmann@msn.com','Markus Hammelmann','August-Herold-Weg 7','Niedernhall','','GERMANY','74676','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 07:48:57',0,NULL,3,1,2,1,NULL,'dk5ax'),(14276,762718354017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','lelebebbel','dirk@menticid.com','Dirk Mohrmann','23 Hardy Street<br>APT 1','Ingham','Queensland','AUSTRALIA','4850','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 08:00:12',0,NULL,3,1,2,1,NULL,'lelebebbel'),(14277,748539462002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','henryhenry0363','hazenleger@skynet.be','Henry de Haas','Oude Dijk 31','Nuenen','NB','NETHERLANDS','5674 TT','0031653358229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 08:02:36',0,NULL,3,1,17,0,NULL,'henryhenry0363'),(14278,748300737002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','henryhenry0363','hazenleger@skynet.be','Henry de Haas','Oude Dijk 31','Nuenen','NB','NETHERLANDS','5674 TT','0031653358229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 08:02:37',0,NULL,3,1,2,1,NULL,'henryhenry0363\rNIKON 镜头盖 77mm     2'),(14279,830088907015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'AA2203',2.75,'hutongstore','tipsylala88','lala880778@gmail.com','Laura Garnham','5, Rouge Val Estate<br>Rouge Rue','St. Peter Port','Channel Islands','UNITED KINGDOM','GY1 1ZB','07839212377','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 08:15:32',0,NULL,3,1,2,1,NULL,'tipsylala88'),(14280,748549353002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','1.10.100.1000','pha10100@yahoo.com.au','P Asel','100 rocky gully road','murray bridge','South Australia','AUSTRALIA','5253','0885310846','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-05 08:50:30',0,NULL,3,0,3,1,'RA183622975CN ','1.10.100.1000\r3xl\r已入库'),(14281,707716307018,280663394007,'500W Photo Studio Continuous Light Kit SoftBox boom arm',4,'AKT064',332,'photographyacc','bougsy','bougsy1@hotmail.com','Andrew Bogan','52 Cedar Street<br>Greenslopes','Brisbane','Queensland','AUSTRALIA','4120','0732752622','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-08-05 09:56:56',0,NULL,3,1,4,1,'YW866127732CN ','bougsy\r注意是四套\r澳标'),(14283,748595129002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-05 12:08:49',0,NULL,3,1,3,1,'RA183622913CN\r ','mariomarques.com.br\r申报gift   申报低值'),(14284,707752157018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','bogan777','andrewlonghurst@dodo.com.au','Andrew Longhurst','144 Herdsman Parade','Wembley','Western Australia','AUSTRALIA','6014','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-05 12:14:07',0,NULL,3,1,4,1,'YW866127721CN ','bogan777\r1.6*2.1  白色背景布   1\r1.6*2.1   黑色背景布  1'),(14285,748600041002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','gianmatte00','gianmatteo.fabbri@gmail.com','Gianmatteo Fabbri c/o Technogym SPA','G. Perticari, 20','Gambettola','FO','ITALY','47035','334 6688695','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 12:27:52',0,NULL,3,1,2,1,NULL,'gianmatte00'),(14286,762790599017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',3,'AA1310',17.85,'photographyacc','wpratt007','elenastoys@gmail.com','Elena Privalova','10/37 Murtha Drive<br>Elanora','Gold Coast','Queensland','AUSTRALIA','4221','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 12:36:54',0,NULL,3,1,2,1,NULL,'wpratt007'),(14287,748606788002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','larrytarakan','larry_tarakan@hotmail.com','Kirill Terentev','52 Moscovskiy Str. App.137','Cheboksary','Chuvashia','RUSSIAN FEDERATION','428017','(8352)453598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 12:52:58',0,NULL,3,1,2,1,NULL,'larrytarakan'),(14288,762797208017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','offand','andsoff@gmail.com','Andrew Offield','284 Warringah Road','Beacon Hill','New South Wales','AUSTRALIA','2100','0292400745','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 12:59:40',0,NULL,3,1,2,1,NULL,'offand'),(14289,830176909015,250600315208,'Flash Softbox Diffuser for external flash SB800 580EX ',2,'AB3302',17.6,'hutongstore','larscph123','lars@landligt.dk','Lars Knudsen','Bygränd 4','Malmö','S','SWEDEN','212 36','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 13:08:53',0,NULL,3,1,3,1,'RA183621189CN\r ','larscph123'),(14290,762806908017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','arielagu','ariel66@argentina.com','Ariel Marconi','Prilidiano Pueyrredon 2989 PB F1','Martinez','Buenos Aires','ARGENTINA','1640','(5411)4721-6282','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-05 13:31:29',0,NULL,3,1,2,1,NULL,'arielagu'),(14291,748618631002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','mpshed','myrkopiche@gmail.com','Myrko Piché','803 Jean-Plouf','Boucherville','QC','CANADA','J4B 3G9','(514) 833-3969','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 13:35:03',0,NULL,3,1,2,1,NULL,'mpshed'),(14292,762823137017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','branislavbuzek','branislavbuzek@zoznam.sk','Branislav Buzek','Legionarska 15','Zilina','','SLOVAK REPUBLIC','010 01','+421911415917','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-05 14:21:58',0,NULL,3,1,2,1,NULL,'branislavbuzek\r欧标'),(14293,830225898015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',42.8,'hutongstore','anin464','nina_grubeck@hotmail.com','Nina Grubeck','Töllergasse 19','Wien','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-05 15:21:10',0,NULL,3,1,4,1,'YW866127710CN ','anin464\r'),(14294,830228701015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.98,'hutongstore','howiemarilyn','howiemarsh@hotmail.com','H. Marsh','29 Clarkson Road<br>Lingwood','Norwich','Norfolk','UNITED KINGDOM','NR13 4BA','01603211414','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 15:28:25',0,NULL,3,1,2,1,NULL,'howiemarilyn'),(14295,830233640015,250599949620,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',17,'hutongstore','filipecus','filipev@gmail.com','Filipe Vicente','Rua Coronel Bento Roma, nº 53, 2º dir','Lisboa','','PORTUGAL','1700-121','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 15:41:01',0,NULL,3,1,3,1,'RA183621192CN\r ','filipecus'),(14296,748674068002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','ram3an','bion2000@mail.ru','Roman Bugrov','30/d Internacionalynaja Str., Apt. 12','Tambov','Tambov reg','RUSSIAN FEDERATION','392000','+79027231030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 16:32:17',0,NULL,3,1,2,1,NULL,'ram3an'),(14297,762911995017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',68,'photographyacc','wafafleur','info@wafadesigns.com','wafa amad','22/10<br>pavonia link','clakson','Western Australia','AUSTRALIA','6064','0400005656','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-05 18:13:59',0,NULL,3,1,4,1,'YW866127706CN ','wafafleur\r澳标\r'),(14298,748563816002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','david.chris','sh4do@hotmail.com','David Christine','35, St thérèse<br>Plaisance','Rose-Hill','','MAURITIUS','mp100','(230) 4641732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 18:41:16',0,NULL,3,1,3,1,'RA183621232CN\r ','david.chris'),(14299,707027686001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 19:23:40',0,NULL,3,1,2,1,NULL,'mellogabriel'),(14300,748764463002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','eitantene','eitan.tene@gmail.com','Eitan Tene','11, Leshem St.','Hod Ha-Sharon','','ISRAEL','45042','+972-54-2493257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 20:22:35',0,NULL,3,1,2,1,NULL,'eitantene'),(14301,707055656001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','catsee2.0','kecskes.tamas.87@gmail.com','Tamás Kecskés','Álmos str. 5.','Jászalsószentgyörgy','Hungary','HUNGARY','H-5054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 20:26:58',0,NULL,3,1,2,1,NULL,'catsee2.0'),(14302,762975967017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','bst1t','trevorsmall@bigpond.com','Trevor Small','59 Willara Street','Carseldine','Queensland','AUSTRALIA','4034','0732633913','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-05 20:44:16',0,NULL,3,1,17,0,NULL,'bst1t'),(14303,830394094015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','xshadowqx','ondra.zde@gmail.com','Ondra Zdenek','Francouzska 6018/63','Ostrava - Poruba','výchozí','CZECH REPUBLIC','70800','0420737140410','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-05 21:21:57',0,NULL,3,1,2,1,NULL,'xshadowqx'),(14304,707082524001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','saychzzz67','saychzzz@yahoo.com','Lynne Shelton','2765 Mill Creek Rd','Chatham','VA','UNITED STATES','24531-4476','(434) 432-9247','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-05 21:45:24',0,NULL,3,1,1,1,' ','saychzzz67'),(14305,707084532001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','handy_man_jeff','handy_man_jeff@hotmail.com','Jeff Clark','526 McGowan Avenue','Kamloops','BC','CANADA','V2B 2P6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-05 21:51:10',0,NULL,3,1,2,1,NULL,'handy_man_jeff\r客户要浅蓝色'),(14306,813108865016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','rocka09','rocka109@o2.co.uk','Wayne Roe','201 St Margarets Road','Birmingham','West Midlands','UNITED KINGDOM','b82be','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 22:41:02',0,NULL,3,1,2,1,NULL,'rocka09'),(14307,813121627016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','sithzombie','allegra_geller77@hotmail.co.uk','Alan Hall','84 Watts Street<br>Levenshulme','Manchester','Lancashire','UNITED KINGDOM','M19 2TS','01614421205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-05 23:26:39',0,NULL,3,1,3,1,'RA183621246CN\r ','sithzombie'),(14308,707122271001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','nickvango','nickv7@optusnet.com.au','Nick Vangopoulos','25 Grange Rd Lower Mitcham','Adelaide','South Australia','AUSTRALIA','5062','0882725431','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 00:30:40',0,NULL,3,1,4,1,'YW866127695CN ','nickvango\r已收到'),(14309,706030640001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','weber88204','kylemcaulayweber@gmail.com','kyle mcaulay-weber','34 rushmore rd','winnipeg','MB','CANADA','R2G 3L6','(204) 663-0037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 00:56:50',0,NULL,3,1,2,1,NULL,'weber88204'),(14310,748841352002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','sarah1432','sarahtsubaa@hotmail.com','sarah Al-Subaa','Taruot','QATIF','Qatif','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 01:08:06',0,NULL,3,1,3,1,'RA183621158CN\r ','sarah1432\r1.6*2.1白色背景布   1\rRA183621060CN\r'),(14311,8881312594354470,111,'40\'x 60\' Collapsible 5-in-1 Photo Reflector Oval Disc',0,'AC3201',0,'hutongstore','agreis81','agreis@agreis.hu','Bela Forgo','Fóti út 122','Budapest','Budapest','HUNGARY','H-1046','36704584638',NULL,NULL,NULL,'2011-08-06 01:32:34',0,NULL,3,1,3,1,'RA183621011CN\r ','补发 (第一次发的被退回来了,补交了$17运费)\r'),(14312,748855802002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','katelyn_621','baby_karen_2007@yahoo.com','Karen Castaneda','301 Prairie Ridge dr','woodstock','IL','UNITED STATES','60098-4193','(224) 201-0729','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 02:13:17',0,NULL,3,1,1,1,NULL,'katelyn_621\r已入库'),(14313,763072562017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','hydeyhihi','tammyhyde@bigpond.com','Benjamin Hyde','PO Box 2892','Emerald','Queensland','AUSTRALIA','4720','0431184605','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 02:45:28',0,NULL,3,1,2,1,NULL,'hydeyhihi'),(14314,748863221002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pablorwc','pablo206@live.com.ar','Pablo Andres Barraza','Diaz Velez 2263','Benavidez','Buenos Aires','ARGENTINA','1621','47361631','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 02:53:24',0,NULL,3,0,17,0,NULL,'pablorwc'),(14315,748862505002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pablorwc','pablo206@live.com.ar','Pablo Andres Barraza','Diaz Velez 2263','Benavidez','Buenos Aires','ARGENTINA','1621','47361631','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 02:53:25',0,NULL,3,0,3,1,'RA183621175CN\r ','pablorwc\rcanon 老款背心 xl    2\r已入库'),(14316,763079459017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',7.28,'photographyacc','ca069425','cpa-001@hotmail.com','Colin Ansell','Traders Hotel Suite 923<br>68 Zhong Hua Road,He Ping District','Shenyang','辽宁省','CHINA','110001','(139) 403-4872 ext.: 9','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-06 03:42:30',0,NULL,5,1,18,0,NULL,'ca069425'),(14317,748887781002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','xsbarnatj','barni@centrum.cz','Jan Barnat','Boskovicka<br>1382/2','Brno','The Czech Republic','CZECH REPUBLIC','62100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 05:19:47',0,NULL,3,1,2,1,NULL,'xsbarnatj'),(14318,708041781018,280685224536,'50x70cm 20\"x28\" Folding Easy Soft box  E27 Bulb Socket',1,'AE2401',35,'photographyacc','zaral2','laura.zahra@mh.org.au','laura zahra','52 Queen street<br>altona','melbourne','Victoria','AUSTRALIA','3018','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 05:24:24',0,NULL,5,1,18,0,NULL,'zaral2\r澳标'),(14319,707177532001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','galiona','meggi-grey@yandex.ru','Galina Tcvetkova','ul Veresaeva  16 kv 69','Tula','','RUSSIAN FEDERATION','300034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 05:47:42',0,NULL,3,1,2,1,NULL,'galiona'),(14320,707185848001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','mehmettoros','info@fotobilen.com','Hakan Bilen','Nar Cad. No:55','Nevşehir','MERKEZ','TURKEY','50100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 06:44:10',0,NULL,3,1,3,1,'RA183621127CN\r ','mehmettoros\r已入库'),(14321,830580964015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',2,'AC1201',4.36,'hutongstore','manmadechickens','spiders_0705@hotmail.com','Jack James','8 Hampton Street<br>Semilong','Northampton','Northamptonshire','UNITED KINGDOM','NN1 2PH','07733424433','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 09:40:04',0,NULL,3,1,2,1,' ','manmadechickens'),(14322,813246713016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','(just4fun)','tony@banh.nu','Tony Banh','Ahrenbergsgatan 14A','Göteborg','','SWEDEN','41673','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 09:42:29',0,NULL,3,1,3,1,'RA183621095CN ','(just4fun)'),(14323,830586658015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',20,'hutongstore','judazuk','peter.lennartsson@gmail.com','Peter J Lennartsson','Ronnebergavagen 8A','Eslov','Skane','SWEDEN','24134','+46763191343','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 09:58:26',0,NULL,3,1,3,1,'RA183621025CN\r ','judazuk\r欧标'),(14324,830589006015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','martinsmith99','orders@ms-imaging.co.uk','MR M Smith','Liza\'s Cottage<br>Earthcott Green','South Gloucestershire','Gloucestershire','UNITED KINGDOM','BS35 3TE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 10:05:10',0,NULL,3,1,2,1,NULL,'martinsmith99'),(14325,830583736015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.8,'hutongstore','cjwestmoreland','caestra2000-cjwebay@yahoo.co.uk','Chris Westmoreland','25 Hudson Way','Tadcaster','North Yorkshire','UNITED KINGDOM','LS24 8JF','01937836124','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 10:08:48',0,NULL,3,1,2,1,NULL,'cjwestmoreland'),(14326,763165356017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','sydney_adam','adamsebire@gmail.com','Adam Sebire','3 Agar Steps\r\nObservatory Hill<br>(above 110 Kent St)','Sydney','New South Wales','AUSTRALIA','2000','0292416168','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 10:18:39',0,NULL,3,1,2,1,NULL,'sydney_adam'),(14327,763166015017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','sifahsaeed','sifah.saeed@gmail.com','sifah saeed','Muart & a design pvt ltd<br>M.Dhaannaage 4th floor','Male\'','Maldives','MALDIVES','20255','+9607772775','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-06 10:23:34',0,NULL,3,1,2,1,NULL,'sifahsaeed'),(14328,708123026018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','analisa_m','analisa_mathrick@hotmail.com','Analisa Mathrick','1B Alwyn Street','Bayswater','Victoria','AUSTRALIA','3153','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 10:26:47',0,NULL,3,1,2,1,NULL,'analisa_m'),(14329,830598453015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','bicester2003','kevin.phare@ntlworld.com','Kevin Phare','21 Lyneham Road','Bicester','Oxfordshire','UNITED KINGDOM','OX264FN','01869601699','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 10:38:53',0,NULL,3,1,2,1,NULL,'bicester2003'),(14330,708130719018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',21.5,'photographyacc','jaykay3bay','anime_lova12@hotmail.com','Jason Kan','67 Springs road Clayton South','Melbourne','Victoria','AUSTRALIA','3169','0395431464','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-06 10:55:21',0,NULL,3,1,3,1,'RA183621201CN\r ','jaykay3bay'),(14331,707259433001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 12:04:30',0,NULL,3,1,17,0,NULL,'goinha2011'),(14332,707259134001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-06 12:04:31',0,NULL,3,1,3,1,'RA183621042CN\r ','goinha2011\r单灯头  欧标     1\r肩架      1\r新地址 \rGLORIA MARIA MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044\r  申报   gift     注意字体\r'),(14333,708149604018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',6.6,'photographyacc','braydos_kd','cricketer_14@hotmail.com','brayden kershaw-donkers','10 wassell place<br>Lindisfarne','Hobart','Tasmania','AUSTRALIA','7015','0362443050','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-06 12:09:59',0,NULL,3,1,2,1,NULL,'braydos_kd'),(14334,707818871018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','jubraga2011','juliebraga@hotmail.com','juliana ferrie','12 groton school rd','ayer','MA','UNITED STATES','01432-1008','(978) 615-3188','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-06 12:37:47',0,NULL,3,1,1,1,NULL,'jubraga2011\r已入库\r75周年那款'),(14335,707286907001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','kathleen9308','kathhughes7@gmail.com','Brian Hughes','Cross Tree Cottage The Green<br>East Hanney','Wantage','Oxfordshire','UNITED KINGDOM','OX12 0HQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 13:40:19',0,NULL,3,1,2,1,NULL,'kathleen9308'),(14336,763237530017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','glloret75','gaspar.lloret@gmail.com','Gaspar Lloret Amoros','c/ Pizarro 30','San Vicente del Raspeig','Comunidad Valenciana','SPAIN','03690','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-06 14:11:40',0,NULL,3,1,2,1,NULL,'glloret75'),(14337,749049675002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 15:57:14',0,NULL,3,1,2,1,NULL,'galtamirgal'),(14338,813419618016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','neilfwilson','n.f.wilson@btinternet.com','Neil Wilson','25 Newark Crescent','Nottingham','Nottinghamshire','UNITED KINGDOM','NG2 4NZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 16:22:01',0,NULL,3,1,2,1,NULL,'neilfwilson'),(14339,707342874001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','manur2009','manuelrivasfresno@yahoo.es','MANUEL RIVAS DEL FRESNO','ARQUITECTO REGUERA 3-6A','OVIEDO','Asturias','SPAIN','33004','629934347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 16:22:02',0,NULL,3,1,2,1,NULL,'manur2009'),(14340,749065270002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ty5603def45','gasha01@hotmail.com','Julie Laflamme','11705, rue Linteau','Québec','QC','CANADA','G2B 3V4','(418) 915-3460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 16:37:55',0,NULL,3,1,3,1,'RA183622989CN\r ','ty5603def45'),(14341,830754396015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','shuv2000','shuv2000@gmail.com','Gregory Bauchau','Rue R. Christiaens 12','Brussels','Brussels','BELGIUM','1160','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 16:58:51',0,NULL,3,1,2,1,NULL,'shuv2000'),(14342,707378763001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','homerogonzalez','hgonza2@tampabay.rr.com','Homero Gonzalez','4307 W Bird St','Tampa','FL','UNITED STATES','33614-2507','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-06 17:50:16',0,NULL,3,1,1,1,NULL,'homerogonzalez'),(14343,749113963002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','natpen','natsharpen@verizon.net','Nathan Pendleton','615 Crossfield Cir','Venice','FL','UNITED STATES','34293-4353','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-06 18:37:43',0,NULL,3,1,1,1,NULL,'natpen'),(14344,813535470016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','burty_55ob','lee_burton2000@yahoo.com','Lee Burton','8 Arnhem Green','Dorchester','Dorset','UNITED KINGDOM','DT1 2PS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 20:06:12',0,NULL,3,1,2,1,NULL,'burty_55ob'),(14345,830870808015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 20:41:55',0,NULL,3,1,17,0,NULL,'humanprofile'),(14346,813552985016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',54,'hutongstore','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 20:41:56',0,NULL,3,1,4,1,'YW866127684CN ','humanprofile\r欧标\r除了c 里的再发\r肩架   1\rLighting Kit   $28\r已收到\r'),(14347,830885010015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','dianer40','dianerussell64@talktalk.net','Diane Russell','3 Lanfine View','Darvel','East Ayrshire','UNITED KINGDOM','KA170FE','01560321034','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-06 21:13:19',0,NULL,3,1,3,1,'RA183621039CN\r ','dianer40'),(14348,707468187001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',2,'AA1214',15.96,'hermeshine','teamkvs','o5hiftgear@yahoo.com','sary sor','2526 hayden brook dr','stockton','CA','UNITED STATES','95212-2797','(209) 337-8379','NoPaymentFailure','CheckoutComplete','Other','2011-08-06 21:37:13',0,NULL,3,1,1,1,NULL,'teamkvs'),(14349,707471740001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',3,'AA1213',8.97,'hermeshine','ggwolf22ruth','tuty2t@gmail.com','Ruth Blima','Nahal Poleg 1/5<br>0','Tzur Ytzhak','no','ISRAEL','45808','+972528969483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 21:47:06',0,NULL,3,1,2,1,NULL,'ggwolf22ruth'),(14350,830898596015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','petteri_t','petteri.teikari@gmail.com','Petteri TEIKARI','7, Rue Diderot<br>Digicode: 893A / 6702','Lyon','Rhône-Alpes','FRANCE','69001','0033646649850','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 21:47:10',0,NULL,3,1,17,0,NULL,'petteri_t'),(14351,830898597015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',2,'AE3401',31.98,'hutongstore','petteri_t','petteri.teikari@gmail.com','Petteri TEIKARI','7, Rue Diderot<br>Digicode: 893A / 6702','Lyon','Rhône-Alpes','FRANCE','69001','0033646649850','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-06 21:47:11',0,NULL,3,1,17,0,NULL,'petteri_t'),(14352,813581687016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE3102',17.7,'hutongstore','petteri_t','petteri.teikari@gmail.com','Petteri TEIKARI','7, Rue Diderot<br>Digicode: 893A / 6702','Lyon','Rhône-Alpes','FRANCE','69001','0033646649850','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-06 21:47:12',0,NULL,3,1,4,1,'YW866127673CN ','petteri_t\rCANON 镜头盖  58mm    1\r灯架  2m     2\r大力夹     3\rlight stand   $22  '),(14353,707501483001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 23:38:09',0,NULL,3,1,5,1,'CP235771623CN ','denisdryashkin'),(14354,707501737001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','davidmatt123','boxfamil@bigpond.net.au','David Box','30 Barnard Street','Beechworth','Victoria','AUSTRALIA','3747','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-06 23:38:57',0,NULL,3,1,2,1,NULL,'davidmatt123'),(14355,708423329018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','crackers450','laurencemccracken@yahoo.com.au','Laurence C McCracken','36 Fitzgerald St','Wentworth Falls','New South Wales','AUSTRALIA','2782','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 00:35:57',0,NULL,3,1,3,1,'RA183622927CN\r ','crackers450'),(14356,707522511001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','sfbay.jon','jon.littell@gmail.com','Jon Littell','1382 Hampshire St','San Francisco','CA','UNITED STATES','94110-4228','','NoPaymentFailure','CheckoutComplete','Other','2011-08-07 01:13:15',0,NULL,3,1,1,1,NULL,'sfbay.jon'),(14357,763486634017,270751512053,'YongNuo 3m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AB3320',28.99,'photographyacc','ca1386','cay1386@yahoo.com','Derek Yu','Tim\'s Watches and Jewellery. Koisk K09 Centre Court<br>Westfield Penrith','Penrith','New South Wales','AUSTRALIA','2750','0416041387','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-08-07 01:19:58',0,NULL,3,1,3,1,'RA183621113CN\r ','ca1386'),(14358,707530691001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cardue2011','cardue57@hotmail.com','carlos dueñas','doblas 505 4 B','capital federal','buenos aires','ARGENTINA','1424','01149220402','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,0,2,1,NULL,'cardue2011\r1.6*2.1  黑色背景布     1'),(14359,749275166002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','p00d00','poodoodoot@gmail.com','Derrick Lai','1912 NW 86th Cir','Vancouver','WA','UNITED STATES','98665-6018','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-07 04:18:55',0,NULL,3,1,1,1,NULL,'p00d00'),(14360,707569303001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','subaru_ca','aat928@yahoo.ca','Calvin Lau','8200, Dalemore Road','Richmond','BC','CANADA','V7C 2A6','(604) 889-0237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 05:26:16',0,NULL,3,1,2,1,NULL,'subaru_ca'),(14361,763538791017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','bitsnbobs57','gallopin57@gmail.com','Steve Hamilton','28 Norfolk Cres','Frankston North','Victoria','AUSTRALIA','3200','0448690229','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 05:38:16',0,NULL,3,1,2,1,NULL,'bitsnbobs57'),(14362,708485626018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','raymondellington','rhaynes.tas@gmail.com','Polymath Professionals (Tas)','5 Ellington Rd','Sandy Bay','Tasmania','AUSTRALIA','7005','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 05:56:17',0,NULL,3,1,4,1,'YW866127662CN ','raymondellington\rLight Stand  $22\r燕文告知需要确认收件方收到货没有   \r需要给客户写信确认一下受到\r 已收到\r'),(14363,749294383002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','6126alain','carouillon@orange.fr','Alain Rouillon','res la boisseliere,Bat 1,401 av de la cauquiere','Cogolin','Provence-Alpes-Côte d\'Azur','FRANCE','83310','04 94 40 17 08','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 06:21:09',0,NULL,3,1,2,1,NULL,'6126alain'),(14364,831033432015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','aartau','aarne.taube@gmail.com','Aarne Taube','Kiiminginpolku 19','Oulu','','FINLAND','90570','+358405565889','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-07 06:32:36',0,NULL,3,1,4,1,'YW866127780CN ','aartau\rlight stand   $22\r燕文告之无人领取 需要联系客户\r已收到'),(14365,708508533018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','aussieblueheeler','narellewinter@hotmail.com','Narelle  Josling','13 Roberta St','TUMBI UMBI ','New South Wales','AUSTRALIA','2261','0243882881','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 07:59:59',0,NULL,3,1,3,1,'RA183621657CN\r ','aussieblueheeler\r除了c 里面的再发\r49cm 接口环    1\r82cm 接口环    1\r广角托架     1\r已入库'),(14366,813750748016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',3,'AD1122',19.5,'hutongstore','ehp764','infoprint@monornet.hu','Tibor Szaniszlo','Szechenyi 42/a','Ullo','Pestmegye','HUNGARY','2225','(36-20)3967256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 08:33:39',0,NULL,3,1,17,0,NULL,'ehp764'),(14367,831064725015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',2,'AD1402',11,'hutongstore','ehp764','infoprint@monornet.hu','Tibor Szaniszlo','Szechenyi 42/a','Ullo','Pestmegye','HUNGARY','2225','(36-20)3967256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 08:33:39',0,NULL,3,1,17,0,NULL,'ehp764'),(14368,831062879015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','ehp764','infoprint@monornet.hu','Tibor Szaniszlo','Szechenyi 42/a','Ullo','Pestmegye','HUNGARY','2225','(36-20)3967256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 08:33:40',0,NULL,3,0,17,0,NULL,'ehp764'),(14369,831063939015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',3,'AE3401',48,'hutongstore','ehp764','infoprint@monornet.hu','Tibor Szaniszlo','Szechenyi 42/a','Ullo','Pestmegye','HUNGARY','2225','(36-20)3967256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 08:33:40',0,NULL,3,1,17,0,NULL,'ehp764'),(14370,813746080016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','ehp764','infoprint@monornet.hu','Tibor Szaniszlo','Szechenyi 42/a','Ullo','Pestmegye','HUNGARY','2225','(36-20)3967256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 08:33:41',0,NULL,3,1,5,1,'CP235771447CN ','ehp764\r闪光灯D座     3\r柔光伞     2\r反光板支架     1\r灯架  2m        3\r新款厚的灯架包     1'),(14371,708538298018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','drneolao','leo@escobar.id.au','Leonardo Escobar','19 Daintree Loop<br>Ellenbrook','Perth','Western Australia','AUSTRALIA','6069','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 09:28:21',0,NULL,3,1,3,1,'RA183621073CN\r ','drneolao'),(14372,763606328017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','kenji.kwok1','kenji.kwok@team.telstra.com.au','Kenji Kwok','6 Wongala Way<br>Mooroolbark','Melbourne','Victoria','AUSTRALIA','3138','0418309371','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 09:53:40',0,NULL,3,1,2,1,NULL,'kenji.kwok1'),(14373,831117943015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','sasmarines','tinogalea@gmail.com','Anthony Galea','79, Luana<br>Buqexrem Street','Fgura','','MALTA','FGR2025','35627809242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 10:28:48',0,NULL,3,1,2,1,NULL,'sasmarines'),(14374,707645944001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','gorgonzi','chaosii@msn.com','JAVIER GONZALEZ GOROSABEL','MUNTANER, 262, 4º 2ª','BARCELONA','Cataluña','SPAIN','08021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 10:31:07',0,NULL,3,1,4,1,'YW866127813CN ','gorgonzi\rTripod   $22'),(14375,749370057002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','eduayerbe','edu_2108_22@hotmail.com','Eduardo Salinero Aso','c/progreso nº8<br>Ayerbe','Huesca','Aragón','SPAIN','22800','974380532','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-07 11:00:34',0,NULL,3,1,3,1,'RA183621087CN\r ','eduayerbe'),(14376,707687043001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','abbydry','gertdawg@gmail.com','James Corliss','45120 Highway 79<br>Lot 931','Aguanga','CA','UNITED STATES','92536-9706','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 12:25:54',0,NULL,3,1,1,1,NULL,'abbydry'),(14377,707701953001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','robcorrr','rmato@centrum.sk','Robert Mato','Bartokova<br>6','Nitra','Nitra','SLOVAK REPUBLIC','94901','0905823238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 13:00:53',0,NULL,3,1,2,1,NULL,'robcorrr'),(14378,707701824001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 13:03:02',0,NULL,3,0,17,0,NULL,'saud-p'),(14379,707699837001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-07 13:03:03',0,NULL,3,1,3,1,'RA183621135CN\r ','saud-p\r1.6*2.1 蓝色背景布     1\r1.6*2.1白色+黑色背景布    1\r背景架2mx2m  + 3个夹子      1\rRA183621144CN\r'),(14380,707627623001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','chrismwak','chris@mwakasisi.com','Chris Mwakasisi','7154 Sandpiper St','Portage','MI','UNITED STATES','49024-7409','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 13:30:05',0,NULL,3,1,1,1,NULL,'chrismwak\r'),(14381,831234923015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','nick8551','matthams230@btinternet.com','Nick Matthams','69 The Street<br>Latchingdon','Chelmsford','Essex','UNITED KINGDOM','CM3 6JS','01621741011','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 14:25:34',0,NULL,3,1,2,1,' ','nick8551'),(14382,707747463001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','wowzwerg','matthiaszettel@freenet.de','Matthias Zettel','Bonhöfferstraße 1','Ahlen','','GERMANY','59227','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 14:47:28',0,NULL,3,1,2,1,NULL,'wowzwerg'),(14383,763758008017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','yiyangyixuan','yiyangyyx@gmail.com','Dapeng LIU','8/35-37 Tramway st','West Ryde','New South Wales','AUSTRALIA','2114','0405271390','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 15:41:50',0,NULL,3,1,3,1,'RA183621250CN\r','yiyangyixuan'),(14384,707792962001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','michborn1956','rewilbur@charter.net','RICK WILBUR','1250 Calls Creek Cir','WATKINSVILLE','GA','UNITED STATES','30677-2599','(706) 769-2816','NoPaymentFailure','CheckoutComplete','Other','2011-08-07 16:15:10',0,NULL,3,0,1,1,NULL,'michborn1956\rL   (已入库）'),(14385,763795904017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','meirabergel','ka250@walla.co.il','Meir Abargil','Mishol ha Zamir140 /2','Dimona','Sud','ISRAEL','86076','+(972)86550381','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-07 16:56:59',0,NULL,3,1,2,1,NULL,'meirabergel'),(14386,749548505002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','f-teams','zeftim@gmail.com','Elica Zdraveva','Pere Tosev 10','Radovis','Macedonia','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','2420','+38970319265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 17:16:55',0,NULL,3,1,2,1,NULL,'f-teams'),(14387,763834888017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','30.d4nm4c','mckenna.dt@gmail.com','Daniel McKenna','12 McKinnon St','Nicholls','Australian Capital Territory','AUSTRALIA','2913','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 17:28:26',0,NULL,3,1,2,1,NULL,'30.d4nm4c'),(14388,708858705018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','ijbishop','bishop03@sasktel.net','Ian J. Bishop','1555 Barton drive','Prince Albert','SK','CANADA','S6V 7P5','(306) 922-6321','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-07 19:15:31',0,NULL,3,1,3,1,'RA183621161CN\r ','ijbishop\r除了c 里面的再加上\r49cm 接口环   1\r82cm 接口环    1\r广角托架    1\r已入库'),(14389,708864336018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','mrbillzwa','bill@saunderz.org','Bill Saunders','714 Central Pl','Sedro Woolley','WA','UNITED STATES','98284-2121','(360) 873-8720','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-07 19:21:34',0,NULL,3,1,1,1,NULL,'mrbillzwa'),(14390,749648973002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','samicoteli','sami@duslerfabrikasi.com','Sami Coteli','Yazmaci Tahir Sok. 48/7<br>Mendirek Ap. Bostanci','Istanbul','','TURKEY','34744','+902163800750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 19:33:32',0,NULL,3,0,2,1,NULL,'samicoteli\r欧标'),(14391,707961360001,110717036916,'NEW PRO LED 312 Panel Camera & Camcorde​r Light 5600k',2,'AD1150',470,'hermeshine','kleiberfragoso','kfvideo@gmail.com','Kleiber Sequeira','Rua República do Peru, 193/ 41<br>Copacabana','Rio de Janeiro','Rio de Janeiro','BRAZIL','22021040','55-21- 254858598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 20:13:40',0,NULL,3,1,17,0,NULL,'kleiberfragoso'),(14392,707961336001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kleiberfragoso','kfvideo@gmail.com','Kleiber Sequeira','Rua República do Peru, 193/ 41<br>Copacabana','Rio de Janeiro','Rio de Janeiro','BRAZIL','22021040','55-21- 254858598','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-07 20:13:40',0,NULL,3,0,17,0,NULL,'kleiberfragoso'),(14393,707966096001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',4,'AE3103',39.2,'hermeshine','kleiberfragoso','kfvideo@gmail.com','Kleiber Sequeira','Rua República do Peru, 193/ 41<br>Copacabana','Rio de Janeiro','Rio de Janeiro','BRAZIL','22021040','55-21- 254858598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 20:17:16',0,NULL,3,1,6,1,'EE495359830CN','kleiberfragoso\r重新包一下，分两个包裹（20110925）\r第一个包裹：利帅LED系列 312A     2\r第二个包裹： 摄影背心 黑色薄 canon  2xl      1\r大力夹云台      4\r3.88\r退回来了   重新发  \rEE495359826CN\r又退回来了'),(14394,707979218001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',5.49,'hermeshine','tdk9403','timkingd@aol.com','Tim King','1133 Sandy St','Elgin','SC','UNITED STATES','29045-9618','(803) 788-7707','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-07 20:41:05',0,NULL,3,1,1,1,NULL,'tdk9403'),(14395,707984660001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','deniswdion','dwdion@gmail.com','Denis Dion','Mellingerstrasse 156','Baden','','SWITZERLAND','5400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 20:52:35',0,NULL,3,1,3,1,'RA183621100CN\r ','deniswdion'),(14396,831552791015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0022',149,'hutongstore','gavinwatton','gavinwatton@yahoo.co.uk','Gavin Watton','14 Shortland Crescent<br>Burnage','Manchester','Greater Manchester','UNITED KINGDOM','M19 1SZ','07788566715','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-07 20:57:34',0,NULL,3,1,4,1,'YW866127791CN ','gavinwatton\rTripod   $28'),(14397,708928131018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',1,'AE2316',12.9,'photographyacc','bst1t','trevorsmall@bigpond.com','Trevor Small','59 Willara Street','Carseldine','Queensland','AUSTRALIA','4034','0732633913','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-07 21:03:34',0,NULL,3,1,2,1,NULL,'bst1t\r方形滤镜接口环 52mm   1\r方镜普通托架（三槽）    1\r天涯方形滤镜系列  星光镜  star6   1\r'),(14398,831555493015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','chicshooka','verdubez@hotmail.com','Vered Beza','Shabazi 1','Yahud','SC','ISRAEL','56000','503212755','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-07 21:04:11',0,NULL,3,1,3,1,'RA183623009CN\r ','chicshooka'),(14399,708934386018,280666893489,'New Green.L 77mm  Gradual Grey ND4 Filter 2-Stop 77 mm',1,'AA3321',8.8,'photographyacc','siupo_ky55','samsam.yeung@gmail.com','Kam Leung Yeung','1819 Douglas Avenue','Ames','IA','UNITED STATES','50010','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-07 21:16:36',0,NULL,3,1,1,1,NULL,'siupo_ky55'),(14400,814243446016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','waddo1','waddo@tesco.net','alan waddington','13 northview,lyngate,','norfolk','Norfolk','UNITED KINGDOM','NR289RF','01692535037','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 21:17:37',0,NULL,3,1,2,1,NULL,'waddo1'),(14401,707996115001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-07 21:21:14',0,NULL,3,1,3,1,'RA183621056CN\r ','paulolagoaseca2010\r新地址\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r申报 gift  \r\r'),(14402,831595591015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','paulhutchison8321','paulhutchison83@aol.com','paul hutchison','15 boase avenue','st andrews','fife','UNITED KINGDOM','ky168bx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-07 22:17:25',0,NULL,3,1,2,1,NULL,'paulhutchison8321'),(14403,749758916002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','kristahill03','kris.hill@gmx.com','kris hill','155 stoneybrook court<br>apt. 307','halifax','NS','CANADA','b3m 4s2','(902) 229-2520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-07 23:19:23',0,NULL,3,1,5,1,'CP235771455CN ','kristahill03'),(14404,708996050018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','90lxfox_body_stang','fox_body_stang@comcast.net','Joseph Dwyer','214 Robin St','Fountain','CO','UNITED STATES','80817-1834','(719) 434-8606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-08 00:12:31',0,NULL,3,0,1,1,NULL,'90lxfox_body_stang\r除了c 里面  再发\r49 cm 接口环   1\r82 cm 接口环    1\r广角托架      1\r已入库'),(14405,708060810001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','princess-dorian','dorianpa@aol.com','DORIAN STUART','4809 Club Dr','READING','PA','UNITED STATES','19606-2419','','NoPaymentFailure','CheckoutComplete','Other','2011-08-08 00:31:40',0,NULL,3,0,1,1,NULL,'princess-dorian\rxl    已入库'),(14406,707673987018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','dingwallpeter','dingwallruth@hotmail.com','peter dingwall','33 panos street','cardwell','Queensland','AUSTRALIA','4849','0740668144','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 00:36:56',0,NULL,3,1,3,1,'RA183622992CN\r ','dingwallpeter'),(14407,763072730017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','d-heis','dana.heis@hotmail.com','Dana Heis','19 Hewat Drive','Highton','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 01:01:48',0,NULL,3,1,17,0,NULL,'d-heis'),(14408,709010030018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','d-heis','dana.heis@hotmail.com','Dana Heis','19 Hewat Drive','Highton','Victoria','AUSTRALIA','3216','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 01:01:49',0,NULL,3,1,4,1,'YW866127776CN ','d-heis\r反光板  80cm 5合1     1\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1'),(14409,708070741001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','eunimperdible','ciclosamuel@gmail.com','Eunice Lopez Palomares','quintana 9, 1º dcha','linares','Andalucía Ceuta y Melilla','SPAIN','23700','670657628','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-08 01:06:31',0,NULL,3,1,4,1,'YW866127765CN ','eunimperdible'),(14410,8881312768221886,111,'New Photo Studio Light Stand Umbrella Flash Mount set ball',1,'AKT014',40,'aliexpress','1003886783 ','erayozden@msn.com','Eray OZDEN	','Turkkonut Platin Sitesi No:29 Cayyolu2 Yenimahalle','Ankara','','TURKEY','06810','905547541903',NULL,NULL,NULL,'2011-08-08 01:50:21',0,NULL,3,1,3,1,'RA183621229CN\r ',' '),(14411,708090482001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','aabarron','aabarron@terra.com.mx','Arturo Andrade','Prol. 12 Nte 2005-3,<br>Barrio de Jesus Tlatenpa % 20 ote y 22 ote cel. 222 1732934','San Pedro Cholula','Puebla','MEXICO','72770','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 02:10:39',0,NULL,3,1,2,1,NULL,'aabarron'),(14412,764121598017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',79,'photographyacc','7816stan','ssimo@tpg.com.au','Stan Simpson','21/66-72 Browns Road','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 02:58:16',0,NULL,3,1,17,0,NULL,'7816stan'),(14413,709043998018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','7816stan','ssimo@tpg.com.au','Stan Simpson','21/66-72 Browns Road','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 02:58:16',0,NULL,3,1,17,1,'\r','7816stan\r灯架  2m      1\r斜臂        1\r115w 220v  灯泡      1\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1\r8月31日再发货!!!'),(14414,709052832018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','jamesd1066','james.donnelly@carabang.net','James Donnelly C/O ADT Security','38 South Street','Rydalmere','New South Wales','AUSTRALIA','2116','0400342852','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 03:30:58',0,NULL,3,1,4,1,'YW866127743CN ','jamesd1066\r------\r新地址:\rJames Donnelly \r153a Gloucester RD,\rHurstville,\rNSW\r2220\rAUSTRALIA\r'),(14415,708810080018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',3,'AA1315',8.97,'photographyacc','solowing0220','godgundam0220@live.com','Lim Wee Yang','choa chu kang st 52 block 545 #12-12','default','','SINGAPORE','680545','67692856','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-08 03:38:01',0,NULL,3,1,11,1,NULL,'solowing0220'),(14416,764132668017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','ciaobaby27','mmaruca@bigpond.com','MARIA MARUCA','P O Box 2240<br>Fortitude Valley BC','BRISBANE','Queensland','AUSTRALIA','4006','61417786750','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 03:52:50',0,NULL,3,1,2,1,NULL,'ciaobaby27'),(14417,764081308017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','lindi1203','jswemmer@bigpond.com','Lindi Swemmer','40 Isles Road<br>Indooroopilly','Brisbane','Queensland','AUSTRALIA','4068','0733655888','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 04:06:37',0,NULL,3,1,4,1,'YW866127625CN ','lindi1203\r澳标\rLighting  Kit  $28'),(14418,708075532018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','danielc2384','danze1@optusnet.com.au','Daniel Carpinteri','29 Simmington Circuit Greenvale','Melbourne','Victoria','AUSTRALIA','3059','0393332853','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 06:21:02',0,NULL,3,1,4,1,'YW866127651CN ','danielc2384\r已收到'),(14419,555594274003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','frydrik_frydrik','frydrik_1@mail.md','tudor bargan','st. Mircea cel Batrin 9 ap 32<br>st. Mircea cel Batrin 9 ap 32','chisinau','chisinau','MOLDOVA, REPUBLIC OF','2044','37322339902','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 06:27:20',0,NULL,3,1,5,1,'CP235771610CN ','frydrik_frydrik'),(14420,830597811015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',6,'hutongstore','ardernthomas','ptruck@mypostoffice.co.uk','Peter Ruck','Garden Cottage<br>Guildford Road','Abinger Hammer','Surrey','UNITED KINGDOM','RH5 6QA','01306730850','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 06:29:34',0,NULL,3,1,3,1,'RA183621303CN\r ','ardernthomas\r客户多交了￡1.2的挂号费'),(14421,749867136002,120539340436,'New 77mm ring adapter replacement for cokin P series',6,'AA2214',13.08,'hermeshine','elenamargherita','elenabg@fastwebnet.it','Aldo Gallo','Piazza 4 Novembre 10','Mandello del lario','LC','ITALY','23826','0341700307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 06:30:34',0,NULL,3,1,3,1,'RA183621215CN\r ','elenamargherita'),(14422,708145216001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','mendruggo','angel.megia@gmail.com','Ángel Megía Ruiz','C/Antonio Buero Vallejo, 3','Ocaña','Castilla-La Mancha','SPAIN','45300','695162341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 06:49:10',0,NULL,3,1,4,1,'YW866127640CN ','mendruggo'),(14423,764170994017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','deviant_ska','cavabro@gmail.com','carlo van den Broeck','61 Isabella street','parramatta','New South Wales','AUSTRALIA','2150','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 07:06:59',0,NULL,3,1,2,1,NULL,'deviant_ska'),(14424,814437981016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','santa.dk','tranfamily@city.dk','Tam Tran','Oesterloekken 118','Tilst Aarhus','','DENMARK','8381','(0045)20887400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 07:31:12',0,NULL,3,1,2,1,NULL,'santa.dk'),(14425,764189037017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','4blackriders','daniel.tokarev@monash.edu','Daniel Tokarev','2/7 Childers Street','Mentone','Victoria','AUSTRALIA','3194','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 08:29:06',0,NULL,3,1,2,1,' ','4blackriders'),(14426,8881312796084181,111,'4灯头上的柔光罩 x  2',1,'',0,'photographyacc','egut7992','edwardsphotography@live.com','Edward Gutierrez','5658 N 6th St','Fresno','CA','UNITED STATES','93710-6348','(559) 367-9673',NULL,NULL,NULL,'2011-08-08 09:34:44',0,NULL,3,0,1,1,NULL,'看一下应该是一个60x60的方形的 \r08-09  \rLK032975732CN'),(14427,708181213001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','bodok15','bodok15@yahoo.com','Elmer Juyo','G. Ortiz Rd., Ulas, Davao City','Davao','Davao del Sur','PHILIPPINES','8023','0822990956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 09:47:04',0,NULL,3,1,2,1,NULL,'bodok15'),(14428,8881312797300083,111,'见备注(澳元)',127,'',1,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971',NULL,NULL,NULL,'2011-08-08 09:55:00',0,NULL,3,0,4,1,'YW866127216CN ','金额应该AU$156 \r------------- \r反光板支架(不包括Holder arm grip) * 4 \r斜臂(不包括Section Telescopic Light Hold Arm) * 4 \r45w 灯泡 * 1\r这个我来吧  东西有变动\r4.386\r-------------'),(14429,749911530002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','aspasia1310','aspasia@fastwebnet.it','Federica Cioccoloni','via Casale Radicelli, 67','Roma','Roma','ITALY','00134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:07:40',0,NULL,3,1,2,1,NULL,'aspasia1310'),(14430,831814348015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','ricardo.bou','bous026@yahoo.es','Ricardo Fco. Bou Sebastián','C/Benimaclet nº 39 - pta 25','Alboraya','Comunidad Valenciana','SPAIN','46120','678446985','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-08 10:36:57',0,NULL,3,1,4,1,'YW866127323CN','ricardo.bou\r'),(14431,8881312800206751,111,'2B柔  x  2',2,'AKT014',0,'hermeshine',' denis5108   ','Enterprog@ya.ru','Denis Savin','Kulikova street 14-38','Ivanovo','','RUSSIAN FEDERATION','153032','+7(908)567-5108',NULL,NULL,NULL,'2011-08-08 10:43:26',0,NULL,3,1,5,1,'CP235771464CN ',NULL),(14432,708195736001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','alperorus','alperor@gmail.com','Alper Orus','Gurpinar Mah. Bulgurlu Cad.<br>Masaldan Is Merkezi G Blok Kat:3','Istanbul','BCamlica','TURKEY','34696','902163165353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 10:45:30',0,NULL,3,1,2,1,NULL,'alperorus'),(14433,708209201001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','lennartlemajo','lebj@telia.com','Lennart Björkegren','Björkåsvägen 20','Karlstad','','SWEDEN','65342','004554568484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 11:36:53',0,NULL,3,1,17,0,NULL,'lennartlemajo'),(14434,831839620015,250599980827,'New Neoprene Reversible Bag Cover for Large-DSLR',1,'AC1302',5.5,'hutongstore','rog3rburton','roger@rogerburton.co.uk','ROGER BURTON','29 Twynham Avenue','Christchurch','Dorset','UNITED KINGDOM','BH23 1QU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 11:47:48',0,NULL,3,1,2,1,NULL,'rog3rburton'),(14435,831844152015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','sergdalvarez','sergdalvarez@hotmail.com','Sergio Alvarez','Acuerdo Nº35 5ºC','Madrid','Madrid','SPAIN','28015','671245584','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-08 12:00:17',0,NULL,3,1,4,1,'YW866127570CN ','sergdalvarez\r Tripod   $25'),(14436,749946097002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','fajus11','megaguiller@hotmail.com','Guillermo Espiga Alonso','C/El Rodo<br>Nº39','Burgos','Castilla y León','SPAIN','09006','606755863','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 12:11:05',0,NULL,3,1,3,1,'RA183621348CN\r ','fajus11'),(14437,831860892015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','chrism8779','chris-bangor@hotmail.co.uk','chris mccann','F 1 grange manor,<br>grange road','bangor','Down','UNITED KINGDOM','BT203QH','02891472314','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 12:47:24',0,NULL,3,1,2,1,NULL,'chrism8779'),(14438,709190837018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','stevesavage0','stevefilby@spin.net.au','Steve Filby','16 Tiara Drive','South Morang','Victoria','AUSTRALIA','3752','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 13:18:43',0,NULL,3,1,3,1,'RA183621277CN\r ','stevesavage0'),(14439,749373814002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',50,'AA1310',274.5,'hermeshine','pinchukov','v_pinchukov@mail.ru','Vassiliy Pinchukov','Karasai Batyra 209/79','Almaty','','KAZAKHSTAN','050009','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-08 14:14:13',0,NULL,3,1,3,1,'RA183621405CN\r ','pinchukov'),(14440,709215731018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','mcev','micioffo@tin.it','Michele Cioffo','via E. Fermi 37','Campegine','Reggio Emilia','ITALY','42040','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-08 14:35:17',0,NULL,3,1,2,1,NULL,'mcev'),(14441,764306262017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','dawsey01','dawsey77@optusnet.com.au','Nathan DAWE','44 Wonga Road','Noranda','Western Australia','AUSTRALIA','6062','0407235920','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 14:53:47',0,NULL,3,1,2,1,NULL,'dawsey01'),(14442,709228849018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','shinetoms2011','shinetoms@gmail.com','Thomas Shine','70, Argyle st','Fawkner','Victoria','AUSTRALIA','3060','0383007549','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 15:13:31',0,NULL,3,1,3,1,'RA183621382CN\r ','shinetoms2011'),(14443,750009103002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','+79232892744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 15:24:30',0,NULL,3,1,5,1,'CP235771478CN ','zenitar16'),(14444,831946058015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','joh_hal','john.hallmen@gmail.com','John Hallmén','Halmstadsvägen 50','Johanneshov','none','SWEDEN','12153','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 16:07:04',0,NULL,3,1,2,1,NULL,'joh_hal'),(14445,708300430001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','kalamazu','wplanned@hotmail.com','Jorge Gonzalez Sanz','Cl/ Grecia 3<br>Portal 4 4.B','Torrejon de Ardoz','Madrid','SPAIN','28850','607592030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 16:29:09',0,NULL,3,1,4,1,'YW866127614CN ','kalamazu\r Tripod   $22'),(14446,555714204003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','lucasward10','vj4@iinet.net.au','Charles Maekivi','PO Box 369','Mt Hawthorn','Western Australia','AUSTRALIA','6915','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 16:36:33',0,NULL,3,1,4,1,'YW866127603CN ','lucasward10\r0823来信说收到了'),(15245,756635621002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',147.8,'hermeshine','whtan07','whtan74@gmail.com','Tan Wei Hong','2B-8-6 Dpiazza Condominium<br>Lengkok Mayang Pasir 1','Bayan Baru','Penang','MALAYSIA','11950','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 01:42:08',0,NULL,3,1,6,1,'EE495341122CN ','whtan07'),(14447,708334853001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','archimix','admin@vip-webstudio.com','Denis Saralidze','Cingizxan Kerimov str.<br>Building 4 Apartment 35','Baku','Xatai','AZERBAIJAN','AZ1123','+994505036483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 17:45:58',0,NULL,3,1,2,1,NULL,'archimix\r欧标'),(14448,764381518017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','beate3496','ulsteinport@hotmail.com','Beate Ingvaldsen','Eaholmsveien 3<br>6518 kristiansund.N','Kristiansund.N','Møre og romsdal','NORWAY','6518','47353700','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-08 17:47:02',0,NULL,3,1,2,1,NULL,'beate3496'),(14449,708345272001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','panzum','ariel.meyrelles@mundonovias.net','Ariel Meyrelles','Manzoni 83','Buenos Aires','Capital','ARGENTINA','C1407ICA','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-08 18:10:42',0,NULL,3,0,3,1,'RA183621379CN\r ','panzum\rxl   已入库'),(14450,750099727002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','old8bits','ebayy@lud.servebeer.com','Ludovic Drolez','2 rue de l\'Argonne','Metz','Lorraine','FRANCE','57000','0950181274','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-08 18:50:08',0,NULL,3,1,3,1,'RA183621263CN\r ','old8bits'),(14451,814709887016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',2,'AA1201',3.7,'hutongstore','luisflorencio','crunch@sapo.pt','Luis Florencio','Rua das Fortunatas 11','Vale das Mos','','PORTUGAL','2205-810','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-08 18:52:12',0,NULL,3,1,2,1,NULL,'luisflorencio'),(14452,750086175002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','florinlazaru','spartan78@hotmail.es','santiago lazaro virgos','c/beethoven 76 1ºd','zaragoza','Aragón','SPAIN','50012','653828337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:03:57',0,NULL,3,1,17,0,NULL,'florinlazaru'),(14453,708352536001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','florinlazaru','spartan78@hotmail.es','santiago lazaro virgos','c/beethoven 76 1ºd','zaragoza','Aragón','SPAIN','50012','653828337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:03:56',0,NULL,3,1,3,1,'RA183621351CN\r ','florinlazaru\r绿叶 UV  52mm     1\r灯架  2m      1'),(14454,708375948001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:09:34',0,NULL,3,1,2,1,NULL,'nixette_nixette'),(14455,708382987001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','renelc2','renelc@gmail.com','Rene Lopez Caballero','Doctor Vazquez Perez 202','Apizaco','Tlaxcala','MEXICO','90350','00522414182259','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:25:05',0,NULL,3,1,2,1,NULL,'renelc2'),(14456,750125322002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','barilka2','janabarilik@gmail.com','Jana Barilikova','Kalinovska 14','Kosice','','SLOVAK REPUBLIC','04022','+421905970536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 19:40:57',0,NULL,3,1,2,1,NULL,'barilka2'),(14457,750151151002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','lennartlemajo','lebj@telia.com','Lennart Björkegren','Björkåsvägen 20','Karlstad','','SWEDEN','65342','004554568484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-08 20:36:28',0,NULL,3,1,3,1,'RA183621334CN\r ','lennartlemajo\r反光板支架      1\r伟峰 6662A 快装板      1'),(14458,832142580015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','robertmatny','robertmathe308@gmail.com','Robert Mathe','3 Serina Court','Nottingham','Nottinghamshire','UNITED KINGDOM','NG92GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-08 22:01:07',0,NULL,3,1,2,1,NULL,'robertmatny'),(14459,709416274018,280709593667,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',36,'photographyacc','bk-maxi','bck.photography@gmail.com','Birgit Korn','c/o Ernst and Young<br>1 Eagle Street, Mail room level 31','Brisbane','Queensland','AUSTRALIA','4000','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-08 22:07:25',0,NULL,3,1,3,1,'\rRA183621325CN\r ','bk-maxi'),(14460,764531034017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','scfp7821','scfp7821@yahoo.com.au','tim mcgrath','22 Hawkes Way','Boat Harbour','New South Wales','AUSTRALIA','2316','0413555329','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-08 23:30:51',0,NULL,3,1,2,1,NULL,'scfp7821'),(14461,708471419001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',77,'hermeshine','bentevengue','beringuy@hotmail.com','Leonardo Beringuy Bentevengue Lima','Rua General Silveira Sobrinho, 145 - Apt 202<br>Vila da Penha','Rio de Janeiro','Rio de Janeiro','BRAZIL','21221-290','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-08 23:34:50',0,NULL,3,1,5,1,'CP235771481CN ','bentevengue'),(14462,708359743001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','limbeta','mars_barsse@yahoo.com','Marcela Barsse','Emperadores 43-A<br>Col. Portales','Mexico','Distrito Federal','MEXICO','03300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:06:35',0,NULL,3,1,17,0,NULL,'limbeta'),(14463,708475983001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','limbeta','mars_barsse@yahoo.com','Marcela Barsse','Emperadores 43-A<br>Col. Portales','Mexico','Distrito Federal','MEXICO','03300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:06:36',0,NULL,3,1,17,0,NULL,'limbeta'),(14464,750093580002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','limbeta','mars_barsse@yahoo.com','Marcela Barsse','Emperadores 43-A<br>Col. Portales','Mexico','Distrito Federal','MEXICO','03300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:06:37',0,NULL,3,1,2,1,NULL,'limbeta\r大号灰卡    1\r绿叶 渐变镜 77mm    1\rCANON 镜头盖  58mm    1'),(14465,750223396002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','gustavomazza','registros@gustavo.net','Gustavo Mazzarollo','Rua Santos Dumont 957<br>sala 202','Teutonia','RS','BRAZIL','95890-000','555193274164','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 00:28:38',0,NULL,3,1,2,1,NULL,'gustavomazza'),(14466,750228815002,120565576624,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.91,'hermeshine','tatyboni','tatyboni2011@hotmail.com','Sergio Ricardo (Tatiane Boni de Souza)','Av. Oliveira Belo, nº  640 - Vila da Penha<br>A/C do Sr. João - Av. Oliveira Belo nº  680 - Vila da Penha','Rio de Janeiro','Rio de Janeiro','BRAZIL','21221-300','21-7812-1574','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 00:49:00',0,NULL,3,1,3,1,'RA183621317CN\r ','tatyboni'),(14467,814877874016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','snep1968','frankjoansierra@gmail.com','Núria Llorca Altirriba','Calle Mayor, 67 3º 2ª','Castelldefels','Barcelona','SPAIN','08860','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 01:21:20',0,NULL,3,1,3,1,'RA183621285CN\r ','snep1968'),(14468,706882514018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','035bronson','lynmcconnell@westvic.com.au','Lynette McConnell','802 Penshurst Road','Kirkstall','Victoria','AUSTRALIA','3283','0355658701','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 02:12:42',0,NULL,3,0,3,1,'RA183622604CN ','035bronson\r(已入库）'),(14469,8881312858117089,111,'3pcs 滤镜袋 x 2',2,'AE1201',0,'hermeshine','coling45','coling7@me.com','Colin Garside','22/31 Langport Parade','Mudgeeraba','Queensland','AUSTRALIA','4213','0755306809',NULL,NULL,NULL,'2011-08-09 02:48:37',0,NULL,3,1,3,1,'RA183621396CN\r ',NULL),(14470,709493192018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',245,'photographyacc','ruinfix','john.michael.green@gmail.com','John Green','5 Tomago Street','Brisbane, Aspley','Queensland','AUSTRALIA','4034','0738634336','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-09 02:56:03',0,NULL,3,1,4,1,'YW866127592CN ','ruinfix\rtripod $35'),(14471,708528991001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','hazidiee','xwormz@hotmail.com','Hazidiee Sharbini','no 7 jalan kecil masin, spg 616-38, kampung masin','Bandar Seri Begawan','','BRUNEI DARUSSALAM','BH 2723','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 03:28:36',0,NULL,3,1,3,1,'RA183621365CN\r ','hazidiee\r已入库  '),(14472,750272824002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','metaryder','john.w.grubb@shaw.ca','John Grubb','238 Coral Reef Manor','Calgary','AB','CANADA','T3J3Y8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 03:46:49',0,NULL,3,0,3,1,'RA183621453CN\r\r ','metaryder\rL  已入库\r'),(14658,709772800001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','omega_r','omer.kasdarma@gmail.com','Omer Kasdarma','Hasircibasi Cd 61/1<br>Kadikoy','Istanbul','','TURKEY','34714','5322722626','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-12 08:35:53',0,NULL,3,1,3,1,'RA184551325CN\r ','omega_r'),(14473,764607122017,270742432150,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',16.64,'photographyacc','johnb5319','bywater2@bigpond.net.au','John W Bywater','1 Tahlee Close','Castle Hill','New South Wales','AUSTRALIA','2154','0418788466','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 04:30:36',0,NULL,3,1,2,1,NULL,'johnb5319\r方形滤镜接口环 55mm    1\r方形滤镜接口环 52mm      1\r方形滤镜接口环 62mm       1\r广角托架      1\r已入库'),(14474,709516750018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','dtlim','dl_te@yahoo.ca','Nick Lim','8 Ellie Drive','Scarborough','ON','CANADA','M1G 2G9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 04:53:26',0,NULL,3,1,2,1,NULL,'dtlim'),(14475,708545723001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','picturesrus1988','picturesrusphotography@yahoo.com','rose black','736 Quail Run Ln','La Follette','TN','UNITED STATES','37766-6966','(423) 871-0465','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,4,0,NULL,'picturesrus1988'),(14476,708571661001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','gilles_cochet1xz5','gilles.cochet@gmail.com','Gilles COCHET','1 rue jules ferry','Velizy Villacoublay','Île-de-France','FRANCE','78140','33139460463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:39:39',0,NULL,3,1,17,0,NULL,'gilles_cochet1xz5'),(14477,708572635001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','gilles_cochet1xz5','gilles.cochet@gmail.com','Gilles COCHET','1 rue jules ferry','Velizy Villacoublay','Île-de-France','FRANCE','78140','33139460463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 07:45:11',0,NULL,3,1,3,1,'RA183621436CN ','gilles_cochet1xz5\r单灯头  欧标     2\r反光板支架     1'),(14478,764644146017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',2,'AKT017',295,'photographyacc','lloydy1986','lloydjohnson@gmail.com','Lloyd Johnson','36 Endeavour Avenue','Bull Creek','Western Australia','AUSTRALIA','6149','0427384547','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-09 07:51:20',0,NULL,3,1,4,1,'YW866127220CN ','lloydy1986\r河北背景架 + 1.6x2.1m 白   1\rc里的是两套 澳标\r已入库'),(14479,750319657002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 08:21:49',0,NULL,3,1,17,0,NULL,'humanprofile'),(14480,750319582002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 08:21:50',0,NULL,3,1,4,1,'YW866127242CN ','humanprofile\r反光板支架   1\r灯架  2m   1\r三脚架 伟峰 EI-717  180    1\r客户要发票    \r申报 $35\r已收到'),(14481,708583041001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','eddi73*123','eddi2001@mail.ru','Eddi Gershengoren','Ha\'armonim 1a/4','Nesher','','ISRAEL','36810','0523378973','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 08:38:46',0,NULL,3,1,2,1,NULL,'eddi73*123'),(14482,750323928002,120753012100,'New Official Original Nikon Photo Vest D300 D90 Size L ',1,'AD1160',55,'hermeshine','jeanluclamaere','jluclamaere@yahoo.fr','jean luc lamaère','19, avenue Léon Bry','gagny','Ile-de-France','FRANCE','93220','0660618703','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 08:44:50',0,NULL,3,1,3,1,'RA183621555CN\r ','jeanluclamaere\r已入库'),(14483,708592992001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','mario061961','mario1961@arcor.de','Elke Plagemann','Zelle Str.15','Berlin','','GERMANY','10247','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 09:28:02',0,NULL,3,1,4,1,'YW866127290CN ','mario061961'),(14484,832333428015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','lucysurbey','ljevans_112@hotmail.com','Lucy surbey','The croft<br>The front','Holywell','Cambridgeshire','UNITED KINGDOM','Pe27 4tg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 09:43:24',0,NULL,3,1,3,1,'RA183621538CN\r ','lucysurbey'),(14485,750341501002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','motorsticker.eu','info@motorsticker.nl','Wouter van der Haar','Tolweg 2W','Ermelo','','NETHERLANDS','3851SK','0652614637','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 10:04:07',0,NULL,3,1,4,1,'YW866127253CN ','motorsticker.eu\r欧标'),(14486,750349278002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',2,'AC3303',17.58,'hermeshine','deecore','kjetil@tollefsrod.com','Kjetil Tollefsrød','Bakkeveien 17','Saltnes','','NORWAY','1642','+47 91808801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 10:37:10',0,NULL,3,1,2,1,NULL,'deecore'),(14487,708610479001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','aguelix10','duval1971@hotmail.com','Antonio Diaz Rodriguez','c/ sorda nº 9 Piso 13','SEVILLA','Andalucía Ceuta y Melilla','SPAIN','41003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 10:42:26',0,NULL,3,1,4,1,'YW866127264CN ','aguelix10'),(14488,708609426001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','ionutcioana','ionutcioana@yahoo.com','ionut cioana','sos vergului 19, bl h4, ap 29, sector 2','bucharest','','ROMANIA','022443','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 10:43:56',0,NULL,3,1,2,1,NULL,'ionutcioana'),(14489,750358081002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','goranavalon','g.ugresic@gmail.com','Goran Ugresic','Borislava Stankovica 5','Gradiska','RS','BOSNIA AND HERZEGOVINA','78400','+387 65 569 189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 11:14:16',0,NULL,3,1,3,1,'RA183621569CN\r ','goranavalon'),(14490,707315246001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','eradiss2','eradiss@roadrunner.com','Elaine Radiss','12 Blue Hill Ln','Great Barrington','MA','UNITED STATES','01230-1288','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 11:23:18',0,NULL,3,1,1,1,NULL,'eradiss2'),(14491,764697377017,270751511455,'YongNuo 3m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3325',28.99,'photographyacc','vertetgris','lesley.prosser@bigpond.com','lesley prosser','15 gardenia cr','bomaderry','New South Wales','AUSTRALIA','2541','0244221249','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 11:25:14',0,NULL,3,1,3,1,'RA183621586CN\r ','vertetgris'),(14492,832364379015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','6403anderson','michael.anderson11@virgin.net','Linda Anderson','42 Ashburn Road<br>Hadrian Park','Wallsend','Tyne and Wear','UNITED KINGDOM','NE28 9UN','01912344332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 11:27:42',0,NULL,3,1,2,1,NULL,'6403anderson'),(14493,764698651017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',12.99,'photographyacc','tagov','tagov@telefonica.net','SANTIAGO VITORES TOLEDO','PLAZA DOCTOR LAGUNA, 9, 8ºB','MADRID','Madrid','SPAIN','28009','630097749','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 11:29:10',0,NULL,3,1,2,1,NULL,'tagov'),(14494,709608308018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','sirus8de8virus','kevan_tay@hotmail.com','Tay Boon Leong','11 Sabine Grove','Alexander Heights','Western Australia','AUSTRALIA','6064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 12:00:24',0,NULL,3,1,2,1,NULL,'sirus8de8virus'),(14495,750375836002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','robertbrown10','rfbrownebay@optusnet.com.au','Robert Brown','10 Kardinia St<br>Sunnybank','Brisbane','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 12:21:40',0,NULL,3,1,3,1,'RA183621419CN\r ','robertbrown10\r澳标  分开发'),(14496,764714870017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2202',30,'photographyacc','robertbrown10','rfbrownebay@optusnet.com.au','Robert Brown','10 Kardinia St<br>Sunnybank','Brisbane','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 12:24:46',0,NULL,3,1,3,1,'RA183621422CN\r ','robertbrown10\r澳标   分开发'),(14497,709619699018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','arieflim','arief_lim@yahoo.com','Arief Lim','Wisma Eka Jiwa, Ruko No.1, Lt.2<br>Jl. Mangga Dua Raya','Jakarta','Jakarta','INDONESIA','10730','+628128663001','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 12:37:31',0,NULL,3,1,2,1,NULL,'arieflim'),(14498,764664153017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','cm411489','dan.401@hotmail.com','Daniel Nicholas','73 Bowen Road Doncaster East ','Melbourne','Victoria','AUSTRALIA','3109','0398425859','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 13:25:04',0,NULL,3,1,2,1,NULL,'cm411489'),(14499,832407076015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','solracml','solracml@msn.com','Carlos Saavedra Roldán','C. Guayaquil nº17, portal 4. 2ºD<br>La Vaguada','Cartagena','Murcia','SPAIN','30394','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-09 13:27:12',0,NULL,3,1,2,1,NULL,'solracml'),(14500,832405049015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',134,'hutongstore','biomaten','phande@broadpark.no','Per Magne Handegaard','Stekervika 23','STRAUME','Fjell','NORWAY','N5353','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-09 13:38:32',0,NULL,3,1,5,1,'CP227167795CN ','biomaten\r欧标'),(14501,750398701002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','cmartin375','cccmartin2001@yahoo.com','christopher martin','601 gibson dr','madison','TN','UNITED STATES','37115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 13:47:14',0,NULL,3,1,17,0,NULL,'cmartin375'),(14502,750398350002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','cmartin375','cccmartin2001@yahoo.com','christopher martin','601 gibson dr','madison','TN','UNITED STATES','37115','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-09 13:47:37',0,NULL,3,1,1,1,NULL,'cmartin375\r方镜广角托架（ 一槽）    1\r方形滤镜接口环 77mm    1'),(14503,708127112001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','loloestonia','ilmar.selter@lolo.ee','Marta Kinugasa','Viljandi mnt 46a-14','Tartu','Tartumaa','ESTONIA','50412','+37253520595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 13:55:51',0,NULL,3,1,2,1,NULL,'loloestonia\r欧标'),(14504,708511699001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',2,'AE1401',75.98,'hermeshine','edithdidi2011','edithlugoe@yahoo.com.mx','edith lugo alvarez','angel dominguez 5,cto. geografos.<br>satelite,naucalpan edo.de mexico','mexico','naucalpan, edo de mexico','MEXICO','53100','5521112648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 13:57:40',0,NULL,3,1,3,1,'RA183621484CN\r ','edithdidi2011\rRA183621498CN\r'),(14505,750386799002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','tricepa-77','johndo.972@gmail.com','Patrice Faula','1 Place jacques Prevert','Bussy saint georges','Ile-de-France','FRANCE','77600','0617717163','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-09 14:00:37',0,NULL,3,1,4,1,'YW866127275CN ','tricepa-77\r欧标'),(14506,709650086018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','made2by','moremadhu@yahoo.com','Madhusudhan More','2606 Park Ridge Rd','Bloomington','IL','UNITED STATES','61704-8428','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 14:22:34',0,NULL,3,1,1,1,NULL,'made2by\r除了c 里面的再发\r49 cm 接口环    1\r82 cm接口环    1\r广角托架   1\r已入库'),(14507,708670544001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jay11j11','j11jay@hotmail.com','Johnson Gabriel','132 Child St','Hyde Park','MA','UNITED STATES','02136-1717','(617) 407-1329','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 14:27:22',0,NULL,3,0,1,1,NULL,'jay11j11\r1.6*2.1 绿色背景布    1'),(14508,709656183018,280717920072,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',28,'photographyacc','lucasward10','vj4@iinet.net.au','Charles Maekivi','PO Box 369','Mt Hawthorn','Western Australia','AUSTRALIA','6915','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-09 14:37:52',0,NULL,3,1,3,1,'RA183621626CN\r\r ','lucasward10\r新产品\r700'),(14509,708679763001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','marius61968','mariusmieke@yahoo.com','Marius  van Niekerk','26 Ryno Kriellaan<br>Universitas','Bloemfontein','Free State','SOUTH AFRICA','9301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 14:57:58',0,NULL,3,1,2,1,NULL,'marius61968'),(14510,764771490017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','mendonca.furtado','_emf_@walla.com','Mendonça Furtado','Rua Francisco Raposo, nº 10','Porto Formoso','Azores','PORTUGAL','9625-424','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 15:18:43',0,NULL,3,1,2,1,NULL,'mendonca.furtado'),(14511,750446609002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',30,'hermeshine','eccarone','eccarone@uol.com.br','Eduardo Carone Costa Jr','Av. Carandai, 100','Belo Horizonte','Minas Gerais','BRAZIL','30-130-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 16:12:09',0,NULL,3,1,3,1,'RA183621467CN\r ','eccarone\r已入库'),(14512,708709525001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 16:26:26',0,NULL,3,1,2,1,NULL,'viong'),(14513,764798837017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',30.75,'photographyacc','niconable','nicolas.porta@voila.fr','Perfex','Porta Nicolas<br>61 av de Toulouse','Escalquens','Midi-Pyrénées','FRANCE','31750','0687283425','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-09 16:40:35',0,NULL,3,1,3,1,'RA183621572CN\r ','niconable\r天涯方形渐变蓝   1\r天涯方形渐变橙    1\r天涯方形渐变棕    1\r广角托架      1\r77cm 接口环     1\r已入库'),(14514,708722007001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','zeroezero','alex.teix@gmail.com','Alex Teixera','Av. Almirante Alvaro Alberto 180 / 402<br>São Conrado','Rio de Janeiro','Rio de Janeiro','BRAZIL','22610-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 17:01:57',0,NULL,3,1,17,0,NULL,'zeroezero'),(14515,708724147001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','zeroezero','alex.teix@gmail.com','Alex Teixera','Av. Almirante Alvaro Alberto 180 / 402<br>São Conrado','Rio de Janeiro','Rio de Janeiro','BRAZIL','22610-070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 17:06:13',0,NULL,3,1,3,1,'RA183621609CN\r ','zeroezero\r柔光箱 60-60cm  四灯头 欧标    1\r柔光箱 50-70cm 单灯头  欧标    1\r注意需要看一下那个棚是60*60的'),(14516,750476347002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','alcasvi','alcasvi@gmail.com','CASTOR VIDAL MARTINEZ','CARMEN CONDE, 44 6º D','CARTAGENA','Murcia','SPAIN','30204','609943347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 17:30:18',0,NULL,3,1,2,1,NULL,'alcasvi'),(14517,708741292001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','peenewalli','drose@optonline.net','Doreen Rose','1810 Front St<br>Apt 8','East Meadow','NY','UNITED STATES','11554-2454','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-09 17:46:48',0,NULL,3,1,3,1,'RA183621475CN ','peenewalli'),(14518,750494477002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','grediss','geovane.rediss@terra.com.br','Geovane Rediss','Rua Fernão de magalhaes, 158','Novo Hamburgo','RS','BRAZIL','93520-170','5199923676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 18:20:37',0,NULL,3,1,2,1,NULL,'grediss'),(14519,832618651015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','loulou2814','louisejones02@aol.com','louise  jones','19 BULFORD CLOSE','haverfordwest','Pembrokeshire','UNITED KINGDOM','SA623EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 20:43:23',0,NULL,3,1,4,1,'YW866127286CN ','loulou2814'),(14520,750565992002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','mladen_22','nomiste@gmail.com','Mladen Savić','Ravnogorska 27','Banja Luka','Republika Srpska','BOSNIA AND HERZEGOVINA','78000','+38765180745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-09 20:46:24',0,NULL,3,1,2,1,NULL,'mladen_22'),(14521,815341548016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','walkfarman','norman@fireway.screaming.net','Angela Vickers','114 Galsworthy Drive<br>Caversham Park','Reading','Berkshire','UNITED KINGDOM','RG4 6QJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-09 23:07:55',0,NULL,3,1,3,1,'RA183621524CN\r ','walkfarman'),(14522,762278587017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','rick.helen418','rho96436@bigpond.net.au','Rick Hoult','12 Darnum St','Drouin','Victoria','AUSTRALIA','3818','0356252142','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-10 00:00:06',0,NULL,3,1,4,1,'YW866127205CN  ','rick.helen418'),(14523,709622028018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','gmailman1968','jessie_13@bigpond.com','gilbert mailman','7 welcombe av','toowoomba','Queensland','AUSTRALIA','4350','0746347113','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 00:32:35',0,NULL,3,1,2,1,' ','gmailman1968'),(14524,708890695001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','kwi16377','zosick16377@yahoo.com','ESSA DASHTI','18221 150th Ave<br>KWI 26851','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','Other','2011-08-10 01:07:46',0,NULL,3,0,1,1,NULL,'kwi16377\rxl   已入库'),(14525,8881312938950518,111,'Nova4 单肩包  Canon   1',1,'AD1106',0,'hermeshine','davide.agata','davide.torrisi@email.it','Davide Torrisi','Via Lombardia, 59','Acireale','CT','ITALY','95024','3477376891',NULL,NULL,NULL,'2011-08-10 01:15:50',0,NULL,3,1,3,1,'RA183621507CN\r ',NULL),(14526,708902864001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5.2,'hermeshine','26nimrod','dlsind@hotmail.com','dave shively','4800 fencerow ln','lafayette','IN','UNITED STATES','47905-7645','(765) 589-8484','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 01:44:07',0,NULL,3,1,1,1,NULL,'26nimrod'),(14527,708907684001,110718665736,'Official Original Nikon Photo Vest D300 D90 Size XL ',2,'AD1161',110,'hermeshine','rayladur','consray@lino.com','Raymond Ladurantaye','1574, Chemin Sullivan','Val d\'Or','QC','CANADA','J9P1M3','(819) 825-6203','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 02:04:23',0,NULL,3,1,3,1,'RA183621541CN\r ','rayladur\r已入库'),(14528,709903471018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','estebanlt09','esteban.latessa@gmail.com','esteban la tessa','117 foveaux street<br>surry hills','sydney','New South Wales','AUSTRALIA','2010','0406510364','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 02:05:05',0,NULL,3,1,2,1,NULL,'estebanlt09'),(14529,709907619018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','ashleyg6410','ashleygrech@optusnet.com.au','Ashley Grech','5 Norfolk Street','Mt Druitt','New South Wales','AUSTRALIA','2770','0298648535','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 02:22:41',0,NULL,3,1,3,1,'RA183621590CN\r ','ashleyg6410'),(14530,750670103002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','jrc9277','celona2@comcast.net','Rose Celona','5 Surrey Ct','Mount Laurel','NJ','UNITED STATES','08054','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 03:08:47',0,NULL,3,1,4,1,'YW866127566CN ','jrc9277\r'),(14531,8881312949929758,111,'澳标插头',2,'',0,'photographyacc','vitabella68','vitatalmont@gmail.com','Vita Talmont','12 Ferris St','Ermington','New South Wales','AUSTRALIA','2115','0288108136',NULL,NULL,NULL,'2011-08-10 04:18:49',0,NULL,3,0,3,1,'RA183621612CN\r ',' '),(14532,709932084018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','write2nessnow','write2nessnow@hotmail.com','Vanessa Norris','30 Berberis Crescent<br>Frankston','Melbourne','Victoria','AUSTRALIA','3199','0397505307','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-10 04:22:53',0,NULL,3,1,4,1,'YW866127544CN ','write2nessnow\rbackground support $25'),(14533,750697091002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','disel_orenburg','disel@yandex.ru','Dmitry Selishev','pr. Dzerzhinskogo, 3-27','Orenburg','Orenburg reg','RUSSIAN FEDERATION','460044','+7 (912) 846-3626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 05:31:21',0,NULL,3,1,3,1,'RA183621705CN\r ','disel_orenburg'),(14534,709252686018,280663394346,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',80,'photographyacc','coghy87','pikkoloprincipe@msn.com','davide coghene','via e.fermi 19','s.giusta','OR','ITALY','09096','3491424190','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-08-10 06:06:12',0,NULL,3,1,17,0,NULL,'coghy87'),(14535,764339621017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',100,'photographyacc','coghy87','pikkoloprincipe@msn.com','davide coghene','via e.fermi 19','s.giusta','OR','ITALY','09096','3491424190','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 06:07:55',0,NULL,3,1,4,1,'YW866127555CN ','coghy87\r背景架2mx2m  + 3个夹子   1\r背景布 1.6 *2.1   黑色+白色\r灯架  2m     2\r柔光箱 50-70cm 单灯头 欧标   2\r灯架包      1'),(14536,765072711017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',12.99,'photographyacc','hiley37','smiley_hiley@hotmail.com','Susan hiley','37 cadiz st<br>Indooroopilly','Brisbane','Queensland','AUSTRALIA','4068','0732177505','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 07:01:40',0,NULL,3,1,2,1,NULL,'hiley37'),(14537,708960913001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','raimof','fridra@inbox.lv','Raimonds Fridrihsons','Pulkveza Brieza 14, 38','Jelgava','','LATVIA','3001','+37126495778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 07:01:43',0,NULL,3,0,2,1,NULL,'raimof\r1.6*2.1 黑色背景布  1'),(14538,765050175017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','jmax987','maxwell4@westnet.com.au','Pamela Maxwell','P.O Box 853','Maleny','Queensland','AUSTRALIA','4552','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 07:27:43',0,NULL,3,1,2,1,NULL,'jmax987'),(14539,750724583002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','jp-photo.dk','ebay@jp-photo.dk','Jan Petersen','Simestedgaardvej 9','Nibe','','DENMARK','9240','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 08:06:15',0,NULL,3,1,2,1,NULL,'jp-photo.dk\r斜壁那个沙袋'),(14540,750728391002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dingdongnz','hairynz@slingshot.co.nz','Dion Mellow','11 Sillary st<br>Hamilton East','Hamilton','','NEW ZEALAND','3216','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 08:25:12',0,NULL,3,0,3,1,'RA183621691CN ','dingdongnz\r3XL  已入库'),(14541,709977202018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',67,'photographyacc','arale_pcr','arale_pcr@hotmail.com','Paloma Cano Rovirosa','C/A Sainz de Baranda Nº 56 7º Izda','Madrid','Madrid','SPAIN','28009','686889773','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 08:40:16',0,NULL,3,1,4,1,'YW866127500CN\r','arale_pcr\r布换成1.6x4m 灰色   1'),(14542,750525882002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','freikeap','eikpedersen@gmail.com','Eik Andreas Pedersen','Bronzealdervænget 12, 1. 7','aarhus V,','Denmark','DENMARK','8210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 09:08:55',0,NULL,3,1,3,1,'RA183621904CN\r ','freikeap'),(14543,750765703002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','kimilio','kimilio98@hotmail.com','joaquin monne lopez','padre lainez, 37 1º','barcelona','Cataluña','SPAIN','08025','932191833','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 11:08:14',0,NULL,3,1,3,1,'RA183621793CN\r ','kimilio'),(14544,707228794018,280717920072,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',28,'photographyacc','mininggirl81','debbie.stewart@live.com.au','Debbie Gibson','14 WENN ROAD','SINGLETON','Western Australia','AUSTRALIA','6175','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 11:20:18',0,NULL,3,1,3,1,'RA183621674CN\r ','mininggirl81'),(14545,708657055001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shaw_bd76','shawkat_alam@yahoo.com','A.N.M. Shawkat Alam','C/O Standard Chartered Bank, Al Fardan Buildng Mezzanine Floor<br>Al Mankhool Road, Bur Dubai. Dubai.','Dubai','Dubai','UNITED ARAB EMIRATES','999','+971505517792','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 11:38:45',0,NULL,3,1,2,1,NULL,'shaw_bd76'),(14546,709023226001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','nalrml','sveaborg@telia.com','Stefan Larsson','Hågavägen 11','Arboga','','SWEDEN','732 33','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 11:45:24',0,NULL,3,1,2,1,NULL,'nalrml'),(14547,765155609017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','333arnold','imaginethat07@gmail.com','Chris Arnold','97 Cossington Smith Crescent, Lyneham','Canberra','Australian Capital Territory','AUSTRALIA','2602','0262480774','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-10 12:26:07',0,NULL,3,1,4,1,'YW866127522CN ','333arnold\r澳标\r Lighting  Kit   $28'),(14548,750797601002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','itsfyn','mb@itsfyn.dk','Mads Binger','Mandal Allé 8A','Middelfart','Fyn','DENMARK','5500','64403031','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 13:02:56',0,NULL,3,0,3,1,'RA183621728CN\r ','itsfyn\r3xl   已入库'),(14549,709045121001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','stein_johan','sebastian@sebastianludvigsen.com','sebastian ludvigsen','Goteborg gata 27 b,  2. etg.,','Oslo','','NORWAY','N-0566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 13:05:16',0,NULL,3,0,3,1,'RA183621970CN\r ','stein_johan\rcanon  77 cm 镜头盖    10  \r已入库'),(14550,765173050017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',4,'AA1203',11.6,'photographyacc','kkhan11514480u','kkhan11514@aol.com','Kevin Khan','6384 coventry way','clinton','MD','UNITED STATES','20735-2256','(240) 832-0051','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 13:16:13',0,NULL,3,1,1,1,NULL,'kkhan11514480u'),(14551,709052482001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','zlobniq','p.karapetkov@gmail.com','Plamen Karapetkov','25 Tzar Asen Str.','Plovdiv','Plovdiv','BULGARIA','4000','+359885786740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 13:28:35',0,NULL,3,1,17,0,NULL,'zlobniq'),(14552,750813405002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','zlobniq','p.karapetkov@gmail.com','Plamen Karapetkov','25 Tzar Asen Str.','Plovdiv','Plovdiv','BULGARIA','4000','+359885786740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 13:56:30',0,NULL,3,1,2,1,NULL,'zlobniq\r52-52mm 双阳环    1\r天涯方形滤镜  渐变灰    1'),(14553,709067975001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','eegypto','eyogui@hotmail.com','Elaine Egypto','Rua Barao do Triunfo, 550 - cj 54','Sao Paulo','Sao Paulo','BRAZIL','04602002','551150930750','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 14:19:55',0,NULL,3,1,5,1,'CP227167469CN ','eegypto\r1.6*2.1 黑色+白色背景布'),(14554,709072141001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','tr_norway','trye@online.no','Torgeir Rye','Sondre husebytun 12E','default','SAUPSTAD','NORWAY','7097','+4741020907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 14:32:32',0,NULL,3,1,17,0,NULL,'tr_norway'),(14555,710081162018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','bobs-toys49','otd86866@aol.com','Robert Curell','7879 Grandview','Show Low','Az','UNITED STATES','85901-8613','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 14:38:22',0,NULL,3,1,1,1,NULL,'bobs-toys49\r除了c 里面的再发\r49cm 接口环    1\r82 cm 接口环     1\r广角托架    1\r已入库'),(14556,709074743001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','tr_norway','trye@online.no','Torgeir Rye','Sondre husebytun 12E','default','SAUPSTAD','NORWAY','7097','+4741020907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 14:41:09',0,NULL,3,1,5,1,'CP227167472CN ','tr_norway\r柔光箱 60-60cm  四灯头  欧标    2'),(14557,750828084002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','unihiekka','epheral@hotmail.com','Macarena Jiménez Nogales','Kaarikuja 5 C 66','Helsinki','','FINLAND','00940','458883840','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 14:46:26',0,NULL,3,1,4,1,'YW866127511CN ','unihiekka\r欧标\r Lighting Kit   $28'),(14558,750835027002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','kbro7815','broumand@hotmail.com','Kamyar Broumand','Schavei 69','Overijse','','BELGIUM','3090','+3226876031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 15:01:41',0,NULL,3,1,2,1,NULL,'kbro7815\r斜壁里的沙袋'),(14559,750837692002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','k95lc02','lcole@nowhereville.org','Leah Cole','5804 Mackenzie Dr','Kewadin','MI','UNITED STATES','49648-9098','(231) 330-8795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 15:09:50',0,NULL,3,1,1,1,NULL,'k95lc02'),(14560,8881312989884914,111,'天涯渐变灰 x 1， 广角托架 x 1',1,'',0,'hermeshine','miginium','mel@migin.net','Melvin Migin','G 10, Lorong Kenari 3,<br>Taman Likas Jaya,','Kota Kinabalu','Sabah','MALAYSIA','88400','0168103500',NULL,NULL,NULL,'2011-08-10 15:24:44',0,NULL,3,0,3,1,'RA183621665CN\r ','渐变灰 x 1\r广角托架 x 1\r渐变灰要好好检查一下\r（已入库） '),(14561,765221284017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','andrew.ong.07','onga07@gmail.com','Andrew Ong','34 Johanson Promenade','Murdoch','Western Australia','AUSTRALIA','6150','0893329676','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-10 15:34:56',0,NULL,3,1,2,1,NULL,'andrew.ong.07'),(14562,710101012018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','helmeczi19','rhondah19@gmail.com','Rhonda Helmeczi','115, 1808 36 Ave SW','Calgary','AB','CANADA','T2T 6J2','(403) 802-1422','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-10 15:35:48',0,NULL,3,1,3,1,'RA183621802CN\r','helmeczi19'),(14563,815633333016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:38:42',0,NULL,3,1,17,0,NULL,'trebor.m'),(14564,815627704016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:38:42',0,NULL,3,1,17,0,NULL,'trebor.m'),(14565,832970470015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:38:43',0,NULL,3,1,17,0,NULL,'trebor.m'),(14566,832966647015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'AKT026',17,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:38:43',0,NULL,3,1,17,0,NULL,'trebor.m'),(14567,815631789016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 15:38:44',0,NULL,5,1,3,1,'RA183621759CN\r ','trebor.m\r电话是：+44(0)1516390789 \r天涯方形滤镜  渐变灰    3\r方形滤镜接口环 67mm    1\r方镜普通托架（三槽）     1\r3片装的滤镜袋     1\r天涯方形滤镜  ND4     1\r天涯方形滤镜  ND8      1\r方形滤镜接口环 58mm      1\r广角托架    1\r已入库   包的东西不对，看着调整\r已发货  点不了\r'),(14568,750848232002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','shay_jackal','shay.as@hotmail.com','Shay Ashkenazy','Remez 41<br>apr. 2','Rishon Le Zion','Rishon Le zion','ISRAEL','75238','+972526024760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 15:42:18',0,NULL,3,1,3,1,'RA183621864CN\r ','shay_jackal'),(14569,709097283001,110718725568,'New Soft Camera Bag Case Cover Nikon D700 + 24-70mm',1,'AD1112',7.8,'hermeshine','marrel76','marrel76@libero.it','Fam. Corvi','Quercia del Vento, 2 (SP 59 Dir. Amelia)<br>GPS: 42° 28\' 39.60\" N , 12° 24\' 2.18\" E','Orte (VT)','VT','ITALY','01028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 16:18:32',0,NULL,3,1,2,1,NULL,'marrel76'),(14570,833041192015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','srakic','stephenrakic@yahoo.co.uk','Steve rakic','84 beeches road','west bromwich','west midlands','UNITED KINGDOM','b70 6hj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-10 17:54:59',0,NULL,3,1,2,1,NULL,'srakic'),(14571,750928846002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','medtagen74','aingemansson@hotmail.com','Andreas Ingemansson','Regeringsgatan 8','Karlshamn','','SWEDEN','37434','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:02:19',0,NULL,3,1,17,0,NULL,'medtagen74'),(14572,709168371001,110718725568,'New Soft Camera Bag Case Cover Nikon D700 + 24-70mm',1,'AD1112',7.8,'hermeshine','medtagen74','aingemansson@hotmail.com','Andreas Ingemansson','Regeringsgatan 8','Karlshamn','','SWEDEN','37434','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:02:19',0,NULL,3,1,2,1,NULL,'medtagen74\rlenspen     2\r内胆包无字加大     1'),(14573,709180307001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mjohn290','mcdonaldajohn@live.com','Mcdonald John','PO Box 1653<br>1K Wheel of Fortune','Frederiksted','VI','UNITED STATES','00841-1653','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-10 19:14:12',0,NULL,3,1,1,1,NULL,'mjohn290'),(14574,833094735015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mpopescu2007','marius.popescu@gmail.com','Marius Popescu','4 Persefonis Street<br>Clariges 3 Building, Flat 202','Lemesos','','CYPRUS','3105','+35799018160','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-10 19:22:37',0,NULL,3,1,2,1,'\r ','mpopescu2007'),(14575,709190883001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','cancan4141','erolyilmaz4141@gmail.com','erol yılmaz-yaşar pekçevik','sera çiçekevi<br>kemalpaşa mah.leyla atakan cad.no:16','izmit','kocaeli','TURKEY','41300','0541 820 4141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 19:35:44',0,NULL,3,1,2,1,NULL,'cancan4141'),(14576,709174928001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 19:37:23',0,NULL,3,1,17,0,NULL,'saud-p'),(14577,709171057001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 19:37:26',0,NULL,3,1,17,0,NULL,'saud-p\r'),(14578,709207618001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mannybeach','mannyguisa@gmail.com','Manny Guisa','811 E G St<br>Ste A','Wilmington','CA','UNITED STATES','90744-6021','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,7,1,18,0,'','mannybeach'),(14579,833130077015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','the.griswolds','email@mykandy.info','Elizabeth Paton','78 Barn Glebe','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 7JZ','01225352101','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-08-10 20:23:44',0,NULL,3,1,4,1,'YW866127496CN ','the.griswolds\r英标\rLighting  Kit   $25'),(14580,709214784001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','alpha19','ajsantos74@gmail.com','Arsenio Santos','612 Welland Ave<br>Unit A','St. Catharines','ON','CANADA','L2M 5V6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 20:30:54',0,NULL,3,1,17,0,NULL,'alpha19'),(14581,750973282002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','alpha19','ajsantos74@gmail.com','Arsenio Santos','612 Welland Ave<br>Unit A','St. Catharines','ON','CANADA','L2M 5V6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 20:30:55',0,NULL,3,1,17,0,NULL,'alpha19'),(14582,750973088002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','alpha19','ajsantos74@gmail.com','Arsenio Santos','612 Welland Ave<br>Unit A','St. Catharines','ON','CANADA','L2M 5V6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-10 20:30:55',0,NULL,3,0,2,1,NULL,'alpha19\r普通有线快门线N1    1\rNIKON 镜头盖 77mm    1\rHB-7 花瓣      1'),(14583,750992498002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','fotografiamoreno','fotografiajosemoreno@gmail.com','Jose Moreno','URB BAIROA GOLDEN GATE 2<br>O13 CALLE H','Caguas','PR','UNITED STATES','00727-1119','787 645 8516','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 21:17:15',0,NULL,3,1,3,1,'RA183621688CN\r ','fotografiamoreno'),(14584,709257164001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','virusinc','mahendra@virusinc.org','Mahendra Gunaratne','No. F84/1, Uthuwana<br>Uthuwankande','Mawanella','Sabaragamuwa','SRI LANKA','71500','+94777783468','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-10 22:32:57',0,NULL,3,1,2,1,NULL,'virusinc'),(14585,709254868001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','brazellw','rh_brazell@hotmail.com','william brazell','507 Avondale Rd','montgomery','AL','UNITED STATES','36109-4529','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 23:10:47',0,NULL,3,0,1,1,NULL,'brazellw\r1.6*2.1  黑色背景布   1'),(14586,751038039002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',29.99,'hermeshine','scoaks','s.aksamit@comcast.net','scott aksamit','4353 oakdale ave s','edina','MN','UNITED STATES','55424-1071','(952) 926-1777','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-10 23:47:24',0,NULL,3,1,1,1,NULL,'scoaks'),(14587,751074684002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mabtokyo','mburgess@zaa.att.ne.jp','Mark Burgess','3-3-14 Naruiwa, Chelt no mori,<br>Toyohira','Chino','Nagano','JAPAN','391-0213','8180-6507-2416','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 02:18:58',0,NULL,3,1,3,1,'RA183621820CN\r ','mabtokyo'),(14588,765466076017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','razzmadazz99','ramon_chan91@hotmail.com','Ray Chan','37/1 Celestial Crt','Carina','Queensland','AUSTRALIA','4152','0420970388','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 02:21:13',0,NULL,3,0,2,1,' ','razzmadazz99'),(14589,709316307001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',3,'AKT029',72,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 02:41:55',0,NULL,3,0,3,1,'RA183621731CN\r ','mariomarques.com.br\r58mm Canon (镜头盖) x 20\r72mm Canon (镜头盖) x 5\r77mm Canon (镜头盖) x 5'),(14590,710341381018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',6.6,'photographyacc','gareths1980','garethschubert@internode.on.net','Gareth Schubert','PO Box 1163','Broome','Western Australia','AUSTRALIA','6725','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 02:49:08',0,NULL,3,1,2,1,NULL,'gareths1980'),(14591,751082561002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','miss_sunshine.312','lana.cosic@gmail.com','Lana Cosic','Luščić 41c / Vukašinović','Karlovac','Croatia','CROATIA','47 000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 02:49:32',0,NULL,3,1,3,1,'RA183621816CN\r ','miss_sunshine.312'),(14592,709324625001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 03:16:13',0,NULL,3,1,3,1,'RA183621776CN\r ','denisyana'),(14593,765483843017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','pc_games_man','quintonwevans@gmail.com','Quinton Evans','51 Fairview Street','Bayview Heights','Queensland','AUSTRALIA','4868','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 03:43:35',0,NULL,3,1,17,0,NULL,'pc_games_man'),(14594,710351313018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',225,'photographyacc','pc_games_man','quintonwevans@gmail.com','Quinton Evans','51 Fairview Street','Bayview Heights','Queensland','AUSTRALIA','4868','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-11 03:43:34',0,NULL,3,1,4,1,'YW866127485CN ','pc_games_man\r除了c 里面的再发\r一转四 灯头    1\r澳标\r Lighting  kit  $30'),(14595,709331400001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','maruayjaa','maruayja@gmail.com','Supa sukhochaiyakit','93/444 lumpini ville Prachacheun Rd.','Bangkaen','nontaburi','THAILAND','11000','66896793332','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 03:52:42',0,NULL,3,1,2,1,NULL,'maruayjaa'),(14596,765489921017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','poojtannum','ypooj@tpg.com.au','Alex Banks','14 Plymouth<br>Quay','Maroochydore','Queensland','AUSTRALIA','4558','0754793072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 04:04:39',0,NULL,3,1,2,1,NULL,'poojtannum'),(14597,8881313042293752,111,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',0,'hermeshine','eugenepowers','gene007@powersandpowers.com','Eugene Powers','5764 Chicopee Ave','Encino','CA','UNITED STATES','91316-1305','',NULL,NULL,NULL,'2011-08-11 05:58:13',0,NULL,5,0,18,0,' ','eugenepowers\r3xl   (已入库）\r---\r客户说第一次发的尺码太小，这次发货前先量一下，尽量找件大点的（身长67cm；胸围130cm以上）'),(14598,705594221001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kelvinbu','calvinbu@hotmail.com','BU CI XIAN','334,JALAN 17/6<br>SECTION 17','PETALING JAYA','Selangor','MALAYSIA','46400','0172697530','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-11 06:13:37',0,NULL,3,0,3,1,'RA183621762CN\r ','kelvinbu\rxxl    已入库'),(14599,8881313044444255,111,'wf1003   x  1',1,'AE1602',0,'photographyacc','ivana.talijan','vladimir.talijan@gmail.com','Ivana Talijan','Grcica Milenka 4a','Belgrade','','SERBIA','11000','381607374555',NULL,NULL,NULL,'2011-08-11 06:34:04',0,NULL,3,1,3,1,'RA183621855CN\r ',''),(14600,709368589001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','third_sunbeam','third_sunbeam@lycos.com','Jean-Robin Ladin Ladin','P.O.Box 1690<br>Surfers Paradise','Gold Coast','Queensland','AUSTRALIA','4217','61406938327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 07:38:17',0,NULL,3,1,4,1,'YW867472563CN ','third_sunbeam\r澳标\rlighting kit $35\r---\r新地址：\rJean-Robin Ladin Ladin\r6/2991 Gold Coast HWY, \rSurfers Paradise\rGold Coast Queensland 4217\rAUSTRALIA\r61406938327\r已收到'),(14601,709378515001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 08:33:50',0,NULL,3,1,6,1,'EE495341167CN ','buyedv\r'),(14602,707932828001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','dimayulanikita','dimaser1978@mail.ru','Дмитрий Казанцев','Пушкинская 253, 3','Ижевск','Удмуртия','RUSSIAN FEDERATION','426008','89090629070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 08:54:14',0,NULL,3,1,3,1,'RA183621878CN\r ','dimayulanikita'),(14603,751149283002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','bluandreone','fotografo959@gmail.com','Andrea Muti','via Leopardi 51','Osimo','AN','ITALY','60027','3331737033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 09:01:03',0,NULL,3,1,3,1,'RA184551056CN\r ','bluandreone\rsoftbox  $10'),(14604,750855756002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',21.9,'hermeshine','ycrpdm','yocarpediem@gmail.com','JUAN DE DIOS MAESTRE QUINTERO','C/ MARE DE DEU DE LORDA 28 SOBREATICO','BARCELONA','Cataluña','SPAIN','08033','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 09:16:14',0,NULL,3,1,3,1,'RA184551042CN\r ','ycrpdm'),(14605,765554878017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',2,'AA3303',11.58,'photographyacc','lourissa','xcmusic@bigpond.net.au','leanne irwin','36 IRONBARK RD','MUSWELLBROOK','New South Wales','AUSTRALIA','2333','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 09:38:00',0,NULL,3,1,2,1,NULL,'lourissa\rcanon   58 cm   镜头盖     2\r绿叶 UV  58mm     2\r已入库'),(14606,751164553002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','mr.des_lebedev','des_@i.ua','Roman Lebedev','ul. Terehovskogo 32','Krivoy Rog','','UKRAINE','50045','+380684064321','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 10:10:45',0,NULL,3,1,2,1,NULL,'mr.des_lebedev'),(14607,765564048017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','underdog_punk182','danielseath@gmail.com','Daniel Seath','P.O Box 183','Balwyn','Victoria','AUSTRALIA','3103','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 10:15:15',0,NULL,3,1,2,1,NULL,'underdog_punk182'),(14608,751166043002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kz.serg','serega2006@km.ru','Sergey Turkevich','9 mikraion d81 kv16','Temirtau','','KAZAKHSTAN','101400','77017359066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 10:18:20',0,NULL,3,1,3,1,'RA183621881CN\r ','kz.serg'),(14609,710430304018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',70,'photographyacc','tuska03','davepickford75@hotmail.com','Dave','4 Bowerbird Place<br>Burleigh Waters','Gold Coast','Queensland','AUSTRALIA','4220','0412607716','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 10:27:08',0,NULL,3,1,3,1,'RA183621966CN\r ','tuska03'),(14610,710255437018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','benjaminxuu','x.zhou@hotmail.com','Zhou Xu','Unit 3<br>24 Alexander Ave','Oakleigh East','Victoria','AUSTRALIA','3166','0433537285','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-11 10:28:06',0,NULL,3,1,2,1,NULL,'benjaminxuu'),(14611,751169480002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.78,'hermeshine','king32_168','antony.king32@yahoo.com','Youn Fatt Lu','54 Vine Street','Hurstville','New South Wales','AUSTRALIA','2220','0295852063','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-08-11 10:35:01',0,NULL,3,1,2,1,NULL,'king32_168\r澳标'),(14612,708656605001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','deborahwar','dwaricka@yahoo.com','DEBORAH or DON WARICKA','8453 SHADY GLEN DRIVE','ORLANDO','FL','UNITED STATES','32819','(407) 926-6104','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-11 11:18:26',0,NULL,3,1,1,1,NULL,'deborahwar'),(14613,765586019017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','apinheirinho','pinheirinho1986@gmail.com','Augusto Pinheirinho','Rua João Martins n.º 41','Setúbal','Setúbal','PORTUGAL','2910-160','(+351)913933701','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 11:36:50',0,NULL,3,1,2,1,' ','apinheirinho'),(14614,751202732002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','bartikyan','michael@bartikyan.com','Mikayel Bartikyan','Za Valem 1315/3','Prague','','CZECH REPUBLIC','14800','+420608432828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 12:40:49',0,NULL,3,1,3,1,'RA183621952CN\r ','bartikyan'),(14615,709456420001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','knights.who.say.nee','knightswhosaynee1@gmail.com','Shellie Benson','8005 Chug Run Rd','Dresden','OH','UNITED STATES','43821-9026','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-11 13:45:18',0,NULL,3,1,1,1,NULL,'knights.who.say.nee'),(14616,710503737018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',2,'AB1406',14.56,'photographyacc','palotair','palotai@mediacenter.hu','Palotai Robert','Bartok Bela str 44 FSZ/6','Budapest','Budapest','HUNGARY','1114','+36709476400','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 14:37:51',0,NULL,3,1,2,1,NULL,'palotair'),(14617,833471898015,250606686008,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'AA2201',2.75,'hutongstore','saker83','medic2849@yahoo.co.uk','Andrew Wright','30 Lissimore Drive<br>Tividale','Tipton','West Midlands','UNITED KINGDOM','DY4 7SX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 14:58:07',0,NULL,3,1,2,1,NULL,'saker83'),(14618,833529060015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','blessingtonlakes2010','dereklawless1980@gmail.com','Derek Lawless','holy valley<br>Blessington','Wicklow','Wicklow','IRELAND','default','0876132021','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 17:08:31',0,NULL,3,1,2,1,NULL,'blessingtonlakes2010'),(14619,751301106002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-11 17:41:12',0,NULL,3,1,3,1,'RA184551039CN\r ','300671igor'),(14620,833565901015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','779ykj','neil.whitehead@mailcity.com','neil whitehead','85 Ilthorpe','Hull','Yorkshire','UNITED KINGDOM','HU6 9EP','07986579729','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 18:16:40',0,NULL,3,1,2,1,NULL,'779ykj'),(14621,709567959001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','bismarke2011','bismarke1@gmail.com','Bismarke Jose','Radio Nacional de Angola<br>Rua comandante Gika','Luanda','Luanda','ANGOLA','1329','00244923515374','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-11 19:00:29',0,NULL,3,1,3,1,'RA184551966CN ','bismarke2011\r1.6*2.1 黑色+白色背景布    \r1.6x2.1m 背景布 * 3 （粉、红、兰）\rRA184551921CN\rRA184551970CN'),(14622,833592955015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',27,'hutongstore','nenomart2010','mail@desenho3d.com','Nelson Martins','Rua Silvério Raposo - 59, 2º Dto','Alcobaça','Leiria','PORTUGAL','2460 075','962335529','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 19:04:30',0,NULL,3,1,3,1,'RA184551025CN\r ','nenomart2010\r欧标'),(14623,710615841018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','azgek','azgekstock@gmail.com','Sergey Mostovoy','Nab. Pobedy str., 130/5/65','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49106','+380503169362','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 19:19:22',0,NULL,3,1,5,1,'CP227167486CN ','azgek\r1.6*2.1 灰色背景布    1'),(14624,709569873001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-11 19:20:11',0,NULL,3,0,3,1,'RA183622003CN ','saud-p\r背景架2m x 3m + 3个夹子   2\r背景架2mx2m  + 3个夹子    1\r1.6*2.1  黑色+白色背景布  \r注意需要在灯架上贴made in china  \r还需要申报实值\r5个小包\rRA183621921CN\rRA183621833CN\rRA183621997CN\rRA183621983CN\r\r'),(14625,765775374017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','sandispriede','sandis.priede@gmail.com','Sandis Priede','Pulkveza Brieza iela 14','Jurmala','Rigas raj','LATVIA','LV-2015','+37129515202','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-11 19:55:49',0,NULL,3,1,2,1,NULL,'sandispriede'),(14626,816290424016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',4,'AA1205',6,'hutongstore','iras5661','marilar.irastorza@gmail.com','Pilar Irastorza de la Cavada','Pl. Francisco Perojo Cagias, 7','Solares','Cantabria','SPAIN','39710','942523884','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 20:17:16',0,NULL,3,1,2,1,NULL,'iras5661'),(14627,709610245001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','manzanoaanalyn','analyn.manzano@yahoo.com','Analyn Manzano','5112 Kalika St','Kapaa','HI','UNITED STATES','96746-2022','','NoPaymentFailure','CheckoutComplete','Other','2011-08-11 20:30:11',0,NULL,3,1,4,1,'YW867472552CN ','manzanoaanalyn\r1.6*2.1 黑色+白色背景布\rBackground Support   $25'),(14628,833643418015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','kai.jokela_123','kaijokela@gmail.com','Kai Jokela','Leipäläntie 62','Turku','','FINLAND','20300','+358 44 011 1147','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 20:35:54',0,NULL,3,1,2,1,NULL,'kai.jokela_123'),(14629,709633944001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-11 21:33:44',0,NULL,3,1,3,1,'RA183621935CN\r ','paulolagoaseca2010\r新地址\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(14630,833688186015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','samantha0340','bevansebastian@hotmail.com','SEBASTIAN BEVAN','10 LAYWELL CLOSE','BRIXHAM','DEVON','UNITED KINGDOM','TQ50DN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 22:02:12',0,NULL,3,1,3,1,'RA183621847CN\r ','samantha0340'),(14631,833709372015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','zippyfurious','zippyfurious@hotmail.com','Matteo Reinerio','Corso Francia 54','Torino','TO','ITALY','10143','+393396161722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-11 23:01:29',0,NULL,3,1,2,1,NULL,'zippyfurious'),(14632,709660842001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','marisete10','marisetemuniz2010@hotmail.com','marisete muniz de lima','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','Paraíba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-11 23:08:24',0,NULL,3,1,3,1,'RA183621949CN ','marisete10\r新地址\rMARISETE MUNIZ DE LIMA\rRua Joao Francisco de Oliveira, 233\rcentro\rLagoa Seca  - Paraiba\r58117-000\rBrazil\rtelefone 83 3366-1044\r注意字体\r\r'),(14633,833714157015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.9,'hutongstore','hatter48','wieege1@virginmedia.com','G M Sheridan','14 Gilbey Close','Wellingborough','Northamptonshire','UNITED KINGDOM','NN9 5YG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-11 23:19:40',0,NULL,3,1,2,1,NULL,'hatter48'),(14634,833737723015,250599389839,'55mm CPL Circular Polarizing Filter 55 CPL Green.L New',1,'AA3309',3.68,'hutongstore','vladek123','vladek@neti.ee','Wladek  Saar','Jarveotsa tee 13 - 93','Tallinn','Estonia','ESTONIA','13520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 00:38:38',0,NULL,3,1,17,0,NULL,'vladek123'),(14635,816389174016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','vladek123','vladek@neti.ee','Wladek  Saar','Jarveotsa tee 13 - 93','Tallinn','Estonia','ESTONIA','13520','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 00:38:39',0,NULL,3,1,2,1,NULL,'vladek123\r绿叶 CPL  55mm      1\r绿叶 CPL  67mm         1'),(14636,710727426018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','urbanrangers','freakybaboon@yahoo.com','Jei Shen Chang','PO Box 3850','Marsfield','New South Wales','AUSTRALIA','2122','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 00:47:49',0,NULL,3,1,3,1,'RA183621895CN\r ','urbanrangers'),(14637,765879584017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','hall_a_k_hall','hall_k_a@yahoo.com.au','Kim Hall','8 Placid Court<br>JOONDALUP','Perth','Western Australia','AUSTRALIA','6027','0893000491','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-12 00:56:34',0,NULL,3,1,4,1,'YW867472541CN ','hall_a_k_hall\rTripod   $25'),(14638,751459947002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','myong_h','myong_h@hotmail.com','Myong Hong (docomo pacific)','219 S Marine Corps Dr<br>Ste 206','Tamuning','GU','UNITED STATES','96913-3927','(671) 929-6905','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 01:19:00',0,NULL,3,1,17,0,NULL,'myong_h'),(14639,765886110017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','jlvbam','jackiev@netspace.net.au','Jackie Van','89A Cheltenham Road','Dandenong','Victoria','AUSTRALIA','3175','0438113412','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 01:20:51',0,NULL,3,1,2,1,NULL,'jlvbam'),(14640,709693083001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','myong_h','myong_h@hotmail.com','Myong Hong (docomo pacific)','219 S Marine Corps Dr<br>Ste 206','Tamuning','GU','UNITED STATES','96913-3927','(671) 929-6905','NoPaymentFailure','CheckoutComplete','Other','2011-08-12 01:27:21',0,NULL,3,1,4,1,'YW867472530CN ','myong_h\r闪光的柔光箱   60cm   1\r背景架2mx2m  + 3个夹子    1\r1.6*2.1 黑色+白色背景布\rBackground Support   $28'),(14641,765890034017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.5,'photographyacc','tania_82','tania_stanley82@hotmail.com','Tania Stanley','20 Gerbera Crescent<br>Strathpine','Brisbane.','Queensland','AUSTRALIA','4500','0437645900','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 01:43:08',0,NULL,3,1,2,1,NULL,'tania_82'),(14642,833757763015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','shahabuddin','shahab.uk@gmail.com','shahab uddin','837 Cranbrook Road<br>Ilford','Essex','London','UNITED KINGDOM','IG6 1JD','07737496210','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-08-12 01:47:10',0,NULL,3,1,4,1,'YW867472526CN ','shahabuddin\r英标   \rLighting Kit  $28'),(14643,765893541017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','debuofcoursewhoelse','dev.p.singh@uts.edu.au','D Singh','2 Somerset Street','Stanhope Gardens','New South Wales','AUSTRALIA','2765','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 01:49:02',0,NULL,3,1,2,1,NULL,'debuofcoursewhoelse'),(14644,710738814018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','somsay2000','noyng_toumngeun@hotmail.com','Noyng Toumngeun','Level 4<br>440 Collins Street','MELBOURNE','Victoria','AUSTRALIA','3000','0390773322','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-12 01:53:14',0,NULL,3,1,4,1,'YW867472515CN ','somsay2000\rBackground Support  $25\r已经收到'),(14645,710744887018,280666916076,'New Fancier Complete Tripod 531BT with Ball head 531BH',1,'AE1102',65,'photographyacc','krotovalex','krotov.alex@gmail.com','Alex Krotov','2/16 Parkside Walk','Hoppers Crossing','Victoria','AUSTRALIA','3029','0406627585','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 02:01:20',0,NULL,3,1,4,1,'YW867472504CN ','krotovalex\r Tripod    $25\r已经收到'),(14646,8881313117650577,111,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',17.9,'hermeshine','markcho817','markshermanc@yahoo.com.hk','Mark Cho','北角英皇道663號泓富產業千禧廣場1606-09室','香港','','香港','','62821605 ',NULL,NULL,NULL,'2011-08-12 02:54:10',0,NULL,3,1,14,1,'301117257648 ',NULL),(14647,751486876002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','altaf1214','altafusa@gmail.com','altaf  Hussain','3730 62nd St','woodside','NY','UNITED STATES','11377-2624','(917) 642-0843','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 03:13:00',0,NULL,3,1,17,0,NULL,'altaf1214'),(14648,709715389001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','altaf1214','altafusa@gmail.com','altaf  Hussain','3730 62nd St','woodside','NY','UNITED STATES','11377-2624','(917) 642-0843','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-12 03:13:01',0,NULL,3,1,1,1,NULL,'altaf1214\rCANON 镜头盖  58mm    2\r橡胶遮光罩 58mm         1\r'),(14649,751488301002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','abpitkevich','gromazek@gmail.com','Artem Pitkevich','Borodinskaya<br>1-65','Saint-Petersburg','','RUSSIAN FEDERATION','191180','921-752-0426','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 03:21:53',0,NULL,3,1,2,1,NULL,'abpitkevich'),(14650,751493752002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','niemalshier','wirwarenniemalshier@yahoo.es','Raquel Leton','Av. Monforte de Lemos 165, 11-1','Madrid','Madrid','SPAIN','28029','913863684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 03:44:56',0,NULL,3,1,17,0,NULL,'niemalshier'),(14651,751494220002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','niemalshier','wirwarenniemalshier@yahoo.es','Raquel Leton','Av. Monforte de Lemos 165, 11-1','Madrid','Madrid','SPAIN','28029','913863684','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 03:47:23',0,NULL,3,1,4,1,'YW866127474CN ','niemalshier\r灯架  2m    3\r柔光箱 60-60cm  四灯头欧标    2\r45w 5500k 灯泡 220v       8\r800w  220v 灯泡      1\r800w红头灯   欧标       1\r灯架包         1\rLighting kit      $35\r▲燕文告知 由于地址错误  现在在当地邮局 需要联系客户  但是从燕文网站查询收到了\r'),(14652,8881313129235040,111,'背景布2块',2,'',30.98,'hermeshine','brandon1999boats','Tasha.maynard@bigpond.com','Tasha maynard','1a Tamar Avenue','George Town','Tasmania','AUSTRALIA','7253','+0400074665',NULL,NULL,NULL,'2011-08-12 06:07:15',0,NULL,3,0,3,1,'RA184551405CN\r ','背景布 1.6x2.1m * 1 （蓝色)\r背景布 1.6x4.0m * 1 （白色) '),(14653,8881313129844772,111,'EW-73B  X   1',1,'AA3408',0,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885',NULL,NULL,NULL,'2011-08-12 06:17:24',0,NULL,3,1,3,1,'RA184551317CN\r ','检查一下，确保成色好 \r仔细包装，上一个路上被磨花了'),(14654,833826180015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','tbmod','tbmod.com@gmail.com','Thomas Bell','17 rte du Rostrenen','Plouguernevel','Bretagne','FRANCE','22110','0256436027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 06:38:54',0,NULL,3,1,2,1,NULL,'tbmod'),(14655,710794800018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','khi-santh','sebastian.becher@abs.gov.au','sebastian becher','1 Nangor St','Waramanga','Australian Capital Territory','AUSTRALIA','2611','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 06:40:22',0,NULL,3,1,2,1,NULL,'khi-santh'),(14656,765960677017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','krusty5210','russell.leaver@bigpond.com','russell leaver','2a mosher way','karratha','Western Australia','AUSTRALIA','6714','0417978301','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 07:23:10',0,NULL,3,1,2,1,NULL,'krusty5210'),(14657,833718360015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','ekillingbeck','elliottkillingbeck@gmail.com','Elliott Killingbeck','42 Blackthorn Crescent','Farnborough','Hampshire','UNITED KINGDOM','GU14 9AF','07842823672','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 08:19:21',0,NULL,3,1,2,1,NULL,'ekillingbeck'),(14659,833066520015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'AKT071',18.5,'hutongstore','reading65','home@barrellclan.wanadoo.co.uk','Roger Barrell','1 Spanbies Road Stratford St Mary','Colchester','Essex','UNITED KINGDOM','CO7 6YH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 08:38:50',0,NULL,3,0,3,1,'RA184551396CN\r ','reading65\r方镜普通托架（三槽） 换  广角托架'),(14660,765978465017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','7816stan','ssimo@tpg.com.au','Stan Simpson','21/66-72 Browns Road','Wahroonga','New South Wales','AUSTRALIA','2076','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 08:54:22',0,NULL,3,0,4,1,'YW866127754CN ','7816stan\r灯架  2m      1\r斜臂        1\r115w 220v  灯泡      1\r单灯头   澳标    2  \r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1\r8月31日再发货!!!\r注意又加了两个单灯头'),(14661,833860959015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','eawtan','eawtan1@gmail.com','Tan Edmund','495F Tampines St 43 #07-356<br>S525495','default','','SINGAPORE','525495','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 08:56:40',0,NULL,3,1,11,1,NULL,'eawtan'),(14662,709780890001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','zlobniq','p.karapetkov@gmail.com','Plamen Karapetkov','25 Tzar Asen Str.','Plovdiv','Plovdiv','BULGARIA','4000','+359885786740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 09:13:45',0,NULL,3,1,2,1,NULL,'zlobniq'),(14663,816528622016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','achiganitovitor','achiganito@gmail.com','Vitor Santos','Pt. Bartolomeu Dias, Lote 113 2º Frente<br>Urbanização Cerrado da Praia','Alcochete','Alcochete','PORTUGAL','2890-138','966082332','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 09:55:11',0,NULL,3,1,17,0,NULL,'achiganitovitor'),(14664,833881390015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','achiganitovitor','achiganito@gmail.com','Vitor Santos','Pt. Bartolomeu Dias, Lote 113 2º Frente<br>Urbanização Cerrado da Praia','Alcochete','Alcochete','PORTUGAL','2890-138','966082332','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 10:09:32',0,NULL,3,1,17,0,NULL,'achiganitovitor'),(14665,816533780016,260660054522,'TianYa NEUTRAL DENSITY ND4 Filter replaces for Cokin P',1,'AA2324',4.65,'hutongstore','achiganitovitor','achiganito@gmail.com','Vitor Santos','Pt. Bartolomeu Dias, Lote 113 2º Frente<br>Urbanização Cerrado da Praia','Alcochete','Alcochete','PORTUGAL','2890-138','966082332','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 10:11:31',0,NULL,3,1,2,1,NULL,'achiganitovitor\r方形滤镜接口环 58mm    1\r方镜普通托架（三槽）   1\r天涯方形滤镜  ND8    1\r天涯方形滤镜  ND4     1'),(14666,833881245015,250600475233,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','kamilkrawczak','kamilkrawczak@yahoo.co.uk','COMPUTER ACES-Kamil Krawczak','UNIT 20A, Terryland Retail Park,<br>Terryland House, Headford Road','Galway','','IRELAND','000','0862527770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 10:12:52',0,NULL,3,1,2,1,NULL,'kamilkrawczak'),(14667,766013516017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','barbzs*b','barb2b@optusnet.com.au','Barbara Bradlington','13<br>Olive Road','Eumemmerring','Victoria','AUSTRALIA','3177','0397939937','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-12 11:05:41',0,NULL,3,1,4,1,'YW866127312CN ','barbzs*b\rLighting  Kit   $28\r澳标'),(14668,751597508002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','fox7600','zavirohin_anton@mail.ru','Антон Завирохин','Невская 8 кв 4','Волгоград','Волгоградская область','RUSSIAN FEDERATION','400087','89053921698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 12:16:00',0,NULL,3,1,3,1,'RA184551572CN\r ','fox7600'),(14669,709828999001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','henring','mdfoto@hotmail.com','Hach Nguyen','10282 perras','montreal','QC','CANADA','H1C2H1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-12 12:33:16',0,NULL,3,0,3,1,'RA184551705CN\r ','henring\rxl  已入库'),(14670,766036975017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',4,'AA1301',10,'photographyacc','spkbuchan','luke.austin22@gmail.com','LUKE S AUSTIN','22 SHAMROCK AVE','BRINSMEAD','Queensland','AUSTRALIA','4870','0432440796','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-12 12:33:18',0,NULL,3,1,2,1,NULL,'spkbuchan'),(14671,710918658018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','rwbyus','short243@outdrs.net','Rick Wilkinson','923 Byus Dr','Charleston','WV','UNITED STATES','25311-1307','(304) 342-3863','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-12 14:34:31',0,NULL,3,1,1,1,NULL,'rwbyus\r除了c 里面的再发\r49 cm 接口环   1\r82 cm 接口环   1\r广角托架   1\r已入库'),(14672,709878083001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','knord848','khiem848@yahoo.com','Khiem Pham','Borgenveien 56','Oslo','oslo','NORWAY','0373','45880765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 15:14:58',0,NULL,3,1,17,0,NULL,'knord848'),(14673,709887971001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','knord848','khiem848@yahoo.com','Khiem Pham','Borgenveien 56','Oslo','oslo','NORWAY','0373','45880765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 15:44:08',0,NULL,3,1,17,0,NULL,'knord848'),(14674,709890981001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','knord848','khiem848@yahoo.com','Khiem Pham','Borgenveien 56','Oslo','oslo','NORWAY','0373','45880765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 15:52:42',0,NULL,3,1,5,1,'CP235771495CN ','knord848\r灯架  2m      2\r反光板支架       1'),(14675,834013824015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','icyblk','debrahmichael@yahoo.co.uk','Michael Debrah','FLAT 10 ROMANY PROSPECT OAKWOOD DRIVE','LONDON','London','UNITED KINGDOM','SE191EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-12 16:08:19',0,NULL,3,1,3,1,'RA184551507CN\r ','icyblk'),(14676,710983966018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','dccii','ds.crawford@rogers.com','Doug Crawford','60 Burnaby Drive','Keswick','ON','CANADA','L4P3Y8','(647) 296-1924','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-12 17:29:07',0,NULL,3,1,2,1,NULL,'dccii'),(14677,751687258002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',2,'AA1309',5.2,'hermeshine','mcaballar','mdawin@yahoo.com','Mark Dawin Caballar','46-A Palma St., 1st. Rd., Baguio City','Baguio','Benguet','PHILIPPINES','2600','9163984527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-12 17:36:31',0,NULL,3,1,2,1,NULL,'mcaballar'),(14678,834086075015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','warbirdmats','vejbymats@gmail.com','Mats Bergstrom','Bjornbarsv. 14','Vejbystrand','Skane','SWEDEN','26083','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 18:36:30',0,NULL,3,1,2,1,NULL,'warbirdmats'),(14679,816738155016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','xbredal','ad_metallica@msn.com','Anne Dorte Bredal','Farverhus 122','6200 Aabenraa','','DENMARK','6200','004561718702','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-12 18:42:28',0,NULL,3,1,2,1,NULL,'xbredal'),(14680,766242296017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','anteminigo','aminigo@gmail.com','Ante Minigo','Grljevacka 128','Podstrana','','CROATIA','21312','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-12 21:07:52',0,NULL,3,1,2,1,NULL,'anteminigo'),(14681,751805209002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','ayshiababy','ayshiababy@hotmail.com','ayshia aycox','1671 Pelican Point Ct','chula vista','CA','UNITED STATES','91911','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-12 22:03:47',0,NULL,3,1,1,1,NULL,'ayshiababy'),(14682,751808288002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gmas2691','gianluigi.masia@tin.it','Gianluigi Masia','via Balistiche, 12','Feltre','BL','ITALY','32032','3487248820','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-12 22:16:23',0,NULL,3,0,3,1,'RA184551688CN\r ','gmas2691\rxl   已入库\rPhoto Vest   $12'),(14683,711121629018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','tigereyes53','brimarycolours@comcast.net','Brian & Mary Jackson','19220 39th Ave S','SeaTac','WA','UNITED STATES','98188-5316','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-12 23:59:26',0,NULL,3,1,1,1,NULL,'tigereyes53'),(14684,709635062001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',72,'hermeshine','melhem8976','mouniranashaar@hotmail.com','Mary','66 Northcote Rd','Greenacre','New South Wales','AUSTRALIA','2190','0297460650','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-13 00:43:11',0,NULL,3,1,3,1,'RA184551691CN\r ','melhem8976\r已入库\r一件m 的  一件3xl 的'),(14685,710062963001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','anthonydragon','yosiniestro@hotmail.com','Antonio borja Yanguas González','C Jose Luis sampedro Nº 194','Almeria','Almeria','SPAIN','04008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 01:01:20',0,NULL,3,1,3,1,'RA184551569CN\r ','anthonydragon'),(14686,710082253001,110566021441,'TianYa ND4 Filter for Cokin P Series Neutral Density',1,'AA2324',7.2,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 02:13:31',0,NULL,3,1,17,0,NULL,'jackchan1974'),(14687,751860072002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 02:01:15',0,NULL,3,1,2,1,NULL,'jackchan1974\r天涯方形滤镜  ND4    1\r天涯方形滤镜  渐变棕     1'),(14688,711160239018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','dusteve','dusteve@hotmail.com','Steve Du','31 Denmark St','Merrylands','New South Wales','AUSTRALIA','2160','0401525254','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 02:40:11',0,NULL,3,1,2,1,NULL,'dusteve'),(14689,751893865002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 05:13:35',0,NULL,3,1,17,0,NULL,'300671igor'),(14690,710116487001,110583278265,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',6.9,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 05:35:27',0,NULL,3,1,2,1,NULL,'300671igor\rlenspen     1\r天涯 cpl 72mm    1'),(14691,711190212018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','menundi83','amanda@afphotographer.com.au','Amanda Keats','67 Derna Rd','Holsworthy','New South Wales','AUSTRALIA','2173','0414459059','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-13 05:37:12',0,NULL,3,1,4,1,'YW866127334CN ','menundi83\rBackground Support  $25'),(14692,710295497018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','zeugma100','ashleyl@cortland.edu','L. Ashley','37 W Court St','Cortland','NY','UNITED STATES','13045-2525','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 05:45:47',0,NULL,3,1,4,1,'YW866127345CN ','zeugma100\rReflector holder  $22'),(14693,816952505016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gst321','g.tabor@ntlworld.com','Graham Tabor','61 Tamar Way','Wokingham','Berkshire','UNITED KINGDOM','RG413UB','01189619593','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-13 06:16:06',0,NULL,3,1,4,1,'YW866127356CN ','gst321\rLighting Kit  $40\r英标'),(14694,766371412017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',7.28,'photographyacc','tvgre','mgre1980@gmail.com','Maris Yakushkin','Levashovskij pr.,h.14,fl.24','Sankt-Petersburg','Russian Federation','RUSSIAN FEDERATION','197110','79119181952','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 06:45:31',0,NULL,3,1,2,1,NULL,'tvgre'),(14695,834318512015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','adpirum','matej.rijavec9@gmail.com','Matej rijavec','Prešernova ulica 2','Ajdovščina','','SLOVENIA','5270','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-13 07:11:05',0,NULL,3,1,2,1,NULL,'adpirum'),(14696,711208355018,280680857434,'New JYC-N3 Wireless Remote Control for Nikon D90 D7000',1,'AA3202',18,'photographyacc','serx88','ksvl88@yandex.ru','Sergey Kazin','ul. Kulibina, dom 13, kv. 47','Penza','Penzenskaya obl','RUSSIAN FEDERATION','440028','+79273640930','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 07:20:22',0,NULL,3,1,2,1,NULL,'serx88'),(14697,711210031018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','4sbewithu','themcmorrows@bigpond.com','Nick McMorrow','22 Squire Street, Kawungan','Hervey Bay','Queensland','AUSTRALIA','4655','070403152154','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 07:27:39',0,NULL,3,1,3,1,'RA184551475CN\r ','4sbewithu'),(14698,751905957002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',2.48,'hermeshine','rege0103','g_raith@web.de','Georg Raith','Waldstraße 10','Grafrath','','GERMANY','82284','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 07:42:57',0,NULL,3,1,17,0,NULL,'rege0103'),(14699,710124702001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','rege0103','g_raith@web.de','Georg Raith','Waldstraße 10','Grafrath','','GERMANY','82284','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 07:44:10',0,NULL,3,1,2,1,NULL,'rege0103\r眼罩 D300     1\r3片装的滤镜袋     1'),(14700,751925497002,120454219798,'Green.L 55mm Neutral Density ND4 Filter ND 4 55',1,'AE2302',5.5,'hermeshine','kooi2010','kooi@beige.plala.or.jp','KIYOSHI OI','63-7 SHINOI','NAKANO','Nagano','JAPAN','3830035','81-269-23-0147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:19:00',0,NULL,3,1,17,0,NULL,'kooi2010'),(14701,710144559001,110419737823,'Green.L 62mm Neutral Density ND4 Filter ND 4 62',1,'AE2304',6,'hermeshine','kooi2010','kooi@beige.plala.or.jp','KIYOSHI OI','63-7 SHINOI','NAKANO','Nagano','JAPAN','3830035','81-269-23-0147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:19:01',0,NULL,3,1,17,0,NULL,'kooi2010'),(14702,710144420001,110414160576,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',6.3,'hermeshine','kooi2010','kooi@beige.plala.or.jp','KIYOSHI OI','63-7 SHINOI','NAKANO','Nagano','JAPAN','3830035','81-269-23-0147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:19:01',0,NULL,3,1,17,0,NULL,'kooi2010'),(14703,710144300001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',5.95,'hermeshine','kooi2010','kooi@beige.plala.or.jp','KIYOSHI OI','63-7 SHINOI','NAKANO','Nagano','JAPAN','3830035','81-269-23-0147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:19:02',0,NULL,3,1,17,0,NULL,'kooi2010'),(14704,751925365002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','kooi2010','kooi@beige.plala.or.jp','KIYOSHI OI','63-7 SHINOI','NAKANO','Nagano','JAPAN','3830035','81-269-23-0147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 08:19:02',0,NULL,3,1,3,1,'RA184551731CN\r ','kooi2010\r绿叶 ND4  55mm   1\r绿叶 ND4  62mm    1\r绿叶 CPL  62mm    1\r绿叶 CPL  55mm     1\rlenspen     2'),(14705,711229760018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','akarangi','benosborne@hotmail.com','Ben Osborne','2/113 Gold St','Collingwood','Victoria','AUSTRALIA','3066','0422123279','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 09:00:32',0,NULL,3,1,2,1,NULL,'akarangi'),(14706,711237949018,280670185466,'Green.L Premium Quality 58mm CPL Circular Polarizer New',1,'AA3310',6.6,'photographyacc','ltokar.sk','lubomir.tokar.sk@gmail.com','Lubomir Tokar, SOOP s.r.o','Mliekarenska 10','Bratislava','Slovakia','SLOVAK REPUBLIC','821 09','421905744891','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 09:33:21',0,NULL,3,1,2,1,NULL,'ltokar.sk'),(14707,751952541002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','oetzbrugger','tobiaso@gmx.at','Tobias Ötzbrugger','Salzburgerstrasse 33c','Hall in Tirol','','AUSTRIA','6060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 10:14:17',0,NULL,3,1,17,0,NULL,'oetzbrugger'),(14708,710171859001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','oetzbrugger','tobiaso@gmx.at','Tobias Ötzbrugger','Salzburgerstrasse 33c','Hall in Tirol','','AUSTRIA','6060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 10:14:18',0,NULL,3,0,2,1,NULL,'oetzbrugger\r方镜广角托架（ 一槽）    1\r天涯方形滤镜  渐变棕      1'),(14709,710180853001,110316941375,'Remote Shutter Release for Canon PowerShot G10 =RS-60E3',1,'AA3210',3,'hermeshine','paulakidd','paulkidd51@gmail.com','Paul Kidd','Valley Rise<br>Old London Road','Stockbridge','Hampshire','UNITED KINGDOM','SO20 6EJ','01264811179','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2011-08-13 10:49:36',0,NULL,3,1,2,1,NULL,'paulakidd'),(14710,710212553001,110597207686,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',65,'hermeshine','trebbor-2008','robbert.vanstraalen@lion-nathan.com.au','Robbert Van Straalen','Locked Bag 14<br>Royal Exchange','Sydney','New South Wales','AUSTRALIA','1225','0437695242','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-13 12:47:58',0,NULL,3,1,4,1,'YW866127360CN ','trebbor-2008\rlight stand  $22'),(14711,710211191001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','i_gioielli_del_mare','info@igioiellidelmare.net','Gianmarco Cataldo','via Sabaudia 136','San Felice Circeo','LT','ITALY','04017','3389853782','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 12:48:19',0,NULL,3,1,2,1,NULL,'i_gioielli_del_mare'),(14712,710220050001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','mrik2305','mrik2005@yahoo.fr','aimeric huclin','27 rue du buisson flocourt','saint witz','Île-de-France','FRANCE','95470','0134688006','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 13:12:56',0,NULL,3,1,2,1,NULL,'mrik2305'),(14713,766482162017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',2,'AB3314',13.38,'photographyacc','raisilva1970','raisilva07@gmail.com','raimundo E verardo Gomes da silva','QNN 06 Conjunto A casa 37<br>Ceilandia sul','Brasilia','Distrito federal','BRAZIL','72220-061','55 61 92217787','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 13:36:46',0,NULL,3,1,2,1,NULL,'raisilva1970'),(14714,711206677018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',23.99,'photographyacc','camparinna','innagold@umail.ru','Inna Samotokhina','Podmoscownaya str 7-30','Moscow','Moscow','RUSSIAN FEDERATION','125362','+7(495)4912289','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 14:19:41',0,NULL,3,0,3,1,'RA184551630CN\r ','camparinna\r1.6*2.1  黑色加白色背景布'),(14715,710240842001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',5.9,'hermeshine','gindreg','gindreg@yahoo.com','Luca Minna','3752 SW 30th Ave','Fort Lauderdale','FL','UNITED STATES','33312-6708','415 999 6922','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 14:20:10',0,NULL,3,1,1,1,NULL,'gindreg'),(14716,752051231002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','helmihel','helmut_feil@yahoo.de','Helmut Feil','Hochberg 37','Wörth a.d. Donau','','GERMANY','93086','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-13 15:47:23',0,NULL,3,0,3,1,'RA184551674CN\r ','helmihel\rxxl  已入库'),(14717,710279667001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:12:03',0,NULL,3,1,17,0,NULL,'roger-damngood'),(14718,752060575002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:12:03',0,NULL,3,1,17,0,NULL,'roger-damngood'),(14719,710279344001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:12:04',0,NULL,3,1,17,0,NULL,'roger-damngood'),(14720,710279470001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:12:04',0,NULL,3,1,17,0,NULL,'roger-damngood'),(14721,752060222002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',70,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:12:05',0,NULL,3,1,4,1,'YW866127382CN ','roger-damngood\r麂皮   1\r带水平仪 热靴保护盖     1\r反光板 110cm 5合1      1\r伟峰 6663A 快装板      1\r2mx1.5m 背景板（蓝，绿）    1\rbackground  plate   $22'),(14722,766540068017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',35,'photographyacc','smkn1','danthros@gmail.com','Manuel  Serrano Godoy','Recesvint 8 CASA','Barcelona','Cataluña','SPAIN','08030','665935681','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 16:12:29',0,NULL,3,0,3,1,'RA184551665CN\r ','smkn1\rxxl  已入库'),(14723,752062335002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','lentejuelao','delgadorodriguez73@yahoo.es','JOSE FRANCISCO DELGADO RODRIGUEZ','NUEVA AVENIDA  Nº 74','LANTEJUELA','Sevilla','SPAIN','41630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 16:17:38',0,NULL,3,1,2,1,NULL,'lentejuelao'),(14724,817161139016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','hestonkellyphotography','hkelly1974@gmail.com','shane mc cay','39 bridge st','strabane','Tyrone','UNITED KINGDOM','BT82 9AB','02871880406','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-13 16:28:50',0,NULL,3,1,3,1,'RA184551484CN\r ','hestonkellyphotography'),(14725,710288477001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','alsmit15','alsmit15@yahoo.com','Lere Akinpelu','47 Bushgrove road<br>dagenham','dagenham','Essex','UNITED KINGDOM','rm8 3sl','02032440159','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-13 16:35:31',0,NULL,3,1,2,1,NULL,'alsmit15'),(14726,752082861002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','rebeccaksimon','rksimon@gmail.com','Rebecca Simon','4184 Johnston Rd','Winston','GA','UNITED STATES','30187-1065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 17:09:23',0,NULL,3,1,1,1,NULL,'rebeccaksimon'),(14727,752090896002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jho4481','janetho@live.ca','Janet Ho','134 Panorama Hills View NW','Calgary','AB','CANADA','t3k 5b8','(403) 889-4481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 17:27:41',0,NULL,3,1,2,1,NULL,'jho4481'),(14728,766594316017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','rjizzy031','arjay031@yahoo.com','Raymund Deslate','1545 S Walnut St<br>Apt 2','Anaheim','CA','UNITED STATES','92802-2620','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 18:19:34',0,NULL,3,1,1,1,NULL,'rjizzy031'),(14729,711461188018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',2,'AA3314',14.4,'photographyacc','monsterpeloe','miguelccesar@hotmail.com','Paulo Cesar','Rua Nicolau Sousa Lima 23A 2º Dto','Ponta Delgada','Açores','PORTUGAL','9500-786','+351919153680','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 19:59:25',0,NULL,3,1,2,1,NULL,'monsterpeloe'),(14730,711489376018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',26,'photographyacc','malak5050','mohamed.shaafee@gmail.com','mohamed Shafy','ma. saadhage<br>Maaveyou Golhi','Male\'','Maafanu','MALDIVES','20242','009607775050','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-13 21:12:04',0,NULL,3,1,3,1,'RA184551467CN\r ','malak5050'),(14731,752205031002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','richjhon','fatspots@gemsi.com','Richard Honey','5408 Painted Hills Rd','Ephrata','WA','UNITED STATES','98823-9698','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 22:34:19',0,NULL,3,1,1,1,NULL,'richjhon'),(14732,752216391002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','wspbgt24','wspbgt24@hotmail.com','Diogenes Tomelden','19515 Gable Crossing Dr','Richmond','TX','UNITED STATES','77407-4016','(713) 679-3322','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-13 23:17:05',0,NULL,3,1,1,1,NULL,'wspbgt24'),(14733,752222763002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','2011temir','anaevtemir@mail.ru','Temir Anaev','via Cunfida 11','Roma','RM','ITALY','00195','3409786514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-13 23:49:09',0,NULL,3,1,3,1,'RA184551759CN\r ','2011temir\r Remote Control   $12'),(14734,710441283001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','djmillare006','dmillar2010@optusnet.com.au','derek millar','44 davistown road','davistown','New South Wales','AUSTRALIA','2251','0243697658','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-13 23:53:48',0,NULL,3,1,2,1,NULL,'djmillare006'),(14735,710456857001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','todoalbo','ppvivanco@gmail.com','Pedro Pablo Vivanco del Rio','Leo 8958<br>Vitacura','Santiago','Región Metropolitana','CHILE','7640236','5622297076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 01:06:57',0,NULL,3,1,5,1,'CP235771606CN ','todoalbo'),(14736,711561765018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','rabbit4109','atingmwp@optusnet.com.au','Anthony Ting','Mt Warren Park Medical Centre<br>Shop 8a/20-30 Mt Warren Blvd','Mt Warren Park','Queensland','AUSTRALIA','4207','0738078588','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 01:45:23',0,NULL,3,1,3,1,'RA184551538CN\r ','rabbit4109'),(14737,766744849017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',6.98,'photographyacc','goldtulip03','pjmullan@bigpond.com','Joanne Mullan','PO Box 45','Lalbert via Swan Hill','Victoria','AUSTRALIA','3542','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 01:48:34',0,NULL,3,1,2,1,NULL,'goldtulip03'),(14738,752261859002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','billybill1205','knoxbilly8@aol.com','Billy Knox','23 Ardmillan st','Glasgow','Lancashire','UNITED KINGDOM','G333BH','01417706557','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 02:44:25',0,NULL,3,1,3,1,'RA184551802CN ','billybill1205\rL'),(14739,752274195002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',147.8,'hermeshine','sarah1432','sarahtsubaa@hotmail.com','sarah Al-Subaa','Taruot','QATIF','Qatif','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 03:34:36',0,NULL,3,1,3,1,'RA184551422CN\r ','sarah1432\rRA184551379CN\rRA184551365CN\rRA184551382CN\r'),(14740,711596090018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','dthoffmann','dthebay@gmail.com','Daan Hoffmann','14/1 George St','Sandringham','Victoria','AUSTRALIA','3191','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 04:32:10',0,NULL,3,1,2,1,NULL,'dthoffmann'),(14741,766795780017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',2,'AD1401',15.6,'photographyacc','tim_df','barrettt@aztech.com.au','Tim Barrett','7 Greenway Drive','Pymble','New South Wales','AUSTRALIA','2073','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 06:00:09',0,NULL,3,1,3,1,'RA184551833CN\r','tim_df\r608\r我算过了  比递四方还便宜'),(14742,711620537018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','krishnaprajapati','erroronkrishna@yahoo.com','krishna prajapai','4/114 victoria street','ashfield','New South Wales','AUSTRALIA','2131','0401295701','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 06:53:33',0,NULL,3,1,2,1,NULL,'krishnaprajapati'),(14743,834826740015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1303',4.52,'hutongstore','gussmithy','gusdave@uwclub.net','Dave Smith','14 Tynedale Rd','Betchworth','Surrey','UNITED KINGDOM','RH37HX','01737842296','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 07:30:57',0,NULL,3,1,2,1,NULL,'gussmithy'),(14744,830852238015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','ds10023','dayatstandish@blueyonder.co.uk','Stephen Day','23 almond brook rd<br>standish','wigan','Lancashire','UNITED KINGDOM','wn6 0tb','0169554517','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 08:33:23',0,NULL,3,1,2,1,NULL,'ds10023'),(14745,710561273001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','tomac_k2','tomac_k@net.hr','Tomislav Krpan','Antona Dolenca 12','Zagreb','Zagreb','CROATIA','10000','+38513835626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 09:26:35',0,NULL,3,1,2,1,NULL,'tomac_k2'),(14746,766869182017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','awantas','awant@takas.lt','Raimundas Mikolaitis','Senojo Vieskelio 48','Plikiskiai','Joniskio r','LITHUANIA','LT-84403','+37067806420','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-14 10:21:36',0,NULL,3,1,2,1,NULL,'awantas'),(14747,766872829017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',5,'AA1203',14.5,'photographyacc','alan221','alan22@bigpond.com.au','Alan Lane','391 Lt. Bourke Street','Melbourne','Victoria','AUSTRALIA','3000','0396700560','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-14 10:30:57',0,NULL,3,1,3,1,'RA184551643CN\r ','alan221'),(14748,752387777002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','jamies_ibanez','jamiesibanez@hotmail.com','Jamie Cameron','Box 118','Portage Du Fort','QC','CANADA','J0X 2T0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 11:22:20',0,NULL,3,1,5,1,'CP235771504CN ','jamies_ibanez\r灯泡是   110v 的'),(14749,710618319001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','lepi77','manuellepitschnik@hotmail.com','Manuel Lepitschnik','82/2  MOO3<br>WMC GYM','Lamai Beach','Koh Samui','THAILAND','84310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 12:05:30',0,NULL,3,1,17,0,NULL,'lepi77'),(14750,710618321001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','lepi77','manuellepitschnik@hotmail.com','Manuel Lepitschnik','82/2  MOO3<br>WMC GYM','Lamai Beach','Koh Samui','THAILAND','84310','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 12:05:31',0,NULL,3,1,3,1,'RA184551745CN\r ','lepi77\r除了c 里面的再发\r方形滤镜接口环 49mm     1\r方形滤镜接口环 52mm    1\r方形滤镜接口环 55mm    1\r方形滤镜接口环 58mm     1\r方形滤镜接口环 62mm     1\r方形滤镜接口环  67mm      1\r方形滤镜接口环 72mm      1\r方形滤镜接口环   77mm       1\r方形滤镜接口环 82mm     1\r方镜普通托架（三槽）    1\r方镜广角托架（ 一槽）     1\r'),(14751,752422949002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 12:58:12',0,NULL,3,1,3,1,'RA184551436CN\r ','paulolagoaseca2010\r新地址\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(14752,710666625001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','robbanljusta','robert.naas@vasabryggeri.se','Robert Nääs','Måndagsvägen 16','Sundsbruk','','SWEDEN','86334','+46703532671','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-14 14:03:38',0,NULL,3,1,3,1,'RA184551555CN\r ','robbanljusta'),(14753,835021427015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','raylesley','lesleyfrancis10@hotmail.co.uk','raymond francis','3 hawke street','derby','Derbyshire','UNITED KINGDOM','de223dp','01332723702','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 14:37:58',0,NULL,3,1,2,1,NULL,'raylesley'),(14754,711807449018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','ivan.86','ivano.dimeglio@virgilio.it','Ivano Di Meglio','Via Vittorio Emanuele 73','Barano d\'Ischia','NA','ITALY','80070','081/990510','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-14 15:06:27',0,NULL,3,1,4,1,'YW866127371CN ','ivan.86\rlighting stand $20'),(14755,835118673015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','o_j_m','ollie_messenger@btinternet.com','Oliver Messenger','33 Ennismore Avenue','Guildford','Surrey','UNITED KINGDOM','GU1 1SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 16:56:27',0,NULL,3,1,2,1,NULL,'o_j_m'),(14756,752560288002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','yefim_f','170161@gmail.com','Yefim Fefer','1 Gadera st, apt 24','Petah Tikva','center','ISRAEL','49724','+972 52 6132451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 17:19:54',0,NULL,3,1,2,1,NULL,'yefim_f\r欧标'),(14757,752569436002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','francacdb','fjcaal@yahoo.es','FRANCISCO JAVIER CASADO ALCAIDE','C/ JOSÉ GARCIA COSÍO. PARQUES CEUTA FASE 2. PORTAL 3. 5ºB','CEUTA','Ceuta','SPAIN','51001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 17:32:41',0,NULL,3,1,2,1,NULL,'francacdb'),(14758,835151981015,250599986868,'Large size Neoprene Lens Pouch Case 90mm x 220mm',2,'AC1203',6.56,'hutongstore','crazybrain2003','crazybrain2003@aol.com','Tom Boosch','Zypressenweg 20','Bremerhaven','','GERMANY','27578','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-14 17:41:02',0,NULL,3,1,2,1,NULL,'crazybrain2003'),(14759,835159600015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','billythekid5000','sporras72@aol.com','WILLIAM BRAY','4 BROOK GATE,BEDLAM LANE<br>EGERTON','ASHFORD','KENT','UNITED KINGDOM','TN279BY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 17:41:32',0,NULL,3,1,3,1,'RA184551419CN\r ','billythekid5000'),(14760,710812452001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',193,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 18:11:48',0,NULL,3,0,3,1,'RA184551590CN ','saud-p\r注意需要在灯架上贴made in china  \r还需要申报实值\rRA184551609CN\rRA184551515CN\rRA184551586CN\r\r'),(14761,752607661002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','omario1000','omario@sympatico.ca','Mario Olteanu','2733 Inlake Crt.','Mississauga','ON','CANADA','L5N 2A4','(905) 819-8985','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 18:19:35',0,NULL,3,1,3,1,'RA184551626CN\r ','omario1000\r已入库'),(14762,817839936016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','g_piroto','gpiroto@gmail.com','Gonçalo P Duarte','R. Particular de Sto Isidro Nº46','Oporto','Portugal','PORTUGAL','4000-379','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-14 18:26:08',0,NULL,3,1,2,1,' ','g_piroto'),(14763,817841804016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','neloz12','ozlemavan@yahoo.com','Nelson Barros SA','76 Inverness Terrace,Flat 4','London','London','UNITED KINGDOM','W2 3LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-14 18:28:33',0,NULL,3,1,2,1,NULL,'neloz12'),(14764,710832768001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','smeagol.9590','rogaup@online.no','Robert Gaupseth','Fløy veien 25','Kristiansund.N.','Møre and Romsdal','NORWAY','6508','95900076','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 18:35:12',0,NULL,3,0,3,1,'RA184551612CN\r ','smeagol.9590\rxxl    已入库'),(14765,711986662018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-14 19:18:00',0,NULL,3,1,3,1,'RA184551541CN\r ','brunos_92'),(14766,752715316002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','buzull','nadimm@windowslive.com','NADIM OMUR','TEKIRDAG YASAM HASTANESI<br>ISTANBUL YOLU 4.KM','MERKEZ','TEKIRDAG','TURKEY','59030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-14 21:06:01',0,NULL,3,1,2,1,NULL,'buzull'),(14767,712059213018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','mirekblumel','miroslavblumel@yahoo.com','Miroslav Blumel','Alborada 7ma Etapa<br>Mz. 730, V. 16','Guayaquil','Guayas','ECUADOR','EC0901','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-14 21:14:20',0,NULL,3,1,5,1,' CP235771597CN','mirekblumel\r0815又多付了$22运费\r申报Gift'),(14768,752725076002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','saesy','lukas.kyzur@gmail.com','Lukas Kyzur','Stefanikova 24','Bratislava','Slovakia','SLOVAK REPUBLIC','811 04','+421949169776','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-14 21:26:47',0,NULL,3,1,5,1,'CP235771518CN ','saesy\r欧标'),(14769,835371358015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',48,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-14 22:09:51',0,NULL,3,1,3,1,'RA184551524CN\r ','leifs123\r申报$20'),(14770,767326867017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','wilsonspy','wilsonyip52@gmail.com','Wilson Yip','6000 Hollister St<br>Apt 1412','Houston','TX','UNITED STATES','77040-6818','(979) 204-1208','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-15 00:42:47',0,NULL,3,1,1,1,NULL,'wilsonspy'),(14771,752792816002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','drumat5280','spam@davecolorado.com','David A Dugdale','1525 Masters Ct','Superior','CO','UNITED STATES','80027','(303) 499-0536','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-15 00:42:50',0,NULL,3,1,1,1,NULL,'drumat5280'),(14772,835457361015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','umo905','umo905@gmail.com','David King','53 Link Road','Anstey','Leicestershire','UNITED KINGDOM','LE7 7BY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 01:47:57',0,NULL,3,1,3,1,'RA184551498CN\r ','umo905'),(14773,8881313373569416,111,'58mm 渐变灰   1',1,'AA3317',0,'photographyacc','robecaco','dennis17@tpg.com.au','Bev Dennis','9 Cashmere St','Rothwell','Queensland','AUSTRALIA','4022','0732030083',NULL,NULL,NULL,'2011-08-15 01:59:29',0,NULL,3,1,3,1,'RA184551657CN\r ','检查镜片别有划痕 '),(14774,767356696017,270742432150,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',3.88,'photographyacc','macaulayjape01','macaulay_jape@hotmail.com','Macaulay  Jape','58B Third Avenue','ST PETERS','South Australia','AUSTRALIA','5069','0437888889','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 02:17:38',0,NULL,3,1,2,1,NULL,'macaulayjape01'),(14775,711036153001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',1.5,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 02:23:04',0,NULL,3,0,17,0,NULL,'gifou'),(14776,711036155001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 02:23:04',0,NULL,3,1,17,0,NULL,'gifou'),(14777,711036156001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',2,'AA3308',11.9,'hermeshine','gifou','fougy1@hotmail.com','Gilles Fouquet','1847 Rue Murillo','Jonquiere','QC','CANADA','G7Z 1S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 02:23:05',0,NULL,3,1,3,1,'RA184551714CN\r ','gifou\r品胜3.0‘    1\r橡胶遮光罩 52mm     2\r绿叶 CPL  52mm       2'),(14778,767362603017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','estryder','emmaglitch@gmail.com','Emma Shephard','17/30 Shelley Street','Elwood','Victoria','AUSTRALIA','3184','6104257134','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-15 02:26:28',0,NULL,3,1,2,1,NULL,'estryder'),(14779,752853417002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',25,'hermeshine','joaoamericobrazil','joaoamericofotografia@gmail.com','João Américo M. Filippi','SQS 314 Bl. E Apto. 103','Brasília','DF','BRAZIL','70383-050','+55 61 8122-1111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 04:01:19',0,NULL,3,1,3,1,'RA184551728CN\r ','joaoamericobrazil'),(14780,752852320002,120448640631,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',4.1,'hermeshine','ironic.jasa','invicibl3_7@yahoo.com','Dewi Rinawati','PT. PLN Cab Bontang<br>Gedung Zebra Lantai 1, Jln. A. Yani No.34','Bontang','Kalimantan Timur','INDONESIA','75311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 04:03:13',0,NULL,3,1,17,0,NULL,'ironic.jasa'),(14781,711058210001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',2.18,'hermeshine','ironic.jasa','invicibl3_7@yahoo.com','Dewi Rinawati','PT. PLN Cab Bontang<br>Gedung Zebra Lantai 1, Jln. A. Yani No.34','Bontang','Kalimantan Timur','INDONESIA','75311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 04:03:14',0,NULL,3,0,17,0,NULL,'ironic.jasa'),(14782,752852109002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','ironic.jasa','invicibl3_7@yahoo.com','Dewi Rinawati','PT. PLN Cab Bontang<br>Gedung Zebra Lantai 1, Jln. A. Yani No.34','Bontang','Kalimantan Timur','INDONESIA','75311','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 04:03:14',0,NULL,3,1,2,1,NULL,'ironic.jasa\r方形滤镜接口环 62mm    1\r方镜普通托架（三槽）     1\r方形滤镜接口环 55mm        1\r爵影红外 sony      1'),(14783,710848257018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',63,'photographyacc','the*glamorous','khashalie@gmail.com','Nathalie suzanne tabba','28 Cecilia street','Belmore','New South Wales','AUSTRALIA','2192','0431554006','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-15 04:13:32',0,NULL,3,1,4,1,'YW866127393CN ','the*glamorous\r1.6*2.1  黑色背景布'),(14784,751863225002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',95,'hermeshine','big_bangkok','apichai_bkk@yahoo.com','apichai tasripetch','148/175 unchun condominium<br>soi onnuch 70/1, onnuch rd.','prawet','bangkok','THAILAND','10250','0816335343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 04:25:44',0,NULL,3,1,6,1,'EE495341153 CN','big_bangkok'),(14785,767399097017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',2,'AA3303',17.24,'photographyacc','aidenjacobmummy','k.ylie@live.com','kylie jeffs','253 Old toowoomba rd','Placid hills','Queensland','AUSTRALIA','4343','0434928187','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 05:09:15',0,NULL,3,1,3,1,'RA184551780CN ','aidenjacobmummy\r绿叶 UV  58mm    2\rcanon  58 cm  镜头盖    2\r58cm  rubber    1\r已入库'),(14786,712200805018,280680102981,'YongNuo Flash Battery Pack for Nikon SB900 SD-9  /8AA',1,'AB3311',52,'photographyacc','jack_sparra','adzk75@hotmail.com','Adz King','64 Ross Road','Queanbeyan','New South Wales','AUSTRALIA','2620','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 05:17:56',0,NULL,3,1,3,1,'RA184551793CN ','jack_sparra\r'),(14787,767404708017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','chummyman','dnbdnb@gmail.com','Oleg Gorohov','Kolhoznaya ul, dom 8, kv 107','Smolensk','','RUSSIAN FEDERATION','214004','(920)660-9110','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-15 05:37:01',0,NULL,3,1,2,1,NULL,'chummyman'),(14788,712211189018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','nikhr','stanislavhrabal@seznam.cz','Stanislav Hrabal','Krivoklatska 970','Nove Straseci','','CZECH REPUBLIC','27101','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-15 06:14:02',0,NULL,3,1,3,1,'RA184551776CN\r ','nikhr'),(14789,712218712018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','raiansmith','raiansmith@hotmail.com','Raian P Smith','438 Meeka Avenue','Paraburdoo','Western Australia','AUSTRALIA','6754','0434214812','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 06:59:13',0,NULL,3,1,3,1,'RA184551855CN\r ','raiansmith'),(14790,752911618002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tocaleretour','stephane.mas@free.fr','Mas Stephane','7 Rue des Rhododendrons','Saint Dionizy','Languedoc-Rousillon','FRANCE','30980','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 09:13:22',0,NULL,3,1,2,1,NULL,'tocaleretour'),(14791,767460700017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','camarorevhead','keith.bradbury@open2view.com.au','keith Bradbury','5 gannet circuit<br>north lakes','Brisbane','Queensland','AUSTRALIA','4509','0738862311','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 09:54:55',0,NULL,3,1,2,1,NULL,'camarorevhead'),(14792,752949986002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',10,'AA1310',54.9,'hermeshine','bobi1330','bobi2124@abv.bg','Borislav Ivanov','ul.Mechka bl.340 vh.B et.6 apt.57','Sofia','Sofia','BULGARIA','1330','00877053885','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 11:45:56',0,NULL,3,1,3,1,'RA184551816CN ','bobi1330\r申报低于$15'),(14793,767497407017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',6.98,'photographyacc','jim150_0','jimbloq@yahoo.com','Jim Dodd','Doctor D, Carriageworks Bays 22-24<br>245 Wilson Street','Eveleigh','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 12:05:22',0,NULL,3,1,2,1,NULL,'jim150_0'),(14794,835631445015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','mukis2','kazysv@delfi.lt','Kazys Venclovas','Ukmerges<br>186-33','Vilnius','Lithuania','LITHUANIA','LT-07170','+370 656 05375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 12:07:04',0,NULL,3,1,2,1,NULL,'mukis2'),(14795,751984077002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'aligator_smile\r'),(14796,835639270015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','painterinlight','martyn.crisp@talktalk.net','Martyn Crisp','Flat 12, Stadium Mews','London','London','UNITED KINGDOM','N5 1FP','02077046821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 12:25:09',0,NULL,3,1,17,0,NULL,'painterinlight'),(14797,835639583015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','painterinlight','martyn.crisp@talktalk.net','Martyn Crisp','Flat 12, Stadium Mews','London','London','UNITED KINGDOM','N5 1FP','02077046821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 12:26:01',0,NULL,3,1,17,0,NULL,'painterinlight'),(14798,835639939015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','painterinlight','martyn.crisp@talktalk.net','Martyn Crisp','Flat 12, Stadium Mews','London','London','UNITED KINGDOM','N5 1FP','02077046821','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 12:26:56',0,NULL,3,1,2,1,NULL,'painterinlight\r橡胶遮光罩 52mm    1\r橡胶遮光罩 55mm    1\r橡胶遮光罩 58mm     1'),(14799,752965396002,120654667964,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380 user',1,'AA2113',40,'hermeshine','subaquabunny','big.bunny@tiscali.co.uk','Simon Morley','6, Eskview Grove','Dalkeith','Midlothian','UNITED KINGDOM','EH221JW','01316632130','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-15 12:41:10',0,NULL,3,0,3,1,'RA184552003CN ','subaquabunny\r已入库'),(14800,709924780001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','johnkevin1210','jaformz24@yahoo.com','John Kevin Rama','hirose higashi 4-34-1<br>junesu sayama 102','sayama shi','Saitama','JAPAN','350-1320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 13:21:32',0,NULL,3,1,3,1,'RA184551878CN ','johnkevin1210'),(14801,752992895002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','bobee76','somchatchu@gmail.com','Ploeng Yakeaw','18 M.1 Soi.Nakarinthanee Village<br>T.Khunlang','A.Hatyai','Songkhla','THAILAND','90110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 14:07:57',0,NULL,3,1,2,1,NULL,'bobee76'),(14802,711214405001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','tsaiyijie','jj.ver2@gmail.com','tsai yi jie @ tsai syn lean','jia jia garments factory, 162, 1st floor,<br>taman hui sing commercial centre, jalan stampin barat','kuching','sarawak','MALAYSIA','93350','0109699986','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 15:08:44',0,NULL,3,1,2,1,NULL,'tsaiyijie'),(14803,711247940001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','bonofoto','ma.bon@tiscalinet.it','Bonomi Marco','via Vittorio Veneto,7','Mercatello','Perugia','ITALY','06072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 16:40:22',0,NULL,3,1,2,1,NULL,'bonofoto\r申报gift'),(14804,710447332001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','roostermomjamie','jndiz2@yahoo.com','jamie  hunt','14247 state road 120','bristol','IN','UNITED STATES','46507-9251','(574) 358-1192','NoPaymentFailure','CheckoutComplete','Other','2011-08-15 17:03:19',0,NULL,3,1,4,1,'YW866127452CN ','roostermomjamie\r1.6*2.1 白色+黑色背景布\rBackground Support  $25'),(14805,835760820015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','lynxiberico','azor_harrys@hotmail.com','Manuel Bellido Bazan','c/ Mulhacén nº 7 -edf .Marina 2º-A<br>las Gabias','Granada','Andalucía Ceuta y Melilla','SPAIN','18110','652860474','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 17:06:08',0,NULL,3,1,2,1,NULL,'lynxiberico'),(14806,835777148015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',2.25,'hutongstore','vanczyz','van_czyz@op.pl','Krzysztof Czyz','Rahoon Road 32<br>Rahoon','Galway','Galway','IRELAND','default','0879516580','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 17:35:36',0,NULL,3,1,2,1,NULL,'vanczyz'),(14807,711280625001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','shaharthesman','thesman@bezeqint.net','Shahar Shoshan','Arlozorov 10','Kfar Saba','','ISRAEL','44453','+972548074540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 17:54:09',0,NULL,3,1,17,0,NULL,'shaharthesman'),(14808,711280718001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 17:54:11',0,NULL,3,1,17,0,NULL,'copetin2009'),(14809,711281273001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','shaharthesman','thesman@bezeqint.net','Shahar Shoshan','Arlozorov 10','Kfar Saba','','ISRAEL','44453','+972548074540','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 17:55:16',0,NULL,3,1,7,1,'EE645685647CN ','shaharthesman\r背景架2m x 3m + 3个夹子   1\r背景布 3x6 绿色    1\r灯架  2m     2\r反光板支架        1\r柔光箱 50-70cm 单灯头  欧标    2\r115w 5500k 灯泡  220v     2\r灯架包       1\r（多付$95运费，发一票大包就可以了）'),(14810,711283278001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 17:59:29',0,NULL,3,1,3,1,'RA184551881CN ','copetin2009\r2m 弹簧灯架     1\r反光伞     1'),(14811,818413167016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','uncle.v','isuael@gmail.com','Viktor Simonic','9 Milner Close','Sawston','Cambridgeshire','UNITED KINGDOM','CB223JJ','01223693655','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 18:16:44',0,NULL,3,1,2,1,NULL,'uncle.v\r---\r新地址：\rViktor Simonic\r84 Kings Street (Flat 6)\rAberdeen\rAB245BA\rUnited Kingdom'),(14812,753091688002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','fenerforce1907','olcayyavas@gmail.com','Ozkan SAKLI','Fevziçakmak mah. Sultanmurat cad.şahir sinasi sk. no:11 d:5<br>Küçükçekmece Sefaköy','istanbul','TÜRKİYE','TURKEY','34295','+90 532 5633282','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-15 18:17:32',0,NULL,3,1,3,1,'RA184551895CN ','fenerforce1907'),(14813,835821254015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','po4po','jojoanan@terra.es','Joan   Guitart Badia','c./ Barcelona  nº 4  ---   1º ---  2ª','BERGA         (Barcelona)','Cataluña','SPAIN','08600','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-15 18:47:09',0,NULL,3,1,4,1,'YW866127430CN ','po4po\rTripod  $22'),(14814,835835352015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','milsey1','milsey_@hotmail.com','Darren Mills','16 Assumption Villas','Mullingar','Westmeath','IRELAND','default','04443640','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-15 19:06:50',0,NULL,3,1,2,1,NULL,'milsey1'),(14815,818461273016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','v83xx','ascrofts@hotmail.com','VI ascroft','79 stanley grove, penwortham','PRESTON','Lancashire','UNITED KINGDOM','PR10JJ','01772740911','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-15 19:34:05',0,NULL,3,1,2,1,NULL,'v83xx'),(14816,753155261002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','joeinvenice','jasgleep@hotmail.com','Joe Stocco','2000 Alberta Ave<br>Apt 11','Venice','CA','UNITED STATES','90291-4565','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'joeinvenice'),(14817,712503108018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','pakarry','gpvelilla@hotmail.com','GERMAN CARRICONDO LOPEZ','C/DE LA ACACIA Nº13 2ºA','VELILLA DE SAN ANTONIO','Madrid','SPAIN','28891','676212458','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-15 20:30:50',0,NULL,3,1,3,1,'RA184551904CN ','pakarry'),(14818,712518788018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','zoey1991','zoeyj_is@hotmail.com','Zoey Jorgensen','2/33 Yakola Parade','Alexandra Headland','Queensland','AUSTRALIA','4572','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 21:04:50',0,NULL,3,1,3,1,'RA184551983CN ','zoey1991'),(14819,753193750002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jenous110','pot0017@vsb.cz','Jan Potůček','Racková 150<br>760 01','Zlín','Zlín','CZECH REPUBLIC','760 01','732 240 990','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 22:05:14',0,NULL,3,1,3,1,'RA184551864CN ','jenous110'),(14820,711394773001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 22:15:16',0,NULL,3,1,17,0,NULL,'paulolagoaseca2010'),(14821,753196517002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',33.98,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 22:15:17',0,NULL,3,1,3,1,'RA184551820CN','paulolagoaseca2010\r单灯头  欧标    1\r双灯头   欧标    2\r新地址\rpaulo sergio muniz de lima\rRua JoaoFrancisco de Oliveira, 233\rLagoa Seca  - paraiba\r58117-000\rBrazil\rTELEFONE:  83 3366-1044 \r\r'),(14822,753206252002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','xunmeritedx','formerxzombie@gmail.com','Michel Merx','Hobbemastraat 17','Zwijndrecht','','NETHERLANDS','3331CB','+31638437926','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 22:46:47',0,NULL,3,1,2,1,NULL,'xunmeritedx'),(14823,767785757017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','wibobay','wfwatt@gmail.com','William Watt','Level 1, 566 City Road<br>South Melbourne','Melbourne','Victoria','AUSTRALIA','3002','0396954026','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-15 23:40:12',0,NULL,3,1,2,1,NULL,'wibobay'),(14824,711422062001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','anubhavmittal333','anubhavmittal_333@yahoo.co.in','anubhav mittal','212 white field dr,N.E','calgary','AB','CANADA','t1y5j2','(403) 616-3300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-15 23:57:07',0,NULL,3,1,3,1,'RA184551997CN ','anubhavmittal333'),(14825,712588669018,280678918166,'Neoprene Camera Cover Case for small Canon & semi slr S',1,'AC2303',6.6,'photographyacc','ausluke1','lukek13@gmail.com','Luke Kliman','Level 4, 153 Walker St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 00:56:26',0,NULL,3,1,2,1,NULL,'ausluke1'),(14826,709207618001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','mannybeach','mannyguisa@gmail.com','Manny Guisa','811 E G St<br>Ste A','Wilmington','CA','UNITED STATES','90744-6021','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 00:58:46',0,NULL,5,1,3,1,'RA183621714CN\r ','mannybeach\r'),(14827,8881313458904077,111,'Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',34.74,'aliexpress','1004005450','aleks-k@mail.ru','Alexey Kremlev','Kerchenskaya 110','Krasnodar','Krasnodarskii Krai	','RUSSIAN FEDERATION	','350001','+8918 4437974',NULL,NULL,NULL,'2011-08-16 01:41:44',0,NULL,3,1,3,1,'RA184557147CN ',''),(14828,711331643018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',78,'photographyacc','amendara','amanda@amendara.com','amanda g williams','132 Wickham Rd','Woolsthorpe','Victoria','AUSTRALIA','3276','0355692439','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-16 02:06:24',0,NULL,3,1,4,1,'YW866127463CN ','amendara\r澳标\r Lighting Kit    $28'),(14829,711463223001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','e-prst','petrovruslanst@gmail.com','Ruslan Petrov','ul.Korovnikova d.13 korp.4 kv.14','Velikiy Novgorod','Novgorodskaya obl','RUSSIAN FEDERATION','173025','79602019371','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 02:48:22',0,NULL,3,1,5,1,'CP235771521CN ','e-prst'),(14839,753346640002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','yuri-kus','yurikus@ukr.net','Iurii Komar','Knyazhiji Zatоn 14B kv.1','Kiev','UA','UKRAINE','02095','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 09:58:59',0,NULL,3,1,3,1,'RA184557028CN ','yuri-kus'),(14830,836040111015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',24.2,'hutongstore','biggyjw','jittiw123@hotmail.com','Jitti Warrawutwittaya','344/64 moo.8 T.Sansainoi','Sansai','Chiangmai','THAILAND','50210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 03:41:34',0,NULL,3,1,3,1,'RA184551918CN\r ','biggyjw'),(14831,753097933002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',15.9,'hermeshine','semircok','gurnik@gmail.com','Martin Gurnik','Ladozska 4','Kosice','','SLOVAK REPUBLIC','04012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 06:23:59',0,NULL,3,0,3,1,'RA184557120CN ','semircok'),(14832,767881909017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',1,'AB3314',6.69,'photographyacc','ben_tong80','ben_tong80@hotmail.com','Ben Tong','Shop 12 Stud Park Shopping Center<br>Stud Road','Rowville','Victoria','AUSTRALIA','3178','0433918822','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-16 06:33:02',0,NULL,3,1,2,1,NULL,'ben_tong80'),(14833,712663016018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','cola-1972','hongchoon@gmail.com','Tay Hong Choon','Blk 621 Ang Mo Kio Ave 9<br>#03-56 Singapore 560621','default','','SINGAPORE','560621','92718572','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 06:50:22',0,NULL,3,1,11,1,NULL,'cola-1972'),(14834,712626721018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',72,'photographyacc','fcal250','fcal2505@gmail.com','L Mackay','p o box 880','tolga','Queensland','AUSTRALIA','4882','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 07:04:10',0,NULL,3,1,3,1,'RA184551935CN ','fcal250'),(14835,753313590002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','xsoratajp','sorata_x1999@hotmail.com','Luis Silva','Asagaya Kita 2-9-6 Casa Primavera 106','Suginami-ku','Tokyo','JAPAN','1660001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 07:04:27',0,NULL,3,1,2,1,NULL,'xsoratajp'),(14836,712680779018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','sugaskull','mouse_crazy_chic@hotmail.com','Marisa Dennis','19 shinnecock hope island','gold coast','Queensland','AUSTRALIA','4212','0755308838','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,'\r ','sugaskull'),(14837,712684093018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','paul451','braydon_foshaur@hotmail.com','paul houston','152 Plucks Rd','Arana Hills','Queensland','AUSTRALIA','4054','0738511159','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-16 08:37:41',0,NULL,3,1,4,1,'YW867472493CN ','paul451'),(14838,753335346002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','pedrower','pedroherrador@hotmail.es','Pedro Herrador','c/ Pollensa, 4 - 2º. Oficina 14','Las Rozas','Madrid','SPAIN','28290','660127210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 08:38:21',0,NULL,3,1,3,1,'RA184551949CN\r ','pedrower'),(14840,712706520018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','temmi69','teemu.tiesto@gmail.com','Teemu Tiestö','Viipurintie 7 A 24','Lahti','','FINLAND','15150','+358400531905','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 10:09:04',0,NULL,3,1,2,1,NULL,'temmi69'),(14841,818739985016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 10:40:08',0,NULL,3,1,17,0,NULL,'melgesmoo'),(14842,836138004015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','melgesmoo','hennessy@otenet.gr','GERALD HENNESSY','PO BOX 278,','FALIRAKI','RHODES','GREECE','85105','(0030) 2241086694','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 10:40:09',0,NULL,3,1,2,1,NULL,'melgesmoo\r渐变灰   1\r72mm 环架   1\r中号内胆包  canon   1'),(14843,8881313491799068,111,'灯架球台  x   1',1,'AB2302',0,'aliexpress','1003886783 ','erayozden@msn.com','Eray OZDEN	','Turkkonut Platin Sitesi No:29 Cayyolu2 Yenimahalle','Ankara','','TURKEY','06810','905547541903',NULL,NULL,NULL,'2011-08-16 10:49:59',0,NULL,3,1,3,1,'RA184557195CN ','检查好别少零件，发成色好一点的 '),(14844,818745592016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',42.8,'hutongstore','paul_harmon','mail@thinkingpictures.com.au','Paul Robert Harmon','1 Park Ave','Gordon','New South Wales','AUSTRALIA','2072','0289001291','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-16 10:51:27',0,NULL,3,1,4,1,'YW867471690CN ','paul_harmon\rbackground board  $25'),(14845,712720012018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','photobm65','bryan@photobm.com','bryan marden','49 bee farm rd<br>springwood','springwood','New South Wales','AUSTRALIA','2777','0247514113','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 11:04:09',0,NULL,3,1,17,0,NULL,'photobm65'),(14846,767956195017,270758476749,'Photo Studio 110cm Reflective White/Silver Umbrella 43 ',1,'AD1126',14.8,'photographyacc','hpis40','hidegpista@gmail.com','Istvan Hideg','Fügefa utca 144.','Érd','','HUNGARY','2030','+36304837138','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 11:45:26',0,NULL,3,1,11,1,NULL,'hpis40'),(14847,712719859018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','photobm65','bryan@photobm.com','bryan marden','49 bee farm rd<br>springwood','springwood','New South Wales','AUSTRALIA','2777','0247514113','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 11:56:49',0,NULL,3,1,2,1,NULL,'photobm65\r沙袋（普通）     2'),(14848,767965820017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','danusadana','dana.zl@centrum.cz','DANA ZLAMALIKOVA','SPOŘICKÁ 960/1A','PRAG 8','','CZECH REPUBLIC','18400','00420606406132','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 12:22:16',0,NULL,3,1,2,1,NULL,'danusadana'),(14849,753389549002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','naseribrahim','i.naseribrahim@gmail.com','Mohd Khairul Naser Ibrahim','Perpustakaan UTHM<br>Universiti Tun Hussein Onn Malaysia','Parit Raja, Batu Pahat','Johor','MALAYSIA','86400','0197703066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 12:24:34',0,NULL,3,1,2,1,NULL,'naseribrahim'),(14850,712757772018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','fluroturtle','bayne_kate@yahoo.co.uk','Kate Bayne','167 Taringa Pde Taringa','Brisbane','Queensland','AUSTRALIA','4068','0733781907','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 13:10:04',0,NULL,3,1,3,1,'RA184557155CN','fluroturtle'),(14851,712759881018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','d_fatouhi','duraidfatouhi@yahoo.com','Duraid Fatouhi','92 Wembley Rd','Logan Central','Queensland','AUSTRALIA','4114','0432284590','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 13:16:37',0,NULL,3,1,3,1,'RA184557031CN ','d_fatouhi'),(14852,712759963018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','notlimeda2010','notlimeda@yahoo.com.br','Ademilton Dutra','Rua Senador Benedito Valadares 897 - Bairro Industrial','Contagem','Minas Gerais','BRAZIL','32223-030','(31) 9752-8644','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 13:18:35',0,NULL,3,1,3,1,'RA184557093CN ','notlimeda2010'),(14853,711597346001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','ptjian_juliett','nein_no_net@mail.ru','Ptjian Juliett','86 bld.1., Seleznyova st., app.106','Krasnodar','krasnodarskiy krai','RUSSIAN FEDERATION','350075','+7 908 690-49-95','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 13:24:09',0,NULL,3,1,3,1,'RA184557080CN ','ptjian_juliett'),(14854,712762356018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','marialuciaph','marianaphph@yahoo.com.br','maria lucia','rua retiro dos artistas <br>1081','rio de janeiro','rio de janeiro','BRAZIL','22770104','2132566257','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 13:24:54',0,NULL,3,1,3,1,'RA184557076CN ','marialuciaph'),(14855,836210932015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',20,'hutongstore','emerson8591','emersonmacldaniel@yahoo.co.uk','Emerson Daniel','9 Banwell Close<br>Mickleover','Derby','Derbyshire','UNITED KINGDOM','DE3 0QP','01283534633','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 13:56:18',0,NULL,3,1,3,1,'RA184557133CN ','emerson8591\r英标'),(14856,753418485002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','sdamon73','staceydamon@netscape.net','Stacey Damon','319A Main St<br>Damon Photography','Wilton','ME','UNITED STATES','04294','(207) 645-7057','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 13:58:51',0,NULL,3,1,4,1,'YW867471701CN ','sdamon73'),(14857,712776010018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','infernal_midget','joshuasmith418@hotmail.com','Joshua Smith','15 Matthew Cres','Blacktown','New South Wales','AUSTRALIA','2148','0433199195','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 14:08:19',0,NULL,3,1,3,1,'RA184557045CN ','infernal_midget'),(14858,836230558015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','youngjim13','jbmcgill@talktalk.net','james mcgill','27,meadowfield<br>north seaton','ashington','Northumberland','UNITED KINGDOM','ne63 9tr','01670814376','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 14:46:07',0,NULL,3,1,2,1,NULL,'youngjim13'),(14859,753436823002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','jreis.2007','reis949@msn.com','Rodrigo Reis','4416 Tonquil Pl','BELTSVILLE','MD','UNITED STATES','20705-2469','(240) 848-1184','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 14:55:21',0,NULL,3,1,1,1,NULL,'jreis.2007'),(14860,711627740001,110408007449,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',7.3,'hermeshine','melfro331','melvynloidis@o2.co.uk','Melvyn Frost','11 Manston Drive<br>Crossgates','Leeds','West Yorkshire','UNITED KINGDOM','LS15 8RB','07711675534','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2011-08-16 15:01:34',0,NULL,3,1,2,1,NULL,'melfro331'),(14861,836237737015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','the_reactor','alanko.hannu@gmail.com','Hannu Alanko','Vuoritie 44','Inkeroinen','Kouvola','FINLAND','46900','0401917111','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 15:03:02',0,NULL,3,1,3,1,'RA184557062CN ','the_reactor'),(14862,753441163002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','sanderleik89','alex_diler@bk.ru','Alexander Bachinskiy','shishkina 52/2-71','Odessa','Odessa','UKRAINE','65088','380936395115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 15:31:21',0,NULL,3,1,17,0,NULL,'sanderleik89'),(14863,836271261015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','radovicsmilan1982','radovicsmilan@gmail.com','Milán Radovics','Deák Ferenc u. 14.','Csongrád','Csongrád','HUNGARY','6640','+36703396832','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-16 16:20:14',0,NULL,3,1,2,1,NULL,'radovicsmilan1982'),(14864,711679993001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','trinniboy68','marlon.kirk@gmail.com','marlon kirk','825 e ridge st','lansford','PA','UNITED STATES','18232','(267) 231-3700','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-16 17:27:09',0,NULL,3,1,3,1,'RA184557014CN ','trinniboy68'),(14865,753507789002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','drossybuyer','rossy_tj@hotmail.com','rosa i gamez','511 E San Ysidro Blvd<br>Ste 2105','san ysidro','CA','UNITED STATES','92173-3150','(619) 565-6794','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-16 18:02:09',0,NULL,3,1,1,1,NULL,'drossybuyer'),(14866,836360229015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','sircutalot','david.banner@tiscali.co.uk','david banner','farlands<br>nightingales lane','chalfont st giles','Buckinghamshire','UNITED KINGDOM','hp8 4sq','07772967442','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 19:04:02',0,NULL,3,1,2,1,NULL,'sircutalot'),(14867,711736877001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','alexbechard','textalex@gmail.com','Alexandre Bechard','20 Avenue des Bonites<br>Morcellement Investors','Tamarin','Black River','MAURITIUS','MP100','2302546699','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 19:49:37',0,NULL,3,1,2,1,NULL,'alexbechard'),(14868,753566323002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','raisa33','kamzan@hotmail.com','Raisa Bocharnikova','T.D. 47','Barkan','Israel','ISRAEL','44820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-16 20:37:24',0,NULL,3,0,17,0,NULL,'raisa33'),(14869,753578230002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','raisa33','kamzan@hotmail.com','Raisa Bocharnikova','T.D. 47','Barkan','Israel','ISRAEL','44820','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-16 20:37:23',0,NULL,3,0,17,0,NULL,'raisa33'),(14870,753569531002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','raisa33','kamzan@hotmail.com','Raisa Bocharnikova','T.D. 47','Barkan','Israel','ISRAEL','44820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 20:37:24',0,NULL,3,1,3,1,'RA184555398CN\r ','raisa33\r摄影背心 黑色厚 无字 2XL    1\r摄影背心 Canon  老款L      1\r摄影背心 夏  L       1\r就发L的吧，客户没回信'),(14871,712961352018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','alvin9904','alvinqueen@gmail.com','Alvin Queen','34, Avenue Henri Golay','Chatelaine','CH','SWITZERLAND','1219','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-16 21:23:47',0,NULL,3,1,2,1,NULL,'alvin9904\r'),(14872,836443203015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','icetreker09','malch57@hotmail.com','Malcolm Hornby','36 Bagganley Lane','Chorley','Lancashire','UNITED KINGDOM','pr6 0ea','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-16 21:33:54',0,NULL,3,1,2,1,NULL,'icetreker09'),(14873,711797003001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','taim602','mladen.trlep@gmail.com','Mladen Trlep','Ulica Kirbisevih 81','Miklavz na Dravskem polju','','SLOVENIA','2204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 22:03:04',0,NULL,3,1,2,1,NULL,'taim602\r欧标'),(14874,711805158001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','sanderleik89','alex_diler@bk.ru','Alexander Bachinskiy','shishkina 52/2-71','Odessa','Odessa','UKRAINE','65088','380936395115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 22:37:40',0,NULL,3,1,2,1,NULL,'sanderleik89\rHB-7 花瓣    1\rNIKON 镜头盖 67mm    1'),(14875,766714313017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','sexygirl1912','sex_c_88@hotmail.com','Hailee young','3 sloane court','Waterford west','Queensland','AUSTRALIA','4133','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-16 22:48:10',0,NULL,3,1,2,1,NULL,'sexygirl1912'),(14876,762406245017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','ike_inkler','ike_inkler@yahoo.com.au','nicholas rutherford','50 wilmoth street','thornbury','Victoria','AUSTRALIA','3071','0394844787','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-16 23:20:16',0,NULL,3,1,4,1,'YW867471712CN ','ike_inkler\r澳标\rLighting  Kit   $28'),(14877,753644701002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',5.9,'hermeshine','thomasmanch92','thomas.manch@gmail.com','Thomas Manch','53 Bedford Street<br>Northland','Wellington','','NEW ZEALAND','6012','04 9737105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 23:52:29',0,NULL,3,1,17,0,NULL,'thomasmanch92'),(14878,711825318001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','thomasmanch92','thomas.manch@gmail.com','Thomas Manch','53 Bedford Street<br>Northland','Wellington','','NEW ZEALAND','6012','04 9737105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 23:52:28',0,NULL,3,1,17,0,NULL,'thomasmanch92'),(14879,753644796002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','thomasmanch92','thomas.manch@gmail.com','Thomas Manch','53 Bedford Street<br>Northland','Wellington','','NEW ZEALAND','6012','04 9737105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-16 23:52:29',0,NULL,3,1,2,1,NULL,'thomasmanch92\r绿叶 ND8  58mm     1\r绿叶 CPL  58mm    1\r绿叶 渐变镜 58mm    1'),(14880,8881313544266104,111,'配件（螺丝）',1,'',0,'hutongstore','gladkovmaxim','maksimk@list.ru','Gladkov Maxim','K.Sutyusheva 47-3','Petropavlovsk','SKO','KAZAKHSTAN','150000','87152527469',NULL,NULL,NULL,'2011-08-17 01:24:26',0,NULL,3,1,3,1,'RA184557204CN ',NULL),(14881,713040912018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',29,'photographyacc','global_ebayer','global.ebayer@gmail.com','Eduardo Oliveros Martin','C/ Juan de Juanes 10, 2C Centro','Mostoles','Madrid','SPAIN','28933','687765221','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 02:03:01',0,NULL,3,1,3,1,'RA184557102CN ','global_ebayer'),(14882,711867196001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','thompel7','lo_heindrich@hotmail.com','Hendrik Lo','Melodi Mas IV blok A 6 No.16<br>Kelapa Gading Pratama','Jakarta','DKI Jakarta','INDONESIA','14250','021-4504795','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 02:33:03',0,NULL,3,1,2,1,NULL,'thompel7'),(14883,713068818018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',245,'photographyacc','ingenero01','alichoudaris@hotmail.com','Adam Lichoudaris','53 Alma Street','Lower Plenty','Victoria','AUSTRALIA','3093','0394448789','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-17 03:57:46',0,NULL,3,1,4,1,'YW867471723CN ','ingenero01\r Tripod    $30'),(14884,713076008018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','shane4692','shanerobo@bigpond.com.au','Shane Robertson','1/65 Bayview Drive','East Ballina','New South Wales','AUSTRALIA','2478','0266864619','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 04:35:29',0,NULL,3,1,3,1,'RA184557178CN ','shane4692'),(14885,8881313557799373,111,'50-70单灯头de白色罩',1,'',0,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026',NULL,NULL,NULL,'2011-08-17 05:09:59',0,NULL,3,1,3,1,'RA184557181CN ',NULL),(14886,768324919017,270750130191,'TianYa Star 8 points  cross filter for Cokin P Series',1,'AE2317',12.9,'photographyacc','bst1t','trvrsmall@gmail.com','Trevor Small','59 Willara Street','Carseldine','Queensland','AUSTRALIA','4034','0732633913','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 05:35:18',0,NULL,3,1,2,1,NULL,'bst1t'),(14887,713087817018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','dumpling111','aussieoi@optusnet.com.au','Frank Maraz','439a Payneham rd','Felixstow','South Australia','AUSTRALIA','5070','0883655984','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 05:41:39',0,NULL,3,1,3,1,'RA184557164CN ','dumpling111'),(14888,836596790015,250848949434,'600w lighting kit with 3mx6m backdrop & 2mx3m support ',1,'AKT037',130,'hutongstore','txgmartins','txgmartins@gmail.com','Thierry Martins','R. Afonso Albuquerque<br>nº13, r/c Dto','Loulé','Algarve','PORTUGAL','8100-531','(351)966570158','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-17 06:24:04',0,NULL,3,1,4,1,'YW867471734CN ','txgmartins\r欧标\rlighting kit    $35'),(14889,768334328017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',2,'AO0005',33.98,'photographyacc','dahnik86','dahnik@hotmail.com','Danielle Kimel','37 Wallis St','Seymour','Victoria','AUSTRALIA','3660','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 06:25:29',0,NULL,3,0,3,1,'RA184557235CN ','dahnik86\r1.6*3 白色+灰色背景布'),(14898,713136928018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','pbtimo','timo_faber@msn.com','Timo Faber','Oostsingel 132','Delft','','NETHERLANDS','2612 HJ','06-10252015','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 10:01:57',0,NULL,3,1,2,1,NULL,'pbtimo'),(14890,753743926002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','0546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 07:34:50',0,NULL,3,1,3,1,'RA184557218CN ','meir_shevach\r欧标'),(14891,836620125015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',20,'hutongstore','orenboder','the_real_oren@hotmail.com','Oren Boder','35 The Drive<br>Edgware','London','Middlesex','UNITED KINGDOM','HA8 8PS','02089312116','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 07:51:48',0,NULL,3,1,3,1,'RA184557221CN ','orenboder\r英标'),(14892,836626883015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','vesi444','vesi477@abv.bg','Veselin Krekmanov','13 Peyo Yavorov str.<br>Kraynitsi','Dupnitsa','Kyustendil','BULGARIA','2633','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 08:19:22',0,NULL,3,1,3,1,'RA184557306CN ','vesi444'),(14893,712718293018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','u_lil_beauty','bonnie__russell@hotmail.com','Bonnie Russell','5 Greenwood Grove','Traralgon','Victoria','AUSTRALIA','3844','0438354020','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-17 08:29:13',0,NULL,3,1,4,1,'YW867471745CN ','u_lil_beauty\rBackground Support  $25'),(14894,713120119018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 08:31:10',0,NULL,3,1,2,1,NULL,'jackchan1974'),(14895,711935521001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','bimuff72','bigmuff@newsguy.com','Sebastien VINEL','3 Rue guillaume','ORLEANS','Centre','FRANCE','45000','06660022752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 08:36:54',0,NULL,3,1,2,1,NULL,'bimuff72'),(14896,713113337018,280719730281,'New Flash Umbrella Holder Mount aluminum metal N',1,'AD1167',16,'photographyacc','ann10000_0','mdorana@bigpond.com','Mark Stevenson','Mullaley  Post   Office<br>Oxley  Highway','Mullaley','New South Wales','AUSTRALIA','2379','0267435213','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 08:43:13',0,NULL,3,0,2,1,NULL,'ann10000_0\r是一个   新产品'),(14897,768378546017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','steveo_jackass','macri20@optusnet.com.au','Marie Macri','14 Groves Street<br>Keilor East','Melbourne','Victoria','AUSTRALIA','3033','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-17 09:51:01',0,NULL,3,1,2,1,NULL,'steveo_jackass'),(14899,836660552015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','jwdozer','jeff.wilkins@btinternet.com','Jeff Wilkins','4, Whitney Close','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6TW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 10:23:23',0,NULL,3,1,2,1,NULL,'jwdozer'),(14900,768397929017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','cvurun','c.vurun@gmail.com','Chris Vu','13 Wirraway cres','Thomastown','Victoria','AUSTRALIA','3074','0394661275','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 11:02:37',0,NULL,3,1,2,1,NULL,'cvurun'),(14901,713164746018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',13.99,'photographyacc','suz18vb','suz18vb@yahoo.com','Susana  Ortiz','2318 1st Ave SE','Vero Beach','FL','UNITED STATES','32962-8207','(772) 562-8557','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 11:38:20',0,NULL,3,0,1,1,NULL,'suz18vb\r1.6*2.1白色背景布   1'),(14902,713167069018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','cazambxwifi','cazam@bathurstwireless.org','Zac Sverdloff','level 1 140 William Street','Bathurst','New South Wales','AUSTRALIA','2795','0263348025','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-17 11:40:54',0,NULL,3,1,2,1,NULL,'cazambxwifi'),(14903,711980739001,110724160501,'All Weather Photography Camera Backpacks Nikon Canon ',1,'AO0032',110,'hermeshine','cyb0011','yb0010@gmail.com','Yaakov Baron','Shmuel Hanagid 8','Raanana','Israel','ISRAEL','43421','050-2-23-27-27','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 11:54:54',0,NULL,3,1,3,1,'RA184557632CN ','cyb0011\r后面的c 不对 \r黑色\r申报GIFT 60$'),(14904,713173940018,280688523982,'High Quality Umbrella Softbox Reflector Studio 35\" 90cm',2,'AD1127',45.8,'photographyacc','yamyabasha','bdkasher@yahoo.com.au','kasher B','2746 Old Coast road','Herron','Western Australia','AUSTRALIA','6211','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 12:33:34',0,NULL,3,1,3,1,'RA184557371CN\r ','yamyabasha'),(14905,713185319018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','the-mil','info@the-mil.com','Michael Marchment','Level 1, Suit 4/74 Clarence Street','Port Macquarie','New South Wales','AUSTRALIA','2444','0448582135','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 12:49:15',0,NULL,3,1,2,1,NULL,'the-mil'),(14906,753824916002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','szjanesz','sz.janko@freemail.hu','Janos Szombati','Hegyalja ut. 23.','Budapest','','HUNGARY','1016','0036 30950-4136','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 13:06:01',0,NULL,3,1,2,1,NULL,'szjanesz'),(14907,768435510017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','kriszfromtm','bozso.krisztian@gmail.com','Krisztian Bozso','Fay Ltp. 3.ep D. Lh. 2/10','Törökszentmiklos','Jasz-Nagykun-Szolnok','HUNGARY','5200','+36303382060','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 13:09:19',0,NULL,3,1,3,1,'RA184557270CN ','kriszfromtm'),(14908,712010692001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','kraisaks','kraisaks@msn.com','Kraisak Suaysompol','4907 Valkeith Dr','Houston','TX','UNITED STATES','77096-4225','(713) 721-5656','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-17 13:44:59',0,NULL,3,1,1,1,NULL,'kraisaks\r转接环77m'),(14909,836743253015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','birddog919','joelove919@yahoo.com','Jose Francisco R. Muñoz','91.9 Love Radio<br>The Penthouse, Wilrose Bldg, Burgos-Locsin Sts','Bacolod City,','Negors 0ccidental','PHILIPPINES','6100','0344344080','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 14:23:19',0,NULL,3,1,17,0,NULL,'birddog919'),(14910,836748217015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',12.99,'hutongstore','birddog919','joelove919@yahoo.com','Jose Francisco R. Muñoz','91.9 Love Radio<br>The Penthouse, Wilrose Bldg, Burgos-Locsin Sts','Bacolod City,','Negors 0ccidental','PHILIPPINES','6100','0344344080','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-17 14:35:45',0,NULL,3,1,3,1,'RA184557266CN ','birddog919\r柔光箱 50-70cm 单灯头    1\r115w 5500k 灯泡  220v       1'),(14911,753856855002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','tobi600_3','arirlor@hotmail.com','jaime casademont corominas','Cami Can Juli     24','L\' Ametlla del Valles','Barcelona','SPAIN','08480','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 14:50:53',0,NULL,3,1,2,1,NULL,'tobi600_3'),(14912,768357730017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','storminx','sarastorm@hotmail.co.uk','Sara Buxton','149 Adelaide st','BUSSELTON','Western Australia','AUSTRALIA','6280','0406975846','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 14:57:30',0,NULL,3,1,2,1,NULL,'storminx'),(14913,713256093018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','eternal_matt','m.b@fullmail.de','Matthias Brellochs','Barbarosssastrasse 24','Schwäbisch Gmünd','','GERMANY','73529','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 16:19:46',0,NULL,3,1,2,1,NULL,'eternal_matt'),(14914,768492254017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',2,'AB3332',8.3,'photographyacc','kimislovedtx59','kimisloved@aol.com','Kim Daniels','702 W Brockett St','Sherman','TX','UNITED STATES','75092','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 16:22:45',0,NULL,3,1,1,1,NULL,'kimislovedtx59\r普通热靴盖     1\r肥皂盒 柔光罩   580EX     2'),(14915,753890013002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','spike_rus','djspike@list.ru','Ilya Sokolov','Kuybisheva 4a-36','Suhodol','Sergievskiy rayon, Samarskaya oblast','RUSSIAN FEDERATION','446552','9277267189','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 16:30:08',0,NULL,3,1,2,1,NULL,'spike_rus'),(14916,711821475001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','ladybug*78','allisonbos@shaw.ca','Allison Bos','101 Fowler Road','Williams Lake','BC','CANADA','V2G 5G7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-17 18:43:53',0,NULL,3,1,5,1,'CP235771583CN ','ladybug*78'),(14917,768567124017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','kloponoid','karakcheev@gmail.com','Sinkov Alexandr','Rashpilevskay  55,34','Krasnodar','RU','RUSSIAN FEDERATION','350000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 18:51:17',0,NULL,3,1,17,0,NULL,'kloponoid\r欧标'),(14918,753948639002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','spiderspart','my.info.hole@gmail.com','artem holodnyak','Medovoi pecheru 38a/ 116','Lviv','Lvivska','UKRAINE','79000','+380509172123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 18:57:02',0,NULL,3,1,3,1,'RA184557354CN ','spiderspart'),(14919,836893083015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','dariukas2008','coldtruck@mail.lt','Darius Mickevicius','Roziu str. 7-3','Ukmerge','','LITHUANIA','20171','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-17 19:30:24',0,NULL,3,1,3,1,'RA184557337CN ','dariukas2008'),(14920,768598512017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','n.m.s','sunface@qwest.net','Tammie Bateman','1011 26th St SE','Rio Rancho','NM','UNITED STATES','87124','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 19:46:46',0,NULL,3,1,1,1,NULL,'n.m.s'),(14921,819499046016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'AC1303',5.5,'hutongstore','kolo_lu','kolo_lu@o2.pl','lukasz grzempowski','11 station court<br>northcote road','bristol','Avon','UNITED KINGDOM','BS5 8HB','00485724902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 20:00:15',0,NULL,3,1,2,1,NULL,'kolo_lu'),(14922,753999120002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','sbarbe77','sylvain.barbe@laposte.net','sylvain barbe','3, impasse François Coli','Ozoir la Ferriere','Île-de-France','FRANCE','77330','0160185927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 20:50:22',0,NULL,3,1,3,1,'RA184557310CN ','sbarbe77'),(14923,754004489002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','crravell','ravello.cesar@gmail.com','Cesar Ravello Serrano','Amunategui 810 Departamento 2412<br>Santiago Centro','Santiago','Region Metropolitana','CHILE','8340181','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-17 20:57:52',0,NULL,3,1,3,1,'RA184557408CN ','crravell'),(14924,768181973017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','stevenshuang','stevenshuang@hotmail.com','WEISHUANG XU','1354 GOLDENLAKE RD','SAN JOSE','CA','UNITED STATES','95131-2524','(510) 557-2884','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 21:33:57',0,NULL,3,1,1,1,NULL,'stevenshuang'),(14925,768653901017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','mandatory72','a_hayden72@hotmail.com','Armanda  Hayden','33 Thornton Street<br>Unit 14 F Thornton Tower','Surfers Paradise','Queensland','AUSTRALIA','4217','0404380935','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 21:54:54',0,NULL,3,1,2,1,NULL,'mandatory72'),(14926,768442077017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','ez4jc','erinrenkema@hotmail.com','Erin  Renkem','44 Yowie Ave ','Sydney','New South Wales','AUSTRALIA','2229','0433334088','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 22:04:10',0,NULL,3,1,2,1,NULL,'ez4jc'),(14927,712130766001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',45.99,'hermeshine','kinguiorasta','netolauro@yahoo.com.br','Dirlene Gomes','Rua 7 de setembro, 55.<br>Bairro: Tabuleiro dos Martins.','Maceió','Alagoas','BRAZIL','57061-140','55-82-33241676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 23:06:43',0,NULL,3,1,3,1,'RA184557323CN ','kinguiorasta'),(14928,836995980015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','angpang95','angpang01@talktalk.net','Angela Higgins','Flat 1/1, 95 Denmilne Street','Glasgow','Glasgow','UNITED KINGDOM','G340AQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-17 23:18:07',0,NULL,3,1,2,1,NULL,'angpang95'),(14929,713426477018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','music_buyerftw','alan_yeap@yahoo.com','Alan Yeap','PO Box 1402','Green Valley','New South Wales','AUSTRALIA','2168','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-17 23:21:12',0,NULL,3,1,2,1,NULL,'music_buyerftw'),(14930,768685857017,270755378942,'4 Bulb Stocks with 24x24\"/60x60cm Folding Easy Soft box',1,'AE2201',42,'photographyacc','cinematics','rosssebek@hotmail.com','Ross Sebek','1202 Forrest Blvd','Decatur','GA','UNITED STATES','30030','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-17 23:48:11',0,NULL,3,1,3,1,'RA184557345CN ','cinematics'),(14931,754057947002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','villors','xibalbafilms@gmail.com','Javier Villalba Martinez','Montes Aluhes #265','San Luis Potosi','San Luis Potosi','MEXICO','78210','4448252010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-17 23:55:02',0,NULL,3,1,2,1,NULL,'villors'),(14932,768695026017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','kraider13','spyralklk@hotmail.com','Kristopher Kaider','244 s. main','wallingford','CT','UNITED STATES','06492','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 00:25:10',0,NULL,3,1,1,1,NULL,'kraider13'),(14933,713446250018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','shuonan.z','shuo.ones@hotmail.com','SHUONAN ZHAO','90 Carillon Avenue<br>Newtown, Australia','Sydney','New South Wales','AUSTRALIA','2042','610430996013','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 01:02:36',0,NULL,3,1,2,1,NULL,'shuonan.z'),(14934,768713903017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','seisoutonos','f@oota.com.br','Kazuko Seki Oota','Av. Industrial, 600 loja 149<br>Bairro Jardim','Santo Andre','Sao Paulo','BRAZIL','09080-500','55 11 4979-5093','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 01:37:14',0,NULL,3,1,2,1,NULL,'seisoutonos'),(14935,768718710017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','yuxia2005','charles_snow001@hotmail.com','charles li','4 Henry road','Riverwood','New South Wales','AUSTRALIA','2210','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 01:53:42',0,NULL,3,1,2,1,NULL,'yuxia2005'),(14936,753745379002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','pohling1988','soon_pl88@hotmail.com','poh ling soon','bishan st 22<br>blk 234 #05-120','default','','SINGAPORE','570234','91886747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 02:43:28',0,NULL,3,1,11,1,NULL,'pohling1988'),(14937,713483704018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','kwaiapkristian','kwa_iap@yahoo.com','Kristian wijaya','Citra Garden I Blok C-13 / 7, Kalideres, Cengkareng','Jakarta Barat','DKI Jakarta','INDONESIA','11840','0215403289','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 03:11:20',0,NULL,3,1,2,1,NULL,'kwaiapkristian'),(14938,754106788002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','jonmd_2009','jondizon@hotmail.com','Jonathan Dizon','78 Country Hills Crescent, NW','Calgary','AB','CANADA','T3K 5A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 03:12:32',0,NULL,3,1,2,1,NULL,'jonmd_2009'),(14939,713498878018,280680879798,'Camera Remote Shutter Release Cord RS-C3 Canon 40D 50D ',1,'AA3211',5.69,'photographyacc','iamtherealdavid','djwierzbowski@hotmail.com','David Wierzbowski','GPO BOX 76','Warrandyte','Victoria','AUSTRALIA','3113','0415899055','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 04:42:18',0,NULL,3,1,2,1,NULL,'iamtherealdavid'),(14940,713507359018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','tracygrosvenor77','tracyandgrant@westnet.com.au','Tracy Grosvenor','PO BOX 443','kalbarri','Western Australia','AUSTRALIA','6536','0899371601','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-18 05:23:37',0,NULL,3,1,4,1,'YW867471756CN ','tracygrosvenor77\rBackground Support    $25\r燕文网站查不到   但是客户已经收到  因为他写信有质量问题'),(14941,754145385002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','cptconforti','marceloconforti@netscape.net','Natalia/Marcelo Conforti','5839 W Higgins Ave<br># 2','chicago','IL','UNITED STATES','60630-2037','(480) 459-0211','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 06:56:52',0,NULL,3,1,1,1,NULL,'cptconforti'),(14942,837110435015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',126,'hutongstore','camham18','camzillo@hotmail.co.uk','Camillo Natale','42 Poppyfields','Welwyn Garden City','Hertfordshire','UNITED KINGDOM','AL7 2HJ','01707881685','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-18 06:56:57',0,NULL,3,1,4,1,'YW867471760CN ','camham18\rTripod  $30'),(14943,754148133002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','dilip2525','autumnmachine@gmail.com','Dilip Singh','10 Duke','Montreal','QC','CANADA','H3C 2L7','(514) 502-3790','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 07:11:48',0,NULL,3,1,2,1,NULL,'dilip2525'),(14944,8881313651567386,111,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user（M + XXL）',2,'AA2106',70,'hermeshine','vlad_molodtsov','molodtsovv@yandex.ru','Vladimir Molodtsov','Chernyshevskogo 29','Mineralnye Vody','Stavropol region','RUSSIAN FEDERATION','357209','+78972264285',NULL,NULL,NULL,'2011-08-18 07:12:47',0,NULL,3,0,3,1,'RA184557368CN\r ',' （M + XXL）各一件\r已入库'),(14945,712323902001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','scarlandco','guicheteau.philippe@wanadoo.fr','Philippe GUICHETEAU','6 rue du point du jour - Hameau de Ducy','Fresnoy le luat','Picardie','FRANCE','60800','0664668802','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:26:44',0,NULL,3,1,4,1,'YW867472482CN ','scarlandco\rtripod $25'),(14946,754164562002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','abilbek2011','abilbek@gmail.com','Abilbek Narembayev','Bokeikhana st 4, apt #45','Astana','','KAZAKHSTAN','010000','+7 701 9530393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 08:40:55',0,NULL,3,1,3,1,'RA184557442CN\r ','abilbek2011\r客户的电话： +7 701 953 0393\r'),(14947,713553449018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','naneedongowa','neil@winchy.com','Neil Winch','Level 7<br>250 Collins St','Melbourne','Victoria','AUSTRALIA','3000','0386614312','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 09:18:05',0,NULL,3,1,3,1,'RA184557592CN ','naneedongowa'),(14948,768812399017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2202',30,'photographyacc','kloponoid','karakcheev@gmail.com','Sinkov Alexandr','Rashpilevskay  55,34','Krasnodar','--','RUSSIAN FEDERATION','350000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 09:27:45',0,NULL,3,0,3,1,'RA184557495CN ','kloponoid\r单灯头   欧标   1\r4灯头 灯头 孔   欧标   1'),(14949,712338255001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','mikasa_86','a.ulmanis@gmail.com','Alfreds Ulmanis','K. Barona 25-11','Riga','','LATVIA','LV-1011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 09:33:25',0,NULL,3,1,2,1,NULL,'mikasa_86'),(14950,754180664002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','topeqs','topeq76@yahoo.co.id','taufiq','jalan haji agus salim, no.45,<br>kebon sirih, menteng - jakarta pusat','dki jakarta','dki jakarta','INDONESIA','10340','628811210791','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 09:56:35',0,NULL,3,1,2,1,NULL,'topeqs'),(14951,754182718002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','122alessio','bagga85@alice.it','alessio bagatti','g. verdi n°1','spilamberto','MO','ITALY','41057','059781019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 10:07:16',0,NULL,3,1,3,1,'RA184557544CN ','122alessio\rLight Stand    $15'),(14952,713569670018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','sergiok','chitinetz@gmail.com','Sergey Konovalov','Stolyarova 14, kv 25','Chita','Zabaykalsky Kray','RUSSIAN FEDERATION','672010','+79242779054','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 10:26:55',0,NULL,3,1,2,1,NULL,'sergiok'),(14953,768835597017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',2,'AA2202',10.96,'photographyacc','maringos74','maringos007@yahoo.com','maged guirguis','4/11 cahors road','padstow','New South Wales','AUSTRALIA','2211','0297923108','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 11:01:31',0,NULL,3,1,2,1,NULL,'maringos74'),(14954,768451990017,270742432910,'New 77mm ring adapter replacement for cokin P series',2,'AA2214',17.76,'photographyacc','19roach87','roach911@hotmail.com','Ryan Ellis','59 Brixton street.','Perth','Western Australia','AUSTRALIA','6107','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 11:01:44',0,NULL,3,1,2,1,NULL,'19roach87\r方形滤镜接口环 77mm    2\r广角托架      2\r已入库'),(14955,768845718017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','bretprew','bretprew@hotmail.com','Bret Prew','10 Bauhinia Street','Tieri','Queensland','AUSTRALIA','4709','0749848619','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 11:35:43',0,NULL,3,1,2,1,NULL,'bretprew'),(14956,768850202017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',125,'photographyacc','max.rec','indian.rec@libero.it','massimo mughini','via roma 8','Sant\'agata sul Santerno','Ravenna','ITALY','48020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 11:52:21',0,NULL,3,1,4,1,'YW867472471CN ','max.rec\r Lighting  Kit  $28\r欧标'),(14957,712374200001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','eshop_masenka','masenka@masenka.eu','Miroslav Horák','Jiřího Wolkera 1888<br>eshop.masenka@masenka.eu','Nymburk','ČR','CZECH REPUBLIC','28802','+420606204980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 12:12:16',0,NULL,3,0,2,1,NULL,'eshop_masenka\r粉色背景布 '),(14958,711964240001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','gligorovski','cgligorovski@hotmail.com','Cvetanco Gligorovski','24 Orkney Sreet','Ferryden Park','South Australia','AUSTRALIA','5010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 12:58:23',0,NULL,3,1,4,1,'YW867472460CN ','gligorovsk*\r1.6*2.1黑色加白色背景布\rBackground Support   $25'),(14959,768882983017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',36,'photographyacc','jackynlil','jacknlil@tpg.com.au','Jacky Lu','11 Salisbury Street<br>Canley Heights','Sydney','New South Wales','AUSTRALIA','2166','0292038488','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 13:41:14',0,NULL,3,1,3,1,'RA184557513CN ','jackynlil'),(14960,754244599002,120581410643,'16chan Wireless Remote Control Cord for Nikon D300 D700',1,'AA3201',18.5,'hermeshine','tek1jay','jps_001@comcast.net','Jay Sakalas','132 Paul St','Rockwood','PA','UNITED STATES','15557','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 14:00:34',0,NULL,3,1,1,1,' ','tek1jay'),(14961,754246367002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','knord848','khiem848@yahoo.com','Khiem Pham','Borgenveien 56','Oslo','oslo','NORWAY','0373','45880765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 14:05:53',0,NULL,3,1,3,1,'RA184557473CN ','knord848'),(14962,712415493001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',7,'AE2312',46.9,'hermeshine','fotoglobal7070','fotoglobal@gmail.com','Ivan Sanches','Av Pedroso de Morais 99','Sao Paulo','São Paulo','BRAZIL','05419-000','11.81347070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 14:36:12',0,NULL,3,1,17,0,NULL,'fotoglobal7070'),(14963,713662158018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','lrargerich','lrargerich@gmail.com','Luis Argerich','Rastreador Fournier 2233','Olivos','Buenos Aires','ARGENTINA','1636','+541147979908','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 15:39:00',0,NULL,3,1,2,1,NULL,'lrargerich'),(14964,754278737002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','dooglestar88','laetitia@songololochildren.com','Laetitia H Casta c/o Liam O\'Prey','Plaza Lesseps 11<br>6º 1ª','Barcelona','Cataluña','SPAIN','08023','670357375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 15:49:03',0,NULL,3,1,2,1,NULL,'dooglestar88'),(14965,753155261002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','joeinvenice','joe.stocco@gmail.com','Joe Stocco','2000 Alberta Ave<br>Apt 11','Venice','CA','UNITED STATES','90291-4565','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 17:01:49',0,NULL,3,1,4,1,'YW867472456CN ','joeinvenice\rTripod   $30'),(14966,713694145018,280695078945,'Aluminium Lightweight 68\" Camera Monopod with ballhead ',1,'AE1604',38,'photographyacc','fietsjefit','ronald.geneyn@gmail.com','Dejaegher filip','oostendsebaan 6','gistel','','BELGIUM','8470','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 17:08:10',0,NULL,3,1,3,1,'RA184557601CN ','fietsjefit'),(14967,713689422018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','soundlove','norma.sale@mail.ru','6Alexander Arnautov','Tveritina<br>34- 193','Ekaterinburg','','RUSSIAN FEDERATION','620026','9226124444','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 17:09:04',0,NULL,3,1,2,1,NULL,'soundlove'),(14968,712474495001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','ain-tova','davidstein48@gmail.com','David Stein','habashan 5','Ramat Gan','','ISRAEL','52266','972459792771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 17:36:22',0,NULL,3,1,2,1,NULL,'ain-tova'),(14969,754316827002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','hascom-computer','hascom@mail.com','Adem Caliskan','Chaussee de Haecht 163 ','Bruxelles','','BELGIUM','1030','022194916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 17:45:23',0,NULL,3,1,3,1,'RA184557535CN','hascom-computer'),(14970,837338389015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','lakiq2','t.modrzejewski1969@wp.pl','Tomasz Modrzejewski','flat 40<br>23 dunkeld road','Perth','Perthshire and Kinross','UNITED KINGDOM','ph15rl','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-18 17:54:51',0,NULL,3,1,2,1,NULL,'lakiq2'),(14971,753962439002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','serj161189','serj1989@mail.ru','Gerashchenko Sergey Mihaylovich','Ulica. Stadionnaya, dom 7/1, kv.54','UFA','Bashkortostan','RUSSIAN FEDERATION','450069','+79876237676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 18:26:33',0,NULL,3,1,3,1,'RA184557439CN ','serj161189'),(14972,754343955002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',1,'AD1125',14.99,'hermeshine','romanrash','rom2297@yandex.ru','Roman Kozhukhar','Kazanskoe shosse, 7 - 259','Nizhniy Novgorod','Nizhegorodskaya oblast','RUSSIAN FEDERATION','603163','(951)9010072','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 18:43:15',0,NULL,3,1,3,1,'RA184557558CN ','romanrash\r我算了  差三元钱 还是挂个号吧 '),(14973,754348902002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','attackshark_12','syahrun_architect@hotmail.com','syahrun furqani','jl. pencak silat no. 11 arcamanik','bandung','west java','INDONESIA','40293','081220217777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 18:54:28',0,NULL,3,1,2,1,NULL,'attackshark_12'),(14974,837380454015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','606222158','laugebl@gmail.com','Lauge Bro Lilleås','Ravnsholt 223 2th','Roskilde','','DENMARK','4000','20822158','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-18 19:11:55',0,NULL,3,1,2,1,NULL,'606222158'),(14975,819982421016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',6.5,'hutongstore','tippgal05','tattybilly@hotmail.com','Jayne Walters','Graigue<br>Rathcabbin','Roscrea','Tipperary','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-18 19:51:19',0,NULL,3,1,2,1,' ','tippgal05\r注意应该是无字那个'),(14976,754380281002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',4,'AE3104',38.72,'hermeshine','musipire','davidchiu@yahoo.com','Musipire Inc.  Atten: Wei Chiu','13237 41st Rd<br>Ste 101','Flushing','NY','UNITED STATES','11355-4235','(917) 723-4673','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-18 20:04:27',0,NULL,3,1,3,1,'RA184557589CN ','musipire'),(14977,754384139002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 20:12:51',0,NULL,3,0,3,1,'RA184557411CN ','nixette_nixette\rL  已入库'),(14978,837431328015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','trip2hop','trip2hop@gmail.com','Aidas','53 Poolboy Quay<br>Blackcastle Lane','Navan','Meath','IRELAND','default','085 1292558','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-18 20:42:52',0,NULL,3,1,2,1,NULL,'trip2hop'),(14979,713801117018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',3,'AD1112',22.74,'photographyacc','casildagarreton2010','casilda.garreton@gmail.com','Maria Casilda Garreton Velasco','Avenida Apoquindo 5701 local 18<br>Las condes','Santiago','Metropolitana','CHILE','7550000','56-02-2244932','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 21:09:42',0,NULL,3,1,3,1,'RA184557425CN ','casildagarreton2010\r410'),(14980,713803018018,280695078945,'Aluminium Lightweight 68\" Camera Monopod with ballhead ',1,'AE1604',38,'photographyacc','n0fd','tdaniels@kc.rr.com','Timothy Daniels','1001 NORTH Broadway','Leavenworth','KS','UNITED STATES','66048','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-18 21:14:51',0,NULL,3,1,3,1,'RA184557527CN ','n0fd'),(14981,712570585001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','boontahr','direktive4@gmail.com','Daniel Chang','1733 N Cherokee Ave<br>Apt 11','Hollywood','CA','UNITED STATES','90028-4801','(818) 434-9100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-18 21:21:11',0,NULL,3,1,1,1,NULL,'boontahr'),(14982,712573905001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','joaoamericobrazil','joaoamericofotografia@gmail.com','João Américo M. Filippi','SQS 314 Bl. E Apto. 103','Brasília','DF','BRAZIL','70383-050','+55 61 8122-1111','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 21:31:36',0,NULL,3,1,3,1,'RA184557487CN ','joaoamericobrazil'),(14983,754418491002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','yea360','marshall-lu@hotmail.com','Chunfen lu','3671 Rosamond Ave','Richmond','BC','CANADA','v7e 1a6','(604) 274-6852','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 21:43:52',0,NULL,3,1,2,1,NULL,'yea360'),(14984,754434290002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','fotoglobal7070','fotoglobal@gmail.com','Ivan Sanches','Av Pedroso de Morais 99','Sao Paulo','São Paulo','BRAZIL','05419-000','11.81347070','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 22:33:41',0,NULL,3,1,3,1,'RA184555146CN ','fotoglobal7070\r除了c 里面的再发\r绿叶 ND8  67mm    7\r绿叶近摄镜 +8  77mm 换成 +10的'),(14985,754435090002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','martsixx','unwell66@gmail.com','martin boulanger','784 montée de l\'eglise','st colonban','QC','CANADA','j5k2j4','(450) 592-5296','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-18 22:37:42',0,NULL,3,0,3,1,'RA184557500CN ','martsixx\r2XL  已入库'),(14986,712597631001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','r57a','okericermin@gmail.com','Ermin Okeric','Kenana Demirovica 80','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','00387-61-213-246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-18 22:55:13',0,NULL,3,1,3,1,'RA184557460CN ','r57a'),(14987,751984077002,120605589203,'New Non Woven Fabric Backdrop 1.6m x 2.1m(5.2x7 ft)',1,'AO0005',12.8,'hermeshine','aligator_smile','achurch1988@hotmail.com','Alex Churchill','4/43 Linden ave','Boambee East','New South Wales','AUSTRALIA','2452','0266585210','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-18 22:55:46',0,NULL,3,0,2,1,NULL,'aligator_smile\r1.6*2.1 白色背景布'),(14988,769122884017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','reno38super','reno38super@hotmail.com','Trevor Brickhill','20 Forge Lane<br>Henley Brook','Perth','Western Australia','AUSTRALIA','6055','0892969407','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 00:03:00',0,NULL,3,1,2,1,NULL,'reno38super'),(14989,820091805016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','ch0mb0r','chombor@gmail.com','Oleg Kondratov','Kutuzova 1<br>flat 47','Moscow','','RUSSIAN FEDERATION','121354','9167300257','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 00:19:12',0,NULL,3,1,2,1,NULL,'ch0mb0r'),(14990,820109008016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','hardeykunlay','latadeyek@gmail.com','Lateef Adeyekun','NTE0512B, Norfolk Terrace<br>University of East Anglia','Norwich','Norfolk','UNITED KINGDOM','NR4 7TJ','07506281905','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 01:21:32',0,NULL,3,1,2,1,NULL,'hardeykunlay'),(14991,754508754002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','subaru_ca','aat928@yahoo.ca','Calvin Lau','8200, Dalemore Road','Richmond','BC','CANADA','V7C 2A6','(604) 889-0237','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 03:43:32',0,NULL,3,1,2,1,NULL,'subaru_ca'),(14992,769190542017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','yuaby_wang','309644861@qq.com','vicky wang','6 margot st','chadstone','Victoria','AUSTRALIA','3148','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 04:49:52',0,NULL,3,1,2,1,NULL,'yuaby_wang'),(14993,713931264018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',13.99,'photographyacc','ivilina.totina','totina.ivilina@abv.bg','Niko  totin','Asen Xristoforow 7','Plovdiv','Plovdiv','BULGARIA','4004','0878130400','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 06:07:33',0,NULL,3,0,2,1,NULL,'ivilina.totina\r1.6*2.1   白色      1'),(14994,8881313737128740,111,'EW-73B',1,'AA3408',0,'hermeshine','asny7411','Asny741@hotmail.com','Hainney Hj.Hamidon','No.11, Simpang 381,Kg.Keriam Tutong TB1141','Bandar Seri Begawan,','Brunei ','BRUNEI DARUSSALAM','TB1141','6738876870',NULL,NULL,NULL,'2011-08-19 06:58:48',0,NULL,3,1,2,1,NULL,NULL),(14995,754542964002,120619188604,'NEW 77mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT048',34,'hermeshine','ydenbroy','yden.broy@centrum.cz','Zdenek Broz','Haje 227','Pribram','','CZECH REPUBLIC','26101','+420602607907','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 07:07:54',0,NULL,3,1,3,1,'RA184555999CN ','ydenbroy\r换成+4的'),(14996,769211046017,270742432772,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',12.76,'photographyacc','inspirationforthesoul','info@lovethismoment.com','Lisa Frost','24 Natan Rd','Mudgeeraba','Queensland','AUSTRALIA','4213','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 07:11:51',0,NULL,3,1,2,1,NULL,'inspirationforthesoul\r方形滤镜接口环 72mm   1\r方形滤镜接口环 52mm    1\r广角托架     1    已入库'),(14997,769220598017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 07:34:08',0,NULL,3,1,2,1,NULL,'gunners456'),(14998,712531650001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','gbelisle10','g_belisle@hotmail.com','Gerald Belisle','29, rue du Lavoir','Leudelange','','LUXEMBOURG','L3358','+352691115276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 07:56:31',0,NULL,3,0,3,1,'RA184557575CN ','gbelisle10\r3XL   已入库'),(14999,712711115001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',75.9,'hermeshine','jws196868','jameson68@gmail.com','Jameson Serfontein','65 Olienhout Avenue<br>Birchleigh','Kemptonpark','Gauteng','SOUTH AFRICA','1621','+27113917354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 08:23:49',0,NULL,3,1,3,1,'RA184557646CN ','jws196868\rRA184557650CN'),(15000,754238065002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sergey73','drserg2004@yandex.ru','Sergey Chichaev','Michurina<br>17','Ulyanovsk','Cherdakly','RUSSIAN FEDERATION','433400','+79021269060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 09:12:28',0,NULL,3,1,2,1,NULL,'sergey73'),(15001,754568189002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','ain-tova','davidstein48@gmail.com','David Stein','habashan 5','Ramat Gan','','ISRAEL','52266','972459792771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 09:43:36',0,NULL,3,1,2,1,NULL,'ain-tova'),(15002,754586529002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','mspelten','info@actiefotografie.nl','Marco Spelten','Pronkmos 2','HOUTEN','','NETHERLANDS','3994LP','(087)8736301','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 10:36:12',0,NULL,3,1,3,1,'RA184557969CN\r ','mspelten\rL'),(15003,712739527001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','jlop1597','ramir@edu.xunta.es','Jose Ramiro Lopez Casal','Estrada da Granxa Nº 110 3ºF<br>Lugo','Lugo','Galicia','SPAIN','27002','615868231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 10:38:26',0,NULL,3,1,4,1,'YW867472445CN ','jlop1597\rTripod  $25'),(15004,754595666002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','temmi69','teemu.tiesto@gmail.com','Teemu Tiestö','Viipurintie 7 A 24','Lahti','','FINLAND','15150','+358400531905','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 11:15:50',0,NULL,3,1,3,1,'RA184557853CN\r ','temmi69'),(15005,837681469015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','anin464','nina_grubeck@hotmail.com','Nina Grubeck','Töllergasse 19','Wien','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 11:20:13',0,NULL,3,1,3,1,'RA184557685CN\r ','anin464'),(15006,837684281015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',48,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-19 11:29:51',0,NULL,3,1,3,1,'RA184557629CN\r ','leifs123\r申报:（英镑）￡20'),(15007,713982904018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',3,'AA1315',8.97,'photographyacc','teddy-baku23','ted.baku@mail.ru','bakuteddi jabrayilov','neftyanikov 145 flat 122','baku','baku','AZERBAIJAN','aze1000','009940502208013','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 11:33:27',0,NULL,3,1,2,1,NULL,'teddy-baku23'),(15008,714006964018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','bellie32','jabec001@bigpond.com','j campbell','351 wongawallan drive','wongawallan','queensland','AUSTRALIA','4210','0428741303','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 11:44:54',0,NULL,3,1,3,1,'RA184557779CN ','bellie32'),(15009,712763835001,110414472986,'Remote Cord Shutter Release for Nikon D200 D3 = MC-30',1,'AA3207',4.18,'hermeshine','dock-hu','martoninfo@gmail.com','Marton Dobossy','Haris köz 5.','Budapest','Budapest','HUNGARY','1052','0036707047154','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 12:17:21',0,NULL,3,1,2,1,NULL,'dock-hu'),(15010,837722303015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ladymaltese','lydia.beetlejuice@gmail.com','Lidia Merinero Crespo','c/ Guetaria<br>110 2º B','Madrid','Madrid','SPAIN','28041','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-19 13:19:19',0,NULL,3,1,2,1,NULL,'ladymaltese'),(15011,754520852002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','robhang','robhang@hotmail.com','Robert Hang','17813 Falconcrest Cir','Germantown','MD','UNITED STATES','20874','(301) 529-4322','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 13:37:33',0,NULL,3,1,1,1,NULL,'robhang'),(15012,769327312017,270758475500,'Photo Studio translucent white umbrella soft 85cm /33\" ',1,'AD1402',7.8,'photographyacc','1billy1963','angelo_grimaldi@hotmail.com','ANGELO GRIMALDI','VIA SATURNO','LENTINI','SR','ITALY','96016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 14:23:22',0,NULL,3,1,17,0,NULL,'1billy1963'),(15013,754651135002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','letusgo4it','p.keijbets@gmail.com','José swelsen','julianastraat 35','Elsoo','','NETHERLANDS','6181 GN','+31640386460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 14:33:05',0,NULL,3,1,4,1,'YW867472434CN ','letusgo4it\rLight Stand  $22\r'),(15014,754656965002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','04-6213177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 14:49:36',0,NULL,3,1,3,1,'RA184557751CN ','denisyana'),(15015,769342798017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','1billy1963','angelo_grimaldi@hotmail.com','ANGELO GRIMALDI','VIA SATURNO','LENTINI','SR','ITALY','96016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 14:56:31',0,NULL,3,1,17,0,'\r ','1billy1963\r'),(15016,820338155016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','jazierugby','vipraw@live.co.uk','Bill H Blackburn','29 St Georges Drive','Rotherham','Yorkshire','UNITED KINGDOM','S60 5NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-19 15:05:30',0,NULL,3,1,2,1,NULL,'jazierugby'),(15017,712775551001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','pugeyes7','pegg.tierney@gmail.com','Peg Tierney','6310 N Lincoln Ave<br>Rosen Management','Chicago','IL','UNITED STATES','60659-1214','(708) 296-0299','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 15:21:36',0,NULL,3,1,17,0,NULL,'pugeyes7'),(15018,754624072002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','pugeyes7','pegg.tierney@gmail.com','Peg Tierney','6310 N Lincoln Ave<br>Rosen Management','Chicago','IL','UNITED STATES','60659-1214','(708) 296-0299','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 15:21:38',0,NULL,3,1,1,1,NULL,'pugeyes7\r橡胶遮光罩 58mm   1\r橡胶遮光罩 77mm     1'),(15019,754677287002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','roptin2009','reneroptin@hotmail.com','rene roptin','8195 rue osaka','brossard','QC','CANADA','J4Y2Z6','(450) 676-6434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 15:49:33',0,NULL,3,1,2,1,NULL,'roptin2009'),(15020,712825710001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','kanemochi45','kanemochi7@yahoo.com','Richard Nicely','9151 N Overlook Dr','Oro Valley','AZ','UNITED STATES','85704-6722','(520) 495-0068','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-19 15:49:32',0,NULL,3,1,1,1,NULL,'kanemochi45'),(15021,714087967018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','james_ryang','jamesryang@gmail.com','James Ryang','50 Herbert St<br>Apt 3R','BROOKLYN','NY','UNITED STATES','11222-5061','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 16:00:01',0,NULL,3,1,1,1,NULL,'james_ryang'),(15022,712844945001,110414470616,'16chan Wireless Remote Control Cord for Sony RM-S1AM',1,'AA3205',18.5,'hermeshine','jonmd_2009','jondizon@hotmail.com','Jonathan Dizon','78 Country Hills Crescent, NW','Calgary','AB','CANADA','T3K 5A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 16:40:41',0,NULL,3,1,2,1,NULL,'jonmd_2009'),(15023,712862343001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','mystery_ghosttrain','anders_1@ukr.net','Vitaliy Ivakin','b-r Perova 15b, kv.4','Kyiv','','UKRAINE','02125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 17:29:56',0,NULL,3,1,3,1,'RA184557915CN\r ','mystery_ghosttrain'),(15024,754762454002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','demoreel2010','demoreelproducciones@gmail.com','Eduardo Real','Juan Jose Paso 382','La Consulta','Mendoza','ARGENTINA','5567','54 02622 470813','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 19:32:54',0,NULL,3,1,3,1,'RA184557907CN ','demoreel2010'),(15025,769458555017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',125,'photographyacc','mistarfix','mistar.fix@gmail.com','Nikolay Yordanov Atanasov','avenida La Alameda numero 8 piso.2-c','Fuente El Saz De Jarama','Madrid','SPAIN','28140','697728521','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 19:39:38',0,NULL,3,1,4,1,'YW867472423CN ','mistarfix\rLighting  Kit   $28\r欧标'),(15026,712917352001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','arrendeavtal','dudek53@gmail.com','Daniel Andersson','Traddragargatan 1','Vasteras','none','SWEDEN','723 37','+46 705 70 93 25','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 19:50:05',0,NULL,3,1,3,1,'RA184555035CN\r ','arrendeavtal'),(15027,769474736017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',15.3,'photographyacc','toni7770_4','thaydon777@gmail.com','Tony Haydon','Unit 110 Matilda Drive<br>BIRV  Foley Street','Bongaree','Queensland','AUSTRALIA','4507','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 20:18:59',0,NULL,3,1,3,1,'RA184555058CN\r ','toni7770_4\r普通热靴盖   2\rmini nikon 红外   1\r眼罩 D300    2\r已入库'),(15028,754785306002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','diegoguimaraes1986','diegoguimaraes@msn.com','Diego Guimarães','Rua Manaiás, 204 - Cj. 01<br>Vila Zelina','São Paulo','SP','BRAZIL','03140-040','+55 11 29240957','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 20:37:19',0,NULL,3,1,2,1,NULL,'diegoguimaraes1986'),(15029,754803961002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','kocur171','marek.oravec171@gmail.com','Marek Oravec','D. Makovického 9/60','Martin','','SLOVAK REPUBLIC','03601','+421917043388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:22:09',0,NULL,3,1,2,1,' ','kocur171\r'),(15030,754801892002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',2,'AO0023',550,'hermeshine','upltradingsro','roman.jurik@upltrading.eu','Roman Jurik','bystre 1323<br>Bystre 1323','frenstat pod radhostem','Moravskoslezsky','CZECH REPUBLIC','74401','00420731104104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:22:27',0,NULL,3,1,17,0,NULL,'upltradingsro'),(15031,712952204001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','upltradingsro','roman.jurik@upltrading.eu','Roman Jurik','bystre 1323<br>Bystre 1323','frenstat pod radhostem','Moravskoslezsky','CZECH REPUBLIC','74401','00420731104104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-19 21:29:17',0,NULL,3,1,12,1,'BJ8824604 ','upltradingsro\r三脚架 伟峰 EI-717  180     2\r背景架2mx2m  + 3个夹子    1\r1.6*2.1  黑色加白色背景布\r\r尝试一下看看DHL是否可以吧'),(15032,714224208018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','danielhornos','daniel_hornos73@hotmail.com','Natalia Dall\' Oglio','Joaquín Suárez 28 - Local 001','Salto','Salto','URUGUAY','50000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-19 21:39:44',0,NULL,3,1,2,1,NULL,'danielhornos'),(15033,754812425002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','spritzf','panoramix20@hotmail.com','Francois Glaude','6171 boulevard bourque','sherbrooke','QC','CANADA','j1n 1h2','(819) 345-2873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-19 21:49:34',0,NULL,3,1,2,1,NULL,'spritzf'),(15034,714238889018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','derekd004','derek681@gmail.com','Derek Dadswell','PO Box 5213','Robina Town Centre','Queensland','AUSTRALIA','4230','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-19 22:46:05',0,NULL,3,1,3,1,'RA184557941CN\r ','derekd004'),(15035,714285236018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','samstiglec','sam.stiglec@gmail.com','Sam Stiglec','70 Drummond St , Chadstone','Melbourne','Victoria','AUSTRALIA','3148','0395698870','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 01:49:10',0,NULL,3,1,3,1,'RA184557725CN ','samstiglec'),(15036,754872146002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','giampy2007','giampaolo@vertigofotografia.it','VERTIGO di Ferraro G.','Via G. Ferrero 16','Milano','MI','ITALY','20143','02 89155537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 02:01:28',0,NULL,3,1,2,1,NULL,'giampy2007'),(15037,714294894018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','phul007','phul@dodo.com.au','Phillip Williams','3-7 Ironbark Close','Warabrook','New South Wales','AUSTRALIA','2304','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 02:36:44',0,NULL,3,1,3,1,'RA184557819CN ','phul007'),(15038,769585313017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','undead2222','andrew.a.nguyen@gmail.com','Andrew Nguyen','50 Normanby St','Villawood','New South Wales','AUSTRALIA','2163','0297263372','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 02:48:10',0,NULL,3,1,2,1,NULL,'undead2222'),(15039,714304398018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','bella_butch','phennapha1978@hotmail.com','Phennapha Inthasith','32 meribula close','flinders','New South Wales','AUSTRALIA','2529','0242951724','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 03:25:45',0,NULL,3,1,3,1,'RA184557898CN\r ','bella_butch'),(15040,714314794018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','torkan007','steveb@logicalbytes.com.au','Steve Bull','PO Box 21','Brighton-le-Sands','New South Wales','AUSTRALIA','2216','0295676723','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'torkan007'),(15041,713045629001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','joneff51','desmo450@hotmail.com','John Farrell','12 Light Place<br>Colonel Light Gardens','Adelaide','South Australia','AUSTRALIA','5041','0883574167','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 04:56:23',0,NULL,3,1,2,1,NULL,'joneff51'),(15042,754924907002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','7000.rami400','rami400@gmail.com','rami khoury','dror 21 st','haifa','','ISRAEL','35156','+972542357000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 07:09:24',0,NULL,3,1,3,1,'RA184557805CN ','7000.rami400'),(15043,769632898017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','genady8310','genady83@gmail.com','Genady Fleishman','Nativ Hen 65','Haifa','','ISRAEL','33688','+972506917485','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 07:14:08',0,NULL,3,1,2,1,NULL,'genady8310'),(15044,714357646018,280700437375,'NIB 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',45,'photographyacc','torkan007','steveb@logicalbytes.com.au','Steve Bull','PO Box 21','Brighton-le-Sands','New South Wales','AUSTRALIA','2216','0295676723','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'torkan007\r'),(15045,838129070015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vincer360','vince@sekai.co.uk','vince Rimmer','185 liverpool road','southport','Merseyside','UNITED KINGDOM','pr84nz','01704562675','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 09:42:09',0,NULL,3,1,2,1,NULL,'vincer360'),(15046,714394715018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',68,'photographyacc','vertetgris','lesley.prosser@bigpond.com','lesley prosser','15 gardenia cr','bomaderry','New South Wales','AUSTRALIA','2541','0244221249','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-20 10:51:55',0,NULL,3,1,4,1,'YW867472412CN ','vertetgris\rbackground plate $20'),(15047,754976527002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 11:01:58',0,NULL,3,1,2,1,NULL,'viong'),(15048,713122046001,110469599873,'Photo Video Light Stands Studio Photo Stand 7ft 200cm',1,'AE3401',28,'hermeshine','15201300','whichguy@hotmail.com','phillip','6/200-202 heathcote rd<br>hammondville','sydney','New South Wales','AUSTRALIA','2170','0433419049','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 11:19:32',0,NULL,3,1,3,1,'RA184557765CN ','15201300'),(15049,702675204018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','solidagoart','solidagoart2010@hotmail.it','marco scarparo','via pertini,21(ex via torino)','gessate','MI','ITALY','20060','3452582706','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 11:26:32',0,NULL,3,1,3,1,'RA184557615CN\r ','solidagoart\rLight Bulb   $12'),(15050,713128632001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','kihaku-san','kavai.pika@gmail.com','Maksim Mozajev','Viru 24a 64','Sillamae','Ida-Virumaa','ESTONIA','40233','+37125900297','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 11:54:32',0,NULL,3,1,2,1,NULL,'kihaku-san'),(15051,714422956018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','bussolarsv','marconi.andrea@libero.it','Andrea Marconi','Viale Manzoni 26','Carpi','MO','ITALY','41012','3482904636','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 12:30:46',0,NULL,3,1,3,1,'RA184557986CN\r ','bussolarsv\r已入库\rPhoto Vest  $12'),(15052,838194248015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','silvestri626','flarty@hotmail.it','laura silvestri','via vincenzo di matteo 64','piedimonte matese','CE','ITALY','81016','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-20 13:08:58',0,NULL,3,1,3,1,'RA184557840CN\r ','silvestri626\rshoulder support $10'),(15053,769735196017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','chantelle4261','flowersinlove@y7mail.com','Chantelle Shaw','33 Webber Rd<br>Moresby','Geraldton','Western Australia','AUSTRALIA','6530','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 13:57:30',0,NULL,3,1,2,1,NULL,'chantelle4261'),(15054,838218805015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','rollerhockeyblue','ygcobras91@aol.com','JEAN Y JONES','38 WATER STREET','LLANLLECHID','BANGOR   ,, GWYNEDD','UNITED KINGDOM','LL573EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 14:11:23',0,NULL,3,0,2,1,NULL,'rollerhockeyblue'),(15055,769749615017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','tatianacassia','tatianadecassia@uol.com.br','tatiana oliveira','rua joao friggi filho,223','sao jose dos campos','sao paulo','BRAZIL','12223580','12 39122446','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 14:24:47',0,NULL,3,1,2,1,NULL,'tatianacassia'),(15056,714485275018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','yachay_soffis','yachay_soffis@yahoo.com','GUILLERMO BARRON DIAZ','AVENIDA CANADA 432 - TERCER PISO - INTERIOR 6<br>LA VICTORIA - LIMA 13','Lima','Lima','PERU','13','994018845','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 15:42:22',0,NULL,3,1,3,1,'RA184557867CN\r ','yachay_soffis'),(15057,714505761018,280667757935,'New Green.L 67mm Macro Close-up Filter +4',1,'AE3219',6.19,'photographyacc','1billy1963','angelo_grimaldi@hotmail.com','ANGELO GRIMALDI','VIA SATURNO','LENTINI','SR','ITALY','96016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 16:35:36',0,NULL,3,1,17,0,NULL,'1billy1963'),(15058,755080375002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','mebuy2007','kurt.hestvik@online.no','Kurt Eivind Hestvik','Hasseløyveien 39','Stavanger','RL','NORWAY','4029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 16:39:24',0,NULL,3,1,3,1,'RA184555101CN\r ','mebuy2007\r422  \r挂号比递四方贵7元'),(15059,714508621018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',2,'AE3103',26,'photographyacc','1billy1963','angelo_grimaldi@hotmail.com','ANGELO GRIMALDI','VIA SATURNO','LENTINI','SR','ITALY','96016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 16:43:08',0,NULL,3,1,3,1,'RA184555075CN','1billy1963\r柔光伞    1\r爵影碗罩P4    1\r绿叶近摄镜 +4  67mm   1\r大力夹云台   2\rphoto  accessory  $15'),(15060,755080600002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','sidraaa88','zoraidamss@yahoo.es','Zoraida Mediavilla Sansegundo','C./ San Roque 47-C Chalet 5','Igollo de Camargo','Cantabria','SPAIN','39608','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 16:46:22',0,NULL,3,1,2,1,NULL,'sidraaa88'),(15061,755123285002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ziview','ziv.aharoni@comverse.com','Ziv Aharoni','Hashoftim 3','Petach Tikva','','ISRAEL','49574','972524577350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 18:32:41',0,NULL,3,1,3,1,'RA184557822CN\r ','ziview'),(15062,838337892015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','daz_144','darylhollands@gmail.com','Daryl Hollands','6 tinsell brook<br>Hilton','Derby','Derbyshire','UNITED KINGDOM','DE655HY','07960275010','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-20 18:33:26',0,NULL,3,1,2,1,NULL,'daz_144'),(15063,713292570001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',2,'AB1403',10.98,'hermeshine','alex061749','alex_mcneill@yahoo.com','Alexander McNeill','3505 Bangor Ct W','Irving','TX','UNITED STATES','75062-7413','(214) 403-6152','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-20 19:51:39',0,NULL,3,1,1,1,NULL,'alex061749'),(15064,755172672002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','bruno.britto','brunob.rosa@uol.com.br','Bruno Rosa','Rua Marques de Abrantes, 107 / apto. 102<br>Flamengo','Rio de Janeiro','RJ','BRAZIL','CEP22230-060','(21) 2552-4531','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 20:44:51',0,NULL,3,1,2,1,NULL,'bruno.britto'),(15065,769924733017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','4sbewithu','themcmorrows@bigpond.com','Nick McMorrow','22 Squire Street, Kawungan','Hervey Bay','Queensland','AUSTRALIA','4655','070403152154','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-20 21:43:20',0,NULL,3,1,3,1,'RA184558006CN\r ','4sbewithu'),(15066,714629371018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','purduegrads1988','purdue1988@comcast.net','Steven E Robinson','2505 Kyle Dr','Lafayette','IN','UNITED STATES','47909','(765) 426-8348','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-20 21:48:35',0,NULL,3,0,1,1,NULL,'purduegrads1988\rxxl  （已入库）'),(15067,713347897001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','rainbow-id','r-i-d@yandex.ru','Dmitriy Galkin','Shelepihinskoe st. 7-1-13','Moscow','','RUSSIAN FEDERATION','123290','7-903-736-19-46','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 22:51:20',0,NULL,3,1,2,1,NULL,'rainbow-id'),(15068,713349299001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','snixdapip','snibourette@gmail.com','Steve Nibourette','Mont-Buxton,Mahe,Seychelles<br>House No25','Victoria','','SEYCHELLES','NONE','(+248) 583081','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-20 22:56:37',0,NULL,3,1,3,1,'RA184555027CN\r ','snixdapip'),(15069,769952796017,270751577658,'New Soft Camera Bag Cover for Canon EOS 5D ii / 24-105',1,'AD1115',12.99,'photographyacc','eddiet1962','eddiet@astroshed.com','Eddie Trimarchi','18 Thelma Avenue','Biggera Waters','Queensland','AUSTRALIA','4216','0755290243','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 23:16:42',0,NULL,3,1,2,1,NULL,'eddiet1962'),(15070,769957734017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',58,'photographyacc','kennyg.02','rckennyg@gmail.com','KEN GORSKI','15 A  AUSTRALIA  ST.','HURSTVILLE','New South Wales','AUSTRALIA','2220','0295802081','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-20 23:41:21',0,NULL,3,1,3,1,'RA184557836CN\r ','kennyg.02\r澳标\r再加115w 220v     1 （ 已入库）'),(15071,714671138018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','lacey_6258','hannaford.lisa@gmail.com','Lisa Hannaford','14b Printer Street<br>Dianella','Perth','Western Australia','AUSTRALIA','6059','0400170186','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 00:26:14',0,NULL,3,0,2,1,NULL,'lacey_6258\r白色  1.6x2.1'),(15072,769988695017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','skinn0909','dan.j.williams@bigpond.com','Daniel Williams','34 Inverness Avenue<br>The Basin','Melbourne','Victoria','AUSTRALIA','3154','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 01:42:08',0,NULL,3,1,17,0,NULL,'skinn0909'),(15073,769989604017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','skinn0909','dan.j.williams@bigpond.com','Daniel Williams','34 Inverness Avenue<br>The Basin','Melbourne','Victoria','AUSTRALIA','3154','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 01:48:38',0,NULL,3,1,3,1,'RA184557924CN\r ','skinn0909\rlenspen   2\r气吹   2\r布    2'),(15074,714693329018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','greggie125','gpast67@bigpond.com','Greg Pastuszka','8-10 VARCOE CLOSE<br>BURWOOD','MELBOURNE','Victoria','AUSTRALIA','3125','0398089513','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 02:14:08',0,NULL,3,1,3,1,'RA184557938CN\r ','greggie125'),(15075,713407579001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','levycarneiro2','levycarneiro@gmail.com','Levy Carneiro - Tecnologia de Informacao Ltda ME','R. Carlos Gomes, 101 Apt 43<br>Campo Grande','Santos','São Paulo','BRAZIL','11075-671','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 03:32:24',0,NULL,3,1,2,1,NULL,'levycarneiro2\r447   我算了  递四方便宜'),(15076,713421267001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','123123maverick','melvin_tan1990@hotmail.com','tan melvin','PAYA LEBAR WAY BLK122, #12-2903','default','','SINGAPORE','381122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 04:50:28',0,NULL,3,1,17,0,NULL,'123123maverick'),(15077,713421957001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','123123maverick','melvin_tan1990@hotmail.com','tan melvin','PAYA LEBAR WAY BLK122, #12-2903','default','','SINGAPORE','381122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 04:55:43',0,NULL,3,1,11,1,NULL,'123123maverick\r橡胶遮光罩 58mm     1\r绿叶 CPL  58mm    1\r'),(15078,770039780017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',16.05,'photographyacc','cassbaybuy','cassbay@iprimus.com.au','Cassy  Tapper','128 Bamboo Avenue','Benowa','Queensland','AUSTRALIA','4217','0755391373','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 06:07:39',0,NULL,3,1,2,1,NULL,'cassbaybuy\r中号内胆包 无字    1\r大号镜头筒      1\r无字 肩带     1\r（已入库）'),(15079,714462964018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','swampy19590_3','swampy3@netspeed.com.au','Tony Hindmarsh','40 Eggleston Cres','Chifley','Australian Capital Territory','AUSTRALIA','2606','0407355572','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-21 06:30:32',0,NULL,3,1,4,1,'YW867472401CN ','swampy19590_3\r背景布 黑色\rbackground support $25'),(15080,770063386017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',125,'photographyacc','alexbechard','textalex@gmail.com','Alexandre Bechard','20 Avenue des Bonites<br>Morcellement Investors','Tamarin','Black River','MAURITIUS','MP100','2302546699','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 07:55:27',0,NULL,3,1,8,1,'CP235771552CN ','alexbechard\r英标'),(15081,770069765017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',27.5,'photographyacc','ciaobaby27','mmaruca@bigpond.com','MARIA MARUCA','P O Box 2240<br>Fortitude Valley BC','BRISBANE','Queensland','AUSTRALIA','4006','61417786750','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 08:30:12',0,NULL,3,1,3,1,'RA184555092CN\r ','ciaobaby27\rCANON 镜头盖  58mm   1\r灯架包  厚    1（和3m背景架的包类似） 已入库'),(15082,713468016001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','victoria_andre','farangesse@mail.ru','Victoria Andreeva','Mustafina 7 - 114','Karaganda','KZ','KAZAKHSTAN','100027','+7 7212 514941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 08:50:34',0,NULL,3,1,2,1,NULL,'victoria_andre'),(15083,713469617001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','4ever-sale','bestofshopping4u@gmail.com','angelina crooy','burgemeester padmosweg 162','wilnis','','NETHERLANDS','3648bm','0636317093','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 08:57:32',0,NULL,3,1,2,1,NULL,'4ever-sale'),(15084,713471473001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','nuxeretes','nuxeretes@hotmail.com','Ricardo Arcones Fernandez','Martinez Villergas 14, 1ºd','Madrid','Madrid','SPAIN','28027','656387963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:02:41',0,NULL,3,1,17,0,NULL,'nuxeretes'),(15085,755342252002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','nuxeretes','nuxeretes@hotmail.com','Ricardo Arcones Fernandez','Martinez Villergas 14, 1ºd','Madrid','Madrid','SPAIN','28027','656387963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:02:41',0,NULL,3,1,17,0,NULL,'nuxeretes'),(15086,755341998002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','nuxeretes','nuxeretes@hotmail.com','Ricardo Arcones Fernandez','Martinez Villergas 14, 1ºd','Madrid','Madrid','SPAIN','28027','656387963','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:02:42',0,NULL,3,1,3,1,'RA184555013CN\r ','nuxeretes\r单灯头  欧标   1\r反光板 60cm 2合1    1\r大力夹     1\r570   中间相差1元钱'),(15087,770086177017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','scottm70','scott.marshall@dhhs.tas.gov.au','Scott Marshall','PO Box 77','Kingston','Tasmania','AUSTRALIA','7051','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-21 09:11:01',0,NULL,3,1,4,1,'YW867472390CN ','scottm70\r澳标'),(15088,714786131018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','035bronson','lynmcconnell@westvic.com.au','Lynette McConnell','802 Penshurst Road','Kirkstall','Victoria','AUSTRALIA','3283','0355658701','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,0,NULL,'035bronson'),(15089,748377656002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','pegasovidal','marcvida@gmail.com','Marcelo Vidal','Myrsnipeveien 53<br>7082 Kattem','Trodnheim','trondheim','NORWAY','7082','99630869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 09:43:41',0,NULL,3,1,2,1,NULL,'pegasovidal'),(15090,713471723001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','antongriffin','hdce@mail.ru','Anton Komkov','Nicolay Ostrovsky st. 49/24 119','Perm','','RUSSIAN FEDERATION','614000','951-938-5841','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 10:08:20',0,NULL,3,1,3,1,'RA184557734CN ','antongriffin\rReflector Holder   $10'),(15091,838657615015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','manateepup','onthelargesideofaverage@hotmail.com','neil tadman','12 Hillmore Court<br>32 Belmont Hill','London','London','UNITED KINGDOM','SE13 5AZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 11:09:42',0,NULL,3,1,2,1,NULL,'manateepup'),(15092,755412875002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','zhdan_vyaz','pluzh.ser@gmail.com','Sergey Pluzhnikov','ul. Metallistov 9-32','Vyazniki','Vladimirskaya','RUSSIAN FEDERATION','601445','8-920-903-3706','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 12:36:12',0,NULL,3,1,3,1,'RA184557717CN ','zhdan_vyaz'),(15093,770169939017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','arpoin','arpoin@hotmail.com','Jose Lopez Lorente','C/ Roser Nº5 - 1-A','Palma De Mallorca','Baleares','SPAIN','07004','666242800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 12:58:26',0,NULL,3,1,2,1,NULL,'arpoin'),(15094,838714249015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','jb101x','john@barratt.eclipse.co.uk','John Barratt','Concept Systems Ltd<br>1 Logie Mill','Logie Green Road','Edinburgh','UNITED KINGDOM','EH7 4HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 13:16:05',0,NULL,3,1,3,1,'RA184557694CN\r ','jb101x'),(15095,755430999002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','joeyharder1','jjharder77@rogers.com','Joey Harder','9-1020 Cedarglen Gate','Mississauga','ON','CANADA','L5C3P4','(905) 803-8020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 13:25:01',0,NULL,3,1,2,1,NULL,'joeyharder1'),(15096,770199631017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','mcev','micioffo@tin.it','Michele Cioffo','via E. Fermi 37','Campegine','Reggio Emilia','ITALY','42040','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 14:10:26',0,NULL,3,1,3,1,'RA184557663CN ','mcev\r欧标\rlighting kit $18'),(15097,714897012018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','verabey','vera_bey@bk.ru','Vera Zamashchikova','Izmailovskaya ploshiad 9 korpus 2','Moscow','Moskow','RUSSIAN FEDERATION','105037','+79197269305','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 14:24:08',0,NULL,3,1,3,1,'RA184557972CN\r ','verabey'),(15098,838754833015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','apfsiete7','apfsiete@gmail.com','Antonio Perez Felipe','Apartado de correos nº 77','parets del Valles','Cataluña','SPAIN','08150','615276242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 14:38:55',0,NULL,3,1,11,1,NULL,'apfsiete7\r395   挂号比递四方贵3元'),(15099,713619150001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','oliver-cisco','olivercisco@gmail.com','Mr. Oscar Ruthner','Csíki-hegyek u. 10.','Budapest','','HUNGARY','1118','(363) 045-1721 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 15:36:28',0,NULL,3,1,17,0,NULL,'oliver-cisco'),(15100,713619147001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','oliver-cisco','olivercisco@gmail.com','Mr. Oscar Ruthner','Csíki-hegyek u. 10.','Budapest','','HUNGARY','1118','(363) 045-1721 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 15:36:28',0,NULL,3,1,3,1,'RA184557884CN\r ','oliver-cisco\r50-70柔光棚 通用金属卡口    1\r反光板支架     1\r'),(15101,713638010001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','liornfib','lior.elb@gmail.com','Eliyahu Lior Elbaz','Yakinton 574 Ap.15<br>Gilo','Jerusalem','Israel','ISRAEL','93844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 16:15:46',0,NULL,3,1,17,0,NULL,'liornfib'),(15102,838817378015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','amhjp','amharrison59@talktalk.net','Andrew & Jane Harrison','19 Purbeck Grove<br>Garforth','Leeds','West Yorkshire','UNITED KINGDOM','LS251HP','01132867620','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 16:20:01',0,NULL,3,0,2,1,' ','amhjp\r灰色'),(15103,713641402001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','liornfib','lior.elb@gmail.com','Eliyahu Lior Elbaz','Yakinton 574 Ap.15<br>Gilo','Jerusalem','Israel','ISRAEL','93844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 16:21:19',0,NULL,3,1,2,1,NULL,'liornfib\r52-58mm 双阳环     1\rcanon 反接环  52mm   1'),(15104,755513090002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','zapxeton','kt26in@gmail.com','Konstantin Tretiyakov','dom 1649, kv. 268','Zelenograd','Moscow','RUSSIAN FEDERATION','124365','79104456800','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 16:21:40',0,NULL,3,1,2,1,NULL,'zapxeton'),(15105,821390980016,260768455412,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',1,'AA1303',1.87,'hutongstore','bluenose150','sjpiper@blueyonder.co.uk','Stephen Piper','15 Spiceland Road<br>Northfield','Birmingham','West Midlands','UNITED KINGDOM','B31 1NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 16:35:45',0,NULL,3,1,2,1,NULL,'bluenose150'),(15106,714976891018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',60,'photographyacc','khaunreiter','hammerider@yahoo.com','Kurt Haunreiter','13811 34th Ave NW','Tulalip','WA','UNITED STATES','98271-7144','(360) 654-1521','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 17:18:41',0,NULL,3,0,1,1,NULL,'khaunreiter\r已入库\r货被客户退回来了 '),(15107,713668260001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','bicicleitor','robegarcia@telefonica.net','JAVIER GARCIA GARCIA','NUEVA-19','CAMPASPERO','Castilla y León','SPAIN','47310','983698494','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-21 17:20:26',0,NULL,3,1,17,0,NULL,'bicicleitor'),(15108,713667798001,110658438313,'Remote Shutter Release Cord for Canon 40D 50D 5DII RE-A',1,'AA2219',4.68,'hermeshine','bicicleitor','robegarcia@telefonica.net','JAVIER GARCIA GARCIA','NUEVA-19','CAMPASPERO','Castilla y León','SPAIN','47310','983698494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 17:20:27',0,NULL,3,1,4,1,'YW867472316CN ','bicicleitor\r三脚架 伟峰 WF-6663A      1\r优永佳快门线 A C3      1\rTripod     $25\r快门线换成普通快门线 C3\r燕文网站查不到  后台也没有留过评价  已发信 ▲'),(15109,838872455015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','mr_musicmadman','k155rog@hotmail.com','ROGER STUBBS','15, Acres Hill Road,<br>darnall','SHEFFIELD','South Yorkshire','UNITED KINGDOM','s9 3db','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 17:30:23',0,NULL,3,1,2,1,NULL,'mr_musicmadman'),(15110,755527797002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','jdneverenoughtoys','p_bratcher@msn.com','Peggy Bratcher','999 Grosscup blvd','West Richland','WA','UNITED STATES','99353-9236','(509) 967-3282','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-21 17:48:54',0,NULL,3,1,17,0,NULL,'jdneverenoughtoys'),(15111,713667479001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','jdneverenoughtoys','p_bratcher@msn.com','Peggy Bratcher','999 Grosscup blvd','West Richland','WA','UNITED STATES','99353-9236','(509) 967-3282','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-21 17:48:54',0,NULL,3,1,17,0,NULL,'jdneverenoughtoys'),(15112,713668434001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jdneverenoughtoys','p_bratcher@msn.com','Peggy Bratcher','999 Grosscup blvd','West Richland','WA','UNITED STATES','99353-9236','(509) 967-3282','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-21 17:48:55',0,NULL,3,1,17,0,NULL,'jdneverenoughtoys'),(15113,713669724001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','jdneverenoughtoys','p_bratcher@msn.com','Peggy Bratcher','999 Grosscup blvd','West Richland','WA','UNITED STATES','99353-9236','(509) 967-3282','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-08-21 17:48:56',0,NULL,3,1,17,0,NULL,'jdneverenoughtoys'),(15114,755532468002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','jdneverenoughtoys','p_bratcher@msn.com','Peggy Bratcher','999 Grosscup blvd','West Richland','WA','UNITED STATES','99353-9236','(509) 967-3282','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-21 17:48:56',0,NULL,3,1,1,1,NULL,'jdneverenoughtoys\r橡胶遮光罩 72mm    1\r3片装的滤镜袋       1\r橡胶遮光罩 58mm   1\rGGS 550D      1\r反光板 80cm 2合1     1\r509'),(15115,713713379001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',84.96,'hermeshine','v.khimenko','vkhimenko@inbox.ru','Khimenko Vasiliy','Mustaphina dom.8 kv.34','Karaganda','','KAZAKHSTAN','100000','(7212) 517-184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 18:09:42',0,NULL,3,1,5,1,'CP235771570CN ','v.khimenko'),(15116,713096478001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',37.99,'hermeshine','vadim*vad','tyutyunin@gmail.com','Vadim Tyutyunin','Sokolov 6/2','Jerusalem','ID','ISRAEL','92144','972-546-384320','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-21 18:41:32',0,NULL,3,1,3,1,'RA184557677CN\r ','vadim*vad'),(15117,713768584001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','kafka88f','kafka88@seznam.cz','Filip Laureys','Nad Liskami 28','Brno','','CZECH REPUBLIC','62400','00420606408354','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 19:28:19',0,NULL,3,1,2,1,NULL,'kafka88f\r欧标'),(15118,838979892015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','phnsk','ricardo.fonseca@velcrew.com','Ricardo Fonseca','Edifício Prime - Av. Quinta Grande, 53 - 8D<br>2614-521 Alfragide','Lisboa','PORTUGAL','PORTUGAL','2614-521','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 19:28:00',0,NULL,3,0,2,1,NULL,'phnsk\r改发67mm的'),(15119,713780579001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','robabhi_fr','robabhi@gmail.com','Abhishek Roy','Porte 37, Etage 6<br>14 rue du Pont Guilhemery','Toulouse','Midi-Pyrénées','FRANCE','31000','0612926640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 19:47:49',0,NULL,3,1,2,1,NULL,'robabhi_fr'),(15120,839042819015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','ral599','richardanlezarklee@googlemail.com','Richard Lee - Marketing','BIC<br>Exeter Road','Bournemouth','Dorset','UNITED KINGDOM','BH2 5BH','01202454768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 20:52:12',0,NULL,3,1,3,1,'RA184557703CN\r ','ral599'),(15121,839046922015,250851158410,'Fancier DSLR Camera Complete Tripod WF-531BT w Ballhead',1,'AE1102',54,'hutongstore','halmo82','shredmaster@azet.sk','Martin Halmo','Cajkovskeho 9','Nitra','','SLOVAK REPUBLIC','94911','+421908545869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 20:59:13',0,NULL,3,1,5,1,'CP235771566CN ','halmo82'),(15122,713827626001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','mecrocket','jesus.ranz@gmail.com','Jesus Ranz Abad','Juan Ramón Jimenez 27','Meco','Madrid','SPAIN','28880','918876056','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 21:20:07',0,NULL,3,1,2,1,NULL,'mecrocket'),(15123,821645245016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','andreroedahl','aro@nom.no','Andre Roedahl','Terminalen 10<br>7080 HEIMDAL','Trondheim','Soer Troendelag','NORWAY','7097','999 - 3655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 22:19:52',0,NULL,3,1,3,1,'RA184557748CN ','andreroedahl'),(15124,715186957018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','dakleton','mark@p166.com','Andrew','Maisgeelstraat 75','Almere','','NETHERLANDS','1339 EN','13146090046','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-21 22:33:24',0,NULL,3,0,3,1,'RA184555044CN\r ','dakleton\rxxxl   已入库'),(15125,821654231016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',2,'AA1304',3.74,'hutongstore','rossistrading','rossistravelling@yahoo.com','Ross Alexander','20 Laburnum Close','Bridgwater','Somerset','UNITED KINGDOM','TA6 4EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 22:43:31',0,NULL,3,1,17,0,NULL,'rossistrading'),(15126,821653193016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','rossistrading','rossistravelling@yahoo.com','Ross Alexander','20 Laburnum Close','Bridgwater','Somerset','UNITED KINGDOM','TA6 4EN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-21 22:43:31',0,NULL,3,1,2,1,NULL,'rossistrading\rCANON 镜头盖  77mm     3'),(15127,712680779018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','sugaskull','mouse_crazy_chic@hotmail.com','Marisa Dennis','19 shinnecock hope island','gold coast','Queensland','AUSTRALIA','4212','0755308838','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 22:57:45',0,NULL,3,0,3,1,'RA184551952CN ','sugaskull'),(15128,715198545018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','sydneyview','jandmpass@gmail.com','John Passmore','18 Woodstock Road','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-21 23:10:31',0,NULL,3,1,2,1,NULL,'sydneyview'),(15129,754487274002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',6,'AE1302',57,'hermeshine','melate8','tonefotos@hotmail.com','Maria Antonieta Cevallos','Obregon 405 pte','Navojoa','Sonora','MEXICO','85830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-21 23:24:44',0,NULL,3,1,3,1,'RA184557875CN\r ','melate8\r\r'),(15130,821676267016,260810104926,'New 35\" 90cm Studio Flash Reflective Umbrella Softbox',1,'AD1127',13.9,'hutongstore','dtsiapas','dtsiapas@gmail.com','Dimitris Tsiapas','Plateia Aneksartisias 15','Hlioupoli','Athens','GREECE','16344','+306973948708','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-21 23:39:54',0,NULL,3,1,3,1,'RA184557782CN ','dtsiapas'),(15131,755480029002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mkoroma25','fjustice23@yahoo.com','mohamed koroma','803 Mississippi Ave NE','roanoke','VA','UNITED STATES','24012-4519','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-21 23:53:25',0,NULL,3,1,3,1,'RA184557796CN ','mkoroma25'),(15132,770531348017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','anth1203','agouros90@gmail.com','Anthony Gouros','10/17A Western Pde','Brooklyn Park','South Australia','AUSTRALIA','5032','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 00:11:55',0,NULL,3,1,2,1,NULL,'anth1203'),(15133,770546005017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','aaronrigby','aaron.rigby@mac.com','Aaron P Rigby','Suite 504<br>157 Walker St','North Sydney','New South Wales','AUSTRALIA','2060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 00:57:02',0,NULL,3,1,2,1,NULL,'aaronrigby'),(15134,839165304015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','bufah78','gretabirgitte@hotmail.com','Greta Birgitte Jaksholt','Holta','Lillesand','','NORWAY','4790','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 01:45:20',0,NULL,3,1,2,1,NULL,'bufah78'),(15135,715278938018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','duongah','dduong84@gmail.com','David Duong','Suite 101, 270 Pacific Highway, Crows Nest','Sydney','New South Wales','AUSTRALIA','2065','61402811434','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 03:46:58',0,NULL,3,1,3,1,'RA184555061CN\r ','duongah'),(15136,715289122018,280700437375,'NIB 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',45,'photographyacc','bugmaster445','bugmaster.professional@gmail.com','Warren Carlson','11<br>Goondi Close','Horsfield Bay','New South Wales','AUSTRALIA','2256','0243445445','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 04:38:00',0,NULL,3,1,3,1,'RA184557955CN\r ','bugmaster445'),(15137,839235253015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','drmkg1','drmkgeorge@yahoo.co.uk','Dr M K  George','4 JULIAN CLOSE<br>BROOMFIELD','CHELMSFORD','Essex','UNITED KINGDOM','CM17AZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 06:10:30',0,NULL,3,1,2,1,NULL,'drmkg1'),(15138,821794341016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK<br>Syntagma','ATHENS','Greece','GREECE','10557','+306972999050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 06:22:56',0,NULL,3,1,4,1,'YW867472375CN ','greeceathens\r欧标   申报低于20\r燕文网站查不到   但是后台已经留过好评'),(15139,713974377001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 06:59:05',0,NULL,3,1,3,1,'RA183626359CN\r ','copetin2009'),(15140,713981012001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','pmk03','pmk3@tpg.com.au','Michelle  Howard','3 Hobson crt','Sunbury','Victoria','AUSTRALIA','3429','0397409197','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 07:38:25',0,NULL,3,1,2,1,NULL,'pmk03'),(15141,821826272016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','soody_1','soodyah@hotmail.com','Masood Ahmad','538 Kenton Lane','harrow','London','UNITED KINGDOM','HA37LJ','07802218316','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 08:35:42',0,NULL,3,1,2,1,NULL,'soody_1'),(15142,839272161015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','shaz_b123','shazia_bashir@hotmail.co.uk','shazad din','228 acklam road','middlesbrough','Cleveland','UNITED KINGDOM','ts5 8aa','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-08-22 08:41:17',0,NULL,3,1,4,1,'YW867472386CN ','shaz_b123\r英标\rlighting kit $30'),(15143,755879850002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','nhisiru','oriol.gogu@gmail.com','Oriol Gonzalez Guirao','Avenida Can Bordoll, 4 - 3º2ª','Sabadell','Cataluña','SPAIN','08202','659555812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 08:42:12',0,NULL,3,1,3,1,'RA183626265CN\r ','nhisiru'),(15144,715337543018,280696883124,'New Pro Photo Vest for all DSLR fans Mesh-line ',2,'AA1217',48,'photographyacc','mate0000','nichollsp@westnet.com.au','Paul Nicholls','Daygabarr,26 Mountview Rd','BOGGABRI','New South Wales','AUSTRALIA','2382','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 08:54:13',0,NULL,3,0,3,1,'RA184555132CN ','mate0000\rxl  (已入库）'),(15145,770674950017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',4,'AA1203',11.6,'photographyacc','senior7010','s.ortiga@y7mail.com','Sergio Ortega','8/59 Mirrabooka Crescent','Little Bay','New South Wales','AUSTRALIA','2036','0296619130','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 10:03:46',0,NULL,3,1,2,1,NULL,'senior7010'),(15146,755916706002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','xredix','redik.line@gmail.com','Alex Sorochan','Novgorodskaja st. dom 6<br>kv. 50','Kyiv','Kyiv','UKRAINE','03151','(063) 077-10-72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:25:19',0,NULL,3,1,17,0,NULL,'xredix'),(15147,755916566002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','xredix','redik.line@gmail.com','Alex Sorochan','Novgorodskaja st. dom 6<br>kv. 50','Kyiv','Kyiv','UKRAINE','03151','(063) 077-10-72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:25:21',0,NULL,3,1,17,0,NULL,'xredix'),(15148,755916810002,120752248934,'33\" double layers reflective and translucent umbrella',2,'AD1156',41.98,'hermeshine','xredix','redik.line@gmail.com','Alex Sorochan','Novgorodskaja st. dom 6<br>kv. 50','Kyiv','Kyiv','UKRAINE','03151','(063) 077-10-72','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 11:25:24',0,NULL,3,1,3,1,'RA184555225CN ','xredix\r灯架包厚      1\r圆形柔光棚 50cm    1\r85cm 两用伞     2'),(15149,770704947017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','muzdav','murray@murraydavidson.com.au','Murray Davidson','3 Uno Street','Belmont','Victoria','AUSTRALIA','3216','0418489522','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 11:48:59',0,NULL,3,1,2,1,NULL,'muzdav'),(15150,770705424017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',10,'AA2202',54.8,'photographyacc','digitalfotosun','ants_ng@hotmail.com','Ng Tze Shin (Foto Sun S/B)','154, Jalan Besar,','kuantan','Pahang','MALAYSIA','25200','609-5142834','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 11:49:25',0,NULL,3,1,3,1,'RA184555795CN\r ','digitalfotosun'),(15151,714045537001,110658456901,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',9,'hermeshine','ericatorquato','ericafmt@gmail.com','ÉRICA TORQUATO','RODRIGUES JUNIOR, 921 APT 802','FORTALEZA','CEARÁ /NORDESTE','BRAZIL','60060-000','(85) 88043698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 12:23:06',0,NULL,3,1,2,1,NULL,'ericatorquato'),(15152,839361309015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3302',29,'hutongstore','pajeros10','vagginet@yahoo.gr','EVAGGELIA THOMAKOU','SPIROU MILIOU 24','KERATSINI','PIRAEUS','GREECE','18756','6974038372','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 13:07:54',0,NULL,3,1,3,1,'RA184555163CN ','pajeros10\rc 里面的东西不对  是40cm闪光的柔光棚'),(15153,839349370015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','170b2','tmarsh@7reeve.freeserve.co.uk','Terry Marsh','7 Reeve Gardens','Kesgrave','Suffolk','UNITED KINGDOM','IP5 2FG','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-22 13:21:07',0,NULL,3,1,2,1,NULL,'170b2'),(15154,714064146001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','nippi123','nippi1985@gmail.com','Sergey Shalimo','Nemiga 6-121','Minsk','','BELARUS','220004','+375291166824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 13:28:31',0,NULL,3,1,2,1,NULL,'nippi123'),(15155,715413924018,280700437375,'NIB 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',45,'photographyacc','dmproductions1989','danielmarolla@gmail.com','Daniel Marolla','42 Marina Parade','Ingham','Queensland','AUSTRALIA','4850','0747761632','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-22 13:34:23',0,NULL,3,1,3,1,'RA184555194CN ','dmproductions1989'),(15156,755959464002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','heroes19-81','cheeyeepang@hotmail.com','Chee Yee Pang','840, Jalan Teratai 36/17,<br>Taman Indahpura,','Kulai','Johor','MALAYSIA','81000','0167255137','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 13:44:01',0,NULL,3,1,2,1,NULL,'heroes19-81'),(15157,821931648016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','michaelpicas','randomizer2000@hotmail.com','Michael Picas','Artemidos 9 Aglantzia','Nicosia','','CYPRUS','2101','0035799806449','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-22 14:01:09',0,NULL,3,1,2,1,NULL,'michaelpicas'),(15158,715427834018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','tarabeloo','manuelmoreiro@yahoo.es','Manuel Moreiro Castro','Avenida de Portugal Nº 109 5ºA','Ourense','Galicia','SPAIN','32002','672028696','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 14:06:21',0,NULL,3,1,2,1,NULL,'tarabeloo'),(15159,715447879018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','anadenn777','anadenn@rambler.ru','Anastasiya Dolgova','Vorushin street 6,apartment 10','Pavlodar','','KAZAKHSTAN','140000','+77015203001','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 15:04:04',0,NULL,3,1,2,1,NULL,'anadenn777'),(15160,714101449001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','stanchev66','stanchev66stanislav@abv.bg','Stanislav Stanchev','Georgi Izmirliev 5 et.4 ap 10<br>PK.10','Plovdiv','Plovdiv','BULGARIA','4002','359888809928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 15:28:40',0,NULL,3,1,3,1,'RA184555177CN ','stanchev66'),(15161,839421696015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','roger4543','randjtaylor@roger4543.plus.com','R J Taylor','1 Hermitage Cottage, Hermitage Low Farm<br>Harpswell','Gainsborough','Lincolnshire','UNITED KINGDOM','DN21 5UZ','01427668670','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 15:34:16',0,NULL,3,1,3,1,'RA184555234CN','roger4543'),(15162,839425989015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','z5ottu','z5ottu@gmail.com','Szloboda Zsolt','Nagytétényi út 29','Budapest','Budapest','HUNGARY','1222','+36302603882','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-22 15:43:23',0,NULL,3,1,5,1,'CP235771535CN ','z5ottu'),(15163,714133674001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','idejoeeb','joeychen@yahoo.com','Joey Chen','5 PALERMO','IRVINE','CA','UNITED STATES','92614','(949) 302-1680','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-22 16:59:22',0,NULL,3,1,1,1,NULL,'idejoeeb'),(15164,770846255017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','nidmalsi','nid.malsi@free.fr','Hichame RAHOUI','2, avenue Paul Cézanne','Élancourt','Île-de-France','FRANCE','78990','0130697953','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 18:02:23',0,NULL,3,1,2,1,' ','nidmalsi'),(15165,839513768015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','phonseca','calum@clara.net','calum stirling','flat 2/1<br>30 nithsdale street','glasgow','Glasgow','UNITED KINGDOM','g41 2py','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 18:29:03',0,NULL,3,1,17,0,NULL,'phonseca'),(15166,839513974015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','phonseca','calum@clara.net','calum stirling','flat 2/1<br>30 nithsdale street','glasgow','Glasgow','UNITED KINGDOM','g41 2py','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 18:29:03',0,NULL,3,1,2,1,NULL,'phonseca\r橡胶遮光罩 55mm    1\r橡胶遮光罩 77mm   1'),(15167,770871599017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',86,'photographyacc','paulinhovb','paulo.villasboas@gmail.com','paulo vilas boas','Av Orestes Quercia, 1727','sao joaquim da barra','sao paulo','BRAZIL','14600000','55+1638182929','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-22 18:56:32',0,NULL,3,0,3,1,'RA184555883CN ','paulinhovb\r爵影碗罩P4    4'),(15168,714204813001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','speedhub50014','info@ridgeback.de','Frank Burggraf','Zum Scherbusch 15','Hennef','','GERMANY','53773','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 19:37:49',0,NULL,3,1,2,1,NULL,'speedhub50014'),(15169,756123856002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','07_lester','jlester@netspace.net.au','James Lester','93 Sharples Street','Rockhampton','Queensland','AUSTRALIA','4701','0749266773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 20:25:33',0,NULL,3,1,2,1,NULL,'07_lester'),(15170,756127349002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','twigsandtassels','lake_hampton@hotmail.com','La Von Stephens','11399 Big Canoe<br>2140 Cinnamon Fern Lane','Big Canoe','GA','UNITED STATES','30143','(678) 618-0936','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-22 20:33:55',0,NULL,3,1,1,1,NULL,'twigsandtassels'),(15171,822140698016,260661403326,'TianYa 72mm CPL filter New 72 Circular Polarizing C-PL',1,'AA2306',5.2,'hutongstore','colinek333','piteret20@poczta.onet.pl','Piotr Komincz','4 Farnworth close','Leicester','Leicestershire','UNITED KINGDOM','le4 7zl','0787660802','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 20:51:18',0,NULL,3,1,2,1,NULL,'colinek333'),(15172,756136027002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','alainh9591','alain.hug56@free.fr','alain hug','24 rue des lilas','ammerschwihr','Alsace','FRANCE','68770','0389473826','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-22 20:54:00',0,NULL,3,1,3,1,'RA184555185CN ','alainh9591\r已入库'),(15173,756135763002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','strykopietro','petertrhan@gmail.com','Radovan Bries','Svermova 28','Banska Bystrica','','SLOVAK REPUBLIC','97404','00421915229900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 20:55:31',0,NULL,3,1,5,1,'CP235771549CN ','strykopietro'),(15174,756148358002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','ashokbuet91','ashokbuet91@yahoo.com','Ashok Karmokar','803-3315 Fieldgate Drive','Mississauga','ON','CANADA','L4X 2J3','(905) 629-4946','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 21:24:10',0,NULL,3,1,2,1,NULL,'ashokbuet91'),(15175,714262496001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','kantabron2004','bernardoallende@gmail.com','Bernardo Allende Saiz','C/ Somera 10- Residencial Miramar','cortiguera','Cantabria','SPAIN','39350','672023974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 22:09:27',0,NULL,3,1,3,1,'RA184555115CN ','kantabron2004'),(15176,756171365002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','spaz1921','puntapalma@gmail.com','Salvio Paz Lorenzo','C/ General Yague nº 20  2ºA','Los Llanos de Aridane','Canarias','SPAIN','38760','638809816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-22 22:34:04',0,NULL,3,1,3,1,'RA184555248CN ','spaz1921'),(15177,839661377015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',2,'AC1201',4.36,'hutongstore','maccaulayjones','macaulay-jones@blueyonder.co.uk','Karl  Jones','5, Craven Lea','Liverpool','Merseyside','UNITED KINGDOM','L120NF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-22 23:19:41',0,NULL,3,1,2,1,NULL,'maccaulayjones'),(15178,714293213001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','suddenly_babe','suddenly_babe@yahoo.es','Raquel Mendez Barbero','Avenida Maria Ros, nº10, puerta 23A','Burjassot','Valencia','SPAIN','46100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 00:09:09',0,NULL,3,1,4,1,'YW867472364CN ','suddenly_babe\rTripod  $25\r燕文网站查补到 但是后台已经留过评价'),(15179,756199432002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',3,'AC1302',22.5,'hermeshine','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','11 83690999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 00:24:39',0,NULL,3,1,2,1,NULL,'diogodrigo2009'),(15180,714324456001,110569963962,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10 ft)',1,'AO0018',45,'hermeshine','mendibla','foto.carlosserrano@gmail.com','Carlos Serrano','portichol 89, local 1<br>n/a','javea','Alicante','SPAIN','0330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 02:13:55',0,NULL,3,0,17,0,NULL,'mendibla'),(15181,714326333001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','mendibla','foto.carlosserrano@gmail.com','Carlos Serrano','portichol 89, local 1<br>n/a','javea','Alicante','SPAIN','0330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 02:25:56',0,NULL,3,1,3,1,'RA184555251CN ','mendibla\r背景布 3x3 白色     1\r67cm接口环      1  \r已入库'),(15182,756234542002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',2,'AC1304',15,'hermeshine','leahnav','marilufdv@aol.com','Rodolfo de Vera','9125 Crebs Ave','Northridge','CA','UNITED STATES','91324-2802','(818) 645-5825','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-23 02:33:32',0,NULL,3,1,1,1,NULL,'leahnav'),(15183,713674717018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','lucky1.luke','lukeodonohue@bigpond.com','Luke Odonohue','1/1703 Roys Road','Coochin Creek','Queensland','AUSTRALIA','4519','0754940308','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 02:42:24',0,NULL,3,1,3,1,'RA184555129CN ','lucky1.luke'),(15184,714334539001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','mx357','allenrhoden58@yahoo.com','Allen Rhoden','21596 Hwy 78','Leonard','TX','UNITED STATES','75452','(903) 821-8594','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-23 03:05:33',0,NULL,3,1,1,1,NULL,'mx357'),(15185,756244918002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','sbag929','stacybaj@hotmail.com','stacy gamache','30 Stage Rd','Williamsburg','MA','UNITED STATES','01096-9304','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-23 03:13:59',0,NULL,3,1,1,1,NULL,'sbag929'),(15186,715722316018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','pagliaccih','lancewsmi@gmail.com','Lance Smith','110 Woolooware Road','Burraneer','New South Wales','AUSTRALIA','2230','0295015671','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 03:38:38',0,NULL,3,1,3,1,'RA184555203CN ','pagliaccih'),(15187,715723573018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','dealboy4','dealboy27@gmail.com','Kavit Patel','1137 Morland Dr','Statesville','NC','UNITED STATES','28677-6973','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 03:48:35',0,NULL,3,1,1,1,NULL,'dealboy4'),(15188,715730010018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',68.99,'photographyacc','paul_harmon','mail@thinkingpictures.com.au','Paul Robert Harmon','1 Park Ave','Gordon','New South Wales','AUSTRALIA','2072','0289001291','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-23 04:18:37',0,NULL,3,1,3,1,'RA184555866CN ','paul_harmon\r加一个布'),(15189,771054795017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','luji567','luji1985@gmail.com','Ji Lu','5a Daly street','South Plympton','South Australia','AUSTRALIA','5038','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 04:30:02',0,NULL,3,1,2,1,NULL,'luji567'),(15190,715737441018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','lill_123','oliviadireen@bigpond.com','Olivia Direen','22 Judds Creek Road','Judbury','Tasmania','AUSTRALIA','7109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 05:02:09',0,NULL,3,0,2,1,NULL,'lill_123\r1.6*2.1  白色背景布    1'),(15191,714356709001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','rachamim','rachamimadony@gmail.com','rachamim adony','duvdvan 402/13','tibeias','israel','ISRAEL','14419','054-4645901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 05:07:43',0,NULL,3,1,2,1,NULL,'rachamim'),(15192,715741661018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','princess-sezza87','princess-sezza@hotmail.com','Sarah Anne Woodhouse','unit 1703 22/34 Glenside Drive ROBINA','Gold Coast','Queensland','AUSTRALIA','4226','0755757280','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 05:27:23',0,NULL,3,0,3,1,'RA184555217CN ','princess-sezza87\r1.6*2.1 黑色加白色背景布');
INSERT INTO `hmsh_ebay_transaction` VALUES (15193,756282306002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','aghia0_1','a.r@artificialia.it','Alessandro Reale c/o SF SERVIZI','Via Alcide Pedretti, 6','Ostia Lido (Roma)','Roma','ITALY','00121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:53:22',0,NULL,3,1,17,0,NULL,'aghia0_1'),(15194,756282039002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','aghia0_1','a.r@artificialia.it','Alessandro Reale c/o SF SERVIZI','Via Alcide Pedretti, 6','Ostia Lido (Roma)','Roma','ITALY','00121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:53:23',0,NULL,3,1,17,0,NULL,'aghia0_1'),(15195,756282212002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','aghia0_1','a.r@artificialia.it','Alessandro Reale c/o SF SERVIZI','Via Alcide Pedretti, 6','Ostia Lido (Roma)','Roma','ITALY','00121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 06:53:23',0,NULL,3,1,2,1,NULL,'aghia0_1\r方形滤镜接口环 77mm  1\r方形滤镜接口环 72mm    1\r方镜广角托架（ 一槽）     1'),(15196,839321684015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','tragic19','craigdonnatuffield@yahoo.co.uk','craig tuffield','41 elmwood drive','bexley','Kent','UNITED KINGDOM','da53pt','02082989532','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 06:59:23',0,NULL,3,1,2,1,NULL,'tragic19'),(15197,822324796016,260808933176,' New Pro Photo Vest for all DSLR fans Nikon  Canon Sony',1,'AA1103',18.6,'hutongstore','321ian','ian_lanman@yahoo.co.uk','Ian Lanman','71 Abbots Gardens','London','London','UNITED KINGDOM','N2 0JG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-23 07:19:24',0,NULL,3,0,3,1,'RA184555305CN ','321ian\rXL   已入库 '),(15198,714382050001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',3,'AE1401',115.5,'hermeshine','vitaliyukr','27poltava@mail.ru','Vitaliy Nazarenko','Borovikovskogo 9-85','Poltava','','UKRAINE','36023','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 07:46:10',0,NULL,3,1,5,1,'CP227167490CN ','vitaliyukr'),(15199,771102709017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',228,'photographyacc','sloganflakes','antxon.c@gmail.com','antonio corcuera del puerto','C/Jose Pellicer 48,4 izda','zaragoza','Aragón','SPAIN','50007','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 07:49:00',0,NULL,3,1,12,1,'BJ8824605','sloganflakes\rtripod $30  \r新地址\rMonika Arzanauskaite\rS.Lozoraićio 24 a\r50136 Kaunas \rLithuania\r'),(15200,8881314086979620,111,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',0,'hermeshine','handy_man_jeff','handy_man_jeff@hotmail.com','Jeff Clark','526 McGowan Avenue','Kamloops','BC','CANADA','V2B 2P6','',NULL,NULL,NULL,'2011-08-23 08:09:39',0,NULL,3,0,2,1,' ','黄色的'),(15201,8881314087669730,111,'1.6x2.1m 红色背景布  x   1',1,'',0,'photographyacc','coghy87','pikkoloprincipe@msn.com','davide coghene','via e.fermi 19','s.giusta','OR','ITALY','09096','3491424190',NULL,NULL,NULL,'2011-08-23 08:21:09',0,NULL,3,0,3,1,'RA184555265CN\r ',NULL),(15202,8881314088386766,111,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'AKT037',140,'hutongstore','arunasan','arunasan@yahoo.co.uk','Private: Arun Asan','Enable Ireland, Seamus Quark Road','New Castle','Galway,Galway','IRELAND','091','',NULL,NULL,NULL,'2011-08-23 08:33:06',0,NULL,5,0,18,0,NULL,''),(15203,714393201001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','dialf1','filipovmail@yahoo.com','Filip Grzincic','Simonettieva 5','Rijeka','Croatia','CROATIA','51000','00385915297604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 08:43:39',0,NULL,3,1,3,1,'RA184555279CN\r ','dialf1'),(15204,715788620018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','the_macksta','treeborcreations@hotmail.co.uk','Robert Mckindley','5 kurrajomg close Viewbank','Melbourne','Victoria','AUSTRALIA','3084','0406005697','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 09:27:14',0,NULL,3,1,3,1,'RA184555336CN\r ','the_macksta'),(15205,715787196018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','jacky_dragon','jacky_dragon@hotmail.com','Jack Zhao','6 riordan place','templestow lower','Victoria','AUSTRALIA','3107','0408013839','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 09:35:48',0,NULL,3,1,3,1,'RA184588192CN ','jacky_dragon'),(15206,714408975001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','ultramarines40k','ultramarines40000@gmail.com','Santo  Halim','Jl . Dr Setia Budi Gg.5 Selatan No 14','Pontianak','Kalimantan Barat','INDONESIA','78122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 10:04:41',0,NULL,3,1,2,1,NULL,'ultramarines40k'),(15207,714433148001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kadirerdil','erdil3455@yahoo.com','kadir erdil yilmaz','keskin kalem sok no 39','istanbul esentepe','esentepe','TURKEY','34394','00902122120665','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 11:36:12',0,NULL,3,0,3,1,'RA184555319CN\r ','kadirerdil\rXXL   已入库        '),(15208,713487660001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','kengrima','kengrima@yahoo.com','Kenneth Grima','Del Sol St. Paul Street','Mellieha','Europe','MALTA','MLH 1192','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 11:41:09',0,NULL,3,1,3,1,'RA184555472CN\r','kengrima\r欧标\rRA184555469CN\r'),(15209,715838918018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','melomert','melo-mert@hotmail.com','Mert Eren','Caglayan Mahallesi 2014 Sokak<br>Doruk Evleri Sitesi B blok kat 5 daire 11','Antalya','Lara/Antaya','TURKEY','07160','+90242 324 1052','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 12:24:37',0,NULL,3,1,3,1,'RA184555322CN\r ','melomert'),(15210,714450789001,110717036916,'NEW PRO LED 312 Panel Camera & Camcorde​r Light 5600k',1,'AD1150',230,'hermeshine','mchana1212','mochana1@hotmail.co.uk','Mohinder Chana','49 Blumfield Crescent','Slough','Berkshire','UNITED KINGDOM','SL1 6NL','01628669132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 12:42:34',0,NULL,3,1,4,1,'YW867471804CN ','mchana1212\r燕文网站查不到  后台也没有留过评价\r▲  已发信'),(15211,714451263001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','nunsojonas','hmagrieger@aol.com','Hartwin Grieger','Wormser 11','Bermersheim','','GERMANY','67593','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 12:44:05',0,NULL,3,1,3,1,'RA184555441CN\r ','nunsojonas'),(15212,714467890001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','tkemaly','nonstop_kb@mail.ru','Alexandr Koryvanov','Turgeneva str 6-20','Stupino','Moscow region','RUSSIAN FEDERATION','142800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 13:44:38',0,NULL,3,1,5,1,'CP227167778CN ','tkemaly'),(15213,714470070001,110469599873,'Photo Video Light Stands Studio Photo Stand 7ft 200cm',1,'AE3401',28,'hermeshine','goranavalon','g.ugresic@gmail.com','Goran Ugresic','Borislava Stankovica 5','Gradiska','RS','BOSNIA AND HERZEGOVINA','78400','+387 65 569 189','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 13:52:37',0,NULL,3,1,17,0,NULL,'goranavalon'),(15214,715873958018,280700437375,'NIB 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',45,'photographyacc','fhano_eu','fhano.eu@scarlet.be','Vanmeenen Stefaan (Fhano.eu)','rue des perdrix 28','Mouscron','','BELGIUM','7700','0477594999','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 14:17:15',0,NULL,3,1,3,1,'RA184555438CN\r ','fhano_eu\r申报 filter  $10'),(15215,714479129001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','goranavalon','g.ugresic@gmail.com','Goran Ugresic','Borislava Stankovica 5','Gradiska','RS','BOSNIA AND HERZEGOVINA','78400','+387 65 569 189','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 14:22:33',0,NULL,3,1,5,1,'CP227167755CN ','goranavalon\r灯架  2m    2\r柔光箱 50-70cm 单灯头  欧标   1\r斜臂     1 \r115w 5500k 灯泡  220v     1\r灯架包      1'),(15216,756396172002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','hannah7534','hannah.chapman@yahoo.co.uk','Hannah Chapman','29 Winchelsea Road','Chatham','Kent','UNITED KINGDOM','me5 7ly','01634201598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 14:25:20',0,NULL,3,1,2,1,NULL,'hannah7534'),(15217,756400572002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','dga650','dga65@libero.it','Angelo Di Gennaro','Via Russi 69','novara','Novara','ITALY','28100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 14:38:44',0,NULL,3,1,3,1,'RA184555367CN\r ','dga650\rLight Stand   $15'),(15218,714492791001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','jules_1955','jules_1955@btconnect.com','Julian Nash','2 Langridge Lane','Bath','Somerset','UNITED KINGDOM','BA1 9BX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:07:38',0,NULL,3,1,2,1,NULL,'jules_1955'),(15219,756409218002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','rareraf','radovanrehak@gmail.com','Radovan Rehák','Geologická 1E','Bratislava','Slovakia','SLOVAK REPUBLIC','82106','00421903768641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:08:01',0,NULL,3,1,3,1,'RA184555384CN\r ','rareraf'),(15220,756420200002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','peterfulop77','peter.fulop77@gmail.com','Peter Fulop','Szekelyhid St 24/b','Budapest','Budapest','HUNGARY','1204','+36706208964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:51:09',0,NULL,3,1,17,0,NULL,'peterfulop77'),(15221,714499585001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','peterfulop77','peter.fulop77@gmail.com','Peter Fulop','Szekelyhid St 24/b','Budapest','Budapest','HUNGARY','1204','+36706208964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:51:10',0,NULL,3,1,17,0,NULL,'peterfulop77'),(15222,714496691001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','peterfulop77','peter.fulop77@gmail.com','Peter Fulop','Szekelyhid St 24/b','Budapest','Budapest','HUNGARY','1204','+36706208964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 15:51:10',0,NULL,3,1,3,1,'RA184555407CN\r ','peterfulop77\r绿叶 渐变镜 62mm    1\r柔光箱 50-70cm 单灯头欧标   1\r大力夹云台     1'),(15223,714520365001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','petroff49','petroff@aaanet.ru','Andrey Petroff','b.Komarova, 9, kv.56','Rostov-na-Donu','Rostov','RUSSIAN FEDERATION','344092','79185549049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 16:26:57',0,NULL,3,1,2,1,NULL,'petroff49'),(15224,714544635001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','rialller','cdomingo@gmail.com','Carlos Domingo Agustín','piso 4 puerta 4<br>Carrer de la Industria 356','BARCELONA','Cataluña','SPAIN','08027','679295939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:34:06',0,NULL,3,1,2,1,NULL,'rialller'),(15225,715949453018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','cricheler','gerry.rysiok@gmail.com','G Rysiok','25 Hounslow Close','Poole','Dorset','UNITED KINGDOM','BH15 4BX','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 17:42:25',0,NULL,3,1,2,1,NULL,'cricheler'),(15226,714549213001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','joseyner','nereidadelcarmen@hotmail.com','Jose ANTON DIAZ','c/ RIO TORMES 18 PUERTA 4','Telde','Canarias','SPAIN','35218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:46:06',0,NULL,3,1,17,0,NULL,'joseyner'),(15227,756466652002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','joseyner','nereidadelcarmen@hotmail.com','Jose ANTON DIAZ','c/ RIO TORMES 18 PUERTA 4','Telde','Canarias','SPAIN','35218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:46:06',0,NULL,3,1,17,0,NULL,'joseyner'),(15228,756465985002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','joseyner','nereidadelcarmen@hotmail.com','Jose ANTON DIAZ','c/ RIO TORMES 18 PUERTA 4','Telde','Canarias','SPAIN','35218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 17:46:07',0,NULL,3,1,2,1,NULL,'joseyner\r方形滤镜接口环 67mm     1\r方镜普通托架（三槽）    1\r方形滤镜接口环 77mm    1\r方镜广角托架（ 一槽）   1'),(15229,715961223018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','alerossella','alessandro.fuccillo@gmail.com','Alessandro Fuccillo','VIA DELL\' INDIPENDENZA 416','Rossano Veneto','VI','ITALY','36028','3664572506','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-23 18:12:04',0,NULL,3,0,4,1,'YW867471782CN ','alerossella\rBackground Support  $25\r1.6*2.1   白色背景布'),(15230,755350637002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','sholag','sholaman@yahoo.com','Ganiyu Maiyaki','7573 S Coles Ave<br>(MAILMAN Pls Ring DOORBELL) Apt 3','chicago','IL','UNITED STATES','60649-4334','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-23 18:46:51',0,NULL,3,1,1,1,NULL,'sholag'),(15231,840071579015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','doart','doapostolova@gmail.com','Dora Apostolova','Svoboda 43','Plovdiv','Plovdiv','BULGARIA','4002','0878 245722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 19:12:45',0,NULL,3,1,2,1,NULL,'doart'),(15232,756518436002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','edusimao','edu.simao@gmail.com','eduardo simão','av são luis, 131<br>apto 52','são paulo','são paulo','BRAZIL','01046001','(11) 70397696','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 19:41:44',0,NULL,3,1,3,1,'RA184555375CN\r ','edusimao'),(15233,756525996002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',5,'AA1310',27.45,'hermeshine','pearlchao','rickychao@gmail.com','Ricky Chao','3289 West 28th Ave','Vancouver','BC','CANADA','V6L 1X6','(604) 739-0579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 20:00:55',0,NULL,3,1,3,1,'RA184555455CN\r ','pearlchao'),(15234,756533044002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','pentiumjim','pentiumjim@hotmail.com','James McFarland','Sharpe Blackmore<br>473 Adelaide St. W.  Suite 300','Toronto','ON','CANADA','M5V 1T1','(416) 779-8941','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 20:16:35',0,NULL,3,1,2,1,NULL,'pentiumjim'),(15235,840129503015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',48,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-23 20:57:19',0,NULL,3,1,3,1,'RA184555509CN\r ','leifs123\r要求申报$20'),(15236,840139653015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','piomareva2006','piomareva@hotmail.com','Carmelo Mata Marín','Avd. Estudiantes nº14. 2ºH','Valdepeñas','Castilla-La Mancha','SPAIN','13300','926310556','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 21:20:10',0,NULL,3,1,2,1,NULL,'piomareva2006'),(15237,756567337002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',20.97,'hermeshine','casildagarreton2010','casilda.garreton@gmail.com','Marco Ruttimann','975 Crandon Blvd','Key Biscayne','FL','UNITED STATES','33149-2753','305 365 5539','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-23 21:36:25',0,NULL,3,1,1,1,NULL,'casildagarreton2010'),(15238,715819804018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','angelboof','melissadean84@yahoo.com.au','Melissa Dean','PO Box 67','Banyo','Queensland','AUSTRALIA','4014','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-23 21:39:25',0,NULL,3,0,2,1,NULL,'angelboof\r白色'),(15239,756589662002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','cipanu_ro','cipanul@gmail.com','Ciprian Iorgu','Piata Stefan cel Mare, nr.12, bl C6, Ap.1','Piatra Neamt','Neamt','ROMANIA','610016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-23 22:44:47',0,NULL,3,1,3,1,'RA184555415CN\r ','cipanu_ro'),(15240,716084755018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','zzrmags','info@canvasmegoria.com','Maggie Dygut','8 Licola Ct','Broadmeadows','Victoria','AUSTRALIA','3047','0432719109','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-23 23:07:46',0,NULL,3,1,4,1,'YW867471771CN ','zzrmags \r1.6*2.1 白色背景布 \r Background Support   $25'),(15241,756600621002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','raisilva1970','raisilva07@gmail.com','raimundo E verardo Gomes da silva','QNN 06 Conjunto A casa 37<br>Ceilandia sul','Brasilia','Distrito federal','BRAZIL','72220-061','55 61 92217787','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 23:26:59',0,NULL,3,1,17,0,NULL,'raisilva1970'),(15242,714678287001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','raisilva1970','raisilva07@gmail.com','raimundo E verardo Gomes da silva','QNN 06 Conjunto A casa 37<br>Ceilandia sul','Brasilia','Distrito federal','BRAZIL','72220-061','55 61 92217787','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-23 23:37:05',0,NULL,3,1,3,1,'RA184555424CN\r ','raisilva1970\rcanon 原厂背心 L    1\r摄影背心 nikon 原厂  L      1  75周年那款\r已入库 '),(15243,840193606015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','bufah78','gretabirgitte@hotmail.com','Greta Birgitte Jaksholt','Holta','Lillesand','','NORWAY','4790','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-23 23:42:25',0,NULL,3,1,2,1,NULL,'bufah78'),(15244,756619649002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','seankelly10','seankgordon@gmail.com','Sean Gordon','7954 Woodlake Dr','Riverdale','GA','UNITED STATES','30274-3936','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-24 00:43:02',0,NULL,3,1,1,1,NULL,'seankelly10'),(15246,8881314150914118,111,'Background Support & Light Kit + 3m x 9m white backdrop',1,'AKT038',140,'hutongstore','arunasan','arunasan@yahoo.co.uk','Private: Arun Asan','Enable Ireland, Seamus Quark Road','New Castle','Galway,','IRELAND','091','0870983174',NULL,NULL,NULL,'2011-08-24 01:55:14',0,NULL,3,1,4,1,'YW867471793CN ','注意：背景布-白色-3x9m \r英标\r申报：lighting kit $40 \r这个应该是没经过ebay  所以查不到'),(15247,756655385002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27.8,'hermeshine','todsapon','suwapanont@hotmail.com','Todsapon Suwapanont','555/104 Thongpracha condo<br>Prachauthid road.  Samsennork','Huaykwang','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 02:54:19',0,NULL,3,1,3,1,'RA184555490CN\r ','todsapon'),(15248,756666499002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-24 03:49:19',0,NULL,3,1,3,1,'RA184555486CN\r ','mariomarques.com.br'),(15249,771507535017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','badicalo','alexfarrugia@me.com','Alex Farrugia','12 Heeterra Place','Cordeaux Heights','New South Wales','AUSTRALIA','2526','0242712226','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 03:50:55',0,NULL,3,1,2,1,NULL,'badicalo'),(15250,756691066002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','studioalisa','aan2020@mail.ru','Sergey Nasakin','Lermontova Street, 42 apt# 25','Sibay','Bashkortostan','RUSSIAN FEDERATION','453830','(7)9373314589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 06:24:14',0,NULL,3,1,3,1,'RA183628964CN ','studioalisa'),(15251,840303500015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','yurys716','yuryss@gmail.com','Yury Sokolov','Kojelaviciaus 210-1','Vilnius','Lithuania','LITHUANIA','LT 11107','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 06:36:23',0,NULL,3,1,2,1,NULL,'yurys716'),(15252,771549173017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','siri9','hema90@hotmail.com','Hemasiri Gamage, co Mrs.Erin Perera','3 Park lane','Canning Vale','Western Australia','AUSTRALIA','6155','0861610541','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 07:36:57',0,NULL,3,1,2,1,NULL,'siri9'),(15253,756709612002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','milo_wei','milo.wei@yahoo.com.hk','Wei Liu','18 Jasper Avenue<br>Mount Roskill','Auckland City','Auckland','NEW ZEALAND','1041','006421532312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 07:55:21',0,NULL,3,1,2,1,NULL,'milo_wei'),(15254,756710645002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','theprivateer81','jimmyzala81@gmail.com','James Zala','04/02<br>281 Joo Chiat Place','default','','SINGAPORE','427962','93744860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-24 08:12:50',0,NULL,3,1,9,1,'104231201108240038 ','theprivateer81\r英标'),(15255,716204510018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','sloshslosh2','jyebuckley@gmail.com','Julie Harding ','9/12 Fig St','Maleny ','Queensland','AUSTRALIA','4552','0754943245','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 08:20:47',0,NULL,3,0,2,1,NULL,'sloshslosh2\r1.6*2.1 白色背景布'),(15256,714795712001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','55mbk55','matvievskiy@gmail.com','Boris Matvievskiy','Krasnoshkolnaya nab.18 kv.36','Kharkov','','UKRAINE','61010','+380503235176','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 09:34:07',0,NULL,3,1,5,1,'CP227167512CN ','55mbk55'),(15257,716229832018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','thanhtan01','thanhhthy@yahoo.com','Thanh Trang','23 Frimley Way','Morley','Western Australia','AUSTRALIA','6062','0892752695','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 10:06:38',0,NULL,3,1,3,1,'RA184555628CN\r ','thanhtan01'),(15258,771585709017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',3,'AO0001',570,'photographyacc','remicoud','remicou@yahoo.fr','Coudreau Rémi','17, Rue du docteur Rollet','Villeurbanne','Rhône-Alpes','FRANCE','69100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-24 10:11:40',0,NULL,3,1,12,1,'BJ8824607 ','remicoud\r5238221833 DHL单号'),(15259,716233965018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',60,'photographyacc','aba8shop','aba007@tpg.com.au','Abraham Liu','9A/ 38 Bridge St','Eltham','Victoria','AUSTRALIA','3095','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 10:23:08',0,NULL,3,1,3,1,'RA184555702CN\r ','aba8shop\r在外包装上贴\rPLEASE DELIVER AFTER 10.30AM\r需要打印'),(15260,771588881017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','jacekid01','jason@kidd.id.au','Jason Kidd','15 Altree Court','Phillip','Australian Capital Territory','AUSTRALIA','2606','0419194408','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-24 10:23:48',0,NULL,3,1,2,1,NULL,'jacekid01'),(15261,840390109015,250599424460,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',2,'AA1308',3.76,'hutongstore','0706alan','cottonmouth@tiscali.co.uk','alan schofield','18 broadfield drive<br>smithybridge.','littleborough','Lancashire','UNITED KINGDOM','ol15 0eu','01706374890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 11:41:57',0,NULL,3,1,2,1,NULL,'0706alan'),(15262,716261966018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','paulblack99','paulblack01@optusnet.com.au','Richard Dabbous','Ground Floor, 601 St Kilda Road','Melbourne','Victoria','AUSTRALIA','3004','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 12:04:14',0,NULL,3,1,2,1,NULL,'paulblack99'),(15263,716264672018,280685226047,'Brand New Light Soft Box for Studio Strobes 70cm x 50cm',1,'AD1124',40,'photographyacc','sloshslosh2','jyebuckley@gmail.com','Julie Harding ','9/12 Fig St','Maleny ','Queensland','AUSTRALIA','4552','0754943245','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 12:12:07',0,NULL,3,1,3,1,'RA184555526CN\r ','sloshslosh2\r澳标'),(15264,756795449002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','aasa_bergem','aasa.bergem@gmail.com','Åsa bergem','Rathkesgate 9','Oslo','OSLO','NORWAY','0558','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 13:45:17',0,NULL,3,1,3,1,'RA184555543CN\r ','aasa_bergem\r申报$35'),(15265,714869820001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jeanmicheljoseph','j-michel.lesquelin@wanadoo.fr','Jean-Michel Lesquelin','3 rue Albert Camus<br>Le Saint Laurent','La Possession','Réunion','REUNION','97419','0262449713','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 14:15:44',0,NULL,3,1,2,1,NULL,'jeanmicheljoseph'),(15266,714912929018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','swannemt','swannemt@bellsouth.net','Rhonda Swann','408 Centerhill Road','Hanceville','AL','UNITED STATES','35077','(256) 338-3309','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-24 14:26:39',0,NULL,3,1,1,1,NULL,'swannemt'),(15267,756805974002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','betlog','betlogbetlog@hotmail.com','Andrew Eglington','166 Herston Road, Herston','Brisbane','Queensland','AUSTRALIA','4006','610738562341','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 14:21:28',0,NULL,3,1,3,1,'RA184555557CN\r ','betlog'),(15268,714878122001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','brosca123','acky@bigpond.com','Alex Brosca','221 Lygon St<br>Carlton','Melbourne','Victoria','AUSTRALIA','3053','0393881156','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-24 14:43:00',0,NULL,3,0,3,1,'RA184555512CN\r ','brosca123\rXXXL   已入库 '),(15269,771673823017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','lasirene2001','melitachung@hotmail.com','Damon Rollings','55 Dunn Bay Rd<br>Shop 7b centrepoint shopping centre','Dunsborough','Western Australia','AUSTRALIA','6281','0897567273','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 14:55:51',0,NULL,3,1,2,1,NULL,'lasirene2001'),(15270,756820563002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 15:03:43',0,NULL,3,1,2,1,NULL,'viong'),(15271,756820435002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','shadowsing11','leon03310@hotmail.com','WEI KONG','BLK 407A #05-23<br>Fernvale Rd','default','','SINGAPORE','791407','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 15:08:01',0,NULL,3,1,3,1,'RA184555605CN\r ','shadowsing11'),(15272,714880117001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-24 15:10:37',0,NULL,3,1,3,1,'RA184555574CN\r ','axonalex'),(15273,716321212018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',2.5,'photographyacc','dmproductions1989','danielmarolla@gmail.com','Daniel Marolla','42 Marina Parade','Ingham','Queensland','AUSTRALIA','4850','0747761632','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 15:20:49',0,NULL,3,1,2,1,NULL,'dmproductions1989'),(15274,840487212015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','esmat2','ameani_asmat@hotmail.com','Asmatullah yaqhubi','20 Champlain house<br>white city state','london','London','UNITED KINGDOM','w12 7qn','07872112309','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-08-24 16:03:09',0,NULL,3,1,12,1,'BJ8824609 ','esmat2\r英标'),(15275,840471194015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','anjelyss','anjelys@yandex.ru','Sergei Kuznecov','Kirova 8 flat 12','Zhukovski','Moscow','RUSSIAN FEDERATION','140185','+79067568317','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 16:04:38',0,NULL,3,1,17,0,NULL,'anjelyss'),(15276,840377697015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','anjelyss','anjelys@yandex.ru','Sergei Kuznecov','Kirova 8 flat 12','Zhukovski','Moscow','RUSSIAN FEDERATION','140185','+79067568317','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-24 16:04:40',0,NULL,3,1,5,1,'CP227167509CN ','anjelyss\r除了c 里面的再发\r圆形柔光棚 60cm    1\r欧标 '),(15277,756843023002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','igartop','igartop@hotmail.com','ignacio Arrieta','Apartado Postal 122','Leioa','Vizcaya','SPAIN','48940','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 16:08:38',0,NULL,3,1,2,1,NULL,'igartop'),(15278,714912744001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','kirjama','kirjama@gmail.com','Goce Eftimov','Hristo Smirnenski 41','Skopje','MK','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','+38978645570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 16:26:26',0,NULL,3,1,3,1,'RA184555588CN\r ','kirjama\r欧标'),(15279,840505542015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','shinnyshan18','noddles18@hotmail.com','sinead ohalloran','59 whitechurch way,ballyboden<br>rathfarnham','dublin','Dublin','IRELAND','16','014946541','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-24 16:32:50',0,NULL,3,1,3,1,'RA184555591CN\r ','shinnyshan18\r英标'),(15280,714928523001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','oagoag','omeralghamdi@gmail.com','omer al ghamdi','P.O.Box 1817 Najma<br>saudi aramco','Ras Tanura','eastern province','SAUDI ARABIA','31311','+966558232023','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-24 17:11:23',0,NULL,3,1,3,1,'RA184555659CN\r ','oagoag\r1.6*2.1黑色加白色背景布\rRA184555645CN\r'),(15281,756885772002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','totsamiy906at','ilqar_kerimli@hotmail.com','Ilqar Kerimli','Apt.50, 121 Mir-Jalal str, 9 Microdistrict, Baku','Baku, Mob:(055) 6501082','','AZERBAIJAN','AZ1147','994556501082','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 17:59:54',0,NULL,3,1,2,1,NULL,'totsamiy906at'),(15282,714965228001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',5.98,'hermeshine','hahadagang','lu_ming@live.concordia.ca','Ming Lu','7400 Sherbrooke West<br>Apt. 603','Montreal','QC','CANADA','H4B 1R8','(514) 559-1658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 18:36:49',0,NULL,3,1,2,1,NULL,'hahadagang'),(15283,716417235018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','protein82','corilee73@hotmail.com','Cori Haugen','8649 Bluff Dr','Pittsville','WI','UNITED STATES','54466-9765','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-24 19:00:59',0,NULL,3,1,4,1,'YW867472320CN ','protein82'),(15284,840602448015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','kostasls','kostasls@yahoo.gr','Konstantinos Liakos','Ifasiou 43','Ano Ilisia','Zografou','GREECE','15772','0030 6936659753','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-24 19:32:01',0,NULL,3,1,3,1,'RA184555530CN\r ','kostasls'),(15285,771791852017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','domino702hotmail','domino702@naver.com','Hangyeol Lee','5 arncliffe close','Carindale','Queensland','AUSTRALIA','4125','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 19:34:46',0,NULL,3,1,2,1,NULL,'domino702hotmail'),(15286,715028969001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','narfit','442@rogers.com','Craig Bishop','30-1133 Ritson Rd N','Oshawa','ON','CANADA','L1G 7T3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 21:02:10',0,NULL,3,1,2,1,NULL,'narfit'),(15287,840667704015,250692237371,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',6.8,'hutongstore','littona123','alanlitton@hotmail.co.uk','Alan Litton','21 Winchester Close, Lower Stratton,','Swindon','Wiltshire','UNITED KINGDOM','SN3 4HB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-24 21:35:41',0,NULL,3,1,2,1,' ','littona123'),(15288,756994525002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',10,'AKT014',369.5,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-24 22:57:21',0,NULL,3,1,12,1,'BJ8824606 ','ahmedphotobh\rdhl单号：5238221822'),(15289,714314794018,280678921922,'Neoprene  Camera Cover 4 Nikon D700 + 24-70mm D3s XL ',1,'AD1112',7.58,'photographyacc','torkan007','steveb@logicalbytes.com.au','Steve Bull','PO Box 21','Brighton-le-Sands','New South Wales','AUSTRALIA','2216','0295676723','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 23:27:53',0,NULL,3,0,17,0,NULL,'torkan007'),(15290,714786131018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','035bronson','lynmcconnell@westvic.com.au','Lynette McConnell','802 Penshurst Road','Kirkstall','Victoria','AUSTRALIA','3283','0355658701','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 23:29:24',0,NULL,3,0,2,1,NULL,'035bronson'),(15291,714357646018,280700437375,'NIB 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',45,'photographyacc','torkan007','steveb@logicalbytes.com.au','Steve Bull','PO Box 21','Brighton-le-Sands','New South Wales','AUSTRALIA','2216','0295676723','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-24 23:29:28',0,NULL,3,0,3,1,'RA184555781CN\r ','torkan007\r内胆包无字加大     1\r可调ND镜 77mm     1  '),(15292,716529035018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','limmerm','limmer.michael@gmail.com','Michael Limmer','25 Butler Blvd.','Winnipeg','MB','CANADA','R2R0Y7','(204) 296-1459','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-24 23:58:02',0,NULL,3,1,3,1,'RA184555631CN\r ','limmerm'),(15293,771895251017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','morts21','joel.mortimer1@hotmail.com','Joel Mortimer','Unit 2/124 Market St','Sale','Victoria','AUSTRALIA','3850','0402348395','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-25 00:28:06',0,NULL,3,1,2,1,NULL,'morts21'),(15294,757024101002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','illan1990','illangonzali@gmail.com','Illán Gonzali González','C/La Playa, 3, 4ºB','Gijón','Asturias','SPAIN','33202','687324960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 00:28:31',0,NULL,3,1,4,1,'YW867472331CN ','illan1990\r欧标  本身应该就是欧标\r已经收到 我在西班牙网站查的    '),(15295,757031173002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 00:45:59',0,NULL,3,1,3,1,'RA184555565CN\r ','mariomarques.com.br'),(15296,715095252001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','firepic','fire511@comcast.net','FLASH VIDEO LIMITED PRODUCTIONS','6810 N Northwest Hwy<br>1C','CHICAGO','IL','UNITED STATES','60631','(312) 719-5177','NoPaymentFailure','CheckoutComplete','Other','2011-08-25 01:09:21',0,NULL,3,0,1,1,NULL,'firepic\r2XL   已入库'),(15297,8881314239025585,111,'45w 5500k 灯泡 220v',1,'AKT007',0,'photographyacc','papucibg','k_rasta@abv.bg','Radoslav Georgiev','Mladost 1 bl.1 fl.11 ap.65<br>Mladost 1 bl.1 fl.11 ap.65','Sofia','Sofia','BULGARIA','1784','546565464',NULL,NULL,NULL,'2011-08-25 02:23:45',0,NULL,3,1,3,1,'RA184555614CN\r ','上一票坏了一个，补发给他个新的。 '),(15298,716582547018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',78,'photographyacc','nimali867','nimalig@gmail.com','Nimali Wickramaratne','201/26 parkside crescent<br>Pinnacle apartments','Campbelltown','New South Wales','AUSTRALIA','2560','0434984488','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-25 03:41:38',0,NULL,3,1,4,1,'YW867472342CN ','nimali867\r澳标'),(15299,716599759018,280709593667,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',36,'photographyacc','bk-maxi','bck.photography@gmail.com','Birgit Korn','c/o Ernst and Young<br>1 Eagle Street, Mail room level 31','Brisbane','Queensland','AUSTRALIA','4000','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-25 05:21:28',0,NULL,3,1,3,1,'RA184555954CN\r ','bk-maxi'),(15300,757092507002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rostov-papa','r.v.chirkov@gmail.com','Roman Chirkov','Lenina 170 app. 8','Rostov-on-Don','','RUSSIAN FEDERATION','344023','918-555-9280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 05:40:35',0,NULL,3,1,2,1,NULL,'rostov-papa'),(15301,708258098001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','zuvaymm','yavuzalbayrak@gmail.com','yavuz albayrak','ataturk bulvari 191/b<br>kavaklidere','ankara','','TURKEY','06680','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 06:01:11',0,NULL,3,1,2,1,NULL,'zuvaymm'),(15302,715162604001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',9.99,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 07:06:30',0,NULL,3,1,17,0,NULL,'copetin2009'),(15303,757108482002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9.95,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 07:14:59',0,NULL,3,1,11,1,NULL,'copetin2009\r柔光伞    1\r闪光灯B座     1'),(15304,715165955001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','aukehoekstra','hoekstra@living-structures.com','Auke Hoekstra','Schelfhoutstraat 16','The Hague','','NETHERLANDS','2526XP','0031703077356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 07:26:52',0,NULL,3,1,2,1,' ','aukehoekstra'),(15305,757110583002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','mjr.tom.s','mjrtom@myworx.de','T. Seiffert','2, Damai 33<br>Jln Damai 33','Kuala Lumpur','','MALAYSIA','55000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 07:31:44',0,NULL,3,0,17,0,NULL,'mjr.tom.s'),(15306,715166061001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','mjr.tom.s','mjrtom@myworx.de','T. Seiffert','2, Damai 33<br>Jln Damai 33','Kuala Lumpur','','MALAYSIA','55000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 07:33:16',0,NULL,3,1,6,1,'EE495359361CN ','mjr.tom.s\r115w 5500k 灯泡  220v      4\r配50-70棚的4灯头伞孔  英标   1'),(15307,715170864001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','setavr80','setavr@mail.ru','Igor Dorofeev','Zapadnaya 15-31','Dimitrovgrad','Ul`yanovskaya obl','RUSSIAN FEDERATION','433513','927-802-3366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 07:51:06',0,NULL,3,1,17,0,NULL,'setavr80'),(15308,757115846002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','setavr80','setavr@mail.ru','Igor Dorofeev','Zapadnaya 15-31','Dimitrovgrad','Ul`yanovskaya obl','RUSSIAN FEDERATION','433513','927-802-3366','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 07:54:15',0,NULL,3,1,5,1,'CP227167747CN ','setavr80\r三脚架 伟峰 WF-6663A    1\rlenspen    1\r气吹 + 布    1'),(15309,716633990018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','tugcanuk1','tugcanutku@hotmail.co.uk','Tugcan Utku','MESA CAMYOLU SITESI  C2/B BLOCK NO:22<br>YASAMKENT MAHALLESI  CAYYOLU','ANKARA','','TURKEY','06538','00905335508684','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 08:26:09',0,NULL,3,1,3,1,'RA184555693CN\r ','tugcanuk1'),(15310,757126903002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','alperorus','alperor@gmail.com','Alper Orus','Gurpinar Mah. Bulgurlu Cad.<br>Masaldan Is Merkezi G Blok Kat:3','Istanbul','BCamlica','TURKEY','34696','902163165353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 08:49:07',0,NULL,3,1,2,1,NULL,'alperorus'),(15311,8881314262313910,111,'反光板支架绞盘1副',1,'',0,'hermeshine','miguel_out','miguelin.moya@gmail.com','Miguel Moya Ramos','Arriero 6','Alcala de Guadaira','Andalucía Ceuta y Melilla','SPAIN','41500','651907808',NULL,NULL,NULL,'2011-08-25 08:51:53',0,NULL,3,1,3,1,'RA184555680CN ',NULL),(15312,772018726017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','maffy5','sues.sss@hotmail.com','sue shepherd','22 grose ave','barrack  heights','New South Wales','AUSTRALIA','2528','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-25 09:19:35',0,NULL,3,1,2,1,NULL,'maffy5'),(15313,840863068015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','salaam45','salaamahmad@mail.com','Salaam Ahmad Hussein','House 35, 34 commercial court,','Glasgow','Glasgow (City of)','UNITED KINGDOM','G5 0PJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 09:33:12',0,NULL,3,1,2,1,NULL,'salaam45'),(15314,757137511002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','ecabras','fakokeroke@hotmail.com','Eduardo Cabras Perez','Calle minerva   nº 65   4ºB','Madrid','Madrid','SPAIN','28032','617520750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 09:52:19',0,NULL,3,1,3,1,'RA184555676CN ','ecabras\r申报$20'),(15315,840869372015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',48,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-25 09:52:48',0,NULL,3,1,17,0,NULL,'leifs123\r申报$20'),(15316,757140795002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','markarper','marknot81@hotmail.com','Marco Di Virgilio','Viale dei Tigli 108','Casalbordino','CH','ITALY','66021','0873916536','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 09:53:48',0,NULL,3,1,4,1,'YW867472305CN ','markarper\r欧标'),(15317,823384821016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','dasagi10','dsg_tgn@hotmail.com','OMNIA SOLUTIONS (Sr. David Sanz Gironès)','C/ del Plom 109 nave 4 Polígon Industrial Riu Clar','Tarragona','Cataluña','SPAIN','43006','680737427','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-25 10:29:06',0,NULL,3,1,17,0,NULL,'dasagi10'),(15318,823384349016,260817943832,'Wireless Remote Shutter Release for Canon 7D 50D 5Dii',1,'AD1120',12.47,'hutongstore','dasagi10','dsg_tgn@hotmail.com','OMNIA SOLUTIONS (Sr. David Sanz Gironès)','C/ del Plom 109 nave 4 Polígon Industrial Riu Clar','Tarragona','Cataluña','SPAIN','43006','680737427','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 10:29:07',0,NULL,3,1,2,1,NULL,'dasagi10\r大力夹云台     1\ryongnuo无线 YN159-C3    1'),(15319,823431402016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','wizard75d','wizard75d@netscape.net','darren behan','19 The View<br>Millmount Abbey, Beamore rd','Drogheda','Meath','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 12:48:16',0,NULL,3,1,3,1,'RA184555755CN\r ','wizard75d'),(15320,715242871001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.1,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:06:21',0,NULL,3,1,17,0,NULL,'sinlightpictures'),(15321,757159665002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:06:21',0,NULL,3,0,17,0,' ','sinlightpictures\r'),(15322,757159533002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:06:22',0,NULL,3,1,17,0,NULL,'sinlightpictures'),(15323,757159467002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:06:22',0,NULL,3,1,17,0,' ','sinlightpictures'),(15324,757159090002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',22,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 13:06:23',0,NULL,3,1,17,0,NULL,'sinlightpictures'),(15325,757193806002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','symadose','office@bestimage.at','sepp  kollmann','koestenbergerstrasse 149','velden am woerthersee','','AUSTRIA','9220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:20:45',0,NULL,3,1,2,1,NULL,'symadose'),(15326,715800877018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','a_soreal','mrfresh7@hotmail.com','Angelos Sourial','Unit 3/157 Holden St','Fitzroy North','Victoria','AUSTRALIA','3068','0431236693','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-25 13:24:41',0,NULL,3,1,2,1,NULL,'a_soreal'),(15327,715215092001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'',28.49,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 13:06:23',0,NULL,3,0,4,1,'YW867472261CN ','sinlightpictures\r方形滤镜接口环 58mm    1\r方镜普通托架（三槽）    1\r1.6*3 灰色背景布   1\r肥皂盒 柔光罩   580EX   1\r斜臂     1\r爵影碗罩P4     1\r新的那个镜子\r6片装滤镜袋  1\rND2         1\rND4        1\rND8       1\r渐变灰ND4    1\r渐变灰ND8     1\r日落镜     1\r'),(15328,757204787002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tiberius.necula','necula.tiberius@gmail.com','NECULA TIBERIUS CONSTANTIN','STR. MARESAL AVERESCU BL.20 SC.C ET.4 AP. 38','DEVA','HUNEDOARA','ROMANIA','330011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 13:56:47',0,NULL,3,1,2,1,NULL,'tiberius.necula'),(15329,772097673017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',17.19,'photographyacc','wehrwolf_at','wolfgang.valicek@chello.at','Wolfgang Valicek','Jonstraße 5','Wien','','AUSTRIA','1140','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 14:09:31',0,NULL,3,1,3,1,'RA184555906CN\r ','wehrwolf_at\r4 片装滤镜袋   1\rnokon d300 眼罩   2\r小号镜头筒        1\rNIKON 镜头盖 77mm    1\r已入库 '),(15330,840966465015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','judazuk','peter.lennartsson@gmail.com','Peter J Lennartsson','Ronnebergavagen 8A','Eslov','Skane','SWEDEN','24134','+46763191343','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 14:31:07',0,NULL,3,1,3,1,'RA184555733CN ','judazuk'),(15331,716737486018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','humbertl_qc','humfame@hotmail.com','lionel humbert','2-2317 Montgomery street','montreal','QC','CANADA','h2k2s2','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 14:36:11',0,NULL,3,1,2,1,NULL,'humbertl_qc'),(15332,757228352002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','robes0','alain.bennet@wanadoo.fr','BENNET Alain','Route principale','Illartein','Midi-Pyrénées','FRANCE','09800','+33561047593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 15:11:55',0,NULL,3,1,2,1,NULL,'robes0'),(15333,715290674001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 15:42:19',0,NULL,3,0,8,1,'CP227167526CN ','saud-p\r欧标\r需要在灯架上贴 made in china    \r还需要申报实值'),(15334,757245793002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','1058terri','teresa.merola@virgilio.it','Teresa Merola','via terragrande<br>49','curti','CE','ITALY','81040','0823811752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 16:03:04',0,NULL,3,1,4,1,'YW867472294CN ','1058terri\r欧标 '),(15335,715128399001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','kanel394820109','kanel3948201@gmail.com','STAVROS KANELLAKIS','STADIOU 178','N ALIKARNASSOS','GRECE / CRETA / HRAKLION','GREECE','71601','+30 6977413192','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 16:11:07',0,NULL,3,1,3,1,'RA184555821CN\r ','kanel394820109'),(15336,715300280001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','emeyefe','parmf@hotmail.com','Fernando Barceló Ballesta','C/ Joaquin Zurita 1, Portal A, Bajo A','Boadilla del Monte','Madrid','SPAIN','28660','628901702','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-25 16:11:27',0,NULL,3,1,4,1,'YW867472283CN ','emeyefe\r燕文告知地址错误  需要联系客户去当地邮局取货\r已经收到'),(15337,716799005018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','ricardo-del-rio','rdr-foto@hotmail.com','Ricardo Garcia Granados','José María Vigil 101-C2<br>Col. Escandón','México','Distrito Federal','MEXICO','11800','5515092737','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 17:27:22',0,NULL,3,1,3,1,'RA184555764CN\r ','ricardo-del-rio'),(15338,716823544018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','pitufo-1975','labv75@gmail.com','Luis Alberto Bustamante Véjar','Avenida Cristobal Colon 4710, Departamento 72, Las Condes','Santiago','','CHILE','7580254','56024927521','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 18:23:47',0,NULL,3,1,2,1,NULL,'pitufo-1975'),(15339,715353851001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','apgv10','vgor@i.ua','Victor Gorban','per. Ostrovskogo, 13','pgt. Pokrovske','obl Dnipropetrovska','UKRAINE','53600','5638-5-00-77','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 18:37:48',0,NULL,3,0,2,1,NULL,'apgv10\r1.6*2.1  蓝色背景布  1'),(15340,715364823001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','4v8james2004','jrglen@sympatico.ca','James Glen','76 Flannery Lane','Thorold','ON','CANADA','L2V 4V8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 18:58:22',0,NULL,3,1,2,1,NULL,'4v8james2004'),(15341,772033419017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','anato01','smart2bay@yandex.ru','Anatoliy Alekseev','86 Golovatogo Str.','Krasnodar','ru','RUSSIAN FEDERATION','350004','(903)453-8945','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 19:05:42',0,NULL,3,1,2,1,NULL,'anato01'),(15342,841138225015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',2,'AKT031',70,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 20:19:52',0,NULL,3,1,17,0,NULL,'leifs123'),(15343,841141167015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',2,'AE3601',25.98,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-25 20:24:50',0,NULL,3,1,5,1,'CP227167733CN ','leifs123\r灯架  2m      2\r115w 5500k 灯泡  220v     6\r申报$20'),(15344,772271913017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',1,'AA1305',2.5,'photographyacc','scottishclimber','richardfield@me.com','Richard Field','Dentistree @ Horley<br>36B High Street','Horley','Surrey','UNITED KINGDOM','RH6 7BB','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-25 20:49:30',0,NULL,3,1,2,1,NULL,'scottishclimber'),(15345,823656864016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','betolud','albertocanrio@gmail.com','alberto canario','rua professor egas moniz nº25 2º frt','seixal','paio pires','PORTUGAL','112 2840','965868707','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-25 20:57:46',0,NULL,3,1,3,1,'RA184555804CN ','betolud\r欧标'),(15346,841156193015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','andreas40470','asyrimis@tiscali.co.uk','Andreas Syrimis','97 Judd Street','London','London','UNITED KINGDOM','WC1H 9JB','02074854047','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-25 20:59:07',0,NULL,3,1,3,1,'RA184555720CN\r ','andreas40470'),(15347,841161096015,250599422673,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',1.88,'hutongstore','andreagaltea','andrea.gian@gmail.com','Andrea Giannini','Via Valdichiana 57','Firenze','FI','ITALY','50127','3475446282','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-25 21:03:22',0,NULL,3,1,2,1,NULL,'andreagaltea'),(15348,715437325001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','namaenai_gilles','gil.allard@sympatico.ca','Gilles Allard','2101 St-Denis','Jonquiere','QC','CANADA','G7S 1M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 22:01:28',0,NULL,3,1,3,1,'RA184555897CN ','namaenai_gilles'),(15349,716927236018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','jbros488','jbrosnan@live.com.au','jay brosnan','566 stafford road<br>stafford','brisbane','Queensland','AUSTRALIA','4053','0433049167','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-25 22:28:40',0,NULL,3,1,3,1,'RA184555852CN\r ','jbros488'),(15350,715447247001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','leifklasson','leif_klasson@hotmail.com','Leif Klasson','Opalgangen 27','Tyreso','Tyreso','SWEDEN','S13549','+46733982501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 22:39:25',0,NULL,3,1,17,0,NULL,'leifklasson'),(15351,715446769001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','leifklasson','leif_klasson@hotmail.com','Leif Klasson','Opalgangen 27','Tyreso','Tyreso','SWEDEN','S13549','+46733982501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 22:39:27',0,NULL,3,1,3,1,'RA184555818CN\r ','leifklasson\r倒影板（白黑）   1 \r圆形柔光棚 60cm   1'),(15352,757405076002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','7200pf','ginko.kun@gmail.com','Aksana Rybina','Vyborgskaya 4-59<br>Выборгская 4-59','Kazan','Tatarstan','RUSSIAN FEDERATION','420006','7-950-4222997','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-25 23:18:46',0,NULL,3,0,3,1,'RA184555716CN\r ','7200pf\r欧标 '),(15353,841227208015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',42.8,'hutongstore','fsaadane','fadel.saadane@gmail.com','fadel saadane','Eiriksgt 17A','Oslo','','NORWAY','0650','47-91136845','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-26 00:03:24',0,NULL,3,1,3,1,'RA184555747CN ','fsaadane'),(15354,715468856001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','carskakk','reilom@online.no','Reidar Lomelde','Jacob Larsensvei 25','Laksevaag','','NORWAY','5163','+4790685773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 00:09:17',0,NULL,3,1,3,1,'RA184555835CN\r ','carskakk'),(15355,715480156001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'',28.49,'hermeshine','kas1978516','lamarvalley_09@live.com','kenneth scott','2520 N Montana Ave','Helena','MT','UNITED STATES','59601-0541','(406) 465-5283','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 00:58:17',0,NULL,3,1,1,1,' ','kas1978516\r这个就是新的那个镜子\r其中包括\r6片装滤镜袋  1\rND2         1\rND4        1\rND8       1\r渐变灰ND4    1\r渐变灰ND8     1\r渐变蓝       1\r'),(15356,715480436001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','julianoareias','juhareiasvidaloca@hotmail.com','juliano areias','travessa barbara lamadrid<br>50','sao paulo','sao paulo','BRAZIL','02567090','0551122082317','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 00:59:39',0,NULL,3,1,3,1,'RA184555849CN\r ','julianoareias'),(15357,757435244002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ajer4','alexvh@bigpond.com','Alex van Harmelen','PO Box 222','Avondale Heights','Victoria','AUSTRALIA','3034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 01:01:46',0,NULL,3,1,2,1,NULL,'ajer4'),(15358,715481066001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','vvkkb','abdoncorp@gmail.com','Victor Blanco','15530 SW 152nd Ave','Miami','FL','UNITED STATES','33187','(786) 242-3274','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 01:02:29',0,NULL,3,1,1,1,' ','vvkkb'),(15359,715494638001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.48,'hermeshine','mrgoodmorning','torhulb@online.no','Tor Hulbakviken','Slalomveien 18d','Lommedalen','','NORWAY','N-1350','95167603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 01:59:17',0,NULL,3,1,17,0,NULL,'mrgoodmorning'),(15360,715494639001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','mrgoodmorning','torhulb@online.no','Tor Hulbakviken','Slalomveien 18d','Lommedalen','','NORWAY','N-1350','95167603','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 01:59:17',0,NULL,3,1,2,1,' ','mrgoodmorning\r眼罩 40D/50D    1\r大力夹云台    1'),(15361,715497208001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','mart777','martyncobbe@gmail.com','Martyn Cobbe','52 Stanton court','Gisborne','Victoria','AUSTRALIA','3437','0354207795','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-26 02:10:00',0,NULL,3,1,3,1,'RA184555662CN\r ','mart777'),(15362,757465986002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','yycabj','yybj@yahoo.ca','yi yang','5010 Grimmer st','Burnaby','BC','CANADA','V5H 3Z8','(604) 779-2908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 03:11:18',0,NULL,3,1,3,1,'RA184555778CN\r ','yycabj'),(15363,757477695002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','sixtyhorses','sixtyhorses@gmail.com','Alex Vargas','1318 8th Ave','San Francisco','CA','UNITED STATES','94122-2408','','NoPaymentFailure','CheckoutComplete','Other','2011-08-26 04:11:11',0,NULL,3,0,1,1,NULL,'sixtyhorses\r110v   (已入库)\r'),(15364,757488844002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','veselovskiy2011','dadusha@mail.ru','Veselovsky Evgeny','Vostania<br>54','kazan','Tatarstan','RUSSIAN FEDERATION','420039','+79600551803','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-26 05:25:27',0,NULL,3,1,3,1,'RA184555968CN ','veselovskiy2011'),(15365,757491094002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','liorzvia','0526093268l@gmail.com','lior tzvia','amir 10','ramat gan','','ISRAEL','52336','972526093268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 05:31:16',0,NULL,3,1,3,1,'RA184555971CN ','liorzvia'),(15366,717028011018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',13,'photographyacc','pallecon','mmolog@hotmail.com','Mile` Stanisic','Suite 11, 6A Gray Street<br>Myshopping.com.au','Bondi Junction','New South Wales','AUSTRALIA','2022','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-26 06:01:40',0,NULL,3,1,2,1,NULL,'pallecon'),(15367,717029749018,280678918166,'Neoprene Camera Cover Case for small Canon & semi slr S',1,'AC2303',5.9,'photographyacc','downbike','dieumyhao@yahoo.com','Hao Dieu','2305 Falling Leaf Ave','Rosemead','CA','UNITED STATES','91770-3127','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-26 06:14:29',0,NULL,3,1,1,1,NULL,'downbike'),(15368,8881314339546173,111,'2m灯架 x2， 4灯头棚x2， 45w 110v x8， 包 x1',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-08-26 06:19:06',0,NULL,3,1,12,1,' BJ8824608','灯泡是110v的 （已入库） \r最终计费泡重： 8\r'),(15369,757503308002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','cheezinphotoproductions','cheezinphotoproductions@comcast.net','melvin delilly','1113 Woodruff Rd','JOLIET','IL','UNITED STATES','60432-1357','(815) 557-4516','NoPaymentFailure','CheckoutComplete','Other','2011-08-26 06:48:10',0,NULL,3,1,4,1,'YW867472272CN ','cheezinphotoproductions\r灯泡是110v  的 \r已入库\r Lighting  Kit   $28'),(15370,772426025017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','maddyj21','rebecca1975@optusnet.com.au','Rebecca Johnston','C-/O Joblink Plus<br>476 Peel Street','Tamworth','New South Wales','AUSTRALIA','2340','0402016195','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-26 07:06:04',0,NULL,3,1,2,1,NULL,'maddyj21'),(15371,841313963015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','ivandegi','ivandegi@gmail.com','Ivan Degiorgio','Block P, Flat 1, Helen Buhagiar Street,','Santa Lucia','Malta','MALTA','SLC 1620','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 07:17:15',0,NULL,3,1,2,1,NULL,'ivandegi'),(15372,841346865015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','kib3001','kib3000@hotmail.co.uk','Paul Davidson','7 Antrim Road','Blackpool','Lancashire','UNITED KINGDOM','FY29UR','01253595355','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 07:59:18',0,NULL,3,1,2,1,NULL,'kib3001'),(15373,717051448018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','garvinwu','garvin@ricestudios.com.au','Garvin Wu','18 Strand Close','Glen Waverley','Victoria','AUSTRALIA','3150','0395608029','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-26 07:59:59',0,NULL,3,1,3,1,'RA184555910CN ','garvinwu'),(15374,8881314345772978,111,'灯架下面的座',1,'',0,'hutongstore','txgmartins','txgmartins@gmail.com','Thierry Martins','R. Afonso Albuquerque<br>nº13, r/c Dto','Loulé','Algarve','PORTUGAL','8100-531','(351)966570158',NULL,NULL,NULL,'2011-08-26 08:02:52',0,NULL,3,0,3,1,'RA184555937CN\r ',NULL),(15375,749608550002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','paulquattrorunner','togherstationery@eircom.net','Paul De Abreu','Togher Stationery Supplies<br>Unit 1a Greenwood Estate Togher','Cork','Cork','IRELAND','6w','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 08:31:28',0,NULL,3,1,3,1,'RA184556005CN\r ','paulquattrorunner'),(15376,757525140002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jvdgeest','johan@vdgeest.org','Johan van der Geest','Zevenbruggetjesweg 11','Bedum','','NETHERLANDS','9781XV','+31 683566669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 08:37:29',0,NULL,3,1,2,1,NULL,'jvdgeest'),(15377,757501978002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','sahersr11','srur173@gmail.com','saher srur','box 146','eilaboun village','','ISRAEL','16972','0527324823','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-26 09:14:13',0,NULL,3,1,3,1,'RA184555945CN\r ','sahersr11'),(15378,715576101001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',3,'AA3302',9.75,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 09:26:35',0,NULL,3,1,17,0,'','jordano-jordano2000\r'),(15380,772471747017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',18.57,'photographyacc','brandolph_sidious','jarrettbush@hotmail.com','Jarrett Bush','digitalLOGIC<br>477 Warrigal Rd','MOORABBIN','Victoria','AUSTRALIA','3189','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-26 10:17:45',0,NULL,3,1,2,1,NULL,'brandolph_sidious\rCANON 镜头盖  72mm  1\r笔+气吹+布      1\rcanon 肩带      1\r已入库'),(15379,757533728002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 09:26:35',0,NULL,3,0,5,1,'CP235627811CN ','jordano-jordano2000\r55mm uv   3\r反光板支架  1\r2m 灯架   1'),(15381,757106689002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',2,'AKT055',126,'hermeshine','luproffessore','info@fotogabry.it','Gabriele Antoniello c/o FOTO GABRY','Piazza de Sanctis, s.n.c.','Sant\'Angelo dei Lombardi','AV','ITALY','83054','0827-24418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 10:31:12',0,NULL,3,1,4,1,'YW867472250CN ','luproffessore\r红头灯本来就是欧标\rlight $28'),(15382,823888703016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','focalpointa','arwalls@btinternet.com','Tony Walls','82 CARLETON ROAD','CHORLEY','Lancashire','UNITED KINGDOM','PR68UB','01257278505','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 10:51:18',0,NULL,3,1,2,1,NULL,'focalpointa'),(15383,717101902018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','vaizdostudija','uab@vaizdostudija.com','Arunas Eimulis','Tulpiu 13-3','Klaipeda','','LITHUANIA','91210','+370 673 92399','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-26 11:23:09',0,NULL,3,1,2,1,NULL,'vaizdostudija'),(15384,841399112015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','bbfury63','fury63@luukku.com','Tommi Tikkanen','Viirikuja 2 B 16','Espoo','','FINLAND','02770','+358443385544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 10:54:08',0,NULL,3,1,2,1,NULL,'bbfury63'),(15385,757573646002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tomasvoim','tomivoim@gmail.com','Tomáš Képeš','Jána Hunyadiho<br>1','Moldava nad Bodvou','','SLOVAK REPUBLIC','04501','+4210907372391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 12:02:46',0,NULL,3,1,17,0,NULL,'tomasvoim'),(15386,757590591002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 13:02:43',0,NULL,3,1,11,1,NULL,'keith10w1977'),(15387,757452772002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','joiartistique','superiorbabies22@yahoo.com','Joi Biddle','1701 W Shields Dr','SHERMAN','TX','UNITED STATES','75092-5538','(512) 644-4623','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-26 13:31:09',0,NULL,3,1,1,1,NULL,'joiartistique'),(15388,841476459015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','jesszippy56','jessdixon.10@hotmail.co.uk','Jess Dixon','131 Blakes Ave<br>Cogges','Witney','Oxfordshire','UNITED KINGDOM','ox28 3su','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 14:23:57',0,NULL,3,1,2,1,NULL,'jesszippy56'),(15389,757616334002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','kabamot','leon@mousevision.com','ABISee','20 Main St<br>Entrance G','Acton','MA','UNITED STATES','01720-3575','(978) 201-9302','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 14:34:44',0,NULL,3,1,1,1,NULL,'kabamot'),(15390,757624696002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','ninopiro','ninopiro@tiscalinet.it','gaetano pirozzi','via monte baldo 21','milano','Milano','ITALY','20153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 14:52:57',0,NULL,3,1,2,1,NULL,'ninopiro'),(15391,717170839018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','argelsex','filmicaproducciones@hotmail.com','ARGEL VERDIGUEL ROJAS','FUENTE DE CHAPULTEPEC 123','CELAYA','GUANAJUATO','MEXICO','38040','461 616093329','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-26 15:00:44',0,NULL,3,1,3,1,'RA184552290CN\r ','argelsex'),(15392,757543265002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kinkylu','luinel123@mail.ru','Alexandra Petrischeva','Tukhachevskovo str 37/21 app 195','Moscow','','RUSSIAN FEDERATION','123154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 15:40:39',0,NULL,3,1,3,1,'RA184552215CN\r ','kinkylu'),(15393,715676312001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','13mixmaslab','mixmaslab@gmail.com','Vitaly Yavorsky','Lenina 13,kv 5','Kozyatyn','Vinnickaya oblast','UKRAINE','22100','+380632665598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 15:49:17',0,NULL,3,1,17,0,NULL,'13mixmaslab'),(15394,757640843002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','13mixmaslab','mixmaslab@gmail.com','Vitaly Yavorsky','Lenina 13,kv 5','Kozyatyn','Vinnickaya oblast','UKRAINE','22100','+380632665598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 15:49:17',0,NULL,3,1,17,0,NULL,'13mixmaslab'),(15395,715676172001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','13mixmaslab','mixmaslab@gmail.com','Vitaly Yavorsky','Lenina 13,kv 5','Kozyatyn','Vinnickaya oblast','UKRAINE','22100','+380632665598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 15:49:18',0,NULL,3,1,5,1,'CP227167530CN ','13mixmaslab\r三脚架 伟峰 WF-6663A    1\r气吹 + 布   1\r伟峰 6663A 快装板    1'),(15396,756016686002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','vampy3008','patritome@hotmail.com','Patricia Tomé González','C. Párroco Florencio Aguilar 3 P 2 2º A','Torremolinos','Andalucía Ceuta y Melilla','SPAIN','29620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-26 17:24:14',0,NULL,3,1,3,1,'RA184552105CN\r ','vampy3008'),(15397,824048026016,260808967188,'Nikon Original Photo Vest D7000 D300s D700 size： M, L',1,'AD1144',42,'hutongstore','robtherocker','robgen@blueyonder.co.uk','Peter Ford','5 Budshead Green<br>Whitleigh','Plymouth','Devon','UNITED KINGDOM','PL54EF','01752295093','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-26 17:38:33',0,NULL,3,0,3,1,'RA184552140CN\r ','robtherocker\rL   已入库\r75周年那款'),(15398,757684899002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','caino01','cesprea@libero.it','Spreafico Giuseppe','Via Emilio Borsa 37','Monza','MI','ITALY','20900','3483100225','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-26 17:39:19',0,NULL,3,1,3,1,'RA184552017CN\r ','caino01\rlight stand $15'),(15399,772627711017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','9590alan','alan_sarah@iprimus.com.au','Alan Ch\'ng','34 Milton St','Yokine','Western Australia','AUSTRALIA','6060','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-26 17:44:52',0,NULL,3,1,11,1,NULL,'9590alan'),(15400,757685818002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',15,'AA1303',39,'hermeshine','opies1','oscar@thelensdepot.com','Oscar Pastrana','2785 Wrights Rd<br>Ste 1101','Oviedo','FL','UNITED STATES','32765-5413','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 17:47:30',0,NULL,3,1,1,1,NULL,'opies1'),(15401,841587735015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','phil845276','philgodfrey@googlemail.com','Philip Godfrey','Laforet Immobilier, Le Suffren<br>7 boulevard Albert 1er','ANTIBES','Provence-Alpes-Côte d\'Azur','FRANCE','06600','0033643216913','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 18:21:12',0,NULL,3,1,2,1,NULL,'phil845276'),(15402,757713839002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','bombaysupply','bombaysupplyco@gmail.com','Liza Ortega','8234 sw 37th st','Miami','FL','UNITED STATES','33155-3329','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-26 18:52:32',0,NULL,3,1,4,1,'YW867472246CN ','bombaysupply\r灯泡是110v 的 放一个欧转美标头'),(15403,757722177002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','r3tuz','m4mb0@rambler.ru','Taras Spasyuk','Dzerjinskogo 9/2 , kv. 33','Surgut','Tyumenskaya oblast','RUSSIAN FEDERATION','628412','79227656982','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-26 19:11:26',0,NULL,3,1,3,1,'RA184552025CN\r ','r3tuz\r Reflector   $10'),(15404,757703799002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','georgiyvylegzhanin','hmdfirm@yahoo.co.uk','Georgiy Vylegzhanin','apt. 32, building 200,<br>KOZHAMKULOV Street','Almaty','Almaty','KAZAKHSTAN','050012','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-26 19:48:40',0,NULL,3,1,5,1,'CP227167702CN','georgiyvylegzhanin'),(15405,772570300017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','panzum','ariel.meyrelles@mundonovias.net','Ariel Meyrelles','Manzoni 83','Buenos Aires','Capital','ARGENTINA','C1407ICA','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-26 20:17:03',0,NULL,3,0,3,1,'RA184552167CN\r ','panzum\rxxl   已入库'),(15406,715794207001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','cellardoor7','clb123091@yahoo.com','chance  beaver','903 SW Crystal st','Bentonville','AR','UNITED STATES','72712-8109','(479) 616-8032','NoPaymentFailure','CheckoutComplete','Other','2011-08-26 20:48:25',0,NULL,3,1,4,1,'YW867472235CN ','cellardoor7\r灯泡是110v 的\r灯架发2m弹簧那种吧\rlighting kit $30'),(15407,841701043015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','osoer4','racz.ferenc@citromail.hu','Ferenc Rácz','Balázs Béla utca 27/A 3/3','Budapest','Budapest','HUNGARY','1094','00-36-20-933-4482','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 22:24:07',0,NULL,3,1,2,1,NULL,'osoer4'),(15408,824186455016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','avia57','dominique.freon@free.fr','Dominique FREON','Le Pilier','Mouzay','Centre','FRANCE','37600','0247923156','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-26 22:31:36',0,NULL,3,1,2,1,NULL,'avia57'),(15409,757853450002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','4432earlene','earlzplace@aol.com','earlene lovern','rr 1 box 269h','fairmont','WV','UNITED STATES','26554-9742','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 02:58:59',0,NULL,3,1,1,1,NULL,'4432earlene'),(15410,824262897016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','k7th','rezario@hotmail.co.uk','Mohammad Reza Keshavarzi','47 Norwood Road<br>stockport','cheshire','Cheshire','UNITED KINGDOM','sk2 7jj','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 03:27:54',0,NULL,3,1,3,1,'RA184552153CN\r ','k7th'),(15411,717428570018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','wilturn3','r.turner@exemail.com.au','Ron Turner','Unit 126<br>1 Hyde Parade','Campbelltown','New South Wales','AUSTRALIA','2560','0246280473','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 04:44:20',0,NULL,3,1,2,1,NULL,'wilturn3'),(15412,772832987017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',32,'photographyacc','sergeykuba','serg_sh@pisem.net','Sergey Shalamov','Nagornaya street, 37-A','Kurganinsk','Krasnodarskij kraj','RUSSIAN FEDERATION','352430','+7-918-4699668','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-27 05:13:19',0,NULL,3,1,3,1,'RA184552082CN\r ','sergeykuba\r这个人在三个店都买了东西 分开发'),(15413,715904232001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','sergeykuba','serg_sh@pisem.net','Sergey Shalamov','Nagornaya street, 37-A','Kurganinsk','Krasnodarskij kraj','RUSSIAN FEDERATION','352430','+7-918-4699668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 05:17:01',0,NULL,3,1,17,0,NULL,'sergeykuba\r欧标\r这个人在三个店都买了东西 分开发'),(15414,772836194017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','lukeone64','lukesherry@gmail.com','Luke Sherry','22 Kewarra St<br>Kenmore','Brisbane','Queensland','AUSTRALIA','4069','0738781545','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 05:33:05',0,NULL,3,1,2,1,NULL,'lukeone64'),(15415,717437062018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','kristy2580','mattandkristy12@hotmail.com','Kristy Bunker','17/255 Avoca St','Randwick','New South Wales','AUSTRALIA','2031','0733254403','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-27 05:42:06',0,NULL,3,1,4,1,'YW867472224CN ','kristy2580\rBackground Support    $25'),(15416,717441339018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','dexeh','cdpugh@gmail.com','Chris Pugh','5051 N. State Street<br>Space 1','Ukiah','CA','UNITED STATES','95482','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-27 06:07:07',0,NULL,3,1,1,1,NULL,'dexeh'),(15417,717436337018,280667759321,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',3.88,'photographyacc','zaunkoenigin123','zaunkoenigin1@arcor.de','Manuela Rechter','Suder Allee 19','Itzehoe','','GERMANY','25524','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-27 06:28:26',0,NULL,3,1,2,1,NULL,'zaunkoenigin123'),(15418,757889005002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 06:40:40',0,NULL,3,1,17,0,NULL,'padre790'),(15419,757888406002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 06:40:41',0,NULL,3,1,17,0,NULL,'padre790'),(15420,757886577002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:40:41',0,NULL,3,1,17,0,NULL,'padre790'),(15421,715914724001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:40:42',0,NULL,3,1,17,0,NULL,'padre790'),(15422,715914507001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:40:42',0,NULL,3,1,17,0,NULL,'padre790'),(15423,715915622001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:40:43',0,NULL,3,1,17,0,NULL,'padre790'),(15424,715914659001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',2,'AA1306',5.2,'hermeshine','padre790','fr_paulj@frontiernet.net','Fr. Paul Johnson','711 E Andy Devine Ave<br>St. Michael Catholic Church','Kingman','AZ','UNITED STATES','86401-5914','(928) 530-1411','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 06:40:43',0,NULL,3,1,1,1,NULL,'padre790\r镜头笔      1\r绿叶 CPL 72mm      1\rNIKON 镜头盖 77mm     1\rNIKON 镜头盖 72mm     1\rNIKON 镜头盖 67mm     1\rNIKON 镜头盖 52mm      1\rNIKON 镜头盖 62mm    2'),(15425,841825982015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','sergeykuba','serg_sh@pisem.net','Sergey Shalamov','Nagornaya street, 37-A','Kurganinsk','Krasnodarskij kraj','RUSSIAN FEDERATION','352430','+7-918-4699668','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-27 07:00:44',0,NULL,3,1,5,1,'CP235627431CN','sergeykuba\r欧标\r单灯头 欧标  2  \r其他订单里合并过来这个，\rphotographyacc里的灯泡单发\r这个人在三个店都买了东西 分开发'),(15426,717459783018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','wayne7524','w_c.markham@internode.on.net','wayne markham','231-241 mundoolun rd','jimboomba','Queensland','AUSTRALIA','4280','0755477325','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 07:43:04',0,NULL,3,1,3,1,'RA184552330CN\r ','wayne7524'),(15427,772874292017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','scollie3','the4colliers@bigpond.com','Simon Collier','13 Grevillea Road<br>Aberfoyle Park','Adelaide','South Australia','AUSTRALIA','5159','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 08:37:37',0,NULL,3,1,2,1,NULL,'scollie3'),(15428,757920408002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','santiagocruzgarcia','scruz@estinca.com','Santiago  Cruz Garcia','c/ Arq. Ant. Florez Urdapilleta nº1 bloque 2, 2ºD','Jaén','Jaen','SPAIN','23003','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-27 09:21:44',0,NULL,3,1,17,0,NULL,'santiagocruzgarcia'),(15429,715950025001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','santiagocruzgarcia','scruz@estinca.com','Santiago  Cruz Garcia','c/ Arq. Ant. Florez Urdapilleta nº1 bloque 2, 2ºD','Jaén','Jaen','SPAIN','23003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 09:21:44',0,NULL,3,1,4,1,'YW867472213CN ','santiagocruzgarcia\r灯架  2m     2\r柔光箱 50-70cm 单灯头  欧标   2\r115w 5500k 灯泡  220v      2\r灯架包      1\r倒影板（白黑）    1\rLighting Kit   $28'),(15430,757934147002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',10,'AE3102',78.9,'hermeshine','spiro9210','spiro9210@hotmail.com','Akinyemi Oyenusi','14627 Argos Pl','Upper Marlboro','MD','UNITED STATES','20774-8862','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-27 10:24:14',0,NULL,3,1,3,1,'RA184552374CN\r ','spiro9210'),(15431,772921605017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','chemistryk','chris@sanuye.net','Chris Sheath','14/3 Keylana Bvd','Mt Waverley','Victoria','AUSTRALIA','3149','0488048810','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 11:29:55',0,NULL,3,1,2,1,NULL,'chemistryk'),(15432,716013609001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','hinggink','kisslips@gmx.net','Andreas Hartwig','Angerstraße 8','Thum','','GERMANY','09419','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 13:08:22',0,NULL,3,1,3,1,'RA184552096CN\r ','hinggink'),(15433,716028912001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','panzikaki','panzikaki@yahoo.es','Javier Navajas Sanchez','Callejon del angel nº 12 Bajo-F','Granada','Granada','SPAIN','18006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 13:56:42',0,NULL,3,1,3,1,'RA184552286CN\r ','panzikaki'),(15434,824449157016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','trebor.m','rob.mercer@virgin.net','Rob Mercer','30 taunton Rd<br>Wallasey','Wirral','Merseyside','UNITED KINGDOM','CH45 3JN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 14:12:48',0,NULL,3,1,2,1,NULL,'trebor.m'),(15435,717574968018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','mitch_pal','mitchell.palmowski@det.nsw.edu.au','Mitchell Palmowski','Unit 14, 33-41 Hanks Street','Ashfield','New South Wales','AUSTRALIA','2131','0249566785','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 14:18:07',0,NULL,3,1,2,1,NULL,'mitch_pal'),(15436,717597700018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','zipa_a_dee_doo_dah','octobercycle@ihug.com.au','Brett Jason East','2/39 Tebbutt St,','Leichhardt','New South Wales','AUSTRALIA','2040','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 15:15:28',0,NULL,3,1,3,1,'RA184552343CN\r ','zipa_a_dee_doo_dah'),(15437,773010739017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','noabn2','noa@noabarness.com','Noa Barness','Hacarmel 16 Ap. 39','Ganey Tikva','Israel','ISRAEL','55900','972-52-5942474','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-27 15:41:06',0,NULL,3,1,2,1,NULL,'noabn2'),(15438,824517781016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','seggie37','seggie37@hotmail.com','Alice Turnbull','flat 2/2 Number 12<br>Stirrat Crescent','Paisley','Renfrewshire','UNITED KINGDOM','PA3 1RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 16:40:28',0,NULL,3,1,17,0,NULL,'seggie37'),(15439,842043563015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.12,'hutongstore','seggie37','seggie37@hotmail.com','Alice Turnbull','flat 2/2 Number 12<br>Stirrat Crescent','Paisley','Renfrewshire','UNITED KINGDOM','PA3 1RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 16:42:20',0,NULL,3,1,17,0,NULL,'seggie37'),(15440,842044519015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','seggie37','seggie37@hotmail.com','Alice Turnbull','flat 2/2 Number 12<br>Stirrat Crescent','Paisley','Renfrewshire','UNITED KINGDOM','PA3 1RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 16:43:52',0,NULL,3,1,2,1,NULL,'seggie37\r天涯方形滤镜  渐变灰   1\r方形滤镜接口环 72mm   1\r方形滤镜接口环 77mm     1\r方镜普通托架（三槽）     1\r'),(15441,716118641001,110454856549,'Adjustable Neoprene Padded Neck shoulder Strap for Sony',1,'AB1406',5.49,'hermeshine','sorairo_eb','ednilson.obana@mandic.com.br','Ednilson Obana','Rua Raul Marques Marinho, 120','Sao Paulo','Sao Paulo','BRAZIL','04653-150','+55 (11) 71309563','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 17:50:28',0,NULL,3,1,2,1,NULL,'sorairo_eb'),(15442,716121501001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','lonelyluke','lonelyluke78@yahoo.com','william ratliff','125 alexranda st.','greenup','KY','UNITED STATES','41144','(606) 473-9233','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-27 17:56:14',0,NULL,3,1,1,1,NULL,'lonelyluke'),(15443,758114510002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','speedhub50014','info@ridgeback.de','Frank Burggraf','Zum Scherbusch 15','Hennef','','GERMANY','53773','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-27 18:44:18',0,NULL,3,0,3,1,'RA184552238CN\r ','speedhub50014\r3XL  已入库'),(15444,716152881001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','gabyramon09','gaby_ramon42@yahoo.com.ar','Gabriel Ramon','Pje Juan Jose Naon 940','ciudad autonoma de Buenos Aires','AS','ARGENTINA','1406','541-011-4633-9702','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-27 19:07:02',0,NULL,3,1,3,1,'RA184552459CN\r ','gabyramon09\r申报gift  低值\rRA184552445CN\r'),(15445,716155443001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','jop3.14','jop3.14@gmail.com','Sergio Betere Moreno','Paris nº 6','Coslada','Madrid','SPAIN','28820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 19:16:47',0,NULL,3,1,2,1,NULL,'jop3.14'),(15446,773114180017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','khalid4545','khalid.4545@hotmail.com','Khalid Hilal Zahir Al Busaidi','7/15 King George St','Victoria Park','Western Australia','AUSTRALIA','6100','0413179273','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 19:19:38',0,NULL,3,1,17,0,NULL,'khalid4545'),(15447,717705522018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',3,'AD1169',19.2,'photographyacc','khalid4545','khalid.4545@hotmail.com','Khalid Hilal Zahir Al Busaidi','7/15 King George St','Victoria Park','Western Australia','AUSTRALIA','6100','0413179273','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-27 19:21:21',0,NULL,3,1,3,1,'RA184552312CN\r ','khalid4545\r沙袋（大）     1\r沙袋（普通）     3'),(15448,824625917016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1171',17.9,'hutongstore','deniswdion','dwdion@gmail.com','Denis Dion','Mellingerstrasse 156','Baden','','SWITZERLAND','5400','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-27 20:04:25',0,NULL,3,1,3,1,'RA184552034CN\r ','deniswdion\r新款大力夹（手柄）\r C里的东西不对'),(15449,842179883015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','stevecostin','steve.costin@btinternet.com','Stephen Costin','10 Wilfred Road','Ramsgate','Kent','UNITED KINGDOM','CT117RB','01843851222','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 21:10:28',0,NULL,3,1,17,0,NULL,'stevecostin'),(15450,824652189016,260660052780,'New Circular Polarizing C-PL CPL Filters for Cokin P',1,'AA2326',10.99,'hutongstore','stevecostin','steve.costin@btinternet.com','Stephen Costin','10 Wilfred Road','Ramsgate','Kent','UNITED KINGDOM','CT117RB','01843851222','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 21:10:28',0,NULL,3,1,17,0,NULL,'stevecostin'),(15451,842179665015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',6.7,'hutongstore','stevecostin','steve.costin@btinternet.com','Stephen Costin','10 Wilfred Road','Ramsgate','Kent','UNITED KINGDOM','CT117RB','01843851222','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-27 21:10:29',0,NULL,3,1,3,1,'RA184552326CN\r ','stevecostin\r星光镜  star6     1\r 星光镜  star8   1\r天涯方形滤镜系列  CPL    1'),(15452,758205453002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','eddymuz','eddy_muz@yahoo.com','muzaidi othman','35 tmn mdn sepakat','Kangar','Perlis','MALAYSIA','01000','0125171503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-27 22:49:22',0,NULL,3,1,2,1,NULL,'eddymuz'),(15453,841805534015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','pratheesh17','prath33sh@gmail.com','pratheesh suntharalingam','bekkestien 14','jessheim','','NORWAY','2050','46698587','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-27 23:24:32',0,NULL,3,1,3,1,'RA184552051CN\r ','pratheesh17'),(15454,842241758015,250599955564,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',98,'hutongstore','john_taguchi','j_taguchi@mac.com','Mr. Junichiro Taguchi','1138-6,<br>Ohfusa,','Koshigaya-shi','Saitama','JAPAN','343-0027','81-(0)48-978-0851','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-27 23:45:44',0,NULL,3,1,6,1,'EE645685633CN ','john_taguchi'),(15455,716275316001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','kaspo2010','a_kaspo@yahoo.com','ayad kaspo','skiftesvagen 12,2tr','Sodertalje','stockholms lan','SWEDEN','151 54','0046704973212','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-28 01:55:19',0,NULL,3,1,3,1,'RA184552048CN\r ','kaspo2010'),(15456,717834557018,280666916076,'New Fancier Complete Tripod 531BT with Ball head 531BH',1,'AE1102',65,'photographyacc','nesnah53','tonyhansen@live.com.au','ANTHONY HANSEN','TALBOT CARAVAN PARK<br>P.O. BOX 68','TALBOT','Victoria','AUSTRALIA','3371','0447177818','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 02:20:52',0,NULL,3,1,4,1,'YW867472202CN ','nesnah53\rTripod   $22'),(15457,773265733017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',2,'AO0005',33.98,'photographyacc','n_greg1984','wkd_wagon@hotmail.com','Nathan Gregory','47 Soren Larsen Crescent','Boambee','New South Wales','AUSTRALIA','2452','0266582749','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 03:30:53',0,NULL,3,0,3,1,'RA184552431CN\r ','n_greg1984\r1.6*3 黑色背景布   1\r1.6*3 白色背景布    1'),(15458,717862152018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','ini125','inigojapan@yahoo.com.au','Inigo Merriman','276 PEASE Street<br>Edge Hill','CAIRNS','Queensland','AUSTRALIA','4870','0400751174','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 04:48:34',0,NULL,3,1,3,1,'RA184552357CN\r ','ini125'),(15459,758301296002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',16.99,'hermeshine','fahzaobrasil','fahzao@gmail.com','fabiano marques','rua lima barreto 1546 sobrado 3 jardim das americas','curitiba','parana','BRAZIL','81530-410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 06:42:46',0,NULL,3,1,17,0,NULL,'fahzaobrasil'),(15460,716324918001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','fahzaobrasil','fahzao@gmail.com','fabiano marques','rua lima barreto 1546 sobrado 3 jardim das americas','curitiba','parana','BRAZIL','81530-410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 06:44:47',0,NULL,3,1,3,1,'RA184552122CN\r ','fahzaobrasil\r双灯头    1\r灯架  2m     1  看看默认是不是美标的'),(15461,758304382002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','oskar_monkey','anish_kanungo@hotmail.com','Anish Kanungo','1108 6 Ave SW, Apt 1508','Calgary','AB','CANADA','T2P5K1','(403) 991-2169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 06:58:00',0,NULL,3,1,2,1,NULL,'oskar_monkey'),(15462,717884265018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','tonyo52','glenwoodtony@live.com.au','Tony OConnor','8 Rothwell Cct','Glenwood','New South Wales','AUSTRALIA','2768','0296292626','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 07:10:32',0,NULL,3,1,3,1,'RA184552255CN\r ','tonyo52\r已入库'),(15463,717898084018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','d3agl3s','dennis@eagles.id.au','Dennis Eagles','GPO Box 2160','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 07:56:52',0,NULL,3,1,17,0,NULL,'d3agl3s'),(15464,717898550018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','d3agl3s','dennis@eagles.id.au','Dennis Eagles','GPO Box 2160','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 07:58:46',0,NULL,3,1,17,0,NULL,'d3agl3s'),(15465,717899579018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','d3agl3s','dennis@eagles.id.au','Dennis Eagles','GPO Box 2160','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 08:02:18',0,NULL,3,1,17,0,NULL,'d3agl3s'),(15466,773320101017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'',28,'photographyacc','d3agl3s','dennis@eagles.id.au','Dennis Eagles','GPO Box 2160','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 08:05:08',0,NULL,3,0,17,0,NULL,'d3agl3s'),(15467,773319067017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','jen095','jen.tai@hotmail.com','Jennifer Tai','PO BOX 520','Malvern','Victoria','AUSTRALIA','3144','0422224030','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 08:08:32',0,NULL,3,1,2,1,NULL,'jen095'),(15468,717902131018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',1,'AE2316',12.9,'photographyacc','d3agl3s','dennis@eagles.id.au','Dennis Eagles','GPO Box 2160','Brisbane','Queensland','AUSTRALIA','4001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 08:12:14',0,NULL,3,1,3,1,'RA184552365CN\r ','d3agl3s\r方镜广角托架（ 一槽）   1\r方形滤镜接口环 82mm   1\r方镜普通托架（三槽）   2\r方形滤镜接口环 77mm     1\r 星光镜  star6       1\r6片装滤镜袋  1\r新的那个镜子非天涯\rND2 x  1 \rND4 x  1 \rND8 x  1 \r渐变灰ND4 x  1 \r渐变灰ND8 x  1 \r渐变蓝      1\r'),(15469,758322930002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 08:19:54',0,NULL,3,1,2,1,NULL,'gedrasas'),(15470,716352421001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','pumelet','mavisonni@yahoo.com','Ginger Roberts','CMR 414 BOX 936','APO','AE','AA','09173','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 08:52:44',0,NULL,3,1,1,1,NULL,'pumelet\rGinger Roberts\rCMR 414 BOX 936\rAPO AE 09173\rUNITED STATES\r'),(15471,716226831001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','tomasvoim','tomivoim@gmail.com','Tomáš Képeš','Jána Hunyadiho<br>1','Moldava nad Bodvou','','SLOVAK REPUBLIC','04501','+4210907372391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 09:11:32',0,NULL,3,1,5,1,'CP227167716CN ','tomasvoim\r2 b 柔    1\r反光板  80cm 5合1    2\r注意重量  如果超了就不发小包\r超了2.203了'),(15472,717923128018,280727836184,'Soft Camera Cover protector XL Nikon D300 D700 18-200mm',1,'AD1174',12.9,'photographyacc','$lim118','mugarinya1@bigpond.com','Sai Lim','PO Box 2786','South Hedland','Western Australia','AUSTRALIA','6722','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 09:19:43',0,NULL,3,1,2,1,NULL,'$lim118'),(15473,773357166017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','petfliss','missfliss71@hotmail.com','Peter Henss','13 Grove Place<br>Dunlop','Canberra','Australian Capital Territory','AUSTRALIA','2615','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 09:58:20',0,NULL,3,1,2,1,NULL,'petfliss'),(15474,824877709016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','vickyparis','vicky6124@hotmail.com','tony paris','avenida magalluf 8,nova III,apt 502<br>magalluf,calvia','mallorca','Baleares','SPAIN','07181','630746145','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-28 09:59:31',0,NULL,3,1,2,1,NULL,'vickyparis'),(15475,717952426018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',2,'AB3331',5.8,'photographyacc','dave_1973_au','dhastie@uow.edu.au','David Hastie','8 Galway Court','Horsley','New South Wales','AUSTRALIA','2530','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-08-28 10:39:38',0,NULL,3,1,2,1,' ','dave_1973_au'),(15476,716393013001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','fabio2050','tzola@hotmail.com','Fabio M. Nilsen','Bølerskrenten 13','Oslo','Oslo','NORWAY','0691','+47 414 414 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 10:43:12',0,NULL,3,1,3,1,'RA184552065CN\r ','fabio2050'),(15477,716398769001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','marius61968','mariusmieke@yahoo.com','Marius  van Niekerk','26 Ryno Kriellaan<br>Universitas','Bloemfontein','Free State','SOUTH AFRICA','9301','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 10:59:38',0,NULL,3,1,2,1,NULL,'marius61968'),(15478,716408183001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','reiger_1880','reiger1880@gmail.com','Jordi Struys','Karel Van Overmeirelaan 30','DEURNE','','BELGIUM','2100','0477790318','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 11:25:54',0,NULL,3,1,2,1,NULL,'reiger_1880'),(15479,773392997017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','sdun7405','sally.dunwell@bigpond.com','Sally Dunwell','32 Andrew Close','Boat Harbour','New South Wales','AUSTRALIA','2316','0249819018','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 11:30:46',0,NULL,3,1,2,1,NULL,'sdun7405'),(15480,717977004018,280673080920,'62mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 62 mm',1,'AB1304',5.66,'photographyacc','czis9999','lguong841@yahoo.com.au','ChangZhi Guo','unit 4,  23 Station Street','Mortdale','New South Wales','AUSTRALIA','2223','0295861968','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 11:51:11',0,NULL,3,1,2,1,NULL,'czis9999'),(15481,717982488018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','saskia_louise','saskia_curts@yahoo.com','Saskia curtis','4 putty beach drive','Killcare','New South Wales','AUSTRALIA','2257','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-08-28 12:00:04',0,NULL,3,1,4,1,'YW867472191CN ','saskia_louise\rBackground Support  $25'),(15482,773405871017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','gormteper09','gormteper@hotmail.com','Gorm Teper','19 Smallwood Crt<br>Samford','Brisbane','Queensland','AUSTRALIA','4520','61732896363','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 12:02:12',0,NULL,3,1,2,1,NULL,'gormteper09'),(15483,717990552018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','dearp77','david@ct.gs','David Earp','11 Wyoming Road','Wyoming','New South Wales','AUSTRALIA','2250','0243293514','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 12:24:35',0,NULL,3,1,3,1,'RA184552272CN\r ','dearp77'),(15484,773414970017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','shawnyuan1986','shawn.yuan@hotmail.com','Xin Yuan','Blooming Angel Pty Ltd<br>42/7 Hoyle Ave','Castle Hill','New South Wales','AUSTRALIA','2154','0430922223','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 12:24:57',0,NULL,3,1,2,1,NULL,'shawnyuan1986'),(15485,773402620017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','rashid310379','rashid31379@gmail.com','Mohammad Rashiduzzaman','2 Laggan Court, Endeavour Hills','Melbourne','Victoria','AUSTRALIA','3802','0397080634','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 11:54:40',0,NULL,3,1,2,1,NULL,'rashid310379'),(15486,717582763018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','mckeop252','mckeop25@hotmail.com','Peter McKeown','47 Sievewright Street<br>Silver Sands','Mandurah','Western Australia','AUSTRALIA','6210','0895820771','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 12:39:02',0,NULL,3,1,4,1,'YW867472180CN ','mckeop252\rtripod $22'),(15487,718002179018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','icieling','icie.eici@gmail.com','Isaac M Leung','3 Foxwood Way','Cherrybrook','New South Wales','AUSTRALIA','2126','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 12:50:16',0,NULL,3,1,3,1,'RA184552269CN\r ','icieling'),(15488,758425175002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','ropheim','rophe@broadpark.no','Roger Opheim','Industriveien 68b','Heimdal','','NORWAY','7080','92447122','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 13:20:15',0,NULL,3,1,2,1,NULL,'ropheim'),(15489,8881314539073492,111,'1.8m 717',1,'AO0003',245,'photographyacc','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090',NULL,NULL,NULL,'2011-08-28 13:44:33',0,NULL,3,0,6,1,'EE645685620CN ','1.8m 的717  c里的东西不对 已入库'),(15490,718022033018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','pernerperner','morten.heggheim@gmail.com','Morten Heggheim','fjordvegen 3','Sola','Sola','NORWAY','4050','41160561','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-28 13:48:37',0,NULL,3,1,2,1,NULL,'pernerperner'),(15491,716484805001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','mindroul','368698@gmail.com','Danny Mindroul','BarEli 14 (app. 32), TelAviv<br>בראלי 14, תלאביב','TelAviv','Israel','ISRAEL','69364','972 528287475','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-28 14:44:32',0,NULL,3,1,3,1,'RA184552207CN\r ','mindroul'),(15492,842550035015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','kavidacat','elizabeth.cannon17@gmail.com','Elizabeth Cannon','Kavida, North Road','Bunwell, Norwich','Norfolk','UNITED KINGDOM','NR16 1RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 14:53:21',0,NULL,3,1,2,1,NULL,'kavidacat'),(15493,842568569015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','espenwisur','espen.wisur@gmail.com','Espen Wisur','Fridtjof Nansens vei 13','Fredrikstad','Østfold','NORWAY','1605','004792225842','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 15:35:45',0,NULL,3,1,2,1,NULL,'espenwisur'),(15494,758494760002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','alexshefer','shefer66@gmail.com','Alexander Shefer','Mivtsa Nahshon 59/5 str.','Beer Sheva','','ISRAEL','84451','972507180363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 15:52:09',0,NULL,3,1,3,1,'RA184552309CN\r ','alexshefer\r分开发\rRA184552136CN\r'),(15495,718087372018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','vitorwood','vmcm@ci.uc.pt','Vítor Madeira','Departamento de Ciências da Vida<br>Apartado 3046','3001-401 Coimbra','','PORTUGAL','3001-401','239855760','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-28 15:57:23',0,NULL,3,1,2,1,NULL,'vitorwood'),(15496,842604482015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.9,'hutongstore','korourke0_0','karen.or@hotmail.co.uk','Karen O\'Rourke','26 South Parade, Stainland','Halifax','West Yorkshire','UNITED KINGDOM','HX49HW','01422374327','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 16:20:30',0,NULL,3,1,2,1,NULL,'korourke0_0'),(15497,716589143001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',5,'AA1211',14.95,'hermeshine','jeans5012010','jeans501@mac.com','HIROYUKI MORINO','6-8-9 MORINO.BLD.<br>Yahiro','Sumida-Ku','Tokyo','JAPAN','131-0041','81-03-3611-1385','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:41:47',0,NULL,3,1,3,1,'RA184552224CN\r ','jeans5012010'),(15498,758557931002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','haligonian53','familycado@bellaliant.net','Dragan Cado','209 Abrams way','Halifax','NS','CANADA','B3P 2R9','(902) 422-2835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:47:41',0,NULL,3,1,2,1,NULL,'haligonian53'),(15499,716600224001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','rufixorg','rufix@inbox.lv','Ruslans Lazurs','Ventas 8-9','Ventspils novads','Varve','LATVIA','3623','(371) 2283-4161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 17:56:15',0,NULL,3,1,2,1,NULL,'rufixorg'),(15500,758578791002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','across-international-com','order@acrossinternational.com','Rentian Huang','6 Murray Hill Mnr','New Providence','NJ','UNITED STATES','07974-1558','(973) 760-4226','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 18:01:18',0,NULL,3,1,3,1,'RA184552198CN\r ','across-international-com'),(15501,758588873002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','u0075979','scott_crandall_2@yahoo.com','Scott Crandall','23812 Helsinki St','Mission Viejo','CA','UNITED STATES','92691','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-08-28 18:11:43',0,NULL,3,1,1,1,NULL,'u0075979'),(15502,842718992015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','slavicripper','xslavic@gmail.com','Veaceslav Condur','str.Drumul viilor 29, sc.8 ,ap:110','Chisinau','','MOLDOVA, REPUBLIC OF','md-2009','78505167','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 18:27:50',0,NULL,3,1,2,1,NULL,'slavicripper'),(15503,716502014001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','j_vilchis','joaquin_vilchis@msn.com','Joaquin Vilchis Soriano','ahuacatitla 75<br>Colona Los Reyes Azcapotzalco','Distrito Federal','Mexico, DF','MEXICO','02010','52 55 53 52 80 35','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 19:10:58',0,NULL,3,1,12,1,'BJ8824612 ','j_vilchis\r0901多付了$58\r实重  7.1 抛重8.2\r灯泡是110V的\rDHL: 5241696331\r最终计费泡重9.5'),(15504,825237498016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','aidasb123','echo@upcmail.ie','Aidas Bernotas','3 Foxborough Grove','Lucan','Dublin','IRELAND','','0862587585','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 19:21:58',0,NULL,3,1,2,1,NULL,'aidasb123'),(15505,758696112002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','monicalib','yanbai18@hotmail.com','Li Bai','Calle Paseo de las Delicias numero 143','Madrid','Madrid','SPAIN','28045','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 20:58:26',0,NULL,3,1,2,1,NULL,'monicalib'),(15506,758698327002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','jhickman1947','jhickman8@embarqmail.com','John Hickman','PO Box 307<br>307 Yost Street','Quincy','OH','UNITED STATES','43343','(937) 585-6206','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-28 21:01:13',0,NULL,3,1,1,1,NULL,'jhickman1947\r应该是L 的'),(15507,842847926015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','chrishobcroft','chris@hobcroft.com','Chris Hobcroft','15 Arundel Mansions<br>Kelvedon Road','London','London','UNITED KINGDOM','SW65BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-28 21:14:27',0,NULL,3,1,2,1,NULL,'chrishobcroft'),(15508,716731653001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.9,'hermeshine','dogmaisfordogs','davidwoodbridge@hotmail.com','David Woodbridge','257 Hull Road','Mooroolbark','Victoria','AUSTRALIA','3138','0422212507','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-28 21:18:26',0,NULL,3,1,3,1,'RA184552175CN\r ','dogmaisfordogs'),(15509,842867008015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','hardpuzzlehelder','helinhas@gmail.com','Helder Almeida','rua antonio gilberto andrade<br>25 - 4Esq','cascais','','PORTUGAL','2750-841','910149417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-28 21:51:15',0,NULL,3,1,2,1,NULL,'hardpuzzlehelder'),(15510,718322154018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',13.2,'photographyacc','feanor981pm','gabriel.marcelli@gmail.com','Gabriele Marcelli C/O Baranello Luisa','Via Giuseppe Mazzini 161','Avezzano','L\'Aquila','ITALY','67051','0863-26070','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-28 21:49:29',0,NULL,3,1,2,1,NULL,'feanor981pm\r绿叶 渐变镜 67mm    1\r绿叶 CPL     67mm    1\r已入库'),(15511,773781573017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','gintsk123','gints.krievins@gmail.com','Gints Krievins','Berzupes iela 6-11','Riga','','LATVIA','LV-1004','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-28 22:53:49',0,NULL,3,1,2,1,NULL,'gintsk123'),(15512,716760286001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-28 22:46:57',0,NULL,3,1,3,1,'RA184552079CN\r ','arnorolf10'),(15513,718352541018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','ben7357','bendoubleyou@gmail.com','Ben Williams','132B Pitt Town Road Kenthurst','Sydney','New South Wales','AUSTRALIA','2156','0407211613','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 23:20:04',0,NULL,3,1,2,1,NULL,'ben7357'),(15514,773794362017,270751505051,'YongNuo Flash Battery Pack for Nikon SB800 SD-8A /8AA',1,'AB3309',52,'photographyacc','dearlizer','elisamcdonald@bigpond.com','Elisa McDonald','1/17 Miami Shore Pde','Miami','Queensland','AUSTRALIA','4220','0417893962','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-28 23:32:35',0,NULL,3,1,3,1,'RA184552184CN\r ','dearlizer'),(15515,716787682001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','ratmiraliev','xrat@inbox.ru','Ratmir Aliev','Korotchenko str.<br>2-43','Kazan','Tatarstan republic','RUSSIAN FEDERATION','420111','9179303303','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-29 00:08:45',0,NULL,3,1,3,1,'RA184552405CN\r ','ratmiraliev\rND8换成ND4'),(15516,716790841001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',3,'AKT029',72,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 00:22:41',0,NULL,3,0,3,1,'RA184552388CN\r ','mariomarques.com.br\rnikon 67 mm 镜头盖    20\rcanon 58 mm 镜头盖    10\r已入库\r申报gift 低值'),(15517,842943206015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','rickyboy002011','richarddonaldson1@hotmail.co.uk','Richard Donaldson','33 High Peak','Guisborough','Cleveland','UNITED KINGDOM','TS147NG','01287639449','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 01:08:48',0,NULL,3,1,2,1,NULL,'rickyboy002011'),(15518,773833725017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','ruta9','rafaruano@yahoo.com','Antonio Ruano','Capitan Viola 279','Salta','Salta','ARGENTINA','A4408AQE','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 01:31:40',0,NULL,3,0,3,1,'RA184552241CN\r ','ruta9\rxxxl  已入库'),(15519,758803815002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','mininoloco2582','tuaire6@aol.com','gabino avila','2821 41st Ave','soquel','CA','UNITED STATES','95073-2112','(831) 334-2241','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 02:10:11',0,NULL,3,0,3,1,'RA184552119CN\r ','mininoloco2582\rc 里面的不对  是3*2 的白色厚的背景布'),(15520,8881314585500238,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box ',1,'AC2402',19.47,'aliexpress','1004171191','g.krylov@online.de','Krylov Gennadi','Kasinoweg 25A','Hofgeismar','Hessen','GERMANY','34369','+0049 178 1579336',NULL,NULL,NULL,'2011-08-29 02:38:20',0,NULL,3,1,3,1,'RA184552604CN\r ',''),(15521,718425065018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','chantilly_art','louisebresolin@yahoo.com.au','Jason Ryan','190  Power Street','Glendenning','New South Wales','AUSTRALIA','2761','61288050076','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 03:23:04',0,NULL,3,1,2,1,NULL,'chantilly_art'),(15522,758829986002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',3,'AE3102',23.67,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100<br>Tel 8(912)939-43-61','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','(912)936-07-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 04:29:24',0,NULL,3,1,3,1,'RA184552391CN\r ','motorfoto'),(15523,758470439002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','813emily','hotam6666@yahoo.com','TAM HO','14747 N Dale Mabry Hwy','TAMPA','FL','UNITED STATES','33618-2025','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 04:45:14',0,NULL,3,1,1,1,NULL,'813emily'),(15524,718382790018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','markp1993','markperrin03@yahoo.com.au','Mark Perrin','Unit 1 at 3 Allard Street','Brunswick West','Victoria','AUSTRALIA','3055','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 04:48:53',0,NULL,3,1,2,1,NULL,'markp1993'),(15525,716871097001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','nrtssm','udm32221@biglobe.ne.jp','Susumu Narita','2-5-9-206,Nagao','Kawasaki-shi,tama-ku','Kanagawa','JAPAN','214-0023','044-922-6998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 06:14:04',0,NULL,3,1,2,1,NULL,'nrtssm'),(15526,716871692001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','emasale','salerno.emanuele@libero.it','Emanuele Salerno','Via Guardini 10','Monza','MI','ITALY','20052','039-2029813','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-29 06:14:52',0,NULL,3,1,3,1,'RA184552502CN ','emasale'),(15527,843029900015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','darmstadt1976','aliirawan@yahoo.de','Ilham Futuh Rohman','Jln. Merak no.9<br>Cakranegara Barat - Mataram','Lombok - Indonesia','','GERMANY','83231','','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,7,0,18,0,' ','darmstadt1976\recheck 结清了再发\r\r'),(15528,773907919017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','bacs111','brettacs@hotmail.com','BRETT SAFFREY','10 GALWAY GROVE','GLADSTONE PARK','Victoria','AUSTRALIA','3034','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 07:11:23',0,NULL,3,1,3,1,'RA184552414CN ','bacs111\r接口环换成77mm的\r托架 换成 广角托架\r已入库'),(15529,773897175017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','letsbuyitnow2009','letsbuyitnow@gmail.com','James Esguerra','737 ridge ave<br>Apt 4C','evanston','IL','UNITED STATES','60202-2679','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 07:12:00',0,NULL,3,1,1,1,NULL,'letsbuyitnow2009'),(15530,773915762017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','linda-1947','linphilmc@gmail.com','Linda   McGloin','PO Box 59','CARRINGTON','New South Wales','AUSTRALIA','2294','0249654184','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 07:45:47',0,NULL,3,1,17,0,NULL,'linda-1947'),(15531,718473018018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','linda-1947','linphilmc@gmail.com','Linda   McGloin','PO Box 59','CARRINGTON','New South Wales','AUSTRALIA','2294','0249654184','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 07:49:43',0,NULL,3,1,2,1,NULL,'linda-1947\r肩带 canon     1\rMini 红外  canon    1'),(15532,8881314606571403,111,'YN159-C3',1,'AD1120',0,'photographyacc','dusteve','dusteve@hotmail.com','Steve Du','31 Denmark St','Merrylands','New South Wales','AUSTRALIA','2160','0401525254',NULL,NULL,NULL,'2011-08-29 08:29:31',0,NULL,3,1,3,1,'RA184552428CN ','只发接受器 '),(15533,716900094001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','anesh2004','pather@pixie.co.za','Anesh Pather','Champion Cosmetics<br>PO Box 1249','Richards Bay','KwaZulu Natal','SOUTH AFRICA','3900','035 - 7533823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 08:47:29',0,NULL,3,1,2,1,NULL,'anesh2004'),(15534,773932062017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',4,'AA1314',11.96,'photographyacc','htteoriginal','han.teo@optusnet.com.au','Han Tiau Teo','23 Boronia Drive<br>Southport','Gold Coast','Queensland','AUSTRALIA','4215','0755327109','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 08:56:05',0,NULL,3,1,2,1,NULL,'htteoriginal'),(15535,758885834002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','saunanen','aldis23@balticom.lv','Aldis Pirtnieks','Lielvardes 101-9','Riga','Riga','LATVIA','LV-1084','+37129422566','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 09:00:30',0,NULL,3,1,2,1,NULL,'saunanen'),(15536,825536869016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','wallram','nilsson.morgan@gmail.com','Morgan Nilsson','Parkstigen 11','Mariehamn','Åland','FINLAND','ax-22100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 09:09:29',0,NULL,3,1,17,0,NULL,'wallram\r转接环 77mm'),(15537,773937201017,270742047297,'32\" 80CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3302',13.8,'photographyacc','kbrow210','kane_is_a_pro_skater@hotmail.com','kane brown','159 mudjimba beach road','sunshine coast','Queensland','AUSTRALIA','4564','0466520322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 09:16:41',0,NULL,3,1,2,1,NULL,'kbrow210'),(15538,825553146016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',2.25,'hutongstore','wallram','nilsson.morgan@gmail.com','Morgan Nilsson','Parkstigen 11','Mariehamn','Åland','FINLAND','ax-22100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 10:02:59',0,NULL,3,1,2,1,NULL,'wallram\r方形滤镜接口环 55mm    1\r天涯方形滤镜  渐变灰    1\r方形滤镜接口环 58mm    1\r方镜普通托架（三槽）     1'),(15539,758901452002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','szucsi11','istvan.szucs@uniqa.hu','István dr. Szűcs','Téglagyártó u. 9/A.','Budapest','','HUNGARY','1203','(70) 355-3639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 10:13:02',0,NULL,3,1,2,1,NULL,'szucsi11'),(15540,716929239001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',59.98,'hermeshine','zeshanrafi1984','zeshanrafi@hotmail.com','Zeshan Rafi','Jægerhusene 76','2620 Albertslund','','DENMARK','2620','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 10:49:05',0,NULL,3,1,3,1,'RA184552581CN\r ','zeshanrafi1984'),(15541,758917810002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','musicjohn2','john@johnenarie.com','J.J. van Kleef','IJssellaan 187','Gouda','','NETHERLANDS','2806TH','(31)182-785434','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-29 11:09:39',0,NULL,3,0,3,1,'RA184552595CN\r ','musicjohn2\rL  已入库'),(15542,825577680016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','buyer1983790','xbox360gh@yandex.ru','Simon Shlionskiy','Street: Krylatsky hills, block 39, building 1, flat 151.','Moskow','','RUSSIAN FEDERATION','121614','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 11:20:09',0,NULL,3,1,2,1,NULL,'buyer1983790'),(15543,0,120767278753,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',1,'AB2214',0.99,'hermeshine','sexyboy143','sandeep_dhillon148@yahoo.com','sandeep dhillon','155 denton ave,','st albans','Victoria','AUSTRALIA','3021','0061430002640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:22:28',0,NULL,3,1,2,1,NULL,'sexyboy143'),(15544,0,120767278977,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.04,'hermeshine','aghunt2005','aghunt2005@exemail.com.au','Alistair Hunt','10 Narangba rd<br>Kallangur','Brisbane','Queensland','AUSTRALIA','4503','0732855965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:23:56',0,NULL,3,1,2,1,NULL,'aghunt2005'),(15545,0,120767278697,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',4,'hermeshine','reuvenst','ruvenst@yahoo.com','Reuven Siman Tov','Levona 44','Jerusalem','Israel','ISRAEL','93843','0972545347060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:29:53',0,NULL,3,1,2,1,NULL,'reuvenst'),(15546,0,110733663643,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',0.99,'hermeshine','thejonsav','jonsav@inwind.it','antonio savini','via cutigliano 115<br>da consegnare al portiere','roma','RM','ITALY','00146','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:31:04',0,NULL,3,1,2,1,NULL,'thejonsav'),(15547,0,120767278776,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',3.79,'hermeshine','slavkoxxl87','slavkoxxl@gmail.com','Yaroslav Kozak','Сhygyevskii pr.,12/30','Kiev','Kiev','UKRAINE','03067','(050)6752265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:32:24',0,NULL,3,1,2,1,NULL,'slavkoxxl87'),(15548,0,110733663688,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',1.54,'hermeshine','huertacarlos','carlos.huerta@gmail.com','Carlos Huerta','Ruiz Huidobro 3640<br>Piso 13 Dto C','Capital Federal','buenos aires','ARGENTINA','1430','+5491161062265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 11:54:58',0,NULL,3,1,2,1,NULL,'huertacarlos'),(15549,843125201015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',120,'hutongstore','antoninamalina','wturman2@inbox.lv','Malina Antonina','kandavas 4a 29','daugapils','','LATVIA','LV-5401','0037129780434','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 11:59:39',0,NULL,3,1,5,1,'CP235627445CN ','antoninamalina\r欧标'),(15550,0,120767278680,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.76,'hermeshine','sisonka2872','arrowgroo@abv.bg','Plamen Lyakov','Kiril and Metodii 55 G7','Dobrich','Dobrich','BULGARIA','9300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:08:16',0,NULL,3,1,2,1,NULL,'sisonka2872'),(15551,0,110733663395,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',1.04,'hermeshine','casillas65','carpaumar@gmail.com','juan manuel casillas delgado','calle universidad hispalense 8','osuna','SEVILLA','SPAIN','41640','629017397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:21:08',0,NULL,3,1,2,1,NULL,'casillas65'),(15552,0,120767279026,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',4.25,'hermeshine','kaspo2010','a_kaspo@yahoo.com','ayad kaspo','skiftesvagen 12,2tr','Sodertalje','stockholms lan','SWEDEN','151 54','0046704973212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:48:08',0,NULL,3,1,2,1,NULL,'kaspo2010'),(15553,716961584001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','caspirius','curtvert@gmail.com','Oleg Polyakov','9/1 Lefortovsky val, apt#96','Moscow','','RUSSIAN FEDERATION','111250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 12:48:56',0,NULL,3,1,2,1,NULL,'caspirius'),(15554,0,110733663532,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',1.69,'hermeshine','kunstwaise','kunstwaisenhaus@yahoo.de','Andrea Koontz','Lise-Meitner-Weg 22','Regensburg','','GERMANY','93055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:21:40',0,NULL,3,1,2,1,NULL,'kunstwaise'),(15555,716973137001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','lgreysys','lgreysy@mail.ru','Sergey A Lyakuev','ul. Rodionova, dom 191, kv.157','Nizhny Novgorod','Nizhegorodskaya obl','RUSSIAN FEDERATION','603163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:30:17',0,NULL,3,1,17,0,NULL,'lgreysys'),(15556,716973005001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','lgreysys','lgreysy@mail.ru','Sergey A Lyakuev','ul. Rodionova, dom 191, kv.157','Nizhny Novgorod','Nizhegorodskaya obl','RUSSIAN FEDERATION','603163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:30:18',0,NULL,3,1,17,0,NULL,'lgreysys'),(15557,0,110733663360,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',2.7,'hermeshine','lgreysys','lgreysy@mail.ru','Sergey A Lyakuev','ul. Rodionova, dom 191, kv.157','Nizhny Novgorod','Nizhegorodskaya obl','RUSSIAN FEDERATION','603163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 13:30:18',0,NULL,3,1,3,1,'RA184552564CN ','lgreysys\r镜头筒 小号     1\r反光板  80cm 5合1      1\r橡胶遮光罩 67mm       1'),(15558,758967110002,120448751908,'Remote Shutter Release Cord for Nikon D70s D80 = MC-DC1',1,'AA3208',4.45,'hermeshine','boyberic58','boyberic@walla.co.il','Ronen Margalit','Hatzav 72','Kfar Vradim','IL','ISRAEL','25147','+972-50-5908174','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:02:52',0,NULL,3,1,2,1,NULL,'boyberic58'),(15559,758967379002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','vel397','jan.velicky@nuov.cz','Jan Velicky','Weilova 1271/6','Praha 10','Praha','CZECH REPUBLIC','10200','274022113','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:03:20',0,NULL,3,1,2,1,NULL,'vel397'),(15560,0,110733663874,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.5,'hermeshine','jimrichard.com','jim@jimrichard.com','Floyd Richard Jr','10014 Schanzer Rd','Hitchcock','TX','UNITED STATES','77563-4564','(281) 337-5015','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 14:19:59',0,NULL,3,1,1,1,NULL,'jimrichard.com'),(15561,825651088016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','tpitt96961','tpitt96961@aol.com','Trevor Pitt','78 Forest Road<br>Greenstead','Colchester','Essex','UNITED KINGDOM','CO4 3RA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 14:32:24',0,NULL,3,1,2,1,NULL,'tpitt96961'),(15562,758973813002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',19.78,'hermeshine','storagejunkie','leesycsold@optusnet.com.au','Sam Lee','117 Cardinal Ave','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-08-29 14:34:58',0,NULL,3,1,17,0,NULL,'storagejunkie'),(15563,758974855002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','storagejunkie','leesycsold@optusnet.com.au','Sam Lee','117 Cardinal Ave','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:36:46',0,NULL,3,0,17,0,NULL,'storagejunkie'),(15564,758975855002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','storagejunkie','leesycsold@optusnet.com.au','Sam Lee','117 Cardinal Ave','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-29 14:36:46',0,NULL,3,0,17,0,NULL,'storagejunkie'),(15565,758976481002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','storagejunkie','leesycsold@optusnet.com.au','Sam Lee','117 Cardinal Ave','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 14:36:47',0,NULL,3,0,3,1,'RA184552520CN\r ','storagejunkie\r单灯头 澳标    2\rc型大力夹     2\r115w 5500k 灯泡  220v     2'),(15566,0,110733663485,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',3.81,'hermeshine','cruzan_rum','hirst@viaccess.net','John Hirst','580 Valley Park RD.','Phoenixville','PA','UNITED STATES','19460','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 14:46:06',0,NULL,3,1,1,1,NULL,'cruzan_rum'),(15567,8881314630971663,111,'115w 110v    x  1',1,'AO0004',0,'hermeshine','jamies_ibanez','jamiesibanez@hotmail.com','Jamie Cameron','Box 118','Portage Du Fort','QC','CANADA','J0X 2T0','',NULL,NULL,NULL,'2011-08-29 15:16:11',0,NULL,3,1,3,1,'RA184552516CN\r ',NULL),(15568,718607997018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','don_mthws','skettynutz@yahoo.com','Don Murphy','2649 W. 90th St.','Evergreen Park','IL','UNITED STATES','60805','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 15:31:12',0,NULL,3,1,1,1,NULL,'don_mthws'),(15569,0,120767278861,'NeopreneCamera Cover Case for Canon Nikon Medium Size',1,'AC1301',2.26,'hermeshine','myaturney','dddirkkk@aim.com','Dirk Kiprik','24011 51st Ave','Douglaston','NY','UNITED STATES','11362-1023','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 15:37:28',0,NULL,3,1,17,0,NULL,'myaturney'),(15570,0,110733663507,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',5,'hermeshine','myaturney','dddirkkk@aim.com','Dirk Kiprik','24011 51st Ave','Douglaston','NY','UNITED STATES','11362-1023','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 15:37:29',0,NULL,3,1,1,1,NULL,'myaturney\r中号内胆包 无字     1\r绿叶 ND4  77mm     1'),(15571,717003759001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','716glyn','glyn.wilkinson78@o2.co.uk','Darryl Wilkinson','38 Bridge Lane','Frodsham','Cheshire','UNITED KINGDOM','WA67HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 15:06:50',0,NULL,3,1,2,1,NULL,'716glyn'),(15572,0,110733663706,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',2.75,'hermeshine','nehalena','bipin@printographics.com','Bipin Khanolkar','2016 USA Drive','Plano','TX','UNITED STATES','75025','(972) 240-7979','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 15:52:03',0,NULL,3,1,1,1,' ','nehalena'),(15573,718628171018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','rakemp1','rkemp@hiwaay.net','Reggie Kemp','3613 Chula Vista Dr SW','Decatur','AL','UNITED STATES','35603','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 16:21:10',0,NULL,3,1,1,1,NULL,'rakemp1'),(15574,0,110733663838,'New wide angle holder for Cokin P series filter',1,'AA2216',2.25,'hermeshine','meejanpetch','mr.nolimit@msn.com','Sakkharin Meejanpetch','Nattawut Mansion 8/12 Nadedee Road Soi 5<br>Tambon Saensuk','Amphur Muang','Chonburi','THAILAND','20130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 16:31:30',0,NULL,3,1,2,1,NULL,'meejanpetch'),(15575,717047319001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','edding7','edding7@terra.es','daniel ruiz ramos','c/ malaga. nº6. Edif Litoral 6-A','Fuengirola','Andalucía Ceuta y Melilla','SPAIN','29640','649142442','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 17:00:57',0,NULL,3,1,4,1,'YW867472154CN ','edding7'),(15576,0,120767279008,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.75,'hermeshine','wittless','powerseller.ebay@gmail.com','robin wittman','14223 n hawthorn ct<br>Apt A','fountain hills','AZ','UNITED STATES','85268','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-29 17:47:40',0,NULL,3,1,1,1,NULL,'wittless'),(15577,759056827002,120757472199,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT074',310,'hermeshine','rodolnoe','noelia112@hotmail.com','noelia fernandez cano','c/pasaje de saro nº4 2ºc','torrelavega','Cantabria','SPAIN','39300','636913005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 17:56:51',0,NULL,3,1,4,1,'YW867472143CN ','rodolnoe\r欧标\rLighting Kit  $40'),(15578,0,120767279001,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.25,'hermeshine','j_vilchis','joaquin_vilchis@msn.com','Joaquin Vilchis Soriano','ahuacatitla 75<br>Colona Los Reyes Azcapotzalco','Distrito Federal','Mexico, DF','MEXICO','02010','52 55 53 52 80 35','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:23:50',0,NULL,3,1,2,1,NULL,'j_vilchis'),(15579,717090007001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','mairiitaa','aivarsradzis@inbox.lv','Mairita Gedominska','Avotu iela 6-13<br>Zaņas pagasts','Saldus','Saldus novads','LATVIA','LV-3897','+37122453817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:35:35',0,NULL,3,1,2,1,NULL,'mairiitaa'),(15580,718690755018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',39.8,'photographyacc','kiidsen','sen.y.lim@gmail.com','Sen Lim','209 George Street','Queens Park','Western Australia','AUSTRALIA','6107','0431347645','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 18:36:48',0,NULL,3,1,3,1,'RA184552533CN\r ','kiidsen'),(15581,717096371001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.48,'hermeshine','emilianoconti','emilianoconti1@gmail.com','oriano conti','Via delle robinie 33A','Roma','RM','ITALY','00172','3475438163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:44:37',0,NULL,3,1,2,1,NULL,'emilianoconti'),(15582,717098922001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','tomcsiaz83','tomcsiaz@gmail.com','Tamás Szádai','Jókai utca 23.','Nyírmártonfalva','Hajdú-Bihar','HUNGARY','4263','+36303750134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 18:49:56',0,NULL,3,1,2,1,NULL,'tomcsiaz83'),(15583,825770026016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',2,'AA1305',3.74,'hutongstore','7rusket','nilsen_merete@hotmail.com','Merete Nilsen','Hegdehaugsveien 22 a','Oslo','','NORWAY','0167','(0047) 48173718','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-29 18:51:02',0,NULL,3,1,2,1,NULL,'7rusket'),(15584,843323085015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','rachepache','rachelharris.home@gmail.com','Dr Rachel Boyce','Birch Hill Medical Centre<br>Leppington','Bracknell','Berkshire','UNITED KINGDOM','RG12 7WW','07956257531','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 18:57:58',0,NULL,3,1,2,1,NULL,'rachepache'),(15585,759107356002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 19:42:10',0,NULL,3,1,17,0,NULL,'andrewespuni1979'),(15586,717120491001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'',28.49,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-29 19:42:09',0,NULL,3,0,17,0,NULL,'andrewespuni1979'),(15587,759108072002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','andrewespuni1979','andrewespuni@hotmail.com','andres mata tome','c/enrique del castillo 3','marbella','Andalucía Ceuta y Melilla','SPAIN','29600','625092804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 19:42:11',0,NULL,3,1,3,1,'RA184552547CN\r ','andrewespuni1979\r方形滤镜接口环 72mm     1\r方镜普通托架（三槽）    1\r天涯方形滤镜  渐变棕     1\r6片装滤镜袋     1\r新的那个镜子非天涯\r渐灰ND4       1\r渐灰ND8       1\rND2       1\rND4         1\rND8          1\r渐变蓝      1\r'),(15588,843401572015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','db_734','ebay@schoenetage.at','dennis brezina','Unit 50 Omega Works<br>4 Roach Road','London','London','UNITED KINGDOM','E3 2PD','07518642570','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-29 20:57:09',0,NULL,3,1,2,1,NULL,'db_734'),(15589,0,120767279085,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',8.5,'hermeshine','mmedvescek','mitja.medvescek@gmail.com','Mitja Medvescek','Hrastinska pot 47','Brezice','Slovenia','SLOVENIA','8250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 20:58:07',0,NULL,3,1,2,1,NULL,'mmedvescek'),(15590,0,120767278666,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.25,'hermeshine','charliek47','ckarrh1@bellsouth.net','Charles Karrh','6 Winding River Ln.<br>PO Box 1196','Inglis','FL','UNITED STATES','34449','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-29 21:14:01',0,NULL,3,1,1,1,NULL,'charliek47'),(15591,718780514018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','suemchats','mchats@optusnet.com.au','sue mchats','14 Loombah Road','Dover Heights','New South Wales','AUSTRALIA','2030','0293430194','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-29 21:33:59',0,NULL,3,1,2,1,NULL,'suemchats'),(15592,0,120767279120,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',2.52,'hermeshine','oleggorenko','oleg.gorenko@ymail.com','Oleg Gorenko','vul.Olimpijska bud.21 kv.10','Kharkiv','','UKRAINE','61060','(380) 689-5304 ext.: 49','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:45:17',0,NULL,3,1,2,1,NULL,'oleggorenko'),(15593,717178271001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','ge_sh','ge_sh1@walla.com','Liron Shiryon','qheilat zion 21','Herzliya','','ISRAEL','46382','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-29 21:51:58',0,NULL,3,1,3,1,'RA184552555CN\r ','ge_sh'),(15594,718801281018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','gianlucabosetti','gianlubos@libero.it','gianluca bosetti','via S. Giorgio 55','Cabiate','CO','ITALY','22060','0495793064','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-29 22:37:10',0,NULL,3,1,2,1,NULL,'gianlucabosetti'),(15595,717228250001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','retrocactus','red8ull@gmail.com','John Biehler','216-151 West Esplanade','North Vancouver','BC','CANADA','V7M 3H9','(604) 351-8146','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 01:10:22',0,NULL,3,0,3,1,'RA184552462CN\r ','retrocactus\r2XL     已入库'),(15596,759228968002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','jymah','junyeumah@hotmail.com','Jun Yeu Mah','3106/483<br>Swanston St','Melbourne','Victoria','AUSTRALIA','3000','0403231456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 01:45:42',0,NULL,3,1,2,1,NULL,'jymah'),(15597,759241980002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','19041980','meneses.icivil@gmail.com','Pablo Meneses Arcos','Volcan Tolguaca 3493<br>Villa Entre Ríos','Valdivia','XIV Región De Los Ríos','CHILE','5101825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 02:36:23',0,NULL,3,1,2,1,NULL,'19041980'),(15598,718872738018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','ip.freely','hughsouyave@hotmail.com','Hugh Souyave','47 Kembla St Fyshwick','ACT','Australian Capital Territory','AUSTRALIA','2609','0262807511','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 03:20:45',0,NULL,3,1,3,1,'RA184552578CN','ip.freely'),(15599,759261308002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','mdovbenko','dovbenko_maria@yahoo.com','Mark Turmell','3219 Chardonnay Ct','Longwood','FL','UNITED STATES','32779','(805) 607-0714','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-30 04:12:25',0,NULL,3,0,1,1,NULL,'mdovbenko\r1.6*3 粉红    1'),(15600,843545380015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','jfquintero','jfquintero3@hotmail.com','John Quintero','6 Mantlet Close<br>Streatham Vale','london','London','UNITED KINGDOM','SW16 5AR','07984608576','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 04:14:26',0,NULL,3,1,2,1,NULL,'jfquintero'),(15601,8881314679314373,111,'77mm 接口环  x   1',1,'AA2214',0,'hutongstore','wallram','nilsson.morgan@gmail.com','Morgan Nilsson','Parkstigen 11','Mariehamn','Åland','FINLAND','ax-22100','',NULL,NULL,NULL,'2011-08-30 04:41:54',0,NULL,3,1,2,1,NULL,NULL),(15602,717272072001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','3235eddy','eddy.robert@mil.be','Eddy Robert','Vengerstraat 74','Bierbeek (Korbeek-Lo)','','BELGIUM','3360','0473991781','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 04:41:51',0,NULL,3,1,3,1,'RA184552652CN ','3235eddy\r已入库\r'),(15603,717274943001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','tak_61','stefano.tacconi4@tin.it','stefano tacconi','via del prete 1','verona','VR','ITALY','37138','045.576610','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 04:59:59',0,NULL,3,1,3,1,'RA184552621CN ','tak_61\rrepair tool    $8'),(15604,718894311018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','cheeky_monkey1980','funky_chicken_bella@yahoo.com.au','Michelle  Loo','40 Moombaki Ave','Bertram','Western Australia','AUSTRALIA','6167','0893584971','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 05:21:40',0,NULL,3,0,2,1,NULL,'cheeky_monkey1980\r1.6*2.1 白色背景布    1'),(15605,774354883017,270748510647,'NIB TianYa Gradual Blue Color Filter for Cokin P series',1,'AA2320',7.29,'photographyacc','echonky','gaglan@ozemail.com.au','Nundah Village Dental','1182 Sandgate Rd<br>( PO box 179 )','Nundah','Queensland','AUSTRALIA','4012','0732606200','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 05:30:57',0,NULL,3,1,2,1,' ','echonky'),(15606,843583947015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','zoran_stupar','zstupar@hotmail.com','Zoran Stupar','V.Nazora 24','Koprivnica','','CROATIA','48000','00385981653262','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 07:14:43',0,NULL,3,1,2,1,NULL,'zoran_stupar'),(15607,718926255018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','shreda','jake_hanger@hotmail.com','jake hanger','2 eagle place dallis park','murwillumbah','New South Wales','AUSTRALIA','2484','0266721222','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 08:15:28',0,NULL,3,1,3,1,'RA184552618CN ','shreda'),(15608,717311570001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','berksozer','sozerberk@gmail.com','Berk Sözer','Yali Mah. Sehit Nedim Ozpolat Sok. Izzetduru Apt. No:5/8<br>Maltepe','Istanbul','','TURKEY','34844','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 08:27:01',0,NULL,3,1,3,1,'RA184552927CN\r','berksozer\r新地址\rSalih Mert Sözer\rYalı Mahallesi Mareşal Fevzi Çakmak Caddesi Esma Sokak No:2\rA Blok Kat:8 Daire:34\rMaltepe/İstanbul\r34844\rTurkey\r货被退回来了     无人领取\r'),(15609,717313287001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',193,'hermeshine','krudo1','antonio.cuda@libero.it','Antonio Cuda','G. Garibaldi, 107','Petilia Policastro','KR','ITALY','88837','3803125615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 08:36:34',0,NULL,3,1,4,1,'YW867472051CN','krudo1\r欧标\r实重7.1  抛重7.8'),(15610,717318472001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','danielbraganow','danielbraga@live.com','Daniel Braga','19, Rue Père Sanson<br>Chambre 227','Caen','BASSE-NORMANDIE','FRANCE','14000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 09:01:53',0,NULL,3,1,2,1,NULL,'danielbraganow'),(15611,843613028015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','dickie300086','richie6_9@hotmail.com','Richard Willis','7 Monk Bridge Drive','Leeds','North Yorkshire','UNITED KINGDOM','LS6 4HU','01892535244','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 09:04:48',0,NULL,3,1,2,1,NULL,'dickie300086'),(15612,774420207017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','frigorifero','buyer99@gmail.com','Antonio Sbaraglia','viale Regina Elena n.74','Pescara','PE','ITALY','65122','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 10:31:48',0,NULL,3,1,2,1,NULL,'frigorifero'),(15613,717362127001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','kborisov79','kalin.borisov@gmail.com','Kalin Borisov','Slavyanska 29<br>et.2','Sofia','Sofia','BULGARIA','1000','0897231130 ','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 12:01:28',0,NULL,3,1,17,0,NULL,'kborisov79'),(15614,717364885001,110718715286,'Soft Camera Bag Case Cover Canon EOS 5D ii + 24-105mm',1,'AD1115',16.9,'hermeshine','leo_e009','leof-009@yandex.ru','Valery Mozharov','ul.Chuvashskaya  d.2 kv.18','Kaliningrad','Russian Federation','RUSSIAN FEDERATION','236038','89062341556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 12:14:41',0,NULL,3,1,2,1,NULL,'leo_e009'),(15615,717364865001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','kborisov79','kalin.borisov@gmail.com','Kalin Borisov','Slavyanska 29<br>et.2','Sofia','Sofia','BULGARIA','1000','0897231130 ','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 12:16:44',0,NULL,3,1,3,1,'RA184585341CN ','kborisov79\r除了c 里面的再发如下\r无牌方镜 渐变灰 （nd4）    1\r无牌方镜 渐变灰 （nd8）    1\r无牌方镜 渐变蓝    1\r无牌方镜 ND2     1\r无牌方镜 ND4    1\r无牌方镜 ND8      1\r6片装的滤镜袋     1\r'),(15616,717345268001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','luisja206','luisja206@hotmail.com','luis javier adiego marques','maria de zapata 27 3ºd','la bañeza (Leon)','Castilla y León','SPAIN','24750','696228246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 12:18:37',0,NULL,3,0,2,1,NULL,'luisja206\r1.6*2.1  白色背景布 1'),(15617,718988431018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','rebelde_21','rebelde_21@msn.com','daniel Rivas Osuna','paseo 22 julio,331, 2º,2ª','terrassa','Barcelona','SPAIN','08225','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 12:20:09',0,NULL,3,1,3,1,'RA184552670CN\r ','rebelde_21'),(15618,843676378015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',5.5,'hutongstore','asyrtico','dipoud@yahoo.gr','Dionisios Poudos','Heracleidon 29','Athens','Haladri','GREECE','15234','2106833037','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 12:20:23',0,NULL,3,1,2,1,NULL,'asyrtico'),(15619,718990254018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','leeanda109','shaun.herbertson@gmail.com','Leeanda cook','5 Kinglake drive','Wyndham Vale','Victoria','AUSTRALIA','3024','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-30 12:20:46',0,NULL,3,1,2,1,NULL,'leeanda109'),(15620,759370569002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','33region','kolpakov921@gmail.com','Dmitry Kolpakov','Sovetskaya 29A-24','Murom','Vladimirskaya oblast`','RUSSIAN FEDERATION','602267','+79209032440','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 12:47:22',0,NULL,3,0,3,1,'RA184552710CN\r ','33region\r3XL   已入库'),(15621,717376102001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',2,'AO0011',159.98,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sarah Al-Subaa','Taruot','QATIF','QATIF','SAUDI ARABIA','31911','966598664682','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 12:48:26',0,NULL,5,0,18,0,NULL,'tawfeekmohammed'),(15622,716498887001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','tiurka','urmositibor@rdslink.ro','Urmosi Tibor','STR:Nicolae Iorga 20<br>BL:34CB     AP:18','Sfantu Gheorghe','Covasna','ROMANIA','520089','0756458943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 12:49:44',0,NULL,3,1,2,1,NULL,'tiurka'),(15623,717381267001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','irishheartbitt','irishheartbit@gmail.com','Yaroslav Ivankin','ul. Bogdana Hmel\'nitskogo<br>dom 14, kv.97','Saransk','Respublika Mordovia','RUSSIAN FEDERATION','430000','89603352907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 13:05:37',0,NULL,3,1,2,1,NULL,'irishheartbitt'),(15624,843696753015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','borneartpromotions','borneartadvertisment@hotmail.co.uk','christine cook','flat 2, 33 Holland road','Hove','East Sussex','UNITED KINGDOM','BN3 1JE','1273831131','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-08-30 13:15:45',0,NULL,3,1,12,1,'BJ8824610','borneartpromotions\r英标\r实重4.3   抛重5.5\r最终计费泡重6'),(15625,843703564015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','alanscape','andrew.alanscape.cameron@gmail.com','Andrew Cameron','7  Kelly Court<br>Broad Street','Stirling','Stirling','UNITED KINGDOM','FK81BG','01786464109','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-30 13:32:11',0,NULL,3,1,2,1,NULL,'alanscape'),(15626,774495667017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','renimperial','aaron.vincent.imperial@gmail.com','Aaron Imperial','64 Dryden Avenue','Carlingford','New South Wales','AUSTRALIA','2118','0298735393','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'renimperial'),(15627,719034839018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','ruah45','mjantzen805@charter.net','Milton Jantzen','101 El Viento','Pismo Beach','CA','UNITED STATES','93449-2863','(805) 773-8388','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 14:42:06',0,NULL,3,1,1,1,NULL,'ruah45\r已入库'),(15628,717414137001,110531023268,'JJC Leather Hand Strap Grip HS-3A D80 D90 40D',1,'AB1410',11.99,'hermeshine','ruah45','mjantzen805@charter.net','Milton Jantzen','101 El Viento','Pismo Beach','CA','UNITED STATES','93449-2863','(805) 773-8388','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-08-30 14:51:37',0,NULL,3,1,1,1,NULL,'ruah45'),(15629,717419755001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','kinretarual','lternik@comcast.net','Laura Ternik','10090 Walthan Way','Fishers','IN','UNITED STATES','46037-8916','(317) 578-9679','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-30 15:08:59',0,NULL,3,1,4,1,'YW867472121CN ','kinretarual'),(15630,717438805001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','artist8800','artist.sa@hotmail.com','Abdulaziz alhanaya#0507871111','P.O.Box 271489<br>alhassan ibn ali street','Riyadh City','AL-ROUDAH','SAUDI ARABIA','11352','(009) 665-0787 ext.: 1111','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 16:03:15',0,NULL,3,1,2,1,NULL,'artist8800'),(15631,716768305001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','bennny69','benedict88@hotmail.com','benedetto cascelli','via delle benedettine 90','roma','RM','ITALY','00135','3383435648','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 16:05:33',0,NULL,3,1,3,1,'RA184552808CN\r ','bennny69\r已入库\r Photo Vest  $12'),(15632,759119995002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','s.tar1982','tar12.12.1982@mail.ru','Sergey Taranishin','Partizanskaya 68-26','Samara','Samara','RUSSIAN FEDERATION','443093','89649800948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 16:33:22',0,NULL,3,1,3,1,'RA184552754CN\r ','s.tar1982'),(15633,719081817018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','1949mordechai','mhakham@yosh.ac.il','Mordechai Hakham-itzhaq','Ariel University center<br>applied physics department','Ariel','','ISRAEL','40700','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 16:46:08',0,NULL,3,1,2,1,NULL,'1949mordechai'),(15634,843797890015,250599395305,'52mm 52 Close Up  Macro Close-Up +8 Filter New',1,'AE3222',3.6,'hutongstore','pmpeixoto2010','pmpeixoto@gmail.com','Pedro Peixoto','Edificio Jardim, Rua da Venteira nº5 3ºpiso','Amadora','','PORTUGAL','2700-841','(+351)963043152','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-30 17:06:08',0,NULL,3,1,2,1,NULL,'pmpeixoto2010'),(15635,718274945018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','haff32','janingar@gmail.com','Jan Ingar Grindheim','Gjøas Vei 44','Bergen','','NORWAY','5067','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 20:50:54',0,NULL,3,1,2,1,NULL,'haff32'),(15636,759573603002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cmcc87320','luminousdesigns@hotmail.com','Courtney McConnell','190 Broadway Street<br>Apt 5','Woodstock','NB','CANADA','E7M6B3','(506) 612-1086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 21:14:02',0,NULL,3,1,2,1,NULL,'cmcc87320'),(15637,719225741018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',3,'AD1169',19.2,'photographyacc','filip2853','filipvanderheyden@telenet.be','Filip Vanderheyden','Herenstraat 22','Genk','','BELGIUM','3600','0478-626232','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 21:54:58',0,NULL,3,1,2,1,NULL,'filip2853'),(15638,719232289018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','jamso123456','janmarius@hotmail.com','Jan M Opsahl','J.Falkbergetsvei 16','Notodden','Telemark','NORWAY','3681','+47 35013929','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 22:15:29',0,NULL,3,1,3,1,'RA184552666CN\r ','jamso123456'),(15639,774699169017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','dmitryflare','dim-on@bk.ru','Dmitry Shulzhenko','Pionerskaya 17, flat 27','Novorossiysk','RU','RUSSIAN FEDERATION','353925','(918)434-3330','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-30 22:36:37',0,NULL,3,1,2,1,NULL,'dmitryflare'),(15640,717603537001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','oeewuk','khulifish@yahoo.co.nz','Daniel Croft','2 Bridgman Rd','Te Awamutu','Waikato','NEW ZEALAND','3800','02102474881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 22:47:20',0,NULL,3,1,2,1,NULL,'oeewuk'),(15641,717605168001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','altairtair1980','altairtair@gmail.com','Andrey Solomatin','Dzerjinskogo st. 2-70','Izhevsk','','RUSSIAN FEDERATION','426050','83412445172','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-30 22:53:25',0,NULL,3,1,3,1,'RA184552737CN\r ','altairtair1980'),(15642,717614670001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','stacey.leth','stacey.leth3@gmail.com','Stacey Leth','7 Jillian dr','Waitakere','Auckland','NEW ZEALAND','0612','0064-(09)9485353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-30 23:48:25',0,NULL,3,1,2,1,NULL,'stacey.leth'),(15643,717622160001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','denisdkan','disens@ukr.net','Denis Davidov','Dneprovskie porogi 25, kv.165','Zaporozhie','','UKRAINE','69096','+380991452523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-31 00:05:45',0,NULL,3,1,3,1,'RA184552745CN\r ','denisdkan'),(15644,759638149002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','danilocarneiro','dan.carneiro.d@gmail.com','Danilo Rosa Carneiro','Rua Estela, 22/408<br>Vila Mariana','São Paulo','São Paulo','BRAZIL','04011-000','55 11 83412343','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 01:09:32',0,NULL,3,1,3,1,'RA184552683CN\r ','danilocarneiro'),(15645,8881314754467079,111,'红头灯 x 4， 800w 220v x5',4,'AKT055',0,'hermeshine','baz-may','baz-studio@hotmail.com','amata ','wattachackwinibat47. Soi Ladkrabang 18 Ladkrabang Rd.','Ladkrabang','Bangkok','THAILAND','10520','',NULL,NULL,NULL,'2011-08-31 01:34:27',0,NULL,3,1,6,1,'EE645685372CN ','红头灯  4\r800w 的灯泡 10个吧， 220v的 \r放4个欧转美标头\r实重8.7   抛重13'),(15646,0,260840970889,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',0.55,'hutongstore','successful_bidder','sold@hotmail.com.au','Kenny Chow','2/1 Norman Street','Allawah','New South Wales','AUSTRALIA','2218','0411048048','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-31 02:23:38',0,NULL,3,1,2,1,NULL,'successful_bidder'),(15647,719300032018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','e2e99','ericbro@bell.net','eric brophy','267 mcleod','chateauguay','QC','CANADA','j6j 2h5','(514) 942-0873','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 02:39:25',0,NULL,3,1,3,1,'RA184552723CN\r ','e2e99\r已入库'),(15648,8881314758757922,111,'2m灯架底座 x 1',1,'',0,'hutongstore','snep1968','frankjoansierra@gmail.com','Núria Llorca Altirriba','Calle Mayor, 67 3º 2ª','Castelldefels','Barcelona','SPAIN','08860','',NULL,NULL,NULL,'2011-08-31 02:45:57',0,NULL,3,1,3,1,'RA184552697CN\r ',NULL),(15649,719307251018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','joshrodgers1992','livefortoday92@gmail.com','Josh Rodgers','18 sellen court <br>leeming','Perth','Western Australia','AUSTRALIA','6149','0893103538','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 03:10:18',0,NULL,3,1,4,1,'YW867472106CN ','joshrodgers1992'),(15650,717666409001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','titovserg','zao_izolyator@mail.ru','Titov Sergei','Sovetskaya 83 - 29','Irkutsk','','RUSSIAN FEDERATION','664009','(902)5781027','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 03:15:18',0,NULL,3,1,2,1,NULL,'titovserg'),(15651,717666482001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','alaflon','alain.schwarzstein@wanadoo.fr','ALAIN SCHWARZSTEIN','LAVERGNE','PAULHIAC','Aquitaine','FRANCE','47150','0608948783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 03:15:46',0,NULL,3,1,2,1,NULL,'alaflon'),(15652,8881314760912164,111,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',80,'aliexpress','1004201309','tanz.fly@libero.it','nicola tanzella	','via nicoli 56 c/o bar nicoli','modena','mo','ITALY','41126','+39 328 2123785',NULL,NULL,NULL,'2011-08-31 03:21:52',0,NULL,3,1,4,1,'c',''),(15653,717670048001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','sbenson2409','shawna.wallace1@gmail.com','Shawna Benson','Box 545<br>#3 Poplar Close','Erskine','AB','CANADA','T0C1G0','(403) 742-8658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 03:32:49',0,NULL,3,1,2,1,NULL,'sbenson2409'),(15654,844084488015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','bigbloke89','martinscott1969@hotmail.com','martin scott','80 mainholm rd','ayr','South Ayrshire','UNITED KINGDOM','KA80QB','01292290813','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-08-31 04:56:18',0,NULL,3,1,3,1,'RA184585409CN ','bigbloke89'),(15655,759696662002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',5,'AKT067',49.5,'hermeshine','budda001','isaev.foto@gmail.com','Jastrebov Dmitry Nikolaevich','Molodejny d.28 kv.48','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:52:33',0,NULL,3,1,17,0,NULL,'budda001'),(15656,759696334002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',5,'AA1310',27.45,'hermeshine','budda001','isaev.foto@gmail.com','Jastrebov Dmitry Nikolaevich','Molodejny d.28 kv.48','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:52:33',0,NULL,3,1,17,0,NULL,'budda001'),(15657,717692313001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','budda001','isaev.foto@gmail.com','Jastrebov Dmitry Nikolaevich','Molodejny d.28 kv.48','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:52:34',0,NULL,3,1,17,0,NULL,'budda001'),(15658,826552022016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','apinthesky','lexapakin@yahoo.com','Alexey Pakin','prospekt Korolyova d.11g kv.51','Korolyov','Moskovskaya oblast\'','RUSSIAN FEDERATION','141077','8-926-4807941','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 06:15:09',0,NULL,3,1,2,1,NULL,'apinthesky'),(15659,759696525002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',8,'AA2203',28,'hermeshine','budda001','isaev.foto@gmail.com','Jastrebov Dmitry Nikolaevich','Molodejny d.28 kv.48','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 05:52:34',0,NULL,3,1,3,1,'RA184553009CN\r ','budda001\rlenspen   10\r气吹    5\r布   5\r麂皮   2\rsony 红外遥控  8'),(15660,8881314773100263,111,'lenspen x 2',2,'AA1310',0,'hermeshine','burgmanlover','serdardikdik@gmail.com','serdar dikdik','turunc 1 mahallesi 2.Sokak No:3<br>Zekeriyakoy SARIYER','ISTANBUL','SARIYER','TURKEY',' 34450','00905323621226',NULL,NULL,NULL,'2011-08-31 06:45:00',0,NULL,3,1,2,1,NULL,NULL),(15661,774830668017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',2,'AC1201',7.98,'photographyacc','mr_demandante','dominic_demandante@y7mail.com','Dominic Demandante','Unit 1, Number 13<br>Mason Street','Reservoir','Victoria','AUSTRALIA','3073','0390771023','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 07:13:21',0,NULL,3,1,2,1,' ','mr_demandante'),(15662,759717346002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','j00be','joope.erkkila@gmail.com','Waltteri Erkkilä','Varikonkatu 18 C','Sastamala','','FINLAND','38210','+358505714824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 07:43:34',0,NULL,3,1,3,1,'RA184552860CN\r ','j00be'),(15663,0,260840970527,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',1.23,'hutongstore','pcmadjacob','jacobwood15@hotmail.co.uk','Jacob wood','36 princes end<br>dawley bank','telford','West Midlands','UNITED KINGDOM','tf42jw','07922137442','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 07:50:11',0,NULL,3,1,2,1,NULL,'pcmadjacob'),(15664,0,260840970470,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',0.31,'hutongstore','16058','barrieforbes@hotmail.co.uk','Barrie Forbes','4 Elmway','Chester-le-Street','Durham','UNITED KINGDOM','DH22LD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 08:05:18',0,NULL,3,1,2,1,NULL,'16058'),(15665,826588003016,260810104926,'New 35\" 90cm Studio Flash Reflective Umbrella Softbox',1,'AD1127',13.9,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK<br>Syntagma','ATHENS','Greece','GREECE','10557','+306972999050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 08:40:26',0,NULL,3,1,17,0,NULL,'greeceathens'),(15666,844138964015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK<br>Syntagma','ATHENS','Greece','GREECE','10557','+306972999050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 08:43:00',0,NULL,3,1,3,1,'RA184552900CN\r ','greeceathens\r反光伞棚90cm    1\r45w 220v   2'),(15667,0,250879671292,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',1.51,'hutongstore','robevell','cutelove89@hotmail.com','Kyle Zammit','63, \'Arc-En-Ciel\'<br>Bastion Street','Fgura','Europe','MALTA','FGR 1246','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-31 08:45:32',0,NULL,3,1,2,1,NULL,'robevell'),(15668,717728542001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','mr_tango','tangeros@yandex.ru','Dmitry O Mayorov','Shokalskogo pr-d, 1-1-22','Moscow','RU','RUSSIAN FEDERATION','127221','7(916)6834953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 08:54:23',0,NULL,3,1,3,1,'RA184585046CN\r ','mr_tango'),(15669,759747499002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','kot_kaskelen','atckot@gmail.com','Konstantin Klevin','Almaty region.Kaskelen town.Tuyakbaeva 12','Almaty','KZ','KAZAKHSTAN','040900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 09:56:12',0,NULL,3,1,2,1,NULL,'kot_kaskelen'),(15670,774873005017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','julia_worrall','julia_worrall@hotmail.com','Julia Worrall','4  Highview  Pde','Hamlyn Heights','Victoria','AUSTRALIA','3215','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 10:16:41',0,NULL,3,1,2,1,NULL,'julia_worrall'),(15671,774875113017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','dalv086','grigore_v@yahoo.com','Vlad Grigore','189 Hampton Square<br>Navan Road','Dublin','Dublin','IRELAND','7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 10:18:13',0,NULL,5,0,18,0,NULL,'dalv086'),(15672,774876938017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','ingmauricio211','ingmauricio2@hotmail.com','HERNAN MAURICIO MUÑOZ MARQUEZ','131 DOUGLAS AVE','SOUTH PERTH','Western Australia','AUSTRALIA','6151','0430038169','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 10:24:32',0,NULL,3,1,2,1,NULL,'ingmauricio211'),(15673,774871223017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',23.99,'photographyacc','pippa9489','pippa.daines@gmail.com','c/o Mrs J Robinson','29/3 Fern Street<br>Enoggera','Brisbane','Queensland','AUSTRALIA','4051','0405401798','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-08-31 10:28:24',0,NULL,3,1,4,1,'YW867471815CN ','pippa9489'),(15674,717756572001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rphoto11','ishrod@gmail.com','Ishai Rodríguez Rodríguez','C/ Lugo y Herrera Nº8, Bajo 7, La Laguna, Santa Cruz de Tenerife','La Laguna','Canarias','SPAIN','38320','651117974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 10:50:29',0,NULL,3,1,3,1,'RA184552887CN\r ','rphoto11'),(15675,0,110733663616,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.4,'hermeshine','tinedl85','tine_dl@hotmail.com','Tine Malterudbakken','Sildreveien 34a','Tønsberg','Tønsberg','NORWAY','3123','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 10:54:12',0,NULL,3,1,2,1,NULL,'tinedl85'),(15676,774896720017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','redpooka77','timwebster_au@yahoo.com','Timothy Webster','154 High Street Road, Ashwood','Melbourne','Victoria','AUSTRALIA','3147','0398071311','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 11:32:24',0,NULL,3,1,2,1,NULL,'redpooka77'),(15677,0,260840970690,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.04,'hutongstore','goldrunner9k','alec_griffiths@ntlworld.com','Alec Griffiths','40 Moss side road, cadishead','manchester','Greater Manchester','UNITED KINGDOM','M445JJ','07912782241','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 11:39:48',0,NULL,3,1,2,1,NULL,'goldrunner9k'),(15678,719412378018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',39.8,'photographyacc','dimusha','info@svetlana51.ru','Dmitriy Rohmistrov','ul. Komarova, d. 23 kv. 13','Monchegorsk','Murmanskaya oblast','RUSSIAN FEDERATION','184510','+7921 7253908','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 11:18:51',0,NULL,3,1,3,1,'RA184552825CN\r ','dimusha'),(15679,844201135015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','moderno_ok','bartoszoch@wp.pl','Bartosz Och','flat 5<br>5-7 South Street','Romford','Essex','UNITED KINGDOM','RM1 1NJ','07825707722','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 12:02:56',0,NULL,3,1,2,1,NULL,'moderno_ok'),(15680,759781451002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','santigariba','santigariba@gmail.com','Santiago García - ONBIQUO S.L.','C/ Santiago de Compostela, 60<br>Local Interior Lateral','Madrid','Madrid','SPAIN','28034','911286025','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:09:16',0,NULL,3,1,2,1,NULL,'santigariba'),(15681,774909490017,270748510647,'NIB TianYa Gradual Blue Color Filter for Cokin P series',1,'AA2320',12.29,'photographyacc','gcoyle78','gcoyle78@hotmail.com','Gerard Coyle','JOSS Construction<br>206 East Street','Albury','New South Wales','AUSTRALIA','2640','0409426953','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 12:15:38',0,NULL,3,1,2,1,NULL,'gcoyle78\r天涯方形滤镜  渐变蓝    1\r广角托架     1\r已入库'),(15682,0,120767278921,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',0.99,'hermeshine','jadidou57','jadeed@ebuyclub.com','samir guilli','9/75 rue de picardie','metz','Lorraine','FRANCE','57070','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 12:28:14',0,NULL,3,1,2,1,NULL,'jadidou57'),(15683,759796018002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','+79232892744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:03:50',0,NULL,3,1,5,1,'CP227167557CN ','zenitar16'),(15684,8881314796210419,111,'115W 220V  X   2',1,'AKT049',0,'hutongstore','lionhart9990','comeupandseem6@hotmail.com','Brian  Lyons','Flat 19<br>47 Cherrywood Close','London','London','UNITED KINGDOM','E3 2DQ','02089833965',NULL,NULL,NULL,'2011-08-31 13:10:10',0,NULL,3,1,3,1,'RA184552811CN\r ',' 115w   220v   2\r45w   220v    2'),(15685,844227713015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','anteroxoulu','anterox_oulu@hotmail.com','Anssi Mietinen','Kurjenpolvi 1 i 3','Oulu','OU','FINLAND','90580','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 13:11:17',0,NULL,3,1,2,1,NULL,'anteroxoulu'),(15686,844228631015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','peyskens2005','badboys0071@hotmail.com','Bertrand Cédric','Rue de la vallée<br>48','Hannut','','BELGIUM','4280','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 13:13:47',0,NULL,3,1,4,1,'YW867471826CN ','peyskens2005\r欧标'),(15687,717796129001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','petersandqvist','peter.sandqvist@umea.riksnet.se','Peter Sandqvist','Radjursvagen 95 B','Umea','Vasterbotten','SWEDEN','90643','0704528901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:14:18',0,NULL,3,1,17,0,NULL,'petersandqvist'),(15688,759800662002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','petersandqvist','peter.sandqvist@umea.riksnet.se','Peter Sandqvist','Radjursvagen 95 B','Umea','Vasterbotten','SWEDEN','90643','0704528901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:14:19',0,NULL,3,1,17,0,NULL,'petersandqvist'),(15689,759800663002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','petersandqvist','peter.sandqvist@umea.riksnet.se','Peter Sandqvist','Radjursvagen 95 B','Umea','Vasterbotten','SWEDEN','90643','0704528901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:14:20',0,NULL,3,1,17,0,NULL,'petersandqvist'),(15690,759800664002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','petersandqvist','peter.sandqvist@umea.riksnet.se','Peter Sandqvist','Radjursvagen 95 B','Umea','Vasterbotten','SWEDEN','90643','0704528901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 13:14:21',0,NULL,3,1,5,1,'CP227167565CN ','petersandqvist\r单灯头 欧标    2\r柔光伞     2\r灯架  2m    2\r反光伞    1\rB座     1'),(15691,844229760015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','ggrbld','gabri.garibaldi@virgilio.it','Gabriele Garibaldi','Via della rosa, 37','Viareggio','LU','ITALY','55049','0584-942292','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 13:16:27',0,NULL,3,1,2,1,NULL,'ggrbld'),(15692,0,260840970758,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',0.95,'hutongstore','snookaman','sculptordavid@sky.com','David T Lyttleton','65 Durham Drive<br>Lightwood','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST3 4TG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 13:17:44',0,NULL,3,1,2,1,NULL,'snookaman'),(15693,843029900015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','darmstadt1976','aliirawan@yahoo.de','Ilham Futuh Rohman','Jln. Merak no.9<br>Cakranegara Barat - Mataram','Lombok - Indonesia','','GERMANY','83231','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-08-31 13:54:21',0,NULL,3,1,6,1,'EE645685580CN ','darmstadt1976\r新地址：\rReceiver Name: Ilham Futuh Rohman\rStree: Jln. Merak no.9 Cakranegara Barat\rCity: Mataram\rState/Province: Lombok\rCountry: Indonesien\rZip code: 83231\rPhone #: (+62) 81808255366'),(15694,717810677001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','bhatkir989','bhatkir@gmail.com','Kiran Bhat','3931 E Patrick Rd','Midland','MI','UNITED STATES','48642-6501','(989) 941-8324','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-08-31 14:02:19',0,NULL,3,1,1,1,NULL,'bhatkir989'),(15695,717816469001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','videodslr','videoallf@gmail.com','ALEKSEY BOGATOV','Presnenskiy Val 8-2-141','Moscow','','RUSSIAN FEDERATION','123022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-08-31 14:20:05',0,NULL,3,1,3,1,'RA184552839CN\r ','videodslr'),(15696,719478560018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','kinjal75','kinjal75@yahoo.com','MR KINJAL SHAH','35 NORVILLE ST','BENTLEIGH EAST','Victoria','AUSTRALIA','3165','0400404949','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 14:49:05',0,NULL,3,1,2,1,NULL,'kinjal75'),(15697,0,250879671623,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',1,'AA1309',0.82,'hutongstore','mr.edzas','jakaitis.valdas@gmail.com','Valdas Jakaitis','Zukausko 43-30','Vilnius','','LITHUANIA','09130','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-31 15:05:38',0,NULL,3,1,2,1,NULL,'mr.edzas'),(15698,844272453015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','awwrispekt','awwrispek@me.com','Adam Knowles','14 Mavis Avenue','Leeds','West Yorkshire','UNITED KINGDOM','LS16 7LJ','07850030594','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 15:09:53',0,NULL,3,1,2,1,NULL,'awwrispekt'),(15699,719505067018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','philippe-vert','philippe.dermine@gmail.com','Philippe Dermine','ISABEL SA<br>13-15 Bvd de l\'Impératrice','Bruxelles','','BELGIUM','1000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 16:01:21',0,NULL,3,1,3,1,'RA184585050CN\r ','philippe-vert\r已入库'),(15700,719507816018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','dreampetrucci','hetfield_heritage@hotmail.it','Emiliano Pedruzzi','Via Gennaro Cassiani n°106','Roma','RM','ITALY','00155','064076200','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 16:07:35',0,NULL,3,1,2,1,NULL,'dreampetrucci'),(15701,759860257002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','yefim_f','170161@gmail.com','Yefim Fefer','1 Gadera st, apt 24','Petah Tikva','center','ISRAEL','49724','+972 52 6132451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 16:11:55',0,NULL,3,1,2,1,NULL,'yefim_f\r欧标'),(15702,0,260840970646,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',0.11,'hutongstore','aguamanza','juancalvarado@gmail.com','JUAN CARLOS ALVARADO OÑATE','Calle Reyes Católicos No. 64 Piso 2, Puerta 3','Gandia','Comunidad Valenciana','SPAIN','46702','617773332','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-08-31 16:18:18',0,NULL,3,1,2,1,NULL,'aguamanza'),(15703,843816869015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',8.48,'hutongstore','chrisbusker','chris_busker@yahoo.co.uk','chris bussicott','221 The Street','W Horsley','Surrey','UNITED KINGDOM','KT24 6HP','07772859492','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 16:34:48',0,NULL,3,1,2,1,NULL,'chrisbusker\rcanon 58 镜头盖  2\r58cm 遮光罩    1\r中号镜头筒    1\r已入库'),(15704,719538282018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','kjulioromano','marco@kjulio.net','Marco Romano','via Circonvallazione 16','Desenzano del Garda','BS','ITALY','25010','+393396589731','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 17:26:23',0,NULL,3,1,3,1,'RA184585179CN ','kjulioromano'),(15705,717910070001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','joe66622','j.bill@nexgo.de','MHV- GmbH, A.Overath (persönlich)','Herforder Str.45 (Badehaus 1)','Bad Oeynhausen','','GERMANY','32545','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 18:24:47',0,NULL,3,1,3,1,'RA184585196CN ','joe66622'),(15706,759948280002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','grippovich','orz@pochta.ru','Pavel Shestakov','Shkolnaya 1/2, 56','Khimki','mkr Podrezkovo','RUSSIAN FEDERATION','141431','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 19:29:23',0,NULL,3,1,2,1,NULL,'grippovich'),(15707,759979210002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','zoharbartuv','zoharbt@gmail.com','zohar bartuv','kvutzat yavne','kvutzat yavne','','ISRAEL','79233','97288548235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 20:38:52',0,NULL,3,1,17,0,NULL,'zoharbartuv'),(15708,759979932002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','zoharbartuv','zoharbt@gmail.com','zohar bartuv','kvutzat yavne','kvutzat yavne','','ISRAEL','79233','97288548235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 20:38:51',0,NULL,3,1,3,1,'RA184552958CN\r ','zoharbartuv\r2B柔         1   \r沙袋（普通）     2'),(15709,0,260840970905,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',3.19,'hutongstore','edd709','ed.diamond@btopenworld.com','Ed Dimond','67 Old Kiln Road<br>Upton','Poole','Dorset','UNITED KINGDOM','BH16 5SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-08-31 20:55:59',0,NULL,3,1,2,1,NULL,'edd709'),(15710,719645344018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','jungeun111','heatal111@hotmail.com','jungeun lee','seranails 2864-b main st','glastonbury','CT','UNITED STATES','06033','(203) 500-1104','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 21:11:27',0,NULL,3,1,1,1,NULL,'jungeun111'),(15711,719657966018,280675886404,'18% Gray Cards 10x8\"& 8x6\" for White balance exposure L',1,'AA2218',13.9,'photographyacc','demeterlaquesis','javiermazzeo2002@yahoo.com.ar','Javier Mazzeo','c/ Hospital   Nº 12','Banyoles','Cataluña','SPAIN','17820','661994147','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-08-31 21:28:15',0,NULL,3,1,2,1,NULL,'demeterlaquesis'),(15712,775158046017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','lies_8','lies_8@hotmail.com','Liesl Sexton','37 Poplar Ave','Traralgon','Victoria','AUSTRALIA','3844','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 21:50:05',0,NULL,3,1,2,1,NULL,'lies_8'),(15713,775172559017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','hannazac','bjw@charterfreight.com.au','Brian Williams','Charter Freightlines<br>324 New Cleveland Road','Tingalpa','Queensland','AUSTRALIA','4173','0738901010','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-08-31 22:33:47',0,NULL,3,1,2,1,NULL,'hannazac'),(15714,760024674002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','inmunerfm2','inmunerfm@hotmail.com','ruben fernandez moreno','c/autonomia nº14 2ºd','basauri','País Vasco','SPAIN','48970','944261181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 22:44:30',0,NULL,3,1,2,1,NULL,'inmunerfm2'),(15715,718025431001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','dibrubel','didier.belrose@gmail.com','Didier BELROSE','BP 43801 FARE TONY - VAIETE','Papeete','Tahiti','FRENCH POLYNESIA','98713','0 689 77 99 21','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-08-31 23:25:01',0,NULL,3,1,3,1,'RA184552895CN\r ','dibrubel'),(15716,719710442018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','kmr1au','kristalm.robinson@gmail.com','kristal robinson','9 Oman Pl','Calwell','Australian Capital Territory','AUSTRALIA','2905','0431073100','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 00:25:07',0,NULL,3,1,3,1,'RA184552873CN\r ','kmr1au'),(15717,719723119018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',1,'AD1170',8.99,'photographyacc','www_ranmamusic_com','david@the-crawfords.com','David Crawford','492 Little Brule Rd.','Warren','ON','CANADA','P0H 2N0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-01 01:38:41',0,NULL,3,1,2,1,NULL,'www_ranmamusic_com'),(15718,718078673001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','jchengliu','liujecheng@hotmail.com','jiacheng Liu','569B Prospect St','New Haven','CT','UNITED STATES','06511-2150','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-01 03:16:52',0,NULL,3,1,1,1,NULL,'jchengliu'),(15719,8881314850252582,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush ',24,'AA1310',111.21,'aliexpress','1004211289','cristiano.orlando@hotmail.com','Cristiano Orlando	','Rua Ernesto dos Santos,110','Sao Paulo	','SP,','BRAZIL','03225000','+55 11 28251318',NULL,NULL,NULL,'2011-09-01 04:10:52',0,NULL,3,1,3,1,'RA184585085CN ',NULL),(15720,719764244018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','glapeyre_pc','glapeyre@aanet.com.au','Greg Lapeyre','28 Lakeside Drive','Point Cook','Victoria','AUSTRALIA','3030','0393953743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 04:21:43',0,NULL,3,1,3,1,'RA184585063CN ','glapeyre_pc'),(15721,718094951001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','dazz01daryl','daryl.op.u@xtra.co.nz','Daryl Zuppicich','88 Avenue Road<br>Westend','Timaru','South Canterbury','NEW ZEALAND','7910','03 6844657','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 04:50:35',0,NULL,3,1,3,1,'RA184585077CN ','dazz01daryl\r已入库'),(15722,8881314853316444,111,'一堆（详见notes）',0,'',324,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-01 05:01:56',0,NULL,3,0,12,1,'BJ8826413 ','2m 灯架 *4\r柔光箱 60-60cm  四灯头（60x60的棚） *4\r45w 5500k 灯泡 110v *9\r灯架包 *2\r铜芯配件 * 1  (已入库）\r实重 10.4  抛重12.2\rDHL:5241696320   最终计费泡重： 12'),(15723,718092559001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','kewpie_tarako','pochogo@gmail.com','Karin Gildemeister Burgos','Monjitas 451 Depto. 804','Santiago','Metropolitana','CHILE','8320083','92176989','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 05:40:50',0,NULL,3,1,3,1,'RA184585103CN ','kewpie_tarako'),(15724,775280179017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','shanebolger82010','shanebolger8@yahoo.com.au','shane bolger','36 patrol street','jamboree heights','Queensland','AUSTRALIA','4074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 06:13:31',0,NULL,3,1,3,1,'RA184585094CN ','shanebolger82010'),(15725,760149442002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','djmarinov','lz3dj@vip.bg','Dinko Marinov','Musagenitsa, bl. 95, vh.B, ap.26','Sofia','Sofia','BULGARIA','1797','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 08:26:10',0,NULL,3,1,2,1,NULL,'djmarinov'),(15726,718127559001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',2,'AB1203',16,'hermeshine','bogybog','bogdahn@gmail.com','Antoine Bardet','23, rue du luxembourg','haubourdin','Nord-Pas-de-Calais','FRANCE','59320','0320507577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 07:58:53',0,NULL,3,1,2,1,NULL,'bogybog'),(15727,718135598001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','evushok','evusho@mail.ru','Eva Hayrapetyan','20 Arzumanyan str., apt# 37','Yerevan','','ARMENIA','0099','0037491193004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 08:39:11',0,NULL,3,1,2,1,NULL,'evushok\r'),(15728,775311813017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','zebchapman','chapman-99@hotmail.com','zeb chapman','5 ALLAMBIE PLACE','moree','New South Wales','AUSTRALIA','2400','0415629098','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 08:48:29',0,NULL,3,1,2,1,NULL,'zebchapman'),(15729,760160465002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','alonetix','alonet@yandex.ru','Vadim Borisov','Pershutova str. 35/1-14','Kovrov','Vladimirskaya obl','RUSSIAN FEDERATION','601902','+79101747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 09:21:14',0,NULL,3,0,3,1,'RA184585386CN\r ','alonetix\r1.6*3 绿色背景布  1'),(15730,8881314869925955,111,'450D 眼罩  x   1',1,'AA1201',0,'photographyacc','vitabella68','vitatalmont@gmail.com','Vita Talmont','12 Ferris St','Ermington','New South Wales','AUSTRALIA','2115','0288108136',NULL,NULL,NULL,'2011-09-01 09:38:45',0,NULL,3,1,2,1,NULL,NULL),(15731,718148933001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','plant305','plantmo@bigpond.com','Norman Plant','30 Henry Sutton Cct<br>Dunlop','Canberra','Australian Capital Territory','AUSTRALIA','2615','0262595662','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 09:40:02',0,NULL,3,0,3,1,'RA184585267CN ','plant305\rXXXL   (已入库）'),(15732,775330134017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','dave_abernethy','dave_abernethy@hotmail.com','david abernethy','PO BOX 157 ','balhannah','South Australia','AUSTRALIA','5242','0883914162','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 10:13:15',0,NULL,3,1,2,1,NULL,'dave_abernethy'),(15733,718168057001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.8,'hermeshine','vitaliyukr','27poltava@mail.ru','Vitaliy Nazarenko','Borovikovskogo 9-85','Poltava','','UKRAINE','36023','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 11:01:26',0,NULL,3,1,5,1,'CP227167588CN ','vitaliyukr'),(15734,718178629001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',2,'AO0011',159.98,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sadeq tawfeek','Qatif','Qatif','Taruot','SAUDI ARABIA','31911','96640616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 11:45:35',0,NULL,3,1,8,1,'CP2271675 74CN','tawfeekmohammed'),(15735,719863058018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','reneegracehodder','renee.grace@hotmail.com','Renee G Hodder','22 Carnegie st','Westlake','Queensland','AUSTRALIA','4074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 12:07:55',0,NULL,3,1,3,1,'RA184585298CN ','reneegracehodder'),(15736,719865597018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','owenzhang90','owenzhang@rocketmail.com','Wensheng Zhang','3/7 Walter St<br>Cranbourne','Melbourne','Victoria','AUSTRALIA','3977','0395853144','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-01 12:27:19',0,NULL,3,1,3,1,'RA184585253CN ','owenzhang90'),(15737,760215976002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','george_su','georgesu0@gmail.com','George Su','2700 Bathurst St<br>Apt 610','North York','ON','CANADA','M6B 2Z7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:04:44',0,NULL,3,1,2,1,NULL,'george_su'),(15738,760222518002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','+33 622632539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:27:01',0,NULL,3,1,3,1,'RA184585372CN ','boyadjy\r我算了  运费相差两元钱 '),(15739,718206758001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',59.98,'hermeshine','robertp4855','r.poplawski@bleu-media.ch','Robert Poplawski','vieux chalet 21','La Tour-de-Trême','','SWITZERLAND','1635','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:27:32',0,NULL,3,1,3,1,'RA184585324CN ','robertp4855\r10个'),(15740,827205672016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jam-dk','jan.madsen@adslhome.dk','Jan Madsen','Torvevangen 24','Asnaes','DK','DENMARK','4550','0045 22827720','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-01 13:33:04',0,NULL,3,1,2,1,NULL,'jam-dk'),(15741,718215207001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','francodesiderio','diving.dept@hotmail.it','DAVINCI Srl','Cso. Umberto I, 391','Montesilvano','PE','ITALY','65015','0854483014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 13:57:29',0,NULL,3,1,2,1,NULL,'francodesiderio\r新地址\rMario Desiderio \rc/o DAVINCI Srl Cso. Umberto I, 391 \r Montesilvano PE 65015\r Italia'),(15742,718255577001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','lexeich','alex_meln@mail.ru','Melnikov Alexey','Krasnoarmeyskaya<br>107 b - 1','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424020','89278831566','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 16:03:24',0,NULL,3,1,3,1,'RA184585236CN ','lexeich'),(15743,718267588001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rphoto11','ishrod@gmail.com','Ishai Rodríguez Rodríguez','C/ Lugo y Herrera Nº8, Bajo 7, La Laguna, Santa Cruz de Tenerife','La Laguna','Canarias','SPAIN','38320','651117974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 16:36:37',0,NULL,3,1,3,1,'RA184585165CN ','rphoto11'),(15744,760291910002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','2009eeandrey','eeandrey@gmail.com','Andrey Ezhov','20-13 Grajdanskaya street','Velikie Lyki','RU','RUSSIAN FEDERATION','182100','+79113699908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 17:02:57',0,NULL,3,1,2,1,NULL,'2009eeandrey'),(15745,760285888002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','the-laird','jmmontgo@comcast.net','James Montgomery','300 Mountain Creek Trce NW','Atlanta','GA','UNITED STATES','30328-3522','(404) 255-6563','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 16:46:12',0,NULL,3,1,1,1,NULL,'the-laird\r已入库'),(15746,760303473002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','kmanely','radiatorman@gmail.com','Keenan Manely','1405 Aberdeen Dr','San Mateo','CA','UNITED STATES','94402-1902','(650) 573-5568','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-01 17:32:08',0,NULL,3,1,1,1,NULL,'kmanely'),(15747,718305610001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',2,'AE2201',75.98,'hermeshine','laplantafer','laplantafer@hotmail.com','Fernando Uribe','4601 Garden Point Trl','Wellington','FL','UNITED STATES','33414-7423','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-01 18:10:50',0,NULL,3,1,4,1,'YW867472062CN ','laplantafer\r发60x60的棚'),(15748,760321598002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','lirvadsa','lirvad@gmail.com','Davril Roman','2 LANGEMERE STREET<br>NORTHPINE','BRACKENFELL','WESTERN-CAPE','SOUTH AFRICA','7560','(27) 73 311-8574','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 18:17:17',0,NULL,3,1,3,1,'RA184585284CN ','lirvadsa'),(15749,760338111002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','1jomi','casanovabelles@hotmail.com','ALBERTO CASANOVA BELLES','Avda. Goles de l\'Ebre, 187 (B.Popular)','Deltebre (TARRAGONA)','Cataluña','SPAIN','43580','655279575','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 18:51:40',0,NULL,3,1,3,1,'RA184585222CN ','1jomi'),(15750,844936052015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','eclomaxkiwi','mikewilcoxxx@yahoo.co.uk','Mike Wilcox','11 Milestone Crescent<br>Charvil','READING','Berks','UNITED KINGDOM','Rg10 9RG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 19:39:31',0,NULL,3,1,2,1,NULL,'eclomaxkiwi'),(15751,827386511016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','barton2548','gazbart@live.co.uk','gary barton','21 arundel walk<br>harworth','doncaster','South Yorkshire','UNITED KINGDOM','dn11 8qy','01302746215','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-01 19:50:50',0,NULL,3,1,4,1,'YW867472073CN ','barton2548\r英标'),(15752,718352357001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',1,'AA3222',45.9,'hermeshine','achystyakov','randorando@gmail.com','Arsenii Chystiakov','Zoryana 23','Lviv','Lvivs\'ka','UKRAINE','79054','+380967816537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 19:55:31',0,NULL,3,1,3,1,'RA184585355CN ','achystyakov'),(15753,760371314002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kirli35','kirlisakal_izmir@hotmail.com','baki bingül','222 Sokak No:10/A   Üçkuyular/ Buca','İzmir','','TURKEY','35390','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 20:09:21',0,NULL,3,1,3,1,'RA184585219CN ','kirli35'),(15754,844989779015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','tl1000rdavid','davehousam@hotmail.co.uk','david Housam','15 Greenhill Chase<br>Wortley','Leeds','West Yorkshire','UNITED KINGDOM','LS12 4HF','01132796716','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 21:23:57',0,NULL,3,1,2,1,NULL,'tl1000rdavid'),(15755,718392109001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 21:35:29',0,NULL,3,1,17,0,NULL,'sinlightpictures'),(15756,718392069001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-01 21:35:30',0,NULL,3,1,3,1,'RA184585338CN ','sinlightpictures\r出了c 里面的再发如下\r方形滤镜接口环 67mm    1\r方镜普通托架（三槽）    1'),(15757,845016373015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','danos.pres','dan.preston@ntlworld.com','Dan Preston','5 Cole Ness Road','Ipswich','Suffolk','UNITED KINGDOM','IP3 0SH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-01 22:23:24',0,NULL,3,1,2,1,NULL,'danos.pres'),(15758,718408025001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','kozak_minerals','kozakminerals@gmail.com','Jaroslav Kozák','Hlaváčiková 2','Bratislava','','SLOVAK REPUBLIC','84105','+421904582108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 22:26:27',0,NULL,3,1,2,1,NULL,'kozak_minerals'),(15759,718409868001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','garupalomas','palomargarufo@hotmail.com','daniel zapater','C/ Pintor Luis Garcia  Nº 4   1ºDerecha','villena','Comunidad Valenciana','SPAIN','03400','644546268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 22:32:57',0,NULL,3,1,4,1,'YW867472084CN ','garupalomas'),(15760,718412888001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','loralaynephotos','loralaynephotography@live.ca','Jacqui Parsons','159 Henhoeffer Crescent','Kitchener','ON','CANADA','N2E 4H2','(519) 577-7078','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-01 22:46:24',0,NULL,3,0,2,1,NULL,'loralaynephotos\r1.6*2.1黑色背景布   1'),(15761,718434468001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','backslash-me','noheadlights@me.com','Carsten Senkfeil','Lampestr. 6','Hannover','','GERMANY','30449','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 00:19:12',0,NULL,3,1,3,1,'RA184585182CN ','backslash-me'),(15762,775649075017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','setojaha','az_metalboyz@yahoo.com','Wan Nurul Azhar Wan Ghazali','B-2-6 Danau Murni Cond,<br>Jln 109F Jln Desa Bakti','Taman Desa','Kuala Lumpur','MALAYSIA','58100','0172327715','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 01:04:41',0,NULL,3,1,2,1,NULL,'setojaha'),(15763,8881314927025385,111,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',0,'photographyacc','thomasang88','thomasang88@gmail.com','Thomas Ang','22/22 Herbert St','West Ryde','New South Wales','AUSTRALIA','2114','61406510234',NULL,NULL,NULL,'2011-09-02 01:30:25',0,NULL,3,1,3,1,'RA184585275CN ','上一票未收到，再发一次。 '),(15764,720144902018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','goldcan07','dwhit@skymesh.com.au','David Whitmore','2112 Tableland Road','Mount Maria','Queensland','AUSTRALIA','4674','0428415187','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 01:44:30',0,NULL,3,1,2,1,NULL,'goldcan07'),(15765,718455862001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','519stace22','stace.420@hotmail.com','Stacey Stunden','240 Burwell Rd unit 29','St.Thomas','ON','CANADA','N5P 4H1','(519) 872-5350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 01:58:08',0,NULL,3,0,3,1,'RA184585390CN\r ','519stace22\r1.6*2.1蓝色背景布  1\r1.6*2.1 粉色背景布    1'),(15766,718458880001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.9,'hermeshine','ivanhamer','ticica@gmail.com','Ivan Hamer','66 Lewis St','Toronto','ON','CANADA','M4M 2H3','(416) 898-7306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 02:07:43',0,NULL,3,1,3,1,'RA184585240CN ','ivanhamer'),(15767,718461799001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','10eagles','walkingyonv@aol.com','Charles R. Holmes','5035 Crosswood Dr','Saint Louis','MO','UNITED STATES','63129-2447','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 02:17:40',0,NULL,3,1,1,1,NULL,'10eagles'),(15768,760482079002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-02 02:26:01',0,NULL,3,1,3,1,'RA184585307CN ','mariomarques.com.br'),(15769,8881314932360069,111,'New Pro Photo Vest for all DSLR fans',1,'AA1217',24.21,'aliexpress','1004230427','point@netvision.com.br','Moacir Giacomozzi	','AV. JUSCELINO KUBITSCHECK 410','JOINVILLE','SANTA CATARINA	','BRAZIL','89201-100','+55 47 30276310',NULL,NULL,NULL,'2011-09-02 02:59:20',0,NULL,3,0,17,0,NULL,NULL),(15770,8881314932571840,111,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',33.16,'aliexpress','1004230426','point@netvision.com.br','Moacir Giacomozzi	','AV. JUSCELINO KUBITSCHECK 410','JOINVILLE','SANTA CATARINA	','BRAZIL','89201-100','+55 47 30276310',NULL,NULL,NULL,'2011-09-02 03:02:51',0,NULL,3,0,3,1,'RA184585735CN\r ','摄影背心 Canon  老款 3XL * 1\r摄影背心 夏  XL  * 1\r(已入库)\r'),(15771,720186106018,280695078945,'Aluminium Lightweight 68\" Camera Monopod with ballhead ',1,'AE1604',38,'photographyacc','dylan5326','dylanlynch82@yahoo.com.au','dylan lynch','7990 chamberlain rd','Lisarow','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 05:12:38',0,NULL,3,1,3,1,'RA184585545CN ','dylan5326'),(15772,8881314940519632,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',50,'aliexpress','1004232460','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2011-09-02 05:15:19',0,NULL,3,1,6,1,'EE645685562CN',''),(15773,718496107001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','cabmerlot99','discus69@gmail.com','Karah Edwards','10 Lake Cooloola Court','Logan Reserve','Queensland','AUSTRALIA','4133','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 05:27:37',0,NULL,3,1,2,1,' ','cabmerlot99'),(15774,760533224002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','wristy107','dc.brosnan@gmail.com','Daniel Brosnan','Unit 22<br>6 Foelsche St','Darwin','Northern Territory','AUSTRALIA','0800','610431843900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 07:22:28',0,NULL,3,1,2,1,NULL,'wristy107'),(15775,8881314953602503,111,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',0,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026',NULL,NULL,NULL,'2011-09-02 08:53:22',0,NULL,3,1,17,0,NULL,NULL),(15776,8881314953637683,111,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',0,'hermeshine','manoj11276','mkumarkt@gmail.com','Manoj Kumar','Flat No 204, Chitrakut Dham II Apartments<br>Byrasandra Main Road, CV Raman Nagar Post,','Bangalore','Karnataka','INDIA','560093','919742246026',NULL,NULL,NULL,'2011-09-02 08:53:57',0,NULL,3,1,12,1,'BJ8824614 ','第一次发货一月未到，再次补发，0902付$39.\r天涯方形滤镜  ND8     1\r方形滤镜接口环 72mm     1\r方镜普通托架（三槽）    1\r---\rDHL: 5241678783（0904被扣关）\rMs崔： 65469318'),(15777,720251412018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','mctipi','siili89@suomi24.fi','Tiko Lasola','Hansatie 4 i 99','Espoo','','FINLAND','02780','045 6305778','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 10:22:30',0,NULL,3,1,2,1,NULL,'mctipi'),(15778,720264900018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','fooey84','jnaughton80@hotmail.com','John Naughton','L7 Solutions, 14th Floor<br>256 Adelaide Tce','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 11:18:17',0,NULL,3,0,2,1,NULL,'fooey84\r1.6*2.1 白色背景布   1'),(15779,775799853017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','sickfish.2007','theraviger@hotmail.com','Aaron Scicluna','7 courageous street Taylors Lakes','melbourne','Victoria','AUSTRALIA','3038','030409094172','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 12:12:46',0,NULL,3,1,2,1,NULL,'sickfish.2007'),(15780,760221103002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','orenspl56','orenspl@mail.ru','Ilya Zverev Sergeevich','pr.Gazovikov 24<br>KB 48','Orenburg','Orenburg Area','RUSSIAN FEDERATION','460051','89619439839','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-02 11:59:33',0,NULL,3,1,3,1,'RA184585899CN\r ','orenspl56'),(15781,845255399015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',70,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-02 12:59:14',0,NULL,3,1,17,0,NULL,'leifs123'),(15782,718595700001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','krispy_fish','bittervenom@gmail.com','Christopher Roberts','MEDCO 1SB Unit 31530 (31530 South Camp)<br>USA','APO','AE','AA','09832','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 12:59:22',0,NULL,3,1,1,1,NULL,'krispy_fish'),(15783,760613229002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jjooste','jj@axxess.co.za','Johan Jooste','PO Box 2214','Beacon Bay','Eastern Cape','SOUTH AFRICA','5205','027832828820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 13:03:23',0,NULL,3,1,2,1,NULL,'jjooste'),(15784,720304907018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','greghatfield123','greg_hatfield@hotmail.com','Greg  Hatfield','4 David Close Osborne Park','Perth','Western Australia','AUSTRALIA','6017','0894436175','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 13:32:39',0,NULL,3,1,17,0,NULL,'greghatfield123'),(15785,720306735018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','greghatfield123','greg_hatfield@hotmail.com','Greg  Hatfield','4 David Close Osborne Park','Perth','Western Australia','AUSTRALIA','6017','0894436175','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 13:36:52',0,NULL,3,1,2,1,NULL,'greghatfield123\r方镜广角托架（ 一槽）   1\r方形滤镜接口环 77mm      1\r方镜广角托架（ 三槽）   1   '),(15786,720307805018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','stfn76','sprincigalli@yahoo.it','STEFANO PRINCIGALLI','viale Eretum, 8','ROMA','RM','ITALY','00131','3389012428','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 13:41:10',0,NULL,3,1,2,1,NULL,'stfn76'),(15787,718610059001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','kosselillo','kossel@gmail.com','Jose Sancho Alonso','C/ Burriana 36 Puerta 9','Valencia','Valencia','SPAIN','46005','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-02 13:47:21',0,NULL,3,1,3,1,'RA184588127CN\r ','kosselillo'),(15788,720339832018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',2,'AA2216',10,'photographyacc','wmicheld','wmichel@estatis.com.br','Walter Deringer','R ELIZEU DI BERNARDI 604 AP 1002<br>CAMPINAS','SAO JOSE','Santa Catarina','BRAZIL','88101-050','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 15:17:11',0,NULL,3,1,2,1,NULL,'wmicheld'),(15789,775863036017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','leanphotografo','leo.lopez.foco@hotmail.com','Leandro Lopez Foco','San Sebastian 3, 1º piso','Palma de Mallorca','Baleares','SPAIN','07001','660259266','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 15:21:49',0,NULL,3,1,3,1,'RA184587784CN ','leanphotografo\r是天涯的\r接口环是58mm'),(15790,718665212001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',28.5,'hermeshine','summydave','dsummerlin23@hotmail.com','David Summerlin','5350 W 20th St','Joplin','MO','UNITED STATES','64804-8048','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-02 16:37:02',0,NULL,3,1,1,1,NULL,'summydave'),(15791,720370016018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',76,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 16:41:46',0,NULL,3,1,4,1,'YW867471966CN ','brunos_92\r▲  已发信'),(15792,718668168001,110583709805,'NEW 58mm CPL+ND8+Macro+8 +Gradual grey+filter case set',1,'AKT044',25,'hermeshine','mdfpxm','xyz704-ebay@yahoo.it','Ivan Pedretti','via Pietro Leo 7','cagliari','CA','ITALY','09129','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-02 16:44:27',0,NULL,3,1,3,1,'RA184588674CN ','mdfpxm\r'),(15793,718694012001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','dlahar127488','dlahar@gmail.com','Dvir Lahar','yamit 108<br>Neve Dkalim','Rishon Le Zion','','ISRAEL','75675','(054) 807-8292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:54:10',0,NULL,3,1,2,1,NULL,'dlahar127488'),(15794,718693233001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','czjqm3','gilles.ruest@videotron.ca','Gilles Ruest','9058 rue Boivin','LaSalle','QC','CANADA','H8R2E4','(514) 366-8222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:54:53',0,NULL,3,1,17,0,NULL,'czjqm3'),(15795,718689594001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',2,'AA1308',5.2,'hermeshine','czjqm3','gilles.ruest@videotron.ca','Gilles Ruest','9058 rue Boivin','LaSalle','QC','CANADA','H8R2E4','(514) 366-8222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:54:55',0,NULL,3,1,17,0,NULL,'czjqm3'),(15796,760708403002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','czjqm3','gilles.ruest@videotron.ca','Gilles Ruest','9058 rue Boivin','LaSalle','QC','CANADA','H8R2E4','(514) 366-8222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:54:54',0,NULL,3,1,17,0,NULL,'czjqm3'),(15797,718690527001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1307',5.2,'hermeshine','czjqm3','gilles.ruest@videotron.ca','Gilles Ruest','9058 rue Boivin','LaSalle','QC','CANADA','H8R2E4','(514) 366-8222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 17:54:55',0,NULL,3,1,3,1,'RA184588135CN\r ','czjqm3\r机身盖/镜头后盖  Nikon    1\rNIKON 镜头盖 72mm     2\rNIKON 镜头盖 77mm     1\rNIKON 镜头盖 67mm    2'),(15798,775945358017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','denissokol70','sokolden@gmail.com','Denis Sokolov','festivalnaya ulitsa 17-1-78','Moscow','','RUSSIAN FEDERATION','125195','79161762004','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-02 18:45:33',0,NULL,3,1,2,1,NULL,'denissokol70'),(15799,718742999001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','lupatniece','zemcova@inbox.lv','Julija Skele','Ruses 5-15','Riga','','LATVIA','LV-1029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 19:56:53',0,NULL,3,1,2,1,NULL,'lupatniece'),(15800,718753036001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','stavrosactor','yiastav@cytanet.com.cy','Stavros Yiannakou','2, Christou Tsiarta, Parissinos-Engomi','Nicosia','','CYPRUS','2412','0035799422185','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 20:17:39',0,NULL,3,1,2,1,NULL,'stavrosactor'),(15801,827902423016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','sweetpeach892011','mschunt89@msn.com','Chimere Hunter','10143 County Road 229','Oxford','FL','UNITED STATES','34484-3955','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-02 20:33:07',0,NULL,3,1,4,1,'YW867471970CN ','sweetpeach892011\r灯泡是110v 的 \r已入库\rLighting Kit   $40'),(15802,845468532015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','0087_courtney','lac-photos@fsmail.net','Lisa Courtney','63 Charlemont Road','East Ham','London','UNITED KINGDOM','E6 6HJ','07792600087','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-02 20:44:01',0,NULL,3,1,2,1,NULL,'0087_courtney'),(15803,718770480001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','pipjt','pipjt@yahoo.co.uk','P Tyler','1 Packe Terrace<br>Main Street','Great Glen','Leicestershire','UNITED KINGDOM','LE8 9GG','01162593514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:06:55',0,NULL,3,1,2,1,NULL,'pipjt'),(15804,760787093002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','luca.eugeni','luca.eugeni@gmail.com','Luca Eugeni','Via Albani, 71<br>c/o Negozio Carola Baby','milano','Milano','ITALY','20148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:07:17',0,NULL,3,1,3,1,'RA184585718CN\r ','luca.eugeni\r Light Stand   $15'),(15805,718783558001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','hjaneiro','herlanderjaneiro@sapo.pt','Herlander  Gomes  (EDP) Electricidade de Portug','Av Antonio Farinha Pereira','Alferrarede - Abrantes','','PORTUGAL','2200','351938191060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:45:42',0,NULL,3,1,2,1,NULL,'hjaneiro'),(15806,718786378001,110454864267,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',7.89,'hermeshine','luiswan','luispad@telefonica.net','Luis Padilla','A. Almendro    78','Aljaraque','Andalucía Ceuta y Melilla','SPAIN','21110','959521424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 21:53:48',0,NULL,3,1,2,1,NULL,'luiswan'),(15807,718787950001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','alexmar2009','alexander_margolin@hotmail.com','alex margolin','P.B. 648','Nes Ziona','Israel','ISRAEL','74106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 22:01:59',0,NULL,3,1,2,1,NULL,'alexmar2009'),(15808,718806143001,110541871813,'New Benro A1691TB0 Monopod Tripod Kit Travel Angel Bag',1,'AKT033',202,'hermeshine','randomharley','kjpowell883@shaw.ca','Keith Powell','105 Rue Madelene','Beaumont','AB','CANADA','T4X 0E8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-02 23:09:10',0,NULL,3,0,5,1,'CP227167591CN ','randomharley\rc 里面的不对   是BENRO 1691  三脚架'),(15809,720524443018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',6,'AD1169',38.4,'photographyacc','petren48','pr.luke@bigpond.com','Peter Luke','373 Main Road','Kuluin, Sunshine Coast','Queensland','AUSTRALIA','4558','0414185108','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-02 23:31:22',0,NULL,3,1,3,1,'RA184585942CN\r ','petren48'),(15810,760838980002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','frederico.mendonca','fredye.mendonca@gmail.com','Frederico Mendonca','Rua Modesto Brocos, 92 apto 304','Jardim Botanico','RJ','BRAZIL','22460-300','(21) 2242-2514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 00:21:43',0,NULL,3,1,3,1,'RA184585770CN\r ','frederico.mendonca'),(15811,720537050018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','mastrootto','mastrootto@yahoo.it','Eugenio aldrighetti','Via Borgo 26','Vezzano','TN','ITALY','38070','3479712400','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-03 00:28:40',0,NULL,3,0,3,1,'RA184588793CN ','mastrootto\r已入库\rPhoto Vest   $12\rxxl   nikon 老款背心（ 黑色）（已入库）'),(15812,760866030002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-03 02:31:32',0,NULL,3,1,3,1,'RA184588232CN\r ','mariomarques.com.br'),(15813,718851778001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','bradjmc','bradjmcintyre@ymail.com','Brad McIntyre','84 Stanley Road','Camp Hill','Queensland','AUSTRALIA','4152','0403800004','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 02:57:24',0,NULL,3,1,2,1,NULL,'bradjmc'),(15814,720568680018,280667759852,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',8.88,'photographyacc','leigh4175','survhill@westnet.com.au','leigh hobba','PO Box 207','HALL','Australian Capital Territory','AUSTRALIA','2618','0262302046','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-03 03:04:58',0,NULL,3,1,2,1,NULL,'leigh4175\r方形滤镜接口环 82mm   \r广角托架     1\r已入库'),(15815,720584155018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','scotth1271','hoganscott70@hotmail.com','Scott Hogan','21A Maude Street<br>Belmont','Newcastle','New South Wales','AUSTRALIA','2280','0240230614','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-03 04:33:20',0,NULL,3,1,2,1,NULL,'scotth1271'),(15816,760884703002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','romakom','romakomka@rambler.ru','Roman Komsyukov','Gnarovskoy Street 8/1, 17','Tyumen','Tyumenskaja Oblast','RUSSIAN FEDERATION','625007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 04:43:08',0,NULL,3,1,2,1,NULL,'romakom'),(15817,760724038002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','villenbull2010','villenbull@hotmail.com','jose luis cabanes hernandez','c/ doctor fleming Nº2 3ºA','villena','Comunidad Valenciana','SPAIN','03400','678682032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 04:59:28',0,NULL,3,1,3,1,'RA184585806CN\r ','villenbull2010'),(15818,718871788001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','bellafleurbowtique','bellafleurbows@yahoo.com','Amanda Catanzano','821 Balmoral dr','Davenport','FL','UNITED STATES','33896-5047','(863) 207-2365','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-03 04:59:42',0,NULL,3,0,1,1,NULL,'bellafleurbowtique\r1.6*2.1粉红+蓝色'),(15819,718872626001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',4,'AC2302',24.84,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 05:10:11',0,NULL,3,1,2,1,NULL,'gorrionsudaca\r申报gift  \r递四方便宜'),(15820,720591566018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',1,'AD1170',8.99,'photographyacc','mcchph23','makcchph@gmail.com','Chan Cheong Mak','12, Taman Skyline,<br>Batu 4 1/2, Jalan Klang Lama .','Kuala Lumpur','Wilayah Persekutuan','MALAYSIA','58200','012-6758509','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-03 05:22:03',0,NULL,3,1,2,1,NULL,'mcchph23'),(15821,845632801015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','addo-d','addo-d@excite.com','Samuel Addo-Debrah','11 Garfield Street','Watford','Hertfordshire','UNITED KINGDOM','WD24 5HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 07:09:24',0,NULL,3,1,3,1,'RA184585797CN\r ','addo-d'),(15822,720624251018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','garry7307','cowling7@bigpond.net.au','Garry Cowling','31 Regency Drive<br>Regents Park','Brisbane','Queensland','AUSTRALIA','4118','0738094202','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-03 08:13:33',0,NULL,3,1,2,1,NULL,'garry7307'),(15823,845652046015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','cheeurs','david@davidbehan.com','David Behan','Web Together, Vision Building, Block A1<br>East Point Business Park','Fairview','Dublin','IRELAND','D3','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 08:21:52',0,NULL,3,1,2,1,NULL,'cheeurs'),(15824,718920458001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rphoto11','ishrod@gmail.com','Ishai Rodríguez Rodríguez','C/ Lugo y Herrera Nº8, Bajo 7, La Laguna, Santa Cruz de Tenerife','La Laguna','Canarias','SPAIN','38320','651117974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 09:17:22',0,NULL,3,1,3,1,'RA184585783CN\r ','rphoto11'),(15825,776195314017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','gr19551','grodger@bigpond.net.au','GRAEME RODGER','14 EUROKA ROAD','WESTLEIGH','New South Wales','AUSTRALIA','2120','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-03 10:38:47',0,NULL,3,1,2,1,NULL,'gr19551'),(15826,718941594001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'123dmarion'),(15827,718937914001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'123dmarion'),(15828,760957056002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'123dmarion\r'),(15829,718948756001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','darkobezic','dbezic1@gmail.com','Nives Jurjevic','Vladimira Varicaka 22','Zagreb','','CROATIA','10010','00385917305497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 11:08:06',0,NULL,3,1,2,1,NULL,'darkobezic'),(15830,828159010016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','nyevrikel','nyevrikel2@gmail.com','Róbert Nyevrikel','Ligetsor street<br>3. III/8.','Székesfehérvár','Fejér','HUNGARY','8000','0036305795759','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 11:50:04',0,NULL,3,1,2,1,NULL,'nyevrikel'),(15831,760981115002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 11:58:44',0,NULL,3,1,2,1,NULL,'viong'),(15832,760994716002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','alexchiva','alexchiva2004@hotmail.com','ALEJANDRO GOMEZ CASTELLOTE','RUBIO, 23','CHIVA','Comunidad Valenciana','SPAIN','46370','658955008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:44:52',0,NULL,3,1,17,0,NULL,'alexchiva'),(15833,760988177002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','alexchiva','alexchiva2004@hotmail.com','ALEJANDRO GOMEZ CASTELLOTE','RUBIO, 23','CHIVA','Comunidad Valenciana','SPAIN','46370','658955008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:44:53',0,NULL,3,1,17,0,NULL,'alexchiva'),(15834,718969097001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','alexchiva','alexchiva2004@hotmail.com','ALEJANDRO GOMEZ CASTELLOTE','RUBIO, 23','CHIVA','Comunidad Valenciana','SPAIN','46370','658955008','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-03 12:44:53',0,NULL,3,1,17,0,NULL,'alexchiva'),(15835,718971444001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','alexchiva','alexchiva2004@hotmail.com','ALEJANDRO GOMEZ CASTELLOTE','RUBIO, 23','CHIVA','Comunidad Valenciana','SPAIN','46370','658955008','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 12:44:54',0,NULL,3,1,4,1,'YW867471981CN ','alexchiva\rlenspen    1\r爵影红外 canon     1\r三脚架 6662A+ 6160H 球台    1\r肥皂盒 柔光罩  430EX    1\rTripod  $25'),(15836,761000452002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','niyaz_ahamed','gniyaz@gmail.com','Niyaz Ahamed','Summit Central Apartments, 108/32 Leichhardt Street<br>Spring hill','Brisbane','Queensland','AUSTRALIA','4000','0405975216','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 13:03:26',0,NULL,3,1,2,1,NULL,'niyaz_ahamed'),(15837,761005323002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','diablessenergy','l-diablo@live.fr','Nicolas BAPTISTE','23 fbg beauregard','chatillon coligny','Centre','FRANCE','45230','0658095780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 13:20:25',0,NULL,3,1,4,1,'YW867471992CN ','diablessenergy\rLight Stand   $25\r已收到'),(15838,845755958015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','geoff_1975','geofcac@yahoo.com','Geoffrey Cachia','1.Vicpol<br>Tal-Mirakli Street,','Lija','','MALTA','Bzn10','7905 7988','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 13:27:16',0,NULL,3,1,2,1,NULL,'geoff_1975'),(15839,761015492002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','photodan85','artnudesmelb@photodan.com.au','Daniel Lee','2 Belsize Avenue','Carnegie','Victoria','AUSTRALIA','3163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 13:53:47',0,NULL,3,1,2,1,NULL,'photodan85'),(15840,720722978018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',1,'AD1170',8.99,'photographyacc','jacobbechmann','jacob.bechmann@gmail.com','Jacob Bechmann Bahr','Grydemosevej 211','Espergaerde','','DENMARK','3060','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-03 13:57:57',0,NULL,3,1,2,1,NULL,'jacobbechmann'),(15841,761025018002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','aa2209','arielamir@yahoo.com','Amir Ariel','9th Begin St.','Givat Shmuel','','ISRAEL','54421','+972-54-227 1403','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:21:46',0,NULL,3,1,2,1,NULL,'aa2209\r是背景架里面的那个包就是上个周到的那个包'),(15842,719009234001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rimskij','rimskij.d@gmail.com','Rimskiy Dmitry','Petrovskogo st. 187/76','Cherkassy','UA','UKRAINE','18020','30937550001','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:30:14',0,NULL,3,1,2,1,NULL,'rimskij'),(15843,719011739001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','lopez74m','clalop74@libero.it','lorenzo cardinali','via oriolo 29','osimo stazione','AN','ITALY','60027','347-4139805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:37:51',0,NULL,3,1,2,1,NULL,'lopez74m'),(15844,719011968001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','fati.1454','f.kiaeeha@gmail.com','fathollah,kiaieha','Erthal 28','Würzburg','','GERMANY','97074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 14:38:54',0,NULL,3,1,2,1,NULL,'fati.1454'),(15845,828229142016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','wabsucram','marcusbaw@gmail.com','Dr Marcus Baw','Rhyl Fold Farm<br>Manchester Road Lancashire','Leigh','Lancashire','UNITED KINGDOM','WN7 2NX','07747600617','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-03 14:49:54',0,NULL,3,1,2,1,NULL,'wabsucram'),(15846,720746387018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',13.99,'photographyacc','dag1972','daniel.gantert@web.de','Daniel Gantert','Arhotie 2 B','Helsinki','','FINLAND','00900','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-03 14:58:59',0,NULL,3,0,2,1,NULL,'dag1972\r1.6*2.1 黑色背景布    1'),(15847,761041993002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','30041977ivan','ims@isavin.ru','Ivan Savin','342-12, Konenkova str.','Moscow','Moscow','RUSSIAN FEDERATION','127560','499-205-5771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 15:10:24',0,NULL,3,1,3,1,'RA184585721CN\r ','30041977ivan'),(15848,719053287001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 16:31:12',0,NULL,3,1,3,1,'RA184588056CN\r ','ramitetro\r分开发吧 \rRA184588042CN\r'),(15849,719053148001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','tkfotografi','tkfotograf@gmail.com','Tommy Karlsson','Ekgatanan 8','Torsas','Kalmar','SWEDEN','38531','+46703397535','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-03 16:31:36',0,NULL,3,1,5,1,'CP237979728CN','tkfotografi\r1.6*2.1黑色+白色\r其实可以发燕文我觉得\rCP227167605CN '),(15850,845840848015,250599978042,'Neoprene Camera Cover for Nikon D50 D70s D80 D90',1,'AC2304',4.5,'hutongstore','diapasonstore','imiceli@email.it','Ivan Miceli','Via Dante Alighieri, 12','Nichelino','TO','ITALY','10042','3924099364','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 16:43:15',0,NULL,3,1,2,1,NULL,'diapasonstore'),(15851,720791945018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','deyanppanayotov','deyanpanayotov@yahoo.com','Deyan Panayotov','Pl. Francesc Macia 1 4/2','L´Hospitalet de Lobregat','Cataluña','SPAIN','08902','658593322','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-03 16:54:12',0,NULL,3,1,3,1,'RA184585823CN\r ','deyanppanayotov'),(15852,761094789002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','igolubic','ivan.golubic@gmail.com','Ivan Golubic','Put Smokovika 60','Split','Dalmatia','CROATIA','21000','+385915177148','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-03 17:29:48',0,NULL,3,1,3,1,'RA184585810CN\r ','igolubic'),(15853,845848656015,250746711959,'52mm Graduated Neutral Density Filter Gradual Grey 52',1,'AA3315',4.8,'hutongstore','byuan57','bob.yuan@yahoo.com','BobYuan Yuan','10621 158A Street','Surrey','BC','CANADA','V5N 3J2','(604) 338-1729','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 16:56:43',0,NULL,3,1,2,1,NULL,'byuan57'),(15854,719072485001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','j3sus11','j3sus.calderon@gmail.com','JESUS CALDERON','c/ virgen del espino 3','MADRID','Madrid','SPAIN','28027','914046287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 18:00:00',0,NULL,3,1,17,0,NULL,'j3sus11'),(15855,761092194002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','j3sus11','j3sus.calderon@gmail.com','JESUS CALDERON','c/ virgen del espino 3','MADRID','Madrid','SPAIN','28027','914046287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 18:00:01',0,NULL,3,1,4,1,'YW867472003CN ','j3sus11\r三脚架 伟峰 WF-6663A    1\rlenspen +气吹 + 布     1\rTripod   $25'),(15856,761110337002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','schaeref','francescoschaerer@hotmail.com','Francesco Schaerer','Via Belvedere, 13<br>13','Castagnola','Ticino','SWITZERLAND','6976','0797403370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-03 18:09:25',0,NULL,3,1,2,1,NULL,'schaeref'),(15857,719110907001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','kazamasa','kazamasas@gmail.com','Domanskii Vladimir','yl Maksima Gorkogo, dom 39 kv 2','Voronezh','','RUSSIAN FEDERATION','394000','+79081394877','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-03 18:53:08',0,NULL,3,1,3,1,'RA184585925CN\r ','kazamasa'),(15858,846024480015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 23:13:44',0,NULL,3,1,5,1,'CP227167628CN ','leifs123\r灯架  2m        4\r双灯头 欧标      2\r反光伞      2\r45w 5500k 灯泡 220v     4\r灯架包        2\r柔光箱 50-70cm 单灯头欧标     2\r申报￡20'),(15859,719202204001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','jeep-n-it-in-nc','hogfootball56@gmail.com','Joe Apodaca','301 Birds Nest Ct','Wilmington','NC','UNITED STATES','28405-2540','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-03 23:24:05',0,NULL,3,1,1,1,NULL,'jeep-n-it-in-nc'),(15860,846028404015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','rev_jim_619','fabio.giraldi.fano@gmail.com','Fabio Giraldi','chiarini 5','fano','PS','ITALY','61032','3400030257','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 23:30:19',0,NULL,3,1,2,1,NULL,'rev_jim_619'),(15861,828460592016,260660053303,'New Neoprene Reversible Cover for Stand-DSLR Camera M',1,'AC1301',4.5,'hutongstore','remiaus','akestanolatienes@gmail.com','Jon Ribera Medina','Betolaza num.7bis bajo dcha','Bilbo','País Vasco','SPAIN','48002','689708226','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-03 23:34:30',0,NULL,3,1,2,1,NULL,'remiaus'),(15862,720946483018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','arvinrox89','arvinbenk@hotmail.com','Arvin Kumarathilake','272<br>Burwood Hwy','Burwood','Victoria','AUSTRALIA','3125','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-03 23:47:33',0,NULL,3,1,2,1,NULL,'arvinrox89'),(15863,719211607001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','draco006','dragonheart700@hotmail.com','Luke Tutin','687 Sunflower Ct','Westminster','MD','UNITED STATES','21157-4638','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-04 00:07:55',0,NULL,3,0,1,1,NULL,'draco006\r110v 的  已入库'),(15864,761246490002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','zibenbar','sebo@zebase.com','Sebastian Zdyb','545 The West Mall # 602','Etobicoke','ON','CANADA','M9C 1G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 01:10:56',0,NULL,3,1,2,1,NULL,'zibenbar\r'),(15865,761247372002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jaideepsidhu','jaideep7@gmail.com','Jaideep Sidhu','100 Cedar St<br>Dept. of Food Science','Athens','GA','UNITED STATES','30602-5028','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-04 01:14:53',0,NULL,3,1,1,1,NULL,'jaideepsidhu'),(15866,720970630018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','laurannkate','killa_blonde@live.com.au','Lauran Bickley','1/2 Ash Street','Kilkenny','South Australia','AUSTRALIA','5009','0422645802','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 01:37:22',0,NULL,3,0,2,1,NULL,'laurannkate\r1.6*2.1白色背景布  1'),(15867,761260699002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-04 02:16:52',0,NULL,3,0,3,1,'RA184588073CN\r ','wikran\rXL  已入库'),(15868,719238803001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','ivicabrujo','bodul@bodul.com','Ivica Brusic','Brusici 24','Malinska','Croatia','CROATIA','51511','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-04 02:19:10',0,NULL,3,1,3,1,'RA184585908CN\r ','ivicabrujo'),(15869,846082801015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','audi6452','esabthai@yahoo.com','Dhanyapongse Virinthorn','546 Mu 10  (Phu Klang prai Resort)<br>Nongsarai, Pakchong','Nakornrajasima','PAKCHONG','THAILAND','30130','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 02:57:35',0,NULL,3,1,2,1,NULL,'audi6452'),(15870,761274942002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',4,'AA1216',55.6,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 03:28:10',0,NULL,3,1,3,1,'RA184585854CN\r ','happyjaya\r注意是4个'),(15871,719260523001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','aperfectgentleman','push.to.start@gmail.com','Ken Cavanagh','1118 Millwood Court','Orleans','ON','CANADA','K1C 3G1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 04:21:01',0,NULL,3,1,2,1,NULL,'aperfectgentleman'),(15872,776552612017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',3,'AA1310',17.85,'photographyacc','caterpillarmechanic5','benswain@live.com.au','Barbara Heywood','5 Webb Street','Narre Warren','Victoria','AUSTRALIA','3805','0397075524','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 04:28:02',0,NULL,3,1,2,1,NULL,'caterpillarmechanic5'),(15873,721014758018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','sharnabooo','sharnaboo@bigpond.com','sharna ballard','8 spence street','hervey bay ','Queensland','AUSTRALIA','4655','0435834678','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 05:37:34',0,NULL,3,0,2,1,NULL,'sharnabooo\r1.6*2.1背景布粉红    1'),(15874,761348706002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','janpmunk1','jan_petter85@hotmail.com','Jan Petter Munkvold','Sørkedalsveien 3C','Oslo','','NORWAY','0369','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 09:20:06',0,NULL,3,1,2,1,NULL,'janpmunk1'),(15875,776641278017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','checkeredcherries','bluebananayellow@hotmail.com','Olivia Isaac','99 haverbrack drive','mulgrave','Victoria','AUSTRALIA','3170','0397950328','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 10:20:28',0,NULL,3,1,2,1,NULL,'checkeredcherries'),(15876,828644744016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','tillytoes','ebayfran@hotmail.com','F Morales','3 Lowood Court<br>Farquhar Road','London','London','UNITED KINGDOM','SE19 1SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-04 10:23:15',0,NULL,3,1,2,1,NULL,'tillytoes'),(16110,778586175017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','orica_mining_services','ryandavidjackson@hotmail.com','Ryan Jackson','6/126 Chuter Av, Ramsgate Beach','Sydney','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 02:18:52',0,NULL,3,1,2,1,NULL,'orica_mining_services'),(15877,776671331017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','blonky_22','maddawg27@gmail.com','Frank Killalea','41C Athens Road<br>Onehunga','Auckland','Auckland','NEW ZEALAND','1061','+64 27 276 3931','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-04 11:41:23',0,NULL,3,1,6,1,'EE645685390CN ','blonky_22'),(15878,761396131002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','pd5620','palee17@gmail.com','Pál Daróczi','Gát ut 20','Nyíracsád','Hajdú-Bihar','HUNGARY','4262','06304713404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 11:44:31',0,NULL,3,1,2,1,NULL,'pd5620'),(15879,721101277018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','dwagnshop','dwagn72@hotmail.com','Mr Denzil Chong','c/- Cuscal<br>L1, 1 Margaret St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 11:47:34',0,NULL,3,1,3,1,'RA184585845CN\r ','dwagnshop'),(15880,721102866018,280680102028,'YongNuo Flash Battery Pack for 580EXII CP-E4 /6AA SF-17',1,'AB3313',42,'photographyacc','bigrigziggy','ziggyobrien@optusnet.com.au','C/O Ziggy OBRIEN','LINFOX<br>5 Devon Street','Rosehill','New South Wales','AUSTRALIA','2142','0412761554','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 11:48:16',0,NULL,3,1,3,1,'RA184588113CN ','bigrigziggy'),(15881,846230874015,250692239955,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',23,'hutongstore','trottolinoamorosotututadada','davico@alice.it','Mauro D\'Avico','via lungarno garibaldi 7c','Uliveto - vicopisano','PI','ITALY','56010','3809026319','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 12:02:58',0,NULL,3,1,3,1,'RA184585766CN\r ','trottolinoamorosotututadada\rReflector Holder   $12'),(15882,719435425001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5.2,'hermeshine','flylynx38','flylynx@gmail.com','Evgeny Kodnevskiy','Sovetskaya 124B-4','Irkutsk','Irkutskaya oblast\'','RUSSIAN FEDERATION','664047','+79149134970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:12:34',0,NULL,3,1,2,1,NULL,'flylynx38'),(15883,721188534018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','drleonardlee','enquiries@drleonardlee.com.au','Leonard Lee','level 31 88 Phillip St','Sydney','New South Wales','AUSTRALIA','2000','0403005998','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 14:47:28',0,NULL,3,1,3,1,'RA184585837CN\r ','drleonardlee'),(15884,719454259001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','khasanshin','rushkhasan@gmail.com','Khasanshin Roustam Rafailovich','dom 10, kvart. 4<br>Lenina','Urussu, Utazinskiy rayon','rep Tatarstan','RUSSIAN FEDERATION','423950','+7(927)4620218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:51:05',0,NULL,3,1,2,1,NULL,'khasanshin'),(15885,776764253017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','ryo1204','ryo.global@gmail.com','Ryo Yamauchi','1/50 Palmer Street','Fitzroy','Victoria','AUSTRALIA','3065','0434674682','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 14:56:18',0,NULL,3,1,2,1,NULL,'ryo1204'),(15886,719457995001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','bencarl399','brianoolsen@mail.dk','Brian Olsen','Belgiensvej 29','Slagelse','','DENMARK','DK-4200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:57:09',0,NULL,3,1,17,0,NULL,'bencarl399'),(15887,719457996001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','bencarl399','brianoolsen@mail.dk','Brian Olsen','Belgiensvej 29','Slagelse','','DENMARK','DK-4200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:57:09',0,NULL,3,1,17,0,NULL,'bencarl399'),(15888,761480612002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',2,'AA1309',5.2,'hermeshine','bencarl399','brianoolsen@mail.dk','Brian Olsen','Belgiensvej 29','Slagelse','','DENMARK','DK-4200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:57:10',0,NULL,3,1,17,0,NULL,'bencarl399'),(15889,761480611002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','bencarl399','brianoolsen@mail.dk','Brian Olsen','Belgiensvej 29','Slagelse','','DENMARK','DK-4200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 14:57:08',0,NULL,3,1,3,1,'RA184585939CN\r ','bencarl399\rNIKON 镜头盖 62mm   1\rNIKON 镜头盖 72mm     1\rNIKON 镜头盖 77mm    2\rNIKON 镜头盖 52mm      1'),(15890,719489569001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','lexeich','alex_meln@mail.ru','Melnikov Alexey','Krasnoarmeyskaya<br>107 b - 1','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424020','89278831566','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-04 15:54:14',0,NULL,3,1,3,1,'RA184585868CN\r ','lexeich'),(15891,718019945001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',78.35,'hermeshine','natashalirette','natasha_lirette@hotmail.com','Natasha Lirette','300 ave Leclerc','Donnacona','QC','CANADA','G3M 2N3','(418) 283-0815','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 18:01:55',0,NULL,3,0,5,1,'CP227167614CN ','natashalirette\r2m*2m背景架+夹子3       1\r1.6*2.1黑色+白色背景布\r已入库'),(15892,761635213002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','hellipieps','helene.kaeschel@freenet.de','Thomas Wehner','Frankfurter Allee 49','Berlin','','GERMANY','10247','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 18:48:50',0,NULL,3,1,2,1,NULL,'hellipieps'),(15893,719630882001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','alici8','alialici8@hotmail.com','Ali Alici','157 Turnpike Lane','LONDON','London','UNITED KINGDOM','N80EA','07932587828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 18:58:14',0,NULL,3,1,3,1,'RA184588201CN\r ','alici8'),(15894,718580896001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','vt_rakshasa','vt_rakshasa@msn.com','Veronica  Thompson','1641 Nile Dr<br>Apt 327','Corpus Christi','TX','UNITED STATES','78412-4961','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 19:10:10',0,NULL,3,1,1,1,NULL,'vt_rakshasa'),(15895,761667229002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','o.k.western','schanbel@online.no','Ole Kristian Western','Thorvald Meyers gate 47B','Oslo','Oslo','NORWAY','0555','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 19:19:13',0,NULL,3,1,2,1,NULL,'o.k.western'),(15896,721397308018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','roamer6512','markbewick@gmail.com','Mark Bewick','17 Schoolhill Terrace','Lossiemouth','Moray','UNITED KINGDOM','IV31 6JZ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-04 19:23:05',0,NULL,3,0,3,1,'RA184588095CN\r ','roamer6512\rxxl  已入库'),(15897,776980098017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','lordofheat','ddiminic@gmail.com','Nina Matejcic','Branimirova 59','Zagreb','Grad Zagreb','CROATIA','10000','+38598217301','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-04 19:33:40',0,NULL,3,1,2,1,NULL,'lordofheat'),(15898,761682200002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','hjf2885','mijy001@nate.com','Jung-Soun Hong','20768 Arline Ave','Lakewood','CA','UNITED STATES','90715-2820','(562) 292-8686','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-04 19:44:52',0,NULL,3,1,4,1,'YW867472014CN ','hjf2885\r灯泡是110v  的  放一个欧转美标头\r新地址\rJung-Soun Hong\r20772 Arline Ave\rLakewood CA 90715-2820\rUNITED STATES\r(562) 292-8686\r Lighting kit   $25'),(15899,846637263015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','tube-snake','kai.h.jakobsen@vkbb.no','Kai-Hugo Jacobsen','Sannan','Alsvaag','','NORWAY','N8432','+4776131328','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 20:20:48',0,NULL,3,1,17,0,NULL,'tube-snake'),(15900,829072922016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','tube-snake','kai.h.jakobsen@vkbb.no','Kai-Hugo Jacobsen','Sannan','Alsvaag','','NORWAY','N8432','+4776131328','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 20:20:49',0,NULL,3,1,17,0,NULL,'tube-snake'),(15901,846637266015,250692237499,'Large size Neoprene Lens Pouch Case 90mm x 220mm L',1,'AC1203',3.28,'hutongstore','tube-snake','kai.h.jakobsen@vkbb.no','Kai-Hugo Jacobsen','Sannan','Alsvaag','','NORWAY','N8432','+4776131328','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-04 20:20:49',0,NULL,3,1,3,1,'RA184585871CN\r ','tube-snake\r独脚架  伟峰 WT-1003    1\r镜头筒 中号    1\r镜头筒 大号      1'),(15902,719683254001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wantmydody','carol.arwen@ntlworld.com','Carol Albison','House Number 6 Rossendale Way<br>off Cowie Street','Shaw','Oldham','UNITED KINGDOM','OL2 7TX','01706663146','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-04 20:13:18',0,NULL,3,0,3,1,'RA184588100CN\r ','wantmydody\r3XL  已入库'),(15903,846674945015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','fwatson86','frazer_watson@hotmail.co.uk','Frazer Watson','145 Skirsa Street<br>Cadder','Glasgow','Glasgow (City of)','UNITED KINGDOM','G23 5DB','01415794628','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-04 21:22:21',0,NULL,3,1,4,1,'YW867472025CN ','fwatson86\r1.6*2.1黑色+白色背景布\rBackground Support   $25'),(15904,719078159001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',48.7,'hermeshine','alessandro1501','alex.manciccio@tiscali.it','Mediaworld (Saracco Alessandro)','Via Città di Boves n.2','Alessandria','AL','ITALY','15121','3287232641','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 21:35:27',0,NULL,3,1,3,1,'RA184588144CN ','alessandro1501\rnikon 反接环  52mm    1\r大号灰卡    1\r绿叶 渐变镜 72mm      1\r绿叶 渐变镜 77mm    1\r绿叶  72cm ND8    1\r绿叶  77cm ND8    1\r已入库'),(15905,774495667017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','renimperial','aaron.vincent.imperial@gmail.com','Aaron Imperial','64 Dryden Avenue','Carlingford','New South Wales','AUSTRALIA','2118','0298735393','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-04 22:43:04',0,NULL,3,1,2,1,NULL,'renimperial'),(15906,719747001001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ice0381','mau2mau@virgilio.it','Maurizio Virga','Via Giuseppe Clemente, 104','Erice C.S. Trapani','TP','ITALY','91016','3405103572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-04 22:50:36',0,NULL,3,1,2,1,NULL,'ice0381'),(15907,719756511001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','iglap','iglap@rogers.com','Ygor Laptev','10 Torresdale ave. #1605','Toronto','ON','CANADA','M2R 3V8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-04 23:20:10',0,NULL,3,0,3,1,'RA184588060CN\r ','iglap\rL   已入库'),(15908,761794288002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 00:16:56',0,NULL,3,1,17,0,NULL,'denisdryashkin'),(15909,719771673001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 00:16:57',0,NULL,3,1,3,1,'RA184585956CN\r ','denisdryashkin\r灯架包薄     1（以前背景架的那个包）\r配50-70棚的4灯头伞孔  欧标     1'),(15910,719790216001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','sunshine_and_smiles99','liz@ypmarketing.com.au','Elizabeth Colley','1 Saints Road','Maitland','South Australia','AUSTRALIA','5573','0400224927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:24:16',0,NULL,3,1,2,1,NULL,'sunshine_and_smiles99'),(15911,761817989002,120454221534,'Green.L 77mm Neutral Density ND4 Filter ND 4 77',1,'AE2307',8.2,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:39:26',0,NULL,3,1,17,0,NULL,'franznawrath'),(15912,719787525001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:39:27',0,NULL,3,1,17,0,NULL,'franznawrath'),(15913,719787073001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:39:28',0,NULL,3,0,17,0,NULL,'franznawrath'),(15914,719793154001,110419738494,'Green.L 72mm Neutral Density ND4 Filter ND 4 72',1,'AE2306',7.3,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:39:28',0,NULL,3,1,17,0,NULL,'franznawrath'),(15915,761812102002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 01:39:29',0,NULL,3,1,3,1,'RA184588158CN\r ','franznawrath\r绿叶 ND4  77mm    1\r橡胶遮光罩 58mm     1\r橡胶遮光罩 52mm     1\r绿叶 ND4  72mm    1\r伟峰 6662A 快装板     1'),(15916,721559562018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',13,'photographyacc','pallecon','mmolog@hotmail.com','Mile` Stanisic','Suite 11, 6A Gray Street<br>Myshopping.com.au','Bondi Junction','New South Wales','AUSTRALIA','2022','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-05 02:16:15',0,NULL,3,1,2,1,NULL,'pallecon'),(15917,8881315190056138,111,'ova4 单肩包  Canon   1',1,'AD1106',0,'hermeshine','davide.agata','davide.torrisi@email.it','Davide Torrisi','Via Lombardia, 59','Acireale','CT','ITALY','95024','3477376891',NULL,NULL,NULL,'2011-09-05 02:34:16',0,NULL,3,1,4,1,'YW867472036CN ','第三次发了，一定确认清楚：包里是6个隔断。'),(15918,719810945001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','phayes1961','hayes1961@comcast.net','Paul Hayes','1366 Deerfield Rd','Washington','PA','UNITED STATES','15301','','NoPaymentFailure','CheckoutComplete','Other','2011-09-05 02:40:50',0,NULL,3,0,1,1,NULL,'phayes1961\rXL  已入库'),(15919,829228410016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0003',169,'hutongstore','robertfairlie','rob.fairlie@gmail.com','Robert Fairlie','Winterfield<br>Terrys Lane','Cookham','Berkshire','UNITED KINGDOM','SL6 9TJ','07585100661','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-05 02:56:34',0,NULL,3,1,4,1,'YW867472040CN ','robertfairlie'),(15920,761848232002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.89,'hermeshine','scrappybluebird','mbcorry@tpg.com.au','Briana Corry','9 Sams Place','Coral Cove','Queensland','AUSTRALIA','4670','0741593988','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-09-05 03:24:56',0,NULL,3,0,2,1,NULL,'scrappybluebird\r澳标'),(15921,719829034001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','chevyninerschick','becky_lindst@hotmail.com','Rebecca Tweedy','1771 148th Ln NW','Andover','MN','UNITED STATES','55304-8488','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 04:03:31',0,NULL,3,1,1,1,NULL,'chevyninerschick'),(15931,712660096001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','asny7411','asny741@hotmail.com','Hainney Hj.Hamidon','No.11, Simpang 381,Kg.Keriam Tutong TB1141','Bandar Seri Begawan','Brunei','BRUNEI DARUSSALAM','TB1141','6738876870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 09:10:45',0,NULL,3,1,17,0,NULL,'asny7411'),(15922,777175741017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','pangabi','francis.lapuz@gmail.com','Francis Lapuz','CGU Insurance<br>L2 181 William Street','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-05 04:53:04',0,NULL,3,1,2,1,NULL,'pangabi'),(15923,761872273002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','mamaxim2011','malaev.maxim@gmail.com','maxim malaev','braha habas 146','haifa','','ISRAEL','33393','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 05:30:35',0,NULL,3,1,2,1,NULL,'mamaxim2011'),(15924,761876608002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','maxkrash','magic_max37@hotmail.com','Maxime Poirier','2385 rue jeanne d\'arc<br>App 7','Montreal','QC','CANADA','h1w 3v8','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 05:55:35',0,NULL,3,1,3,1,'RA184588011CN ','maxkrash'),(15925,761887762002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','charlesclem','joe@bridge.com.au','Joe Klein','Unit 3, 125 MacPherson Street','Bronte','New South Wales','AUSTRALIA','2024','0293898440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 06:58:37',0,NULL,3,1,4,1,'YW867471911CN ','charlesclem'),(15926,761892558002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','silverchain21','carol@improvision.com.au','Carol Pugh','7 Bradwardine Road','Bathurst','New South Wales','AUSTRALIA','2795','0263322826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 07:23:36',0,NULL,3,1,2,1,NULL,'silverchain21'),(15927,8881315208446909,111,'Double-Q-strap 双肩带',1,'AD1111',26.32,'aliexpress','1004264641','andrey.palitsyn@gmail.com','Gintaras Shlekta	','pr. Lomonosova, house 177, flat 20','Arkhangelsk','Arkhangelsk region	','RUSSIAN FEDERATION	','163000','+007 911 5961555',NULL,NULL,NULL,'2011-09-05 07:40:46',0,NULL,3,1,3,1,'RA184588396CN\r ',''),(15928,8881315208662185,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box ',1,'AC2402',19.47,'aliexpress','1004256718','milokz@gmail.com','Artem Karimov	','bulvar Admirala Ushakova 18-247','Moscow','','RUSSIAN FEDERATION	','117042','79262483557',NULL,NULL,NULL,'2011-09-05 07:44:22',0,NULL,3,1,3,1,'RA184588285CN\r ',''),(15929,777209513017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','cm411489','dan.401@hotmail.com','Daniel Nicholas','73 Bowen Road Doncaster East ','Melbourne','Victoria','AUSTRALIA','3109','0398425859','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-05 07:50:25',0,NULL,3,1,2,1,NULL,'cm411489'),(15930,777219850017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','spmason49','spmason2@bigpond.com','Steve  Mason','8 Honeyman Street','Mount Warren Park','Queensland','AUSTRALIA','4207','0738076080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-05 08:50:30',0,NULL,3,1,2,1,NULL,'spmason49'),(15932,754505369002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','asny7411','asny741@hotmail.com','Hainney Hj.Hamidon','No.11, Simpang 381,Kg.Keriam Tutong TB1141','Bandar Seri Begawan','Brunei','BRUNEI DARUSSALAM','TB1141','6738876870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 09:10:45',0,NULL,3,1,2,1,NULL,'asny7411\rET-65B    1\rEW-73B    1'),(15933,721649928018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','oreste2000','oreste.perfetti@libero.it','oreste perfetti c/o Eugenia ferraro','marinelle 24','rogliano','CS','ITALY','87054','3404114442','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-05 09:30:50',0,NULL,3,1,2,1,NULL,'oreste2000'),(15934,721654960018,280666852926,'Photo Studio Light Stand Heavy Duty Clamp Copper head  ',1,'AE3102',10,'photographyacc','toshiroken','tbanh095@gmail.com','Tan Banh','1/66 Kensington Terrace','Toowong','Queensland','AUSTRALIA','4066','(042) 512-5422','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-05 09:52:45',0,NULL,3,1,2,1,NULL,'toshiroken'),(15935,8881315217456387,111,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',0,'photographyacc','alan.nan.wu','rac131111@yahoo.com.au','Alan Wu','Level 1, 502 Hay Street','Subiaco','Western Australia','AUSTRALIA','6008','0433136183',NULL,NULL,NULL,'2011-09-05 10:10:56',0,NULL,3,1,3,1,'RA184588277CN\r ','第一票一月未到，补发。'),(15936,8881315221472473,111,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',70,'hermeshine','vahan2008','vahannersesyan@yahoo.com','Vahan Nersesyan','Nerkin Shengavit , street 4 , house 38','Yerevan','','ARMENIA','0074','',NULL,NULL,NULL,'2011-09-05 11:17:52',0,NULL,3,1,5,1,'CP235627476CN ','vahan2008\r欧标\r'),(15937,761946450002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','talesofbambi','cindeljane@hotmail.com','CINDEL HEPERI','3/25-31 SUNDERLAND STREET','EVANS HEAD','New South Wales','AUSTRALIA','2473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 11:21:36',0,NULL,3,1,2,1,NULL,'talesofbambi'),(15938,776154804017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',16.68,'photographyacc','freddie_mercuryblue','paul@freddiemercury.no-ip.org','Paul Roberts','PO Box 2005','Hobart','Tasmania','AUSTRALIA','7001','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-05 12:42:59',0,NULL,3,1,2,1,NULL,'freddie_mercuryblue\r普通有线快门线S1    1\rlenspen    1\r气吹 + 布      1'),(15939,719949301001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','jason2ces','jason@2ces.com','Jason Caldwell','19 Eridani Ave','Kingston','Queensland','AUSTRALIA','4114','0732995357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 12:58:53',0,NULL,3,1,2,1,NULL,'jason2ces'),(15940,719951275001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','tibby_f','tibby@mediadesign.com.au','Tibby Flora','5 broadwalk grv<br>endeavour hills','melbourne','Victoria','AUSTRALIA','3802','0408316018','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 13:06:23',0,NULL,3,0,3,1,'RA184588325CN\r ','tibby_f\rL   已入库'),(15941,761991908002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 13:48:38',0,NULL,3,1,2,1,NULL,'roger-damngood'),(15942,846986566015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0022',149,'hutongstore','mike_g-h','mikegh1@hotmail.co.uk','Michael Greaves-Hurd','53 Station Road East<br>Ash Vale','Aldershot','Hampshire','UNITED KINGDOM','GU125LY','07733076346','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-05 13:52:52',0,NULL,3,1,4,1,'YW867471922CN ','mike_g-h'),(15943,777326992017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','dmitry2601','dimib1@bezeqint.net','Dmitry Bronshteyn','59 Shapira st.<br>apt 2','Petah-Tikva','Israel','ISRAEL','49600','972-54-3195007','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-05 14:20:31',0,NULL,3,1,2,1,NULL,'dmitry2601'),(15944,777327654017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',2,'AD1401',15.6,'photographyacc','eriz2008','eriz4ya@hotmail.com','Erwin Ramos','45 Cuthbert Avenue','Truganina','Victoria','AUSTRALIA','3029','0383682482','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-05 14:21:41',0,NULL,3,1,3,1,'RA184588440CN\r ','eriz2008\r算一下运费   差两元'),(15945,762008692002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','aldoscic','aldosc@go.net.mt','Aldo Scicluna','89 Claire E. Engel Street','St Julian\'s','','MALTA','STJ 1814','+356 21382654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 14:37:59',0,NULL,3,1,2,1,NULL,'aldoscic'),(15946,760966036002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','panineduard','panin_e@inbox.ru','Panin Eduard','ul. Strelnikova, d. 6, kv. 52','Khabarovsk','','RUSSIAN FEDERATION','680054','+79241050202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 14:52:35',0,NULL,3,1,2,1,NULL,'panineduard'),(15947,762026447002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','st_maxime','just.ebayusa@gmail.com','Michael Just','299 E 8th St<br>Apt 13','New York','NY','UNITED STATES','10009-5205','(212) 380-8379','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 15:24:43',0,NULL,3,1,1,1,NULL,'st_maxime'),(15948,720018997001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','fernandogenes','fsotogalvan@hotmail.com','Fernando Soto Galván','Palacios Malaver 18, 2º izq.','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41003','685119428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 16:13:53',0,NULL,3,1,4,1,'YW867471933CN ','fernandogenes'),(15949,777377521017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','photo_master.and','andrey.schnell@gmail.com','Andrey Schnell','Beregowaja 41','Aksu','Pawlodar','KAZAKHSTAN','140100','87183733084','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-05 16:23:53',0,NULL,3,1,2,1,NULL,'photo_master.and'),(15950,762045401002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','lamptomyfeet','jbakker3@mergetel.com','John C. Bakker','1299 Third Street','St. Catharines','ON','CANADA','L2R 6P9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 16:11:29',0,NULL,3,1,2,1,NULL,'lamptomyfeet'),(15951,762065097002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','lenkaren2','lenk222@hotmail.com','Kent Björklind','Mariebergsgatan 9B','Sala','','SWEDEN','73334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 16:57:08',0,NULL,3,1,2,1,NULL,'lenkaren2\r需要算运费'),(15952,720049575001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','blububble','marta.breijo@gmail.com','Marta Breijo Pena','Avenida de Burgos 34 - 9E','Madrid','Madrid','SPAIN','28036','913838108','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 17:23:14',0,NULL,3,1,2,1,NULL,'blububble'),(15953,762098014002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','alejonimo','monfry90@hotmail.com','alejandro nieto monfrino','ministerio de la vivienda b/7-9d','malaga','malaga','SPAIN','29010','667541654','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 18:04:28',0,NULL,3,1,3,1,'RA184588229CN\r ','alejonimo'),(15954,721843740018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',2,'AA3312',13.2,'photographyacc','neli5504nelka','neli5504@gmail.com','NELKA HEWAGE','52/B/1,NANDA ELLAWALA ROAD<br>ETHOYA','RATNAPURA','SABARAGAMUWA','SRI LANKA','70000','+94775430700','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-05 18:20:39',0,NULL,3,1,2,1,NULL,'neli5504nelka'),(15955,720089166001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','marrikixox','marriki.schlifer@gmail.com','Marriki Schlifer','Apt 2 - 328 Fourth Street','New Westminster','BC','CANADA','V3L 2T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 18:38:24',0,NULL,3,1,3,1,'RA184588317CN\r ','marrikixox'),(15956,720083283001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','dmanjd','jim@jimduarte.com','Jimmy Duarte','6201 Majestic Ave','oakland','CA','UNITED STATES','94605-1860','(510) 346-0008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-05 18:43:54',0,NULL,3,1,1,1,NULL,'dmanjd'),(15957,720112442001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','gantzclub','emy.bass_sound@live.com.ar','emiliano gonzalez','guido spano 1460','gral rodriguez','buenos aires','ARGENTINA','1748','0111535516358','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 19:20:37',0,NULL,3,0,3,1,'RA184588348CN\r ','gantzclub\rL 已入库'),(15958,762115159002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','buttigheddu87','buttigheddu@tiscali.it','andrea demuro','via frati de addis<br>4','aggius','SS','ITALY','07020','3382169867','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 19:29:14',0,NULL,3,1,3,1,'RA184588351CN\r ','buttigheddu87\r已入库\rPhoto Vest   $10'),(15959,720129740001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',16,'hermeshine','cristine157','loren8@btinternet.com','Loren Jackson','157 Lawefield Lane','Wakefield','West Yorkshire','UNITED KINGDOM','WF28SX','01924365301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-05 19:53:21',0,NULL,3,1,2,1,NULL,'cristine157'),(15960,846882826015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','andreasko2008','apea@centrum.sk','Ing.Lubomir Engler','Sidlisko Rimava 36','Rimavska Sobota','RS','SLOVAK REPUBLIC','97901','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 20:27:04',0,NULL,3,1,2,1,NULL,'andreasko2008'),(15961,762177984002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','snick265','snickflora@gmail.com','Flora, Nick','700 S Jefferson St','Macon','MS','UNITED STATES','39341-3012','(662) 736-6005','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-05 20:32:25',0,NULL,3,1,1,1,NULL,'snick265'),(15962,720159330001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 20:57:50',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(15963,720169169001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','hassanare09','ashkir14@hotmail.com','Hassan Are Ashkir','stovner senter 1<br>oslo','oslo','oslo','NORWAY','0985','004747844022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:17:49',0,NULL,3,1,17,0,NULL,'hassanare09'),(15964,762199049002,120752153194,'Photo Studio Background Support Carrying Carry Bag',6,'AD1129',59.4,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:28:36',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(15965,720169654001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',62,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:28:35',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(15966,762199459002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',3,'AE3101',95.67,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 21:28:35',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(15967,720177992001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',4,'AKT015',315.6,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-05 21:45:00',0,NULL,3,1,12,1,'5241693903 ','ahmedphotobh\r肩架      1\r灯架包薄     6\r反光板支架    2\r斜臂     3\r背景架2mx2m  + 3个夹子   4\r1.6*2.1黑色+白色背景布     4\r抛重17.98  实重18.1'),(15968,847262656015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 21:58:53',0,NULL,3,1,17,0,NULL,'kadedoll'),(15969,847262290015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','kadedoll','divaaa1@hotmail.com','FRANCISCO IVAN GARCIA PEREZ','C/Lope de Vega nº5 Chalet','Fuenlabrada (Loranca)','Madrid','SPAIN','28942','669625244','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-05 21:58:53',0,NULL,3,1,4,1,'YW867471944CN ','kadedoll\r一转四 灯头   2\r灯架  2m    2\r柔光箱 50-70cm 单灯头欧标    2\r灯架包      1'),(15970,720186883001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','liornfib','lior.elb@gmail.com','Eliyahu Lior Elbaz','Yakinton 574 Ap.15<br>Gilo','Jerusalem','Israel','ISRAEL','93844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:05:44',0,NULL,3,1,2,1,NULL,'liornfib'),(15971,762229981002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','nueve2000','jjosserme@gmail.com','Jorge Josserme','San Lorenzo 3887','Olivos','Buenos Aires','ARGENTINA','B1636ERU','5491147040210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 22:51:29',0,NULL,3,0,2,1,' ','nueve2000\r欧标'),(15972,720212852001,110541871813,'New Benro A1691TB0 Monopod Tripod Kit Travel Angel Bag',1,'AKT033',202,'hermeshine','videbota1979','videbota@gmail.com','Lluís Garcia Rovira','Sants Màrtirs, 16','Ulldecona','Cataluña','SPAIN','43550','676228780','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-05 23:41:25',0,NULL,3,0,4,1,'YW867471841CN ','videbota1979\r百诺A1691  三脚架'),(15973,762255657002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',95,'hermeshine','hassanare09','ashkir14@hotmail.com','Hassan Are Ashkir','stovner senter 1<br>oslo','oslo','oslo','NORWAY','0985','004747844022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 00:23:01',0,NULL,3,1,5,1,'CP235627480CN ','hassanare09\r三脚架 伟峰 WF-6663A    1\r灯架  2m      2\r双灯头 欧标     2\r反光伞      2\r灯架包       1'),(15974,762265573002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','amandaroseann','angelpuppy4989@hotmail.com','amanda rodgers','9264 hwy 201<br>RR #1','wilmot','NS','CANADA','B0P 1W0','(902) 309-0135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 01:02:31',0,NULL,3,0,3,1,'RA184588294CN\r ','amandaroseann\r1.6*3白色背景布    1'),(15975,720237637001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','eriebtsugua','abiere@sympatico.ca','August Biere','2 Campbell','Mont-Saint-Hilaire','QC','CANADA','J3H3T9','(450) 464-8736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 01:21:21',0,NULL,3,1,2,1,NULL,'eriebtsugua'),(15976,8881315272729937,111,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',0,'hermeshine','mkhitar73','gel73@mail.ru','Mkhitar Hovhannisyan','Lernagorcner st. 16/30 Lernagorcner st. 15/14','Qajaran','Syunik','ARMENIA','3309','+37491223355',NULL,NULL,NULL,'2011-09-06 01:32:09',0,NULL,3,1,5,1,'CP235627459CN ','mkhitar73\r上一票被退回来了，重发。\r已经退回来了'),(15977,720250917001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','azureti','ksanghoon1@gmail.com','SANGHOON KIM','515ho, hyundae hyperion efficiency apartment, Bansong-dong','Hwaseong-si','Gyeonggi-do','KOREA,REPUBLIC OF','445-160','01080309838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 02:32:04',0,NULL,3,1,3,1,'RA184588405CN\r','azureti'),(15978,847252321015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','j.carlos.blanco','jcarlosblanco@terra.es','Juan Carlos Blanco Colomer','Plaza de la Inmaculada 5, 1-B','Palencia','Palencia','SPAIN','34001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 02:42:47',0,NULL,3,1,2,1,NULL,'j.carlos.blanco'),(15979,762294791002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','esrods','esrods@tpg.com.au','Edward Shin','32 Munmorah Cct','Woodcroft','New South Wales','AUSTRALIA','2767','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 02:49:34',0,NULL,3,1,2,1,NULL,'esrods'),(15980,762140355002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',110.85,'hermeshine','tomasvoim','tomivoim@gmail.com','Tomáš Képeš','Jána Hunyadiho<br>1','Moldava nad Bodvou','','SLOVAK REPUBLIC','04501','+4210907372391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 04:25:36',0,NULL,3,1,5,1,'CP235627462CN ','tomasvoim'),(15981,722056900018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','derbarrett','bigdaddy2927@yahoo.com','Derrick Barrett','920 Memorial Dr SE<br>Unit 5','Atlanta','GA','UNITED STATES','30316-1480','(704) 779-7914','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 04:50:33',0,NULL,3,1,3,1,'RA184588215CN\r ','derbarrett'),(15982,762328267002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rtg7174','rmg7174@hotmail.com','Ruben Guerrero','10343 Craftsman Way<br>Apt 107','San Diego','CA','UNITED STATES','92127-3537','(858) 254-1071','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-06 05:49:13',0,NULL,3,1,1,1,NULL,'rtg7174'),(15983,777679684017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','may16478','shellmay@hotmail.com','Shelley Akers','204 Broughton Street','Tumut','New South Wales','AUSTRALIA','2720','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-06 06:02:16',0,NULL,3,1,2,1,NULL,'may16478\r澳标'),(15984,777678141017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','macaulayjape01','macaulay_jape@hotmail.com','Blanc Bistro Bar and Grill','Shop 31/81 O\'Connell St','North Adelaide','South Australia','AUSTRALIA','5006','61437888889','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-06 06:04:06',0,NULL,3,1,2,1,NULL,'macaulayjape01'),(15985,847403830015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','qaizer11','mohdkhaira@gmail.com','Mohd Khaira bin Daud','Jabatan Imigresen Malaysia<br>Bahagian Penguatkuasa, Aras 5 Wisma MAIDAM','Kuala Terengganu','Terengganu','MALAYSIA','20100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 06:12:30',0,NULL,3,1,17,0,NULL,'qaizer11'),(15986,847403644015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','qaizer11','mohdkhaira@gmail.com','Mohd Khaira bin Daud','Jabatan Imigresen Malaysia<br>Bahagian Penguatkuasa, Aras 5 Wisma MAIDAM','Kuala Terengganu','Terengganu','MALAYSIA','20100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 06:12:31',0,NULL,3,1,2,1,NULL,'qaizer11\r肥皂盒 柔光罩   580EX    1\r伟峰 6662A 快装板    1'),(15987,720298651001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','bigredimages','laureenlees@hotmail.com','Laureen Lees','45 Caithness St. East, Apt. 301','Caledonia','ON','CANADA','N3W1L5','(905) 765-1102','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 06:35:33',0,NULL,3,1,2,1,NULL,'bigredimages'),(15988,762339024002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','p_filter','pfilter@hotmail.com','Pablo Fílter Pérez','Pardito, 5','Cañada Rosal','Andalucía Ceuta y Melilla','SPAIN','41439','661965558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 06:54:48',0,NULL,3,1,3,1,'RA184588303CN\r ','p_filter'),(15989,761079407002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','victorgo2000us','victorgo2000@gala.net','VIKTOR GOLUBENKO','ul Yakuba Kolasa 11 165','Kyiv','','UKRAINE','03146','380444035665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 07:16:21',0,NULL,3,1,2,1,NULL,'victorgo2000us'),(15990,722083414018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','gary.cooper007','gary.cooper@exemail.com.au','Gary Cooper C/- Lake Macquarie City Council','126-138 Main Road','Speers Point','New South Wales','AUSTRALIA','2284','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-06 07:18:40',0,NULL,3,1,3,1,'RA184588382CN\r ','gary.cooper007\r已入库'),(15991,720311322001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 07:40:40',0,NULL,3,1,3,1,'RA184588379CN\r ','nixette_nixette'),(15992,762350679002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','0546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 08:09:32',0,NULL,3,1,17,0,NULL,'meir_shevach'),(15993,762352428002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','0546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 08:09:32',0,NULL,3,1,17,0,NULL,'meir_shevach'),(15994,720315552001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','0546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 08:09:33',0,NULL,3,1,3,1,'RA184588365CN\r ','meir_shevach\r大力夹   1\r沙袋（普通）   1\r反光板支架       1'),(15995,8881315298478928,111,'(2螺丝扳手)Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',0,'hermeshine','betlog','betlogbetlog@hotmail.com','Andrew Eglington','166 Herston Road, Herston','Brisbane','Queensland','AUSTRALIA','4006','610738562341',NULL,NULL,NULL,'2011-09-06 08:41:18',0,NULL,3,1,3,1,'RA184588453CN\r ',' 上一票发错了，这票一定注意！-- 是“2螺丝井字扳手”，不是“4螺丝”。'),(15996,777712712017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',2,'AA1302',5,'photographyacc','sillymoocow','burroblando@gmail.com','Benjamin Holgate','Level 36, Australia Square<br>264 George Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-06 08:57:22',0,NULL,3,1,2,1,NULL,'sillymoocow'),(15997,847453162015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','unison60','jordicoll.pine@telefonica.net','Jordi Coll Galvany','Mossèn Cinto Verdaguer 60 piso 12','Pineda de Mar','Barcelona','SPAIN','08397','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 09:11:01',0,NULL,3,1,17,0,' ','unison60\r欧标\r--\r地址加上这个电话号码：670514179\r'),(15998,720331813001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','cribou68','chrisbours@gmail.com','Christian BOURS','14 avenue Poincaré','COLMAR','Alsace','FRANCE','68000','03.89.80.90.11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:15:15',0,NULL,3,1,3,1,'RA184588436CN\r ','cribou68'),(15999,847467731015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','pesi0215','petr@simunek.org','Petr Simunek','Mecislavova 7<br>(Digital Media Production, inc.)','Prague','','CZECH REPUBLIC','CZ14200','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-06 09:54:59',0,NULL,3,1,5,1,'CP227167659CN ','pesi0215'),(16000,720341969001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','dmitry092009','diim1@mail.ru','Dmitry Scheglov','4-7<br>Kirillova st.','Saransk','Mordovia','RUSSIAN FEDERATION','430004','9176960916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 09:57:44',0,NULL,3,1,5,1,'CP227167662CN ','dmitry092009'),(16001,8881315304279876,111,'115W 220V 灯泡 * 1',1,'AO0004',0,'hermeshine','markarper','marknot81@hotmail.com','Marco Di Virgilio','Viale dei Tigli 108','Casalbordino','CH','ITALY','66021','0873916536',NULL,NULL,NULL,'2011-09-06 10:17:59',0,NULL,3,1,3,1,'RA184588524CN ','markarper\r第一票坏了一个，补发。\rLight Bulb   $8'),(16002,847451617015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','levon1992','le.von@live.com','Levon ang','blk 406 fajar road #08-295','default','SC','SINGAPORE','670406','97883167','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-06 10:41:42',0,NULL,3,1,9,1,'10423111090700004\r ','levon1992\r背景布 白 + 黑  1.6x2.1'),(16003,847504976015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','aochristian','aoccommunications@yahoo.co.uk','Christian Ashaiku','98 Bedford Road<br>Edmonton','London','London','UNITED KINGDOM','N9 7DB','02088045742','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-06 11:45:06',0,NULL,3,1,12,1,'5241673555 ','aochristian\r英标\r实重11.67  抛重14.6  最终泡重：13kg'),(16004,846933844015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',81.49,'hutongstore','mobeats-uk','accounts@mobeats.co.uk','Jeff Edelsten','7 Hagley Road','Reading','Berkshire','UNITED KINGDOM','RG2 0DN','01189018891','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-06 12:12:18',0,NULL,3,1,4,1,'YW865546092CN ','mobeats-uk\r肩架   1\r2m 灯架   2\r50-70 棚   2 英标\r灯架包    1\rlighting kit $26\r实重5.46  泡重8.2'),(16005,720394101001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','odysseas80','info@ouranios.com','Odysseas Ouranios','10 Ariadnes Str','Lakatamia','Nicosia','CYPRUS','2321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 13:07:31',0,NULL,3,1,2,1,NULL,'odysseas80'),(16006,722199092018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','catanddog777','tutupoezd@mail.ru','Alexey Dukachev','Demyana Bednogo h. 23 ap. 163','Khabarovsk','Khabarovskii krai','RUSSIAN FEDERATION','680009','+79144076138','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 14:19:36',0,NULL,3,1,17,0,NULL,'catanddog777\r'),(16007,720417393001,110658426775,'New  Studio 20\"x 27\" Softbox Universal  Metal Mount',1,'AE2204',24.99,'hermeshine','slanzro','zro@freemail.hu','Zsolt Bartha','Moszkva tér 13. mfsz 6. (Median)','Budapest','','HUNGARY','H1122','(36)205588892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:21:41',0,NULL,3,1,3,1,'RA184588498CN ','slanzro'),(16008,720417038001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:30:57',0,NULL,3,1,17,0,NULL,'saud-p'),(16009,720414379001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:30:59',0,NULL,3,1,12,1,'5241673533 ','saud-p\r背景架2m x 3m + 3个夹子   1\r背景布 3x6 绿色     1\r灯架  2m    4\r柔光箱 50-70cm 单灯头欧标     4\r115w 5500k 灯泡  220v    4\r灯架包      2\r背景架2mx 1.6m      1\r1.6*2.1黑色背景布    1\r需要在灯架上贴 made in china    \r还需要申报实值 申报Lighting kit  $400\r实重16.1   抛重  19.6'),(16010,720420875001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','zsuzso000','michlzsuzsi@hotmail.com','Dr. Grépály István','Rákóczi utca 29','Nagykőrös','','HUNGARY','2750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 14:34:00',0,NULL,3,1,3,1,'RA184588515CN ','zsuzso000'),(16011,777827885017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',2,'AKT052',85.6,'photographyacc','catanddog777','tutupoezd@mail.ru','Alexey Dukachev','Demyana Bednogo h. 23 ap. 163','Khabarovsk','Khabarovskii krai','RUSSIAN FEDERATION','680009','+79144076138','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 14:53:01',0,NULL,3,1,5,1,'CP227167645CN ','catanddog777\r河北背景架 +夹子  1\r1.6x2.1 白色背景布   1\r2m 灯架  2\r云台  2\r柔光伞   2 '),(16012,830023354016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','yaheni','yahenimilto@gmail.com','Yaheni Milto','Admonit 6/8','Lod','','ISRAEL','71110','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-06 16:03:07',0,NULL,3,1,3,1,'RA184588609CN ','yaheni\r欧标  '),(16013,762491114002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','fernandopita','nanko4@hotmail.com','Fernando Pita Castro','Avda. Republica saharaui s/n CASEM-Universidad de Cádiz','Puerto Real','Andalucía Ceuta y Melilla','SPAIN','11510','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-06 16:08:42',0,NULL,3,1,3,1,'RA184588555CN ','fernandopita'),(16014,720458236001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','h3lang','ganhelang@hotmail.com','Helang Gan','Blk 651B Jurong West Street 61 #09-356 Singapore 642651','default','','SINGAPORE','642651','90039956','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-06 16:15:13',0,NULL,3,1,17,0,NULL,'h3lang'),(16015,720459633001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','h3lang','ganhelang@hotmail.com','Helang Gan','Blk 651B Jurong West Street 61 #09-356 Singapore 642651','default','','SINGAPORE','642651','90039956','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:17:19',0,NULL,3,1,3,1,'RA184588422CN ','h3lang\r无牌方镜 渐变灰 （nd4   1\r无牌方镜 渐变灰 （nd8）    1\r无牌方镜 渐变蓝     1\r无牌方镜 ND2      1\r无牌方镜 ND4       1\r无牌方镜 ND8        1\r6片装的滤镜袋    1\r方形滤镜接口环 77mm     1\r方镜普通托架（三槽     1'),(16016,762497009002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','zhengx123','xzms@hotmail.com','Zheng Xiang','#205-1720 Richmond Ave','Victoria','BC','CANADA','V8R 4P8','(250) 588-5608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:26:21',0,NULL,3,1,17,0,NULL,'zhengx123\r'),(16017,762346116002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','arcane2962','ralphru@gmail.com','Ralph Ruivivar','Commission on Population<br>Cabatangan','Zamboanga City','Zamboanga del Sur','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:33:14',0,NULL,3,1,17,0,NULL,'arcane2962'),(16018,720324548001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','arcane2962','ralphru@gmail.com','Ralph Ruivivar','Commission on Population<br>Cabatangan','Zamboanga City','Zamboanga del Sur','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:33:13',0,NULL,3,1,3,1,'RA184568286CN\r ','arcane2962\r85cm 两用伞    1\r橡胶遮光罩 58mm    1'),(16019,762502427002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','dai_fabio_dai','fabioborra@alice.it','Fabio Borra','via sabin<br>24','Cattolica','RN','ITALY','47841','3334772527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 16:36:02',0,NULL,3,1,3,1,'RA184588475CN ','dai_fabio_dai\r Light Stand    $15'),(16020,762551111002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','jesolins','gjssolin@yahoo.com','James Solinski','2343 Estate Gate Dr.','San Antonio','TX','UNITED STATES','78260','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-06 18:24:29',0,NULL,3,1,1,1,NULL,'jesolins'),(16021,722309530018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',18.59,'photographyacc','matesku','kusakmartin@email.cz','Martin Kusak','Poradi 323','Uh. Brod','Uh Brod','CZECH REPUBLIC','68801','608860459','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-06 18:46:34',0,NULL,3,1,2,1,NULL,'matesku\r58cm CPL    1\r58cm+4 近摄镜    1\r绿叶 渐变镜 58mm    1\r已入库 \r'),(16022,762569128002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','unison60','jordicoll.pine@telefonica.net','Jordi Coll Galvany','Mossèn Cinto Verdaguer 60 piso 12','Pineda de Mar','Barcelona','SPAIN','08397','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 19:02:10',0,NULL,3,1,4,1,'YW865546103CN ','unison60\r灯架  2m   2\r柔光箱 50-70cm 单灯头欧标   2\r灯架包       1\r闪光的柔光箱   60cm     1\r地址加上这个电话号码：670514179\r已收到'),(16023,720538499001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','moses_big','mark.br.mail@gmail.com','Mark Berber','hatafit<br>14/13','afula','','ISRAEL','18757','+972528385577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 19:08:27',0,NULL,3,1,3,1,'RA184588590CN ','moses_big'),(16024,720541833001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','smurfboy604','irwin_j_lee@hotmail.com','Irwin Lee','#2204 - 4353 Halifax Street','Burnaby','BC','CANADA','v5c5z4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-06 19:14:26',0,NULL,3,1,3,1,'RA184588419CN ','smurfboy604'),(16025,830149902016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','fidel.cornelis','fidel.cornelis@gmail.com','Fidel Paul Cornelis Gimenez','Calle 1º de Mayo Nº 35 , Puerta 12','Alfara del Patriarca','Comunidad Valenciana','SPAIN','46115','655829242','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-06 19:39:53',0,NULL,3,1,12,1,'5241673544 ','fidel.cornelis\r欧标 \r实重7.13  抛重8.9  最终计费泡重：8.5'),(16026,762616857002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','honda_jolin','bhuynh9@ymail.com','Binh Huynh','8532 Amy Ave','Garden Grove','CA','UNITED STATES','92841-3208','(909) 333-6799','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-06 20:33:31',0,NULL,3,1,1,1,NULL,'honda_jolin'),(16027,762633222002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',147.8,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sarah Al-Subaa','Taruot','QATIF','QATIF','SAUDI ARABIA','31911','966598664682','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:09:29',0,NULL,3,1,8,1,'CP227167631CN ','tawfeekmohammed\r实重5.53 抛重4.85'),(16028,720606054001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:37',0,NULL,3,1,17,0,NULL,'brain_stergeon'),(16029,762642183002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:38',0,NULL,3,1,17,0,NULL,'brain_stergeon'),(16030,762642272002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:38',0,NULL,3,1,17,0,NULL,'brain_stergeon'),(16031,720605842001,110664971677,'GGS Glass LCD Screen Protector for Canon 50D 5DII',1,'AB2211',7.6,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:39',0,NULL,3,1,17,0,NULL,'brain_stergeon'),(16032,762642379002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',5.9,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:39',0,NULL,3,1,17,0,NULL,'brain_stergeon'),(16033,720605455001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.3,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:40',0,NULL,3,1,17,0,' ','brain_stergeon'),(16034,720611556001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','david20737','davidwhittet@xtra.co.nz','David Whittet','147 Settlement Road','Kurow','North Otago','NEW ZEALAND','9435','+6421344107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:48:30',0,NULL,3,1,3,1,'RA184588541CN ','david20737'),(16035,762652670002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','ruben20051008','ruben.2gb@gmail.com','Ruben Alves','Rua do Lameiro 559','Oliveira do Douro','Vila Nova de Gaia','PORTUGAL','4430-444','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 22:00:09',0,NULL,3,1,4,1,'YW865546070CN ','ruben20051008\r欧标 '),(16036,762642578002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','brain_stergeon','farrell.justin@gmail.com','Justin Farrell','309-2125 Burtch Rd','Kelowna','BC','CANADA','V1Y8N1','(250) 448-2831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 21:35:37',0,NULL,3,1,3,1,'RA184588507CN ','brain_stergeon\r52-58mm 双阳环    1\r绿叶 UV  52mm    1\r普通有线快门线C3    1\rGGS 50D/5DII     1\r绿叶 ND4  58mm    1\r绿叶 UV  58mm     2\rlenspen     1\r气吹 + 布     1'),(16037,762672141002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','2c0','kangta_cz@yahoo.com','Hai Ha Nguyen','Breicetlova 880/9','Prague','Prague','CZECH REPUBLIC','19800','00420773477710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-06 23:01:24',0,NULL,3,1,3,1,'RA184588467CN ','2c0'),(16038,720638974001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','pacvdopaul','pacvdo@gmail.com','Paul Acevedo','Urb. Libertad Mz. A Lote 21<br>Trujillo','Trujillo','La libertad','PERU','00001','005144216380','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-06 23:21:35',0,NULL,3,1,2,1,NULL,'pacvdopaul'),(16039,722387957018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','superrabbit32','qinyi32@hotmail.com','Richard Qin','43 Dinah Parade','Keilor East','Victoria','AUSTRALIA','3033','0393310106','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-06 23:35:55',0,NULL,3,1,3,1,'RA184588484CN ','superrabbit32'),(16040,722459783018,280680267419,'New Neoprene Camera Cover for Nikon D80 D5000 +18-55mm',1,'AC1305',9.99,'photographyacc','slowurolll','vuznot@yahoo.com.au','vu hoang','22 nathan crescent<br>dean park','sydney','New South Wales','AUSTRALIA','2761','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 00:48:53',0,NULL,3,1,2,1,NULL,'slowurolll'),(16041,720670321001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',2,'AA1308',5.2,'hermeshine','yeliabttam','ebaymattb@gmail.com','Matt Bailey','2608 Hewn Rock Way','Pearland','TX','UNITED STATES','77584','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 01:16:13',0,NULL,3,1,1,1,NULL,'yeliabttam'),(16042,720702770001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','guinader','guinader@hotmail.com','Guilherme Z Andre','22 Derry St','Hudson','NH','UNITED STATES','03051-4006','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 03:20:22',0,NULL,3,1,1,1,NULL,'guinader'),(16043,720720305001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',2,'AA1308',5.2,'hermeshine','valentinophoto','valentinophoto@sbcglobal.net','James Valentino','N8228 Carnot Drive','Algoma','WI','UNITED STATES','54201-9594','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 04:55:59',0,NULL,3,1,1,1,NULL,'valentinophoto'),(16044,830360013016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','inna_batrak','i.batrak@hotmail.com','Inna Batrak','9, Aytiev str, app. 7','Almaty','','KAZAKHSTAN','050026','7(701)755-5608','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 05:09:11',0,NULL,3,1,2,1,NULL,'inna_batrak'),(16045,762769162002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','zhengx123','xzms@hotmail.com','Zheng Xiang','#205-1720 Richmond Ave','Victoria','BC','CANADA','V8R 4P8','(250) 588-5608','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 05:23:05',0,NULL,3,1,3,1,'RA184588586CN\r ','zhengx123\r灯架  2m     1\r换成反光伞  1\rB座换成云台      1\r永诺 CTR-301P 接受器 * 1\r永诺 CTR-301P 接受器 * 1'),(16046,722540508018,280722265640,'New 10 pcs Landscape Color Filters Kit for Cokin P',1,'AKT077',42,'photographyacc','ssouthur','scott@southurst.id.au','Scott Southurst','Suite 6c Global Innovation Centre<br>Technology Park','Mt Helen','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 06:46:05',0,NULL,3,1,3,1,'RA184588626CN ','ssouthur'),(16047,722538401018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','zriddle16','zach@hotmail.com.au','Zachary Riddle','59 Reardon Street','Calamvale','Queensland','AUSTRALIA','4116','0429319961','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'zriddle16\r结清再发'),(16048,758503545002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 07:37:51',0,NULL,3,1,2,1,NULL,'gedrasas'),(16049,847806391015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','ix0dides','ixo@umail.ie','Maciej Latusek','92 The Orchards','Kinsale','Cork','IRELAND','default','0867827333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 08:01:59',0,NULL,3,1,2,1,NULL,'ix0dides'),(16050,848004160015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','wacmwamaudave','wacmwa@hotmail.com','maudave stephan','12 collett pde','parramatta','New South Wales','AUSTRALIA','2150','0435769297','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 08:14:59',0,NULL,3,1,4,1,'YW865546114CN ','wacmwamaudave\r澳标'),(16051,722560369018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','wacmwamaudave','wacmwa@hotmail.com','maudave stephan','12 collett pde','parramatta','New South Wales','AUSTRALIA','2150','0435769297','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 08:20:33',0,NULL,3,0,2,1,NULL,'wacmwamaudave\r1.6*2.1 黑色背景布   1\r'),(16052,722568823018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','caratyuska','caratyuska@gmail.com','Peter Torok','Szechenyi street 56 3/2','Miskolc','BAZ','HUNGARY','3530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 08:56:38',0,NULL,3,1,2,1,NULL,'caratyuska'),(16053,720530157001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',194,'hermeshine','gk-finnrus','gk.finnrus@gmail.com','Georgii Karvonen','Heinämiehentie 19 B 4','Helsinki','Uusimaa','FINLAND','00660','0452071785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 08:56:49',0,NULL,3,1,12,1,'5241673640\r ','gk-finnrus\r1.6*2.1黑色+白色背景布\r申报US$40\r实重  7.1 抛重8.5   最终计费重量7.5'),(16054,778207558017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',2,'AKT030',116,'photographyacc','krispy-kris','kris.bech@hotmail.com','Kristofer Bech-Howley','6 Hare Court','Willagee','Western Australia','AUSTRALIA','6156','0893316370','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 09:14:48',0,NULL,3,1,4,1,'YW865546125CN ','krispy-kris'),(16055,830421316016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','fear_player','faer_player@one.lv','Vladimirs Vainus','62 Templenewsam Road<br>Halton','Leeds','West Yorkshire','UNITED KINGDOM','LS15 0DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 09:18:34',0,NULL,3,1,2,1,' ','fear_player\r环是77mm的'),(16056,762825445002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','mknofler2','raulramon@msn.com','Raul Ramon','Andres Vives Nº2 3ºC','Alcañiz','Teruel','SPAIN','44600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 09:58:59',0,NULL,3,1,2,1,NULL,'mknofler2'),(16057,830445009016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','pedrower','pedroherrador@hotmail.es','Pedro Herrador','c/ Pollensa, 4 - 2º. Oficina 14','Las Rozas','Madrid','SPAIN','28290','660127210','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-07 10:35:25',0,NULL,3,1,11,1,'\\ ','pedrower\r差五元'),(16058,720792136001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','arachnids10','aakkash@hotmail.com','Aakash Dangol','14/854 pascoe vale rd<br>glenroy','Melbourne','Victoria','AUSTRALIA','3046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 10:44:25',0,NULL,3,1,2,1,NULL,'arachnids10'),(16059,762844861002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ashaker11','ahmed.shaker@inbox.com','Ahmed Shaker','Olaya Road, North - Morooj District<br>P.O. Box 87925 Riyadh 11652 Saudi Arabia','Riyadh','Riyadh','SAUDI ARABIA','11652','966569169710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:15:30',0,NULL,3,1,3,1,'RA184588731CN ','ashaker11'),(16060,722604476018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','caratyuska','caratyuska@gmail.com','Peter Torok','Szechenyi street 56 3/2','Miskolc','BAZ','HUNGARY','3530','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 11:16:46',0,NULL,3,1,2,1,NULL,'caratyuska'),(16061,830461675016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','c6bon','lens444@yahoo.fr','Jean Louis Carrasco','57 rue du Moulin Vert','PARIS','PARIS','FRANCE','75014','+33611183830','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 11:26:07',0,NULL,3,1,17,0,NULL,'c6bon'),(16062,830454632016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',115,'hutongstore','c6bon','lens444@yahoo.fr','Jean Louis Carrasco','57 rue du Moulin Vert','PARIS','PARIS','FRANCE','75014','+33611183830','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 11:26:08',0,NULL,3,1,12,1,'5241673953 ','c6bon\rc以外再发：\r灯架  2m   1\r柔光箱 50-70cm 单灯头  1  欧标\r斜臂    1\r115w 5500k 灯泡  220v   1\r灯架包     1\r实重 8.7  抛重：9.6 最终计费重量10kg\r'),(16063,720809618001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','cepilin','verikas@yandex.ru','victor verikas','9 - 5v - 32','Temirtau','Karaganda region','KAZAKHSTAN','101400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:52:29',0,NULL,3,1,5,1,'CP235628922CN ','cepilin\rtripod  $22\r'),(16064,778252835017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','josephsondan','josephson.dan@gmail.com','Dan Josephson','Hannasi Shazar 17','Mazkeret Batya','','ISRAEL','76804','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 11:54:52',0,NULL,3,1,2,1,NULL,'josephsondan'),(16065,762856076002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'',98,'hermeshine','thebest1221','the-best1221@hotmail.com','Reda Almorohen','3013/3 Parkland boulevard','brisbane','Queensland','AUSTRALIA','4000','0412357681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 11:56:28',0,NULL,3,0,4,1,'YW865546136CN ','thebest1221\r2m 灯架   1\r斜臂   1\r60cm 闪光灯棚  （2层柔光布）   1\r已入库'),(16066,778230724017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',18.79,'photographyacc','saintsftw','go.the.saints@hotmail.com','dong hong lin','24 McKenzie St','Doncaster East','Victoria','AUSTRALIA','3109','0431902330','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 11:35:45',0,NULL,3,1,3,1,'RA184587665CN ','saintsftw\r反光伞    1\r1.6x2.1 白色背景布   1'),(16067,720820467001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','uliukas','jovitn@gmail.com','Jovita Nevierienė','Josvainiu 43-4','Kedainiai','','LITHUANIA','57267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 12:29:48',0,NULL,3,1,2,1,NULL,'uliukas'),(16068,761844348002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',51.99,'hermeshine','caczerny','carlos.czerny@gmail.com','Carlos Victor  Czerny','Santa Fe 1743 PB Dto2','Avellaneda','Buenos Aires','ARGENTINA','1870','15-5019-3614','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 12:30:45',0,NULL,3,1,3,1,'RA184588759CN ','caczerny\r2云柔   1\rcanon 三角包    1'),(16069,720824265001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','matosfotografia','matosfotografia@gmail.com','Francisco José Moniz Matos','Rua Batista Pereira Nº 27 R/c Drt','Forte da Casa','Povoa Santa Iria','PORTUGAL','2625-400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 12:42:24',0,NULL,3,1,2,1,NULL,'matosfotografia\r红盒，canon logo， 植绒'),(16070,762872084002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','digmail','ipdigma@gmail.com','Olga Petrov','Krinitzi St. 80/10','Ramat Gan','','ISRAEL','52601','972545547910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 12:52:20',0,NULL,3,1,3,1,'RA184588612CN ','digmail'),(16071,762755009002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','maurolisboa','lisboa_mauro@hotmail.com','Mauro Lisboa Annicchiarico','13430 S.W. 131 St.<br>P.O.BOX NB# 123497','Miami','FL','UNITED STATES','33186','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 13:11:24',0,NULL,3,1,3,1,'RA184588802CN ','maurolisboa'),(16072,848105379015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','ellie-rs','novakova.elza@seznam.cz','Eliška Nováková','Uhersko 9','Uhersko','pardubický','CZECH REPUBLIC','53373','+420737556298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 13:25:58',0,NULL,3,1,2,1,NULL,'ellie-rs'),(16073,762883157002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','eggyloom','eggyloom@hotmail.com','Egert Lehtla','Tähe 86-1','Tartu','Tartu','ESTONIA','50107','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:26:28',0,NULL,3,1,2,1,NULL,'eggyloom'),(16074,762882960002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','bahadircoban','bahadir.coban@gmail.com','duygu karasu','8291 Sokak No: 1 Caher Dudayev Bulvarı adenpark sitesi A1 Blok<br>Kat: 5 Daire: 21 Mavisehir  Izmir ZIP: 35530','İZMİR','','TURKEY','35530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 13:27:30',0,NULL,3,1,3,1,'RA184588728CN ','bahadircoban\r分开发\rRA184588745CN'),(16075,722648191018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','lakeside-bookshop','gostolat@charter.net','Terri Gostola','223 Seneca Pl','Cadillac','MI','UNITED STATES','49601','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 13:35:45',0,NULL,3,1,1,1,NULL,'lakeside-bookshop'),(16076,720840937001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',8.99,'hermeshine','expert2102','janaphoto@yandex.ru','Yana Danilova','Stepana Razina st. 60/167','Izhevsk','RU','RUSSIAN FEDERATION','426032','7-919-901-79-52','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 13:36:52',0,NULL,3,1,2,1,NULL,'expert2102'),(16077,720841830001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sadeq tawfeek','Qatif','tarout','QATIF','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 13:45:42',0,NULL,3,1,3,1,'RA184588714CN ','tawfeekmohammed'),(16078,848118828015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','turniplipz','kanlailey@googlemail.com','Kan Lailey','2 Friar Close','Brighton','East Sussex','UNITED KINGDOM','bn16nr','07809611666','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 13:48:07',0,NULL,3,1,4,1,'YW865546140CN ','turniplipz'),(16079,720849745001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','cholladino','dmetla@gmail.com','Dino Metlicic','Supetar 4<br>Poljica - Marina','Trogir','Dalmatia','CROATIA','21222','+385989893073','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 14:04:14',0,NULL,3,1,2,1,NULL,'cholladino'),(16080,848127557015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','danighost-2008','andreoli_d@yahoo.it','Daniele Andreoli','V.le della Libetà 6','Sangiano','VA','ITALY','21038','0332 628995','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 14:09:47',0,NULL,3,1,2,1,NULL,'danighost-2008'),(16081,778310653017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','infrarot-foto','ricohallas@online.de','Rico Hallas','Zwickauer Str. 101','Dresden','','GERMANY','01187','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 14:45:51',0,NULL,3,1,2,1,NULL,'infrarot-foto'),(16082,762920698002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','priseris','menovell@hotmail.com','José Valero Sánchez','c/ Maria Luisa Ruiz, 17 (1ºK)','Petrer','Comunidad Valenciana','SPAIN','03610','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 15:21:54',0,NULL,3,1,17,0,NULL,'priseris'),(16083,762923883002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','priseris','menovell@hotmail.com','José Valero Sánchez','c/ Maria Luisa Ruiz, 17 (1ºK)','Petrer','Comunidad Valenciana','SPAIN','03610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:30:14',0,NULL,3,1,17,0,NULL,'priseris'),(16084,564965391003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','priseris','menovell@hotmail.com','José Valero Sánchez','c/ Maria Luisa Ruiz, 17 (1ºK)','Petrer','Comunidad Valenciana','SPAIN','03610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:30:14',0,NULL,3,1,4,1,'YW865546151CN ','priseris\r三脚架  伟峰 WF-6662A    1\r圆形柔光棚 50cm   1\r爵影红外 nikon     1'),(16085,762931537002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','oddlet007','oddlet@hotmail.com','KRIT ONWAN','549/138 jaransanitwong rd.<br>bangkhunsri','bangkoknoi','bangkok','THAILAND','10700','66818211007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:49:30',0,NULL,3,1,2,1,NULL,'oddlet007'),(16086,762932902002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','gobiosoma76','gobiosoma@i.ua','Yamkovyy Ruslan','str.Mira 21 - 14','Komsomolsk','Poltava region','UKRAINE','39800','+380686416869','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 15:52:45',0,NULL,3,1,3,1,'RA184588691CN ','gobiosoma76'),(16087,830594573016,260660051795,'New 100% Genuine Lenspen x 2 lens perfect cleaning tool',1,'AKT051',7.52,'hutongstore','jimmya222','jimmyacris@gibtelecom.net','Mr J.W.Acris','25 crown Daisy House<br>Waterport terrace','Gibraltar','Gibraltar','GIBRALTAR','GX11 1AA','00350 20051701','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 16:50:22',0,NULL,3,1,2,1,NULL,'jimmya222'),(16088,830610141016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','davidwademuir','daviekirkmuir@yahoo.co.uk','David Muir','23 Bellfield Cres','Barrhead / Glasgow','East Renfrewshire','UNITED KINGDOM','G78 1HL','01415637061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 17:20:17',0,NULL,3,1,2,1,NULL,'davidwademuir'),(16089,762972671002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',79.76,'hermeshine','vacarciucalexandru','quizzical@inbox.ru','Vacarciuc Alexandru','Alba-Iulia 89/1 ap.15','Chisinau','Republic of Moldova','MOLDOVA, REPUBLIC OF','MD2071','+373 69441029','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 17:33:28',0,NULL,3,1,3,1,'RA184587838CN ','vacarciucalexandru\r分开发 \rRA184588665CN'),(16090,762974599002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','emil_akhmadi','akhmadistudio@gmail.com','Emil Akhmadeev','Khimikov, dom 27, kv. 59','Kazan','Tatarstan','RUSSIAN FEDERATION','420085','+79046668659','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-07 17:36:36',0,NULL,3,1,17,0,NULL,'emil_akhmadi'),(16091,762975703002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','emil_akhmadi','akhmadistudio@gmail.com','Emil Akhmadeev','Khimikov, dom 27, kv. 59','Kazan','Tatarstan','RUSSIAN FEDERATION','420085','+79046668659','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 17:38:44',0,NULL,3,1,5,1,'CP235628936CN ','emil_akhmadi\r反光板 100*150 40*60 5合1    1\r闪光的柔光箱   60cm    1\r超重就发sal  '),(16092,719836651001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','art-latinamerican','eduardocastrejon@prodigy.net.mx','EDUARDO CASTREJON','8854 Feather Trl','Helotes','TX','UNITED STATES','78023-4486','(210) 372-9773','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-07 17:53:58',0,NULL,3,1,1,1,NULL,'art-latinamerican'),(16093,722754136018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','carlv090','cnventer@telkomsa.net','Carl Venter','PO Box 40014<br>Moreletaridge','Pretoria','Gauteng','SOUTH AFRICA','0044','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 17:59:53',0,NULL,3,1,3,1,'RA184568357CN\r ','carlv090'),(16094,848296741015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','aochristian','aoccommunications@yahoo.co.uk','Christian Ashaiku','98 Bedford Road<br>Edmonton','London','London','UNITED KINGDOM','N9 7DB','02088045742','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-07 19:21:39',0,NULL,3,1,17,0,NULL,'aochristian\r'),(16095,720981601001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','aldagu','gubitosi@adinet.com.uy','Daniel Gubitosi','Paraguay 1068','Montevideo','','URUGUAY','11100','29015345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 19:29:53',0,NULL,3,0,3,1,'RA184588688CN ','aldagu\r NIKON  x 52mm  2\rNIKON  x 62mm  2\rNIKON  x 67mm  2\rNIKON  x 72mm  2\rNIKON  x 77mm  2\r已入库'),(16096,778467503017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',52,'photographyacc','1717kane','michael61@dodo.com.au','Michael Phipps','15 Kununurra Cr Shailer Park','Brisbane','Queensland','AUSTRALIA','4128','0732096020','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-07 20:13:06',0,NULL,3,1,17,0,NULL,'1717kane'),(16097,778467698017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','1717kane','michael61@dodo.com.au','Michael Phipps','15 Kununurra Cr Shailer Park','Brisbane','Queensland','AUSTRALIA','4128','0732096020','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-07 20:13:07',0,NULL,3,1,4,1,'YW865546162CN ','1717kane\r三脚架  伟峰 WF-6662A    1\r带水平仪 热靴保护盖   1'),(16098,830726632016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','veretine','alexandre.veretine@gmail.com','Alexandre Veretine','Vaijeritie 3c1','Vantaa','','FINLAND','01640','+358407342838','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-07 20:30:42',0,NULL,3,0,17,0,NULL,'veretine'),(16099,722852224018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','gtarasiuk','guuutarasiuk@hotmail.de','Gustavo Tarasiuk','Rua Carneiro Lobo, 243 AP 1801','Curitiba','Paraná','BRAZIL','80240-240','554191585889','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-07 21:04:04',0,NULL,3,1,3,1,'RA184568799CN\r ','gtarasiuk'),(16100,848331746015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','veretine','alexandre.veretine@gmail.com','Alexandre Veretine','Vaijeritie 3c1','Vantaa','','FINLAND','01640','+358407342838','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-07 20:30:45',0,NULL,3,1,12,1,'5238175143\r ','veretine\r欧标\r除了c 再发\r1.6*3 白色背景布  1'),(16101,721037981001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','beygv','info@flashteam.biz','Alma Kadic','15. april bb','Gornji Vakuf','SB','BOSNIA AND HERZEGOVINA','70240','030265245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 21:31:37',0,NULL,3,1,5,1,'CP235628940CN ','beygv'),(16102,721036056001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','titoeuftoeuf','titoeuf@artpix.fr','Teddy DUMONT','8 Allée de Beaulieu<br>Apt 146 - 2 Etage','Amiens','Picardie','FRANCE','80090','0649883327','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 21:36:38',0,NULL,3,1,2,1,NULL,'titoeuftoeuf'),(16103,762898198002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','tinolive','tinolive@hotmail.com','Olivier Amiens / Emanuelle Pluchon','11 avenue de Vert Bois','CRAN GEVRIER','Rhône-Alpes','FRANCE','74960','0674203952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 22:47:26',0,NULL,3,1,17,0,NULL,'tinolive'),(16104,720210136001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',30.29,'hermeshine','tinolive','tinolive@hotmail.com','Olivier Amiens / Emanuelle Pluchon','11 avenue de Vert Bois','CRAN GEVRIER','Rhône-Alpes','FRANCE','74960','0674203952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-07 22:47:27',0,NULL,3,1,3,1,'RA184588705CN ','tinolive\r防寒罩     1\r镜头筒 中号     1\r430Ex 肥皂盒     1\r爵影sony 红外    1\r60cm 2 和1反光板   1\rsony 热靴保护盖   1\r内胆包无字加大       1\r已入库\r\r'),(16105,848407107015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',6.7,'hutongstore','krisshaw0192','satansworkisdone@hotmail.com','kristian shaw','54 fairfield drive','ossett','West Yorkshire','UNITED KINGDOM','wf50du','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-07 22:58:18',0,NULL,3,1,2,1,NULL,'krisshaw0192'),(16106,721072607001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','ruazn2','ru_azn2@hotmail.com','Wei Jie Cheng','4628 Thimbleberry Ln','San Jose','CA','UNITED STATES','95129-1946','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-07 23:53:38',0,NULL,3,1,1,1,NULL,'ruazn2'),(16107,722916032018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','arekudemon','arekudemon@underabluesky.com','Alexandra Szweryn','182 Jones Road<br>Carina Heights','Brisbane','Queensland','AUSTRALIA','4152','0733953686','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 00:41:03',0,NULL,3,1,2,1,NULL,'arekudemon'),(16108,777614859017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','barnabas880','rmcleodx@shaw.ca','Ron McLeod','108-6450 Dawson Road','Prince George','BC','CANADA','V2K 5Y4','(250) 962-8181','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 02:04:36',0,NULL,3,1,2,1,NULL,'barnabas880'),(16109,722938195018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',248,'photographyacc','jevadamir','damirjevtic@gmail.com','Damir Jevtic','Save Jugo Bujkove 23','Rijeka','Primorsko-goranska zupanija','CROATIA','51000','00385915720398','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 02:07:05',0,NULL,3,1,5,1,'CP235628919CN ','jevadamir\r申报$50'),(16111,8881315450458309,111,'一堆（详见notes - 和上一票一模一样）',0,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-08 02:54:18',0,NULL,3,1,12,1,'5238175154\r ','0907 12:42 - 付款信\r2m 灯架 * 4\r柔光箱 60-60cm  四灯头（60x60的棚） * 4\r45w 5500k 灯泡 110v * 8\r灯架包 *2  (已入库）'),(16112,722953443018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','sydneyview','jandmpass@gmail.com','John Passmore','18 Woodstock Road','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 03:12:25',0,NULL,3,1,3,1,'RA184588780CN ','sydneyview\r已入库'),(16113,722956327018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','anniesbitz2011','anniesbitz@hotmail.com','Annie Laird','Canoona ave','Windsor downs','New South Wales','AUSTRALIA','2756','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 03:27:16',0,NULL,3,0,2,1,NULL,'anniesbitz2011\r白色'),(16114,848486691015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','afdhusni','afdzal@bimbholdings.com','Afdzal Husni Hussain','BIMB Holdings Berhad, L18 Menara Yayasan Tun Razak<br>No 200, Jln Bukit Bintang','Kuala Lumpur','WP Kuala Lumpur','MALAYSIA','55100','0327812999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 03:30:55',0,NULL,3,1,2,1,NULL,'afdhusni'),(16115,763183573002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','topgor','topgor@teol.net','Goran Topic','Visokih Decana 11','Banjaluka','Republika Srpska','BOSNIA AND HERZEGOVINA','78000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 03:49:57',0,NULL,3,0,3,1,'RA184588776CN ','topgor\rXL   已入库'),(16116,763192520002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','sonnymaniego','smctm@global.net.pg','RENATO MANIEGO','PAPINDO TRADING CO PTY LTD','LAE CITY MOROBE PROVINCE','','PAPUA NEW GUINEA','00000','4722930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:40:54',0,NULL,3,1,2,1,NULL,'sonnymaniego'),(16117,763193440002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',2,'AO0023',550,'hermeshine','allinaclick','dallarosa.enterprises@bigpond.com','Michael  Dalla Rosa','30 Freelands Drv','Burnside Heights','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 04:46:51',0,NULL,3,1,4,1,'YW867471852CN ','allinaclick'),(16118,763197167002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',50.45,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:24:35',0,NULL,3,1,17,0,NULL,'shadowsing11'),(16119,763197100002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',50.45,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:24:35',0,NULL,3,1,17,0,NULL,'shadowsing11'),(16120,721994358018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','soslo_31','jesspignotti@hotmail.com','jess pignotti','86 white ave','mount gambier','South Australia','AUSTRALIA','5290','0887258055','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-08 05:30:23',0,NULL,3,1,4,1,'YW865546195CN ','soslo_31\r白+黑\r'),(16121,763201081002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 05:33:06',0,NULL,3,1,3,1,'RA184569131CN\r','shadowsing11\r无牌方镜10片装套装   2\r77mm ring   2\r72mm ring   1\r普通托架   1\r广角托架   1\r'),(16122,778635846017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',2,'AD1401',15.6,'photographyacc','rodrigogianesi','rogianesi@gmail.com','Rodrigo Gianesi','Rua das Gérberas 209<br>Alphaville D. Pedro','Campinas','SP','BRAZIL','13097170','+5519 32070754','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 06:28:29',0,NULL,3,1,2,1,NULL,'rodrigogianesi\r递四方或者国内小包\r475'),(16123,721019391001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','pravinselva','shelva9@hotmail.com','Selva Anathakumar','Reina 10','Hareid','More og Romsdal','NORWAY','6060','99011932','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 06:40:01',0,NULL,3,1,4,1,'YW865546206CN ','pravinselva\r给我泡重也'),(16124,722990622018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','coconutq','anotherfish@gmail.com','Quan Do','55 Rossmore Avenue','Punchbowl','New South Wales','AUSTRALIA','2196','0414880821','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 06:40:41',0,NULL,3,1,3,1,'RA184587841CN ','coconutq'),(16125,848539392015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','charlotte_rose2008','charlotte_rose@email.com','Charlotte Rose','P.O Box 256<br>Stratford','Cairns','Queensland','AUSTRALIA','4870','0740519466','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 07:28:56',0,NULL,3,1,3,1,'RA184587824CN ','charlotte_rose2008'),(16126,721169284001,110408007449,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',7.3,'hermeshine','robbb76','rob_davies@blueyonder.co.uk','Robert Davies','20 Netherwood Road<br>Norris Green','Liverpool','Merseyside','UNITED KINGDOM','L115AU','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardRate','2011-09-08 07:42:41',0,NULL,3,1,2,1,NULL,'robbb76'),(16127,8881315468680939,111,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',225,'photographyacc','17_cameras','ww2011@live.com.au','Wayne W','P.O BOX 2057 ','Bedford','Western Australia','AUSTRALIA','6052','',NULL,NULL,NULL,'2011-09-08 07:58:00',0,NULL,3,1,4,1,'YW867471863CN',NULL),(16128,723022549018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','gkocougar','gkreilly5@bigpond.com.au','Pam Reay (Kylie Reay-Reilly)','DO NOT SAFE DROP<br>36 Queen Street','WARNERS BAY','New South Wales','AUSTRALIA','2282','0437123279','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-08 09:10:38',0,NULL,3,1,4,1,'YW867471874CN ','gkocougar'),(16129,721189903001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','touta_maruca','lucianodivalentino@libero.it','Luciano Di Valentino','C.da San Giovanni 1 H','Francavilla al Mare','CH','ITALY','66023','+393287166195','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 09:22:21',0,NULL,3,0,2,1,NULL,'touta_maruca\r灰色'),(16130,762792725002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','arrkart','aridany@gmail.com','Aridany Ramírez Rodríguez','c Farmacuetico Pedro Rivero nº 11, 9ºC','Las Palmas de Gran Canaria','Canarias','SPAIN','35013','649055805','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 09:32:51',0,NULL,3,1,3,1,'RA184587753CN ','arrkart'),(16131,723042469018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','pinkygirl17','craft17@bigpond.net.au','Pina Chaplin','50 Federation Way','Andrews Farm','South Australia','AUSTRALIA','5114','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 10:27:57',0,NULL,3,0,3,1,'RA184587767CN ','pinkygirl17\rxxxl   已入库'),(16132,720854388001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',245.96,'hermeshine','oiramrep','marioper@libero.it','industries spa/peron mario','via venezia 1','trebaseleghe','padova','ITALY','35010','3470819631','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 10:35:31',0,NULL,3,1,4,1,'YW867471885CN\r ','oiramrep\r85cm 两用伞     1\r反光板  80cm 5合1    1\r3m 伸缩横杆      1\r灯架  2m     2\r柔光箱 60-60cm  四灯头  欧标    2\r45w 5500k 灯泡 220v       8\r灯架包        1\r已入库\r燕文一票两件  横杆单发'),(16133,565206547003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','mrzoro82','mr.zoro@gmail.com','Zoran Mrdjenovic','Vojvode Momcila 8','Banja Luka','','BOSNIA AND HERZEGOVINA','78000','0038765567162','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 10:49:41',0,NULL,3,1,5,1,'CP238031158CN ','mrzoro82'),(16134,778720288017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','brett_fisher','brett_fisher61@yahoo.com.au','Andreas Herrmann','22 Windrest street<br>Aspley','Brisbane','Queensland','AUSTRALIA','4034','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 12:05:20',0,NULL,3,1,2,1,NULL,'brett_fisher\r澳标\r 电话  0405317223'),(16135,763293605002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','hobbaac','hobbaac82@bigpond.com','Isaac Jaensch','c/- Nextbyte - Bundall Circle<br>12 Upton St','Bundall','Queensland','AUSTRALIA','4217','0410012545','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 12:37:57',0,NULL,3,0,4,1,'YW867471896CN ','hobbaac\r澳标'),(16136,723088807018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','andrewclark1983','ajcalh@iinet.net.au','Andrew Clark','6 Belgrade Road, Wanneroo','Perth','Western Australia','AUSTRALIA','6065','0894059479','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 14:03:49',0,NULL,3,1,3,1,'RA184568768CN ','andrewclark1983'),(16137,723107588018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','d.vega650','vega650@hotmail.com','David Vega Martin','IBM Avenida Diagonal 571 bajo','Barcelona','Cataluña','SPAIN','08029','650264778','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 14:04:10',0,NULL,3,0,17,0,NULL,'d.vega650'),(16138,721267430001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',2,'AD1179',31.8,'hermeshine','kasadmin','jim@j-evans.com','Jim Evans','12205 Jason Dr','Medway','OH','UNITED STATES','45341-9651','(937) 405-1790','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 14:06:05',0,NULL,3,1,1,1,NULL,'kasadmin'),(16139,723114549018,280689694480,'New Continuous Lighting System umbrella with bulbs',1,'AKT068',115,'photographyacc','d.vega650','vega650@hotmail.com','David Vega Martin','IBM Avenida Diagonal 571 bajo','Barcelona','Cataluña','SPAIN','08029','650264778','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 14:24:33',0,NULL,3,0,4,1,'YW865546372CN ','d.vega650\r除了c 里面的再发\r背景架 2mx3m 河北 + 1.6x2.1 白 +夹子   1\r欧标  实重和泡重\r实重7.215\r抛重9.72\rlighting kit $35'),(16140,848688456015,250847020386,'Green Slim 77mm Fader ND Filter adjustable ND2 to ND400',1,'AD1143',27.9,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 14:53:31',0,NULL,3,1,3,1,'RA184561685CN ','photosax'),(16141,848687369015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 14:53:32',0,NULL,3,0,17,0,NULL,'photosax'),(16142,831068906016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0003',169,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 14:53:32',0,NULL,3,1,4,1,'YW865546383CN','photosax\r可调ND镜 77mm     1\r带水平仪 热靴保护盖   1\r717  180    1'),(16143,721297319001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 15:53:03',0,NULL,3,1,17,0,NULL,'saud-p'),(16144,721267991001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 15:53:04',0,NULL,3,1,8,1,'CP238031011CN ','saud-p\r背景架2m x 3m + 3个夹子     1\r1.6*2.1 黑色背景布     2\r灯架  2m    3\r斜臂    1\r柔光箱 50-70cm 单灯头欧标   3\r115w 5500k 灯泡  220v    3\r灯架包     1\r需要在灯架上贴 made in china    \r还需要申报实值\r实重，10.6    泡重： 12.7'),(16145,763355544002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','l-e0n','en72ri@libero.it','Enrico Savio','via Kennedy 32','Rivanazzano Terme','PV','ITALY','27055','327-7364505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 15:53:28',0,NULL,3,1,2,1,NULL,'l-e0n'),(16146,721313448001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','themk92','the-mk92@hotmail.fr','Aviv Itzhaky','54 rue villiers de l\'isle adam','paris','Île-de-France','FRANCE','75020','0682421731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 16:17:51',0,NULL,3,1,2,1,NULL,'themk92'),(16147,830700145016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0003',169,'hutongstore','aochristian','aoccommunications@yahoo.co.uk','Christian Ashaiku','98 Bedford Road<br>Edmonton','London','London','UNITED KINGDOM','N9 7DB','02088045742','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-08 16:32:05',0,NULL,3,1,4,1,'YW865546210CN','aochristian\rWT600     1\r717  180     1'),(16148,723171036018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','lemp797','lemp797@yahoo.com','Luis Enrique Munoz Palma','Mar del Norte 8126, PENALOLEN','Santiago','Region Metropolitana','CHILE','794-0208 PEN','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 16:53:39',0,NULL,3,1,2,1,NULL,'lemp797'),(16149,848766442015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',11.99,'hutongstore','grician_2007','grishain@gmail.com','Grigory Pilipenko','192/3 Vienibas Gatve Str., Apt. 9','Riga','','LATVIA','LV-1058','+37129548923','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-08 17:31:26',0,NULL,3,1,2,1,NULL,'grician_2007'),(16150,721321362001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','maneedang','e_maneedang@hotmail.com','NARET JAISOMKHOM','5/7 soi tandiew, asia road<br>tumbon maesot','maesot','tak','THAILAND','63110','0857276756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 17:40:46',0,NULL,3,1,17,0,NULL,'maneedang'),(16151,565282398003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','maneedang','e_maneedang@hotmail.com','NARET JAISOMKHOM','5/7 soi tandiew, asia road<br>tumbon maesot','maesot','tak','THAILAND','63110','0857276756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 17:40:48',0,NULL,3,1,17,0,NULL,'maneedang'),(16152,721307290001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','maneedang','e_maneedang@hotmail.com','NARET JAISOMKHOM','5/7 soi tandiew, asia road<br>tumbon maesot','maesot','tak','THAILAND','63110','0857276756','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 17:40:47',0,NULL,3,1,6,1,'EE645685488CN ','maneedang\r大力夹云台      1\r手动升降背景架      1\rWT600    1'),(16153,723193620018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','tbaier1','tomaz.baier@gmail.com','Tomaž Baier','Trčova 260','Maribor','Malečnik','SLOVENIA','2229','0038641824993','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 17:43:34',0,NULL,3,0,3,1,'RA184587798CN ','tbaier1\rxxl   已入库'),(16154,763411490002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',45.9,'hermeshine','dphotom','dpuigmataro@gmail.com','David Puig Bermejo','C/: Pujol, 26 2n 2a','Mataró','Cataluña','SPAIN','08301','626925962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 18:05:33',0,NULL,3,1,17,0,NULL,'dphotom'),(16155,721361444001,110451007962,'New Timer Remote Control for Canon EOS 5DMarkII 5D 50D',1,'AA3222',45.9,'hermeshine','dphotom','dpuigmataro@gmail.com','David Puig Bermejo','C/: Pujol, 26 2n 2a','Mataró','Cataluña','SPAIN','08301','626925962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 18:09:36',0,NULL,3,1,3,1,'RA184587807CN ','dphotom\r永诺 MC-C1   1\r永诺 MC-C3      1'),(16156,763419720002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','shamsheeds','studio.s@intnet.mu','shamsheed sobha','4 dorades st<br>elizabethvile','tombeau bay','','MAURITIUS','230','2307655030','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-08 19:10:50',0,NULL,3,1,17,0,NULL,'shamsheeds'),(16157,721392076001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','alexstar333','alexstar333.ebay@gmail.com','ALEXANDR STARODUBTSEV','AKADEMIKA BAHA<br>DOM 11/1, KV.45.','NIZHNIY NOVGOROD','NIZHEGORODSKAYA OBL','RUSSIAN FEDERATION','603132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 19:12:17',0,NULL,3,1,2,1,NULL,'alexstar333'),(16158,763430122002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','shamsheeds','studio.s@intnet.mu','shamsheed sobha','4 dorades st<br>elizabethvile','tombeau bay','','MAURITIUS','230','2307655030','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 19:10:49',0,NULL,3,1,3,1,'RA184587719CN','shamsheeds\r爵影碗罩P1      1\r永诺 CTR-301P 触发器    1\r永诺 CTR-301P 接受器   1'),(16159,718937914001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 21:07:32',0,NULL,3,0,17,0,' ','123dmarion'),(16160,718941594001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-08 21:07:47',0,NULL,3,0,17,0,NULL,'123dmarion'),(16161,760957056002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','123dmarion','dmarion1959@primus.ca','David Marion','6361 Sterling Dr N','Sterling Heights','MI','UNITED STATES','48312-4553','(800) 696-9218 ext.: 1243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-08 21:07:50',0,NULL,3,0,1,1,NULL,'123dmarion\r肥皂盒 柔光罩   sb800    1\rEW-78D     1  有made in japan字样的那种，放在红盒里发\r绿叶 CPL 72mm     1'),(16162,723297324018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','evil--akuma','evil-akuma@hotmail.com','DAWOOD MOHD SALEH/dxb 13447','147-29 182nd St','Springfield Gardens','NY','UNITED STATES','11413','718 553 8740','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-08 21:16:08',0,NULL,3,1,1,1,NULL,'evil--akuma'),(16163,763509855002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','agvrt','a.gevart@libertysurf.fr','GEVART ARTHUR','74 RUE DU PORT BOYER','NANTES','Pays de la Loire','FRANCE','44300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 21:33:21',0,NULL,3,1,3,1,'RA184587722CN ','agvrt'),(16164,723307277018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',3,'AD1170',26.97,'photographyacc','smalltimejackson','grevzin@hotmail.com','Gennady Revzin','6/61 Ormond Road','Elwood','Victoria','AUSTRALIA','3184','0399390730','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 21:35:00',0,NULL,3,1,2,1,NULL,'smalltimejackson'),(16165,778971883017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',99.56,'photographyacc','spothandy-sandy','baznsan@bigpond.com','Sandra Johnston','12 Rouse Street','WORONGARY','Queensland','AUSTRALIA','4213','0755227000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-08 22:02:15',0,NULL,3,1,4,1,'YW865546221CN ','spothandy-sandy\r2 B 柔    1\r110cm 5和1     1\r67cm 遮光罩    1\r镜头笔    2\r爵影无线C1   1\r已入库'),(16166,763524512002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','atias007','tsahiatias@gmail.com','Tsahi Atias','Zabutinski 50/1103','Givaat Shmuel','','ISRAEL','54010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-08 22:18:56',0,NULL,5,1,3,1,'RA184587736CN','atias007\r已发货改不了状态'),(16167,721199683001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','stroev_2009','stroev@stroev.ru','Yury Stroev','Palchevskogo, 33','Vladivostok','','RUSSIAN FEDERATION','690041','+79242444444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:15:02',0,NULL,3,1,17,0,NULL,'stroev_2009'),(16168,721203361001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','stroev_2009','stroev@stroev.ru','Yury Stroev','Palchevskogo, 33','Vladivostok','','RUSSIAN FEDERATION','690041','+79242444444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:15:02',0,NULL,3,1,17,0,NULL,'stroev_2009'),(16169,721145861001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',34.77,'hermeshine','stroev_2009','stroev@stroev.ru','Yury Stroev','Palchevskogo, 33','Vladivostok','','RUSSIAN FEDERATION','690041','+79242444444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 00:37:37',0,NULL,3,1,3,1,'RA184587740CN ','stroev_2009\r单灯头  欧标   2\r大力夹云台    2\r45w 5500k 灯泡 220v     2\r大力夹    2\r已入库'),(16170,779024869017,270755378942,'4 Bulb Stocks with 24x24\"/60x60cm Folding Easy Soft box',2,'AE2201',84,'photographyacc','baronesabeor','solbeor@hotmail.com','Cynthia Lebedinsky','Amenabar 1055 6 D','Capital Federal','Buenos Aires','ARGENTINA','1426','00541147869459','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 00:49:40',0,NULL,3,1,17,0,NULL,'baronesabeor'),(16171,779023030017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','carolyn03070','carolyn.whamond@telstra.com','Carolyn Whamond','394 Sandy Bay Road','Sandy Bay','Tasmania','AUSTRALIA','7005','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-09 00:52:03',0,NULL,3,1,2,1,NULL,'carolyn03070'),(16172,723361243018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','baronesabeor','solbeor@hotmail.com','Solange Latorre Beorlegui','Amenabar 1055 6 D','Capital Federal','Buenos Aires','ARGENTINA','1426','00541147869459','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 00:52:43',0,NULL,3,1,17,0,NULL,'baronesabeor'),(16173,779027316017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','baronesabeor','solbeor@hotmail.com','Solange Latorre Beorlegui','Amenabar 1055 6 D','Capital Federal','Buenos Aires','ARGENTINA','1426','00541147869459','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 00:56:33',0,NULL,3,1,5,1,'CP238031161CN ','baronesabeor\r柔光箱 60-60cm  四灯头    2\r灯架  2m   2\r单灯头 欧标    1\r反光伞   1 '),(16174,721520904001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','creativechan77','mannychan77@aol.com','manny chan','6428 Stewart Rd','galveston','TX','UNITED STATES','77551-1879','(409) 740-3019','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 01:58:06',0,NULL,3,1,1,1,NULL,'creativechan77'),(16175,763582300002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','kearnsy_69','miss_kearnsy@live.com.au','renee kearns','2 whinmoor street','katoomba','New South Wales','AUSTRALIA','2780','0247829476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 02:10:42',0,NULL,3,1,2,1,NULL,'kearnsy_69'),(16176,721301287001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','lunaluvshockey','crlkluna@hotmail.com','Christine Ellis','22 Dewey Ave','Windsor','VT','UNITED STATES','05089-1104','(603) 573-5733','NoPaymentFailure','CheckoutComplete','Other','2011-09-09 02:40:27',0,NULL,5,0,18,0,NULL,'lunaluvshockey\r2XL  已入库'),(16177,8881315540202846,111,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',0,'photographyacc','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','',NULL,NULL,NULL,'2011-09-09 03:50:02',0,NULL,3,1,3,1,'RA184587775CN ','上一个坏了，补发一个新的。'),(16178,8881315541303868,111,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',102,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines<br>del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-09 04:08:23',0,NULL,3,1,12,1,'5238162053\r ','这票只发架子，2块布不发 \r实重 2.6  抛重2.9'),(16179,8881315541373514,111,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',246,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-09 04:09:33',0,NULL,3,1,12,1,'5238162075\r ','（背景布-白色）\r再加2块1.6x2.1m 背景布 （黑+白）、\r灯泡是110v  的  \r实重 8.3  抛重10.7'),(16180,779084031017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','mjp.klp','palmguitars@bigpond.com','michael palm','26 Seawitch Crescent','Cooloola Cove,','Queensland','AUSTRALIA','4580','0754864067','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-09 04:58:26',0,NULL,3,1,2,1,NULL,'mjp.klp'),(16181,721572497001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','helmesham','warlords80@hotmail.com','Helmesham Helmesham','Blk 740, Yishun Ave 5, #11-478, Singapore 760740','default','','SINGAPORE','760740','+6598502583','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-09 06:40:33',0,NULL,3,1,11,1,NULL,'helmesham'),(16182,723433958018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','stmad10','stmad10@hotmail.com','Steven Madsen','6 Convent Court','Caboolture','Queensland','AUSTRALIA','4510','0754280506','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-09 06:48:21',0,NULL,3,1,3,1,'RA184589003CN\r ','stmad10'),(16183,849069277015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','kalle385','zoran@kalinic.info','Zoran Kalinic','Gromacine 24','Njivice','','CROATIA','51512','385-51-847-147','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 06:59:33',0,NULL,3,1,11,1,NULL,'kalle385\r398'),(16184,849080591015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','fishfood0_1','stewart.harrison2@ntlworld.com','Stewart Harrison','15 Cloudside Rd, SANDIACRE','Nottingham','Derbyshire','UNITED KINGDOM','NG105FB','07928609522','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 07:46:17',0,NULL,3,1,2,1,NULL,'fishfood0_1'),(16191,761718933002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','inesmagalhaes','ineseskesita@hotmail.com','Ines Magalhaes','rua da costa grande de cima,904','Amarante','Europa','PORTUGAL','4600-681','+351-914945728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 10:42:39',0,NULL,3,1,2,1,NULL,'inesmagalhaes'),(16185,723055798018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',20,'photographyacc','happysmilingbuddha','tim.lin1983@gmail.com','Tim Lin','2 Eighth Avenue','Maylands','Western Australia','AUSTRALIA','6051','0433280080','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-09 08:53:43',0,NULL,3,1,3,1,'RA184588997CN\r ','happysmilingbuddha'),(16186,763667399002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','sharafin','arafin.sharif@gmail.com','Muhammad Sharif Ul Arafin','Dubai Islamic Bank<br>Business Banking - Cash Management, Al Shoala Building, 6th Flr','Dubai','Dubai','UNITED ARAB EMIRATES','1080','00971553004639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 09:33:36',0,NULL,3,1,17,0,NULL,'sharafin'),(16187,763667903002,120581410694,'NIB TianYa 72mm ND8 filter New 72 Neutral Density Grey',1,'AA2313',7.4,'hermeshine','sharafin','arafin.sharif@gmail.com','Muhammad Sharif Ul Arafin','Dubai Islamic Bank<br>Business Banking - Cash Management, Al Shoala Building, 6th Flr','Dubai','Dubai','UNITED ARAB EMIRATES','1080','00971553004639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 09:36:46',0,NULL,3,1,2,1,NULL,'sharafin\r天涯 ND8 67mm   1\r天涯 ND8 72mm     1'),(16188,763672701002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 09:57:52',0,NULL,3,1,4,1,'YW865546350CN ','roger-damngood\r燕文告之无人领取 现在货在当地邮局\r▲已发信\r客户收到了'),(16189,763674478002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','cesc116','duncan2107@hotmail.com','Javier Suescun Sádaba','Merindad de Sangüesa, 3-9º dcha.','Burlada','Navarra','SPAIN','31600','948124644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 10:08:31',0,NULL,3,1,2,1,NULL,'cesc116'),(16190,763678075002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','plowucha123','mplowucha@wp.pl','Magdalena Plowucha chez Guillaume Trouve','35, Rue Pascal','paris','Île-de-France','FRANCE','75013','06.67.11.82.97','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 10:20:43',0,NULL,3,1,2,1,NULL,'plowucha123'),(16192,848873680015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','pratheesh17','prath33sh@gmail.com','pratheesh suntharalingam','bekkestien 14','jessheim','','NORWAY','2050','+47 46698587','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 10:45:24',0,NULL,3,1,3,1,'RA184588847CN\r ','pratheesh17'),(16193,779163701017,270751510931,'YongNuo 10m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3326',45,'photographyacc','sommme','tsomogyi@web.de','Tibor Somogyi','Bergstr. 7','Boxdorf','','GERMANY','01468','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 11:01:09',0,NULL,3,1,3,1,'RA184588855CN\r ','sommme'),(16194,849157102015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','bex_bridge','artemisfx@gmail.com','Rebecca Bridge','6 Kings Quay Street','Harwich','Essex','UNITED KINGDOM','CO12 3EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 12:17:46',0,NULL,5,1,3,1,'RA184568167CN\r ','bex_bridge\r已发货改不了状态'),(16195,723389894018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',55,'photographyacc','zurucucu','ee_studio@hotmail.com','MONSAK HINPRAKOB','546/5 Tanaproncord (room-309)<br>soi 28 Ladprao 87  Wangtonglang','bangkok','bangkok','THAILAND','10310','66038709394','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 12:38:46',0,NULL,3,1,6,1,'EE645685430CN ','zurucucu\r付了ems的运费'),(16196,721654721001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','roger-damngood','benbrunnekreef@yahoo.com.au','Ben Brunnekreef','9/69 Alfred St','Ramsgate','New South Wales','AUSTRALIA','2217','0413754972','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-09 12:33:18',0,NULL,3,1,2,1,NULL,'roger-damngood'),(16197,779205497017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','luca3d90','luca.gianetti@hotmail.it','Luca Gianetti','Piazza Galileo Galilei  6 / 6<br>Albisola Superiore','Albisola Superiore','SV','ITALY','17011','3389285626','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 13:35:46',0,NULL,3,1,3,1,'RA184568215CN\r ','luca3d90\r接口环是67mm的， 已入库'),(16198,763750031002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','marpfa2003','martin@pfannenstein.net','Martin Pfannenstein','Arcisstr. 21<br>TUM / Lst. f. Medientechnik','München','','GERMANY','80333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 14:33:04',0,NULL,3,1,4,1,'YW865546361CN ','marpfa2003\r别忘了加一块柔光布\rlighting kit $25'),(16199,849261989015,250599395305,'52mm 52 Close Up  Macro Close-Up +8 Filter New',1,'AE3222',3.6,'hutongstore','mignon93','mignonwilson@ymail.com','Mignon wilson','28 , Holmes st<br>Holmes st','avon','Somerset','UNITED KINGDOM','bs5 9ty','07552512415','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 16:06:26',0,NULL,3,1,2,1,NULL,'mignon93'),(16200,762049113002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','marinerodelosmares','marinerodelosmares@hotmail.com','gustavo gracia comellas','maestro aguilar 28 - 9','valencia','Comunidad Valenciana','SPAIN','46006','676093076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 16:07:15',0,NULL,3,1,3,1,'RA184588833CN\r ','marinerodelosmares\r---\r新地址：\rC/San Vicente Martir 170-7\r46007\rValencia\rValencia\rComunidad Valenciana\rEspaña-Spain'),(16201,721730040001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',1,'AB3307',49.99,'hermeshine','1gpmltt3','gpmltt@hotmail.com','Gregory Miller','2416 Adelaide Dr','Thompsons Station','TN','UNITED STATES','37179','(615) 599-0644','NoPaymentFailure','CheckoutComplete','Other','2011-09-09 16:21:19',0,NULL,3,1,1,1,' ','1gpmltt3'),(16202,721751511001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','maariaa_maaria','maariaa@gmx.net','Maria Karzel','Martin-Buber Str. 30','Bremen','','GERMANY','28279','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 17:17:00',0,NULL,3,1,2,1,NULL,'maariaa_maaria'),(16203,721753929001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','pushlan','pushlan@gmail.com','Alexandr Osadcii','K. Marks, 150, apt. 7','Tiraspol','','MOLDOVA, REPUBLIC OF','MD3300','(373) 777-15352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 17:22:22',0,NULL,3,1,5,1,'CP235628896CN ','pushlan'),(16204,849305880015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',2.25,'hutongstore','abjele.2007','leabby@eircom.net','sharon sheridan','50 kilnacourt woods','portarlington','Laois','IRELAND','default','0578640353','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 17:35:18',0,NULL,3,1,2,1,NULL,'abjele.2007'),(16205,849332621015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','victorsalt','vicsalt@msn.com','Vittorio Saltalamacchia','7 compton gardens','frome','sommerset','UNITED KINGDOM','ba112xy','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 18:23:12',0,NULL,3,1,2,1,NULL,'victorsalt'),(16206,723660187018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','locke280290','engesser.patrick@web.de','Patrick Engeßer','Lerchenweg 4','Donaueschingen','','GERMANY','78166','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 18:37:33',0,NULL,3,1,3,1,'RA184588970CN\r ','locke280290'),(16207,763848766002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','philsal503','philbrault@gmail.com','Phil Brault','3631 W Commercial Blvd','Tamarac','FL','UNITED STATES','33309-3311','(954) 889-7770','NoPaymentFailure','CheckoutComplete','Other','2011-09-09 18:47:27',0,NULL,3,1,3,1,'RA184568462CN ','philsal503'),(16208,763848768002,120762404074,'600w Photography Lighting Kit 45w bulbs 110cm umbrella',1,'AKT078',90,'hermeshine','philsal503','philbrault@gmail.com','Phil Brault','3631 W Commercial Blvd','Tamarac','FL','UNITED STATES','33309-3311','(954) 889-7770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 18:47:28',0,NULL,3,1,17,0,NULL,'philsal503'),(16209,721787707001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',4,'AE2501',124,'hermeshine','philsal503','philbrault@gmail.com','Phil Brault','3631 W Commercial Blvd','Tamarac','FL','UNITED STATES','33309-3311','(954) 889-7770','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 18:47:28',0,NULL,3,1,4,1,'YW865546313CN ','philsal503\r反光板 100*150 40*60 5合1    1\r灯架  2m    1\r4灯头  伞孔    1\r110cm  反光伞  白面   1\r45w 110v    4  已入库\r反光板支架    4\r6.6     燕文一票两件\r美国走不了一票两件\r\r'),(16210,721794644001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.2,'hermeshine','mustard30005','doyle.zhang@gmail.com','Dao Zhang','9824 Georgia Ave<br>Apt 302','Silver Spring','MD','UNITED STATES','20902-5233','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 19:05:06',0,NULL,3,1,1,1,NULL,'mustard30005'),(16211,831734664016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','privetkakdela','serafimaya@gmail.com','Andrey Kudryashov','Hamovnicheskiy val 28 kv 54','Moscow','Moscow','RUSSIAN FEDERATION','119048','926 1921916','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 19:23:00',0,NULL,3,1,2,1,NULL,'privetkakdela'),(16212,849395351015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','kida1995','johnjuel@ofir.dk','john juel','nørregade 16','hørve','sjælland','DENMARK','4534','04520154090','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-09 20:14:29',0,NULL,3,1,3,1,'RA184588949CN\r ','kida1995'),(16213,721694097001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','seller_mike64','seller_mike64@yahoo.com','Mike Farrell','1515 W Main St','Greensburg','IN','UNITED STATES','47240-9585','(812) 662-6100','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 20:21:15',0,NULL,3,1,4,1,'YW865546324CN ','seller_mike64'),(16214,721834417001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','sashokass','sashokas@yandex.ru','Alexander Khudokormov','Bulvarnoe Koltso dom №15 - kvartira 120','Krasnodar','','RUSSIAN FEDERATION','350089','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 20:33:17',0,NULL,3,1,3,1,'RA184588935CN\r ','sashokass'),(16215,721827761001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','wisky_studio','wisky@wisky.ru','Andrey Guryanov','Melnikova 20/1 - ap.12','Kirov','','RUSSIAN FEDERATION','610006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 20:15:49',0,NULL,3,1,2,1,NULL,'wisky_studio'),(16216,721842458001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','bertoldo77','bertoldomio@mail.ru','Владимир Гринь','str. Mira, 4a<br>Volnovakha District','Bligniy','Donetskaya oblast','UKRAINE','85736','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-09 20:51:53',0,NULL,3,1,3,1,'RA184588921CN\r ','bertoldo77'),(16217,763916980002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','gerel125','gerry.leonardo@yahoo.com','GERARDO Leonardo','177B Mall Street<br>C-308 Pacific Towers','Tamuning','GU','UNITED STATES','96913','(671) 649-4547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-09 21:33:53',0,NULL,3,1,3,1,'RA184568405CN\r','gerel125\r放小布进去，柔光布有大小两种\r看一下重量'),(16218,721864143001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','klee8669','kohayre@broomfield.org','Kristy OHayre','5357 Rustic Ave','Firestone','CO','UNITED STATES','80504-5929','','NoPaymentFailure','CheckoutComplete','Other','2011-09-09 21:58:02',0,NULL,3,1,4,1,'YW865546291CN ','klee8669'),(16219,831819925016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','iwal8668','walker@ianlynne.freeserve.co.uk','Ian Walker','10 Grampian Way<br>LYTHAM','Lytham St Annes','Lancashire','UNITED KINGDOM','FY8 4TB','07801716457','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-09 22:20:59',0,NULL,3,1,2,1,NULL,'iwal8668'),(16220,763932230002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','nofotografia','danielagnese@hotmail.com','Daniel Agnese','Itapirú<br>35','Buenos Aires','Buenos Aires','ARGENTINA','1822','1536053154','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-09 22:22:46',0,NULL,3,1,3,1,'RA184588918CN\r ','nofotografia'),(16221,763936700002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','btownfisch','jfny78@gmail.com','John Fischer','415 Herondo St<br>Apt 259','Hermosa Beach','CA','UNITED STATES','90254-5508','(857) 472-3071','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-09 22:37:26',0,NULL,3,1,1,1,NULL,'btownfisch'),(16222,779416142017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',3,'AC1301',17.94,'photographyacc','cotebupa','majobupa@gmail.com','M. Jose Bustamante','Santa Beatriz<br>269 Depto 302','Providencia','Santiago','CHILE','7500496','(56-9) 7-8639769','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-09 22:49:29',0,NULL,3,1,2,1,NULL,'cotebupa'),(16223,763949596002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','bahadircoban','bahadir.coban@gmail.com','duygu karasu','8291 Sokak No: 1 Caher Dudayev Bulvarı adenpark sitesi A1 Blok<br>Kat: 5 Daire: 21 Mavisehir  Izmir ZIP: 35530','İZMİR','','TURKEY','35530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 23:30:41',0,NULL,3,1,3,1,'RA184588966CN\r ','bahadircoban\r---\r新地址：\rBahadir COBAN\rIstasyonalti mahallesi Eski Havaalani Caddesi No:39 k:6 d:11 Cigli / IZMIR PK:35580 \rTURKEY'),(16224,779453474017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','pinczi','plucinski.adam@gmail.com','Adam Plucinski','1 Market street<br>level 11','Sydney','New South Wales','AUSTRALIA','2000','0421896838','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-09 23:49:59',0,NULL,3,1,2,1,NULL,'pinczi'),(16225,763954413002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','bahadircoban','bahadir.coban@gmail.com','duygu karasu','8291 Sokak No: 1 Caher Dudayev Bulvarı adenpark sitesi A1 Blok<br>Kat: 5 Daire: 21 Mavisehir  Izmir ZIP: 35530','İZMİR','','TURKEY','35530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-09 23:50:52',0,NULL,3,1,3,1,'RA184588881CN\r ','bahadircoban\r---\r新地址：\rBahadir COBAN\rIstasyonalti mahallesi Eski Havaalani Caddesi No:39 k:6 d:11 Cigli / IZMIR PK:35580 \rTURKEY'),(16226,763956676002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','skif2979','skifmakgul@mail.ru','Enver Gulcheti','Krasnoarmeyskaya 18, kv.9','Vladikavkaz','RSO-Alania','RUSSIAN FEDERATION','362002','+7-8672-505310','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-10 00:02:44',0,NULL,3,1,3,1,'RA184588816CN\r ','skif2979'),(16227,723804427018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','rscra470','robert.cragg@bigpond.com','Robert Cragg','41 Woodburn Lane','Wallaroo','New South Wales','AUSTRALIA','2618','0392309394','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-10 02:03:10',0,NULL,3,1,4,1,'YW865546302CN ','rscra470\r已发信   客户来信已经收到'),(16228,723808143018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','raylewing','raymondlee72@gmail.com','Raymond Lee','48 Wolli St<br>Kingsgrove','Sydney','New South Wales','AUSTRALIA','2208','0297959896','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-10 02:20:19',0,NULL,3,1,3,1,'RA184588904CN\r ','raylewing'),(16229,763998664002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',2,'AD1171',15.98,'hermeshine','alesabha','alucha78@hotmail.com','Maria Alejandra Sabha','Junin 605 <br>7mo piso  -  Dpto. \"A\"','San Miguel de Tucuman','Tucuman','ARGENTINA','4000','0381-4211063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 03:18:03',0,NULL,3,1,17,0,NULL,'alesabha'),(16230,763998577002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','alesabha','alucha78@hotmail.com','Maria Alejandra Sabha','Junin 605 <br>7mo piso  -  Dpto. \"A\"','San Miguel de Tucuman','Tucuman','ARGENTINA','4000','0381-4211063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 03:18:03',0,NULL,3,1,2,1,' ','alesabha\r新款内胆包 S  Nikon    3\r211'),(16231,764000136002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-10 03:26:16',0,NULL,3,1,3,1,'RA184588895CN\r ','mariomarques.com.br\r\\'),(16232,721935596001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','ytshuva','kobi_psh@bezeqint.net','kobi tshuva','tiltan 12','yavne','israel','ISRAEL','81556','(972) 894-2648 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 03:26:39',0,NULL,5,0,18,0,' ','ytshuva\r看看能不能控制在2kg以下\r不能的话就不发了'),(16233,764027324002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','icnet22','hanka@inter-computers.com','TU München - LKN - Oliver Hanka','Arcisstr. 21<br>Lehr. f. Kommunikationsnetze','München','','GERMANY','80333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 06:18:45',0,NULL,3,1,2,1,NULL,'icnet22'),(16234,721965500001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','midcoast_surf','sales@midcoastsurf.com','Alison Cosgrove','51 Main Rd','Heddon Greta','New South Wales','AUSTRALIA','2321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 06:27:58',0,NULL,3,1,2,1,NULL,'midcoast_surf'),(16235,849587631015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','goran1960','skonerten@hotmail.com','Göran Almén','Tre Vänners Väg 43','Kalmar','','SWEDEN','39359','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 07:25:48',0,NULL,3,1,3,1,'RA184588878CN\r ','goran1960'),(16236,721990808001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','aivitelvik','aivi.telvik@gmail.com','Aivi Telvik','Tiigi põik 3','Kärdla','','ESTONIA','92412','+3725175585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:29:30',0,NULL,3,1,17,0,' ','aivitelvik'),(16237,764054235002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','aivitelvik','aivi.telvik@gmail.com','Aivi Telvik','Tiigi põik 3','Kärdla','','ESTONIA','92412','+3725175585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:29:31',0,NULL,3,1,12,1,'5241700354\r ','aivitelvik\r加上\r反光板  80cm 5合1\r如果反光板影响泡重就单发挂号小包\r最终计费： 13'),(16238,721997289001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','clavanis','ivansniper@mail.ru','Ion  Nistor','31 August n.40','Floresti','Moldova','MOLDOVA, REPUBLIC OF','5001','37325026095','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 08:57:12',0,NULL,3,1,3,1,'RA184568105CN\r\r ','clavanis\r8个\rIon Nistor\r31 August n.40\rFloresti Moldova 5001\rMoldova\r37325026095\r\r'),(16239,779567094017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','jojot930','kjoson@optusnet.com.au','JEROME JOSON','208 BENNETT  RD','ST CLAIR','NEW SOUTH WALES','AUSTRALIA','2759','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-10 08:53:41',0,NULL,3,1,2,1,NULL,'jojot930'),(16240,849634475015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','essuera','oshakurov@gmail.com','Олег Шакуров','Гагарина, 89/55, 75','Казань','Татарстан','RUSSIAN FEDERATION','420039','(843)5435990','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 10:00:34',0,NULL,3,1,2,1,NULL,'essuera'),(16241,722047420001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','martin.magal01','martin.magal@gregi.net','Martin Magal','A.Sladkovica 1','Nove Mesto nad Vahom','Slovakia','SLOVAK REPUBLIC','915 01','00421905956751','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 12:10:20',0,NULL,3,1,5,1,'CP235628905CN ','martin.magal01'),(16242,849681151015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','l3asinger','grnflv80@libero.it','Flavio Granato','via al quarto miglio 52','Roma','Roma','ITALY','00178','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 12:12:58',0,NULL,3,1,2,1,NULL,'l3asinger'),(16243,764136369002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','uthum2010','12scienceb@gmail.com','uthum perera','46/1b,<br>St.Xaviers` Road,','Ja-Ela,','Gampaha district','SRI LANKA','11350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 13:34:43',0,NULL,3,1,2,1,NULL,'uthum2010'),(16244,849716533015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','waxthemusic','oldtapewax@yahoo.co.uk','DEREK  SORHAINDO','33 DORMER ROAD<br>EASTVILLE','BRISTOL','Avon','UNITED KINGDOM','BS5 6XH','07717383002','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 13:41:02',0,NULL,3,1,2,1,' ','waxthemusic'),(16245,722050079001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-10 14:03:22',0,NULL,3,1,17,0,NULL,'saud-p'),(16246,764152947002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 14:30:13',0,NULL,3,1,17,0,NULL,'saud-p'),(16247,722083961001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-10 14:30:12',0,NULL,3,1,3,1,'RA184568025CN\r','saud-p\r2mx2m 背景架   2\r1.6x2.1 背景布   4   都要黑色的\r50-70柔光棚 通用塑料卡口    1\r分五票\rRA184568034CN\rRA184568051CN\rRA184568048CN\rRA184568017CN\r '),(16248,849791100015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','dr.qwerty','bobchapman@talktalk.net','Bob Chapman','158 Arthurton road<br>Spixworth','Norwich','Norfolk','UNITED KINGDOM','NR10 3QZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-10 16:20:22',0,NULL,3,1,2,1,NULL,'dr.qwerty'),(16249,849794497015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lovebugkalina','kalina.n.panayotova@gmail.com','Kalina Panayotova','Mladost III block 317 entr 2 apt 36','Sofia','','BULGARIA','1712','3592899183266','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 16:27:27',0,NULL,3,1,2,1,NULL,'lovebugkalina'),(16250,724029459018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','ourlynne','lynne.robertson@sympatico.ca','Lynne Robertson','44 Hunter Way','Brantford','ON','CANADA','N3T 6S3','(519) 753-1777','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-10 16:38:36',0,NULL,3,1,3,1,'RA184568785CN\r ','ourlynne\r---\r新地址：\rLynne Robertson \r44 Hunter Way \rBrantford ON \rN3T 6S3 \rCanada \r'),(16251,8881315673439689,111,'72mm canon 镜头盖  2 ',2,'AA1303',0,'hutongstore','0706alan','cottonmouth@tiscali.co.uk','alan schofield','18 broadfield drive<br>smithybridge.','littleborough','Lancashire','UNITED KINGDOM','ol15 0eu','01706374890',NULL,NULL,NULL,'2011-09-10 16:50:39',0,NULL,3,1,3,1,'RA184588864CN\r ','上次发成77mm的，这次一定注意，是72mm的canon '),(16252,779786199017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','robertr226','robertrusselw@hotmail.com','Robert Russell','12011 Front Beach Rd<br>unit 1407','panama city','FL','UNITED STATES','32407-3463','(678) 410-7242','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-10 18:49:22',0,NULL,3,1,1,1,NULL,'robertr226'),(16253,764268855002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','deluco87','xdelucox@hotmail.com','Beatriz  de Lillo Peruyera','Plaza America num 3 - 7','Oviedo','Asturias','SPAIN','33005','985235611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 19:08:22',0,NULL,3,1,17,0,NULL,'deluco87'),(16254,764270498002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','deluco87','xdelucox@hotmail.com','Beatriz  de Lillo Peruyera','Plaza America num 3 - 7','Oviedo','Asturias','SPAIN','33005','985235611','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 19:12:07',0,NULL,3,1,2,1,NULL,'deluco87\r方镜广角托架（ 一槽）   1\r方形滤镜接口环 77mm   1'),(16255,779821112017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','pelendonia','jiciria@gmail.com','Jose Ignacio Ciria Espuelas','c/ Uribarri, Nº 28, 3º dcha','Bilbao','País Vasco','SPAIN','48007','607434815','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-10 20:01:11',0,NULL,3,1,2,1,NULL,'pelendonia'),(16256,832280166016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','antoniod430','antoniodematteo@hotmail.com','Antonio De Matteo','via cerveteri 14','Roma','RM','ITALY','00183','3498738293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-10 20:19:55',0,NULL,3,1,4,1,'YW865546276CN ','antoniod430\r欧标'),(16257,722248067001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','gerty-dreamer','h_ohtsu@hokuriku.me','Ohtsu Kouhei','4035-1, Ngasawa, Fuchu-machi','Toyama-shi','Toyama','JAPAN','939-2606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-10 20:56:49',0,NULL,3,0,11,1,NULL,'gerty-dreamer\r1.6x2.1  黑色'),(16258,779847316017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',37.05,'photographyacc','henricao.tri','henricao.tri@gmail.com','Henrique Araujo','Rua Jerseryna Novakowski, 106.<br>Bigorrilho','Curitiba','Paraná','BRAZIL','80710-690','(5541) 3339-8191','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-10 21:03:25',0,NULL,3,1,3,1,'RA184588952CN\r ','henricao.tri\rcanon 反接环  52mm    1\r9个环+2个托架\r3片装滤镜袋   1\r水平仪热靴盖    1\r\r入库\r\r\r'),(16259,779891098017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','*143jude*','judejyla_naldoza@yahoo.com','Jude Naldoza','3 Campbell st','Kingaroy','Queensland','AUSTRALIA','4610','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-10 23:07:17',0,NULL,3,1,2,1,NULL,'*143jude*'),(16260,724207543018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sheppajo','jodiesheppard@graffiti.net','Jodie Sheppard','32A/64 Gilston Rd<br>RSCC - Huntingdale','Nerang','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-10 23:31:33',0,NULL,3,1,4,1,'YW865546280CN ','sheppajo'),(16261,8881315702769037,111,'肩架的配件（仔细检查）',1,'',0,'photographyacc','kiidsen','sen.y.lim@gmail.com','Sen Lim','209 George Street','Queens Park','Western Australia','AUSTRALIA','6107','0431347645',NULL,NULL,NULL,'2011-09-11 00:59:29',0,NULL,3,0,3,1,'RA184568326CN\r ','我来拿吧 '),(16262,8881315704157811,111,'115w 220v',1,'AE3601',0,'hutongstore','borneartpromotions','borneartadvertisment@hotmail.co.uk','christine cook','flat 2, 33 Holland road','Hove','East Sussex','UNITED KINGDOM','BN3 1JE','1273831131',NULL,NULL,NULL,'2011-09-11 01:22:37',0,NULL,3,1,3,1,'RA184568198CN\r ',NULL),(16263,8881315705102515,111,'背景架+1.6x2.1 白布',1,'AO0009',0,'hutongstore','peyskens2005','badboys0071@hotmail.com','Bertrand Cédric','Rue de la vallée<br>48','Hannut','','BELGIUM','4280','',NULL,NULL,NULL,'2011-09-11 01:38:22',0,NULL,3,1,4,1,'YW865546254CN ','还有块白布 '),(16264,846086120015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',4.23,'hutongstore','didiy83','dee_fakh@yahoo.com','Hadisah M. Salleh','No. 72b Tkt Bawah, Jln Kangar-Arau, Tmn Sena Indah,','Kangar,','Perlis','MALAYSIA','01000','0177983558','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 01:38:53',0,NULL,3,1,2,1,NULL,'didiy83'),(16265,8881315705325457,111,'9个环+2个托架',1,'AKT025',0,'photographyacc','henricao.tri','henricao.tri@gmail.com','Henrique Araujo','Rua Jerseryna Novakowski, 106.<br>Bigorrilho','Curitiba','Paraná','BRAZIL','80710-690','(5541) 3339-8191',NULL,NULL,NULL,'2011-09-11 01:42:05',0,NULL,3,1,17,0,NULL,NULL),(16266,764401772002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','edkolb','edkolb@comcast.net','Edgar C. Kolb','4696 S Landings Dr','Fort Myers','FL','UNITED STATES','33919','(239) 454-4297','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-11 02:13:02',0,NULL,3,1,1,1,NULL,'edkolb'),(16267,764413927002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','chchkameel','colin.e.chaney@hotmail.com','Colin Chaney','252 Avonhead Road<br>Avonhead','Christchurch','Canterbury','NEW ZEALAND','8540','+6433579982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 03:09:26',0,NULL,3,1,2,1,NULL,'chchkameel'),(16268,779955005017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','arkan3223','sales.innovision@hotmail.com','Aleksandar Matic','69 Vella crescent, Blacktown','Sydney','New South Wales','AUSTRALIA','2148','0298316730','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-11 03:25:16',0,NULL,3,1,2,1,NULL,'arkan3223'),(16269,764419783002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','maxho37','sa7272@mail.ru','Alexander Treygo','Putilova 7/51','Omsk','','RUSSIAN FEDERATION','644092','905-941-8288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 03:40:26',0,NULL,3,1,2,1,NULL,'maxho37'),(16270,722348760001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',6,'AE3301',83.88,'hermeshine','melate8','tonefotos@hotmail.com','Maria Antonieta Cevallos','Obregon 405 pte','Navojoa','Sonora','MEXICO','85830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 03:43:51',0,NULL,3,1,3,1,'RA184568119CN\r ','melate8'),(16271,722354946001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','happylittlebee76','debbie_marie_smith@hotmail.com','Debbie Smith','5/8 Weston Street','Coorparoo','Queensland','AUSTRALIA','4151','61418199392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 04:20:12',0,NULL,3,1,2,1,NULL,'happylittlebee76'),(16272,724294671018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','dolphin8au','mail4ed@gmail.com','Edmund Lee','34 Leon Road','Dalkeith','Western Australia','AUSTRALIA','6009','0893891983','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-11 06:50:35',0,NULL,3,1,3,1,'RA184568122CN\r ','dolphin8au'),(16273,722260645001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','videokuks','videoksy@gmail.com','Oxana Bogatova','Klimashkina 1-84','Moscow','','RUSSIAN FEDERATION','123557','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 06:55:10',0,NULL,3,1,3,1,'RA184568207CN\r ','videokuks'),(16274,722382465001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','martinenecek','pavlik@winternet.cz','Martin Pavlik','Rokytnice 451','Vsetin','Vsetin','CZECH REPUBLIC','75501','777-619-067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 07:04:20',0,NULL,3,1,2,1,NULL,'martinenecek\r铝合金那种\r申报： $8'),(16275,722398286001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','aitzien','johnnennes@yahoo.gr','Ioannis Nennes','Agias Triados 16','Athens','Attica','GREECE','14341','+302102511269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 08:07:53',0,NULL,3,0,2,1,NULL,'aitzien\r1.6x2.1 黑色   1'),(16276,724326198018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','martymcfly1424','martymcfly14@seznam.cz','Jiri Petrlik','Vatin 9','Zdar nad Sazavou','','CZECH REPUBLIC','59101','420777634904','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-11 08:47:19',0,NULL,3,1,17,0,NULL,'martymcfly1424'),(16277,722409553001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','mrchester21','chrisfar@aapt.net.au','bob faries','3/706 mowbray rd','lane cove','New South Wales','AUSTRALIA','2066','0296034705','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 08:47:40',0,NULL,3,1,3,1,'RA184568290CN\r ','mrchester21'),(16278,780031757017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'',28,'photographyacc','martymcfly1424','martymcfly14@seznam.cz','Jiri Petrlik','Vatin 9','Zdar nad Sazavou','','CZECH REPUBLIC','59101','420777634904','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-11 09:07:15',0,NULL,3,1,3,1,'RA184568388CN\r ','martymcfly1424\r方形滤镜接口环 72mm   1\r方镜普通托架（三槽）     1\r6片装滤镜袋    1\r无牌方镜  ND2   1\r无牌方镜  ND4   1\r无牌方镜  ND8   1\r无牌方镜  渐变灰 ND4 1\r无牌方镜  渐变灰 ND8 1\r无牌方镜  渐变蓝  1  已入库'),(16279,780047569017,270750130191,'TianYa Star 8 points  cross filter for Cokin P Series',2,'AE2317',25.8,'photographyacc','rustyfox2112','rfox3@bigpond.com','Russell Fox','38 St Albans Street','St Albans Park','Victoria','AUSTRALIA','3219','0430926095','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-11 09:48:31',0,NULL,3,1,17,0,NULL,'rustyfox2112'),(16280,780063322017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','clementine_x','clementine_georgia@hotmail.com','Clementine Phillips & Joseph Lawton','1a Milne street','Mitcham','Victoria','AUSTRALIA','3132','0447190779','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-11 10:28:31',0,NULL,3,1,2,1,NULL,'clementine_x'),(16281,722459026001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','pureangel21','sufiboen@yahoo.com','Sufi Boenyamin','81 Yishun Street 81 #09-02<br>Orchid Park Condominium','default','','SINGAPORE','768445','94574309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:03:11',0,NULL,3,1,17,0,'\\ ','pureangel21'),(16282,722458740001,110618888297,'Pro Photo Vest for Sony A230,A200,A330,​A350,A380  user',1,'AA2121',32,'hermeshine','leathalism','leathalism@optusnet.com.au','lee mccurtayne','7 Paris Street','Balgowlah','New South Wales','AUSTRALIA','2093','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 11:03:35',0,NULL,3,0,3,1,'RA184569145CN\r ','leathalism\rXXL 已入库'),(16283,764531185002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','pureangel21','sufiboen@yahoo.com','Sufi Boenyamin','81 Yishun Street 81 #09-02<br>Orchid Park Condominium','default','','SINGAPORE','768445','94574309','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:08:19',0,NULL,3,1,11,1,'\\ ','pureangel21\r小号内胆包 Nikon     1\r小号内胆包 canon    1'),(16284,764538892002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','ssrdjann','ssrdjann@yahoo.com','Srdjan Sladakovic','GCAA, SZ Centre<br>PO box 666','Abu Dhabi','Abu Dhabi','UNITED ARAB EMIRATES','6666','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 11:29:59',0,NULL,3,1,3,1,'RA184568136CN\r ','ssrdjann'),(16285,724391933018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','hansi*07','arthansi@free.fr','hansi MECHLING','19, place des cordeliers','annonay','Rhône-Alpes','FRANCE','07100','0617100844','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-11 11:47:28',0,NULL,3,1,2,1,NULL,'hansi*07'),(16286,764545071002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',7,'AA2106',247,'hermeshine','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 11:47:31',0,NULL,3,0,6,1,'EE645685443CN ','wikran\rXL   (已入库）\r7件'),(16287,722476434001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','0verclock','blackadder_31@hotmail.com','Oriol Domingo Llorens','C Montblanc num 18, 3r 2a','Vilafranca del Penedes','Cataluña','SPAIN','08720','670827203','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 11:52:35',0,NULL,3,1,4,1,'YW865546346CN','0verclock'),(16288,764577625002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',95,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:02',0,NULL,3,1,17,0,NULL,'audibase'),(16289,722473767001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:01',0,NULL,3,1,17,0,NULL,'audibase'),(16290,764565194002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',16.99,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:03',0,NULL,3,1,17,0,NULL,'audibase'),(16291,722497370001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:02',0,NULL,3,1,17,0,NULL,'audibase\r\r'),(16292,764571774002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',5,'AA1206',19.95,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:04',0,NULL,3,1,17,0,NULL,'audibase'),(16293,722500993001,110502533743,'Brand New 3.0\" LCD Screen Protector for G10 A2000 SX110',10,'AB2214',15,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:05',0,NULL,3,1,17,0,NULL,'audibase'),(16294,764577858002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 13:18:06',0,NULL,3,1,17,0,NULL,'audibase\r'),(16295,764569054002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',6.5,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:05',0,NULL,3,1,17,0,NULL,'audibase'),(16296,722502125001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:18:06',0,NULL,3,1,17,0,NULL,'audibase'),(16297,722509052001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',32,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:49',0,NULL,3,1,17,0,NULL,'audibase\r'),(16298,764542918002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:50',0,NULL,3,1,17,0,NULL,'audibase'),(16299,764543694002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3302',23.96,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:51',0,NULL,3,1,17,0,NULL,'audibase'),(16300,722497534001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:50',0,NULL,3,1,17,0,NULL,'audibase'),(16301,722498272001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.3,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:52',0,NULL,3,1,17,0,NULL,'audibase'),(16302,764543885002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',79.76,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 13:28:52',0,NULL,3,1,17,0,NULL,'audibase'),(16303,764543267002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:53',0,NULL,3,1,17,0,NULL,'audibase'),(16304,722474753001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:54',0,NULL,3,1,17,0,NULL,'audibase'),(16305,764565951002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','audibase','eb@solidsound.fr','Alexandre Gonot-Tiver-Stanford','16, Avn. Edouard Grinda<br>Solid Sound Studio - La Victorine','Nice','Provence-Alpes-Côte d\'Azur','FRANCE','06200','(33)669741020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 13:28:53',0,NULL,5,1,12,1,'5241706750\r ','audibase\r灯架  2m   8\r斜臂         2\r反光板支架    1\r50-70 单灯头柔光箱   6  欧标\r双灯头       3 欧标\r反光伞       2\r柔光伞       2\r110cm 反光伞   黑色的     2\r115w 220v     8\r灯架包      3\r橡胶遮光罩 52mm   2\r橡胶遮光罩 58mm   2\r带水平仪热靴盖   5\r品胜3.0“ 膜    10\rc型大力夹   2\r绿叶 UV  52mm    2\r绿叶 UV  58mm    2\r铝合金灯座（N）     2\r反光板 80cm 2合1    2\r反光板 100*150 40*60 5合1     2\r实重21.669   抛重22.89\r--\r反光板 100*150 40*60 5合1     2   \r这两个单发燕文\rYW865546825CN\r最终计费23\r状态改不了， 已经发货了\r'),(16306,8881315748043314,111,'1600W  套装',2,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-09-11 13:34:03',0,NULL,3,1,12,1,'5241700365\r ','灯泡是110v的 \r最终计费 15'),(16307,8881315748077409,111,'2300W 套装',2,'AKT041',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-11 13:34:37',0,NULL,3,1,12,1,'5241706746\r ',' 灯泡是110v的 \r周三再发\r除了C里的内容再加一个“单灯头 柔光棚”\r实重15.405  抛重20.46\r实际计费19'),(16308,779652923017,270747481572,'New Neoprene Neck Shoulder Strap for Pentax SLR camera',3,'AB1405',15.24,'photographyacc','cigglund2011','cigglund@vtr.net','Cristhian Igglund Ramirez','San Gabriel N°3256<br>Las Condes','Santiago','Metropolitana','CHILE','7550402','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-11 14:10:31',0,NULL,3,1,2,1,'/ ','cigglund2011'),(16309,832671664016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',2,'AD1128',36,'hutongstore','noodlecoco','paul@norank.co.uk','Elaine Harrison','11 Hawkshill Drive<br>Felden','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP3 0BS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 14:32:18',0,NULL,3,1,3,1,'RA184588820CN ','noodlecoco'),(16310,850322221015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','rtr541','squirrelpus@yahoo.co.uk','patrick campbell','2 greenbanks','blackpool','Lancashire','UNITED KINGDOM','FY20NZ','01253596283','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 14:34:49',0,NULL,3,1,3,1,'RA184568140CN\r ','rtr541..'),(16311,724497753018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','sweetstomps','adamgresty@gmail.com','Claire Gresty','PO Box 8024<br>Sumner Post Office','Brunswick East','Victoria','AUSTRALIA','3057','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-11 15:28:11',0,NULL,3,1,4,1,'YW865546232CN ','sweetstomps'),(16312,764655424002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','inspire336','corey.mcivor@gmail.com','corey','po box 318','scarborough','Western Australia','AUSTRALIA','6922','0417921934','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 15:47:57',0,NULL,3,1,3,1,'RA184569074CN\r ','inspire336..'),(16313,850395053015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',3,'AE3301',23.4,'hutongstore','logan12584','palmieri.nicola@gmail.com','Nicola Palmieri','San francesco 12','termoli','CB','ITALY','86039','3494205889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 16:22:28',0,NULL,3,1,17,0,NULL,'logan12584'),(16314,832743994016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','logan12584','palmieri.nicola@gmail.com','Nicola Palmieri','San francesco 12','termoli','CB','ITALY','86039','3494205889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 16:22:29',0,NULL,3,1,17,0,NULL,'logan12584'),(16315,850393811015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','logan12584','palmieri.nicola@gmail.com','Nicola Palmieri','San francesco 12','termoli','CB','ITALY','86039','3494205889','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-11 16:22:30',0,NULL,3,1,17,0,NULL,'logan12584'),(16316,850393288015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','logan12584','palmieri.nicola@gmail.com','Nicola Palmieri','San francesco 12','termoli','CB','ITALY','86039','3494205889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 16:22:30',0,NULL,3,1,17,0,NULL,'logan12584'),(16317,832742169016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','logan12584','palmieri.nicola@gmail.com','Nicola Palmieri','San francesco 12','termoli','CB','ITALY','86039','3494205889','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-11 16:22:30',0,NULL,3,1,4,1,'YW865546394CN','logan12584\rc里的东西外再加：\r一转四 灯头      3\r2m 灯架    1\r50-70 单灯头 柔光箱   1  欧标\r斜臂   1\r115w 220v    3\r45w 220v    4\r灯架包   1\r背景布 3x6 白色  * 1\r实重17.313 泡重23.39\r申报 lighting kit $40\r---\r新地址：\rNicola Palmieri\rviale san francesco 12 \rtermoli 86039 (CB)\rITALY\r3494205889'),(16318,722650478001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','wayne1hurford','waynehurford@hotmail.com','Wayne Hurford','Box  291','Squamish','BC','CANADA','V8B0A3','(604) 892-4964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 17:19:25',0,NULL,3,1,2,1,'\\ ','wayne1hurford'),(16319,764758253002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','antonukhanov','mail@antonukhanov.ru','Anton Ukhanov','Ulitsa Nagatinskaya, dom 33, korpus 1, kvartira 32<br>Telefon +7 926 156 27 74','Moscow','','RUSSIAN FEDERATION','115533','(926) 156-2774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 18:01:17',0,NULL,3,1,3,1,'RA184569065CN\r ','antonukhanov..'),(16320,850510899015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45.8,'hutongstore','iamaud','a_tanapong@yahoo.com','Tanapong Ariyapongse','10/5 Soi Ekkamai 2, Sukhumvit 63 Rd.,','Wattana','Bangkok','THAILAND','10110','668 9660 6966','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 18:13:22',0,NULL,3,1,6,1,'EE645685457CN','iamaud'),(16321,722765732001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','the-gpvideo','thegpvideo@gmail.com','Pavel Gulyga','pos. Saharnyj zavod, d.25, kv.1','Timashevsk','Krasnodarskij kraj','RUSSIAN FEDERATION','352701','79180175737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 19:37:41',0,NULL,3,1,3,1,'RA184569105CN\r ','the-gpvideo'),(16322,764860383002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','gymgirl197012','gymgirl1970@yahoo.com','Holly Wreggitt','245 victoria ave north','Lindsay','ON','CANADA','k9v6c9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 20:11:59',0,NULL,3,1,5,1,'CP235628851CN ','gymgirl197012'),(16323,850659169015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',8.4,'hutongstore','miguelpar','migelpar@yahoo.es','Miguel Ramiro Paredes','Sixto Celorrio  20-22   5º  C','Zaragoza','Aragón','SPAIN','50015','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-11 20:54:37',0,NULL,3,1,2,1,'/ ','miguelpar'),(16324,722820496001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','eshop_masenka','masenka@masenka.eu','Miroslav Horák','Jiřího Wolkera 1888<br>eshop.masenka@masenka.eu','Nymburk','ČR','CZECH REPUBLIC','28802','+420606204980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 21:08:11',0,NULL,3,0,17,0,NULL,'eshop_masenka'),(16325,724765618018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','ufologisthunter2011','ufologisthunter@yahoo.com','deborah york','1396 E Hancock Dr<br>Ste J','deltona','FL','UNITED STATES','32725-6444','(386) 860-4548','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-11 21:26:56',0,NULL,3,1,1,1,'/ ','ufologisthunter2011'),(16326,764902726002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','eshop_masenka','masenka@masenka.eu','Miroslav Horák','Jiřího Wolkera 1888<br>eshop.masenka@masenka.eu','Nymburk','ČR','CZECH REPUBLIC','28802','+420606204980','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-11 21:28:26',0,NULL,3,1,5,1,'CP235628865CN ','eshop_masenka\r河北背景架   1\r1.6x2.1 背景布  2   蓝色 绿色\r/'),(16327,850698066015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','greglbrown','greg@sqzi.com','Greg Brown','ConocoPhillips (U.K.) Limited<br>Rubislaw House, Anderson Drive','Aberdeen','Aberdeen City','UNITED KINGDOM','AB15 6FZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-11 22:16:14',0,NULL,3,1,2,1,'/ ','greglbrown'),(16328,722856790001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','merriclubov','keyflux@gmail.com','Scott Anderson','2900 Meade Ave<br>Ste 8','Las Vegas','NV','UNITED STATES','89102-7882','','NoPaymentFailure','CheckoutComplete','Other','2011-09-11 22:45:08',0,NULL,3,1,1,1,'/ ','merriclubov'),(16329,764935762002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','tejoal','berends@shaw.ca','Mike Berends','749 Northmount Dr. NW','Calgary','AB','CANADA','T2K 3K1','(403) 467-8402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-11 22:59:43',0,NULL,3,1,3,1,'RA184569159CN\r ','tejoal..'),(16330,724821301018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','5459eady','djeady@gmail.com','Dan Eady','2/23 Westbourne Street<br>Highgate Hill','Brisbane','Queensland','AUSTRALIA','4101','61410854000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 00:13:53',0,NULL,3,1,3,1,'RA184568771CN ','5459eady'),(16331,764966142002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 00:41:32',0,NULL,3,1,17,0,NULL,'ramitetro'),(16332,764966984002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 00:41:32',0,NULL,3,1,17,0,NULL,'ramitetro'),(16333,722890760001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 00:41:33',0,NULL,3,1,17,0,NULL,'ramitetro'),(16334,722891105001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 00:41:33',0,NULL,3,1,3,1,'RA184568343CN\r ','ramitetro\rlenspen   1\r气吹   1\r布   1\r麂皮    1\r反光板支架   1\r摄影背心 Canon  老款  L   1 （已入库）\r如果超2kg就分开发\r1.7\r'),(16335,722892150001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','rusty0149john','cal832pc@leadhill.net','john madison','PO Box 459','lead hill','AR','UNITED STATES','72644-0459','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 00:43:47',0,NULL,3,1,1,1,'/ ','rusty0149john'),(16336,722305245001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','68.radek','radikkio@hotmail.com','forma international','via luca comerio 5','milano','milano','ITALY','20145','0245706100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 00:50:45',0,NULL,3,1,2,1,NULL,'68.radek'),(16337,724841546018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','oliviaoliviatex','olivia@oliviatexierphotography.com.au','Olivia Texier','28/12 Hazelwood close','Suffolk Park','New South Wales','AUSTRALIA','2481','04075501380407550138','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 01:21:38',0,NULL,3,1,3,1,'RA184568153CN ','oliviaoliviatex'),(16338,722921450001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','mlau6185','morin.laurin@sympatico.ca','Marc Laurin','111, rue Wolfe','Granby','QC','CANADA','j2g1j7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 02:23:32',0,NULL,3,1,3,1,'RA184568082CN\r ','mlau6185..'),(16339,764998625002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mlau6185','morin.laurin@sympatico.ca','Marc Laurin','111, rue Wolfe','Granby','QC','CANADA','j2g1j7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 02:23:33',0,NULL,3,1,3,1,'RA184568184CN\r ','mlau6185..'),(16340,765005222002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','amh0430','jaxvolfreak@aol.com','john  harwell','10321 wood dove way','jacksonville','FL','UNITED STATES','32221-3001','(904) 781-0329','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 02:36:27',0,NULL,3,1,3,1,'RA184568079CN\r ','amh0430..'),(16341,780606327017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','mgur','manual.lens@yandex.ru','Mikhail Gurevich','Novoizmailovskiy Prospekt<br>Dom 53 Kv 43','St. Petersburg','St Petersburg','RUSSIAN FEDERATION','196247','812 3710971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 03:40:21',0,NULL,3,1,3,1,'RA184568309CN\r ','mgur'),(16342,724898157018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',6,'AA1315',17.94,'photographyacc','shutterbeak','goodwinf001@hawaii.rr.com','William Goodwin','94-1146 Kukula St','WAIPAHU','HI','UNITED STATES','96797','(808) 676-1137','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 05:32:34',0,NULL,3,1,1,1,' ','shutterbeak'),(16343,780633003017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','alvinandcc','alvin_huang@yahoo.com','Alvin Huang','8/72 George St<br>Norwood','Adelaide','South Australia','AUSTRALIA','5067','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 06:00:55',0,NULL,3,1,2,1,NULL,'alvinandcc'),(16344,833203070016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',65.98,'hutongstore','trudi.b','trudi@blueyonder.co.uk','Trudi Butler','23/3 Boswall Avenue','Edinburgh','Midlothian','UNITED KINGDOM','EH5 2EA','01314760136','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 06:48:09',0,NULL,3,1,12,1,'5241700376\r','trudi.b\r帮我看下实重 泡重\r实重3.82    泡重3.69\r最终计费  4'),(16345,765058835002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','brow_nie','glenyygoh@gmail.com','Glen Goh','#07-11, Blk 11, Farrer Park Road','default','','SINGAPORE','210011','(065) 96305267','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 07:11:30',0,NULL,3,1,3,1,'RA184569026CN\r ','brow_nie..'),(16346,724921227018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',262.5,'photographyacc','riccardo-ugo','riccardougo@yahoo.it','Rimoldi Ugo','Piazza del Filatoio','Orsenigo','CO','ITALY','22030','348-3583121','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 07:38:49',0,NULL,3,1,12,1,'5241700391','riccardo-ugo\r1.8m 717    1\rCANON 镜头盖  77mm     1\r给我一个泡重\r7.6\r最终计费8\r\r'),(16347,765066938002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','maximkaplansky','kaplansky@yandex.ru','Maxim Kaplansky','Razdolnaya str., 35-122','Oryol','','RUSSIAN FEDERATION','302038','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 07:51:33',0,NULL,3,1,3,1,'RA184569012CN\r ','maximkaplansky..'),(16348,850880009015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','cdb2750','craigboyes@bigfoot.com','c boyes','88 norton road','winton','Dorset','UNITED KINGDOM','bh9 2pz','07973111573','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 08:03:19',0,NULL,3,1,2,1,'/ ','cdb2750'),(16349,724931545018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','mgw_mgw','marg.g.wong@gmail.com','Margaret Wong','8 Cedar Ct','Glen Waverley','Victoria','AUSTRALIA','3150','0392148542','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 08:27:57',0,NULL,3,1,2,1,'/ ','mgw_mgw'),(16350,765078224002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','scda81','tinadavid@gmx.de','David Schickle','P.B. 3','Kazanlak','','BULGARIA','6100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 08:44:13',0,NULL,3,1,2,1,'/ ','scda81'),(16351,850897870015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','235milton','melissa_milton@hotmail.com','Melissa Milton','7 Wilga Court<br>Beaconsfield','Mackay','Queensland','AUSTRALIA','4740','0749445486','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 09:05:37',0,NULL,3,1,4,1,'YW865546416CN ','235milton\r已收到'),(16352,849771127015,250599945149,'New EyeCup for Nikon Af D80 D90 D200',1,'AA1203',1.85,'hutongstore','n1k0n.user30','matt.j.dodwell@gmail.com','Matthew Dodwell','37 Bodenham Field<br>Abbeymead','Gloucestershire','Gloucestershire','UNITED KINGDOM','GL4 5TS','01453371188','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-12 09:09:41',0,NULL,3,1,2,1,'/ ','n1k0n.user30'),(16353,765116143002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','burundukov','diman_al@samsobaka.com','Дмитрий Бурундуков','ул.Домостроителей, д.14, кв.140','Тюмень','Тюменская область','RUSSIAN FEDERATION','625034','(922)4708217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 11:16:47',0,NULL,3,1,3,1,'RA184569088CN\r ','burundukov'),(16354,723041525001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','wolf121267','vlm1967@gmail.com','Vadim L. Makarov','Marshal Zhukov street<br>dom 13 kv. 139','Odincovo','Moskovskaya oblast','RUSSIAN FEDERATION','143005','+79057586221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 11:35:08',0,NULL,3,1,5,1,'CP235628879CN ','wolf121267'),(16355,724982071018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mitchelle1995','mitchymoo5@hotmail.com','mitchell edwards','107 south st','medowie','New South Wales','AUSTRALIA','2318','0403094418','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-12 11:37:05',0,NULL,3,1,4,1,'YW865546420CN ','mitchelle1995'),(16356,724988438018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',2,'AE3103',26,'photographyacc','thedge007','thedgester@gmail.com','GregSinclair','179 Northcott Drive','Adamstown Heights','New South Wales','AUSTRALIA','2289','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-12 11:57:55',0,NULL,3,1,2,1,NULL,'thedge007'),(16357,723049552001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','videodslr','videoallf@gmail.com','ALEKSEY BOGATOV','Presnenskiy Val 8-2-141','Moscow','','RUSSIAN FEDERATION','123022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 12:02:17',0,NULL,3,1,3,1,'RA184568065CN\r ','videodslr'),(16358,833303415016,260817868705,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',20.99,'hutongstore','rescue999alan','aj.centra@hotmail.co.uk','Alan Crawford','104 moat street','Donaghadee','Down','UNITED KINGDOM','BT21 0ED','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-12 12:15:10',0,NULL,3,1,3,1,'RA184569091CN\r ','rescue999alan'),(16359,725004876018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','donaldone','don@woerleegroup.com.au','donald ward','33 bateman rd','mt pleasant','Western Australia','AUSTRALIA','6153','0893649168','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 12:49:33',0,NULL,3,1,2,1,NULL,'donaldone'),(16360,8881315833612530,111,'45w 220v   x     1',1,'AO0003',0,'hutongstore','c6bon','lens444@yahoo.fr','Jean Louis Carrasco','57 rue du Moulin Vert','PARIS','PARIS','FRANCE','75014','+33611183830',NULL,NULL,NULL,'2011-09-12 13:20:12',0,NULL,3,1,3,1,'RA184568269CN\r ',NULL),(16361,780092884017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','rustyfox2112','rfox3@bigpond.com','Russell Fox','38 St Albans Street','St Albans Park','Victoria','AUSTRALIA','3219','0430926095','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 13:35:47',0,NULL,3,1,3,1,'RA184568913CN ','rustyfox2112\r除了c 里面的再发\r天涯方形滤镜系列  星光镜  star8    2'),(16362,850995563015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','finnmagnust','magnus@milrab.no','Finn Magnus Torall','Fagernes 15  lnr 204','Bergen','Hordaland','NORWAY','5043','+4799436157','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-12 13:39:11',0,NULL,3,1,12,1,'5241700402\r ','finnmagnust\r欧标\r实重7.1  抛重8.64\r最终计费8'),(16363,723082745001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',33.99,'hermeshine','marce175','marcelo77@hotkey.net.au','Marcelo Di Florio','1/67  Chesterville  RD','Highett','Victoria','AUSTRALIA','3190','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 13:51:33',0,NULL,3,1,3,1,'RA184568224CN\r ','marce175'),(16364,765172631002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','shualy','uri_avitan@yahoo.com','uri  avitan','Hativa Shmoneh 19/5','Beer Sheva','Israel','ISRAEL','84252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 14:19:16',0,NULL,3,1,2,1,NULL,'shualy'),(16365,723093108001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.48,'hermeshine','drpapad','niikos@gmail.com','Nikolas Papapadopoulos','The Graduate Apartments St\' Pauls University College<br>G501 - 196 Westmount rd North','Waterloo','ON','CANADA','N2L 3G5','226 978 4373','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 14:23:41',0,NULL,3,1,2,1,NULL,'drpapad'),(16366,723097799001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',90,'hermeshine','caityem','caitlyn.major@hotmail.com','Caitlyn Major','61 Nyandi crt','Thornlie','Western Australia','AUSTRALIA','6163','61410735097','NoPaymentFailure','CheckoutComplete','AU_Express','2011-09-12 14:37:31',0,NULL,3,1,4,1,'YW865546442CN ','caityem\r澳标'),(16367,725036728018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',60,'photographyacc','caityem','caitlyn.major@hotmail.com','Caitlyn Major','61 Nyandi crt','Thornlie','Western Australia','AUSTRALIA','6163','61410735097','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-12 14:41:58',0,NULL,3,0,4,1,'YW865546431CN ','caityem\r\r'),(16368,762336108002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','vladimirmartinenko','uyt-vova@mail.ru','Vladimir Martinenko','St.Budennogo 27','Krasnodar','Krasnodar Region','RUSSIAN FEDERATION','350004','(918)474-3737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 15:01:52',0,NULL,3,0,3,1,'RA184568096CN\r ','vladimirmartinenko\rXL'),(16369,725048842018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','jptproductions','payment@jptmedia.com','Ethan Thompson - PMB #1266','PO Box 129<br>4200 Glendale Rd.','Pottersville','NY','UNITED STATES','12860-0129','(585) 861-0192','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 15:03:14',0,NULL,3,1,1,1,NULL,'jptproductions'),(16370,765196846002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','andrey735','terechov1@yandex.ru','Andrey Terechov','Bratislavskaya street 6-1-221','Moscow','','RUSSIAN FEDERATION','109341','79163859451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 15:33:06',0,NULL,3,1,3,1,'RA184568238CN\r ','andrey735'),(16371,723144349001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','luiman0921','raymond_leung@alumni.sfu.ca','Raymond Leung','2787 Coleridge Ave.','Vancouver','BC','CANADA','V5S3A4','(778) 881-1909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 16:40:59',0,NULL,3,1,2,1,NULL,'luiman0921'),(16372,722234251001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','winners76','shahsachin@hotmail.com','Sachin Shah','15835 Sedona Dr','Chino Hills','CA','UNITED STATES','91709-7826','(909) 994-1290','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 16:47:46',0,NULL,3,1,1,1,NULL,'winners76'),(16373,763793062002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','upul79','upulcdayawansa@inmail24.com','upul.c. dayawans','122/52a,Diyahoda Waththa,<br>Kotahara','Avissawella','western province','SRI LANKA','10700','+94-0713272639','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 16:48:20',0,NULL,3,1,2,1,NULL,'upul79'),(16374,723121438001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','blueamesbury','blueamesbury@hotmail.com','danielle murphy','2100 Meadow Rd','waco','TX','UNITED STATES','76710-2732','(617) 283-1667','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-12 16:56:56',0,NULL,3,1,1,1,NULL,'blueamesbury'),(16375,765241701002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jsimmons95','jsimmons@sitechcorp.com','Sitech Corporation','2543 Wasser Terrace, No. 405','Herndon','VA','UNITED STATES','20171','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 17:21:23',0,NULL,3,1,1,1,NULL,'jsimmons95'),(16376,780846270017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',37.79,'photographyacc','sicnaxyz','christian.jarry@gmail.com','Christian Jarry','13 rue de Provence','Ile-Perrot','QC','CANADA','J7V 8C7','(514) 425-0021','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 17:25:40',0,NULL,3,1,3,1,'RA184568175CN\r ','sicnaxyz\r绿叶 UV  77mm     1\r绿叶CPL 77mm       1\r110cm 5和 1        1\r已入库\r'),(16377,723184513001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 18:06:56',0,NULL,3,1,5,1,'CP235628882CN ','denisdryashkin'),(16378,765296252002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','gchen1900','ch.gideon@gmail.com','Gideon Chen','5 Sharona st.','Rishon Lezion','','ISRAEL','75289','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-12 19:07:37',0,NULL,3,1,3,1,'RA184569057CN\r ','gchen1900'),(16379,765302095002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 19:17:20',0,NULL,3,1,2,1,NULL,'solsuny'),(16380,723209793001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','fry_electronics','xtreemware@live.com','Jacqueline Velasco','Corso 3 Novembre, 8','Trento','TN','ITALY','38122','328-0946364','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 19:34:12',0,NULL,3,1,2,1,NULL,'fry_electronics'),(16381,833539782016,260838264614,'New Large High quality heavy duty sand bag Empty',1,'AD1168',8.99,'hutongstore','aryms','alexandremothe@hotmail.com','Alexandre Mothe chez Mr Dimitri Mothe','48 bis Avenue Mozart','Paris','Ile-de-France','FRANCE','75016','06.49.14.46.39','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-12 19:54:39',0,NULL,3,1,2,1,NULL,'aryms'),(16382,725215601018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','mrhash','ebay@mrhash.com','Fernando Hashiba','Av. Diaz Velez 4580 14 D','Capital','BUENOS AIRES','ARGENTINA','1405','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 20:48:21',0,NULL,3,1,6,1,'EE645685465CN ','mrhash\r三脚架 伟峰 EI-717  180 * 1\r115w 5500K  220v  灯泡 *  4（已入库）\r申报：US$22'),(16383,725227897018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',3,'AE1203',16.5,'photographyacc','luissane','luisane@denbogestion.es','L A SAN EMETERIO ARGUMOSA','Areatza,32 - 5ºC','Plentzia','Vizcaya','SPAIN','48620','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 21:13:20',0,NULL,3,1,2,1,NULL,'luissane'),(16384,765370709002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','luchochm','luischm@gmail.com','Luis Chigne','Jr. Manuel Segura 720 - Lince','Lima','Lima','PERU','LIMA 14','+51992728758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 21:47:38',0,NULL,3,1,3,1,'RA184569030CN\r ','luchochm'),(16385,780992115017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','ttees*closet*','misdf@hotmail.com','Melissa Fisher','146 Donora Rd','Monongahela','PA','UNITED STATES','15063','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 22:08:17',0,NULL,3,1,1,1,' ','ttees*closet*'),(16386,765381243002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','dr-tooth','tomdkw@gmail.com','Thomas Diekwisch','1819 Denison Rd','Naperville','IL','UNITED STATES','60565-6758','(312) 413-9683','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-12 22:19:27',0,NULL,3,1,4,1,'YW865546475CN ','dr-tooth\r不要忘了那个白色的布\r'),(16387,765385180002,120757472199,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT074',310,'hermeshine','ab4ddon001','ab4ddon@gmail.com','Luis Silva','Rua Pedro José Ornelas, 36A - 3L','Funchal','Madeira','PORTUGAL','9050-069','965115147','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-12 22:45:09',0,NULL,3,1,4,1,'YW865546486CN ','ab4ddon001\r欧标\r泡重\r实重 12.174 抛重16.968\r'),(16388,722538401018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','zriddle16','zach@hotmail.com.au','Zachary Riddle','59 Reardon Street','Calamvale','Queensland','AUSTRALIA','4116','0429319961','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-12 22:50:40',0,NULL,3,1,4,1,'YW865546453CN ','zriddle16\r燕文告之无人领取现在货在当地邮局\r▲已发信'),(16389,724861900018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','karimamegelus','karima@pureselect.com.au','Karima Asaad','402/ 410 elizabeth St','surry hills','New South Wales','AUSTRALIA','2010','0412452712','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-12 23:16:57',0,NULL,3,1,4,1,'YW865546464CN ','karimamegelus'),(16390,725269302018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','josealbertoblane','josealberto_alc@hotmail.com','JOSE ALBERTO ALCAZAR CASTAÑAR','C/RAFAEL CANOGAR Nº6, BAJO B','RIVAS-VACIAMADRID','Madrid','SPAIN','28521','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-12 23:22:45',0,NULL,3,0,3,1,'RA184569043CN\r ','josealbertoblane\rXL   已入库'),(16391,725274918018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','cdfturner','cdturner@iinet.net.au','Craig Turner','Po Box 7150, Safety Bay','Rockingham','Western Australia','AUSTRALIA','6169','0895277413','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-12 23:44:46',0,NULL,3,1,2,1,NULL,'cdfturner'),(16392,723329336001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','gem89','gtreble@optusnet.com.au','Geoffrey John Treble','12-14 Churchill Avenue,','Kirrawee','New South Wales','AUSTRALIA','2232','0295421011','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 00:17:41',0,NULL,3,1,2,1,NULL,'gem89'),(16393,781040593017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','shoshi1715','hossain_t@hotmail.com','Tanvir Hossain','7 Blane Street','Minto','New South Wales','AUSTRALIA','2566','0296032130','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 00:59:41',0,NULL,3,1,2,1,NULL,'shoshi1715'),(16394,765433185002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','hyde9585','hyde9585@yahoo.ca','Andrea Hyde','7273 Terragar Blvd.','Mississauga','ON','CANADA','L5N 7L8','(416) 780-2866','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 01:31:47',0,NULL,3,1,2,1,NULL,'hyde9585'),(16395,723352263001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','collector1311','hsantana2@yahoo.com','Hector Santana','1514 Judd Ct','Herndon','VA','UNITED STATES','20170-2564','(703) 587-9816','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 01:48:52',0,NULL,3,1,1,1,NULL,'collector1311'),(16396,781069182017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','violeiropescador','marcoaurelio123@zipmail.com.br','MARCO AURÉLIO GODOI ALVES','APTO 219<br>QI 23 LT 03 RESIDENCIAL MILÃO','GUARÁ - II','DISTRITO FEDERAL','BRAZIL','71060-631','61-381-3963','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 02:44:10',0,NULL,3,1,11,1,NULL,'violeiropescador'),(16397,765457339002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','rickm427','rick396@frontier.com','Rick Martindale','7100 NW Century Blvd<br>Beaverton Foods Inc.','Hillsboro','OR','UNITED STATES','97124-8570','(503) 648-1914','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 03:18:42',0,NULL,3,1,1,1,NULL,'rickm427'),(16398,725339515018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','kabirsydney','kabirsydney@yahoo.com.au','AN Kabir Ahmed','16/77 Liverpool Road<br>Ashfield','Sydney','New South Wales','AUSTRALIA','2131','610413576607','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 04:10:47',0,NULL,3,1,2,1,NULL,'kabirsydney'),(16399,725341660018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','sajith050683','sajith83@gmail.com','Sajith Amendra','171 Templer\'s Rd','Mount Lavinia','Colombo','SRI LANKA','CO P 10370','+94-72-2995503','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 04:23:13',0,NULL,3,1,3,1,'RA184568272CN\r ','sajith050683'),(16400,725351291018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','resin_de','b.hammer.meister@web.de','Burkhard Hammermeister','Breite Straße 35','Rohrberg','','GERMANY','38489','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 05:21:30',0,NULL,3,0,3,1,'RA184568330CN\r ','resin_de\rXXXL   (已入库）'),(16401,723388735001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',136.63,'hermeshine','silverrain1986','vithiwat@gmail.com','Vithiwat Rojanatrekoon','64 Ladpraw 62<br>Wangthonglang','Bangkok','','THAILAND','10310','029335811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 05:53:03',0,NULL,3,1,6,1,'EE495359432CN ','silverrain1986\r50-70单灯头 柔光箱  * 2\r115w 220v 灯泡 *2\r2m 灯架 * 2\r灯架包 * 1\r普通有线快门线C1  * 1\r普通有线快门线C3  * 1（已入库）\r实重4.48 抛重6.38\r'),(16402,765484044002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','chesysmax','rcnacpil@hotmail.com','Raymond Nacpil','Commonwealth Engineers Co. Ltd 3-35-2 Nagaoka 2 Bldg, Takadanobaba','Shinjuku-ku','Tokyo','JAPAN','169-0075','(81)03-5389-2303','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 05:32:31',0,NULL,3,1,3,1,'RA184568241CN\r ','chesysmax'),(16403,723414531001,110417009256,'NIB TianYa 77mm ND8 filter New 77 Neutral Density Grey',1,'AA2314',7.4,'hermeshine','oxfv','ebay@nikak.net','Valera Fooksman','930 Far Creek Way','Emerald Hills','CA','UNITED STATES','94062-3434','(650) 520-5239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 07:18:45',0,NULL,3,1,1,1,NULL,'oxfv'),(16404,723268364001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',31,'hermeshine','edubod','eduardob1@bezeqint.net','eduardo  bodner','Ha pikus 144','Newe Yamin','-','ISRAEL','49920','(972)-52-3654698','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 07:34:22',0,NULL,3,1,3,1,'RA184568476CN ','edubod'),(16405,8881315899749780,111,'72mm 环架套装',1,'',0,'hermeshine','jcrldo','charly_1987_19@msn.com','Carlos Ruiz','francisco pizarro<br>Nº 1','lebrija','Andalucía Ceuta y Melilla','SPAIN','41740','955971975',NULL,NULL,NULL,'2011-09-13 07:42:29',0,NULL,3,0,3,1,'RA184568312CN\r ','jcrldo\r第一次平邮发货没收到，重发（已入库） '),(16406,8881315901516931,111,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',212.64,'aliexpress','1004333531','jmz@mail.ru','Oleg Dubovtsev	','Moskovsky Prospekt 61-107','Togliatti','Samara Region	','RUSSIAN FEDERATION	','445028','+007- 927 7792967',NULL,NULL,NULL,'2011-09-13 08:11:56',0,NULL,3,1,5,1,'CP238031025CN ','C++\r力飞 影视闪光灯 lf200w  *  2（已入库）'),(16407,8881315902086255,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',19.47,'aliexpress','1004352589','lixoapc@gmail.com','Adao Paulo Caldeira	','Rua Nova Delhi 352 CS3 Jardim Edith','Sao Paulo	','','BRAZIL','04813240','+55 11 35324701',NULL,NULL,NULL,'2011-09-13 08:21:26',0,NULL,3,1,3,1,'RA184568391CN\r ',NULL),(16408,723434470001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','bellotari_badajoz','malfonsogon@gmail.com','Valentín Cantero Holguera','Montesinos, 23<br>Policía Local','Badajoz','Extremadura','SPAIN','06002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 09:00:38',0,NULL,3,1,2,1,NULL,'bellotari_badajoz'),(16409,781150152017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','4_our_4_kids','4our4kids@live.com.au','Thomas Maywald','14 Parker Street','Port Pirie','South Australia','AUSTRALIA','5540','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 09:13:33',0,NULL,3,1,2,1,NULL,'4_our_4_kids'),(16410,851467089015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',61,'hutongstore','gordy.russ','gordy.russell@yahoo.com','Gordon Russell','25d Bridge Street','Dumbarton','West Dunbartonshire','UNITED KINGDOM','G82 1NY','07825235049','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-13 09:36:14',0,NULL,3,1,4,1,'YW865546560CN','gordy.russ\r英标'),(16487,766049416002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',15,'AE3102',118.35,'hermeshine','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 14:23:41',0,NULL,3,1,4,1,'YW865546814CN ','fa636739\r2.3'),(16411,723449366001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',8.99,'hermeshine','colzie72','tickle_pink@hotmail.com','Ann Coles','26 Pembroke Rd','Stratford','Taranaki','NEW ZEALAND','4332','0273215692','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 10:01:47',0,NULL,3,1,17,0,NULL,'colzie72'),(16412,765539395002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','colzie72','tickle_pink@hotmail.com','Ann Coles','26 Pembroke Rd','Stratford','Taranaki','NEW ZEALAND','4332','0273215692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 10:05:16',0,NULL,3,1,11,1,NULL,'colzie72\r反光伞    1\rcanon 三角包  D3    1'),(16413,723459628001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','athula_wijerathna','athulawijerathna@gmail.com','Athula Wijerathna','Homagama, Kelanigama,','Ginigathhena','Central Province','SRI LANKA','20688','094776552944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 10:45:15',0,NULL,3,1,2,1,NULL,'athula_wijerathna'),(16414,765553697002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','petrs4321','freedomphoto@email.cz','Petr Svoboda','Palachova 425/22<br>tel.: 608177730','Poděbrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 11:02:04',0,NULL,3,1,2,1,NULL,'petrs4321'),(16461,851954669015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','cabalistor2008','foreternallove@hotmail.com','Edgar Lim','Blk 840, Yishun Street 81<br>#11-380','default','','SINGAPORE','760840','+6591860288','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 05:34:58',0,NULL,3,1,11,1,NULL,'cabalistor2008'),(16415,781182860017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','adambramley','adam.bramley@scottwilson.com','Adam Bramley','16/245 Main Street<br>Kangaroo Point','Brisbane','Queensland','AUSTRALIA','4169','0449255241','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 11:13:19',0,NULL,3,1,2,1,NULL,'adambramley'),(16416,8881315913253494,111,'New Timer Remote Control for Canon EOS 450D 400D 350D',50,'',1800,'hermeshine','Pierro Astro','pierro@pierro-astro.com','PIERRO ASTRO - Pierre FRANQUET','Le Clos de Naïs 6 rue du Chardonnay','LIEURAN LES BEZIERS','','FRANCE','34290','+33 6 09 57 47 38',NULL,NULL,NULL,'2011-09-13 11:27:33',0,NULL,3,1,12,1,'5241700645\r ',' 实重9.62 抛重7.87\r最终计费  10'),(16417,850357697015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',2,'AKT017',140,'hutongstore','gazpachu2002','joanmira@gmail.com','Joan Mira','21 lacewing close. Plaistow','London','London','UNITED KINGDOM','E138AD',' 07775288613','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-13 11:52:32',0,NULL,3,1,12,1,'5241706735\r ','gazpachu2002\r英标\r实重8.4 抛重10.04\r最终计费11'),(16418,723478395001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','greycat755','greycat@tut.by','Siarhei Patapau','Mazurova 117a-1','Gomel','','BELARUS','246006','+375297316272','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-13 11:58:55',0,NULL,3,1,3,1,'RA184568459CN ','greycat755'),(16419,723477276001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','alperorus','alperor@gmail.com','Alper Orus','Gurpinar Mah. Bulgurlu Cad.<br>Masaldan Is Merkezi G Blok Kat:3','Istanbul','BCamlica','TURKEY','34696','902163165353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 12:01:18',0,NULL,3,1,2,1,NULL,'alperorus'),(16420,781198756017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',57.8,'photographyacc','c5032005','jah_81@bigpond.com','James Harris','173 Queen St','Warragul','Victoria','AUSTRALIA','3820','0356235005','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 12:06:44',0,NULL,3,1,3,1,'RA184568533CN ','c5032005\r天涯方形滤镜系列  CPL    1\r1 * 无牌 方形滤镜渐灰ND4\r1 * 无牌 方形滤镜渐灰ND8\r1 * 无牌 方形滤镜渐变蓝\r1 * 无牌 方形滤镜渐变橙\r1 * 无牌 方形滤镜渐变日落\r1 * 无牌 方形滤镜渐变棕\r1 * 无牌 方形滤镜渐变红\r1 * 无牌 方形滤镜ND2\r1 * 无牌 方形滤镜ND4\r1 * 无牌 方形滤镜ND8'),(16421,781201916017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',35.96,'photographyacc','c4ris82','c4ris.young@bigpond.com','christine young','25 calais cct','cranbourne west','Victoria','AUSTRALIA','3977','0359951770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 12:29:18',0,NULL,3,1,17,0,NULL,'c4ris82'),(16422,851535514015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','krokimodell','stripper@live.se','Marcus Sandberg','Sjogard 20','Lemland','Aland','FINLAND','FIN-22610','+3584573688182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 12:52:50',0,NULL,3,1,2,1,NULL,'krokimodell'),(16423,725460343018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','pashpink9','pash-pink@hotmail.com','melissa sita','108  Railway  Pde','Pascoe Vale','Victoria','AUSTRALIA','3044','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 13:01:04',0,NULL,3,1,3,1,'RA184568502CN ','pashpink9'),(16424,723497685001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','kouikaros','kou_ele@hotmail.com','NIKOLAOS SIMOU','ALEKSANDROU PANTOY 4-6','KALLITHEA','ATHENS','GREECE','17671','+306974228013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 13:03:24',0,NULL,3,1,17,0,' ','kouikaros'),(16425,725465290018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','balibm','laky.balazs@hu.ibm.com','Balazs Laky','Hubner A 18 IV/5','Szekesfehervar','Fejer','HUNGARY','8000','36206631597','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 13:14:34',0,NULL,3,1,2,1,NULL,'balibm'),(16426,725465136018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',2,'AC2301',11.8,'photographyacc','iit1992','jerry88317@yahoo.com.tw','Chih Yung Tsai','4F 13 LN98 Hoping W. Rd.Section 2','Taipei','','TAIWAN','0932-824734','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 13:14:42',0,NULL,3,1,2,1,NULL,'iit1992'),(16427,723504044001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','dmitry092009','diim1@mail.ru','Dmitry Scheglov','4-7<br>Kirillova st.','Saransk','Mordovia','RUSSIAN FEDERATION','430004','9176960916','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 13:24:14',0,NULL,3,1,3,1,'RA184568365CN ','dmitry092009'),(16428,851561717015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','kpn274f9','grant@topmail.ie','stephen grant','25 rosemount park<br>rosegreen','cashel','Tipperary','IRELAND','default','06285008','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 14:03:55',0,NULL,3,1,3,1,'RA184568374CN ','kpn274f9'),(16429,765611997002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','marikksk','sembaevm@gmail.com','Marat Sembayev','ulica Kustanaiskaya 79, kvartira 75','Semey','KZ','KAZAKHSTAN','071410','77222348163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 14:21:35',0,NULL,3,1,3,1,'RA184568428CN ','marikksk\r放布'),(16430,723546281001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','futagiki','alexgor1973@yandex.ru','Gorokhov Aleksandr Gorokhov','Chernyakhovskogo 33-74','kursk','','RUSSIAN FEDERATION','305018','+7-910-730-82-83','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-13 15:41:46',0,NULL,3,1,3,1,'RA184568445CN ','futagiki'),(16431,723503206001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.95,'hermeshine','kouikaros','kou_ele@hotmail.com','NIKOLAOS SIMOU','ALEKSANDROU PANTOY 4-6','KALLITHEA','ATHENS','GREECE','17671','+306974228013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 15:52:06',0,NULL,3,1,17,0,NULL,'kouikaros'),(16432,723552687001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','dmemval','dmemram@gmail.com','david memram','40 yzthak rabin, appartment 3','modiin','IN','ISRAEL','71704','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 15:55:56',0,NULL,3,1,2,1,NULL,'dmemval'),(16433,851613237015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','sawber67','billkemmy@eircom.net','Bill Kemmy','Bishop\'s House<br>Dublin Road','Carlow','Carlow','IRELAND','default','0872308053','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-13 16:01:10',0,NULL,3,1,17,0,NULL,'sawber67'),(16434,851611018015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','sawber67','billkemmy@eircom.net','Bill Kemmy','Bishop\'s House<br>Dublin Road','Carlow','Carlow','IRELAND','default','0872308053','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 16:01:10',0,NULL,3,1,4,1,'YW865546556CN ','sawber67\r除了c 里面的再发\r115w 5500k 灯泡  220v    2\r英标'),(16435,765648516002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','kouikaros','kou_ele@hotmail.com','NIKOLAOS SIMOU','ALEKSANDROU PANTOY 4-6','KALLITHEA','ATHENS','GREECE','17671','+306974228013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:06:24',0,NULL,3,1,2,1,NULL,'kouikaros\r52-58mm 双阳环   1\r绿叶 CPL  52mm    1\r绿叶 UV  52mm     1'),(16436,765656771002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',218,'hermeshine','antikobby','cislorod@mail.ru','Vitali  Fedorchenko +79219092939','Maliy pr.Petrog side 70/18 flat 3.','Sankt-peterburg','','RUSSIAN FEDERATION','197136','+79219092939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:27:03',0,NULL,3,1,17,0,NULL,'antikobby'),(16437,765658013002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','antikobby','cislorod@mail.ru','Vitali  Fedorchenko +79219092939','Maliy pr.Petrog side 70/18 flat 3.','Sankt-peterburg','','RUSSIAN FEDERATION','197136','+79219092939','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 16:31:28',0,NULL,3,1,5,1,'CP235627825CN ','antikobby\r灯架  2m    2\r力飞 影视闪光灯 lf200w  欧标  2\r50-70柔光棚 通用塑料卡口   2\r灯架包      1  （ 牛津布的那个）\r圆形柔光棚 50cm     1\r实重6.26 抛重7.03'),(16438,765696520002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',2,'AD1172',17.98,'hermeshine','alesabha','alucha78@hotmail.com','Maria Alejandra Sabha','Junin 605 <br>7mo piso  -  Dpto. \"A\"','San Miguel de Tucuman','Tucuman','ARGENTINA','4000','0381-4211063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 17:59:27',0,NULL,3,1,2,1,NULL,'alesabha'),(16439,725445964018,280680883047,'Dslr Remote Shutter Release Cord RS-S1 SONY RM-S1AM',1,'AA3212',5.69,'photographyacc','c4ris82','c4ris.young@bigpond.com','christine young','25 calais cct','cranbourne west','Victoria','AUSTRALIA','3977','0359951770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 19:15:12',0,NULL,3,1,3,1,'RA184568604CN\r ','c4ris82\r爵影红外 canon     1\r普通有线快门线S1    1\r柔光伞    1\r普通有线快门线C1     1\r1.6*3白色背景布    1\r已入库'),(16440,724792532018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','mereacre1','tolick@gmail.com','Anatol Mereacre','Petru Zadnipru 6, apt. 25','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2044','+37369516622','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-13 19:37:42',0,NULL,3,1,3,1,'RA184568414CN ','mereacre1\r加一块柔光布'),(16441,765750292002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','izapem1','izapem@fidnet.com','Eddie Tyree','560 Mossy Glen rd','Sullivan','MO','UNITED STATES','63080','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-13 19:46:10',0,NULL,3,1,1,1,NULL,'izapem1'),(16442,765750354002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','al2260','netaffects@hotmail.com','Alberto Sanchez','3001 SW 2nd Ave','Miami','FL','UNITED STATES','33129-2705','(786) 426-0062','NoPaymentFailure','CheckoutComplete','Other','2011-09-13 19:46:57',0,NULL,3,1,17,0,NULL,'al2260'),(16443,723654816001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','al2260','netaffects@hotmail.com','Alberto Sanchez','3001 SW 2nd Ave','Miami','FL','UNITED STATES','33129-2705','(786) 426-0062','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-13 19:47:00',0,NULL,3,1,4,1,'YW865546545CN ','al2260\r伟峰717 手柄   1\r三脚架 伟峰 EI-717  155    1\r应该是两个手柄'),(16444,834090560016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','aldoscic','aldosc@go.net.mt','Aldo Scicluna','89 Claire E. Engel Street','St Julian\'s','','MALTA','STJ 1814','+356 21382654','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-13 20:14:53',0,NULL,3,1,2,1,NULL,'aldoscic'),(16445,765772854002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','blacky0405','blacky0504@aol.com','michaela huth','robert-bosch-str.5','frickenhausen','','GERMANY','72636','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-13 20:32:50',0,NULL,3,1,3,1,'RA184568555CN ','blacky0405\rL   '),(16446,765803502002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','anin464','nina_grubeck@hotmail.com','Nina Grubeck','Töllergasse 19','Wien','','AUSTRIA','1210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 21:46:09',0,NULL,3,1,2,1,NULL,'anin464'),(16447,765814962002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','hamgamgi','deewey@gmail.com','David Guvå','Gullhönevägen 27','Skövde','Västra Götaland','SWEDEN','54165','+46733807286','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 22:20:49',0,NULL,3,1,17,0,NULL,'hamgamgi'),(16448,723715697001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','neno63','neno.draganic@inet.hr','Nenad Draganic','Na moru 2<br>Mokosica','Dubrovnik','Hrvatska','CROATIA','20236','00911624166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 22:22:54',0,NULL,3,0,3,1,'RA184568516CN\r ','neno63\r1.6*2.1黑色+白色背景布'),(16449,723717487001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','hamgamgi','deewey@gmail.com','David Guvå','Gullhönevägen 27','Skövde','Västra Götaland','SWEDEN','54165','+46733807286','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 22:28:02',0,NULL,3,1,4,1,'YW865546571CN ','hamgamgi\r800w红头灯      1\r800w  220v 灯泡   1\r欧标\r灯架  2m      1  '),(16450,725320977018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','ngatokoa2007','ntekii@hotmail.com','Ngatokoa Tekii','7 Respall Way','Arundel','Queensland','AUSTRALIA','4214','0405668842','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-13 22:56:03',0,NULL,3,1,4,1,'YW865546501CN  ','ngatokoa2007\r1.6*2.1黑色+白色背景布'),(16451,723731287001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','ntinosss','ntinosss@gmail.com','KONSTANTINOS DIMAS','KIMI EVIAS','KIMI EVIAS','','GREECE','34003','00302222024307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-13 23:25:46',0,NULL,3,1,4,1,'YW865546582CN ','ntinosss\r燕文告知地址错误  现在货在邮局 需要联系客户▲\r已发信'),(16452,725709650018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.66,'photographyacc','ronxx711','bigbirdxx7@yahoo.com','Ron Tesch','2/11 henry st','stuart park','Northern Territory','AUSTRALIA','0820','0447312976','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 23:54:15',0,NULL,3,1,2,1,NULL,'ronxx711'),(16453,781486828017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','rustydazzle','dljacob@dodo.com.au','Darren jacob','36 Balmoral crescent','Bairnsdale','Victoria','AUSTRALIA','3875','0438574691','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-13 23:54:31',0,NULL,3,1,2,1,NULL,'rustydazzle'),(16454,781491394017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','melkjb','melkjb@aapt.net.au','Melissa Rudzinski','17 Strathmore Road','Caves Beach','New South Wales','AUSTRALIA','2281','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 00:11:07',0,NULL,3,1,2,1,NULL,'melkjb'),(16455,765843780002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.89,'hermeshine','vinay4y','vinay4y@gmail.com','Vinay Kanth Koduri','Foster\'s Group Limited<br>77 Southbank Boulevard','Southbank','Victoria','AUSTRALIA','3006','0433492744','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-09-14 00:11:51',0,NULL,3,0,2,1,NULL,'vinay4y\r澳标'),(16456,851360857015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','edjones42','edjones42@hotmail.com','Kraft Foods  C/O  Ed Jones','367 Haynes Dr','Wood Dale','IL','UNITED STATES','60191-2614','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 00:18:04',0,NULL,3,1,3,1,'RA184568431CN ','edjones42\r好像地上有一个包好的，但需要看下里面是否有两块布\r'),(16457,723745282001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','tolis1365','flioukas@yahoo.gr','Tolis Flioukas','herostratous 11','Chios','Greece','GREECE','82100','6945885305','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-14 00:25:25',0,NULL,3,1,2,1,NULL,'tolis1365'),(16458,725738659018,280722265640,'New 10 pcs Landscape Color Filters Kit for Cokin P',1,'AKT077',42,'photographyacc','tristanmurphy1991','tmurphyphotography@gmail.com','Tristan Murphy','315<br>High st','Maitland','New South Wales','AUSTRALIA','2320','249347007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 01:09:52',0,NULL,3,1,3,1,'RA184568520CN ','tristanmurphy1991'),(16459,725749899018,280667759489,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',38.87,'photographyacc','designgirl705','lindasletterbox@hotmail.com','Linda Wright','7 alexander parade','Charlestown','New South Wales','AUSTRALIA','2290','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 01:59:00',0,NULL,3,0,3,1,'RA184568547CN ','designgirl705\r闪光灯D座     1\r方形滤镜接口环 67mm    1\r方形滤镜接口环 77mm     1\r广角托架       1\r普通托架       1\r普通热靴保护盖    1\r已入库\r'),(16460,725768186018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',53.19,'photographyacc','joeyblowie','jgr23741@bigpond.net.au','Joe Grech','43 Greendale rd','Wallacia','New South Wales','AUSTRALIA','2745','0247738020','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 03:06:24',0,NULL,3,1,3,1,'RA184568493CN ','joeyblowie\r绿叶 UV  67mm    1\r2螺丝井字扳手    1'),(16462,723565022001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',5,'AE1201',19.5,'hermeshine','20103153735','3153735@gmail.com','Vladislav Likholetov','Golubinskaya st. 8 -301','Volgograd','','RUSSIAN FEDERATION','400131','+79033153735','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 05:46:38',0,NULL,3,1,3,1,'RA184568480CN ','20103153735'),(16463,851966364015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','davidt16','davidt4@gmail.com','David Turgeman','2/7 hanechalim st.','Maale Edomim','israel','ISRAEL','98350','972-50-8870146','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-14 06:27:08',0,NULL,5,0,18,0,NULL,'davidt16'),(16464,725806558018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','davidt16','davidt4@gmail.com','David Turgeman','2/7 hanechalim st.','Maale Edomim','israel','ISRAEL','98350','972-50-8870146','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 06:30:15',0,NULL,5,0,18,0,NULL,'davidt16'),(16465,765929290002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','fatcat2248','sold@powerup.com.au','Jack Woollett','7 Hawthorne Street','Woody Point','Queensland','AUSTRALIA','4019','0418191155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 06:35:51',0,NULL,3,1,2,1,' ','fatcat2248'),(16466,723826022001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','eurinet','cedric.jordi84@gmail.com','Cédric Jordi','Riehentorstrasse 33','Basel','','SWITZERLAND','4058','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-14 07:03:30',0,NULL,3,1,2,1,NULL,'eurinet'),(16467,725813226018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','keefy_sg','kimmikeef@gmail.com','Kai Yuan Lee','Unit 31<br>60 Brocks Lane','Newtown','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 07:09:52',0,NULL,3,0,2,1,NULL,'keefy_sg\r1.6*2.1白色背景布  1'),(16468,781591731017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','plant305','plantmo@bigpond.com','Norman Plant','30 Henry Sutton Cct<br>Dunlop','Canberra','Australian Capital Territory','AUSTRALIA','2615','0262595662','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 07:26:16',0,NULL,3,1,2,1,NULL,'plant305'),(16469,765948312002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','amicidicani','tiffanianne66@hotmail.com','anne maenurm','via della villa 55/h<br>castions della mura','bagnaria arsa','UD','ITALY','33050','3496160874','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 08:12:52',0,NULL,3,1,3,1,'RA184568595CN\r ','amicidicani'),(16470,781613687017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',18.48,'photographyacc','utemart73','utemart@optusnet.com.au','Leon Whitworth','73 Lower West Burleigh Rd','Burleigh Heads','Queensland','AUSTRALIA','4220','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 09:00:32',0,NULL,3,1,3,1,'RA184568670CN\r ','utemart73\rcanon 机身盖、镜头后盖    1\rmini红外遥控  canon     1\rlenspen    1\r气吹+布    1（已入库）\r'),(16471,834323512016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',9,'hutongstore','milnrow','merman@supanet.com','John S Bracewell','193 Market St<br>Shawforth','Rochdale','Lancashire','UNITED KINGDOM','OL12 8PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 09:11:11',0,NULL,3,1,2,1,NULL,'milnrow'),(16472,8881315993879856,111,'1.6x3m 背景布  灰色   x   1',1,'',0,'hermeshine','sinlightpictures','dybowskipiotr@gmail.com','Piotr Dybowski','eBay Limited, The Atrium<br>Old Navan Road, Blanchardstown','Dublin','Dublin','IRELAND','15','0876329866',NULL,NULL,NULL,'2011-09-14 09:51:19',0,NULL,3,0,3,1,'RA184568745CN\r ',NULL),(16473,723854436001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','matushkin123','matushkin@gmail.com','Alexey  Matushkin','Kosmonavtov street, 25-12','Rostov-on-Don','rnd','RUSSIAN FEDERATION','344113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 09:20:58',0,NULL,3,1,5,1,'CP235627771CN ','matushkin123'),(16474,765980506002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','xdne0756','paypal0756@gmail.com','Md Asdeny Hj Yakub','No 8 Spg 1626 Kg Tanjong Nangka Km 18<br>Jln Tutong','BSB 10','Brunei Muara','BRUNEI DARUSSALAM','BG2321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:29:45',0,NULL,3,1,2,1,NULL,'xdne0756'),(16475,716757277001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',31,'hermeshine','goronzz','goronz@libero.it','Luca Goroni','via di porta fabbrica , 15 int.b12','Roma','RM','ITALY','00165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 10:44:59',0,NULL,3,1,3,1,'RA184568754CN ','goronzz\rreflector holder $18'),(16476,765989432002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',67.36,'hermeshine','ilovehairandbeauty','suzyhiggins_58@hotmail.com','Suzy Higgins','22 Keats st<br>Cannon Hill','Brisbane','Queensland','AUSTRALIA','4170','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-14 11:05:56',0,NULL,3,1,4,1,'YW865546630CN ','ilovehairandbeauty\r1.6*2.1白色背景布    1'),(16477,765991835002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','xxltv','klod@list.ru','Arman Ghazaryan','Yana Rainisa boulevard<br>House 45, Building 1, Apartment 151','Moscow','Moscow','RUSSIAN FEDERATION','125373','+79266501040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 11:14:10',0,NULL,3,1,2,1,NULL,'xxltv'),(16478,765994806002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','babybutchers','sarb07@isynergy.com.au','sarah butcher','20 pelican ave<br>condon','townsville','Queensland','AUSTRALIA','4815','0419763383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 11:31:23',0,NULL,3,1,2,1,NULL,'babybutchers'),(16479,852050233015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','c6bon','lens444@yahoo.fr','Jean Louis Carrasco','57 rue du Moulin Vert','PARIS','PARIS','FRANCE','75014','+33611183830','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-14 11:15:52',0,NULL,3,1,3,1,'RA184568666CN\r ','c6bon\r再加4灯头里的保险丝 2个'),(16480,723121367001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','katiuneabay','katiunea@inbox.ru','Bicov Vitali','str. Independentei 14/4, ap. 79','Chisinau','MDA','MOLDOVA, REPUBLIC OF','2043','(373) 22 85 05 05','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 11:38:30',0,NULL,3,1,5,1,'CP235627785CN','katiuneabay\r欧标\r实重7.1  抛重8.83'),(16481,781660183017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','grahamlane0','grahamlane@bigpond.com','GRAHAM LANE','76 CHESTERFIELD PARADE','BRONTE','New South Wales','AUSTRALIA','2024','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 11:43:03',0,NULL,3,1,2,1,NULL,'grahamlane0'),(16482,725887880018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','lasting99','laisoon.ting@gmail.com','Lai Soon Ting','Lot 2255, Jalan Piasau Lorong 2B','Miri','Sarawak','MALAYSIA','98000','0132688881','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 12:06:17',0,NULL,3,1,3,1,'RA184568808CN ','lasting99'),(16483,723909393001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','archimix','admin@vip-webstudio.com','Denis Saralidze','Cingizxan Kerimov str.<br>Building 4 Apartment 35','Baku','Xatai','AZERBAIJAN','AZ1123','+994505036483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 12:47:29',0,NULL,3,0,2,1,NULL,'archimix\r 绿色 1.6x2.1'),(16484,852085139015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','snaphappyspen','daniel.spencer@hotmail.co.uk','Daniel Spencer','3 Woodside Cottages<br>Milnsbridge','Huddersfield','West Yorkshire','UNITED KINGDOM','HD3 4PP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 12:47:51',0,NULL,3,1,3,1,'RA184568635CN ','snaphappyspen'),(16485,723925770001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','alexandrosmargo','acunmargo@yahoo.com','Heriyanto Margo','49-289 Sussex St.','Sydney','New South Wales','AUSTRALIA','2000','61430435666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 13:41:46',0,NULL,3,1,4,1,'YW865546641CN ','alexandrosmargo'),(16486,723911952001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',2,'AO0011',159.98,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sadeq tawfeek','Qatif','tarout','QATIF','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-14 12:56:52',0,NULL,3,1,3,1,'RA184568839CN ','tawfeekmohammed\r大概分4票\rRA184568842CN\rRA184568825CN\rRA184568856CN'),(16488,766056558002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','froshmasta','jwoodman@easthants.ca','Jonathan Woodman','31 Lacey rd','Milford Station','NS','CANADA','B0N1Y0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 14:43:59',0,NULL,3,1,2,1,NULL,'froshmasta'),(16489,766065475002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','matsprest','mats_prestegard@hotmail.com','Siri Prestegård','Olav Kyrre Gate 5','Bryne','Rogaland','NORWAY','4340','93426686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 15:10:51',0,NULL,3,1,2,1,NULL,'matsprest'),(16490,725955772018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','1969knudsen1969','ung-nat@hotmail.com','Photo Care','Att. John Knudsen<br>Bredgade 15E','Herning','Denmark','DENMARK','7400','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 15:24:28',0,NULL,3,1,2,1,NULL,'1969knudsen1969'),(16491,766080520002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','wetpsych','leochristianlumbre@yahoo.com','Leo Christian Lumbre','#6 Sapphire Street Pangilinan Compound<br>Tandang Sora','Quezon City','GMA','PHILIPPINES','1100','6324337777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 15:49:19',0,NULL,3,1,3,1,'RA184568652CN ','wetpsych'),(16492,723976819001,110414160576,'62mm CPL Circular Polarizing Filter 62 CPL Green.L ',1,'AA3311',6.3,'hermeshine','vacha156','edgaze@inbox.lv','Edgars Zarins','Telegrafa 4-59','Tukums','Tukums','LATVIA','LV3101','+37129162335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 16:10:28',0,NULL,3,1,2,1,NULL,'vacha156'),(16493,852190803015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',4,'AC2402',48.4,'hutongstore','baklan4ikof','saveleva.da@gmail.com','Saveleva Darya','3 Vladimirskaya 8/1- 8','Mosсow','Russian Federation','RUSSIAN FEDERATION','111123','(926)345-5526','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-14 16:49:18',0,NULL,3,1,3,1,'RA184568683CN\r ','baklan4ikof\r超重就发sal '),(16494,723998607001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jueves_12','jueves_12@hotmail.com','Carlos Lucas Tamames','c/ Palanca, 42<br>Fuentesaúco','Zamora','Castilla y León','SPAIN','49400','629847457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 17:03:47',0,NULL,3,1,2,1,NULL,'jueves_12'),(16495,852208739015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',20.99,'hutongstore','free-poet','peter.williams4@ntlworld.com','Peter Williams','2 Stour Court<br>Thornhill','Cwmbrân','Torfaen','UNITED KINGDOM','NP44 5UE','01633671608','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-14 17:18:54',0,NULL,3,1,3,1,'RA184568581CN ','free-poet\r840'),(16496,781805480017,270744172089,'55mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT019',4.19,'photographyacc','fusion711','sdlafferty@gmail.com','Scott Lafferty','1/82 Tyler St, Tuart Hill','Perth','Western Australia','AUSTRALIA','6060','0894023276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-14 17:56:31',0,NULL,3,1,2,1,NULL,'fusion711'),(16497,766148343002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',31.89,'hermeshine','algordon','photogord@aol.com','Gordon-Ralston Photography','315 Hickerson Dr<br>Ste B','Murfreesboro','TN','UNITED STATES','37129-3528','(615) 396-8776','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-14 18:31:58',0,NULL,3,1,3,1,'RA184568564CN ','algordon'),(16498,852248407015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','redraven2021','redraven2021@yahoo.co.uk','Paul M Dean','75A Beechwood Dr.<br>Bonhill, Alexandria','Glasgow','West Dunbartonshire','UNITED KINGDOM','G839LR','01389607315','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 18:36:31',0,NULL,3,1,2,1,NULL,'redraven2021'),(16499,724050695001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','hipanto','augustomoliveira@yahoo.com.br','Augusto Oliveira','Rua Pedro Luis de Lima, nº 317<br>Bairro Floramar','Belo Horizonte','Minas Gerais','BRAZIL','31742-235','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-14 18:51:57',0,NULL,3,1,2,1,NULL,'hipanto'),(16500,852314026015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','biker_adrian','adrianrclarke@yahoo.co.uk','Adrian Clarke','Keillour House<br>9 Wildernesse Mount','Sevenoaks','Kent','UNITED KINGDOM','TN13 3QS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-14 20:00:12',0,NULL,3,1,3,1,'RA184568578CN\r ','biker_adrian'),(16501,726111629018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','kapitaen-flitschauge','kapitaen-flitschauge@gmx.de','Not-Humdrum D.Sign UGhb c/o Mich','Haubahn 20','Wuppertal','','GERMANY','42119','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 20:48:26',0,NULL,3,0,3,1,'RA184568697CN\r ','kapitaen-flitschauge\rxxxl    已入库'),(16502,726156128018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',60,'photographyacc','pozo012','pozojorge@hotmail.com','Jorge Pozo Estrella','Ramon Mas 21, 2º 2ª','Sant Cugat del Valles','Barcelona','SPAIN','08174','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 22:54:25',0,NULL,3,1,4,1,'YW865546615CN ','pozo012'),(16503,723704120001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-14 23:28:50',0,NULL,3,0,3,1,'RA184568618CN ','saud-p\r1.6*2.1黑色背景布    2\r贴made in china\rRA184568621CN'),(16504,781957578017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','videomike1243','mlynch112@aol.com','michael lynch','5501 W Agatite Ave','CHICAGO','IL','UNITED STATES','60630-3504','(773) 481-0324','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-14 23:33:23',0,NULL,3,1,1,1,NULL,'videomike1243'),(16505,726198933018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','mayla6570','mpiccininni@virginbroadband.com.au','mandy piccininni','2a adamson road<br>brentwood','perth','Western Australia','AUSTRALIA','6153','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-15 01:46:30',0,NULL,3,1,4,1,'YW865546626CN ','mayla6570\r燕文告知收件人不在 需邮件 ▲\r已发信'),(16506,726217237018,280673080920,'62mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 62 mm',1,'AB1304',5.66,'photographyacc','majorautojunkie','nat.wilson@live.com.au','Nat Wilson c/o Radio 2LT','289 Main Street','Lithgow','New South Wales','AUSTRALIA','2790','0423642568','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 03:01:17',0,NULL,3,1,2,1,NULL,'majorautojunkie'),(16507,724215726001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','dabre4','bremner.doug@gmail.com','Douglas Bremner','17/46 Eucalyptus Drive','Maidstone','Victoria','AUSTRALIA','3012','0422961200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 03:46:32',0,NULL,3,1,2,1,NULL,'dabre4'),(16508,782027394017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',33.98,'photographyacc','elempleadodelmes','sebasmac.foto@gmail.com','Sebastian Maciel','CC853<br>J.D. Peron 242','Correo Central','Buenos Aires','ARGENTINA','1000','00541148566250','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-15 04:17:47',0,NULL,3,1,3,1,'RA184568706CN\r ','elempleadodelmes\r永诺 canon ttl 线  1m    1\r永诺  nikon  ttl 线  1m      1\r已入库\r  '),(16509,8881316060295798,111,'Photo Studio Light Kit Stand Tripod Boom Arm w 115W bulb',2,'AKT064',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México Distrito Federal','','MEXICO','14200','',NULL,NULL,NULL,'2011-09-15 04:18:15',0,NULL,3,1,12,1,'5241709071\r ','灯泡都是110v\rc里的东西 再加上\r\r45w 110v   8\r115w   110v    1（加上c里的一共3个）\r50-70 单灯头棚    1 （已入库）\r实重8.26 抛重11.52\r\r'),(16510,8881316061146025,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',15.58,'aliexpress','1004387752','afelipe87@hotmail.com','Felipe Cartagena','Alameda Nabuco de Araujo 422 kitinete 6','Ponta Grossa	','Parana','BRAZIL','84031510','+55 42 99232446',NULL,NULL,NULL,'2011-09-15 04:32:26',0,NULL,3,1,3,1,'RA184566016CN ',''),(16556,724623064001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',4,'AA1312',6,'hermeshine','proudirishgirl2','proudirishgirl@hotmail.com','Maureen O\'Toole-Roselli','118 Wait Street','Springfield','MA','UNITED STATES','01104-1942','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 03:21:51',0,NULL,3,1,1,1,NULL,'proudirishgirl2'),(16511,766354209002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','felixzhai11','houbing.zhai@live.longwood.edu','Houbing Zhai','Longwood University Box No.856','Farmville','VA','UNITED STATES','23909','(434) 219-7698','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-15 05:06:14',0,NULL,3,1,1,1,NULL,'felixzhai11'),(16512,782038539017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','catnewman84','cat84@ymail.com','Catherine Newman','C/- Cooper Grace Ward<br>Level 21, 400 George Street','Brisbane','Queensland','AUSTRALIA','4000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 05:14:13',0,NULL,3,1,2,1,NULL,'catnewman84'),(16513,726244906018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','tilly-ally','tilly-ally@hotmail.com','Alison Ramsamy','161 goldsmith st mackay, qld australia  4740','Mackay','Queensland','AUSTRALIA','4740','0439717228','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-15 05:27:42',0,NULL,3,1,4,1,'YW865546593CN ','tilly-ally\r1.6*2.1黑色加白色背景布'),(16514,721055662001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','tuokarki','tkarki@jippii.fi','Tuomas Kärki','Tellervonkatu 15 b1','Jyväskylä','Keski-Suomi','FINLAND','40200','+358405763513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 06:30:15',0,NULL,3,1,3,1,'RA184568723CN ','tuokarki'),(16515,726256616018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','blachtom','tom@tomblachford.com','Tom Blachford','147 Kerferd Road Albert Park','Melbourne','Victoria','AUSTRALIA','3206','0396963525','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 06:33:06',0,NULL,3,1,3,1,'RA184568737CN ','blachtom'),(16516,766369552002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','zcurbside','aimz_curbside@hotmail.com','Amy Parks','17 Hugo Street<br>Chippindale','Sydney','New South Wales','AUSTRALIA','2008','0413124483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 06:37:50',0,NULL,3,1,2,1,NULL,'zcurbside'),(16517,567402751003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','damien.v','damien.vignaux@9online.fr','Damien VIGNAUX','Metzer strasse 24','BERLIN','','GERMANY','10405','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 07:03:36',0,NULL,3,1,4,1,'YW865546604CN ','damien.v'),(16518,782045464017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',5,'AA1301',40,'photographyacc','yagnol','rorymahony@gmail.com','Rory Mahony','4 Titian ct','Grovedale','Victoria','AUSTRALIA','3216','0438074299','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 07:30:13',0,NULL,3,0,3,1,'RA184568710CN ','yagnol\rCANON  77CM 镜头盖    8\rCANON  58CM 镜头盖    8\r已入库'),(16519,766385723002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','davebuck11','buckfuddy420@gmail.com','Matt Collier','306-84 Street SW','Edmonton','AB','CANADA','T6X 1H8','(780) 399-3472','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 07:58:38',0,NULL,3,1,2,1,NULL,'davebuck11'),(16520,852544291015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','horst_kirschner','horst@acumine.com','Horst Kirschner','Suite 145, National Innovation Centre, Australian Technology Park<br>4 Cornwallis St.','Eveleigh','New South Wales','AUSTRALIA','2015','0292094147','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 08:10:38',0,NULL,3,1,2,1,NULL,'horst_kirschner'),(16521,724271213001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','kristy3762','haweskristy@gmail.com','Kristy Hawes','4 scenic Cres','Albion Park','New South Wales','AUSTRALIA','2527','0242564895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 08:53:32',0,NULL,3,1,2,1,NULL,'kristy3762'),(16522,852558698015,250599955564,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',98,'hutongstore','serparsergio','serparsa@hotmail.com','sergio Párraga Sánchez','C Luis Sancenon nª 27<br>Manises','Valencia','Comunidad Valenciana','SPAIN','46940','605475010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 09:01:10',0,NULL,3,1,4,1,'YW865546652CN ','serparsergio'),(16523,724282896001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','rukshankb','admin@facepeer.com','Rukshan Kothwala','153/1, Tuttirigoda, Bulumulla<br>Kiribathkumbura','Kandy','Central','SRI LANKA','20442','+94718259370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 09:39:03',0,NULL,3,1,3,1,'RA184568873CN ','rukshankb'),(16524,852572095015,250599955564,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',98,'hutongstore','wilturn3','r.turner@exemail.com.au','Ron Turner','Unit 126<br>1 Hyde Parade','Campbelltown','New South Wales','AUSTRALIA','2560','0246280473','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 09:59:10',0,NULL,3,1,4,1,'CP865546663CN ','wilturn3'),(16525,766430605002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','ilkerkirmiziilker','ilkerkirmizi06@gmail.com','ilker kırmızı','Basbakanlik Yurtdisi Turkler ve Akr. Topl. Baskanligi<br>Mevlana Bulv. Oguzlar mah. No:145 Balgat - ÇANKAYA','ANKARA','','TURKEY','06520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 11:18:07',0,NULL,3,1,3,1,'RA184568935CN ','ilkerkirmiziilker\r别忘了放白色柔光布'),(16526,726326838018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','rn.biker','kc_reyes18@yahoo.com','Karlo Cesar III Reyes','PO Box 10003<br>PMB 323','Saipan','MP','UNITED STATES','96950','(670) 989-7055','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-15 11:43:44',0,NULL,3,1,3,1,'RA184568811CN ','rn.biker'),(16527,724318798001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','ghazwaan2005','khamase@optusnet.com.au','ghazwaan khamase','3/13 cragg st condell park','sydney','New South Wales','AUSTRALIA','2200','0297933597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 12:08:24',0,NULL,3,1,17,0,NULL,'ghazwaan2005'),(16528,766443555002,120757500040,'New Rolling Hard Case with Dividers for Photo Equipment',1,'AD1165',125,'hermeshine','ghazwaan2005','khamase@optusnet.com.au','ghazwaan khamase','3/13 cragg st condell park','sydney','New South Wales','AUSTRALIA','2200','0297933597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 12:08:24',0,NULL,3,1,4,1,'YW865546674CN ','ghazwaan2005\r红边套装包      1\r拉杆箱     1'),(16529,834920789016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',1.5,'hutongstore','stevecostin','steve.costin@btinternet.com','Stephen Costin','10 Wilfred Road','Ramsgate','Kent','UNITED KINGDOM','CT117RB','01843851222','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 12:12:00',0,NULL,3,1,17,0,NULL,'stevecostin'),(16530,726340163018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',32.99,'photographyacc','marlabe','helmutk@westnet.com.au','H & G  KUMMER','PO BOX 49','MARLO','Victoria','AUSTRALIA','3888','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 12:33:39',0,NULL,3,1,3,1,'RA184568927CN ','marlabe\r永诺 nikon ttl 线  1m     1\rN座    1'),(16531,782155677017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','cspiegel90','freak__im__kaefig@hotmail.com','Christoph Spiegel','Ursula Hall<br>Building 50, Daley Rd','Canberra','Australian Capital Territory','AUSTRALIA','0200','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 13:10:01',0,NULL,3,1,2,1,NULL,'cspiegel90'),(16532,782166774017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','sickfish.2007','theraviger@hotmail.com','Aaron Scicluna','7 courageous street Taylors Lakes','melbourne','Victoria','AUSTRALIA','3038','030409094172','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 13:44:23',0,NULL,3,1,2,1,NULL,'sickfish.2007'),(16533,852665216015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','manudyan','emmanueldyan@gmail.com','Emmanuel DYAN','25 Rue Bergère','Paris','Ile-de-France','FRANCE','75009','0662021518','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 14:13:06',0,NULL,3,1,4,1,'YW865546685CN ','manudyan\r1.6*2.1黑色加白色    '),(16534,851493187015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',51.99,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 14:23:11',0,NULL,3,1,17,0,NULL,'zetra450'),(16535,766480030002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rezooo4','mohrez10@yahoo.com','mohammad Rezaie','12 Grand View Ave','Dandenong','Victoria','AUSTRALIA','3175','0432103661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 14:27:42',0,NULL,3,1,2,1,NULL,'rezooo4'),(16536,766482970002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 14:37:39',0,NULL,3,1,4,1,'YW865546884CN ','zetra450\r柔光箱 50-70cm 单灯头欧标    1\r灯架包厚    1 （ 和2mx3m 背景架里用的包类似的那个）\r灯架包薄    1\r反光板支架   1   \r灯架   2   \r100-150 5in1  反光板    1\r115w 220v     2\r一票两件     （已入库）\r\r'),(16537,852684008015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','stevecostin','steve.costin@btinternet.com','Stephen Costin','10 Wilfred Road','Ramsgate','Kent','UNITED KINGDOM','CT117RB','01843851222','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 14:56:05',0,NULL,3,1,2,1,NULL,'stevecostin\r热靴保护盖  sony   1\r小号灰卡    1'),(16538,724382356001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','sarahjwentzell','sarahjwentzell@hotmail.com','sarah wentzell','308-197 dufferin street','bridgewater','NS','CANADA','B4V2G9','(902) 543-0055','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-15 15:33:51',0,NULL,3,1,2,1,NULL,'sarahjwentzell'),(16539,724389699001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','polovnikov','polovnikov-a@yandex.ru','Алексей Половников','Менделеева, 75,-','Полевской','','RUSSIAN FEDERATION','623388','+79122963299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 15:55:22',0,NULL,3,1,17,0,NULL,'polovnikov'),(16540,766518997002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','polovnikov','polovnikov-a@yandex.ru','Алексей Половников','Менделеева, 75,-','Полевской','','RUSSIAN FEDERATION','623388','+79122963299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 16:01:47',0,NULL,3,1,5,1,'CP235627493CN ','polovnikov\r150-200cm 5in1 反光板    1\r反光板 80cm 2合1      1'),(16541,726419404018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','lleone123','lle07612@bigpond.net.au','Lisa Leone','16 Seine Close','Werribee','Victoria','AUSTRALIA','3030','0397310745','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 16:20:01',0,NULL,3,1,3,1,'RA184568895CN ','lleone123'),(16542,852745874015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','drc232','denniscole@sky.com','Dennis Cole','2 Calshot Court, Calshot','Southampton','Hampshire','UNITED KINGDOM','so451bl','07880737390','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 17:10:05',0,NULL,3,1,3,1,'RA184568860CN ','drc232'),(16543,852769114015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','ricardocaliari','ricaliari@gmail.com','Ricardo Oliveira','Landsberger Strasse 456','Munich','','GERMANY','81241','4915129416844','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-15 17:54:55',0,NULL,3,1,2,1,NULL,'ricardocaliari'),(16544,724438086001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','vicenza67','yosemite@virgilio.it','LOVATO LUCIANO','VIA MARANI 44','(VI)','VICENZA','ITALY','36100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 17:57:21',0,NULL,3,1,3,1,'RA184568887CN ','vicenza67\rLight Stand   $15 '),(16545,782309016017,270777060056,'Studio Continuous Light Kit 23\' SoftBox 4 output 45w x8',1,'AKT039',183,'photographyacc','shabelski77','delian@hot.ee','Anton Sabelski','Heki tee 4-57','Haabneeme alevik, Viimsi vald','Harjumaa','ESTONIA','74001','+37256281095','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-15 19:16:51',0,NULL,3,1,5,1,'CP235627502CN ','shabelski77\r欧标 220v'),(16546,766586822002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','va_logutenko','va.logutenko@gmail.com','Vladimir Logutenko','Engelsa, 6-A, 58','Bryansk','RU','RUSSIAN FEDERATION','241022','79103300784','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-15 18:44:21',0,NULL,3,1,3,1,'RA184568958CN ','va_logutenko'),(16547,724503475001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','tomasbrannan','tomas.alund@gmail.com','Tomas Alund','Brannavagen 17','Harnosand','västernorrland','SWEDEN','87160','0702934399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 20:13:04',0,NULL,3,1,2,1,NULL,'tomasbrannan'),(16548,852858590015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','alanp2t','alan.piachaud@talktalk.net','Alan Piachaud','184 Tufnell Park Road','London','London','UNITED KINGDOM','N70EE','02072728573','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-15 20:23:30',0,NULL,3,1,2,1,NULL,'alanp2t'),(16549,766649492002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','squabbler','shapovaltanya@gmail.com','Tatiana Shapoval','Sokol 1/7/20','Dniepropetrovsk','UA','UKRAINE','49126','+380632508697','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-15 20:50:13',0,NULL,3,1,3,1,'RA184568944CN ','squabbler'),(16550,766670511002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','dubrovnik4','dubrovnik4@hotmail.com','Dubravko Garbin','Moluntska 2','Dubrovnik','','CROATIA','20000','+385-91-1436634','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 21:55:49',0,NULL,3,1,2,1,NULL,'dubrovnik4'),(16551,724556774001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','wielitton','nilllitton@gmail.com','Julia Tarasenko','Novotushinskiy proezd, 10/1, kv.68','Moscow','Moskovskaya oblast\'','RUSSIAN FEDERATION','125464','+7 915 300 80 78','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 22:40:52',0,NULL,3,1,17,0,NULL,'wielitton'),(16552,726307822018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','cordia76','kim@kimandshane.com','Shane Nord','25 Halstead Turn','Wellard','Western Australia','AUSTRALIA','6170','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-15 23:08:43',0,NULL,3,1,3,1,'RA184566095CN ','cordia76'),(16553,766700059002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','wielitton','nilllitton@gmail.com','Julia Tarasenko','Novotushinskiy proezd, 10/1, kv.68','Moscow','Moskovskaya oblast\'','RUSSIAN FEDERATION','125464','+7 915 300 80 78','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-15 23:30:14',0,NULL,3,1,5,1,'CP235627516CN ','wielitton\r灯架  2m    2\r柔光箱 50-70cm 单灯头 欧标   2\r灯架包      1\r反光板 80cm 2合1   1'),(16554,782427754017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','mq5514','ltran88@spoofee.com','Quach','5514 W Lunt Ave','Chicago','IL','UNITED STATES','60646-1514','(773) 627-3816','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-16 00:29:03',0,NULL,3,1,1,1,NULL,'mq5514'),(16555,724585741001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','technofou','jolosephjo@hotmail.com','Jay Machalani','2950 Boul. de Mascouche<br>Apt.5','Mascouche','QC','CANADA','J7K3E4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 00:44:50',0,NULL,3,1,3,1,'RA184568900CN ','technofou'),(16557,724630966001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','rafikh','drhodeib@gmail.com','rafik hodeib','7344 Vine Crest Place','Rancho Cucamonga','CA','UNITED STATES','91739','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 03:58:59',0,NULL,3,1,1,1,NULL,'rafikh'),(16558,853028309015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','comsubin87','marcoangiusnet@libero.it','Marco Angius','Via Regina Elena 19','Quartu sant\' Elena','CA','ITALY','09045','3403883161','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-16 04:38:36',0,NULL,3,0,3,1,'RA184566104CN ','comsubin87\r Light Stand   $15'),(16559,853031006015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','sergeymybeemoney','mybeemoney@yandex.ru','Sergey Kozhevnikov','Beryozoviy proezd, 2 - 26','Kostroma','Kostromskaya oblast','RUSSIAN FEDERATION','156011','+7-905-150-2864','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-16 04:52:57',0,NULL,3,1,3,1,'RA184566055CN ','sergeymybeemoney'),(16560,726673431018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','kiarahs_mum','lizzi3@optusnet.com.au','Elizabeth Smith','2/85 Synnot Street','Werribee','Victoria','AUSTRALIA','3030','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 04:56:11',0,NULL,3,1,2,1,NULL,'kiarahs_mum\r澳标'),(16561,724646822001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','swen2521','chart08@hotmail.com','chartwattana sornchumsieng','69/90 moo 5 soi 3/12 Rajchapreuk Road, Mahaswat, Bangkruay','Bangkruay','Nontaburi','THAILAND','11130','66818228411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 05:33:01',0,NULL,3,1,17,0,NULL,'swen2521'),(16562,766787604002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 06:05:40',0,NULL,3,0,3,1,'RA184566047CN ','bipede38\r2XL    \r新地址\rMarcos De Laurentis \rAV. AGUIA DE HAIA, 873 \rSÃO PAULO - SÃO PAULO 03694000 \rBrazil \rTEL 55-11-20471770 '),(16563,782513883017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.5,'photographyacc','johnnybravof5','birdacelionel@yahoo.com','Birdacel Ionel','34/135 Bage street','Nundah','Queensland','AUSTRALIA','4012','0402587161','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 06:57:05',0,NULL,3,1,2,1,NULL,'johnnybravof5'),(16564,782520820017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.59,'photographyacc','jozefbinder','bindo01@gmail.com','Jozef Binder','Pribišova 43','Bratislava','','SLOVAK REPUBLIC','84105','+421 902 217 797','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-16 07:33:49',0,NULL,3,1,2,1,NULL,'jozefbinder'),(16565,724670121001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','countrygirlnz08','countrygirlnz@gmail.com','Janelle Stuart-Menzies','411B Ohauiti Rd<br>RD3','Tauranga','Bay of Plenty','NEW ZEALAND','3173','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 07:42:29',0,NULL,3,1,17,0,NULL,'countrygirlnz08'),(16566,766805795002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','countrygirlnz08','countrygirlnz@gmail.com','Janelle Stuart-Menzies','411B Ohauiti Rd<br>RD3','Tauranga','Bay of Plenty','NEW ZEALAND','3173','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 07:42:30',0,NULL,3,1,3,1,'RA184566020CN ','countrygirlnz08'),(16567,766805905002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','countrygirlnz08','countrygirlnz@gmail.com','Janelle Stuart-Menzies','411B Ohauiti Rd<br>RD3','Tauranga','Bay of Plenty','NEW ZEALAND','3173','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 07:42:30',0,NULL,3,1,17,0,NULL,'countrygirlnz08'),(16568,766805953002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','countrygirlnz08','countrygirlnz@gmail.com','Janelle Stuart-Menzies','411B Ohauiti Rd<br>RD3','Tauranga','Bay of Plenty','NEW ZEALAND','3173','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 07:42:29',0,NULL,3,1,17,0,NULL,'countrygirlnz08'),(16569,766806045002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',1,'AC1203',5.6,'hermeshine','countrygirlnz08','countrygirlnz@gmail.com','Janelle Stuart-Menzies','411B Ohauiti Rd<br>RD3','Tauranga','Bay of Plenty','NEW ZEALAND','3173','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 07:42:28',0,NULL,3,1,6,1,'EE495359477CN','countrygirlnz08\rnikon 反接环  52mm    1\r反光板 100*150 40*60 5合1   1\r反光板支架    1\r灯架  2m    1\r三脚架  伟峰 WF-6662A    1\r镜头筒 大号     1'),(16570,835366366016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lvolpato50','lvolpato50@vodafone.it','Lorenzo Volpato','via XXV Aprile, n.81','San Biagio di Callalta','TV','ITALY','31048','3494086783','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 08:01:03',0,NULL,3,1,2,1,NULL,'lvolpato50'),(16571,782529541017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','awkwardt','michael.voros@westnet.com.au','Michael Voros','Freehills, QV1 Building<br>250 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','61409437497','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 08:12:23',0,NULL,3,1,2,1,NULL,'awkwardt'),(16572,726711765018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','gilbertnapoles','gilbertnapoles@yahoo.com','gilbert napoles','4/3 Victoria Avenue','Penshurst','New South Wales','AUSTRALIA','2222','0437127296','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 08:15:22',0,NULL,3,1,3,1,'RA184566033CN ','gilbertnapoles'),(16573,766818605002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','r_engineer','hrytsa@gmail.com','Roman Hrytsa','Washington street 5/27','Lviv','Lvivska oblast','UKRAINE','79032','+30636009696','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 08:40:26',0,NULL,3,1,2,1,NULL,'r_engineer'),(16574,782548268017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','qsneli','iisalmi@gmail.com','Georgi Dolishvili','Haukiniemenkatu 5C 20','Iisalmi','','FINLAND','74100','358468917490','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-16 09:28:26',0,NULL,3,1,2,1,NULL,'qsneli'),(16575,726687785018,280687532335,'Studio Light 1000W Continuous Lighting Complete Kit  ',1,'AKT005',182,'photographyacc','shiva_trade','re26575@bigpond.net.au','Patrick Shiva','43-45 Kylta Rd, Gate 2<br>West Heidelberg','Melbourne','Victoria','AUSTRALIA','3081','0394594466','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-09-16 09:54:03',0,NULL,3,1,4,1,'YW865546405CN ','shiva_trade\r澳标'),(16576,724699902001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','swen2521','chart08@hotmail.com','chartwattana sornchumsieng','69/90 moo 5 soi 3/12 Rajchapreuk Road, Mahaswat, Bangkruay','Bangkruay','Nontaburi','THAILAND','11130','66818228411','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 09:58:13',0,NULL,3,1,2,1,NULL,'swen2521\r58-58mm 双阳环    1\r52-58mm 双阳环    1'),(16577,766838327002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.89,'hermeshine','inbornuido','geran.andres@gmail.com','Gerardo Andres','21 Tingha Close<br>Hinchinbrook','Liverpool','New South Wales','AUSTRALIA','2168','0296080803','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-09-16 10:07:50',0,NULL,3,1,2,1,NULL,'inbornuido\r澳标'),(16578,853117050015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','fuuzi-sk','ebay.de@fuuzi.com','Igor Kolenic','Znievska 42','Bratislava','','SLOVAK REPUBLIC','85106','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 10:23:27',0,NULL,3,1,2,1,NULL,'fuuzi-sk'),(16579,766843390002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','deonk6905','deonk@spargs.co.za','Deon Kretschmer','10 Edge Road<br>Beacon Bay','East London','Eastern Cape','SOUTH AFRICA','5205','0825526752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 10:28:23',0,NULL,3,1,2,1,NULL,'deonk6905'),(16580,853139027015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',2,'AKT015',92,'hutongstore','flovett14','fhaden@hotmail.com','Fran Lovett','Shebbear College<br>Shebbear','Beaworthy','Devon','UNITED KINGDOM','Ex21 5HJ','01409282000','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-16 11:36:26',0,NULL,3,1,12,1,'5554309876\r ','flovett14\r背景架 （ 白+黑）  x  2\r尽量体积小一点， 给我实重和泡重\r抛重     7.056    实重     6.328'),(16581,853141671015,250599983762,'New Neoprene Reversible Cover for Nikon D200 D300 D700',1,'AC1303',5.5,'hutongstore','sternogiro','albertouyarra@gmail.com','alberto uyarra vicente','oviedo 9 - 5 izq.','burgos','Castilla y León','SPAIN','09002','947269241','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 11:38:38',0,NULL,3,1,2,1,NULL,'sternogiro'),(16582,724724983001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','kaschmek','lisa@lisalove.se','LisaLove Bäckman','Fogdevreten 4 lgh 1214','Solna','Stockholm','SWEDEN','17165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:40:24',0,NULL,3,1,17,0,NULL,'kaschmek'),(16583,766861949002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','kaschmek','lisa@lisalove.se','LisaLove Bäckman','Fogdevreten 4 lgh 1214','Solna','Stockholm','SWEDEN','17165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:40:25',0,NULL,3,1,4,1,'YW865546792CN ','kaschmek\rc里的东西， 再加上：\r反光板 110cm 5合1    1\r大号灰卡    1  \r（闪光灯的棚需要放第二块柔光布，放大的）\r燕文一票两件\rlighting kit  $26'),(16584,724724984001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','kaschmek','lisa@lisalove.se','LisaLove Bäckman','Fogdevreten 4 lgh 1214','Solna','Stockholm','SWEDEN','17165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 11:40:25',0,NULL,3,1,17,0,NULL,'kaschmek\r'),(16585,766867251002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3302',23.96,'hermeshine','eyesonyouphoto2011','eyesonyouphoto@optonline.net','Deborah Jennings','632 Warburton Ave<br>Hudson View House Apt 1F','Yonkers','NY','UNITED STATES','10701-1633','(914) 330-1171','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 12:10:18',0,NULL,3,1,1,1,NULL,'eyesonyouphoto2011'),(16586,726774775018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','mikeyv1984','mikeyv1984@gmail.com','Michael Valli','Billing Bureau, Level 5 South Tower<br>459 Collins Street','Melbourne','Victoria','AUSTRALIA','3000','0420532525','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 12:21:23',0,NULL,3,1,3,1,'RA184566118CN ','mikeyv1984'),(16587,766813465002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 13:04:05',0,NULL,3,1,17,0,NULL,'zetra450'),(16588,852664784015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',63.49,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 13:06:18',0,NULL,3,1,17,0,NULL,'zetra450'),(16589,724755586001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',2,'AB3311',99.98,'hermeshine','pierbettoni','pierangelo.bettoni@gmail.com','Cavalli Strumenti Musicali - Pie','via Artigiani, 1','Castrezzato','Brescia','ITALY','25030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 13:30:23',0,NULL,3,1,3,1,' RA184560906CN\r','pierbettoni\rbattery pack  $18\r看够不够'),(16590,853192725015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','spencer19660','spencertarrant@live.co.uk','spencer tarrant','16 augusta park<br>victoria','ebbw vale','Blaenau Gwent','UNITED KINGDOM','np238dn','01495306190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 13:55:19',0,NULL,3,1,2,1,NULL,'spencer19660'),(16591,718669755001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','mdfpxm','xyz704-ebay@yahoo.it','Ivan Pedretti','via Pietro Leo 7','cagliari','CA','ITALY','09129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 14:09:18',0,NULL,3,1,2,1,NULL,'mdfpxm'),(16592,766911265002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','jeffr4593','jeff1x1@hotmail.com','jeff roots','18 glen ayre avenue','horsley','New South Wales','AUSTRALIA','2530','0242612423','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 14:24:15',0,NULL,3,1,2,1,NULL,'jeffr4593'),(16593,726821243018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',4,'AD1137',119.96,'photographyacc','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-16 14:40:54',0,NULL,3,0,3,1,'RA184566237CN\r ','wikran\r改定单了，\r换成：\r\rnikon 原厂背心（75周年）  xl    x   2\r2件 （ 看看还够不够2件）'),(16594,782647650017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',4,'AE3301',59.2,'photographyacc','meola227','mmeola@optusnet.com.au','michael meola','7henson','brighton le sands','New South Wales','AUSTRALIA','2216','0295993666','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 14:54:50',0,NULL,3,1,3,1,'RA184566183CN ','meola227'),(16595,835515781016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','boo.boris303','boris303@gmail.com','László Marton','Széchenyi krt. 29.','Kecskemét','','HUNGARY','6000','36302944793','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 15:18:24',0,NULL,3,1,3,1,'RA184566170CN ','boo.boris303'),(16596,853232995015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','phangazone','phanga@msn.com','Reginaldo Sousa','Rua de Nachingweia Nº487','Maputo','Cidade de Maputo','MOZAMBIQUE','1101','+258 82 391 6810','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-16 15:33:05',0,NULL,3,1,17,0,NULL,'phangazone'),(16597,766940196002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','kenz-o','kenz-o@neuf.fr','LUDOVIC MARCATO','67 rue de l\'ouest apt N 2, 1er Etage','PARIS','Île-de-France','FRANCE','75014','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 15:47:15',0,NULL,3,1,3,1,'RA184566197CN ','kenz-o'),(16598,766951863002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','zxman74','wyattwagner@aol.com','Wyatt Wagner','6921 E 7th St','Tulsa','OK','UNITED STATES','74112','(918) 630-5851','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 16:26:23',0,NULL,3,1,1,1,NULL,'zxman74'),(16599,766963973002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1185',16.5,'hermeshine','terri5035','tlredder@yahoo.com','Terri Redder','15008 Lakeshore Dr','Grand Haven','MI','UNITED STATES','49417-8638','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-16 16:50:47',0,NULL,3,0,1,1,NULL,'terri5035\rNikon 帽子    1 （已入库）'),(16600,853284600015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','crdmhl','michael.cereda@gmail.com','Michael Cereda','Via A. De Gasperi 13/c','Trezzo sull\'adda','MI','ITALY','20056','0290939812','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 17:18:26',0,NULL,3,1,2,1,NULL,'crdmhl'),(16601,853321045015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','pixelart2011','ika11@mail.ru','Irina Vasilieva','Krenholmi<br>7-36','Narva','Ida-Virumaa','ESTONIA','20304','+37255548470','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 18:31:56',0,NULL,3,1,5,1,'CP238031042CN ','pixelart2011'),(16602,767011057002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','hawkdsgn','hawk@catalogdesign.com','Stephen Hawk','605 Hickory','Sugar Grove','IL','UNITED STATES','60554-9314','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 18:40:59',0,NULL,3,1,1,1,NULL,'hawkdsgn'),(16603,835617090016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','mikeparsons1974','mcpuk1@btinternet.com','Mike Parsons - Capture Moments Photography','No 5 Green Lawns<br>14 Bay View Road','Colwyn Bay','Conwy','UNITED KINGDOM','LL298DW','01492531032','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 18:41:19',0,NULL,3,1,2,1,NULL,'mikeparsons1974\r是和我们套装里放的那个包一样大，材料厚的那个。\r不知道是哪个的话给我电话'),(16604,782753758017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',5,'photographyacc','coinman-jack','jtade@msn.com','Jack Tade','4842 Royal Greens Pl','San Diego','CA','UNITED STATES','92117-3137','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-16 18:59:27',0,NULL,3,1,1,1,NULL,'coinman-jack'),(16605,767027518002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',10.34,'hermeshine','ntsakris','sturry45@hotmail.com','NIKOLAS TSAKRIS','EPTANISOU 4','ATHENS','ALIMOS','GREECE','17455','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 19:17:13',0,NULL,3,1,17,0,NULL,'ntsakris'),(16606,767027519002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','ntsakris','sturry45@hotmail.com','NIKOLAS TSAKRIS','EPTANISOU 4','ATHENS','ALIMOS','GREECE','17455','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 19:17:14',0,NULL,3,1,4,1,'YW865546840CN ','ntsakris\rNG128 柔光罩      1\r2b柔       2\rlight stand   $20'),(16607,835649227016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','phangazone','phanga@msn.com','Reginaldo Sousa','Rua de Nachingweia Nº487','Maputo','Cidade de Maputo','MOZAMBIQUE','1101','+258 82 391 6810','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 19:43:42',0,NULL,3,1,17,0,NULL,'phangazone'),(16608,853360096015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',49,'hutongstore','phangazone','phanga@msn.com','Reginaldo Sousa','Rua de Nachingweia Nº487','Maputo','Cidade de Maputo','MOZAMBIQUE','1101','+258 82 391 6810','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 19:43:43',0,NULL,3,1,6,1,'EE495359914CN ','phangazone\r背景架2mx2m  + 3个夹子  1\r背景布 1.6x2.1m     2  （黑白）\r背景布 1.6x3m         1 （绿色）\r灯架  2m   2\r柔光箱 50-70cm 单灯头   2\r115w 220v 灯泡   2\r灯架包   1\r申报：48$, 打印一张$48的纸发票放箱子里'),(16609,724914964001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','greece4you','ilias@kapetanakis.org','Ilias Kapetanakis','Aristotelous 98 (Vassani)','Volos','προεπιλογή','GREECE','38333','(+30) 2421035041','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 20:21:42',0,NULL,3,0,3,1,'RA184566254CN ','greece4you\rL  ( 已入库）'),(16610,767059856002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',2,'AA1315',5.98,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 20:32:44',0,NULL,3,1,17,0,NULL,'blinker-182'),(16611,724919887001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 20:32:45',0,NULL,3,1,17,0,NULL,'blinker-182'),(16612,767059859002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5.2,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 20:32:46',0,NULL,3,1,3,1,'RA184566245CN ','blinker-182\r机身盖/镜头后盖  Canon     2\r机身盖/镜头后盖  Nikon      2\rNIKON 镜头盖 52mm         2'),(16613,726986030018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','stantonsmusic','geoffsta@bigpond.net.au','Geoff Stanton','9 Ronald St','Bruthen','Victoria','AUSTRALIA','3885','0351575538','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 21:09:52',0,NULL,3,1,2,1,NULL,'stantonsmusic'),(16614,767073958002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 21:10:44',0,NULL,3,1,17,0,NULL,'ilievbp'),(16615,767074587002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-16 21:12:03',0,NULL,3,1,4,1,'YW865546851CN ','ilievbp\r2mx1.5m 背景板（黑，白）     1  是背景板，一面黑一面有点灰的那个\r2B柔    1\r燕文一票两件\rreflector holder  $20\r'),(16616,853415911015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',11,'hutongstore','matthewmclean','mclean.m@btinternet.com','Matthew Mclean','76C Church Street','Berwick-upon-Tweed','Northumberland','UNITED KINGDOM','TD15 1DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 21:19:33',0,NULL,3,1,17,0,NULL,'matthewmclean'),(16617,853415912015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',2,'AD1402',11,'hutongstore','matthewmclean','mclean.m@btinternet.com','Matthew Mclean','76C Church Street','Berwick-upon-Tweed','Northumberland','UNITED KINGDOM','TD15 1DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 21:19:34',0,NULL,3,1,17,0,NULL,'matthewmclean'),(16618,835699525016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','matthewmclean','mclean.m@btinternet.com','Matthew Mclean','76C Church Street','Berwick-upon-Tweed','Northumberland','UNITED KINGDOM','TD15 1DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-16 21:19:35',0,NULL,3,1,3,1,'RA184566206CN ','matthewmclean\r反光伞    2\r柔光伞    2\r牛津布大包      1\r\r'),(16619,724936873001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',2,'AA3405',19.98,'hermeshine','edmizaca','emzdistributors@hotmail.com','Edson  Zapata','198 Calle Arena<br>Urb. Costa Norte','HATILLO','PR','PUERTO RICO','00659-2773','(787) 342-1612','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-16 21:20:49',0,NULL,3,1,1,1,NULL,'edmizaca'),(16620,724938810001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','bielhate','bielhate@hotmail.com','biel b.c.','mostasaf 18','inca','Baleares','SPAIN','07300','653949433','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-16 21:26:34',0,NULL,3,1,3,1,'RA184566166CN ','bielhate'),(16621,853426305015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','veretine','alexandre.veretine@gmail.com','Alexandre Veretine','Vaijeritie 3c1','Vantaa','','FINLAND','01640','+358407342838','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-16 21:44:22',0,NULL,3,1,4,1,'YW865546862CN ','veretine\r'),(16622,727006377018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','meek00900','mavoon@gmail.com','Devon Wright','17 Parbury Ave','Lake Gardens','Victoria','AUSTRALIA','3355','0428347351','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-16 22:08:47',0,NULL,3,0,2,1,NULL,'meek00900\r1.6x2.1  黑色    1'),(16623,853471512015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',61,'hutongstore','arek10050','arek1005@o2.pl','A Kozubek','106a Lansdowne Way','London','London','UNITED KINGDOM','SW8 2EP','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-17 00:10:30',0,NULL,3,0,4,1,'YW865546873CN ','arek10050\r英标\rlighting kit  $20'),(16624,727043294018,280717890656,'Rolling Hard Case with Dividers for Photo Lighting Kit',1,'AD1165',135,'photographyacc','bmibreall67','bmibreall@gmail.com','brandon hall','2657 midway rd','decatur','GA','UNITED STATES','30030-4577','(404) 207-7036','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'bmibreall67'),(16625,8881316221916899,111,'sf18里面的金属片',1,'',0,'hermeshine','kosselillo','kossel@gmail.com','Jose Sancho Alonso','C/ Burriana 36 Puerta 9','Valencia','Valencia','SPAIN','46005','',NULL,NULL,NULL,'2011-09-17 01:11:56',0,NULL,3,0,3,1,'RA184566285CN\r ','我来吧 '),(16626,8881316223085487,111,'摄影背心 夏  L ',1,'AA1217',0,'hermeshine','katelyn_621','baby_karen_2007@yahoo.com','Karen Castaneda','301 Prairie Ridge dr','woodstock','IL','UNITED STATES','60098-4193','(224) 201-0729',NULL,NULL,NULL,'2011-09-17 01:31:25',0,NULL,3,1,1,1,NULL,'检查所有的拉链 \rLK068319469CN '),(16627,725020223001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','trinity_disorder','satanicupsman@yahoo.com','Everardo Valencia','107 Maple Dr<br>Unit 92','orange cove','CA','UNITED STATES','93646-2159','(559) 397-3690','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-17 03:20:42',0,NULL,3,1,1,1,NULL,'trinity_disorder'),(16628,727087607018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','tenchi4u','apocmeow@satx.rr.com','Matthew Moore','2307 Mountain Fall','San Antonio','TX','UNITED STATES','78258','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 04:10:29',0,NULL,3,1,1,1,NULL,'tenchi4u'),(16629,725028473001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','arjeliam','amendez2@verizon.net','Arjelia Mendez','431 W Colorado Blvd<br>Backhouse','Monrovia','CA','UNITED STATES','91016','(626) 483-0518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 04:12:11',0,NULL,3,1,4,1,'YW865546836CN ','YWarjeliam'),(16630,8881316238776997,111,'河北背景架 + 1.6x2.1 白布',1,'AO0010',0,'photographyacc',' mrbenfoster','ben@thailandphotography.net','Benjamin Foster','The Four Seasons Resort at Kuda Huraa<br>North Male Atoll','Kuda Huraa','north male','MALDIVES','','',NULL,NULL,NULL,'2011-09-17 05:52:56',0,NULL,3,0,3,1,'RA184566360CN\r ','录错了，\r正确的单子是：\r反光板支架    1\r2m 灯架    1\r铝合金座 N     1\r110cm 柔光伞    1\r（已入库） \rRA184566311CN\r'),(16631,782937405017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','blachtom','tom@tomblachford.com','Tom Blachford','147 Kerferd Road Albert Park','Melbourne','Victoria','AUSTRALIA','3206','0396963525','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 06:06:37',0,NULL,3,1,2,1,NULL,'blachtom'),(16632,727106259018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','mkarchitect','mki_architect88@hotmail.com','MUN KIEN PHANG','60, DRY ST','INVERMAY','Tasmania','AUSTRALIA','7248','0413976552','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 06:10:45',0,NULL,3,1,2,1,NULL,'mkarchitect'),(16633,782939249017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','jolandagraaf','jgraaf@zonnet.nl','Jolanda Graaf','Dr. Siebingasingel 19','Opeinde','','NETHERLANDS','9218 PT','+31 651446619','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 06:17:31',0,NULL,3,1,2,1,NULL,'jolandagraaf'),(16634,782939318017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','krusty5210','russell.leaver@bigpond.com','russell leaver','2a mosher way','karratha','Western Australia','AUSTRALIA','6714','0417978301','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 06:18:11',0,NULL,3,1,2,1,NULL,'krusty5210'),(16635,767214550002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','bid-inyourface','empireality@gmail.com','Kangchuen Loh','40 Hatherley Parade','Perth','Western Australia','AUSTRALIA','6150','0403114860','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:07:06',0,NULL,3,1,2,1,NULL,'bid-inyourface'),(16636,853586265015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','coaltester1','ian@ian997.wanadoo.co.uk','IAN ARCHER','108 WILMOT ROAD','SWADLINCOTE','Derbyshire','UNITED KINGDOM','DE119BJ','01283551614','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 08:20:30',0,NULL,3,1,2,1,NULL,'coaltester1'),(16637,727138172018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','acidmati','acid25@o2.pl','mateusz jurek','2/29-31 simpson street<br>bondi beach','sydney','New South Wales','AUSTRALIA','2026','0424818994','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 08:39:39',0,NULL,3,1,3,1,'RA184566651CN ','acidmati'),(16638,725076558001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',2,'AO0018',132,'hermeshine','nasru_123','nasrullaharoon@gmail.com','Nasrulla Haroon','G. Breman, 1st Floor<br>Alikilegefaanu Magu','Male','','MALDIVES','20129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:46:34',0,NULL,3,1,17,0,NULL,'nasru_123'),(16639,767221381002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','nasru_123','nasrullaharoon@gmail.com','Nasrulla Haroon','G. Breman, 1st Floor<br>Alikilegefaanu Magu','Male','','MALDIVES','20129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:46:34',0,NULL,3,1,17,0,NULL,'nasru_123'),(16640,725075847001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','nasru_123','nasrullaharoon@gmail.com','Nasrulla Haroon','G. Breman, 1st Floor<br>Alikilegefaanu Magu','Male','','MALDIVES','20129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:46:35',0,NULL,3,1,17,0,NULL,'nasru_123'),(16641,767221549002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','nasru_123','nasrullaharoon@gmail.com','Nasrulla Haroon','G. Breman, 1st Floor<br>Alikilegefaanu Magu','Male','','MALDIVES','20129','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-17 08:46:36',0,NULL,3,1,17,0,NULL,'nasru_123'),(16642,568003905003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','nasru_123','nasrullaharoon@gmail.com','Nasrulla Haroon','G. Breman, 1st Floor<br>Alikilegefaanu Magu','Male','','MALDIVES','20129','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:46:36',0,NULL,3,1,12,1,'5554309865\r ','nasru_123\r手动升降背景架          1\r2云柔                            1\r倒影板                           1\r斜臂                               1\r3mx6m 背景布             2（白 ， 黑）\r'),(16643,725081799001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','novelloenzo','enzo.novello@poste.it','Enzo Novello','Via nazionale, 55','San Sosti','Cosenza','ITALY','87010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 08:58:05',0,NULL,3,1,2,1,NULL,'novelloenzo'),(16644,725092850001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 09:41:20',0,NULL,3,0,2,1,NULL,'ilievbp'),(16645,853617554015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.9,'hutongstore','jiantsquidz','jiantsquidz@hotmail.com','Tom Grey','24 Levitt Lane<br>Waterbeach','Cambridge','Cambridgeshire','UNITED KINGDOM','CB25 9AZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-17 09:59:18',0,NULL,3,1,2,1,NULL,'jiantsquidz'),(16646,725104883001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','studiomrak','kemal.becirevic@gmail.com','Kemal Becirevic','Trebinjska 68','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 10:31:11',0,NULL,3,1,2,1,NULL,'studiomrak'),(16647,727172851018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','8mileplains','gweiaus@gmail.com','Gang Wei','c/o: Air Design Pty Ltd<br>45 Nestor Drive','Meadowbrook','Queensland','AUSTRALIA','4131','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 10:49:40',0,NULL,3,1,3,1,'RA184566648CN ','8mileplains'),(16648,767258463002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','selamiozmen52','ozmenselami@msn.com','SELAMi OZMEN','INKILAP MH.ALEMDAG CD.BOLUKBASI IS MERK<br>NO:139/29 UMRANIYE','ISTANBUL','','TURKEY','34768','00902166300421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 11:02:02',0,NULL,3,1,2,1,NULL,'selamiozmen52'),(16649,725125230001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','stratomaster','reidlowe@gmail.com','Reid Lowery','16625 Redmond Way<br>Ste M PMB 246','Redmond','WA','UNITED STATES','98052-4499','(425) 503-3394','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-17 11:43:57',0,NULL,3,1,1,1,NULL,'stratomaster'),(16650,783031632017,270753944377,'New Lambency Flash Diffuser for Nikon SB600 SB800 P1',1,'AB3306',21.5,'photographyacc','markd4365','docdoran_64@hotmail.com','LCPL M B DORAN','R8-LG-030<br>Russell Offices','Canberra','Australian Capital Territory','AUSTRALIA','2600','0421811180','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-17 12:12:45',0,NULL,3,1,17,0,NULL,'markd4365'),(16651,727200578018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','daize337','mos@puzzling.org','Mauricio V Ortiz','45 Albert St','Petersham','New South Wales','AUSTRALIA','2049','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 12:23:04',0,NULL,3,1,3,1,'RA184566991CN ','daize337'),(16652,727204280018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',6.2,'photographyacc','albaregia2009','alba@homelan.lg.ua','Andrey Iatsechko','Nayki st. 13, ap 117','Severodonetsk','Luganskii reg Ukraine','UKRAINE','93400','+380501016962','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 12:33:32',0,NULL,3,1,2,1,NULL,'albaregia2009'),(16653,783040138017,270751505051,'YongNuo Flash Battery Pack for Nikon SB800 SD-8A /8AA',1,'AB3309',52,'photographyacc','markd4365','docdoran_64@hotmail.com','LCPL M B DORAN','R8-LG-030<br>Russell Offices','Canberra','Australian Capital Territory','AUSTRALIA','2600','0421811180','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 12:34:14',0,NULL,3,1,3,1,'RA184566308CN\r ','markd4365\r爵影碗罩P1        1\r永诺 SF18- NIKON SB800      1'),(16654,727207449018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','antoonph66','antoonh66@optusnet.com.au','Antoon Hoekstra','2/5-7 Fleming Rd','HERSTON','Queensland','AUSTRALIA','4006','0413049815','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 12:43:31',0,NULL,3,1,2,1,NULL,'antoonph66'),(16655,727210913018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','miss.cinnabar','rebeka.koska@bigpond.com','Rebeka Koska c/o Geon','181 Forster Road<br>Mount Waverley','Melbourne','Victoria','AUSTRALIA','3149','0385459081','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-17 12:54:09',0,NULL,3,1,4,1,'YW865546696CN ','miss.cinnabar'),(16656,853618916015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','cristinacpcosta11','cristinacpcosta@hotmail.com','cristina costa','lugar da taberna seca nº16 1ºdt','sardoal','sardoal','PORTUGAL','2230-230','241855583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-17 13:00:44',0,NULL,3,1,2,1,NULL,'cristinacpcosta11'),(16657,836023848016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','chencz2010','goomba@email.cz','Jan Lysý','Sokolovská 1530','Sokolov','výchozí','CZECH REPUBLIC','356 05','721290911','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-17 15:20:18',0,NULL,3,1,3,1,'RA184566299CN\r ','chencz2010\r欧标'),(16658,727302841018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','benbrad007','benbaliban@gmail.com','Ben Baliban','5 Brockwell Parkway Landsdale','Perth','Western Australia','AUSTRALIA','6065','0893026919','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-17 16:52:19',0,NULL,3,1,4,1,'YW865546700CN ','benbrad007'),(16659,727348210018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','frojas','ab4qc@yahoo.com','Felipe Rojas','2020 Woods River Ln','Duluth','GA','UNITED STATES','30097-7963','(678) 226-1662','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 18:27:20',0,NULL,3,1,1,1,NULL,'frojas'),(16660,725293592001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','time12slowfunk','miquelbox@yahoo.es','Miguel Navalpotro Garcia','Pou, 30-32, 1º-3ª','Barcelona','Cataluña','SPAIN','08016','655759839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 19:02:36',0,NULL,3,1,3,1,'RA184566339CN\r ','time12slowfunk'),(16661,727371202018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','apaq007','apaq007@hotmail.com','andre paquette','180 de Niagara','Repentigny','QC','CANADA','J5Y 3L6','(450) 585-0072','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-17 19:17:28',0,NULL,3,1,3,1,'RA184566342CN\r ','apaq007'),(16662,767503149002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','nickjaimesnicolas','nickjaimes@gmail.com','nicolas santiago','Mihara 2-20-19,206','Asaka City','Saitama','JAPAN','351-0025','080-3251-9769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 21:37:11',0,NULL,3,1,17,0,NULL,'nickjaimesnicolas'),(16663,836222991016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-17 21:38:04',0,NULL,3,0,2,1,NULL,'vojpal\r天涯渐变灰 (ND4)  1\r62mm 接口环    1\r广角托架     1\r已入库'),(16664,767504788002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','nickjaimesnicolas','nickjaimes@gmail.com','nicolas santiago','Mihara 2-20-19,206','Asaka City','Saitama','JAPAN','351-0025','080-3251-9769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 21:41:16',0,NULL,3,1,3,1,'RA184566271CN\r ','nickjaimesnicolas\r2b柔    1\r灯架包厚     1\r'),(16665,767510420002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','siwelb','l2lewis@ryerson.ca','Stan Sher','233 Sassafras Circle','Thornhill','ON','CANADA','L4J 8M6','(647) 220-8921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-17 22:05:24',0,NULL,3,1,2,1,NULL,'siwelb'),(16666,725226938001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','nikondslr161168','rtormoz@yahoo.com','pavil tormozov','2191 w ridgewood dr','wasilla','AK','UNITED STATES','99654-5314','(907) 982-6276','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-17 22:47:36',0,NULL,3,1,4,1,'YW865546711CN ','nikondslr161168'),(16667,767539709002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.89,'hermeshine','stiaanras1','stiaanras@yahoo.com','christiaan ras','1 Outlook court','Kallangur','Queensland','AUSTRALIA','4503','0732044993','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-09-17 23:45:29',0,NULL,3,1,2,1,NULL,'stiaanras1\r澳标'),(16668,767557210002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gramo1125','admin@digital-diy.com','Graham Mitchell','103 Mount Hall Road','Raymond Terrace','New South Wales','AUSTRALIA','2324','0249876998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 01:00:06',0,NULL,3,1,2,1,NULL,'gramo1125'),(16669,725407974001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','rdigz','andresgrdi@hotmail.com','andres gomez','4233 Mountain View Dr','ANCHORAGE','AK','UNITED STATES','99508-1547','','NoPaymentFailure','CheckoutComplete','Other','2011-09-18 01:09:14',0,NULL,3,0,1,1,NULL,'rdigz\rL  （已入库）'),(16670,767560323002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','mapleodessa','navigator89@sympatico.ca','oleg kutov','1101-555 Sheppard ave.west','Toronto','ON','CANADA','m3h2r7','(416) 633-2448','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 01:11:59',0,NULL,3,1,2,1,NULL,'mapleodessa'),(16671,767586329002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','marvinfs11','marvinfs@gmail.com','Vladimir Nikiforov','48g Moskovskaya str.','Ekaterinburg','','RUSSIAN FEDERATION','620102','+79122475390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 03:11:57',0,NULL,3,1,17,0,NULL,'marvinfs11'),(16672,725434718001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','marvinfs11','marvinfs@gmail.com','Vladimir Nikiforov','48g Moskovskaya str.','Ekaterinburg','','RUSSIAN FEDERATION','620102','+79122475390','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-18 03:11:57',0,NULL,3,1,17,0,NULL,'marvinfs11'),(16673,725434646001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','marvinfs11','marvinfs@gmail.com','Vladimir Nikiforov','48g Moskovskaya str.','Ekaterinburg','','RUSSIAN FEDERATION','620102','+79122475390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 03:11:58',0,NULL,3,1,3,1,'RA184566546CN\r\r ','marvinfs11\r除了c 里面的再发\r天涯方形滤镜系列  CPL    1\r天涯 渐变灰    1\r天涯 渐变橙     1\r天涯 渐变蓝     1\r天涯ND2/ ND4/ ND8    各1\r6片装滤镜袋    1'),(16674,767587773002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','beb3704','beb3704@louisiana.edu','Blake Berard','413 Martin St','Breaux Bridge','LA','UNITED STATES','70517-5017','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 03:14:01',0,NULL,3,1,3,1,'RA184566268CN\r ','beb3704'),(16675,725436400001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','allysonhissashi','allyson.hissashi@gmail.com','Allyson Hissashi Nishimoto e Souza','Rua Herculano de Freitas - 40<br>Gutierrez','Belo Horizonte','Minas Gerais','BRAZIL','30441-039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 03:15:11',0,NULL,3,1,3,1,'RA184566325CN\r ','allysonhissashi'),(16676,767615252002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','wetpsych','leochristianlumbre@yahoo.com','Leo Christian Lumbre','#6 Sapphire Street Pangilinan Compound<br>Tandang Sora','Quezon City','GMA','PHILIPPINES','1100','6324337777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 05:54:43',0,NULL,3,1,3,1,'RA184567008CN ','wetpsych'),(16677,783432514017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','andrey.shak','andrey.shak@gmail.com','Andrey Gudkov','Starobitsevskaya st. 11-406','Moscow','RU','RUSSIAN FEDERATION','117628','+79031990828','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 08:25:39',0,NULL,3,1,2,1,NULL,'andrey.shak'),(16678,725499207001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','mustine','velasco.lopez@gmail.com','Jose Velasco Lopez','Calle Pepe Pintado Numero 4','La Paloma - El Palmar','Murcia','SPAIN','30120','655052415','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:30:51',0,NULL,3,1,2,1,NULL,'mustine'),(16679,727582611018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','pusur2009','heelveru@online.no','Heidi Westum','Elvran Nordre','Elvarli','','NORWAY','7519','0047 74800284','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 08:35:52',0,NULL,3,1,3,1,'RA184566926CN ','pusur2009'),(16680,725429256001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','aumimk','aumimk@internode.on.net','Michael McKenzie','61 Madeline St Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0439839059','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:45:34',0,NULL,3,1,2,1,NULL,'aumimk'),(16681,725506943001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','atias007','tsahiatias@gmail.com','Tsahi Atias','Zabutinski 50/1103','Givaat Shmuel','','ISRAEL','54010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 08:54:27',0,NULL,3,1,3,1,'RA184566930CN ','atias007'),(16682,725516502001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','alyonaarch','damo4ka.c@gmail.com','Alyona Bulygina','oljicha<br>7/42','Kiev','Kiev','UKRAINE','04060','+380939413109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 09:20:07',0,NULL,3,1,2,1,NULL,'alyonaarch'),(16683,767669000002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5.2,'hermeshine','chavander','vandecappelle@gmail.com','Gerard Vandecappelle','16 Rue des Swagnes','NAMUR (Wepion)','','BELGIUM','5100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 09:24:28',0,NULL,3,1,17,0,'、、 ','chavander'),(16684,767668758002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',4,'AA1301',10.4,'hermeshine','chavander','vandecappelle@gmail.com','Gerard Vandecappelle','16 Rue des Swagnes','NAMUR (Wepion)','','BELGIUM','5100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 09:24:28',0,NULL,3,1,3,1,'RA184566400CN\r','chavander\rCANON 镜头盖  67mm     2\rCANON 镜头盖  58mm     4\rlens cap  $8'),(16685,854175018015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','kav_ish','drk-force@hotmail.com','Dinashesing Rambaree','Royal Road','Petit Raffray','Mru','MAURITIUS','230','7087367','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 10:09:44',0,NULL,5,0,18,0,NULL,'kav_ish'),(16686,727646979018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',55,'photographyacc','toastiejojo','toastiejo@hotmail.com','Josephine Ellis','2 Camden Court<br>Capalaba','Brisbane','Queensland','AUSTRALIA','4157','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-18 11:25:30',0,NULL,3,1,4,1,'YW865546722CN ','toastiejojo'),(16687,767729535002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','dmorgan807','morgans@worldnet.co.nz','Dave Morgan','170 Lord Rutherford Rd South<br>Brightwater','Nelson','Nelson','NEW ZEALAND','7022','03 5423979','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 11:57:22',0,NULL,3,1,2,1,NULL,'dmorgan807'),(16688,767745787002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','reidun42','reidun.gronstol@gmail.com','Reidun Grønstøl','Bolkesjø','Notodden','Notodden','NORWAY','3680','04735018710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 12:34:58',0,NULL,3,1,2,1,NULL,'reidun42'),(16689,767772390002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','nighthawkalex','alex_bh93@hotmail.fr','Alexandre Ben Hadid','28 Bis Rue Guynemer','Rosny sous bois','Île-de-France','FRANCE','93110','0148543542','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 13:33:47',0,NULL,3,1,2,1,NULL,'nighthawkalex'),(16690,767800224002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','der_smarte_hank','hank@hankma.de','Hank Heise / Autohaus SIEMON','Osnabrücker Straße 301','Ibbenbüren','','GERMANY','49479','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 14:29:08',0,NULL,3,1,2,1,NULL,'der_smarte_hank'),(16691,8881316358192087,111,'2云柔+5个云台',5,'AKT052',0,'hermeshine','caczerny','carlos.czerny@gmail.com','Carlos Victor Czerny','Peru 160 Piso 5to sistemas (int. 4145)','Ciudad autonoma de Buenos Aires','','ARGENTINA','C1067AAD','+5491150193614',NULL,NULL,NULL,'2011-09-18 15:03:12',0,NULL,3,1,5,1,'CP238031008CN ',' 2云柔    x 5\r云台       x 5'),(16692,727780607018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','nikofishhunter','fishhunter888@gmail.com','Nikolay Golubev','Tulenina street.10','Almaty','KZ','KAZAKHSTAN','050007','+77017226113','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 15:50:09',0,NULL,3,1,3,1,'RA184566356CN\r ','nikofishhunter'),(16693,725727122001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','hakber78','hakonbergseth@hotmail.com','Hakon Rasmus Bergseth','Bøgata 25 C','Oslo','','NORWAY','0655','0047 95977117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 16:35:00',0,NULL,3,1,4,1,'YW865546803CN ','hakber78'),(16694,727804176018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','jarvismphoto','jarvismebay@yahoo.com','Jeff Foltice','9682 Boone ct','Zeeland','MI','UNITED STATES','49464-1272','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 16:35:55',0,NULL,3,1,1,1,NULL,'jarvismphoto'),(16695,725768816001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','lenkaren2','lenk222@hotmail.com','Kent Björklind','Mariebergsgatan 9B','Sala','','SWEDEN','73334','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 17:51:04',0,NULL,3,1,3,1,'RA184566532CN\r\r ','lenkaren2'),(16696,854496632015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','sellsstuffonline','media@london.com','Matthew Widgery','74 South End','Bassingbourn','Hertfordshire','UNITED KINGDOM','SG8 5NL','07402225677','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 17:58:22',0,NULL,3,1,2,1,NULL,'sellsstuffonline'),(16697,767973122002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','cuatro_r9oeo','cuatro_r@bellsouth.net','Rafael R Rodriguez','362 Streamview way','Winter Springs','fl','UNITED STATES','32708','(407) 359-0989','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-18 18:27:23',0,NULL,3,1,1,1,NULL,'cuatro_r9oeo'),(16698,854553892015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','vikuleczkaa','krzysztof.piwowarczyk@interia.eu','Krzysztof Piwowarczyk','63 Longmead','Hatfield','Hertfordshire','UNITED KINGDOM','AL10 0AD','7503704454','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-18 18:48:57',0,NULL,3,1,3,1,'RA184566223CN\r ','vikuleczkaa'),(16699,768038882002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','mellogabriel','mellogabriel@yahoo.com.br','Gabriel Mello','Rua Leandro Dupret, 364 Ap. 142<br>Vila Clementino','São Paulo','São Paulo','BRAZIL','04025-011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 19:49:09',0,NULL,3,1,2,1,NULL,'mellogabriel\r欧标'),(16700,783821461017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','rm-09','luis_s_o@hotmail.com','Luis Salazar','2703 E 8th St','Douglas','AZ','UNITED STATES','85607-3574','520 805 1867','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-18 20:06:31',0,NULL,3,1,1,1,NULL,'rm-09'),(16701,768066442002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','maiinatb','maiina_@hotmail.com','Martine Beaudoin','215 Isabelle','Ste-Sophie','QC','CANADA','J5J 2J6','(450) 432-3509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 20:33:14',0,NULL,3,1,2,1,NULL,'maiinatb'),(16702,854644175015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','lawry6666','lawrence.dermody@gmail.com','Lawrence Dermody','Huvudstalundsvagen 8','Solna','','SWEDEN','17163','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 20:31:38',0,NULL,3,1,2,1,NULL,'lawry6666'),(16703,725935708001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','padodaniel1901','padodaniel@libero.it','Daniele Padovan','Via Leonardo Da Vinci  46/B','Rio S. Martino Scorzè','Venezia','ITALY','30037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 21:23:00',0,NULL,3,1,3,1,'RA184566210CN\r ','padodaniel1901\r实重1.693  抛重2.17'),(16704,728038470018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','lordenrique69','senorivero@bigpond.com','HENRY RIVERO','46 MENTMORE AVE<br>ROSEBERY','SYDNEY','New South Wales','AUSTRALIA','2018','0266536123','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-18 21:43:23',0,NULL,3,1,2,1,NULL,'lordenrique69'),(16705,854700335015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','chrigu_88','chrigu_1988@hotmail.com','Christoph Müller','Alpenblickstrasse 37','Zollikofen','','SWITZERLAND','3052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-18 22:05:45',0,NULL,3,1,3,1,'RA184566395CN\r ','chrigu_88\r2块布'),(16706,725954422001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','ribak808','ktsymbalov@yahoo.com','Konstantin Tsymbalov','75 Lilac Dr<br>Apt 6','rochester','NY','UNITED STATES','14620-3275','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-18 22:10:21',0,NULL,3,1,1,1,' ','ribak808'),(16707,725988431001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','pinderking2010','pinderking@yahoo.co.uk','arpinder singh','20 lintlaw close','leicester','Leicestershire','UNITED KINGDOM','le4 7yh','01162668236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-18 23:58:03',0,NULL,3,1,3,1,'RA184566458CN\r ','pinderking2010\r1.359'),(16708,725991278001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','pinderking2010','pinderking@yahoo.co.uk','arpinder singh','20 lintlaw close','leicester','Leicestershire','UNITED KINGDOM','le4 7yh','01162668236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 00:06:06',0,NULL,5,0,18,0,NULL,'pinderking2010\r'),(16709,726013675001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','kristinq4544','kristinquick1021@yahoo.com','Kristin Quick','166 Timber Rd','Morrisdale','PA','UNITED STATES','16858-8730','(814) 345-3835','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-19 01:09:40',0,NULL,3,1,1,1,NULL,'kristinq4544'),(16710,768184843002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','lymychrus','lymych@i.ua','Ruslan Lymych','Str. Ivana Franka 20/8','Komarno','lvivska','UKRAINE','81562','+380974759322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 01:36:57',0,NULL,3,1,2,1,NULL,'lymychrus'),(16711,767793482002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','rojanyoung','trojan_young@yahoo.com','rojan young','blk 204 bishan st 23 #09-435','default','','SINGAPORE','570204','6591991049','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 02:37:56',0,NULL,3,1,3,1,'RA184566577CN ','rojanyoung\r分开发\rRA184566563CN'),(16712,8881316401356267,111,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',37.89,'aliexpress','1004415927','marileneaa@gmail.com','Marilene Aparecida de Souza Barbosa	','Av. Dona Chiquinha de Avelar,587 Bairro Progresso','Sete Lagoas	','Minas Gerais	','BRAZIL','35701098','+55 31 37735090',NULL,NULL,NULL,'2011-09-19 03:02:36',0,NULL,3,1,3,1,'RA184566373CN\r ',NULL),(16713,8881316401932852,111,'云台*2',2,'',0,'aliexpress','1004201309','tanz.fly@libero.it','nicola tanzella	','via nicoli 56 c/o bar nicoli','modena','mo','ITALY','41126','+39 328 2123785',NULL,NULL,NULL,'2011-09-19 03:12:12',0,NULL,5,0,18,0,' ',' '),(16714,726054877001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','themaccasarah','sarahamclay@gmail.com','sarah mclay','4/14 chapel street','st kilda','Victoria','AUSTRALIA','3183','0414670605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 03:31:58',0,NULL,3,1,4,1,'YW865546781CN ','themaccasarah\r澳标'),(16715,728151823018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','pipmoor','elised@ekit.com','Elise De Simoni','7 Moorland Avenue<br>Beverley','Adelaide','South Australia','AUSTRALIA','5009','0883462058','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-19 03:48:10',0,NULL,3,1,2,1,NULL,'pipmoor'),(16716,8881316407018304,111,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',0,'photographyacc','toni7770_4','thaydon777@gmail.com','Tony Haydon','Unit 110 Matilda Drive<br>BIRV  Foley Street','Bongaree','Queensland','AUSTRALIA','4507','',NULL,NULL,NULL,'2011-09-19 04:36:58',0,NULL,5,0,18,0,NULL,''),(16717,8881316407626746,111,'见notes',0,'',0,'photographyacc','toni7770_4','thaydon777@gmail.com','Tony Haydon','Australian Embassy<br>5 Gideon Hashofet St','Herzliya Pituach','','ISRAEL','46668','',NULL,NULL,NULL,'2011-09-19 04:47:06',0,NULL,3,1,3,1,'RA184566603CN\r ','第一票地址不对，重发。\r\r普通热靴盖   2\rmini nikon 红外   1\r眼罩 D300    2\r已入库 '),(16718,726077249001,110717023826,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',228.2,'hermeshine','mikeraj88','mikeraj@streamyx.com','Michael Raj Marks','16 Taman Putra, Kelang Lama','Kulim','Kedah','MALAYSIA','09000','0124315187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 05:18:49',0,NULL,3,1,6,1,'EE495359980CN ','mikeraj88\r英标\r地址应该是一样\rMichael Raj Marks \r16 Taman Putra Kelang Lama \rKulim Kedah 09000 \rMalaysia \rTel: 012-4746703'),(16719,8881316412474190,111,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',0,'aliexpress','1004201309','tanz.fly@libero.it','nicola tanzella	','via nicoli 56 c/o bar nicoli<br>5 Gideon Hashofet St','modena','mo','ITALY','41126','+39 328 2123785',NULL,NULL,NULL,'2011-09-19 06:07:54',0,NULL,3,1,3,1,'RA184566594CN\r ','欧标 '),(16720,726099993001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','laheradehielo','cbhera33@yahoo.ca','Arturo Hernandez','2313 Islington Ave Apt 112','Etobicoke','ON','CANADA','M9W3X1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-19 07:24:50',0,NULL,3,1,3,1,'RA184566515CN\r ','laheradehielo'),(16721,784081169017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',4,'AA1301',10,'photographyacc','siddins61','gabsiddins@hotmail.com','Gavin Siddins','39 Hogan Street','Park Avenue','Queensland','AUSTRALIA','4701','0749277790','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-19 07:41:11',0,NULL,3,1,2,1,NULL,'siddins61'),(16722,768271517002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','$chibli','philschibli@gmail.com','Phillip Schibli','26 Raymond street','Perth','Western Australia','AUSTRALIA','6153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 07:54:36',0,NULL,3,1,17,0,NULL,'$chibli'),(16723,768271621002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pinipinilla','fran_javichu@yahoo.es','Francisco Javier Pulido Vaquero','C/ Julian Camarillo, 29, Edificio D1, 4ª Planta (Interflora)','Madrid','Madrid','SPAIN','28037','646539217','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-19 07:58:59',0,NULL,3,1,3,1,'RA184566529CN\r ','pinipinilla'),(16724,726114066001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','lizlopesi','liz_lopesi@hotmail.com','elizabeth lopesi','110 frances street','south wentworthville','New South Wales','AUSTRALIA','2145','0296130765','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 08:30:51',0,NULL,3,1,3,1,'RA184566585CN ','lizlopesi'),(16725,726123591001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',2,'AA1307',5.2,'hermeshine','theelorax','doyouroo@hotmail.com','thee lorax','Po box 804790','Chicago','IL','UNITED STATES','60680-4109','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-19 09:10:26',0,NULL,3,1,17,0,NULL,'theelorax'),(16726,726123460001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','theelorax','doyouroo@hotmail.com','thee lorax','Po box 804790','Chicago','IL','UNITED STATES','60680-4109','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 09:10:27',0,NULL,3,1,17,0,NULL,'theelorax'),(16727,768288903002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','theelorax','doyouroo@hotmail.com','thee lorax','Po box 804790','Chicago','IL','UNITED STATES','60680-4109','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-19 09:10:27',0,NULL,3,1,1,1,NULL,'theelorax\rNIKON 镜头盖 67mm   2\r绿叶 UV  67mm    1\r橡胶遮光罩 67mm    1'),(16728,728220213018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','ntbirder','mccrie@gmail.com','Niven McCrie','Po Box 41382','Casuarina','Northern Territory','AUSTRALIA','0811','0889451130','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-19 09:22:07',0,NULL,3,1,2,1,NULL,'ntbirder\r澳标'),(16729,726129456001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','$chibli','philschibli@gmail.com','Phillip Schibli','26 Raymond street','Perth','Western Australia','AUSTRALIA','6153','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 09:33:59',0,NULL,3,1,4,1,'YW865546770CN ','$chibli\r45w 5500k 灯泡 220v   2\r桌面灯灯头澳标  2\r灯架 38cm   2'),(16730,726132643001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',32,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 09:47:38',0,NULL,3,1,3,1,'RA184566767CN ','gulbrandtang'),(16731,8881316427629213,111,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',12.21,'aliexpress','1004412833','yeti@na-svyazi.ru','Yuri Tinyukov	','Chernyshevskogo 6-109','Cheboksary','Chuvashia','RUSSIAN FEDERATION	','428038','+7 905 3455777',NULL,NULL,NULL,'2011-09-19 10:20:29',0,NULL,3,1,17,0,NULL,NULL),(16732,8881316427760612,111,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',80,'aliexpress','1004412834','yeti@na-svyazi.ru','Yuri Tinyukov	','Chernyshevskogo 6-109','Cheboksary','Chuvashia','RUSSIAN FEDERATION	','428038','+7 905 3455777',NULL,NULL,NULL,'2011-09-19 10:22:40',0,NULL,3,1,5,1,'CP238030815CN ','2云柔 * 2\r85cm反光伞  * 2'),(16733,837224849016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','david.j.mancey','david_mancey@yahoo.co.uk','David Mancey','5 Cocokhall Close<br>Litlington','Royston','Hertfordshire','UNITED KINGDOM','SG80RB','01763852863','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-19 11:41:42',0,NULL,3,0,17,0,' ','david.j.mancey'),(16734,854966195015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','david.j.mancey','david_mancey@yahoo.co.uk','David Mancey','5 Cocokhall Close<br>Litlington','Royston','Hertfordshire','UNITED KINGDOM','SG80RB','01763852863','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-19 11:47:00',0,NULL,3,1,3,1,'RA184566824CN ','david.j.mancey\r除了c 里面的再发\r天涯方形滤镜  渐变灰   1\r方形滤镜接口环 77mm    1\r方镜广角托架（一槽）   1\r已入库'),(16735,768330712002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',3,'AA1216',41.7,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 11:52:31',0,NULL,3,1,3,1,'RA184560027CN ','happyjaya'),(16736,854973133015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.89,'hutongstore','atuulas','albert.tuulas@gmail.com','Albert Tuulas','Harjannetie 5 B 50','Helsinki','Uusimaa','FINLAND','00710','+358468155555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 12:03:05',0,NULL,3,1,2,1,NULL,'atuulas'),(16737,768335483002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','joaoouriques','joaofso@gmail.com','João Felipe Silva Ouriques','Rua Professor Emílio Araújo Chaves, 255<br>Catolé','Campina Grande','Paraíba','BRAZIL','58411-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 12:08:17',0,NULL,3,1,2,1,NULL,'joaoouriques'),(16738,726177316001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','nixette_nixette','nixette@mail.ru','Nikolay Gernet','ul. Suvorova, d.9, korp.2, kv 8','Arkhangelsk','Arkhangelskaya obl','RUSSIAN FEDERATION','163061','+7 911 593 9342','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 12:31:51',0,NULL,3,1,3,1,'RA184566807CN ','nixette_nixette'),(16739,837245914016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','npmonkko','niko.monkkonen@gmail.com','Niko Mönkkönen','Hevossalmentie 6','Helsinki','','FINLAND','00870','+358407314788','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-19 12:32:08',0,NULL,3,1,3,1,'RA184566722CN\r ','npmonkko'),(16740,768351235002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','srclaudinei','srclaudinei@yahoo.com.br','Claudinei Rodrigues dos Santos','Av:  Souza Lima, 557 - Universitária II','Campo Grande','Mato Grosso do Sul','BRAZIL','79071340','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-19 13:04:16',0,NULL,3,1,5,1,'CP238030991CN ','srclaudinei\r欧标'),(16741,837265477016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','kenton791','kenton79@hotmail.com','Androi Kenton','1313-2869 Battleford Road','Mississauga','ON','CANADA','L5N 2S6','(905) 399-3720','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-19 13:22:52',0,NULL,3,1,5,1,'CP238030974CN ','kenton791\r灯泡是110v 的\r---新地址：\rAndroi Kenton\r2946 Rainwater Drive\rMississauga ON, L5N 6K8\rCanada\r(905) 399-3720'),(16742,726208372001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','yuttabay','yuttab@gmail.com','Alexandr Mironenko','Belorechenskaya 41  2 - 75','Moscow','Moscow','RUSSIAN FEDERATION','109387','89265344085','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:08:20',0,NULL,3,1,3,1,'RA184566753CN\r ','yuttabay'),(16743,568791676003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','deandemos','studio@deandemos.co.za','Dean Demos','19 Ukosi Road','Durban','','SOUTH AFRICA','3610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:25:05',0,NULL,5,0,18,0,NULL,'deandemos'),(16744,768387036002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','paulklo','paulk123@gmail.com','Paul Klõšeiko','Õismäe tee 5-4','Tallinn','Harjumaa','ESTONIA','13514','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 14:44:37',0,NULL,3,1,3,1,'RA184566912CN ','paulklo'),(16745,726227579001,110717023826,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',228.2,'hermeshine','baronushka76','zoar.shteinbach@gmail.com','Zoar Shteinbach','964 Canna Crescent S.W.','Calgary','AB','CANADA','T2W1N9','(403) 650-2089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 15:05:10',0,NULL,3,1,6,1,'EE495359945CN ','baronushka76\r实重1.4  抛重2.1'),(16746,855070600015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','stanketto468','darses@gmail.com','Giovanni Sessa','Via Centenate 35','Varese','VA','ITALY','21100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 15:52:25',0,NULL,3,1,3,1,'RA184566634CN\r ','stanketto468\rgift   $10'),(16747,768446648002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','mpnul','mzfk@bk.ru','Lev Filippov','K. Marksa str. 26/16 - 76','Ulianovsk','UL oblast','RUSSIAN FEDERATION','432071','+79084793344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 17:15:15',0,NULL,3,1,2,1,NULL,'mpnul'),(16748,728396790018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',89.5,'photographyacc','llorco','cllorco@gmail.com','Llorenç Conejo','Gran Vía Corts Catalanes, 697,, 2º1ª<br>Barcelona','Barcelona','Cataluña','SPAIN','08013','607110069','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-19 17:42:08',0,NULL,3,1,4,1,'YW865546766CN ','llorco\r1.6*2.1白色加黑色背景布'),(16749,768471475002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','rainmaxx80','rainmaxx@mail.ru','Roman Maksimov','26 Bakinskih Komissarov street, 155','Lugansk','Luganskaya','UKRAINE','91047','+380974253254','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 18:02:52',0,NULL,3,1,3,1,'RA184566719CN\r ','rainmaxx80'),(16750,728411538018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','shajan49thomas','shajan49@gmail.com','THOMAS THOMAS','1306 Willow Wood Dr','CARROLLTON','TX','UNITED STATES','75010-1304','(972) 492-5654','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-19 18:12:12',0,NULL,3,1,4,1,'YW865546755CN ','shajan49thomas\r放布'),(16751,728427027018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','1billy1963','angelo_grimaldi@hotmail.com','ANGELO GRIMALDI','VIA SATURNO','LENTINI','SR','ITALY','96016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-19 18:36:54',0,NULL,3,1,3,1,'RA184566617CN\r ','1billy1963\r放布'),(16752,768500461002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','giantswan.ff','kratova.alla@yandex.ru','Alla Kratova','Akademika Vargi st. 36 app. 84','Moscow','','RUSSIAN FEDERATION','117133','74953398169','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 18:53:28',0,NULL,3,1,2,1,NULL,'giantswan.ff'),(16753,726364877001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 19:53:45',0,NULL,3,1,3,1,'RA184566625CN\r ','diretordecriacao\r欧标'),(16754,768539991002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','brimstone35tc','brimstone35@hotmail.com','Akgün Önen','174 sok. Ersoy Apartmanı. No: 37 Daire: 7 Basın sitesi<br>Karabağlar','izmir','türkiye','TURKEY','35380','(533) 304-2567','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-19 20:12:01',0,NULL,3,1,3,1,'RA184566736CN\r ','brimstone35tc\r放布'),(16755,726375797001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','landrelektra','leonid0025@yahoo.com','Leonid Laznik','212 Kings Hwy','Brooklyn','Ny','UNITED STATES','11223','(718) 946-0343','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-19 20:14:52',0,NULL,3,1,3,1,'RA184566679CN\r ','landrelektra'),(16756,768572850002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pakgoddes','flestavel@hotmail.com','fernand lestavel','55 rue mozart','beuvry','Nord-Pas-de-Calais','FRANCE','62660','0617247579','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-19 21:20:00',0,NULL,3,0,3,1,'RA184566775CN\r ','pakgoddes\r2XL  已入库'),(16757,728542605018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','sverrir1966','sgisla@visir.is','Sverrir Gislason','Engihjalli 3','Kopavogur','','ICELAND','200','354 690-9995','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-19 22:46:04',0,NULL,3,1,3,1,'RA184566665CN\r ','sverrir1966'),(16758,768613582002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','mortimer1029','clement.lombart@gmail.com','Lombart Clément','35 rue François Raspail','St André les Vergers','Champagne-Ardenne','FRANCE','10120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-19 23:31:25',0,NULL,3,1,3,1,'RA184566798CN\r ','mortimer1029'),(16759,855327960015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','hugobalula','chihironikotin@gmail.com','hugo balula','rua joao azevedo nº 27 r/c dto','costa da caparica','costa da caparica','PORTUGAL','2825-433','(00351) 916003498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-19 23:33:07',0,NULL,3,1,2,1,NULL,'hugobalula'),(16760,784459704017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',49.88,'photographyacc','bellsoot','leigh-ann@photonatural.com.au','Leanne Olson','13 The Avenue Heathcote','Sydney','New South Wales','AUSTRALIA','2233','0295209995','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-19 23:45:50',0,NULL,3,1,3,1,'RA184566838CN\r ','bellsoot\r1.6x2.1m 背景布 * 2 （白、粉）\r110cm 5in1 反光板 * 1\r带水平仪 热靴盖 * 1\r（已入库）'),(16761,784464316017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','glamour_23','luba.g@hotmail.com','John m','6 Ronald Ave','Altona North','Victoria','AUSTRALIA','3025','0439393107','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-19 23:58:00',0,NULL,3,1,2,1,NULL,'glamour_23'),(16762,726164304001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','Rua Sempre Viva 155/304<br>Privavera','Timoteo','Minas Gerais','BRAZIL','35182-446','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-20 00:03:28',0,NULL,3,1,3,1,'RA184566705CN\r ','elizeucine'),(16763,855345755015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',24,'hutongstore','bichandra','sergio@mail.pf','SIMO CHRISTINE','BP51091','PIRAE','TAHITI','FRENCH POLYNESIA','98716','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-20 00:29:33',0,NULL,3,1,3,1,'RA184566696CN\r ','bichandra'),(16764,726462526001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','charles0591charles','bellicpm@optusnet.com.au','Charles Belli','76 KINTERBURY DRIVE','KINGS PARK','Victoria','AUSTRALIA','3021','0393669908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 00:49:57',0,NULL,3,1,2,1,NULL,'charles0591charles'),(16765,855363999015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','u0ajp2','andyjamespower@hotmail.com','andy power','94 Snowberry Crescent','Warrington','Cheshire','UNITED KINGDOM','WA51DW','01925711831','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 01:27:36',0,NULL,3,1,3,1,'RA184566682CN ','u0ajp2'),(16766,8881316482500033,111,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',0,'photographyacc','sillymoocow','burroblando@gmail.com','Benjamin Holgate','Level 36, Australia Square<br>264 George Street','Sydney','New South Wales','AUSTRALIA','2000','',NULL,NULL,NULL,'2011-09-20 01:35:00',0,NULL,3,1,3,1,'RA184566855CN ','上一票少发了1个，补发。 '),(16767,855374890015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','aidymaltby','aidys1@yahoo.co.uk','Adrian Maltby','21 Church Close<br>Great Wilbraham','Cambridge','Cambridgeshire','UNITED KINGDOM','CB21 5JL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 01:58:57',0,NULL,3,1,3,1,'RA184566740CN\r ','aidymaltby'),(16768,728603115018,280683073882,'16\" / 40cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3327',38.99,'photographyacc','kaneo33','kanenaaraat@yahoo.com','kane','14 Gawler st','Seaview Downs','South Australia','AUSTRALIA','5049','0419035412','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 02:33:25',0,NULL,3,1,3,1,'RA184566841CN\r ','kaneo33'),(16769,728604108018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','adrielsantos','adrielsantosblack@gmail.com','adriel santos','RUI BARBOSA - 2657 - CENTRO -','CAMPO GRANDE','MATO GROSSO DO SUL','BRAZIL','79002-361','(067)8453 - 3922','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 02:41:05',0,NULL,3,0,3,1,'RA184566784CN\r ','adrielsantos\rxxxl  已入库'),(16772,726414924001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cancan4141','erolyilmaz4141@gmail.com','erol yılmaz-yaşar pekçevik','sera çiçekevi<br>karabaş mah.leyla atakan cad.no:16 -İzmit','KOCAELİ','KOCAELI','TURKEY','41300','05418204141','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-20 05:17:58',0,NULL,3,0,3,1,'RA184560058CN ','cancan4141\r'),(16770,728620908018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','rob66b','rob66b@hotmail.com','robert brown','unit 208<br>105 Campbell Street Surry Hills','Sydney','New South Wales','AUSTRALIA','2010','0292800173','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 03:53:31',0,NULL,3,1,2,1,NULL,'rob66b\r澳标'),(16771,728622818018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','treehouse30kc','kc@kcsmithphotography.com','KC  Smith','4 Echoview Cir','Lexington','NC','UNITED STATES','27292-5529','(336) 250-1133','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,'RA184566988CN ','treehouse30kc\r结清再发\r不用等结清了，没关系\r'),(16773,768706564002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','infinitywillc','infinitywillc@aol.com','GUILLERMO CADENA','1762 ROCKVILLE DRIVE','BALDWIN','NY','UNITED STATES','11510','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-20 06:20:04',0,NULL,3,1,1,1,NULL,'infinitywillc'),(16774,784562731017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',187,'photographyacc','emmavideopower','emma@videopowerplanet.net','Emma Ocholla','268 Prince','Grafton','New South Wales','AUSTRALIA','2460','0428422913','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-20 07:02:10',0,NULL,3,1,4,1,'YW866011614CN ','emmavideopower'),(16775,726542537001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','lenfrol','lfroelund@live.dk','Lennart Frølund','Strandvangsvej 83','egå','danmark','DENMARK','8250','452 143 7763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 07:22:14',0,NULL,3,1,2,1,NULL,'lenfrol'),(16776,784574599017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',2,'AB3312',43,'photographyacc','krystof-photography','chris@meder.net','Christopher Meder','30 Jardine St<br>Fairy Meadow','Wollongong','New South Wales','AUSTRALIA','2519','0414292952','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 07:55:20',0,NULL,3,1,3,1,'RA184566974CN ','krystof-photography'),(16777,728669934018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','missjanesc','guchilittlepiggy@hotmail.com','Jane Bradshaw','5/20 Canberra Terrace','Caloundra','Queensland','AUSTRALIA','4551','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 08:15:30',0,NULL,3,1,3,1,'RA184566965CN ','missjanesc'),(16778,728676371018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','steve-p1957','theparsonsclan@gmail.com','Steve Parsons','20 Cedarwood Drive','Cherrybrook','New South Wales','AUSTRALIA','2126','0400801708','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 08:40:58',0,NULL,3,1,3,1,'RA184560044CN ','steve-p1957'),(16779,726574246001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','jack.barron','vitomarinelli@libero.it','VITO MARINELLI','Via Marconi, 49','Modugno','Bari','ITALY','70026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 09:45:55',0,NULL,3,1,12,1,'5241800933\r ','jack.barron\r欧标\r实重  7.1 抛重8.35\r'),(16780,726578092001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','severinkaradzhov12','cccp0887@gmail.com','severin karadzhov','61A block, floor 5, apt.511 Studentski grad distr.','Sofia','Bulgaria/Sofia/Sofia','BULGARIA','1700','0883453927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 09:59:07',0,NULL,3,1,2,1,NULL,'severinkaradzhov12'),(16781,726573395001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','denis5108','enterprog@ya.ru','Denis Savin','Kulikova street 14-38','Ivanovo','','RUSSIAN FEDERATION','153032','+7(908)567-5108','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-20 10:03:45',0,NULL,3,1,5,1,'CP238031056CN ','denis5108\r 白+ 黑'),(16782,837760216016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','przemroj','rojek@gmx.co.uk','Przemyslaw Rojek','33 Shekespare Close','Tamworth','Staffordshire','UNITED KINGDOM','B798DJ','07706916005','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 10:32:09',0,NULL,3,1,3,1,'RA184560092CN ','przemroj'),(16783,784616881017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',3,'AE1302',29.4,'photographyacc','misspoppy12','lavache12@yahoo.com','Anna Young','802/221 Sturt Street','Southbank','Victoria','AUSTRALIA','3006','0413592877','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 10:38:32',0,NULL,3,1,17,0,NULL,'misspoppy12\r澳标'),(16784,784614833017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','locpham97','phamloc97@hotmail.com','Loc Pham','10 Merton St','Springvale','Victoria','AUSTRALIA','3171','0385114948','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 10:41:07',0,NULL,3,1,2,1,NULL,'locpham97'),(16785,766026989002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','korsar_64','konstantinas@soklys.lt','Konstantinas Samcenko','Svedes 43<br>Ginkunai','Siauliai','','LITHUANIA','81491','+37069827827','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:42:19',0,NULL,3,1,2,1,NULL,'korsar_64'),(16786,726591184001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','dvid1976','dvid9976@gmail.com','David Andres','C/Colegiata 8, 2º B','Ciempozuelos','Madrid','SPAIN','28350','650934109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:52:49',0,NULL,3,1,17,0,NULL,'dvid1976'),(16787,768764946002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','dvid1976','dvid9976@gmail.com','David Andres','C/Colegiata 8, 2º B','Ciempozuelos','Madrid','SPAIN','28350','650934109','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 10:52:50',0,NULL,3,1,3,1,'RA184560075CN ','dvid1976\r大力夹云台    1\r斜臂      1'),(16788,768771478002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','716glyn','glyn.wilkinson78@o2.co.uk','Darryl Wilkinson','38 Bridge Lane','Frodsham','Cheshire','UNITED KINGDOM','WA67HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 11:15:34',0,NULL,3,1,2,1,NULL,'716glyn'),(16789,728719951018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','arttouch2011','h.boudhil@gmail.com','Hichem BOUDHIL','45 rue du faubourg de saverne','Strasbourg','Alsace','FRANCE','67000','0637067839','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 11:29:09',0,NULL,3,1,4,1,'YW866011625CN ','arttouch2011'),(16790,726602566001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','8898bogo','bogo8898@gmail.com','Branislav Golkovsky','Dolne Otrokovce 168','Dolne Trhoviste','Europe','SLOVAK REPUBLIC','92061','+421905424513','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 11:33:20',0,NULL,3,1,2,1,NULL,'8898bogo'),(16791,768780754002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','stratomaster','reidlowe@gmail.com','Reid Lowery','16625 Redmond Way<br>Ste M PMB 246','Redmond','WA','UNITED STATES','98052-4499','(425) 503-3394','NoPaymentFailure','CheckoutComplete','Other','2011-09-20 11:43:30',0,NULL,3,0,1,1,NULL,'stratomaster\rXXXL  (已入库）'),(16792,728725237018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','dwnrox','slake79@hotmail.com','Sara Lake','PO Box 272','Howard Springs','Northern Territory','AUSTRALIA','0835','0889885468','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 11:45:30',0,NULL,3,1,4,1,'YW866011636CN ','dwnrox'),(16793,726617047001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','olika_mur','olika.mur@gmail.com','Olga Kitaeva','Panferova str., 9 - 6','Moscow','','RUSSIAN FEDERATION','119261','(916) 299-5329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 12:25:01',0,NULL,3,1,2,1,NULL,'olika_mur'),(16794,726620122001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','slimens2011','slimens@yandex.ru','Anna Sviridenko','str.Chervaukova d.2 k.4. kv.103','Minsk','Minskau obl','BELARUS','220002','8029-5429589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 13:17:59',0,NULL,3,1,2,1,NULL,'slimens2011'),(16795,726507024001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',57.35,'hermeshine','lblockst','blockstein@gmail.com','Lior Blockstein','2020 Cherokee Pl. NW<br>Apartment E','Calgary','AB','CANADA','T2L0X3','(403) 926-2005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 14:29:57',0,NULL,3,1,3,1,'RA184560146CN ','lblockst\r45w 110v        2\r单灯头              2\rc型大力夹       2\r（已入库）\r\r'),(16796,855604403015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','shorty_butler-2007','shorty_butler@hotmail.co.uk','Lee Butler','21 School Rd','Silver End','Essex','UNITED KINGDOM','CM8 3RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-20 14:31:35',0,NULL,3,1,2,1,NULL,'shorty_butler-2007'),(16797,728785448018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','fototovar','dima_pastushenko@hotmail.com','Dmitro Pastushenko','Kurchatova, st - 1d, kv - 15','Khmelnitskiy','','UKRAINE','29000','+380972971035','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 14:45:20',0,NULL,3,1,2,1,NULL,'fototovar'),(16798,784706101017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','2010solo883','hoang.cao.swin@gmail.com','Hoang CAO','230 Langridge Street','Abbotsford','Victoria','AUSTRALIA','3067','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 15:04:15',0,NULL,5,0,18,0,NULL,'2010solo883'),(16799,768848923002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','philip_bmx','philip_bmx11@yahoo.com','Philipp Maksyutov','Voznesenskaya st. 51 40','Ryazan','','RUSSIAN FEDERATION','390000','4912 45 89 65','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 15:12:57',0,NULL,3,1,2,1,NULL,'philip_bmx'),(16800,855641603015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','ssshams','psychosaurus@hotmail.com','Syed Saqib Shams','A-9/II/B, NCEH Society,<br>Gulshan-e-Iqbal Bl. 10-A','Karachi','','PAKISTAN','75300','00923452219747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-20 15:52:04',0,NULL,3,1,2,1,NULL,'ssshams'),(16801,855651337015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','crapnamesleft','chris_mansfield@ntlworld.com','Chris Mansfield','38 linkfield<br>Welwyn Garden City','Hertfordshire','Not Listed','UNITED KINGDOM','AL7 4DW','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-20 16:10:39',0,NULL,3,1,4,1,'YW866011662CN ','crapnamesleft\r英标'),(16802,726707077001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','monastig3','alayan_arqitecture@yahoo.com','Mon Alayan','321 A<br>Albany Highway','North Shore','Auckland','NEW ZEALAND','0632','021 184 6033','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 16:40:20',0,NULL,3,1,2,1,NULL,'monastig3'),(16803,768900017002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','yakolokooo','yacobsen@hotmail.com','Jacob Ventoso','San Roque Nº80B / San Miguel','Villanueva de Arosa','Galicia','SPAIN','36620','664712820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 17:16:33',0,NULL,3,1,2,1,NULL,'yakolokooo'),(16804,784762959017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','caollen_n_owen','caollen_beth@hotmail.com','Craig Bartlett','173 Juers Street','Kingston','Queensland','AUSTRALIA','4114','0420963793','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 17:24:54',0,NULL,3,1,2,1,NULL,'caollen_n_owen'),(16805,726804762001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','fhyr86','fhloranterana@yahoo.com','Fhlorante Rana c/o Linn Arnesen','Lars Hagerups Veg 23<br>Lars Hagerups Veg 23','Tromsø','norway','NORWAY','9012','+4796800560','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-20 19:57:05',0,NULL,3,1,2,1,NULL,'fhyr86'),(16806,769001848002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','scotta7290','kruz@live.no','scott adams','Røyskattvegen 56','Kattem','','NORWAY','7082','(47) 41613752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 20:33:58',0,NULL,3,1,3,1,'RA184560089CN ','scotta7290'),(16807,784882794017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','paciaruch','paruchadam@gmail.com','Adam Paruch','Aleja Pokoju<br>30/26','Kraków','małopolskie','POLAND','31564','12 4110604','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 20:51:43',0,NULL,3,1,2,1,NULL,'paciaruch'),(16808,769013315002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','sajjadfm','sajjadf@gmail.com','Reza Falamaki','131/15 Herbert St','ST LEONARDS','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 20:58:58',0,NULL,3,1,2,1,NULL,'sajjadfm\r澳标'),(16809,726849229001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','ville_karas','ville.ebay@gmail.com','Ville Karas','Muurlantie 365 E 4 as 3','Muurla','','FINLAND','25130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-20 21:34:49',0,NULL,3,1,2,1,NULL,'ville_karas'),(16810,726662982018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','giggity-gooo','giggity_gooo@live.com','marco torchia','35 BALMORAL Place','DECEPTION BAY','Queensland','AUSTRALIA','4508','0410245764','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-20 21:39:01',0,NULL,3,1,3,1,'RA184560061CN ','giggity-gooo'),(16811,728992625018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','ville_karas','ville.ebay@gmail.com','Ville Karas','Muurlantie 365 E 4 as 3','Muurla','','FINLAND','25130','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 22:05:31',0,NULL,3,1,2,1,NULL,'ville_karas\r'),(16812,729015125018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','mudbiker','cmostech@gmail.com','Derek Darmstaedter','325 G St','Smyrna','TN','UNITED STATES','37167','(901) 262-7551','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-20 23:20:12',0,NULL,3,1,1,1,NULL,'mudbiker'),(16813,769073185002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','apoyyayil78','apoyyayil@hotmail.com','Ashley Poyyayil','4 Squatter Court','Werribee','Victoria','AUSTRALIA','3030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 00:03:15',0,NULL,3,1,3,1,'RA184560509CN\r ','apoyyayil78'),(16814,729038509018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','rodangib76','rodangib@gmail.com','Rodrigo Gibson','8/33 Waugh Street','Port Macquarie','New South Wales','AUSTRALIA','2444','0421968478','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'rodangib76'),(16815,769098361002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',2,'AKT051',23,'hermeshine','lef2323','bgedl@hotmail.com','Edward Lefrancois','22 Green Knolls Ln','Rutland','VT','UNITED STATES','05701-3369','(802) 558-6464','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 01:27:47',0,NULL,3,1,1,1,NULL,'lef2323'),(16816,729058591018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','chegui05','josepasofino@aol.com','wallace Castellar','11600 SW 2nd St<br>Apt 305','pembroke pines','FL','UNITED STATES','33025-4907','(954) 821-7870','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 02:04:14',0,NULL,3,1,1,1,NULL,'chegui05'),(16817,784988653017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','buying2selling-onthenet','transaction.account@revenue.com','Sukhpreet Dhamoon','1/Level 2,<br>330 Church Street','Parramatta','New South Wales','AUSTRALIA','2150','0402406076','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-21 02:09:53',0,NULL,3,1,4,1,'YW866011651CN ','buying2selling-onthenet\r澳标'),(16818,769110842002,120764190483,'600W Strobe Studio Flash Light Kit Lighting Photography',1,'',350,'hermeshine','alfredomol86','eddarm2009@live.com','Alfredo Santiago','PO Box 39','Cidra','PR','PUERTO RICO','00739-0039','7872636664','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 02:10:13',0,NULL,5,0,18,0,NULL,'alfredomol86'),(16819,8881316572231114,111,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',0,'photographyacc','amendara','amanda@amendara.com','amanda g williams','132 Wickham Rd','Woolsthorpe','Victoria','AUSTRALIA','3276','0355692439',NULL,NULL,NULL,'2011-09-21 02:30:31',0,NULL,3,1,3,1,'RA184560101CN ','前一个灯口化了，补发一个。\r澳标'),(16820,8881316573379767,111,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',29.99,'aliexpress','1004445715 ','marileneaa@gmail.com','Marilene Aparecida de Souza Barbosa	','Av. Dona Chiquinha de Avelar,587 Bairro Progresso','Sete Lagoas	','Minas Gerais	','BRAZIL','35701098','+55 31 37735090',NULL,NULL,NULL,'2011-09-21 02:49:39',0,NULL,3,1,3,1,'RA184560013CN ',NULL),(16821,769123552002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','pak7155','pakjpg@gmail.com','pakorn tuwajit','57/33 serithai road<br>klongkum bungkum','bangkok','bangkok','THAILAND','10240','662 377 2820','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 02:56:37',0,NULL,3,1,2,1,NULL,'pak7155'),(16822,8881316574141988,111,'100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',5,'',25.8,'aliexpress','1004462625','maln@inbox.ru','Leonid Malygin	','Sowjetskai 64 17','YAROSLAVL','RUSSIA','RUSSIAN FEDERATION	','150003','+7 910 8197527',NULL,NULL,NULL,'2011-09-21 03:02:21',0,NULL,3,1,3,1,'RA184560035CN ',NULL),(16823,855966583015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','wai.cheong','andychan@bigpond.net.au','Andy Chan','99 John Oxley Drive','Frenchs Forest','New South Wales','AUSTRALIA','2086','61414881388','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 03:03:55',0,NULL,3,1,2,1,NULL,'wai.cheong'),(16824,785013860017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','misspoppy12','lavache12@yahoo.com','Anna Young','802/221 Sturt Street','Southbank','Victoria','AUSTRALIA','3006','0413592877','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 03:49:17',0,NULL,3,1,17,0,NULL,'misspoppy12'),(16825,785013715017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',68,'photographyacc','misspoppy12','lavache12@yahoo.com','Anna Young','802/221 Sturt Street','Southbank','Victoria','AUSTRALIA','3006','0413592877','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-21 03:49:17',0,NULL,3,1,17,0,NULL,'misspoppy12'),(16826,785013616017,270777043723,'Video 2400w Red Head Continuous Lighting Kit 800w x 3',1,'AKT072',299,'photographyacc','misspoppy12','lavache12@yahoo.com','Anna Young','802/221 Sturt Street','Southbank','Victoria','AUSTRALIA','3006','0413592877','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-21 03:49:18',0,NULL,3,0,4,1,'YW866011732CN ','misspoppy12\r除了c 里面的再发\r单灯头 澳标     3 \r一转四 灯头      1\r灯架  2m       1\r柔光箱 50-70cm 单灯头澳标   1\r斜臂     1\r灯架包      1\r实重16.1   抛重15.93'),(16827,782975714017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','itexpress*1','itexpress1@hotmail.com','Brad McCarthy','14 Vincent Blvd','Trafalgar','Victoria','AUSTRALIA','3824','0438800300','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-21 06:08:08',0,NULL,3,1,4,1,'YW866011673CN ','itexpress*1\r澳标'),(16828,785045235017,270755020831,'800W Red Head for Studio Continuous Light Bulb x 5 220v',1,'AKT059',50,'photographyacc','formenfun','rupertananda@yahoo.com','Rupert Brown','20 Kenilworth St.<br>Bondi Junction','Sydney','New South Wales','AUSTRALIA','2022','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 06:24:29',0,NULL,3,1,3,1,'RA184560415CN\r ','formenfun'),(16829,785045504017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','dkminds','kishoredubasi@yahoo.co.in','Phani Yerabati','8 Rodborough Rd , Frenchs Forest','Sydney','New South Wales','AUSTRALIA','2086','0061430169333','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 06:27:47',0,NULL,3,1,3,1,'RA184560438CN\r ','dkminds\r---\r打印后贴外头：\rPlease deliver between 9.30am to 12.00pm on australian working days only.'),(16830,726980589001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','a0794673','evgeny.danishevsky@sandisk.com','Evgeny Danishevsky','ha-Arava st. 4, apt. 2','Ariel','','ISRAEL','44837','+972544842101','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 06:35:13',0,NULL,3,1,3,1,'RA184560424CN\r ','a0794673'),(16831,726985107001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',82,'hermeshine','tamim.n','afg_2nv@hotmail.com','Tamim Nawabi','90-98 victoria rd','Drummoyne','New South Wales','AUSTRALIA','2047','020411643265','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 06:58:05',0,NULL,3,1,4,1,'YW866011684CN ','tamim.n'),(16832,769170776002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','txberiu','tiberiu@sgnx.net','Tiberiu Ana','str. Belizarie nr. 1<br>bl. XXI/5, sc. A, et. 3, ap. 10, sect. 1','Bucharest','','ROMANIA','013965','(407) 417-4257 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 07:00:12',0,NULL,5,0,18,0,NULL,'txberiu\reBay通知账户被盗用，所以取消订单。'),(16833,726996279001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','sinanyus','sinanunan@hotmail.com','sinan unan','m.mazharbey cad. selvi apt. no:71/3<br>feneryolu','istanbul','','TURKEY','34724','+905072428488','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 08:10:15',0,NULL,3,1,2,1,NULL,'sinanyus'),(16834,854911108015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','interfun23','interpan23@gmail.com','Panayot Paunov','erimi,pafou 13 photo christodoulos avraam','erimi','limasol','CYPRUS','4630','0035796381798','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-21 08:15:23',0,NULL,3,1,12,1,'5241805601\r ','interfun23\r实重12.6  抛重13.6'),(16835,727003412001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','j00be','joope.erkkila@gmail.com','Waltteri Erkkilä','Varikonkatu 18 C','Sastamala','','FINLAND','38210','+358505714824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:24:14',0,NULL,3,1,17,0,NULL,'j00be'),(16836,769188040002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','allmarvin22','msul1@um.edu.mt','Marvin Sultana','Faculty for the Built Environment Building<br>University of Malta','Msida','','MALTA','MSD 2080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:24:40',0,NULL,3,1,3,1,'RA184560490CN ','allmarvin22'),(16837,769189195002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','j00be','joope.erkkila@gmail.com','Waltteri Erkkilä','Varikonkatu 18 C','Sastamala','','FINLAND','38210','+358505714824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:25:59',0,NULL,3,1,4,1,'YW866011695CN ','j00be\r2mx3m 背景架    1\r3mx6m 白色背景布    1\r2B柔      1\r7.29'),(16838,729143851018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',2,'AE3101',76,'photographyacc','rarefishbook','rarefishbooks@iinet.net.au','G Lavender','15 Northampton Crescent','Caroline Springs','Victoria','AUSTRALIA','3023','0393630609','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 08:37:07',0,NULL,3,1,2,1,' ','rarefishbook'),(16839,727007995001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','nidarayburn','nidarayburn@yahoo.com.au','Nida Rayburn','No 3 K.S. Residence, Room 103, Sukhumvit Road<br>Soi 54, Bangjak, Prakhanong','Bangkok','Bangkok','THAILAND','10260','662-715-9648','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 08:45:57',0,NULL,3,1,6,1,'EE495359905CN ','nidarayburn\r实重：12.33\r泡重：15.42'),(16840,727002619001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','j00be','joope.erkkila@gmail.com','Waltteri Erkkilä','Varikonkatu 18 C','Sastamala','','FINLAND','38210','+358505714824','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 08:22:07',0,NULL,3,1,17,0,NULL,'j00be'),(16841,785079696017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','dj_stick3722','dj_stick@driverheaven.net','Chris Stannard','2/226 Governor Rd','Braeside','Victoria','AUSTRALIA','3195','0395805800','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 09:15:08',0,NULL,3,1,2,1,NULL,'dj_stick3722'),(16842,769200850002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',4,'AE1201',19.2,'hermeshine','camera_bloke','fangio@netspace.net.au','Angelo Sartore','4 Southward Avenue','Port Melbourne','Victoria','AUSTRALIA','3207','0417522748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 09:16:02',0,NULL,3,1,2,1,' ','camera_bloke'),(16843,727018068001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','spsss17','uber.spsss@gmail.com','John Glover','P.O. Box 4088','Langwarrin','Victoria','AUSTRALIA','3910','0397899224','NoPaymentFailure','CheckoutComplete','AU_Express','2011-09-21 09:37:03',0,NULL,3,1,4,1,'YW866011743CN ','spsss17\r澳标\r实重7.83  抛重11.15'),(16844,8881316598291073,111,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',34.99,'photographyacc','tina_phan','service@paypal.com.hk','Tina Phan','16 hurtle st','lalor, Victoria','','AUSTRALIA','3075','',NULL,NULL,NULL,'2011-09-21 09:44:51',0,NULL,3,1,4,1,'YW866011706CN ',' 燕文告之收件人不在  需要联系客户\r▲已发信'),(16845,727015699001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','zappeastusa3','zappusa3@gmail.com','Andrei Third','30 Panas Rd','Foxboro','MA','UNITED STATES','02035-1072','(508) 242-9760','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-21 10:06:05',0,NULL,3,1,4,1,'YW866011710CN','zappeastusa3\r在我们自己打的那张签上打上：\ritem number：110741142180'),(16846,729181013018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','wil1616','willilepou@hotmail.com','william Gagné','343 notre-dame nord','Sainte-marie','QC','CANADA','g6e 2k5','(418) 387-3363','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 11:02:27',0,NULL,3,1,2,1,NULL,'wil1616'),(16847,769232835002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','stratomaster','reidlowe@gmail.com','Reid Lowery','16625 Redmond Way<br>Ste M PMB 246','Redmond','WA','UNITED STATES','98052-4499','(425) 503-3394','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 11:20:27',0,NULL,3,1,1,1,' ','stratomaster'),(16848,785118993017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','terra_operative','jaredcabot@live.com.au','Jared Cabot','37 Condamine Street','Runcorn','Queensland','AUSTRALIA','4113','0412556660','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 11:21:39',0,NULL,3,1,2,1,NULL,'terra_operative'),(16849,726179746001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','lindajohnsen','lindapooh83@hotmail.com','Linda Johnsen','Fergeland','Steinkjer','','NORWAY','7718','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 12:09:36',0,NULL,3,1,3,1,'RA184560631CN ','lindajohnsen\r新地址：\rLinda Johnsen\rKalv Arnesons gate 6\r7715 Steinkjer\rNorway\r'),(16850,729208571018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','chocopie88','princesscherryboutiquefb@gmail.com','U Cutie (ATT: Thy Ha Ngo)','Shop T43, Moonee Ponds Central<br>72-80 Puckle Street','Moonee Ponds','Victoria','AUSTRALIA','3039','0422344997','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-21 12:42:19',0,NULL,3,1,4,1,'YW866011721CN ','chocopie88'),(16851,769257140002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','grdimal','grdimal2@hotmail.fr','gérard Lami','Rue Eugénie Le San Carlo C6','Hyères','Provence-Alpes-Côte d\'Azur','FRANCE','83400','0672170857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 12:44:33',0,NULL,3,1,3,1,'RA184560605CN ','grdimal'),(16852,768754436002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','woo46304763','woo4630@gmail.com','Fook Leong Woo','Blk 107 Aljunied Crescent #12-04','default','','SINGAPORE','380107','96844763','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 12:45:40',0,NULL,3,0,3,1,'RA184560591CN ','woo46304763\r我来吧'),(16853,769267270002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','marcelogeriba','praseresdesign@bol.com.br','Marcelo Oliveira','Estrada Cafundá, 1757 - Bloco 10<br>Apto 507 - Taquara','Rio de Janeiro','Rio de Janeiro','BRAZIL','22725-030','552187776052','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 13:17:54',0,NULL,3,1,3,1,'RA184560512CN ','marcelogeriba\r欧标'),(16854,785186678017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','thorsy','thorsy@gmx.net','Thorsten Schulz','Viktoriastr. 11','Östringen','','GERMANY','76684','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 14:38:18',0,NULL,3,1,11,1,NULL,'thorsy'),(16855,729253870018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','13bobbella','jsmith_70@msn.com','Julian T Smith','26 Fernwood Road','Narre Warren','Victoria','AUSTRALIA','3805','0402434997','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 14:53:10',0,NULL,3,1,3,1,'RA184560543CN ','13bobbella'),(16856,769306541002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','istokka','admoccia@alice.it','pasquale saviano','via GRAMSCI 55','Frattaminore','NA','ITALY','80020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 15:15:32',0,NULL,3,1,3,1,'RA184560469CN ','istokka\rflash accessory $12'),(16857,727133581001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','gillesr1501','marigil2@rogers.com','Gilles Ravignat','1501 Bonneville cres.','Orleans','ON','CANADA','K1C7N1','(613) 824-5200','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 15:55:16',0,NULL,3,1,3,1,'RA184560557CN ','gillesr1501'),(16858,856228342015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',23.49,'hutongstore','seekponey','sickpony@gmail.com','Artsiom Kryvapust','Zharkovskogo 13, 21<br>Belarus','Gomel','','BELARUS','246050','375-29-1245630','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-21 16:30:39',0,NULL,3,1,3,1,'RA184560659CN ','seekponey'),(16859,785240144017,270797800419,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',35,'photographyacc','renatovm75','renato@evgbank.com','Renato Machado','Ruta 8, KM 17500<br>Edificio @3 - Oficina 108','Montevideo','Montevideo','URUGUAY','91600','598 2 518 2297','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 16:50:25',0,NULL,3,1,17,0,NULL,'renatovm75'),(16860,729301101018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','renatovm75','renato@evgbank.com','Renato Machado','Ruta 8, KM 17500<br>Edificio @3 - Oficina 108','Montevideo','Montevideo','URUGUAY','91600','598 2 518 2297','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 16:53:32',0,NULL,3,1,3,1,'RA184560486CN ','renatovm75\r新款大力夹（手柄）    1\r反光板 60cm 2合1       1\r申报 gift  $45'),(16861,727179490001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.8,'hermeshine','mylenakhkh','kakona@ua.fm','Elena Moskalchuk','Lesja Kurbasa 7a flat,89','Kiev','','UKRAINE','03194','+380632137757','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 17:46:34',0,NULL,3,1,5,1,'CP238031135CN ','mylenakhkh'),(16862,729331475018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','dontnee','find_dontnee@yahoo.com','Donny Lo','743-755  George  St<br>UNIT 1202 CAPITOL TERRACE','Haymarket','New South Wales','AUSTRALIA','2000','61450424859','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-21 18:05:07',0,NULL,3,1,2,1,NULL,'dontnee'),(16863,727209469001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','talefeather','talefeather@att.net','Joe Bagley','232 W Mariposa St','Altadena','CA','UNITED STATES','91001','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-21 18:43:27',0,NULL,3,1,1,1,NULL,'talefeather'),(16864,727221262001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','jupijasmin','najs.jupic@yahoo.com','Jasmin Jupic','Dobojska 63<br>Matuzici','Doboj Jug','F BiH','BOSNIA AND HERZEGOVINA','74203','+387-32-699-020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 19:07:47',0,NULL,3,1,2,1,NULL,'jupijasmin'),(16865,727234159001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','2010evele2010','katan4@inbox.lv','Vladimirs Romanko','Gimnastikas 7-5','Riga','','LATVIA','LV1004','371-292-024-717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 19:35:31',0,NULL,3,1,3,1,'RA184560588CN ','2010evele2010'),(16866,838580500016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','ajg2803','spyyike@sky.com','andrew graham','20 hampden road','leyland','Lancashire','UNITED KINGDOM','pr25 3sr','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-21 19:43:55',0,NULL,3,1,4,1,'YW866011754CN ','ajg2803'),(16867,729396277018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','honesting4284','ingo@dere.org','INGO DERE','35443 Riverwood Ct','Crosslake','MN','UNITED STATES','56442-4067','(321) 276-6634','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 20:00:12',0,NULL,3,1,17,0,NULL,'honesting4284'),(16868,729399706018,280670190865,'Green.L Premium Quality 72mm CPL Circular Polarizer New',1,'AA3313',7.2,'photographyacc','honesting4284','ingo@dere.org','INGO DERE','35443 Riverwood Ct','Crosslake','MN','UNITED STATES','56442-4067','(321) 276-6634','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 20:06:25',0,NULL,3,1,1,1,' ','honesting4284\r绿叶 UV  72mm     1\r绿叶 CPL 72mm     1\r'),(16869,727253382001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','alex-zh84','zh.foto@yahoo.com','Alexander Zhigarev','Andriabuzhnaya<br>74','Orel','Orlovskaya oblast\'','RUSSIAN FEDERATION','302011','89200878777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 20:13:13',0,NULL,3,1,2,1,NULL,'alex-zh84'),(16870,785364816017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','bretonvb','bretonv@gmail.com','Vincent Breton','651 boul du lac','Quebec','QC','CANADA','G2M 0E3','(418) 849-3174','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 20:55:35',0,NULL,3,0,3,1,'RA184560530CN ','bretonvb\rXXL   (已入库）'),(16871,727274390001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','eduardopennaepz','eduardopenna@epz.com.br','Eduardo Penna','Rua Vitorio Antônio Menezelo, 283','São José do Rio Preto','São Paulo','BRAZIL','15192100','17 3229 5558','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 21:06:03',0,NULL,3,1,17,0,NULL,'eduardopennaepz'),(16872,727276313001,110717761104,'New 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',36.99,'hermeshine','snimemvse','thegenius@list.ru','Novozhilova Ludmila','Leninskaya ulica, dom 14, kv 444','Yubileyniy','Moskovskaya oblast','RUSSIAN FEDERATION','141090','+79637110356','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 21:11:20',0,NULL,3,1,3,1,'RA184561654CN ','snimemvse'),(16873,727278393001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','eduardopennaepz','eduardopenna@epz.com.br','Eduardo Penna','Rua Vitorio Antônio Menezelo, 283','São José do Rio Preto','São Paulo','BRAZIL','15192100','17 3229 5558','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-21 21:25:50',0,NULL,3,1,3,1,'RA184560472CN ','eduardopennaepz\rc里的东西 加上\r9个环 + 两个托架    \r'),(16874,769475333002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','lydia41161','kmboomer@comcast.net','Katie Meade','163 Bates College','Lewiston','ME','UNITED STATES','04240-6064','(603) 531-3396','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-21 21:32:08',0,NULL,3,1,1,1,NULL,'lydia41161'),(16875,727043294018,280717890656,'Rolling Hard Case with Dividers for Photo Lighting Kit',1,'AD1165',135,'photographyacc','bmibreall67','bmibreall@gmail.com','brandon hall','2657 midway rd','decatur','GA','UNITED STATES','30030-4577','(404) 207-7036','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-21 21:57:47',0,NULL,3,1,4,1,'YW866011765CN ','bmibreall67'),(16876,720169788001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','ticouti78','ticouti@hotmail.com','Luis Gustavo Utiyama','561 walnut st','Elizabeth','NJ','UNITED STATES','07201-1104','201 943 8640','NoPaymentFailure','CheckoutComplete','Other','2011-09-21 22:27:00',0,NULL,3,1,1,1,NULL,'ticouti78'),(16877,769504632002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','dihencs','csdihen@freemail.hu','Dihen Csaba','Szitás u. 21.','Debrecen','','HUNGARY','4033','(36) 30 - 9439809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 23:03:13',0,NULL,3,1,17,0,NULL,'dihencs'),(16878,727313375001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','dihencs','csdihen@freemail.hu','Dihen Csaba','Szitás u. 21.','Debrecen','','HUNGARY','4033','(36) 30 - 9439809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-21 23:05:48',0,NULL,3,1,3,1,'RA184560574CN ','dihencs\r斜臂       1\r反光板支架     1\r'),(16879,838701948016,260810104926,'New 35\" 90cm Studio Flash Reflective Umbrella Softbox',2,'AD1127',27.8,'hutongstore','ddmatiasv','danmatv@hotmail.com','Daniel Matias','Av. Raimondi 121','Tingo Maria','Huanuco    Tingo Maria','PERU','Huan 62','51 62 561250','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 00:33:49',0,NULL,3,1,3,1,'RA184560565CN ','ddmatiasv'),(16880,729489196018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','em*azing','neldonia@aol.com','Emily D. Nelson','7012 Hawaii Kai Dr<br>Unit 908','Honolulu','HI','UNITED STATES','96825-4164','(808) 342-7137','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 00:35:41',0,NULL,3,1,1,1,NULL,'em*azing'),(16881,727310911001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','camaratroy','july0763@centurylink.net','troy fisler','155 County Road 1764<br>null','clifton','TX','UNITED STATES','76634-4002','','NoPaymentFailure','CheckoutComplete','Other','2011-09-22 00:50:11',0,NULL,3,1,1,1,NULL,'camaratroy'),(16882,769544628002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',67.36,'hermeshine','claudec4416','c_coulombe@hotmail.com','Claude Coulombe','5, Traversy','Gatineau','QC','CANADA','J8P 6P2','(819) 669-4318','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 01:43:53',0,NULL,3,1,5,1,'CP238031144CN','claudec4416\r背景架  + 1.6x2.1 白布'),(16883,769551118002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','outstuff','yanickdrouin@gmail.com','Sylvain Drouin','40 Chopin','Boisbriand','QC','CANADA','J7G1K3','(450) 433-2673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 02:07:11',0,NULL,3,1,2,1,NULL,'outstuff'),(16884,729514940018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','aportruchass','albertomvilla@yahoo.es','ALBERTO MIGUEL VILLA','SIERRA DE ALCUBIERRE 12 Izq 6ºB','ALCORCON','Madrid','SPAIN','28923','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 02:18:59',0,NULL,3,1,3,1,'RA184560645CN ','aportruchass'),(16885,8881316662070309,111,'New Hairlight photostudio boom arm ',1,'AE3101',25.99,'aliexpress','1004476210','820080@rambler.ru','Alexander Porotikov	','ul.Pridonskaya, d.44 b, k.4','Voronezh','Voronezhskaya obl.	','RUSSIAN FEDERATION	','394040','89038542295',NULL,NULL,NULL,'2011-09-22 03:27:50',0,NULL,3,1,3,1,'RA184560897CN\r',NULL),(16886,729536348018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','santinak','santinakeith@msn.com','Santina Keith','3 Westbury St','Chipping Norton','New South Wales','AUSTRALIA','2170','0296018195','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-22 04:02:47',0,NULL,3,1,3,1,'RA184560526CN ','santinak'),(16887,729548267018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','davevalentine','d.valentine@bigpond.com','David Valentine','Altus Renewables<br>Suite 4, 3974 Pacific Highway','Loganholme','Queensland','AUSTRALIA','4129','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-22 05:14:27',0,NULL,3,1,3,1,'RA184561230CN\r ','davevalentine\r放布'),(16888,729552229018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','streetcandyvintage','streetcandyoz@gmail.com','Liz Jones','24 O\'Connell Street','West End','Queensland','AUSTRALIA','4101','0478182953','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-22 05:37:02',0,NULL,3,1,4,1,'YW866011640CN ','streetcandyvintage'),(16889,769598197002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','ehar9979','ernest.harvey@gmail.com','Ernest Harvey','307 Papillon Dr','Belleville','IL','UNITED STATES','62226-1048','(618) 698-6678','NoPaymentFailure','CheckoutComplete','Other','2011-09-22 06:18:08',0,NULL,3,0,1,1,NULL,'ehar9979\rXXL   (已入库）'),(16890,727405637001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','harpreet_johal841210','harpreet_johal84@yahoo.com','harpreet johal','212-whitefield drive(basement suite)<br>north east','calgary','AB','CANADA','t1y5j2','(403) 919-2424','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 06:33:58',0,NULL,3,1,3,1,'RA184560628CN ','harpreet_johal841210'),(16891,8881316677747587,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.84,'aliexpress','1004444677','rossospillo@libero.it','Calcagni Riccardo','Viale Europa 175 c/o PosteItaliane S.p.A. stanza G316','Roma','Italia','ITALY','00144','+0039 3771607676',NULL,NULL,NULL,'2011-09-22 07:49:07',0,NULL,3,1,3,1,'RA184560614CN\r ',NULL),(16892,785547303017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','jad25au','cathy25au@hotmail.com','Cathy Vecchio','25 Gloucester Street','Concord, Sydney','New South Wales','AUSTRALIA','2137','61020403781979','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-22 08:51:45',0,NULL,3,1,17,0,NULL,'jad25au'),(16893,729590651018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','jad25au','cathy25au@hotmail.com','Cathy Vecchio','25 Gloucester Street','Concord, Sydney','New South Wales','AUSTRALIA','2137','61020403781979','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-22 08:51:45',0,NULL,3,1,3,1,'RA184560702CN ','jad25au\r爵影红外 canon    1\r独脚架  伟峰 WT-1005    1'),(16894,727447324001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','stephanevanis','stephane.vanisrael@scarlet.be','Stephane Van Israel','28 rue du trone','Bruxelles','','BELGIUM','1000','0486324454','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 09:51:38',0,NULL,3,1,3,1,'RA184560821CN\r ','stephanevanis'),(16895,769640059002,120761242928,'New 10 pcs for P Series Cokin filter box',1,'AD1170',9.9,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','(00420)608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 09:52:44',0,NULL,3,1,2,1,NULL,'robertbookshop'),(16896,769647537002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','gil_photo','just.gil@gmail.com','Gil Levy','No.3 Shkediya St. Apt.5','Ramat Gan','Israel','ISRAEL','52447','+972523892798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 10:15:24',0,NULL,3,1,2,1,NULL,'gil_photo'),(16897,769658467002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',218,'hermeshine','jonic1982kr','ev-rs@yandex.ru','Evgeny Krylov','pr. Lybyanoy 4','Krasnodar','Russia','RUSSIAN FEDERATION','350034','+7-918-47-47-490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 11:10:24',0,NULL,3,1,5,1,'CP235627799CN ','jonic1982kr\r欧标  实重5.43  抛重5.58'),(16898,727472672001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','pauldotorg','pauldotcom@mac.com','Paul del Rosario','4-1-1-819 Koremasa','Fuchu','Tokyo','JAPAN','183-0014','(814) 240-5771 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 11:31:03',0,NULL,3,1,6,1,'EE495359874CN ','pauldotorg'),(16899,729636768018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','sansuds','sansuds@gmail.com','santosh kumar murli','30-32 garden bvd<br>Dotmar engg plastics , Dingley','melbourne','Victoria','AUSTRALIA','3172','0395524400','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-22 11:50:29',0,NULL,3,1,2,1,NULL,'sansuds'),(16900,769675128002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','buddmeister','fredrikmolnar@gmail.com','Fredrik Molnar','Eriksfältsgatan 67D','Malmö','','SWEDEN','21455','+46703932121','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 12:02:00',0,NULL,3,1,4,1,'YW866011791CN ','buddmeister\r+1.6x2.1 白布\r燕文告之需要确认是否收到\r已发信-1012回信说刚刚回国，应该今天能收到'),(16901,727485421001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','leightro','tradebaymail@gmail.com','robert leighton','17 stanley st','concord','New South Wales','AUSTRALIA','2137','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:16:44',0,NULL,3,1,3,1,'RA184560781CN\r ','leightro'),(16902,769679886002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','exemxm','exem_xm@hotmail.com','Mohamed Ahmed (7979079)','Ma. Inguruge','Male\'','','MALDIVES','20165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:20:55',0,NULL,3,1,3,1,'RA184560764CN ','exemxm\r分开发\rRA184560852CN\r'),(16903,727484416001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 12:22:40',0,NULL,3,0,17,0,NULL,'makrousm'),(16904,769671678002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:41',0,NULL,3,1,17,0,NULL,'makrousm'),(16905,769672349002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:40',0,NULL,3,1,17,0,NULL,'makrousm'),(16906,769670925002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:41',0,NULL,3,1,17,0,NULL,'makrousm'),(16907,769671835002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:42',0,NULL,3,1,17,0,NULL,'makrousm'),(16908,727479417001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.48,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:43',0,NULL,3,1,17,0,NULL,'makrousm'),(16909,769670267002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','makrousm','libor@makrlik.cz','Libor Makrlik','Vazovova 3214','Prague 412','CZ','CZECH REPUBLIC','14300','+420603226673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:22:42',0,NULL,3,1,5,1,'CP238030930CN ','makrousm\r背心 黑色薄 canon  XXXL   1\r2.4x3m背景架+ 白布     1\r闪光的柔光箱   60cm    1\r反光板支架     1\r灯架  2m      2\r闪光灯B座    1\r柔光伞      1\r眼罩 40D/50D     1\r大力夹     2'),(16910,769689047002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','adi2827','adi1sh@hotmail.com','Adi Shaashua','Narkis 5','Beer-Yaakov','','ISRAEL','70300','97289281498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 12:53:37',0,NULL,3,1,3,1,'RA184561892CN ','adi2827\r申报$45'),(16911,0,250896888810,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',0.95,'hutongstore','markanathan100','skylinegtr100@hotmail.co.uk','Mark Nathan','40 shirley gdns<br>manadon','plymouth','Devon','UNITED KINGDOM','pl5 3eu','01752302622','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:09:15',0,NULL,3,1,2,1,NULL,'markanathan100'),(16912,0,260858209096,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',0.01,'hutongstore','bluepanda0_2','paulschambers@hotmail.co.uk','Paul Chambers','63 Norfolk Road','Salisbury','Wiltshire','UNITED KINGDOM','SP2 8HQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:11:45',0,NULL,3,1,2,1,NULL,'bluepanda0_2'),(16913,0,260858209105,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',0.01,'hutongstore','severin.auctions','james3mc@gmail.com','Mr. James McCann','6 Anton Way','Aylesbury','Buckinghamshire','UNITED KINGDOM','HP21 9LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:13:45',0,NULL,3,1,17,0,NULL,'severin.auctions'),(16914,0,250896888814,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',1,'AA1309',0.06,'hutongstore','severin.auctions','james3mc@gmail.com','Mr. James McCann','6 Anton Way','Aylesbury','Buckinghamshire','UNITED KINGDOM','HP21 9LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:13:44',0,NULL,3,1,2,1,NULL,'severin.auctions\rNIKON 镜头盖 67mm    1\rNIKON 镜头盖 77mm     1'),(16915,727497418001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 13:13:50',0,NULL,3,1,3,1,'RA184560804CN\r ','axonalex'),(16916,0,250896888816,'New 72mm Lenscap for Canon Lens Snap-on 72  Front Cap',1,'AA1303',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:38',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16917,0,260858209090,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:38',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16918,0,250896888808,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',1,'AA1308',0.11,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:39',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16919,0,260858209092,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',0.11,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:39',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16920,0,260858209093,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',0.16,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:39',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16921,0,250896888819,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',0.06,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:40',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16922,0,260858209100,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:40',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16923,0,260858209099,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',0.16,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:41',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16924,0,260858204380,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:14:41',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16925,0,260858210837,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',4.99,'hutongstore','sinknote1','richardm50@hotmail.co.uk','07554176120','HATCHMOOR NURSING HOME<br>HATCHMOOR COMM0N LANE','GREAT TORRINGTON','Devon','UNITED KINGDOM','EX387AT','01805625721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:20:21',0,NULL,3,0,2,1,NULL,'sinknote1\r黑色'),(16926,0,250896888829,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:21',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16927,0,260858204384,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',0.4,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:21',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16928,0,260858204381,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',1,'AA1306',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:22',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16929,0,250896888825,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:22',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16930,0,250896888820,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',0.01,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:22',0,NULL,3,1,17,0,NULL,'lakeland_photos'),(16931,0,250896888811,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',0.11,'hutongstore','lakeland_photos','lakedistrictphotos@gmail.com','A Drake','12 Craika Road','Dearham','Cumbria','UNITED KINGDOM','CA15 7EH','07415000944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:27:23',0,NULL,3,1,3,1,'RA184560693CN\r ','lakeland_photos\rCANON 镜头盖  72mm    1\rnikon 反接环  52mm   1\rNIKON 镜头盖 72mm      1\rCANON 镜头盖  67mm     1\rNIKON 镜头盖 67mm     2\r方形滤镜接口环 62mm     1\r热靴保护盖  sony     1\rNIKON 镜头盖 77mm     1\rNIKON 镜头盖 52mm    1\r方形滤镜接口环 77mm     1\rNIKON 镜头盖 62mm     2\r方形滤镜接口环 67mm     1\rcanon 反接环  58mm     1\r'),(16932,0,250896888824,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',0.01,'hutongstore','maxstein72','jnorton@jnorton.plus.com','John Norton','23 Lime Crescent','Church Warsop','Nottinghamshire','UNITED KINGDOM','NG20 0SY','01623845434','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:32:58',0,NULL,3,1,2,1,NULL,'maxstein72'),(16933,0,250896884599,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',1,'AA1309',0.35,'hutongstore','rogermoore0','rogermoorephoto@aol.com','Roger Moore','Cappadocia<br>Hermon,   Cynwyl Elfed,','Carmarthen','Carmarthenshire','UNITED KINGDOM','SA33 6SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:35:26',0,NULL,3,1,17,0,NULL,'rogermoore0'),(16934,0,250896884594,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',1,'AA1308',0.16,'hutongstore','rogermoore0','rogermoorephoto@aol.com','Roger Moore','Cappadocia<br>Hermon,   Cynwyl Elfed,','Carmarthen','Carmarthenshire','UNITED KINGDOM','SA33 6SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:35:27',0,NULL,3,1,2,1,NULL,'rogermoore0\rNIKON 镜头盖 77mm    1\rNIKON 镜头盖 72mm      1'),(16935,0,250896888827,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',0.01,'hutongstore','ezeeshop','edward.mitch2@virgin.net','paul mitchell','14 newlands road','wisbech cambridgeshire','Cambridgeshire','UNITED KINGDOM','PE134LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 13:38:35',0,NULL,3,1,2,1,NULL,'ezeeshop'),(16936,729672889018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','falconetti10','falcondiets@yahoo.co.uk','Pedro Falcon Marrero','Calle del cedro, 12<br>La Jaca','Arico','Santa Cruz de Tenerife','SPAIN','38588','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 13:46:48',0,NULL,3,1,2,1,NULL,'falconetti10'),(16937,856713478015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','frankb1816','frankbell@myway.com','Frank Bell','5 Parkside<br>Marcham','Abingdon','Oxfordshire','UNITED KINGDOM','OX13 6NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 14:19:01',0,NULL,3,1,2,1,NULL,'frankb1816'),(16938,727523164001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','vasma777','webster777@bk.ru','Vasya Malyk','Visotskoho 8<br>Village of Myhalcha','Storozhinezkiy District','Chernivtsi Region','UKRAINE','59040','+380990160560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 14:22:49',0,NULL,3,1,5,1,'CP235627754CN','vasma777'),(16939,0,260858209094,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',0.01,'hutongstore','nick32rs','haighn39@hotmail.co.uk','Nick Haigh','29 Octavian Crescent<br>North Hykeham','Lincoln','Lincolnshire','UNITED KINGDOM','LN6 8HJ','07807020671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 14:45:09',0,NULL,3,1,2,1,NULL,'nick32rs'),(16940,727502461001,110454856549,'Adjustable Neoprene Padded Neck shoulder Strap for Sony',1,'AB1406',5.49,'hermeshine','daviderons','daviderons@hotmail.it','davide cositore','1trv via barracano nuovo parco azzurro scala M int 1','giugliano in campania','NA','ITALY','80014','3935692612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 14:48:51',0,NULL,3,1,2,1,NULL,'daviderons'),(16941,769728420002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','synapticmysfire','jonathanhewlett@me.com','Jonathan Hewlett','PO Box U352<br>Charles Sturt University','Wagga Wagga','New South Wales','AUSTRALIA','2678','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 14:58:48',0,NULL,3,1,2,1,NULL,'synapticmysfire'),(16942,729697956018,280727897663,'400w Studio Strobe Kit flash+ 2m stand + soft umbrella',1,'AKT079',199,'photographyacc','camille_shopping','camilleforget@hotmail.com','Camille Forget','6585 38e avenue appt 6','Montréal','QC','CANADA','H1T 2X8','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 15:02:51',0,NULL,5,1,18,0,' ','camille_shopping'),(16943,0,260858209102,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',0.01,'hutongstore','reliable*trader','auctionhome@btopenworld.com','Mr A Brown','9 St Martins Crescent<br>Scawby','BRIGG','Lincolnshire','UNITED KINGDOM','DN20 9BQ','07803129733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 15:39:27',0,NULL,3,1,17,0,NULL,'reliable*trader'),(16944,0,250896888830,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',0.01,'hutongstore','reliable*trader','auctionhome@btopenworld.com','Mr A Brown','9 St Martins Crescent<br>Scawby','BRIGG','Lincolnshire','UNITED KINGDOM','DN20 9BQ','07803129733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 15:39:27',0,NULL,3,1,17,0,NULL,'reliable*trader'),(16945,0,250896884603,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',0.01,'hutongstore','reliable*trader','auctionhome@btopenworld.com','Mr A Brown','9 St Martins Crescent<br>Scawby','BRIGG','Lincolnshire','UNITED KINGDOM','DN20 9BQ','07803129733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 15:39:28',0,NULL,3,1,17,0,NULL,'reliable*trader'),(16946,0,250896888828,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',0.01,'hutongstore','reliable*trader','auctionhome@btopenworld.com','Mr A Brown','9 St Martins Crescent<br>Scawby','BRIGG','Lincolnshire','UNITED KINGDOM','DN20 9BQ','07803129733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 15:39:28',0,NULL,3,1,17,0,NULL,'reliable*trader'),(16947,0,260858209089,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',0.01,'hutongstore','reliable*trader','auctionhome@btopenworld.com','Mr A Brown','9 St Martins Crescent<br>Scawby','BRIGG','Lincolnshire','UNITED KINGDOM','DN20 9BQ','07803129733','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 15:39:28',0,NULL,3,1,3,1,'RA184560662CN\r ','reliable*trader\r方形滤镜接口环 49mm   1\r眼罩 40D/50D     1\r热靴保护盖  sony     1\r眼罩 450D/500D     1\rcanon 反接环  52mm     1'),(16948,838983437016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','lilly7816','christainwill04@hotmail.com','Lilly McGee','PO Box 661<br>308 3rd Street','Simpsonville','KY','UNITED STATES','40067-0661','(502) 569-1004','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-22 16:10:12',0,NULL,3,1,4,1,'YW866011802CN ','lilly7816'),(16949,0,250896888821,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',0.01,'hutongstore','biddy116','john.skeates1@btopenworld.com','JOHN SKEATES','116 CONSTABLE ROAD','IPSWICH','SUFFOLK','UNITED KINGDOM','IP4 2XA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 17:36:06',0,NULL,3,1,2,1,NULL,'biddy116'),(16950,727610657001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','ramanliu','ramanliujh@hotmail.com','Jinghui Liu','20 Bloorview Pl<br>Suite 308','North York','ON','CANADA','M2J0A6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 18:11:17',0,NULL,3,0,3,1,'RA184560747CN\r ','ramanliu\rNikon   52cm 镜头盖       10\r已入库'),(16951,769807909002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','123_pizele','santa.pizele@inbox.lv','Santa Pizele','Daugavpils iela  72-6','Preili','LV','LATVIA','5301','26484943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 18:16:17',0,NULL,3,1,2,1,NULL,'123_pizele\r欧标'),(16952,0,260858204382,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',0.25,'hutongstore','aardvaark2010','hwaller45@googlemail.com','Heinz Waller','36 Spinney Street','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6ES','07768335007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:20:18',0,NULL,3,1,17,0,NULL,'aardvaark2010'),(16953,0,260858209085,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',1,'AA1306',0.01,'hutongstore','aardvaark2010','hwaller45@googlemail.com','Heinz Waller','36 Spinney Street','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6ES','07768335007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:22:19',0,NULL,3,1,17,0,NULL,'aardvaark2010'),(16954,0,250896888818,'New EyeCup for Nikon Af D80 D90 D200',1,'AA1203',0.01,'hutongstore','aardvaark2010','hwaller45@googlemail.com','Heinz Waller','36 Spinney Street','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6ES','07768335007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:23:11',0,NULL,3,1,17,0,NULL,'aardvaark2010'),(16955,0,260858209095,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',0.01,'hutongstore','aardvaark2010','hwaller45@googlemail.com','Heinz Waller','36 Spinney Street','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6ES','07768335007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:24:08',0,NULL,3,1,17,0,NULL,'aardvaark2010'),(16956,0,250896888826,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',0.01,'hutongstore','aardvaark2010','hwaller45@googlemail.com','Heinz Waller','36 Spinney Street','Raunds','Northamptonshire','UNITED KINGDOM','NN9 6ES','07768335007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:25:29',0,NULL,3,1,3,1,'RA184560795CN\r ','aardvaark2010\r热靴保护盖  普通     2\rNIKON 镜头盖 62mm    1\r眼罩 D300    1\rpentax 反接环  52mm    1'),(16957,839059430016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','lape1234','remisvin@gmail.com','Tanya Vindasius','29 Villa close','Biddulph','Staffordshire','UNITED KINGDOM','ST8 6LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 18:33:17',0,NULL,3,1,3,1,'RA184561861CN ','lape1234'),(16958,0,250896884601,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',0.01,'hutongstore','nikthegreek66','n.ambridge@sky.com','Nick Ambridge','38 The Hemsleys','Please Pottage','West Sussex','UNITED KINGDOM','RH119BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 19:29:14',0,NULL,3,1,17,0,NULL,'nikthegreek66'),(16959,727662707001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','rob12564','robandangie@talktalk.net','R Hill','Flat 47, Roydon Court<br>Mayfield Road','Walton-on-Thames','Surrey','UNITED KINGDOM','KT12 5HZ','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 19:52:17',0,NULL,3,1,3,1,'RA184560716CN\r ','rob12564'),(16960,729839484018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','maurizio1948','maurizio@geologoazzola.it','maurizio azzola','gavazzeni 6','sondrio','SO','ITALY','23100','0342214938','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 20:10:49',0,NULL,3,1,17,0,NULL,'maurizio1948'),(16961,729841491018,280722265640,'New 10 pcs Landscape Color Filters Kit for Cokin P',1,'AKT077',42,'photographyacc','maurizio1948','maurizio@geologoazzola.it','maurizio azzola','gavazzeni 6','sondrio','SO','ITALY','23100','0342214938','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-22 20:15:26',0,NULL,3,1,3,1,'RA184560680CN\r ','maurizio1948\r除了c 里面的再发9个环+两种托架\r\rfilters  $15'),(16962,769872773002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','patou4266','ptremblay40@gmail.com','Patrice Tremblay','3267, St-Jacques','Montréal','QC','CANADA','H4c 1G8','(514) 678-0304','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 20:29:04',0,NULL,3,1,2,1,NULL,'patou4266'),(16963,0,250896884597,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',0.01,'hutongstore','sambridge07','s.ambridge@sky.com','Sarah Ambridge','38 The Hemsleys','Pease Pottage','West Sussex','UNITED KINGDOM','RH11 9BX','01483230349','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 20:40:23',0,NULL,3,1,17,0,NULL,'sambridge07'),(16964,856911215015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','ritienne85','ritiennecutajar@hotmail.com','Ritienne Vella','St.Rita Siggiewi Street','Haz-Zebbug','','MALTA','ZBG 2308','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-22 20:42:40',0,NULL,3,1,3,1,'RA184560778CN\r ','ritienne85'),(16965,0,260858204385,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',0.01,'hutongstore','sambridge07','s.ambridge@sky.com','Sarah Ambridge','38 The Hemsleys','Pease Pottage','West Sussex','UNITED KINGDOM','RH11 9BX','01483230349','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 20:42:50',0,NULL,3,1,17,0,NULL,'sambridge07'),(16966,727675092001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','marcel_cristocea','marcel.cristocea@gmail.com','Marcel Cristocea','Tomis 253, Bl T1, Sc D, ap 69, Et 2','Constanta','Constanta','ROMANIA',' 900395 ','+40 724 513 534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 20:45:10',0,NULL,3,1,17,0,NULL,'marcel_cristocea'),(16967,769867979002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','marcel_cristocea','marcel.cristocea@gmail.com','Marcel Cristocea','Tomis 253, Bl T1, Sc D, ap 69, Et 2','Constanta','Constanta','ROMANIA',' 900395 ','+40 724 513 534','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 20:45:11',0,NULL,3,1,5,1,'CP238030890CN ','marcel_cristocea\r大力夹云台    2\r反光板 100*150 40*60 5合1    1\r闪光的柔光箱   60cm    1\r新地址\r Alexandru Cristocea \rStreet:Str Matei Basarab Nr 52, Bl E2 Sc A Ap 2\rCity:Slobozia\rState:Ialomita\rCountry:Romania\rZip code:920072\rPhone #:0724513534'),(16968,769867726002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','marcel_cristocea','marcel.cristocea@gmail.com','Marcel Cristocea','Tomis 253, Bl T1, Sc D, ap 69, Et 2','Constanta','Constanta','ROMANIA',' 900395 ','+40 724 513 534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 20:45:12',0,NULL,3,1,3,1,'RA184560883CN ','marcel_cristocea\r这票就发斜壁和灯架   60的闪光的柔光箱跟下一票发走\r新地址\r Alexandru Cristocea \rStreet:Str Matei Basarab Nr 52, Bl E2 Sc A Ap 2\rCity:Slobozia\rState:Ialomita\rCountry:Romania\rZip code:920072\rPhone #:0724513534'),(16969,0,250896888831,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',0.01,'hutongstore','sambridge07','s.ambridge@sky.com','Sarah Ambridge','38 The Hemsleys','Pease Pottage','West Sussex','UNITED KINGDOM','RH11 9BX','01483230349','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 20:45:23',0,NULL,3,1,2,1,NULL,'sambridge07\rCANON 镜头盖  58mm    1\rCANON 镜头盖  77mm     2'),(16970,0,260858209086,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',0.01,'hutongstore','nikthegreek66','n.ambridge@sky.com','Nick Ambridge','38 The Hemsleys','Please Pottage','West Sussex','UNITED KINGDOM','RH119BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 21:03:16',0,NULL,3,1,17,0,NULL,'nikthegreek66'),(16971,0,250896888817,'52mm Snap-on Front Cap for Nikon 52mm Filters Lens New',1,'AA1305',0.01,'hutongstore','nikthegreek66','n.ambridge@sky.com','Nick Ambridge','38 The Hemsleys','Please Pottage','West Sussex','UNITED KINGDOM','RH119BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 21:05:59',0,NULL,3,1,17,0,NULL,'nikthegreek66'),(16972,0,250896888815,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',0.01,'hutongstore','nikthegreek66','n.ambridge@sky.com','Nick Ambridge','38 The Hemsleys','Please Pottage','West Sussex','UNITED KINGDOM','RH119BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-22 21:08:07',0,NULL,3,1,2,1,NULL,'nikthegreek66\rCANON 镜头盖  67mm    1\rNIKON 镜头盖 52mm     2\rCANON 镜头盖  58mm   1'),(16973,769891549002,120486048007,'New Timer Remote Control for Canon EOS 450D 400D 350D',1,'AA3221',45.9,'hermeshine','karolain-e','afernandez.caro@gmail.com','Antonio Fernández Caro','Carretas 14, 5º G3','Madrid','Madrid','SPAIN','28012','651082832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-22 21:16:00',0,NULL,3,1,3,1,'RA184560755CN\r ','karolain-e'),(16974,727741335001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.9,'hermeshine','omer.erkol','omer-erkol@hotmail.com','Ömer ERKOL','223 Sokak No:59 D:3 Buca','Izmir','','TURKEY','35390','905077244797','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-22 23:50:17',0,NULL,3,1,3,1,'RA184560835CN\r ','omer.erkol'),(16975,729934091018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','silvajones1','silva@tsn.cc','Elaine Vaughan-Jones','14 Bain Street','Wauchope','New South Wales','AUSTRALIA','2446','0265861813','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 01:13:28',0,NULL,3,0,3,1,'RA184560720CN\r ','silvajones1\r XL  已入库'),(16976,769962124002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','ska2005','hyperpatron@gmail.com','Igor Khitev','Metallurgov 48/5/26','Moscow','Moscow','RUSSIAN FEDERATION','111399','495-304-5843','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-23 01:34:22',0,NULL,3,1,17,0,NULL,'ska2005'),(16977,727767920001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','ska2005','hyperpatron@gmail.com','Igor Khitev','Metallurgov 48/5/26','Moscow','Moscow','RUSSIAN FEDERATION','111399','495-304-5843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 01:44:46',0,NULL,3,1,5,1,'CP235627768CN ','ska2005\r爵影碗罩P1    1\r150-200cm 5in1 反光板     1'),(16978,785920389017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',225,'photographyacc','iceau','koorizzihan@gmail.com','Zhihang Zhou','84 Dunedin st','Sunnybank','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-23 01:53:35',0,NULL,3,1,4,1,'YW866011813CN ','iceau'),(16979,727739347001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','danit8569','danit6985@yahoo.com','Daniel Dyar','8020 Sunny Ln','Fort Wayne','IN','UNITED STATES','46835-1172','(812) 278-6172','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 01:47:05',0,NULL,3,1,3,1,'RA184560849CN\r ','danit8569'),(16980,8881316745085383,111,'72mm Snap-on Front Cap for Nikon 72mm Filters Lens New',2,'AA1308',0,'hutongstore','0706alan','cottonmouth@tiscali.co.uk','alan schofield','18 broadfield drive<br>smithybridge.','littleborough','Lancashire','UNITED KINGDOM','ol15 0eu','01706374890',NULL,NULL,NULL,'2011-09-23 02:31:25',0,NULL,3,1,3,1,'RA184560818CN\r ','72mm Nikon 镜头盖 * 2'),(16981,729963534018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','kyoungdong087','kim.stephanog@gmail.com','Stephano Kim','6 Cooke Way','Epping','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 03:12:26',0,NULL,3,1,3,1,'RA184560676CN\r ','kyoungdong087'),(16982,769995555002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','valentinagilyadova','valelik18@yandex.ru','valentina schlesinger','7060 county road 21','alliston','ON','CANADA','l9r1v2','(647) 892-1881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 04:08:32',0,NULL,3,1,3,1,'RA184560954CN ','valentinagilyadova'),(16983,769999190002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','namoradinha','altairzmieski@hotmail.com','Althir Zmieski','200 Leisure Ln #78','Stoneham','MA','UNITED STATES','02180','(857) 207-2774','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 04:28:02',0,NULL,3,1,1,1,NULL,'namoradinha'),(16984,727746855001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',141.05,'hermeshine','rowan1659','rowmat@net2000.com.au','Rowan Matthews','Rowan Matthews<br>4 Carramar Court','Emerald','Victoria','AUSTRALIA','3782','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 04:34:30',0,NULL,3,1,17,0,NULL,'rowan1659'),(16985,727746107001,110568758656,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',219.56,'hermeshine','rowan1659','rowmat@net2000.com.au','Rowan Matthews','Rowan Matthews<br>4 Carramar Court','Emerald','Victoria','AUSTRALIA','3782','','NoPaymentFailure','CheckoutComplete','NotSelected','2011-09-23 04:35:43',0,NULL,3,1,4,1,'YW866011824CN ','rowan1659\r澳标\r除了c 里面的再发\r大号灰卡    1\r4灯头 灯头 孔   澳标   1\r115w 220v 灯泡    4\r双灯头 澳标     2\r单灯头 澳标     4\r已入库\r'),(16986,729983475018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','mmmystuff','ebay@maxiusmedia.com','Damien Goates','13 Bizana St','West Footscray','Victoria','AUSTRALIA','3012','0414351919','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 05:01:02',0,NULL,3,1,3,1,'RA184560866CN ','mmmystuff'),(16987,785962125017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','ashnreen','ashz@internode.on.net','Ashleigh Perkins','36 Coromont Drive','Hallidays Point','New South Wales','AUSTRALIA','2430','0265593847','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 05:15:27',0,NULL,3,1,2,1,NULL,'ashnreen'),(16988,785962242017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',2,'AB3332',5.8,'photographyacc','mitch151','finlandphoto@hotmail.com','Mitch Carlin','1-10 Snipe Street ','Miami, Gold Coast','Queensland','AUSTRALIA','4220','0755764538','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-23 05:16:27',0,NULL,3,1,2,1,NULL,'mitch151'),(16989,727808126001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.9,'hermeshine','sayedfaridhaiderzadeh','mohazareh@gmail.com','Sayed Haiderzadeh','3 Ellesmere Street PH 12','Richmond Hill','ON','CANADA','L4B 4N2','(905) 707-5193','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-23 05:35:13',0,NULL,3,1,3,1,'RA184560870CN ','sayedfaridhaiderzadeh'),(16990,727810866001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','msijka','msijka@gmail.com','Mark Sijka','94 Cherrywood Dr','Nashua','NH','UNITED STATES','03062-3080','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-23 05:38:51',0,NULL,3,1,1,1,NULL,'msijka'),(16991,785967764017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','bernardo_vieira','omatador_bucareste@hotmail.com','Bernardo Vieira','Flat 3, 319 High Street<br>Mornington','Dunedin','Dunedin','NEW ZEALAND','9016','0220987951','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 05:44:45',0,NULL,3,1,2,1,NULL,'bernardo_vieira'),(16992,729998075018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','assilem09','melandh@hotmail.com','Melissa Hawkins','Serpentine<br>Mail Service 381','Springsure','Queensland','AUSTRALIA','4722','0749855072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 06:30:18',0,NULL,3,1,17,0,NULL,'assilem09'),(16993,785974979017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','assilem09','melandh@hotmail.com','Melissa Hawkins','Serpentine<br>Mail Service 381','Springsure','Queensland','AUSTRALIA','4722','0749855072','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 06:30:19',0,NULL,3,1,2,1,NULL,'assilem09\r绿叶 UV  72mm     1\rCANON 镜头盖  72mm    1'),(16994,770034611002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','doeoentjes','doeoentjes@web.de','Jana Lämmerer','Raintalerstr. 12a','München','','GERMANY','81539','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-23 07:57:50',0,NULL,3,1,12,1,'5241807336\r ','doeoentjes\r欧标实重4.278  抛重5.79'),(16995,786013571017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','shanebolger82010','shanebolger8@yahoo.com.au','Shane','36 Patrol street','Jamboree Heights','QLD','AUSTRALIA','4074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 09:13:53',0,NULL,3,1,2,1,NULL,'shanebolger82010'),(16996,726966957001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','dronizz2010','dronizz@inbox.ru','Andrei Olefirenko','Kim<br>28','Krasnodar','krasnodarskiy','RUSSIAN FEDERATION','350000','+7 918 37 468 73','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 09:22:03',0,NULL,3,1,5,1,'CP238030957CN ','dronizz2010'),(16997,770050946002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',2,'AO0001',380,'hermeshine','siemko79','siemlik@op.pl','Maciej Siemieniuch','ul. Hetmańska 98','Poznań','wielkopolskie','POLAND','60-491','61 8303789','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 09:32:55',0,NULL,3,1,5,1,'CP238030965CN ','siemko79'),(16998,857163706015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','thormika','thormika@yahoo.com','sovanna ith','93 avenue Aristide Briand','cachan','Île-de-France','FRANCE','94230','0610047347','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 10:28:39',0,NULL,3,1,2,1,NULL,'thormika'),(16999,786034139017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','simpleton74','sim.goh@gmail.com','Sim Goh','Level 7, Aon House, 63 Pirie St','Adelaide','South Australia','AUSTRALIA','5000','61419334232','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 10:31:17',0,NULL,3,1,2,1,NULL,'simpleton74'),(17000,839377949016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','vartimus','arturs.vikmanis@gmail.com','Arturs Vikmanis','Tilta 24-21','Riga','','LATVIA','LV1005','+37129696787','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 10:31:56',0,NULL,3,1,2,1,NULL,'vartimus'),(17001,727873906001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','thpriest','pincemince@gmail.com','andrew maclaurin','c/ atocha 90, 7c','madrid','Madrid','SPAIN','28012','911889398','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-23 10:43:02',0,NULL,3,1,12,1,'5241743614\r ','thpriest\r可以发货了\r实重1.29 抛重 2.016'),(17002,769158249002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','sahersr11','srur173@gmail.com','saher srur','box 146','eilaboun village','','ISRAEL','16972','0527324823','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 10:53:17',0,NULL,3,1,3,1,'RA184561019CN\r ','sahersr11'),(17003,856716516015,250600315208,'Flash Softbox Diffuser for external flash SB800 580EX ',1,'AB3302',25.74,'hutongstore','tepes1972','dmitriy.shindin@gmail.com','Дмитрий Шиндин','Васильковская, 15/14, 56','Киев','','UKRAINE','03040','(380) 504442200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 11:07:08',0,NULL,3,1,3,1,'RA184561433CN\r ','tepes1972\r肥皂盒  580ex    1\r肥皂和  sb800    1\rNG200        1\r镜头筒  xl       1\r闪光灯D座    1 （有一次和b座一起到的那个）\r热靴盖水平仪     1\r已入库\r\r\r\r\r\r'),(17004,730069869018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','iliko-1911','avto015@mail.ru','Ilham Aliyev','M.Hadi Street 71. aprt.55','Baku','','AZERBAIJAN','1129','+994503261911','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 11:29:19',0,NULL,3,1,2,1,'\r ','iliko-1911'),(17005,786066536017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','solly07','solly007@bigpond.com','Rebecca Solomon','40 Karinda Drive','Inverell','New South Wales','AUSTRALIA','2360','0439072769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 12:21:41',0,NULL,3,1,17,0,NULL,'solly07'),(17006,786066328017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',1,'AA1305',2.5,'photographyacc','solly07','solly007@bigpond.com','Rebecca Solomon','40 Karinda Drive','Inverell','New South Wales','AUSTRALIA','2360','0439072769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 12:21:42',0,NULL,3,1,2,1,NULL,'solly07\rlenspen     1\r气吹+布       1\rNIKON 镜头盖 52mm    1\r'),(17007,730089489018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','peternovitzky','pnovitzky@gmail.com','Peter Novitzky','Kezmarska 16','Kosice','','SLOVAK REPUBLIC','04011','+420773130848','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 12:33:48',0,NULL,3,1,3,1,'RA184561098CN\r ','peternovitzky'),(17008,770112952002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','marpfa2003','martin@pfannenstein.net','Martin Pfannenstein','Arcisstr. 21<br>TUM / Lst. f. Medientechnik','München','','GERMANY','80333','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 13:06:52',0,NULL,3,1,2,1,NULL,'marpfa2003'),(17009,728622818018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','treehouse30kc','kc@kcsmithphotography.com','KC  Smith','4 Echoview Cir','Lexington','NC','UNITED STATES','27292-5529','(336) 250-1133','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 13:29:12',0,NULL,3,1,3,1,'RA184566988CN  ','treehouse30kc'),(17010,857234756015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','dereklynchphotography2011','dereklynchphotography@gmail.com','Derek Lynch','19 wellview park<br>blanchardstown','dublin','Dublin','IRELAND','15','0857483634','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 13:47:15',0,NULL,3,1,4,1,'YW866011916CN ','dereklynchphotography2011\r白+黑\rbackground support  $20'),(17011,786104423017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',5.98,'photographyacc','braidedbirchfarm','john.tourgee@gmail.com','John Tourgee','511 Jarmany Hill Rd','Sharon','NH','UNITED STATES','03458-7011','(603) 924-9183','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 14:11:02',0,NULL,3,1,1,1,NULL,'braidedbirchfarm'),(17012,786111544017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','ritanrob','rstella1976@gmail.com','Robert Stella','6 Halifax Ave','Heidelberg','Victoria','AUSTRALIA','3084','0394405873','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 14:31:28',0,NULL,3,1,17,0,NULL,'ritanrob'),(17013,786110697017,270742402381,'New IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AA2201',5.48,'photographyacc','ritanrob','rstella1976@gmail.com','Robert Stella','6 Halifax Ave','Heidelberg','Victoria','AUSTRALIA','3084','0394405873','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-23 14:31:29',0,NULL,3,1,17,0,NULL,'ritanrob'),(17014,786110519017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','ritanrob','rstella1976@gmail.com','Robert Stella','6 Halifax Ave','Heidelberg','Victoria','AUSTRALIA','3084','0394405873','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-23 14:31:29',0,NULL,3,1,2,1,NULL,'ritanrob\rlenspen    1\r爵影红外 nikon     1\r绿叶 UV  52mm      1\r'),(17015,857277349015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','ssscid','cid@glocalnet.net','Rodrigo Cid','Travbanan 3','Tumba','Stockholm','SWEDEN','14734','+46 706683948','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 15:25:38',0,NULL,3,1,4,1,'YW866011920CN ','ssscid\r+白布\rbackground support  $20'),(17016,730149136018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',83,'photographyacc','licangelo','likangelo@yahoo.it','Hopeland di Bartolomeo Giuliano PI 03696360613','Via Vivaldi n°10','Marcianise','CE','ITALY','81025','3283829042','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 15:29:01',0,NULL,3,1,4,1,'YW866011894CN ','licangelo\r欧标\rlighting kit $20\r'),(17017,786140745017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','dfcorreia','forrepe@hotmail.com','Daniel Correia','51, Rue Raymond Losserand - Porte verte à droite.<br>DIGICODE: 96B13','Paris','Ile-de-France','FRANCE','75014','0672609642','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 15:47:31',0,NULL,3,1,2,1,NULL,'dfcorreia'),(17018,786152382017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',52,'photographyacc','hesy1','hesy@telenet.be','Werner Heselmans','Kerkenbosstraat 1','Linden','','BELGIUM','3210','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 16:18:34',0,NULL,3,1,3,1,'RA184561380CN\r ','hesy1'),(17019,857302503015,250599398064,'62mm 62 Close Up  Macro Close-Up +8 Filter New',1,'AE3225',3.8,'hutongstore','9438jackshao2005','jackshao2005@yahoo.com.sg','Jacky Ong','Blk 26, #04-415, Chai Chee Road','default','','SINGAPORE','460026','64439438','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 16:19:23',0,NULL,3,1,11,1,NULL,'9438jackshao2005'),(17020,786162492017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','kriszfromtm','bozso.krisztian@gmail.com','Krisztian Bozso','Fay Ltp. 3.ep D. Lh. 2/10','Törökszentmiklos','Jasz-Nagykun-Szolnok','HUNGARY','5200','+36303382060','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 16:40:48',0,NULL,3,1,2,1,NULL,'kriszfromtm'),(17021,786184199017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','user5117','unknown20@aol.com','Franco Valerio Pelfort','2896 SW 144th Pl','Miami','FL','UNITED STATES','33175','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 17:31:38',0,NULL,3,1,1,1,'、 ','user5117'),(17022,839560544016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lillo2k1','monicarn@interfree.it','Saluzzi Domenico','Via Ausa 69','Coriano','Rimini','ITALY','47853','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 17:53:27',0,NULL,3,1,2,1,NULL,'lillo2k1'),(17023,770227773002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','elfachi','elgranfachi@hotmail.com','Martìn Fabian Gonzàlez Collazo','Daniel Muñoz 1982 esq. Repùblica','Montevideo','Montevideo','URUGUAY','11200','59899579685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 18:20:13',0,NULL,3,1,3,1,'RA184561036CN\r ','elfachi'),(17024,770233166002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','medic21347','paulas@ns.sympatico.ca','Paula Sutherland','10526 Hwy 103 Clyde River<br>P.O. Box 106, Clyde River','Shelburne County','NS','CANADA','B0W 1R0','(902) 637-2408','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'medic21347'),(17025,728040683001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','marina.turetsky','marina.tu@gmail.com','Marina Turetsky','Kaznelson 16/13','Azor','','ISRAEL','58016','972546300739','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 18:48:02',0,NULL,3,1,2,1,NULL,'marina.turetsky'),(17026,730245307018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','atav7344','nana77426@hotmail.com','antonio tavares','14 oak ridge dr','clinton','MA','UNITED STATES','01510-3126','(978) 618-9896','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 19:12:24',0,NULL,3,0,1,1,'、 ','atav7344\rxxl  (已入库）'),(17027,728069055001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','gilles_cochet1xz5','gilles.cochet@gmail.com','Gilles COCHET','1 rue jules ferry','Velizy Villacoublay','Île-de-France','FRANCE','78140','33139460463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 19:52:22',0,NULL,3,1,17,0,NULL,'gilles_cochet1xz5'),(17028,770271605002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',50.45,'hermeshine','gilles_cochet1xz5','gilles.cochet@gmail.com','Gilles COCHET','1 rue jules ferry','Velizy Villacoublay','Île-de-France','FRANCE','78140','33139460463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 19:56:43',0,NULL,3,1,3,1,'RA184561504CN ','gilles_cochet1xz5\rc以外  再发9个环+2个支架'),(17029,770297680002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','sukka_nen','jenni.lahtimaa@kotinet.com','Jenni Lahtimaa','Upseerinkatu 3 a 9','Oulu','','FINLAND','90130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 20:58:06',0,NULL,3,1,3,1,'RA184561022CN\r ','sukka_nen'),(17030,728102138001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jfarmer50','jan.sedlak@atlas.cz','Jan Sedlak','Nad Razakem 32','Prague','','CZECH REPUBLIC','14300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-23 21:17:13',0,NULL,3,1,2,1,NULL,'jfarmer50'),(17031,728109028001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','lampleyj','jlampley@rochester.rr.com','Jeannette Lampley','56 Ellicott St','Rochester','NY','UNITED STATES','14619-2057','(585) 749-8283','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-23 21:36:56',0,NULL,3,0,1,1,NULL,'lampleyj\r110v的  （ 已入库）'),(17032,857473460015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','sapon_ire','sapon_dream@yahoo.com','MOHAMMAD HOSSAIN','1O TULACH ARD<br>RAHOON','GALWAY','Galway','IRELAND','default','0857115771','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-23 21:41:29',0,NULL,3,1,2,1,NULL,'sapon_ire'),(17033,770332104002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','mitunya','planibel@gmail.com','Dmitry Deniskin','Samarkandskij blvd, 15-1-95','Moscow','','RUSSIAN FEDERATION','109507','+7(926) 666-8220','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-23 23:15:34',0,NULL,3,1,5,1,'CP238030943CN ','mitunya'),(17034,728145611001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','rrobert999','ricrobert@videotron.ca','Richard Robert','9695 de Chamerolles','Quebec','QC','CANADA','G2B5J5','(418) 842-4060','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-23 23:56:59',0,NULL,3,1,2,1,NULL,'rrobert999'),(17035,730347009018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','dinodamo','dinodamo@gmail.com','APOSTOLOU FOTIS','RODOY 12','PETROUPOLI','ATTIKI','GREECE','13231','2105013061','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 00:00:38',0,NULL,3,1,3,1,'RA184561172CN\r ','dinodamo'),(17036,730375276018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','gunwondergun','neek.nick@inbox.ru','Nikolaev Nikolay','st. 50 let VLKSM, 15/2, 9','Stavropol','Stavropol region','RUSSIAN FEDERATION','355040','+7(8652)726952','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 02:06:20',0,NULL,3,1,2,1,NULL,'gunwondergun'),(17037,730385556018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','sabrinaraven','travtravtrav@hotmail.com','Matthew Reid','46 Donna Avenue<br>Rochedale South','Brisbane','Queensland','AUSTRALIA','4123','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 02:57:08',0,NULL,3,1,2,1,NULL,'sabrinaraven'),(17038,786386063017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','auto-matic2','jeffrey.difabrizio@mail.mcgill.ca','Jeffrey Di Fabrizio','5104 46th street','Yellowknife','NT','CANADA','x1a 1l5','(867) 444-0095','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 03:53:00',0,NULL,3,1,2,1,NULL,'auto-matic2'),(17039,728191987001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','johndillinger6','graeme.hutton@btconnect.com','Graeme Hutton','2 Blairhill Place','Coatbridge','North Lanarkshire','UNITED KINGDOM','ML51PL','01236421700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 03:57:54',0,NULL,3,1,3,1,'RA184561345CN\r ','johndillinger6'),(17040,730404788018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','planetyumrobin','sales@planetyum.com.au','Robin Imms','33 Vernon Street','Greystanes','New South Wales','AUSTRALIA','2145','0296365598','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 04:50:06',0,NULL,3,1,3,1,'RA184561169CN\r ','planetyumrobin'),(17041,857595587015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','petercoster','dragonslairfilms@yahoo.co.uk','peter  coster','4 chestnut way','bramley','Surrey','UNITED KINGDOM','GU5 0JB','01483893589','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184561257CN\r ','petercoster'),(17042,857599473015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','jun1920','paulcathrussell@gmail.com','Paul Russell','Peacehaven, Little quob Lane<br>WEST END','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO30 3GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 05:47:07',0,NULL,3,1,2,1,NULL,'jun1920'),(17043,786412797017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','peterrussi','fiddly.welds@bigpond.com.au','Peter Russi','186 Mooroondu Rd','Thorneside','Queensland','AUSTRALIA','4158','0413627227','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 05:57:47',0,NULL,3,1,2,1,NULL,'peterrussi'),(17044,730419329018,280666919433,'New Neoprene Camera Cover for Canon 550D+18-55mm',1,'AC1305',7.99,'photographyacc','katyjanered','cathiemc@iprimus.com.au','Cathie McNamara','3 Summerhill Rd<br>West Hobart','Hobart','Tasmania','AUSTRALIA','7000','0362347171','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 06:09:44',0,NULL,3,1,2,1,NULL,'katyjanered\r没有logo的'),(17045,728219683001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','bigdeal195310','bigdeal1953@gmail.com','IOSI MARCU','HAZAIT ST-20','ORANIT','israel','ISRAEL','44813','050-6801372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 06:55:56',0,NULL,3,1,2,1,NULL,'bigdeal195310'),(17046,786429424017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','benproc','benproc@internode.on.net','Ben Proctor','1/48 Sternberg St','Kennington','Victoria','AUSTRALIA','3550','0407867139','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 07:20:54',0,NULL,3,1,2,1,NULL,'benproc'),(17047,728236329001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','sam34290','samirquarcia81@msn.com','samir quarcia','les 4 vents chemins des serres','montblanc','Languedoc-Rousillon','FRANCE','34290','0467390291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 08:11:13',0,NULL,3,1,3,1,'RA184561067CN\r ','sam34290'),(17048,730446352018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','fozziebearpeter','p_fozzie@hotmail.com','Peter Foster','51 Greenville Drive<br>Grovedale','Geelong','Victoria','AUSTRALIA','3216','0352438770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-24 08:14:58',0,NULL,3,1,2,1,NULL,'fozziebearpeter'),(17049,770453212002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','buster04181','r.tiemann@gmx.net','Rainer Tiemann','Hermann-Burgdorf-Str. 64','Buchholz','','GERMANY','21244','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-24 08:56:13',0,NULL,3,0,3,1,'RA184561328CN\r ','buster04181\rL  已入库'),(17050,786458140017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',3,'AE1302',29.4,'photographyacc','llorco','cllorco@gmail.com','Llorenç Conejo','Gran Vía Corts Catalanes, 697,, 2º1ª<br>Barcelona','Barcelona','Cataluña','SPAIN','08013','607110069','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 09:10:49',0,NULL,3,1,17,0,NULL,'llorco'),(17051,730461431018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',39,'photographyacc','llorco','cllorco@gmail.com','Llorenç Conejo','Gran Vía Corts Catalanes, 697,, 2º1ª<br>Barcelona','Barcelona','Cataluña','SPAIN','08013','607110069','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 09:13:46',0,NULL,3,1,3,1,'RA184561420CN\r ','llorco\r单灯头  欧标     3\r45w 5500k 灯泡 220v     4\r'),(17052,728269712001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','pablovanwetten1975','pablovanwetten@gmail.com','LUNGOCCINO','Heisteeg 5','Amsterdam','','NETHERLANDS','1012 WC','0642120759','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-24 10:24:27',0,NULL,3,1,3,1,'RA184561155CN\r ','pablovanwetten1975'),(17053,730486688018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','dashmore777','david.ashmore@gmail.com','hee joung Yoon','6 pedder court','petrie','Queensland','AUSTRALIA','4502','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-24 10:45:20',0,NULL,3,1,2,1,NULL,'dashmore777'),(17054,857698737015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','rimutiaaa','promopocket@gmail.com','Rima Ozelyte','Siloju g. 48<br>Traksedziai','Silute','','LITHUANIA','99104','0037063633749','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-24 11:22:30',0,NULL,3,1,5,1,'CP238030912CN ','rimutiaaa\r欧标'),(17055,728300820001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','peterbreivik','breivik.peter@gmail.com','Peter Breivik','Bergsligata 7','Trondheim','','NORWAY','7018','0047 474 18 617','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 12:13:34',0,NULL,3,1,4,1,'YW866011905CN ','peterbreivik\rreflector  $20'),(17056,839934426016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','jensfridesjo','peacelake87@msn.com','Jens Fridesjö','jägargatan 11','Boden','Norrbotten','SWEDEN','96167','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-24 12:39:37',0,NULL,3,1,3,1,'RA184561875CN ','jensfridesjo'),(17057,728317809001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','alkidiri','kegome2003@yahoo.com','Ahmed ALKHUDHARY','Kuwait Mubareek Alkabeer<br>mailbox: AL - QOSOOR, P:OBOX: 563, c/o 47406','kuwait','kwt','KUWAIT','47406','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 13:08:41',0,NULL,7,0,18,0,NULL,'alkidiri\r'),(17058,728331763001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','cancan4141','erolyilmaz4141@gmail.com','erol yılmaz-yaşar pekçevik','sera çiçekevi<br>karabaş mah.leyla atakan cad.no:16 -İzmit','KOCAELİ','KOCAELI','TURKEY','41300','05418204141','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 13:49:39',0,NULL,3,1,2,1,NULL,'cancan4141'),(17059,857764844015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','apleaple78','apleaple@gmail.com','Dainis Birznieks','14 Broadleaf<br>Broad Street','Limerick','Limerick','IRELAND','default','0872844341','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 14:08:04',0,NULL,3,1,3,1,'RA184560999CN\r ','apleaple78'),(17060,857766257015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','jsua4160','yhunsuarez@yahoo.co.uk','Joani Suarez','Flat 6 Grand Union House<br>156 Ratcliffe Road','Loughborough','Leicestershire','UNITED KINGDOM','LE11 1LH','07766397884','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 14:11:36',0,NULL,3,1,2,1,NULL,'jsua4160'),(17061,728349879001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','sam8d','dsamare@gmail.com','D. Samarasinghe','114/4, Gunalankara Mw.<br>Saranankara Road','Kalubowila - Dehiwala','Western','SRI LANKA','10350','011942731162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 14:44:10',0,NULL,3,1,3,1,'RA184561115CN\r ','sam8d'),(17062,8881316875975364,111,'单灯头上一个螺丝（徐远方有）',1,'',0,'hutongstore','wockerjabb','genieysjp2@hotmail.com','Jean-Philippe Genieys','27 rue Haxo','Paris','IDF','FRANCE','75020','',NULL,NULL,NULL,'2011-09-24 14:52:55',0,NULL,3,1,3,1,'RA184561005CN\r ',NULL),(17063,857790120015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','activat20','alansaunders099@googlemail.com','A  Saunders','108 Rowner Road','Gosport','Hampshire','UNITED KINGDOM','PO13 9RG','07809695297','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-24 15:04:10',0,NULL,3,1,3,1,'RA184561274CN\r\r ','activat20'),(17064,728357784001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','a.saksonov','asaksonov@gmail.com','Андрей Саксонов','ул. Карла Либкнехта, д.3 кв.8<br>ул. Карла Либкнехта, д.3 кв.8','Ульяновск','Ульяновская область','RUSSIAN FEDERATION','432017','(927) 8156878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 15:05:43',0,NULL,3,1,3,1,'RA184561566CN ','a.saksonov'),(17065,728371817001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jjd821','kmartgirl8@aol.com','Jeanette J. Dick','2986 Bay St','Sarasota','FL','UNITED STATES','34237','(941) 330-9674','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 15:38:39',0,NULL,3,0,1,1,NULL,'jjd821\r黑色'),(17066,857865581015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','cmgrafics','chris.sammut@maltanet.net','Christopher Sammut','16, Villa Ichang,<br>Mos Alfredo Mifsud str.','Ta\'Xbiex XBX 1063','','MALTA','xbx 1063','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 17:28:43',0,NULL,3,1,2,1,NULL,'cmgrafics'),(17067,857457170015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',66.95,'hutongstore','dp341','daniel@pendery.org','Daniel Pendery','7 Elland Road<br>Churwell','Leeds','West Yorkshire','UNITED KINGDOM','LS277SY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 17:51:16',0,NULL,3,1,4,1,'YW866011872CN ','dp341\r反光板支架     1\r新款大力夹 手柄    1\r110cm 反光伞    1\r大号灰卡    1\r倒影板      1\r已入库\r\r'),(17068,728429269001,110531022936,'3ft Universal TTL Off camera Cord  Canon/Nikon/Pentax',1,'AB3319',18.5,'hermeshine','mephotographer','mephotographer1@yahoo.com','Jeff Robey','307 N Broad St','lancaster','OH','UNITED STATES','43130-3004','(740) 654-6527','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 17:54:14',0,NULL,3,1,1,1,NULL,'mephotographer'),(17069,730646212018,280680853908,'JYC-C1 Wireless Remote Control for Canon 60D 550D 450D',1,'AA3203',18,'photographyacc','nisapat1','nisapat21usa@hotmail.com','Prasong Poolkhwan','Baan Suay Rim Suan 305 Moo 6 Pornprapanimit 16<br>Baan Suay Rim Suan 305 Moo 6 Pornprapanimit 16','Nongplue , Banglamung','Chon - Buri , Thailand','THAILAND','20150','(038) 730-740','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 18:00:19',0,NULL,3,1,2,1,NULL,'nisapat1'),(17070,857910852015,250600470828,'18% Gray card set 8x6\" 6x4\" for White balance exposure',1,'AA2217',6.75,'hutongstore','rimantas82','rimtar@gmail.com','Rimantas Tarvydas','vingio 15-2','Klaipeda','','LITHUANIA','95196','8-600-12745','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-24 18:46:33',0,NULL,3,1,2,1,NULL,'rimantas82'),(17071,770660482002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','pampulito','mc.icnusa@gmail.com','Sergey Savostchenko','Zhumabaeva 28 f. 1','Almaty','Kazakhstan','KAZAKHSTAN','050037','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 18:46:57',0,NULL,3,1,2,1,NULL,'pampulito'),(17072,728480514001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','caled0n','kjetilnordaas@gmail.com','Kjetil Nordaas','616 Corporate Way<br>Ste 2-3602','Valley Cottage','NY','UNITED STATES','10989-2044','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 19:43:35',0,NULL,3,1,3,1,'RA184561305CN\r ','caled0n\r新地址：\rKjetil Nordaas\rHaugavegen 34\rStraume\rNORWAY\r'),(17073,728483927001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',3,'AA1306',7.8,'hermeshine','rwed19','rwedinger@aol.com','richard wedinger','11 devonshire cot.','middletown','NJ','UNITED STATES','07748','(201) 333-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-24 19:53:47',0,NULL,3,1,1,1,NULL,'rwed19'),(17074,786724474017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','pboruta10','pavelboruta@photopb.cz','Pavel Bořuta','za humny 309','Zlín','Kostelec','CZECH REPUBLIC','763 14','721370094','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 20:11:25',0,NULL,3,1,2,1,NULL,'pboruta10'),(17075,728498034001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','urechesandu78','urechesandu@yahoo.com','Alexandru Ureche','str. Alba-Iulia 3, apt. 93','Chisinau','','MOLDOVA, REPUBLIC OF','2051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 20:25:44',0,NULL,3,1,2,1,NULL,'urechesandu78'),(17076,770738250002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','yosicom','yosi_gruber@yahoo.com','Joseph Gruber','Hashomer 16','Kiriat Bialik','Haifa','ISRAEL','27237','972522419040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-24 21:51:18',0,NULL,3,1,3,1,'RA184561288CN\r ','yosicom'),(17077,858008603015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','closet2k7','rudeboyb8@aol.com','Shazaan Ali Visualise Studio','28 Ellesmere Road','Birmingham','Co','UNITED KINGDOM','B8 1NG','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-24 21:52:40',0,NULL,3,1,3,1,'RA184560910CN\r ','closet2k7'),(17078,786781251017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','nbelancic','nbelancic@gmail.com','Nikola Belancic','Put Petrovca 7','Sinj','CRO','CROATIA','21230','0038521 822 835','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 22:42:07',0,NULL,3,1,17,0,NULL,'nbelancic'),(17079,730772604018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','nbelancic','nbelancic@gmail.com','Nikola Belancic','Put Petrovca 7','Sinj','CRO','CROATIA','21230','0038521 822 835','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-24 22:42:08',0,NULL,3,1,2,1,NULL,'nbelancic\r眼罩 450D/500D   1\r3片装的滤镜袋       2'),(17080,858031937015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','dave_borth','dave.borthwick@btinternet.com','Dave J Borthwick','84 London Rd','IPSWICH','Suffolk','UNITED KINGDOM','IP1 2HE','07772074279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-24 22:59:05',0,NULL,3,1,3,1,'RA184561190CN\r ','dave_borth'),(17081,728595931001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','luigui676','luigui676@hotmail.com','luigui','195 w arden ln','round lake','il','UNITED STATES','60073-5658','(847) 236-0000','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 02:25:01',0,NULL,3,1,3,1,'RA184560923CN\r ','luigui676\r▲小包挂号查到这-max'),(17082,8881316919634768,111,'canon ttl 线   1m',1,'AB3321',0,'photographyacc','arielagu','ariel66@argentina.com','Ariel Marconi','Prilidiano Pueyrredon 2989 PB F1','Martinez','Buenos Aires','ARGENTINA','1640','(5411)4721-6282',NULL,NULL,NULL,'2011-09-25 03:00:34',0,NULL,3,1,3,1,'RA184561393CN\r ',NULL),(17083,730839969018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','fumiyasam','samkoek75@hotmail.com','Wah Onn Koek','1 Flemming Ave, Maribyrnong','Melbourne','Victoria','AUSTRALIA','3032','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 03:12:48',0,NULL,3,1,2,1,NULL,'fumiyasam'),(17084,786871007017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','tmtf70','teenasix@bigpond.com.au','Teena Thompson','313 Cullendulla Drive','Longbeach','New South Wales','AUSTRALIA','2536','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 04:46:57',0,NULL,3,1,17,0,NULL,'tmtf70'),(17085,730857886018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','tmtf70','teenasix@bigpond.com.au','Teena Thompson','313 Cullendulla Drive','Longbeach','New South Wales','AUSTRALIA','2536','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 04:46:57',0,NULL,3,0,2,1,NULL,'tmtf70\r爵影红外 canon   1\r1.6*2.1黑色背景布  1'),(17086,728621803001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','kwi16377','zosick16377@yahoo.com','ESSA DASHTI','18221 150th Ave<br>KWI 26851','Springfield Gardens','NY','UNITED STATES','11413-4010','(718) 553-8740','NoPaymentFailure','CheckoutComplete','Other','2011-09-25 04:50:42',0,NULL,3,1,1,1,NULL,'kwi16377\r已入库'),(17087,786874266017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',2,'AA1306',5,'photographyacc','rudvput','rudvput@hetnet.nl','RJP van Putten','Zwedenburg 87','Den Haag','','NETHERLANDS','2591BB','(070) 3355517','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 05:03:40',0,NULL,3,1,17,0,NULL,'rudvput'),(17088,786874680017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',2,'AA1305',5,'photographyacc','rudvput','rudvput@hetnet.nl','RJP van Putten','Zwedenburg 87','Den Haag','','NETHERLANDS','2591BB','(070) 3355517','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 05:06:03',0,NULL,3,1,2,1,NULL,'rudvput\rNIKON 镜头盖 62mm    2\rNIKON 镜头盖 52mm   2'),(17089,728630901001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',33.99,'hermeshine','2680brett','bhansbauer@cinci.rr.com','Brett Hansbauer','8137 Country Oaks Sta','West Chester','OH','UNITED STATES','45069-2770','(513) 779-6669','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-25 05:48:04',0,NULL,3,1,3,1,'RA184561447CN\r ','2680brett'),(17090,786886358017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','chapz10','chap.z@live.com','Brandon Chappell','2 vienna avenue<br>Aberfoyle park','Adelaide','South Australia','AUSTRALIA','5159','61412111639','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-25 06:11:31',0,NULL,3,1,4,1,'YW866011883CN ','chapz10'),(17091,786889917017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','arnold_sangalang','sangalang_arnold@yahoo.com.au','Arnold Sangalang','65 Kolodong Dr','Quakers Hill','New South Wales','AUSTRALIA','2763','0298377268','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 06:29:43',0,NULL,3,1,3,1,'RA184561362CN\r ','arnold_sangalang'),(17092,728390741001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','sergkomp2010','sergkomp@gmail.com','Sergey Kompaneetc','Lyzhnaya st., house 7, flat 19','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185011','89114258616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 06:44:20',0,NULL,3,1,5,1,'CP238030926CN ','sergkomp2010'),(17093,730890104018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','thelordhybrid','johnblackstar@msn.com','Alexander English Jr','1539 N Bronson Apartment 20','Hollywood','CA','UNITED STATES','90028','(803) 319-8451','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 07:29:30',0,NULL,3,1,4,1,'YW866011850CN ','thelordhybrid'),(17094,786942751017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','tyler_henley','tyler.henley@live.com.au','Tyler Henley','12 Ninnis Court','Greenwith','South Australia','AUSTRALIA','5125','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 09:16:31',0,NULL,3,1,2,1,NULL,'tyler_henley'),(17095,858215765015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','wojtek_puchatek','wojtekwilczynski@yahoo.co.uk','Mark Wilczynski','5 Melville Avenue','Greenford','London','UNITED KINGDOM','ub6 0lg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 09:35:55',0,NULL,3,1,2,1,NULL,'wojtek_puchatek'),(17096,770900621002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','foto14lexa','lea.hult@luukku.com','Lea Hult','Metsänhoitajankuja 1A 6','Vantaa','Oletus','FINLAND','01370','0500658717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 09:39:04',0,NULL,3,1,17,0,NULL,'foto14lexa'),(17097,730942304018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','ncoo2937','nicolecooperphotography@live.com.au','Nicole Cooper','39/30-34 Greenoaks Ave ','Cherrybrook','New South Wales','AUSTRALIA','2126','0299806172','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-25 09:56:44',0,NULL,3,1,2,1,NULL,'ncoo2937'),(17098,730943513018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','canon20man','casielover@gmail.com','paul  garcia','770 live oak ridge rd','nipomo','CA','UNITED STATES','93444-8859','(805) 406-4363','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 09:59:44',0,NULL,3,1,3,1,'RA184561107CN\r ','canon20man'),(17099,728705264001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','arcane2962','ralphru@gmail.com','Ralph Ruivivar','Commission on Population<br>Cabatangan','Zamboanga City','Zamboanga del Sur','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:09:40',0,NULL,3,1,17,0,NULL,'arcane2962'),(17100,728702034001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','arcane2962','ralphru@gmail.com','Ralph Ruivivar','Commission on Population<br>Cabatangan','Zamboanga City','Zamboanga del Sur','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:09:41',0,NULL,3,1,2,1,NULL,'arcane2962\r橡胶遮光罩 58mm    2\r绿叶 UV  58mm       1'),(17101,770923716002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','amadeos1971','yosefko@gmail.com','Yosi Koifman','Ha Vradim 8   / 3','Nesher','Israel','ISRAEL','36781','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:21:58',0,NULL,3,1,3,1,'RA184561291CN\r ','amadeos1971\r新式球台'),(17102,786971750017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','the-goof66','goof1966@gmail.com','Neil Bedford','8 Browne Street','Yarraman','Queensland','AUSTRALIA','4614','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 10:30:13',0,NULL,3,1,2,1,NULL,'the-goof66'),(17103,728714120001,110664971677,'GGS Glass LCD Screen Protector for Canon 50D 5DII',1,'AB2211',7.6,'hermeshine','foto14lexa','lea.hult@luukku.com','Lea Hult','Metsänhoitajankuja 1A 6','Vantaa','Oletus','FINLAND','01370','0500658717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 10:31:09',0,NULL,3,1,3,1,'RA184561084CN\r ','foto14lexa\r2 B 柔        1\rGGS 50D/5DII       1'),(17104,770965519002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','raymon.koko','raymonq@gmail.com','ramon portales auñon','luz casanova, 24-11','valencia','Valencia','SPAIN','46009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 12:05:53',0,NULL,3,1,11,1,NULL,'raymon.koko'),(17105,787019743017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','denisb4376','dboboskic@hotmail.com','Denis Boboskic','3/8 Mill St','Aspendale','Victoria','AUSTRALIA','3195','0415747032','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 12:18:08',0,NULL,3,1,17,0,NULL,'denisb4376'),(17106,731002658018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','denisb4376','dboboskic@hotmail.com','Denis Boboskic','3/8 Mill St','Aspendale','Victoria','AUSTRALIA','3195','0415747032','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 12:21:56',0,NULL,3,1,4,1,'YW866011861CN ','denisb4376\r反光板  80cm 5合1    1\r2m 灯架      1\r反光板支架     1'),(17107,840513532016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','carlojourdan','carlo.jourdan@gmail.com','Carlo','166, Estartit, San Michael Street','Fgura','Malta','MALTA','FGR 1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 12:42:26',0,NULL,3,1,2,1,NULL,'carlojourdan'),(17108,770983529002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','robertbookshop','robert@neco.cz','Robert Tichy','Hrbitovni 33','Pilsen','West Bohemia','CZECH REPUBLIC','31200','(00420)608826881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 12:50:23',0,NULL,3,1,3,1,'RA184561889CN ','robertbookshop'),(17109,771006769002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ha.dungle','xledh@yahoo.com','Ha Le','180 Bank Street','South Melbourne','Victoria','AUSTRALIA','3205','0401282336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 13:41:02',0,NULL,3,1,3,1,'RA184561040CN\r ','ha.dungle'),(17110,8881316959557674,111,'单灯头',1,'AE1302',0,'hermeshine','vahan2008','vahannersesyan@yahoo.com','Vahan Nersesyan','Nerkin Shengavit , street 4 , house 38','Yerevan','','ARMENIA','0074','',NULL,NULL,NULL,'2011-09-25 14:05:57',0,NULL,3,1,3,1,'RA184561226CN\r ',NULL),(17111,730847210018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','heasley1975','bheasley@optusnet.com.au','William Heasley','77 McConaghy Street<br>Mitchelton','Brisbane','Queensland','AUSTRALIA','4053','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 14:39:53',0,NULL,3,0,2,1,NULL,'heasley1975\r白色'),(17112,731076291018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','lmaudio','lukegm@bigpond.net.au','Luke Mulligan','26 Pyenna Avenue','Launceston','Tasmania','AUSTRALIA','7249','612419048350','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-09-25 14:57:55',0,NULL,3,1,4,1,'YW866011931CN ','lmaudio\r放柔光布'),(17113,728793423001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','genny0378','genevievearpin@hotmail.com','Geneviève Arpin','5340 Rivard','Ste-Catherine','QC','CANADA','J5C 1H3','(450) 633-1269','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 15:05:58',0,NULL,3,1,3,1,'RA184560968CN\r ','genny0378\r黑色、白色\r'),(17114,728885432001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 16:29:32',0,NULL,3,1,17,0,NULL,'leifs123'),(17115,771097115002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-25 16:29:33',0,NULL,3,1,5,1,'CP238030824CN','leifs123\r2m  灯架  2\r115w 5500k 灯泡  220v   4\r申报$35'),(17116,728895643001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','smajeric','sandi.majeric@gmail.com','Sandi Majeric','Zagrebacka 100','Prigorje Brdovecko','Prigorje Brdovecko','CROATIA','10291','00385915133910','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 16:42:14',0,NULL,3,1,2,1,NULL,'smajeric'),(17117,771110493002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','andr_ew2009','andr_ew@mail.ru','Andrew Mishakov','Nijnyaya Pervomaiskaya ul., dom 42, kv. 82','Moscow','','RUSSIAN FEDERATION','105203','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 16:52:02',0,NULL,3,1,2,1,NULL,'andr_ew2009\r欧标'),(17118,771118332002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',67.36,'hermeshine','ilya79','ilyapetrenko@yahoo.com','ilya petrenko','hanegev str 2/5','nahariya','','ISRAEL','22222','0544494807','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-25 16:57:51',0,NULL,3,1,3,1,'RA184560985CN\r ','ilya79\r1.6*2.1白色背景布   1\rRA184560971CN\r'),(17119,858490503015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','ltidltid','markcollinsifa@hotmail.com','Mark Collins','41 Narborough Road South','Leicester','Leicestershire','UNITED KINGDOM','LE3 2HB','07939007372','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-25 17:04:49',0,NULL,3,1,2,1,' ','ltidltid'),(17120,771138577002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',29.99,'hermeshine','joao_guarapari','srjoao@terra.com.br','João Batista Assis de Oliveira','Rua Cachoeiro de Itapemirim, nº 243<br>Belo Horizonte (Meaipe)','Guarapari','Espirito Santo','BRAZIL','29208-230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 17:21:37',0,NULL,3,1,3,1,'RA184561212CN\r ','joao_guarapari'),(17121,858012407015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','fitoreta','mersaultenlamarsalada@gmail.com','DISAUT Mar Fitor','C/Magallanes, Local 2','Sant Joan d\'Alacant','Comunidad Valenciana','SPAIN','03550','676523537','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 17:31:50',0,NULL,3,1,2,1,NULL,'fitoreta'),(17122,858539427015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','kris_papiez25','kris_papiez@wp.pl','Krzysztof Papiez','64 Dunsinane Drive','Perth','Perthshire and Kinross','UNITED KINGDOM','PH1  2DY','07897289903','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-25 17:49:31',0,NULL,3,1,2,1,NULL,'kris_papiez25'),(17123,731240073018,280667758840,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.88,'photographyacc','pal996','pal996@maltanet.net','John Joseph Pace','Pace Associates Ltd<br>134, Stefano Zerafa Street','Marsa','Marsa','MALTA','HMR03','99441617','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 18:27:26',0,NULL,3,1,17,0,NULL,'pal996'),(17124,731239451018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT076',53,'photographyacc','pal996','pal996@maltanet.net','John Joseph Pace','Pace Associates Ltd<br>134, Stefano Zerafa Street','Marsa','Marsa','MALTA','HMR03','99441617','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 18:27:26',0,NULL,3,1,3,1,'RA184561416CN\r ','pal996\r除了c 里面的再发\r方形滤镜接口环 52mm    1  \r 方镜广角托架（ 一槽）  1\r方形滤镜接口环 58mm    1'),(17125,731239659018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','pal996','pal996@maltanet.net','John Joseph Pace','Pace Associates Ltd<br>134, Stefano Zerafa Street','Marsa','Marsa','MALTA','HMR03','99441617','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 18:27:27',0,NULL,3,1,17,0,NULL,'pal996'),(17126,731239856018,280667759184,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',3.88,'photographyacc','pal996','pal996@maltanet.net','John Joseph Pace','Pace Associates Ltd<br>134, Stefano Zerafa Street','Marsa','Marsa','MALTA','HMR03','99441617','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 18:27:27',0,NULL,3,1,17,0,NULL,'pal996\r'),(17127,729010185001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','dumontco','dumontco@hotmail.com','John    Dumont','5965 Lake Hennessy Ct','San Jose','CA','UNITED STATES','95123-2471','(408) 398-0666','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-25 18:50:15',0,NULL,3,1,1,1,NULL,'dumontco'),(17128,728715358001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mr.sumaila','patrick_pabai@hotmail.com','Patrick S Pabai','Bjørndalsskogen 45<br>5171','Loddefjord','Loddefjord','NORWAY','5171','+4790192290','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 19:05:44',0,NULL,3,0,2,1,NULL,'mr.sumaila\r1.6*2.1黑色背景布     1'),(17129,858648534015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','markcarrherts','markterrimba@aol.com','Mark Siegieniewicz','101, Overstone Road','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 5PL','01582620357','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 19:24:09',0,NULL,3,0,17,0,NULL,'markcarrherts'),(17130,729041761001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',5,'AB3330',13,'hermeshine','3strada','josee@net-cid.com','Jose Luis Estrada','8121 20th St','Westminster','CA','UNITED STATES','92683-3235','(714) 472-1292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-25 19:27:46',0,NULL,3,1,1,1,NULL,'3strada'),(17131,858645393015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','iveinbergs1','iveinbergs@inbox.lv','Ilvars Veinbergs','3 Bodmin grove','Birmingham','West Midlands','UNITED KINGDOM','B74PG','07955203710','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 19:25:50',0,NULL,3,1,3,1,'RA184561053CN\r ','iveinbergs1'),(17132,858640644015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','markcarrherts','markterrimba@aol.com','Mark Siegieniewicz','101, Overstone Road','Harpenden','Hertfordshire','UNITED KINGDOM','AL5 5PL','01582620357','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 19:16:32',0,NULL,3,1,2,1,NULL,'markcarrherts\r橡胶遮光罩 67mm   1\r1.6*2.1黑色背景布    1'),(17133,858644720015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','dementedway','micaelopt@gmail.com','Ricardo Marques','Rua António Sérgio número 740 1º direito Custóias','Matosinhos','Porto','PORTUGAL','4460-679','351916484114','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-25 19:20:27',0,NULL,3,1,2,1,NULL,'dementedway'),(17134,771270327002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','mizio62','mauriziobaudo@virgilio.it','Sirio Brunetti','Via di Monteverde, 4','Roma','RM','ITALY','00152','339-5769172','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 19:47:22',0,NULL,3,1,3,1,'RA184561186CN\r ','mizio62\r欧标    Light Stand   $15'),(17135,731302246018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','thaihandicraft2010','sincehot@gmail.com','Widhit Luengwitayakorn','28 Malonga Drive','Burnie','Tasmania','AUSTRALIA','7320','0487807291','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-25 19:48:23',0,NULL,3,1,2,1,NULL,'thaihandicraft2010'),(17136,771304918002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','albertamar','aalbert2@walla.com','albert amar','coresh 19/15','afula','IL','ISRAEL','18310','972506614463','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 20:40:38',0,NULL,3,1,3,1,'RA184561141CN\r ','albertamar'),(17137,729115354001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','poutchiedugas','s.dugas@hotmail.com','Sylvie Dugas','5655 route 340','Haut-Paquetville','NB','CANADA','E8R 1T1','(506) 764-5521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 21:31:09',0,NULL,3,1,3,1,'RA184561075CN\r ','poutchiedugas\r绿色、棕色'),(17138,840955760016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',62,'hutongstore','edwaed698','e.connolly53@ntlworld.com','edward  connolly','39 arthur ave','newtownabbey','Antrim','UNITED KINGDOM','BT367EJ','07931130700','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-25 21:54:31',0,NULL,3,1,4,1,'YW866011942CN ','edwaed698\r放柔光布'),(17139,858744940015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','vegasminimalist','photography@laymond.com','anne-cecile laymond','19B Sutherland Avenue','London','London','UNITED KINGDOM','w9 2he','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-25 22:19:44',0,NULL,3,1,3,1,'RA184561265CN\r ','vegasminimalist\r放柔光布'),(17140,787433661017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',2,'AD1190',32,'photographyacc','schoen-old-toys','bradforttt@yahoo.de','Matthias Schoen','Buchholzerstrasse 43','Burg in Dithmarschen','','GERMANY','25712','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-25 22:29:38',0,NULL,3,1,2,1,NULL,'schoen-old-toys'),(17141,771355947002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','juji_gatame','surikonde@yahoo.fr','Viu-Yiep KONG','16, rue Henri Janin','Valenton','Ile-de-France','FRANCE','94460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-25 22:37:21',0,NULL,3,1,3,1,'RA184561243CN\r ','juji_gatame\r放布'),(17142,729038509018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','rodangib76','rodangib@gmail.com','Rodrigo Gibson','8/33 Waugh Street','Port Macquarie','New South Wales','AUSTRALIA','2444','0421968478','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-25 22:49:22',0,NULL,3,1,2,1,NULL,'rodangib76'),(17143,728286255001,110562231928,'Camera shoulder bag nova 4 with raincover 4 D300s D700',1,'AD1105',40.99,'hermeshine','stroev_2009','stroev@stroev.ru','Yury Stroev','Palchevskogo, 33','Vladivostok','','RUSSIAN FEDERATION','690041','+79242444444','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 00:02:05',0,NULL,3,1,3,1,'RA184561376CN\r ','stroev_2009'),(17144,787211519017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',100,'photographyacc','battycola','faith_f2002@yahoo.com','Faith Frisby-Petrusevski','5132 W Warwick Ave','Chicago','IL','UNITED STATES','60641-3446','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 00:14:08',0,NULL,3,1,4,1,'YW866011835CN ','battycola'),(17145,731456076018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',4,'AA3314',28.8,'photographyacc','aussiebrewedbargains','aussiebrewedbargains@gmail.com','John Brewster','18 Cantala Cresent','Ringwood North','Victoria','AUSTRALIA','3134','0397615801','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 01:31:28',0,NULL,3,1,3,1,'RA184561637CN ','aussiebrewedbargains  投递不成功退回'),(17146,731467823018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','augywilangkara','augy_wilangkara@yahoo.com','Augy Wilangkara','29 Scribbly Gum Sq.<br>Willetton','Perth','Western Australia','AUSTRALIA','6155','0427487399','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 02:07:15',0,NULL,3,1,4,1,'YW866011846CN ','augywilangkara\r'),(17147,8881317004651927,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',23.99,'aliexpress','1004501895','leibenko@gmail.com','Victor Leibenko	','Nikolay Himushina 3 corp.3 kv.51','Moscow','','RUSSIAN FEDERATION	','107143','+7 926 8160628',NULL,NULL,NULL,'2011-09-26 02:37:31',0,NULL,3,1,3,1,'RA117762168CN ','第一次的丢了，补发。（已减库）\r<第一次的单号和同时发的另外一票一样（RA184561455CN），客户收到另外一件东西，但其中没有2m灯架。据小王回忆，可能是单号录重了。>'),(17148,731478190018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','pando0151','pando151@gmail.com','paul pandoulis','45 the esplanade','drummoyne','New South Wales','AUSTRALIA','2047','0412929296','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 02:39:43',0,NULL,3,1,2,1,NULL,'pando0151'),(17149,8881317005944901,111,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',35.99,'aliexpress','1004501915','leibenko@gmail.com','Victor Leibenko	','Nikolay Himushina 3 corp.3 kv.51','Moscow','MO','RUSSIAN FEDERATION	','107143','+7 926 8160628',NULL,NULL,NULL,'2011-09-26 02:59:04',0,NULL,3,1,3,1,'RA184561455CN ',NULL),(17150,730817741018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','nikonwoman1947','nikonman@live.com.au','Dr R Johnson','5 Helena Street','Biggera Waters','Queensland','AUSTRALIA','4216','0412011140','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 04:37:33',0,NULL,3,0,3,1,'RA184561314CN\r ','nikonwoman1947\r2XL (已入库)  '),(17151,771469067002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','pakorntan2010','thanate191@aim.com','Thanate Tantiratapong','268/1 Rajwitti 19 Rd,<br>Vachira.','Dusit','Bangkok','THAILAND','10300','6696791239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 05:19:46',0,NULL,3,1,2,1,NULL,'pakorntan2010'),(17152,731512853018,280696883124,'New Pro Photo Vest for all DSLR fans Mesh-line ',1,'AA1217',24,'photographyacc','gmor6650','gracemorle@hotmail.com','grace morley','1/12 macleay street','potts point','New South Wales','AUSTRALIA','2011','0293577902','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 05:22:56',0,NULL,3,1,3,1,'RA184561331CN\r ','gmor6650'),(17153,771483292002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',2,'AA1309',5.2,'hermeshine','babb454','babb454@hotmail.com','Zachary Babb','3810 Kitt Dr','Helena','MT','UNITED STATES','59602-7322','(406) 461-9522','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 06:45:31',0,NULL,3,1,1,1,NULL,'babb454'),(17154,771487065002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',4,'AE3102',31.56,'hermeshine','stanislavgolovin','stanislavoice@gmail.com','Stanislav Golovin','haneurim st. 5','Herzelya','','ISRAEL','46308','9720546525212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 07:04:38',0,NULL,3,1,3,1,'RA184561359CN\r ','stanislavgolovin'),(17155,771493499002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','justaman_123','abaturin@gmail.com','Andrey Baturin','Libknehta st, 3-1','Ryazan','Ryazanskaya','RUSSIAN FEDERATION','390006','+79038355057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 07:35:50',0,NULL,3,1,2,1,NULL,'justaman_123'),(17156,729282999001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','claudiozamia','claudio.garlaschi@gmail.com','claudio garlaschi','via frua, 26','milano','MI','ITALY','20146','3487268026','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 08:29:05',0,NULL,3,1,3,1,'RA184561402CN\r ','claudiozamia\rbattery pack  $15'),(17157,787607052017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','nangapanda','jimmyt5000@yahoo.com','James Tapscott','1/182 Dundas St','Thornbury','Victoria','AUSTRALIA','3071','0466565148','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 09:22:15',0,NULL,3,1,2,1,NULL,'nangapanda'),(17158,787608285017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','rodnette_1','rodlynnat@gmail.com','Rod Richards','18 Nords Wharf Rd','Nords Wharf','New South Wales','AUSTRALIA','2281','0414925417','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 09:27:45',0,NULL,3,1,2,1,NULL,'rodnette_1'),(17159,731571074018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','kbka','isinsession@gmail.com','Kate Armstrong','Lvl 4<br>33 Alfred Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 09:58:38',0,NULL,3,1,2,1,NULL,'kbka'),(17160,729304535001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','chocfishau','ptgammell@optusnet.com.au','Paula Gammell','22 Parklands Avenue','Chirnside Park','Victoria','AUSTRALIA','3116','0397273647','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 10:01:45',0,NULL,3,1,2,1,NULL,'chocfishau'),(17161,771531705002,120505803042,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19.78,'hermeshine','bigears48','thecorps@bigpond.com','Mr Owen Corps','c/- Melbourne Pathololgy<br>103 Victoria Parade','Collingwood','Victoria','AUSTRALIA','3066','0425725334','NoPaymentFailure','CheckoutComplete','AU_Regular','2011-09-26 10:23:19',0,NULL,3,1,2,1,NULL,'bigears48\r澳标'),(17162,787641128017,270757371314,'Studio Light 900W Continuous Lighting Complete Kit  ',1,'AKT070',170,'photographyacc','cliffehanger07','simone.blum@bigpond.com','Simone Cliffe','24 Santa Monica Drive, Keilor Lodge','Melbourne','Victoria','AUSTRALIA','3038','0383616356','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-09-26 11:23:20',0,NULL,3,1,4,1,'YW866012034CN ','cliffehanger07\r澳标\rc 里面的不对  没有那些镜子'),(17163,859016687015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','anarinya10','anarinya10@hotmail.com','Sonia Ruano Moreno','virgen de begoña nº 2 3º A','toledo','Castilla-La Mancha','SPAIN','45006','645502760','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-26 11:36:19',0,NULL,3,1,17,0,NULL,'anarinya10'),(17164,859017087015,250606686795,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2202',2.75,'hutongstore','anarinya10','anarinya10@hotmail.com','Sonia Ruano Moreno','virgen de begoña nº 2 3º A','toledo','Castilla-La Mancha','SPAIN','45006','645502760','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 11:36:20',0,NULL,3,1,4,1,'YW866012045CN ','anarinya10\r三脚架 伟峰 wf-6662A+ 6160H 球台    1\r爵影红外 canon    1'),(17165,787647229017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','rmb806','dandar600@lizzy.com.au','Darren BELL','600 Mc Dowell Loop<br>Parkerville','Perth','Western Australia','AUSTRALIA','6081','0892955103','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 11:42:26',0,NULL,3,1,2,1,NULL,'rmb806'),(17166,729348584001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','topgor','topgor@teol.net','Goran Topic','Visokih Decana 11','Banjaluka','Republika Srpska','BOSNIA AND HERZEGOVINA','78000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 12:42:26',0,NULL,3,0,3,1,'RA184561535CN ','topgor\rXL 已入库'),(17167,729350833001,110531022936,'3ft Universal TTL Off camera Cord  Canon/Nikon/Pentax',1,'AB3319',18.5,'hermeshine','cassiusclay1','carlo_vilar@hotmail.com','Carlo Vilar','Unit 18<br>104 Springs Road','Clarinda','Victoria','AUSTRALIA','3169','0395512257','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 12:51:46',0,NULL,5,1,18,1,NULL,'cassiusclay1'),(17168,771583213002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5.2,'hermeshine','barry6701','barryjones33@btinternet.com','Barry Jones','Blinkbonny, Lyness','Stromness','Orkney','UNITED KINGDOM','KW16 3NY','01856791322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 13:23:16',0,NULL,3,1,2,1,NULL,'barry6701'),(17169,859061576015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','dartagnan1_fr','dartagnan1@free.fr','Eric SOUBIES','232 Montée de Tramoyes','La Boisse','Rhône-Alpes','FRANCE','01120','0478064181','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 13:33:57',0,NULL,3,1,2,1,NULL,'dartagnan1_fr'),(17170,771597436002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','jz1515','jz3@comcast.net','Amtek Tool','535 E 10 Mile Rd<br>Attn: Jon Zmudka','Madison Heights','MI','UNITED STATES','48071','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 14:07:24',0,NULL,3,1,3,1,'RA184561495CN ','jz1515'),(17171,0,120782011742,'New Battery for Pentax K10 K10D K20D D-Li50 / NP400 DLi50',1,'',5.25,'hermeshine','zydec0458','ts004i8599@blueyonder.co.uk','Gerard Small','12 Somerset Road','Willenhall','West Midlands','UNITED KINGDOM','WV132RY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 14:08:16',0,NULL,3,1,2,1,NULL,'zydec0458'),(17172,0,110746871724,'New Battery for Nikon EN-EL9 EN-EL9a ENEL9 ENEL9a D60 D40x',1,'',4.49,'hermeshine','casillas65','carpaumar@gmail.com','juan manuel casillas delgado','calle universidad hispalense 8','osuna','SEVILLA','SPAIN','41640','629017397','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 14:11:01',0,NULL,3,1,2,1,NULL,'casillas65'),(17173,731649901018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',5.9,'photographyacc','dimitrios662','d.mavrakakis@yahoo.gr','DIMITRIOS MAVRAKAKIS','MANAROLI 5','GREECE','CHANIA- CRETE','GREECE','73100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 14:19:25',0,NULL,3,1,2,1,NULL,'dimitrios662'),(17174,771610377002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','egub3498','eliso45@yahoo.com','Eliso Gubeladze-Mergen','1513 Essex ct','Toms River','NJ','UNITED STATES','08755','(732) 644-6525','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-26 14:46:38',0,NULL,3,1,1,1,NULL,'egub3498'),(17175,859093604015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',8,'AA1301',15.04,'hutongstore','yo1415','yo51@free.fr','Yves OLIVARI','300 Route du Barri','ASPREMONT','Provence-Alpes-Côte d\'Azur','FRANCE','06790','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-26 15:15:54',0,NULL,3,1,3,1,'RA184561518CN ','yo1415'),(17176,731672299018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','illumsell','poschoice@optusnet.com.au','R Turner & J Collins Turner','PO Box 1090','Stafford','Queensland','AUSTRALIA','4053','0403003344','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-26 15:23:28',0,NULL,3,1,2,1,NULL,'illumsell'),(17177,729403787001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','eugene.kv','eugene.khruschev@gmail.com','Eugene Khruschev','Ulica Geroev Panfilovcev, dom 3, kv. 75','Moscow','','RUSSIAN FEDERATION','125480','79851600163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 15:32:34',0,NULL,3,1,2,1,NULL,'eugene.kv'),(17178,729378631001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-26 15:37:47',0,NULL,3,1,1,1,NULL,'revikom'),(17179,731608744018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','berndkorteling','bkorteling@gmail.com','Bernd Korteling','Oude Langendijk 8','Delft','','NETHERLANDS','2611GK','0652350443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:04:15',0,NULL,3,1,17,0,NULL,'berndkorteling'),(17180,787654393017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','berndkorteling','bkorteling@gmail.com','Bernd Korteling','Oude Langendijk 8','Delft','','NETHERLANDS','2611GK','0652350443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:04:15',0,NULL,3,1,17,0,NULL,'berndkorteling'),(17181,787655318017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','berndkorteling','bkorteling@gmail.com','Bernd Korteling','Oude Langendijk 8','Delft','','NETHERLANDS','2611GK','0652350443','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:04:16',0,NULL,3,0,3,1,'RA184561606CN ','berndkorteling\r眼罩 40D/50D     2\r还有9个环+两种托架  '),(17182,729420124001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','oficheck','oficheck@gmail.com','Miguel Labrador Anton','Honda 1','Herencia','Ciudad Real','SPAIN','13640','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 16:15:02',0,NULL,3,1,4,1,'YW866011990CN ','oficheck'),(17183,731702840018,280688523982,'High Quality Umbrella Softbox Reflector Studio 35\" 90cm',1,'AD1127',22.9,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:05',0,NULL,3,1,17,0,NULL,'kjetilbm'),(17184,731703171018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:04',0,NULL,3,1,17,0,NULL,'kjetilbm'),(17185,731702362018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:05',0,NULL,3,1,17,0,NULL,'kjetilbm'),(17186,731698386018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:06',0,NULL,3,1,3,1,'RA184561950CN ','kjetilbm\r反光板 100*150 40*60 5合1     1\r反光板 60cm 2合1     1\r挪威不能发一票两件'),(17187,787751880017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:07',0,NULL,3,1,17,0,NULL,'kjetilbm'),(17188,731701374018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:07',0,NULL,3,1,17,0,NULL,'kjetilbm'),(17189,787751534017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',2,'AB3314',13.38,'photographyacc','kjetilbm','kbm@epost.no','Kjetil B Mathisen','Nedre Goslia 1','Lommedalen','','NORWAY','N-1350','+4790025408','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 16:56:08',0,NULL,3,1,4,1,'YW866012071CN ','kjetilbm\r反光伞棚90cm     1\r灯架  2m   1\r闪光灯D座     1\r万用遮光罩      2\r反光伞     1\r挪威不能发一票两件\r\r'),(17190,787763839017,270751505051,'YongNuo Flash Battery Pack for Nikon SB800 SD-8A /8AA',1,'AB3309',52,'photographyacc','urgyen_digital','urgyenlhawong@hotmail.com','Karma Choekyi','Milchbuckstrasse 3','zürich','','SWITZERLAND','8057','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 17:01:21',0,NULL,3,1,3,1,'RA184561521CN ','urgyen_digital'),(17191,729453741001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','moto4876','vanko.st@gmail.com','Ivan Ivanov','Bulgarka; bldg 16; fl 12; app. 60','Sliven','','BULGARIA','8800','359898603040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 17:31:41',0,NULL,3,1,2,1,NULL,'moto4876'),(17192,787780744017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','sholami23','s.mollame@shaw.ca','Connie Mollame','55 Oryme Avenue','Sault Ste. Marie','ON','CANADA','P6B 4C2','(705) 942-7820','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 17:34:03',0,NULL,3,1,2,1,' ','sholami23'),(17193,771680441002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','foje3854','pocher@wanadoo.es','FRANCISCO OJEDA CHERTA','GRAN AVENIDA 305 VILLA 7','BENICASIM','Comunidad Valenciana','SPAIN','12560','615983229','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 17:41:18',0,NULL,3,1,3,1,'RA184561478CN ','foje3854'),(17194,729458025001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','aldagu','gubitosi@adinet.com.uy','Daniel Gubitosi','Paraguay 1068','Montevideo','','URUGUAY','11100','29015345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 17:44:38',0,NULL,3,0,3,1,'RA184561597CN ','aldagu\r4 x 52mm Nikon \r3 x 58mm Canon \r1 x 67mm Canon \r1 x 72mm Canon \r1 x 77mm Canon\r已入库'),(17195,0,120782009708,'New BP-511A BP511A Battery For Canon EOS 5D 40D 30D 50D',1,'',4.49,'hermeshine','polyab','paypal@bnet.hu','Balázs Pólya','Arató utca 4.','Budapest','Pest Megye','HUNGARY','1121','+36302242048','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 18:11:13',0,NULL,3,1,2,1,NULL,'polyab'),(17196,729486738001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','mrvicaval021','skymaster111@gmail.com','Goran Martinovic','Podceline 47<br>Strozanac','Podstrana','Splitsko-Dalmatinska','CROATIA','21312','092/1338585','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 18:34:29',0,NULL,3,1,3,1,'RA184561481CN ','mrvicaval021'),(17197,771717986002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','matsprest','mats_prestegard@hotmail.com','Mats Prestegård','Olav Kyrre Gate 5','Bryne','Rogaland','NORWAY','4340','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 18:52:34',0,NULL,3,1,17,0,NULL,'matsprest'),(17198,841444282016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','aglo5083','indiorc@gmail.com','Andre Gloria','36 Fernwood<br>Albert Drive, Southfields','Wimbledon','London','UNITED KINGDOM','SW19 6LR','07834988558','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-26 19:24:50',0,NULL,3,1,4,1,'YW866012001CN ','aglo5083\r英标\r'),(17199,787822846017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','deeneshen','incu_bus_17@yahoo.co.uk','Deeneshen Sabapathee','Mootoo Lane<br>Allee Brillant','Vacoas','','MAURITIUS','0000','+2304903234','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 19:36:21',0,NULL,3,1,2,1,NULL,'deeneshen'),(17200,729524836001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 19:44:43',0,NULL,3,1,2,1,NULL,'solsuny'),(17201,841468628016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','matsprest','mats_prestegard@hotmail.com','Mats Prestegård','Olav Kyrre Gate 5','Bryne','Rogaland','NORWAY','4340','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-26 20:02:20',0,NULL,3,1,3,1,'RA184561645CN ','matsprest\r柔光伞    2\r牛津布大包    1\r挂号便宜'),(17202,771755796002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','angelalovesbruce','bruce@purplehorse.ca','bruce jollimore','15 bonita drive','dartmouth','NS','CANADA','b2x 3a2','(902) 404-2989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:02:55',0,NULL,3,1,2,1,NULL,'angelalovesbruce'),(17203,771766337002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','feriddyusifoglu2011','daniel.m.gavin@gmail.com','Ferid Davudov','Xudu Mammadov 2944a, build 6, apt. 142','Baku','Xatai','AZERBAIJAN','AZ1123','(+99455)5801188','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-26 20:24:58',0,NULL,3,1,3,1,'RA184561464CN ','feriddyusifoglu2011'),(17204,771772487002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','paul-i-13','paul.ingham13@googlemail.com','Paul Ingham','7 Sellerdale drive<br>Wyke','Bradford','West Yorkshire','UNITED KINGDOM','BD12 9DA','07968824943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 20:36:30',0,NULL,3,1,2,1,NULL,'paul-i-13'),(17205,859117876015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','petharrypeter','ph.atkinson@yahoo.co.uk','Peter Atkinson','222 Blackhill Ave<br>Hadrian Park','Wallsend','Tyne and Wear','UNITED KINGDOM','NE28 9XR','01912635490','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-26 20:06:40',0,NULL,3,1,2,1,NULL,'petharrypeter'),(17206,771785449002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','kristina_pavlova','kristina_reklama@mail.ru','Pavlova Kristina','197 Stachki Ave., apt. 58','Rostov-on-Don','Russian Federation','RUSSIAN FEDERATION','344058','+79081822887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-26 21:05:19',0,NULL,3,1,2,1,' ','kristina_pavlova'),(17207,731845784018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','giorgioeb','giorgio.aulisio@gmail.com','Giorgio Aulisio','37, Rue Lafayette','Paris','Ile-de-France','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 21:10:55',0,NULL,3,1,17,0,NULL,'giorgioeb'),(17208,731844584018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',2,'AC2301',11.8,'photographyacc','giorgioeb','giorgio.aulisio@gmail.com','Giorgio Aulisio','37, Rue Lafayette','Paris','Ile-de-France','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 21:10:56',0,NULL,3,1,17,0,NULL,'giorgioeb'),(17209,771788169002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','cathyli27','cathyli@optonline.net','Cathy Kovarik','403 Starlight Dr','East Yaphank','NY','UNITED STATES','11967','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 21:12:19',0,NULL,3,1,1,1,NULL,'cathyli27'),(17210,731846635018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','giorgioeb','giorgio.aulisio@gmail.com','Giorgio Aulisio','37, Rue Lafayette','Paris','Ile-de-France','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 21:12:24',0,NULL,3,1,17,0,NULL,'giorgioeb'),(17211,731847844018,280673081875,'77mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 77 mm',1,'AB1307',5.09,'photographyacc','giorgioeb','giorgio.aulisio@gmail.com','Giorgio Aulisio','37, Rue Lafayette','Paris','Ile-de-France','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 21:15:18',0,NULL,3,1,3,1,'RA184561583CN ','giorgioeb\r大号内胆包 无字   2\r小号内胆包 无字   2\r橡胶遮光罩 77mm    1'),(17212,859335103015,250804357708,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',1,'AA1306',1.87,'hutongstore','genevieve1000','genevieverichardson@hotmail.com','Genevieve Richardson','7 Burlington Lodge<br>Lubbock rd.','Chislehurst','Kent','UNITED KINGDOM','BR7 5QR','2074882946','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-26 21:43:37',0,NULL,3,1,2,1,NULL,'genevieve1000'),(17213,731880368018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','09franni','serenityjane@live.com','Serenity Caldwell','167 Patchs bch Rd','Patchs Beach','New South Wales','AUSTRALIA','2478','0432664164','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,1,18,1,'','09franni'),(17214,731881499018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','spothandy-sandy','baznsan@bigpond.com','Sandra Johnston','12 Rouse Street','WORONGARY','Queensland','AUSTRALIA','4213','0755227000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 22:58:40',0,NULL,3,1,17,0,NULL,'spothandy-sandy'),(17215,787940473017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','spothandy-sandy','baznsan@bigpond.com','Sandra Johnston','12 Rouse Street','WORONGARY','Queensland','AUSTRALIA','4213','0755227000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 22:58:41',0,NULL,3,1,2,1,NULL,'spothandy-sandy\r新款内胆包 大号 canon logo    1\r镜头筒 xl 大号     1'),(17216,731883062018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','phayes1961','hayes1961@comcast.net','Paul Hayes','1366 Deerfield Rd','Washington','PA','UNITED STATES','15301','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-26 22:58:47',0,NULL,3,0,1,1,NULL,'phayes1961\rxxl  已入库'),(17217,787954025017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','mister_infinity','obfusk8@hotmail.com','Zen Durbidge','4/1A Prince Edward Street','Malabar','New South Wales','AUSTRALIA','2036','0424164048','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-26 23:41:10',0,NULL,3,1,2,1,NULL,'mister_infinity'),(17218,729611661001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',2,'AB1404',10.98,'hermeshine','valeron789','murkaukr@yahoo.com','valeriya kozlova','1176 queen st','clearwater','FL','UNITED STATES','33756-3221','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-26 23:54:29',0,NULL,3,1,1,1,NULL,'valeron789'),(17219,731897387018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','danehaseldine','fangz_nofriends@hotmail.com','Dane Haseldine','17 burgess st Hamersley','perth','Western Australia','AUSTRALIA','6022','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-26 23:57:47',0,NULL,3,1,2,1,' ','danehaseldine'),(17220,731904520018,280687532335,'Studio Light 1000W Continuous Lighting Complete Kit  ',1,'AKT005',182,'photographyacc','chop48','wayne@jcap.com.au','Wayne Owens','663 Waverley Road','Glen Waverley','Victoria','AUSTRALIA','3150','0417107595','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-09-27 00:25:59',0,NULL,3,1,4,1,'YW866012060CN ','chop48\r澳标'),(17221,731899921018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','bboy_nattee','endlessnatty@hotmail.com','Nathan Pinkerton','Unit 6 / 135 Russell St','Morley','Western Australia','AUSTRALIA','6062','61413726403','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 00:08:32',0,NULL,3,1,2,1,NULL,'bboy_nattee'),(17222,731916773018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','soulbrounder','julie1031@bigpond.com','Julie Phillips','3 Gore Street','Amity Point','Queensland','AUSTRALIA','4183','0734097949','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-09-27 01:06:50',0,NULL,3,1,4,1,'YW866012012CN ','soulbrounder'),(17223,729637108001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','toolsrus_melbourne','toolsrusaustralia@hotmail.com','TOOLS R US AUSTRALIA PTY LTD','821 NEPEAN HWY EAST BRIGHTON','MELBOURNE','Victoria','AUSTRALIA','3187','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 01:34:24',0,NULL,3,1,2,1,NULL,'toolsrus_melbourne'),(17224,729637721001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',71.98,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','Rua Sempre Viva 155/304<br>Privavera','Timoteo','Minas Gerais','BRAZIL','35182-446','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 01:49:32',0,NULL,3,1,5,1,'CP235627520CN ','elizeucine\r肩架     2  （已入库）\r---\r新地址：\rCleria Figueiredo Costa\rRua Sempre Viva, 155/304\rPrimavera, Timoteo, MG, Brazil\rCEP 35182-446'),(17225,729656164001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','cfwegman','cfwegman@earthlink.net','Charlie Wegman','6396 Burnt Poplar Ct<br>C.E. Smith Company','Greensboro','NC','UNITED STATES','27409-9710','(336) 908-7130','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-27 02:53:57',0,NULL,3,1,4,1,'YW866012152CN ','cfwegman'),(17226,788012094017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',4,'AC2305',23.92,'photographyacc','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dpto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','+5411 4718 3175','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 03:07:56',0,NULL,3,1,2,1,NULL,'gorrionsudaca\r申报gift'),(17227,859446410015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','arifinukk','a_oik@ymail.com','a islam','61 zetland street, london<br>london','london','London','UNITED KINGDOM','e146pr','02075156481','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 03:19:44',0,NULL,3,1,2,1,NULL,'arifinukk'),(17228,731951190018,280719730281,'New Flash Umbrella Holder Mount aluminum metal N',2,'AD1167',32,'photographyacc','tab.berger','t.berger@curtin.edu.au','Tabitha Berger','C/O Curtin University<br>GPO Box U1987','Perth','Western Australia','AUSTRALIA','6845','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 03:29:25',0,NULL,3,1,3,1,'RA184561549CN ','tab.berger'),(17229,731958374018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','est24','estherh08@optusnet.com.au','Esther Haberfield','24 Robertson Street','East Geelong','Victoria','AUSTRALIA','3219','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 03:58:42',0,NULL,3,0,17,0,NULL,'est24'),(17230,731958821018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','est24','estherh08@optusnet.com.au','Esther Haberfield','24 Robertson Street','East Geelong','Victoria','AUSTRALIA','3219','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 04:01:08',0,NULL,3,0,3,1,'RA184561552CN ','est24\r1.6*2.1黑色+白色'),(17231,788031138017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','5751jane','jane.eccleston@iinet.net.au','Jane  Eccleston','14 Morotai Crescent','Castlecrag','New South Wales','AUSTRALIA','2068','0299584893','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 04:40:12',0,NULL,3,1,2,1,NULL,'5751jane'),(17232,731967581018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','engineerroly','rolandwheeler@gmail.com','Roland Wheeler','16/11 Merlin Street','Neutral Bay','New South Wales','AUSTRALIA','2089','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 04:51:02',0,NULL,3,1,2,1,NULL,'engineerroly'),(17233,731969439018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','roo2b2','r.png@neura.edu.au','Reuben Png','Neuroscience Research Australia<br>Barker St','Randwick','New South Wales','AUSTRALIA','2031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 05:01:47',0,NULL,3,1,2,1,NULL,'roo2b2'),(17234,8881317103463947,111,'普通托架    1',1,'AA2215',0,'photographyacc','kabirsydney','kabirsydney@yahoo.com.au','AN Kabir Ahmed','16/77 Liverpool Road<br>Ashfield','Sydney','New South Wales','AUSTRALIA','2131','610413576607',NULL,NULL,NULL,'2011-09-27 06:04:23',0,NULL,3,1,3,1,'RA184561570CN ',NULL),(17235,8881317103963938,111,'4灯头+60x60棚 + 115w 220v x4',1,'',0,'hutongstore','houselinen_uk','robertorocco@tiscali.co.uk','Houselinen.co.uk','48 Thorpe rd','kingston upon thames','Surrey','UNITED KINGDOM','kt2 5eu','07773712658',NULL,NULL,NULL,'2011-09-27 06:12:43',0,NULL,3,0,4,1,'YW866012163CN ','已入库 \r2.7'),(17236,8881317106996145,111,'312AS的包+英文说明书',1,'',0,'hermeshine','mikeraj88','mikeraj@streamyx.com','Michael Raj Marks','16 Taman Putra, Kelang Lama','Kulim','Kedah','MALAYSIA','09000','0124315187',NULL,NULL,NULL,'2011-09-27 07:03:16',0,NULL,3,1,6,1,'EE495359741CN ','312A * 1 （已入库）\r312A * 1（只有灯和包）\r---\r新地址\rMichael Raj Marks\r16 Taman Putra\rKelang Lama\r09000 Kulim\rKedah\rMalaysia\r申报：30$'),(17237,8881317111985594,111,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',442,'hermeshine','alkidiri','kegome2003@yahoo.com','Ahmed ALKHUDHARY','Kuwait Mubareek Alkabeer<br>mailbox: AL - QOSOOR, P:OBOX: 563, c/o 47406','kuwait','kwt','KUWAIT','47406','',NULL,NULL,NULL,'2011-09-27 08:26:25',0,NULL,3,1,8,1,'CP235627666CN','欧标 220v\r除了C里的内容，再加2块3x6m的背景布\r一共3块（黑白绿）\r由于科威特不能超过10公斤 所以分两票发CP235627652CN'),(17238,771760846002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',67.36,'hermeshine','pin_et_ree','pine_tree@mail.ru','Sosnin Kirill','Lenina 153/1, 36','Kostroma','Kostroma','RUSSIAN FEDERATION','156007','(909)254-7959','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 08:45:20',0,NULL,3,1,5,1,'CP235627745CN ','pin_et_ree\r1.6*2.1白色'),(17239,859520730015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','canelita0','manololara@vodafone.es','MANUEL LARA CARDENAS','JOSE ALEJO BONMATI, N31,2º','Santa Pola','Comunidad Valenciana','SPAIN','03130','605567038','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 08:48:43',0,NULL,3,1,2,1,NULL,'canelita0'),(17240,771956508002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 08:55:53',0,NULL,3,1,17,0,NULL,'ilievbp'),(17241,729725855001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 08:56:56',0,NULL,3,1,17,0,NULL,'ilievbp'),(17242,729726115001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','ilievbp','blagoy_iliev@yahoo.com','BLAGOY ILIEV','Cesar Franckstraat 174','Delft','Zuid-Holland','NETHERLANDS','2625CE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 08:58:14',0,NULL,3,1,3,1,'RA184561610CN\r ','ilievbp\rc型大力夹    1\r反光板支架的夹子 双轮   1\r铝合金灯座（N）      1'),(17243,771958134002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kakalo_70','jesus.barron@hotmail.es','Jesus Barron','Rue de Mercure 2D/3','SHAPE','','BELGIUM','7010','0471390181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 09:05:54',0,NULL,3,1,3,1,'RA184561708CN\r ','kakalo_70'),(17244,732022155018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','thompson9135','b0zz32@hotmail.com','Susan Thompson','29 Lalina Avenue','Tweed Heads West','New South Wales','AUSTRALIA','2485','0755998291','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 09:28:26',0,NULL,3,1,2,1,NULL,'thompson9135\r澳标'),(17245,841732417016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','jrooke91','supperstar_jade@hotmail.com','Jade Rooke','49 Everson Road','Gympie','Queensland','AUSTRALIA','4570','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-27 10:08:27',0,NULL,3,1,4,1,'YW866012082CN ','jrooke91\r澳标'),(17246,788103191017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','2bad4maxgmail','2bad4max@gmail.com','max novikov','Irakliou 2','Athens','Attiki / Athens / Patisia','GREECE','11141','0302102014193','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 10:09:46',0,NULL,3,1,2,1,NULL,'2bad4maxgmail'),(17247,732035911018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',225,'photographyacc','karleighs123','karleigh4@bigpond.com','Karleigh Strauch','100 Lyall Street','kalgoorlie','Western Australia','AUSTRALIA','6430','0890228616','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-27 10:18:01',0,NULL,3,1,4,1,'YW866012093CN ','karleighs123\r澳标'),(17248,859556173015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','spraytanpro','funkypumpkinbay@googlemail.com','Siennasol','Unit 4 Phoenix Business Park<br>Low Mill','Ripon','North Yorkshire','UNITED KINGDOM','HG4 1NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 10:34:35',0,NULL,3,1,3,1,'RA184561668CN\r ','spraytanpro'),(17249,729742217001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 10:52:37',0,NULL,3,1,17,0,NULL,'tim-vl'),(17250,771972740002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','tim-vl','bogdanov_d@mail.ru','Dmitry Bogdanov','14 Djakonova str., apt.67','Velikie Luki','Pskov region','RUSSIAN FEDERATION','182100','(911) 362-3498','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 10:52:38',0,NULL,3,1,3,1,'RA184561739CN\r ','tim-vl\r肩架   1\r小号灰卡    1'),(17251,729703434001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','prajuabsaeng125','prajuabs.3001@gmail.com','prajuab saengma(Box 18)','naraimaharat road','Muang','LB','THAILAND','15000','0898061452','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 10:54:08',0,NULL,3,1,3,1,'RA184561835CN\r ','prajuabsaeng125'),(17252,788117307017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','dush_mehta','dushy1978@yahoo.com','Dushyant Mehta','1/11 Truganini Road<br>Carnegie','Melbourne','Victoria','AUSTRALIA','3163','0399430285','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 11:00:58',0,NULL,3,1,3,1,'RA184561827CN\r ','dush_mehta'),(17253,729770755001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','henrikgl','henrikgl@hotmail.com','henrik leinan','sandmyrveien 13','narvik','nordland','NORWAY','8516','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 12:03:26',0,NULL,3,1,5,1,'CP235627723CN','henrikgl\r背景布是1.6*2.1黑色\r欧标\r\r泡重：7.71\r实重：9.27'),(17254,788136824017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',19.99,'photographyacc','henrikgl','henrikgl@hotmail.com','henrik leinan','sandmyrveien 13','narvik','nordland','NORWAY','8516','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 12:05:26',0,NULL,3,0,3,1,'RA184561813CN\r ','henrikgl\r1.6*3白色背景布'),(17255,729774776001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','giulas38','giulas@me.com','giuliano barone saade','al. franca 973 ap 91<br>jardim paulista','são paulo','São Paulo','BRAZIL','01422-001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 12:12:19',0,NULL,3,1,3,1,'RA184561756CN\r ','giulas38'),(17256,732078933018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',36.8,'photographyacc','neonnikk','shuleiko@gmail.com','Dzianis Shuleika','Vrublevskogo street, 7-207','Grodno','','BELARUS','230009','375336575112','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 12:51:46',0,NULL,3,1,3,1,'RA184561800CN\r ','neonnikk\r申报：shoulder pad，$37，\r还要勾选绿色报关签条上“其他/Other”'),(17257,788168081017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','subintercettore','imped@tiscali.it','Domenico Impedovo','Via Machiavelli 7/C','Conversano','BA','ITALY','70014','0804959549','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 13:41:07',0,NULL,3,1,2,1,NULL,'subintercettore'),(17258,859629225015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1307',5.12,'hutongstore','arifinukk','a_oik@ymail.com','a islam','61 zetland street, london<br>london','london','London','UNITED KINGDOM','e146pr','02075156481','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 13:52:52',0,NULL,3,1,2,1,NULL,'arifinukk'),(17259,732100103018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','ryanlim7','poseidon_park@hotmail.com','Ryan Lim','24, Jalan Gembira,<br>Taman Gembira,','Batu Pahat','Johor','MALAYSIA','83000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 13:54:18',0,NULL,3,1,2,1,NULL,'ryanlim7'),(17260,788176485017,270741930246,'QR Quick Release Plate Video Tripod Head 717 EI-717AH',1,'AB1204',18,'photographyacc','bgoodie88','vishvag@hotmail.com','Vishva Gunasena','44 Edinburgh Cct','Cecil Hills','New South Wales','AUSTRALIA','2171','0401677236','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 14:07:04',0,NULL,3,1,2,1,NULL,'bgoodie88'),(17261,729812905001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','metamorphochris','metamorphochris@yahoo.co.uk','chris daniels','18  sycamore close<br>erdington','birmingham','West Midlands','UNITED KINGDOM','b248aq','07746209246','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 14:23:26',0,NULL,3,1,2,1,NULL,'metamorphochris'),(17262,729844914001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','slavikm','slavikmatej@gmail.com','Matej Slávik','L. Stura 16/27','Beluša','','SLOVAK REPUBLIC','01861','0902221737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 15:58:14',0,NULL,3,1,3,1,'RA184561671CN\r ','slavikm'),(17263,859695063015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','marvyn091077','marvynddebono@hotmail.com','Marvyn Dimech De Bono','Speranza Court Flt1<br>Triq San Guzepp','Mosta','########','MALTA','MST 1260','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 16:24:44',0,NULL,3,1,2,1,NULL,'marvyn091077'),(17264,859695327015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','dtom22tom','dtom22@ymail.com','tom streeter','38 moonstone sq, sittingbourne<br>sittingbourne','kent','Kent','UNITED KINGDOM','me105jn','01795424443','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-27 16:32:13',0,NULL,3,1,12,1,'5241817151\r','dtom22tom\r英标\r实重11.69  抛重12.96'),(17265,859768114015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',1.87,'hutongstore','8105ian','bower@shafton1.orangehome.co.uk','ian bower','14a beale walk<br>shafton','barnsley','South Yorkshire','UNITED KINGDOM','s72 8rg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-27 18:30:32',0,NULL,3,1,2,1,NULL,'8105ian'),(17266,729961408001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wvb2120','wvb@execpc.com','William V. Breyfogle','9246 N 70th St','Milwaukee','WI','UNITED STATES','53223-1108','(414) 690-2136','NoPaymentFailure','CheckoutComplete','Other','2011-09-27 20:11:42',0,NULL,3,0,1,1,NULL,'wvb2120\rXL   已入库'),(17267,859840690015,250606689979,'IR Remote Control for OLYMPUS E420 E510 E520 E620 RM-1',1,'AA2204',2.75,'hutongstore','nevin570','jnevin@ieee.org','James Nevin','Electronics Dept. GMIT<br>Dublin Road','Galway','Galway','IRELAND','default','0857076984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 20:18:52',0,NULL,3,1,2,1,NULL,'nevin570'),(17268,859855223015,250804358294,'New 72mm Lenscap for Nikon Lens Snap-on 72  Front Cap',1,'AA1308',1.87,'hutongstore','ammenas326','hans.blomberg@xoox.se','Hasse Blomberg','Lievägen 32','Älvsjö','Stockholm','SWEDEN','12533','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-27 20:46:58',0,NULL,3,1,2,1,NULL,'ammenas326'),(17269,727507098001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 20:58:22',0,NULL,3,1,3,1,'RA184561711CN\r ','saud-p\r贴made in china\r总申报价值$80\rRA184561725CN\r'),(17270,772219893002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sreten1984','sreten.spasojevic84@gmail.com','Sreten Spasojević','Hebrangova 14 A','Karlovac','Karlovac','CROATIA','47000','047422908','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-27 21:10:37',0,NULL,3,0,3,1,'RA184561787CN\r ','sreten1984\r2XL  已入库'),(17271,730003011001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','lolalangel1971','charmed3brat@yahoo.com','angie jensen','627 4th ave sw','Le Mars','IA','UNITED STATES','51031-2221','(712) 541-3817','NoPaymentFailure','CheckoutComplete','Other','2011-09-27 21:55:20',0,NULL,3,1,4,1,'YW866012115CN ','lolalangel1971\r1.6*2.1黑色+白色'),(17272,788194919017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','ricknt1961','ricknt@westnet.com.au','Rick Talbot','11 Corbet Pl','South Hedland','Western Australia','AUSTRALIA','6722','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-27 22:25:31',0,NULL,3,1,4,1,'YW866012126CN ','ricknt1961\r▲燕文查到这-max'),(17273,788419033017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','kfu1972','drkentfu@gmail.com','Kent Fu','63 Central Avenue<br>St Lucia','Brisbane','Queensland','AUSTRALIA','4067','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-27 23:21:30',0,NULL,3,1,2,1,NULL,'kfu1972'),(17274,772261719002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','nueve2000','jjosserme@gmail.com','Jorge Josserme','San Lorenzo 3887','Olivos','Buenos Aires','ARGENTINA','B1636ERU','5491147040210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-27 23:24:57',0,NULL,3,1,2,1,NULL,'nueve2000\r欧标\r特殊要求：剪掉美标头'),(17275,732339211018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','lukasz.eurodent','lukasz.kachnikiewicz@gmail.com','Lukasz Kachnikiewicz','Bajana 31D','Wroclaw','dolnoslaskie','POLAND','54129','693 864676','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 23:30:46',0,NULL,3,1,2,1,NULL,'lukasz.eurodent'),(17276,732343935018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','staceh0728','stace_7_28@hotmail.com','Stacey Harnish','286 Highway 329<br>PO Box 164','Hubbards','NS','CANADA','B0J 1T0','(902) 277-0742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-27 23:49:07',0,NULL,3,0,2,1,NULL,'staceh0728\r1.6*2.1白色背景布'),(17277,788432224017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',32,'photographyacc','buying2selling-onthenet','transaction.account@revenue.com','Sukhpreet Dhamoon','1/Level 2,<br>330 Church Street','Parramatta','New South Wales','AUSTRALIA','2150','0402406076','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 00:08:36',0,NULL,3,1,3,1,' ','buying2selling-onthenet'),(17278,772274840002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','reinan19','a_bebot@yahoo.com','bianca rosales','41 walkinstown green','Walkinstown','Dublin','IRELAND','12','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 00:13:08',0,NULL,3,1,3,1,'RA184561760CN\r ','reinan19'),(17279,772284419002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','elaynecristina2011','elaynebaldarate@yahoo.com.br','Elayne Cristina Cavalcante','doutor paulo marcelo 2820 A','Fortaleza','Ceara','BRAZIL','60834155','8532476826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 00:48:05',0,NULL,3,1,2,1,NULL,'elaynecristina2011'),(17280,842132552016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',62,'hutongstore','woodyjake94','jakewoodnutt@hotmail.co.uk','Jake Woodnutt','Amberwood, Ruette Des Cornilles<br>Castel, Cobo','Guernsey','Channel Islands','UNITED KINGDOM','GY5 7HF','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-28 01:24:15',0,NULL,3,1,4,1,'YW866012130CN ','woodyjake94'),(17281,772295133002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','smocksnfrocks','drywallsolutions@live.com','Daniel Lamarche','1001-1801 Riverside Dr.','Ottawa','ON','CANADA','K1G 0E7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 01:28:29',0,NULL,3,1,5,1,'CP235627737CN ','smocksnfrocks'),(17282,732082037018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',30.79,'photographyacc','70m_c','x8tmc8x@gmail.com','Thomas Clyne','1324 W Carmen Ave','Chicago','IL','UNITED STATES','60640-2904','(773) 728-4407','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 01:36:00',0,NULL,3,1,1,1,NULL,'70m_c\r反光板支架的夹子（双轮）   1\r闪光灯D座    1'),(17283,842142215016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','obionekenobe','mark_ps_jaffe@hotmail.com','Mark Jaffe','364 Harrogate Rd','Leeds','West Yorks','UNITED KINGDOM','ls17 6qb','01132697977','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 01:52:24',0,NULL,3,1,3,1,'RA184561773CN\r ','obionekenobe'),(17284,730064338001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','okino61524','nikolaidelacruz@gmail.com','Niko Dela Cruz','170 Joyceton Ter','Upper Marlboro','MD','UNITED STATES','20774-1479','(240) 565-8723','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 01:58:33',0,NULL,3,1,1,1,NULL,'okino61524'),(17285,8881317179861407,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',45.58,'aliexpress','1004554984','dector@r46.ru','VADIM SHEHOVCOV','Kirova 17-1','Kursk','Kurskaya','RUSSIAN FEDERATION	','305000','+7 950 8782798',NULL,NULL,NULL,'2011-09-28 03:17:41',0,NULL,3,1,5,1,'CP238030869CN ',''),(17286,788490479017,270755020831,'800W Red Head for Studio Continuous Light Bulb x 5 220v',2,'AKT059',100,'photographyacc','jenko184','jenko184@gmail.com','Andrew Jenkins','100 Lamorna Ave Beecroft','Sydney','New South Wales','AUSTRALIA','2119','0298712715','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 03:46:52',0,NULL,3,1,3,1,'RA184561844CN\r ','jenko184'),(17287,732408465018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','117leanne','leannelarcombe@bigpond.com','Leanne Larcombe','90 Sandakan Rd<br>Revesby Hts','Revesby Hts','New South Wales','AUSTRALIA','2212','0297712253','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 04:20:00',0,NULL,3,0,2,1,NULL,'117leanne\r白色'),(17288,8881317184355946,111,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',0,'hermeshine','lenkaren2','lenk222@hotmail.com','Kent Björklind','Mariebergsgatan 9B','Sala','','SWEDEN','73334','',NULL,NULL,NULL,'2011-09-28 04:32:35',0,NULL,3,1,3,1,'RA184561858CN\r ','上一套坏了，补发一套。\r这次挑一套质量好些的！'),(17289,8881317184631187,111,'nikon 75th 背心  xl    1',1,'',0,'photographyacc','khaunreiter','hammerider@yahoo.com','Kurt Haunreiter','13811 34th Ave NW','Tulalip','WA','UNITED STATES','98271-7144','(360) 654-1521',NULL,NULL,NULL,'2011-09-28 04:37:11',0,NULL,3,0,1,1,NULL,'已入库 \r改一个  \rLK048845148CN'),(17290,732415650018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','p.hai','hai.pham@yahoo.com','Hai Pham','17 Dantum Grove Braybrook','Melbourne','Victoria','AUSTRALIA','3019','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 05:00:36',0,NULL,3,1,3,1,'RA184561795CN\r ','p.hai'),(17291,730108461001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jaminbenn','rtank@att.net','Robert Tanksley','1717 Springridge Rd','Raymond','MS','UNITED STATES','39154','(601) 924-0461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 05:46:05',0,NULL,3,1,1,1,NULL,'jaminbenn'),(17292,8881317191010875,111,'New 10 slots filter box for 10 Pcs filters Cokin  P',3,'AD1170',0,'photographyacc','smalltimejackson','grevzin@hotmail.com','Gennady Revzin','6/61 Ormond Road','Elwood','Victoria','AUSTRALIA','3184','0399390730',NULL,NULL,NULL,'2011-09-28 06:23:30',0,NULL,3,1,3,1,'RA184561901CN ','注意包装，这就是抱怨表面粘胶擦不干净的那位。 '),(17293,8881317192864358,111,'1600W  套装',1,'AKT039',214,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-09-28 06:54:24',0,NULL,3,1,12,1,'5241817162\r ','(灯泡都是110v）\r除了C里的东西再加\r110v  45w bulbs * 2 \r110v  115w bulbs * 1（已入库）\r实重6.69 抛重9.408'),(17294,715364211001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','e-heart007','nk-ktk@hotmail.com','MR.Nakarin Kitikul','11/2 m.6 ,Soi Wat-Yai-swang-arom<br>Rachaphruk Rd.','Pak-Kret,Om-Kret','Nonthaburi','THAILAND','11120','6687-495-7883','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 07:00:05',0,NULL,3,1,2,1,NULL,'e-heart007'),(17295,730122767001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','galileoiv','isbreen@gmail.com','Hans Olav Breen c/o David See','8672 Country Crossings St','Las Vegas','NV','UNITED STATES','89123-3651','702 423 5293','NoPaymentFailure','CheckoutComplete','Other','2011-09-28 07:07:23',0,NULL,3,1,1,1,NULL,'galileoiv'),(17296,732441181018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','d3sketchbook','butterflysunset@hotmail.com','Marie-Ellen Dufourq','54 Dunbar Road','Burpengary','Queensland','AUSTRALIA','4505','0754978824','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-28 07:14:58',0,NULL,3,1,4,1,'YW866012141CN ','d3sketchbook'),(17297,732452317018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','michielhimself','michielhimself@gmail.com','Michiel Bijlsma','De Vijnen 8','NEDERHORST DEN BERG','','NETHERLANDS','1394KM','(0294) 257359','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 08:05:37',0,NULL,3,1,3,1,'RA184561946CN ','michielhimself'),(17298,730136742001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','rimakbud2009','rimakbud@gmail.com','Akbudak Rimma','Telmana 68-19','Almetyevsk','Tatarstan','RUSSIAN FEDERATION','423400','+7(927)492-18-70','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 08:12:36',0,NULL,3,1,3,1,'RA184561932CN ','rimakbud2009'),(17299,860082214015,250692240567,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 09:10:41',0,NULL,3,0,2,1,NULL,'vojpal\r 天涯渐变蓝   1 （已入库）'),(17300,732465517018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','goatydude','catsa@wideband.net.au','Daniel Gangur','41 Patten st','Sale','Victoria','AUSTRALIA','3850','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 09:17:00',0,NULL,3,1,2,1,NULL,'goatydude'),(17301,860086209015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','rimutiaaa','promopocket@gmail.com','Rima Ozelyte','Siloju g. 48<br>Traksedziai','Silute','','LITHUANIA','99104','0037063633749','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 09:23:10',0,NULL,3,1,5,1,'CP235627706CN ','rimutiaaa'),(17302,730157712001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','dandrade199310','dandrade1993@yahoo.com','Daniel Andrade','13171 Herron St','Sylmar','CA','UNITED STATES','91342-2522','(818) 362-8983','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 09:44:39',0,NULL,3,1,1,1,NULL,'dandrade199310'),(17303,772412019002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','85balerafon','michaelv85@gmail.com','Michael Vyazmensky','Tuval 18 apartment 5','Ramat Gan','Ramat Gan','ISRAEL','52522','97288644143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 10:35:00',0,NULL,3,1,3,1,'RA184562005CN ','85balerafon'),(17304,772417687002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','foto14lexa','lea.hult@luukku.com','Lea Hult','Metsänhoitajankuja 1A 6','Vantaa','Oletus','FINLAND','01370','0500658717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 10:59:10',0,NULL,3,1,3,1,'RA184561977CN ','foto14lexa'),(17305,788591185017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','tr3nt111','i-like-ur-eyes@hotmail.com','Trent Davis','3 appadene st<br>Ormeau','Brisbane','Queensland','AUSTRALIA','4208','0429008429','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 11:11:08',0,NULL,3,1,2,1,NULL,'tr3nt111'),(17306,732500364018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',2,'AD1179',29.98,'photographyacc','anatolzzz','a@2xsamara.com','Anatoliy Samara','Cherkasova d.3, kv.68','Donetsk','Donetskaya obl','UKRAINE','83023','+380509323323','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 11:16:11',0,NULL,3,1,17,0,NULL,'anatolzzz'),(17307,788594876017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',2,'AO0005',33.98,'photographyacc','elbretto33','brett@primaledge.com.au','Brett Crockford','22-28 Boundary St','South Melbourne','Victoria','AUSTRALIA','3205','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 11:25:12',0,NULL,3,0,3,1,'RA184561963CN ','elbretto33\r1.6*3  黄色+粉红背景布'),(17308,732503681018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','anatolzzz','a@2xsamara.com','Anatoliy Samara','Cherkasova d.3, kv.68','Donetsk','Donetskaya obl','UKRAINE','83023','+380509323323','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 11:26:32',0,NULL,3,1,3,1,'RA184561915CN ','anatolzzz\r反光板支架的夹子（双轮）  2\rc型大力夹    2'),(17309,842301130016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','coletted01','colettesphotography@hotmail.co.uk','colette donnachie','3 redholm cottage<br>cliff terrace road','weymss bay','Renfrewshire','UNITED KINGDOM','pa18 6ad','01475707953','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 11:46:15',0,NULL,3,1,3,1,'RA184561929CN ','coletted01'),(17310,788610692017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','nolesmax5','noles@skymesh.com.au','john knowles','21 parsons drive','acacia hills','tasmania','AUSTRALIA','7306','0364272960','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-28 12:12:59',0,NULL,3,1,2,1,NULL,'nolesmax5'),(17311,732520625018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','s_onyx','sonx@narod.ru','Vavinov Olexandr','40 Costi Palama, Lomcon Court<br>flat 7','Limassol','Limassol','CYPRUS','3095','+357 99 802158','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 12:23:20',0,NULL,3,1,2,1,NULL,'s_onyx'),(17312,732520963018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','ipsc_eh','bats@cbn.net.id','Ebram Harimurti','Jalan Raden Saleh 2, No. 25 A, Cikini Menteng','Jakarta','Jakarta','INDONESIA','10330','+62811144811','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 12:23:49',0,NULL,3,1,2,1,NULL,'ipsc_eh'),(17313,772450734002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','wahyu7619','mitra7619@gmail.com','IRWAN WAHYUDI','DSN. VI. SUKARAME NO.1540A RT.21B RW.09 NATAR','LAMPUNG SELATAN','LAMPUNG','INDONESIA','35362','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 12:53:39',0,NULL,3,1,2,1,NULL,'wahyu7619'),(17314,730212924001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.8,'hermeshine','davieg1947','gandm062009@gmail.com','Garry Davies','19 Brolga Prom','Willetton','Western Australia','AUSTRALIA','6155','0894577504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 13:12:22',0,NULL,3,1,2,1,NULL,'davieg1947'),(17315,842347966016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','k.c.1957','k_a_c@blueyonder.co.uk','kevin  cox','17 Durnford Avenue<br>Ashton','Bristol','Avon','UNITED KINGDOM','bs32al','01179664996','PayPalPaymentInProcess','CheckoutComplete','UK_StandardShippingFromOutside','0000-00-00 00:00:00',0,NULL,7,0,18,0,'','k.c.1957\r'),(17316,772468425002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','nine-one-one-911','nine-one-one@hotmail.com','Damien Martinet','14 allée henri sellier','toulouse','Midi-Pyrénées','FRANCE','31400','0561523370','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 13:50:54',0,NULL,3,1,2,1,NULL,'nine-one-one-911'),(17317,841923789016,260660053270,'New Neoprene Reversible Cover for Nikon D300S D700 L',1,'AC1303',5.5,'hutongstore','johnwyllie','wyllie@gmail.com','John Wyllie','LBi, Truman Brewery<br>146 Brick Lane','London','London','UNITED KINGDOM','E1 6RU','07771532531','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-28 14:01:44',0,NULL,3,1,2,1,NULL,'johnwyllie'),(17318,730220702001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','cdb7499','hourglassimages@comcast.net','David Barfield','4733 179th Ave E','Lake Tapps','WA','UNITED STATES','98391-8948','(253) 987-5184','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-28 13:37:45',0,NULL,3,1,3,1,'RA184562014CN ','cdb7499'),(17319,788666974017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','sonnybeans','heyzuzz@yahoo.com','ryan heath','1003 frank hall dr','albert lea','MN','UNITED STATES','56007','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 14:55:40',0,NULL,3,1,1,1,NULL,'sonnybeans'),(17320,732595066018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','mortimer1029','clement.lombart@gmail.com','Lombart Clément','35 rue François Raspail','St André les Vergers','Champagne-Ardenne','FRANCE','10120','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 16:04:17',0,NULL,3,0,3,1,'RA184562028CN ','mortimer1029\rxxl 已入库'),(17321,732619676018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','spasso661215','bond661215@aol.com','sungkyun kang','4549 Vauxhall Rd','Richmond','VA','UNITED STATES','23234-3556','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 17:01:58',0,NULL,3,1,1,1,NULL,'spasso661215'),(17322,788740584017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','sokolovatatiana','stvlinda@mail.ru','Tatiana Sokolova','Sovetskaya<br>10/31 62','Elektrougli','Moscow Region','RUSSIAN FEDERATION','142455','926-399-6467','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 17:50:59',0,NULL,3,1,2,1,NULL,'sokolovatatiana'),(17323,730309241001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','2010jujuba','jultins@gmail.com','Eduardo Moraes','av.Bernardino de Campos, 76','Amparo','São Paulo','BRAZIL','13900400','19.38085083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 17:56:29',0,NULL,3,1,2,1,NULL,'2010jujuba'),(17324,772576318002,120458030092,'Marco O Flash o-flash Ring Light For SB900 580EXII F170',1,'AO0026',38.49,'hermeshine','arkadiykr','krasnoyarovi@gmail.com','Arkadiy Krasnoyarov','Mangeldina 44- 70','Shymkent','UKO','KAZAKHSTAN','160005','+77057003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:20:55',0,NULL,3,1,3,1,' RA184562354CN','arkadiykr\r'),(17325,730332822001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','vojtechv123','vojtech_v@email.cz','Vojtěch Vomáčka - asistent soudce','NSS - Moravské náměstí 6','Brno','Czech Republic','CZECH REPUBLIC','657 40','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:36:40',0,NULL,3,1,2,1,NULL,'vojtechv123\r欧标'),(17326,730343767001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','mastersamara','abolshakov2@gmail.com','Alexey Bolshakov','Parizhskoi Kommuni st. 18 / 141','Samara','RU','RUSSIAN FEDERATION','443112','+7 917 944 12 64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 18:54:38',0,NULL,3,1,2,1,NULL,'mastersamara'),(17327,788784249017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','skaw80','skawi@yahoo.com','Sebastian Kawahira','Concepcion Arenal 2978, PB \"D\"','Colegiales, Capital Federal','Buenos Aires, Argentina','ARGENTINA','1426','5411 4777 7564','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-28 19:10:11',0,NULL,3,1,2,1,NULL,'skaw80'),(17328,772639525002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','superkhiet13z','xtaikix@hotmail.com','Khiet Nguyen','9835 Xerxes Curv S','Bloomington','MN','UNITED STATES','55431-2864','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-28 20:22:16',0,NULL,3,1,1,1,NULL,'superkhiet13z'),(17329,860427939015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',1,'AO0018',40,'hutongstore','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','004741267856','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-28 21:20:51',0,NULL,3,0,4,1,'YW866012196CN ','ibico1974\r3*6白色背景布\r▲已发信'),(17330,730419366001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','2309371292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 21:38:29',0,NULL,3,1,3,1,'RA184561994CN ','demonod'),(17331,860441362015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','cattyfly','moreira.fjm@gmail.com','Fernando Moreira','Trav. da Curpilheira, 78, 2º Drt','Alfena','Valongo','PORTUGAL','4445-250','939378854','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-28 21:49:03',0,NULL,3,1,3,1,'RA184561985CN ','cattyfly'),(17332,772680984002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',147.8,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sarah Al-Subaa','Taruot','QATIF','Taruot','SAUDI ARABIA','31911','0540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-28 22:10:16',0,NULL,3,1,8,1,'CP238030872CN ','tawfeekmohammed'),(17333,730458918001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','sanderleik89','alex_diler@bk.ru','Alexander Bachinskiy','shishkina 52/2-71','Odessa','Odessa','UKRAINE','65088','380936395115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 00:06:59',0,NULL,3,1,2,1,NULL,'sanderleik89'),(17334,788909391017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','rockuchan','kpang@adam.com.au','Ket Pang','53 Warri Parri Drive<br>Flagstaff Hill','Adelaide','South Australia','AUSTRALIA','5159','0412223936','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 00:17:15',0,NULL,3,1,2,1,NULL,'rockuchan'),(17335,732802669018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','mvheyst','marcel@vanheyst.id.au','MHJ VAN HEIJST','40C Winchelsea Road<br>Nollamara','Perth','Western Australia','AUSTRALIA','6061','61434446198','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 00:19:51',0,NULL,3,1,3,1,'RA184562059CN ','mvheyst'),(17336,772718006002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','dongdory2','jayman1004@gmail.com','hyunjin yoon','4145 11th Ave NE<br>Apt 52','seattle','WA','UNITED STATES','98105-6352','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-09-29 00:26:45',0,NULL,3,1,1,1,NULL,'dongdory2'),(17337,732809969018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',2,'AD1120',36,'photographyacc','chosenindustries','mattdarleybentley@hotmail.com','Chosen Industries','32  Brougham  ST','East Gosford','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 00:46:31',0,NULL,3,1,17,0,NULL,'chosenindustries'),(17338,788918229017,270751924000,'YongNuo Studio Flash Trigger CTR-301P Three Receivers',1,'AKT002',59,'photographyacc','chosenindustries','mattdarleybentley@hotmail.com','Chosen Industries','32  Brougham  ST','East Gosford','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 00:49:57',0,NULL,3,1,3,1,'RA184562147CN\r ','chosenindustries\ryongnuo无线 YN159-C3     2\rCTR-301P 1托3      1\r'),(17339,730492130001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','aragornelviejo1952','larcont_1952@yahoo.com.ar','Daniel Angel LARRONDO','Pellegrini 466','TANDIL','Pcia de Buenos Aires','ARGENTINA','B7000GZJ','054-2293-422827','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 02:22:05',0,NULL,3,0,3,1,'RA184562031CN ','aragornelviejo1952\r3XL   已入库'),(17340,730497759001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',2,'AKT028',21.98,'hermeshine','pradit-3100','pradit.w3100@sanook.com','Pradit Wongchawalit','39 Moo1 Sudbantad Rd. Tandieo','Kangkhoi','Saraburi','THAILAND','18110','0806643222','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 02:48:06',0,NULL,3,1,3,1,'RA184562045CN ','pradit-3100\r天涯渐变灰  * 1 （保留原厂包装）\r天涯方形滤镜ND8  * 1 （保留原厂包装）\r58mm 转接环  * 1\r77mm 转接环  * 1\r普通滤镜托架  * 1\r广角滤镜托架  * 1\r\r'),(17341,732852862018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','shenie92','shenie.shen.shen@live.com.au','Aysen Osman','28 Burbank Street CanningVale','Perth','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 03:41:05',0,NULL,3,1,2,1,NULL,'shenie92\r白色\r'),(17342,8881317267969852,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',45.58,'aliexpress','1004567781','tatianasud@yandex.ru','tatiana sudareva	','bulvar Zarechniy 7/1-153','Nizniy Novgorod	','Nizegorodskaya','RUSSIAN FEDERATION	','603032','+7 902 9027806373',NULL,NULL,NULL,'2011-09-29 03:46:09',0,NULL,3,1,5,1,'CP235627697CN ',''),(17343,730496034001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','melpopov','melissa_popov@hotmail.com','Melissa Popov','Cairns Innovative Physio, 40 campus shopping Village<br>Cnr Cook hway and Mcgregor road Smithfield','Cairns','Queensland','AUSTRALIA','4870','0740556200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 04:14:41',0,NULL,3,1,2,1,NULL,'melpopov'),(17344,772773796002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','tolis1365','flioukas@yahoo.gr','Tolis Flioukas','herostratous 11','Chios','Greece','GREECE','82100','6945885305','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 04:17:10',0,NULL,3,0,3,1,'RA184562102CN ','tolis1365\r3XL  已入库'),(17345,788973038017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','d_j_spiral27','spiral27@bigpond.net.au','Matthew Osborne','c/o Electroboard<br>20 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0424267285','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 04:35:40',0,NULL,3,1,17,0,NULL,'d_j_spiral27'),(17346,732861309018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','d_j_spiral27','spiral27@bigpond.net.au','Matthew Osborne','c/o Electroboard<br>20 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0424267285','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 04:35:41',0,NULL,3,1,3,1,'RA184562076CN ','d_j_spiral27\r2B柔     1\r反光伞110cm     1'),(17347,730486915001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','dryll27','27tees@gmail.com','Niniek Sugiarti','18, PJU 1A/56B<br>Damansara Legenda','Petaling Jaya','Selangor','MALAYSIA','47410','0123158555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 04:47:11',0,NULL,3,1,6,1,'EE495359809CN ','dryll27\r1.6*2.1黑色+白色'),(17348,788975844017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','addjdl','addjdl@yahoo.com','Jayson De Leon','ADD Convention Center<br>Sampaloc','Apalit','Pampanga','PHILIPPINES','2016','0458791418','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 04:49:30',0,NULL,3,1,2,1,NULL,'addjdl'),(17349,732865854018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','atomic_love_vintage','leerowthorne@hotmail.com','Lee Rowthorne','37 Condor Place','Clothiers Creek','New South Wales','AUSTRALIA','2484','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 04:56:28',0,NULL,3,0,2,1,NULL,'atomic_love_vintage\r红色'),(17350,730522601001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',36.89,'hermeshine','esiskandar','esiskandar@yahoo.com.sg','Is\'al Ismail','Blk 787B, Woodlands Crescent,<br>#04-78','default','','SINGAPORE','732787','96971456','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 06:26:28',0,NULL,3,1,3,1,'RA184562062CN ','esiskandar\r圆形柔光棚 40cm   *  1\r倒影板   *  1 （已入库）'),(17351,788977952017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',5.98,'photographyacc','leemo69','leehutchings@live.com','kylee hutchings','22 bath road morley','perth','Western Australia','AUSTRALIA','6062','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 06:38:19',0,NULL,3,1,2,1,NULL,'leemo69'),(17352,789004351017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',2,'AA1206',5.8,'photographyacc','josephmglad','alegreaj@gmail.com','Josep Maria Alegre','Av Cami de la Fita 15, 4t, 3a','Sitges','Cataluña','SPAIN','08870','659253368','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 07:16:58',0,NULL,3,1,2,1,NULL,'josephmglad'),(17353,730547246001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','olgaaksenova23','aksenova23@mail.ru','Olga Aksenova','Yana-Poluyana 15, 41','Krasnpdar','Krasnodar region','RUSSIAN FEDERATION','350062','(918) 370-55-11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 07:18:22',0,NULL,3,1,17,0,NULL,'olgaaksenova23'),(17354,772809704002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','olgaaksenova23','aksenova23@mail.ru','Olga Aksenova','Yana-Poluyana 15, 41','Krasnpdar','Krasnodar region','RUSSIAN FEDERATION','350062','(918) 370-55-11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 07:34:19',0,NULL,3,1,3,1,'RA184562093CN ','olgaaksenova23\rEW-73B    2\r9个环+两种托架'),(17355,789013696017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','jennysophian','jenny_sophian@yahoo.com','Stefani Tanzil','6-22 magnet road','Canning Vale','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 08:00:57',0,NULL,3,1,2,1,NULL,'jennysophian'),(17356,730561711001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','music.outlet.italy','info@lucaesposito.com','Luca Esposito','C/O Postel SPA<br>Via Guglielmo Massaia, 31','Roma','RM','ITALY','000154','0651426658','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 08:32:29',0,NULL,3,0,3,1,'RA184562155CN ','music.outlet.italy\rL  已入库'),(17357,732912887018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','tugunted','tugunted1@gmail.com','Lauren Wright','50 The Parc<br>2 Inland Drive','Tugun','Queensland','AUSTRALIA','4224','0430142024','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 09:03:39',0,NULL,3,1,2,1,NULL,'tugunted'),(17358,732923030018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','giantocr30','rantalldaryl@hotmail.com','Melinda McIntosh','46 Campbell Street','Port Fairy','Victoria','AUSTRALIA','3280','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 09:46:46',0,NULL,3,1,2,1,' ','giantocr30'),(17359,730593517001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','renb2812','reneebarker28@hotmail.com','renee barker','8 dundas street','newstead','Victoria','AUSTRALIA','3462','0408532858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 10:54:38',0,NULL,3,1,2,1,NULL,'renb2812'),(17360,842823175016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0023',169,'hutongstore','stephen-kershaw','stephen.kershaw@gmail.com','Stephen Kershaw','115A Helix Road','London','London','UNITED KINGDOM','SW2 1RB','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-29 10:55:40',0,NULL,3,1,4,1,'YW866012200CN ','stephen-kershaw\r泡重：7.58'),(17361,860676631015,250693634907,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',4.99,'hutongstore','fsab47','frederic_saboural@yahoo.fr','Frédéric SABOURAL','63 Rue Résidence du Claux','SAINT-CHAPTES','Languedoc-Roussillon','FRANCE','30190','09.50.29.93.84','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 11:42:03',0,NULL,3,1,2,1,NULL,'fsab47'),(17362,860695140015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','suzy9882','suzy.wilson17@googlemail.com','Luca Romita','ECMWF<br>Shinfield Park, Shinfield','READING','Berkshire','UNITED KINGDOM','RG2 9AX','07984103682','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 12:34:35',0,NULL,3,1,3,1,'RA184562133CN\r ','suzy9882'),(17363,730622306001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','vanyok_kirov','annvan@mail.ru','Ivan Tretyakov','Lenina<br>185-13','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 12:43:01',0,NULL,3,1,5,1,'CP235627670CN ','vanyok_kirov'),(17364,732981954018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','phoenix_stalker','cag.phox@gmail.com','Warren Duncan','290 Gray Hawk Trl','Clarksville','TN','UNITED STATES','37043','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 13:13:42',0,NULL,3,1,3,1,'RA184562204CN\r ','phoenix_stalker'),(17365,732989247018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','syestone','syestarshit@hotmail.com','Simon Lecoy','51 rue lepic','Paris','Ile-de-France','FRANCE','75018','06 22 56 23 84','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 13:36:22',0,NULL,3,1,3,1,'RA184562218CN\r ','syestone'),(17366,789108591017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','monastig3','alayan_arqitecture@yahoo.com','Mon Alayan','321 A<br>Albany Highway','North Shore','Auckland','NEW ZEALAND','0632','021 184 6033','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 13:47:46',0,NULL,3,1,2,1,NULL,'monastig3\r'),(17367,730643228001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',8.99,'hermeshine','khrys321','guerreirochristophe@hotmail.com','Christophe GUERREIRO','Rua Padre Adriano Botelho nº 5 (3-esq)','Lisboa','Lisboa','PORTUGAL','1300-437','00.351.964.371.642','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 13:56:05',0,NULL,3,1,2,1,NULL,'khrys321'),(17368,772906625002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','iliang','il_siu@yahoo.com','I-Liang Siu','13408 Commonwealth Dr.','Burnsville','MN','UNITED STATES','55337','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 14:06:28',0,NULL,3,1,3,1,'RA184562221CN\r ','iliang'),(17369,772908286002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','row-2008','roland.rollig@yahoo.com','Roland Röllig','28A Borgundvegen','Alesund','More og Romsdal','NORWAY','6003','(47)92885889','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 14:12:06',0,NULL,3,1,4,1,'YW866012233CN ','row-2008\r布是灰色的\r实重3.86\r泡重4.78\rbackground support   $22\r来信说已经收到！'),(17370,772920347002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','kakalo_70','jesus.barron@hotmail.es','Jesus Barron','Rue de Mercure 2D/3','SHAPE','','BELGIUM','7010','0471390181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 14:52:01',0,NULL,3,1,3,1,'RA184562181CN\r ','kakalo_70'),(17371,772928435002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','edward102222','edward1022@gmail.com','Edward Ross','19323 Starlight Dr','Tarzana','CA','UNITED STATES','91356-4410','(818) 881-7664','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-29 15:15:21',0,NULL,3,1,3,1,'RA184562195CN\r ','edward102222'),(17372,730669461001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','rus.mukhamedov','predictor@yandex.ru','Ruslan Mukhamedov','ul. KARLA ILMERA, 1/88','Tomsk','','RUSSIAN FEDERATION','634057','79069592369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:24:47',0,NULL,3,0,2,1,NULL,'rus.mukhamedov\r黑色'),(17373,730675562001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','myck3690','myckkkkk@hotmail.com','Thaspan Thasnanipan','19/4 Master Piece Vill. Pradidmanoontham Road.<br>Soi. Sukhonthasawat','Bangkok','BA','THAILAND','10230','0865528888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:45:55',0,NULL,3,0,17,0,NULL,'myck3690'),(17374,730672219001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','myck3690','myckkkkk@hotmail.com','Thaspan Thasnanipan','19/4 Master Piece Vill. Pradidmanoontham Road.<br>Soi. Sukhonthasawat','Bangkok','BA','THAILAND','10230','0865528888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 15:45:56',0,NULL,3,0,17,0,NULL,'myck3690'),(17375,730674356001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','myck3690','myckkkkk@hotmail.com','Thaspan Thasnanipan','19/4 Master Piece Vill. Pradidmanoontham Road.<br>Soi. Sukhonthasawat','Bangkok','BA','THAILAND','10230','0865528888','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 15:45:55',0,NULL,3,1,6,1,'EE495359786CN ','myck3690\r背景布 3x6 白色    1\r背景布 3x6 黑色     1\r背景架2m x 3m + 3个夹子    1\r'),(17376,772308731002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','ctsworld','ttambay2@yahoo.com','troy tambay','3332 knoxville ave','long beach','CA','UNITED STATES','90808-4145','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-29 16:04:32',0,NULL,3,1,1,1,NULL,'ctsworld'),(17377,789162097017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',2,'AKT030',116,'photographyacc','lordarkonium','arkonium@gmail.com','Combelles Antoine','88 Boulevard Emile Zola','Croix','Nord-Pas-de-Calais','FRANCE','59170','0320723557','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 16:17:03',0,NULL,3,1,17,0,NULL,'lordarkonium'),(17378,733043283018,280745347210,'Photo Video Continuous light 5 Head E27 AC Bulb Socket with 60x90 Softbox',2,'AD1191',124,'photographyacc','lordarkonium','arkonium@gmail.com','Combelles Antoine','88 Boulevard Emile Zola','Croix','Nord-Pas-de-Calais','FRANCE','59170','0320723557','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 16:17:04',0,NULL,3,1,12,1,'1107575545\r ','lordarkonium\r2m 灯架     2  （ 发弹簧灯架给他）\r斜臂    2\r5头灯    2  欧标\r实重8.395      泡重：7.728'),(17379,842945971016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.12,'hutongstore','uksarky','rocksmore@googlemail.com','Edward Sweeney','1 Mayfair Drive<br>Sale','Manchester','Lancashire','UNITED KINGDOM','M334JT','01619623862','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 16:20:45',0,NULL,3,1,2,1,NULL,'uksarky'),(17380,860786305015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','traygleeson17','traygleeson@yahoo.co.uk','Tracey Gleeson','16 Killucan Manor Green<br>Rathwire','Mullingar','Westmeath','IRELAND','default','0449376544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 16:21:52',0,NULL,3,0,2,1,NULL,'traygleeson17\r红色'),(17381,733070843018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','aciamaj007','aciamaj007@aol.com','Joe Vitale','7001 Brandy Cir. NW','North Canton','OH','UNITED STATES','44720','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 17:27:47',0,NULL,3,1,1,1,NULL,'aciamaj007'),(17382,772995303002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','matteo930','the3mors@hotmail.com','Matteo Baldini','via Pisacane, 6','Selargius','CA','ITALY','09047','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 18:09:04',0,NULL,3,1,3,1,'RA184562164CN\r ','matteo930\rballhead  $18'),(17383,772907356002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',10,'AC1302',75,'hermeshine','jlocatell','jlocatell@gmail.com','Julio Locatelli','Santa Maria del Buen Aire 835<br>PB 01','Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1277','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 18:27:02',0,NULL,3,1,3,1,'RA184562252CN\r ','jlocatell'),(17384,773008156002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','a.saksonov','asaksonov@gmail.com','Андрей Саксонов','ул. Карла Либкнехта, д.3 кв.8<br>ул. Карла Либкнехта, д.3 кв.8','Ульяновск','Ульяновская область','RUSSIAN FEDERATION','432017','(927) 8156878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 18:35:29',0,NULL,3,1,2,1,NULL,'a.saksonov'),(17385,860890478015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',20.99,'hutongstore','harveylyndon','lyndonharvey@aol.com','lyndon  harvey','Meadow End<br>Crease Lane','Tavistock','Devon','UNITED KINGDOM','PL198EW','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-29 19:22:05',0,NULL,3,1,3,1,'RA184562249CN\r ','harveylyndon'),(17386,773063317002,120568073319,'YONGNUO 33ft E-TTL(II) Off-Camera Flash Sync Cord for C',1,'AB3326',45.99,'hermeshine','crravell','ravello.cesar@gmail.com','Cesar Ravello','Artemio Gutierrez 2531<br>San Joaquin','Santiago','Region Metropolitana','CHILE','8940713','25569337','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-29 20:27:23',0,NULL,5,1,18,1,NULL,'crravell'),(17387,731442644018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','cutiepiexo','kiza-kso@hotmail.com','Keara Okines','4 central ave','tyabb','Victoria','AUSTRALIA','3913','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-29 20:28:51',0,NULL,3,0,3,1,'RA184562306CN ','cutiepiexo\r黑白绿'),(17388,860934443015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','chseychell','info@aate.biz','Charlo Seychell','Fralaw, Triq ic-Cawsli','Qormi','-','MALTA','QRM3900','(+356) 9945 0624','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-29 20:34:07',0,NULL,3,1,2,1,NULL,'chseychell'),(17389,773090354002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','spaz1921','puntapalma@gmail.com','Salvio Paz Lorenzo','C/ General Yague nº 20  2ºA','Los Llanos de Aridane','Canarias','SPAIN','38760','638809816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 21:44:47',0,NULL,3,1,3,1,'RA184562235CN\r ','spaz1921'),(17390,860970681015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','clemmo50','david.clement@btinternet.com','David Clement','57 Launcelot Close<br>King Arthurs Way','Andover','Hampshire','UNITED KINGDOM','SP10 4BX','01264333932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 21:47:33',0,NULL,3,1,2,1,NULL,'clemmo50'),(17391,733196882018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','hudla_cz','hudla@hudla.cz','Jan Waldauf','Košická 304','Děčín','','CZECH REPUBLIC','405 05','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 21:55:08',0,NULL,3,1,2,1,NULL,'hudla_cz\r'),(17392,860976014015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','gazboy0070','gaz.boy@virgin.net','Gary Gillette','50 Constitution Hill','Snodland','Kent','UNITED KINGDOM','ME6 5DH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 21:59:35',0,NULL,3,1,3,1,'RA184562178CN\r ','gazboy0070'),(17393,789316013017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',5.98,'photographyacc','mamat80','mamat80@wanadoo.fr','NOWINSKI MATTHIEU','14 rue de Navarre','PENLY','Haute-Normandie','FRANCE','76630','0667386742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-29 21:37:53',0,NULL,3,1,2,1,NULL,'mamat80'),(17394,731880368018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','09franni','serenityjane@live.com','Serenity Caldwell','167 Patchs bch Rd','Patchs Beach','New South Wales','AUSTRALIA','2478','0432664164','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-29 22:44:47',0,NULL,3,0,4,1,'YW866012056CN  ','09franni'),(17395,773119019002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','glam3333','glam33@hotmail.com','Gary Lam','Flat 2. No.8<br>St. Michaels Street','Southampton','Hampshire','UNITED KINGDOM','SO14 2DB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 23:10:17',0,NULL,3,1,2,1,NULL,'glam3333'),(17396,843161595016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.12,'hutongstore','mr2-uk','mr2.uk@ntlworld.com','Phil Bellamy','12 Grosvenor Avenue<br>Oakhill','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST4 5BQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-29 23:28:18',0,NULL,3,1,2,1,NULL,'mr2-uk'),(17397,773114609002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','stop_ka','pinchenkov@gmail.com','Mihail Pinchenkov','ul.Sofia Kovalevskaya, dom 5, korp.2, kv.12','St. Peterburg','Russia','RUSSIAN FEDERATION','195252','+79500383843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-29 22:53:58',0,NULL,3,1,5,1,'CP235627683CN ','stop_ka'),(17398,861023316015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','pmirosevic','gazdapavo@gmail.com','Pavao Mirosevic','Jaruscica 11<br>S623','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 00:25:39',0,NULL,3,1,3,1,'RA184562116CN\r ','pmirosevic'),(17399,730871386001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','ronniepeligro','r_peligro@hotmail.com','Ronald Sarmiento Cun','Paseo Goya 9, 5to a','Mostoles','Madrid','SPAIN','28932','669711962','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 00:37:28',0,NULL,3,1,2,1,NULL,'ronniepeligro'),(17400,861027435015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','frostino619','frostino619@hotmail.com','Chris  Frost','52 leamoor Avenue, Somercotes','Alfreton','Derbyshire','UNITED KINGDOM','DE551RL','01773606205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 00:39:38',0,NULL,3,1,2,1,NULL,'frostino619'),(17401,773141985002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','igoroslo','rojer1@gmail.com','IGOR KOLESNIKOV','BETZY KJELSBERGS VEI 17B, U0101','OSLO','','NORWAY','0486','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 00:42:25',0,NULL,3,1,2,1,NULL,'igoroslo'),(17402,733261999018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',20,'photographyacc','jsimard01','jean.simar3d@gmail.com','Jean Simard','512 Versant du Ruisseau','Prévost','QC','CANADA','j0r1t0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 02:02:13',0,NULL,3,1,2,1,NULL,'jsimard01'),(17403,733268362018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','pezwah11','pezwah@hotmail.com','Chris Perrett','17 Clematis Rd','Mount Evelyn','Victoria','AUSTRALIA','3796','0397371242','NoPaymentFailure','CheckoutComplete','AU_Other','2011-09-30 02:29:00',0,NULL,3,1,2,1,NULL,'pezwah11'),(17404,733262211018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',20,'photographyacc','canon7dpeter','pstepien@aol.com','Peter Stepien','77 Sterling St','Worcester','MA','UNITED STATES','01610-2144','(508) 755-7261','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 02:05:27',0,NULL,3,1,1,1,NULL,'canon7dpeter'),(17405,733271576018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','japsrodriguez','cuchi_koo@yahoo.com','Gilbert Rodriguez','52 Mannavue blvd.','Cranbourne North','Victoria','AUSTRALIA','3977','0422882675','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 02:42:26',0,NULL,3,1,2,1,NULL,'japsrodriguez'),(17406,773178453002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','donzellg35','gordon3195@sbcglobal.net','Donzell Gordon','2820 N Rockwell St','Chicago','IL','UNITED STATES','60618-7804','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 03:12:45',0,NULL,3,1,3,1,'RA184562120CN\r ','donzellg35'),(17407,8881317352711912,111,'1600W  套装',1,'AKT039',238,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-09-30 03:18:31',0,NULL,3,1,12,1,'1107560506\r ','(灯泡都是110v）\r除了C里的东西再加 \r1.6x3m 背景布 （白色）\r实重6.39 抛重7.8'),(17408,730920655001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','field_of_dreams58','lexdenn@hotmail.com','robert dennison','PO Box 178','bishop','CA','UNITED STATES','93515','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 04:30:21',0,NULL,3,1,1,1,NULL,'field_of_dreams58'),(17409,730925872001,110734167587,'NEW PRO LED 312 Panel Camera & Camcorde​r Light 5600k',1,'AD1150',230,'hermeshine','radradrudd','radrudd@hotmail.com','Rad Rudd','PO BOX 6030','KINGSTON','Australian Capital Territory','AUSTRALIA','2604','0416118014','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 05:03:42',0,NULL,3,1,4,1,'YW866012244CN ','radradrudd'),(17410,861103941015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','carlosalbertocharly','pompoy_@hotmail.com','carlos alberto estupinan diaz','via.collodi N°2','noventa di piave','VE','ITALY','30020','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-09-30 05:28:37',0,NULL,3,1,12,1,'1107560495\r ','carlosalbertocharly\r欧标\r实重4.39  抛重5.71'),(17411,861105495015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','llusninomis','simon273@sky.com','Simon Insull','45 Sutton Road','Kidderminster','Worcestershire','UNITED KINGDOM','DY11 6QP','01562638815','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-09-30 05:35:03',0,NULL,3,1,3,1,'RA184562270CN ','llusninomis'),(17412,733313563018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','4328shaw','douglasshaw@aapt.net.au','douglas shaw','146 logan st, eagleby','brisbane','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 06:26:31',0,NULL,3,1,3,1,'RA184562283CN ','4328shaw'),(17413,730949582001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','luizfernandoborgesnomura','fernandonomura@hotmail.com','luiz fernando borges nomura','nagasaka 1 chome 172 kopo station park-A 104<br>nagasaka 1 chome 172 kopo station park-A 104','kani-shi','Gifu','JAPAN','509-0257','080-36482104','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 07:21:42',0,NULL,3,0,3,1,'RA184562297CN ','luizfernandoborgesnomura\r3XL 已入库'),(17414,733327563018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','berlingo1990','erlingatrondsen@hotmail.com','Erling Trondsen','Lille øvregaten 12','Bergen','','NORWAY','5018','95409919','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 07:41:36',0,NULL,3,1,2,1,NULL,'berlingo1990'),(17415,733328057018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',2.5,'photographyacc','jopica','jovukic@inet.hr','Josip Vukic','Luke Sorkocevica','Zadar','','CROATIA','23000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 07:44:00',0,NULL,3,1,2,1,NULL,'jopica'),(17416,773229824002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pilot5253','ravit1020@nana10.co.il','ravit mental','kibuz dgania b<br>kibuz dgania b','kibuz dgania b','israel','ISRAEL','15130','0506274895','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 07:54:30',0,NULL,3,0,3,1,'RA184562266CN ','pilot5253\rxl 已入库'),(17417,730643817001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','anadenn777','anadenn@rambler.ru','Anastasiya Dolgova','Vorushin street 6,apartment 10','Pavlodar','','KAZAKHSTAN','140000','+77015019202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 09:20:48',0,NULL,3,1,8,1,'CP238030886CN ','anadenn777'),(17418,773252889002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','mgjassociates','admin@mgj-associates.co.uk','Jason Barrett','37 Church Rise','Forest Hill','London','UNITED KINGDOM','SE23 2UG','02086991100','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 09:43:52',0,NULL,3,0,3,1,'RA184562898CN\r ','mgjassociates\r3XL   已入库'),(17419,789494194017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','media-designppg','denisisakovic@bih.net.ba','Denis Isakovic','Olimpijska 40','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','+38733459482','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 09:58:15',0,NULL,3,1,2,1,NULL,'media-designppg'),(17420,730983444001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','joycelyne01','joycejm@orange.fr','Jean-Marie RAMBOZ','312 chemin des curnillats','MONTAGNAT','RHONES -ALPES','FRANCE','01250','06.33.61.19.12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 10:02:30',0,NULL,3,1,4,1,'YW866012270CN ','joycelyne01\r已发信\r▲'),(17421,730429050001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',59.97,'hermeshine','13mixmaslab','mixmaslab@gmail.com','Vitaly Yavorsky','Lenina 13,kv 5','Kozyatyn','Vinnickaya oblast','UKRAINE','22100','+380632665598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:07:15',0,NULL,3,1,3,1,'RA184589493CN ','13mixmaslab\r新款内胆包 中号  Nikon     1\r防寒罩    1\r圆形柔光棚 60cm  1\r已入库'),(17422,731000033001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','pientje2009','nienepientje@gmail.com','Janine Tepper','Romeinenlaan 40','Apeldoorn','','NETHERLANDS','7312kz','0645632640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:11:55',0,NULL,3,1,2,1,NULL,'pientje2009'),(17423,733377161018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','falaah','falaah@cybermaldives.net','Ibrahim Falaah','M for S Pte Ltd. M.Kudaveyomatheege<br>Sabudelimagu','Male\'','Maafannu','MALDIVES','20315','(960)7771385','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 11:12:45',0,NULL,3,1,3,1,'RA184562575CN\r ','falaah'),(17424,789518840017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',187,'photographyacc','13eddy13','eddydagun@hotmail.com','Eddy Hamra','22 Maria Street Tanunda','Adelaide','South Australia','AUSTRALIA','5352','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'13eddy13\r结清再发'),(17425,773280026002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kamal_4773','kamal_4773@hotmail.com','Kamal Hizrian','#525 Kg.Belimbing Jln Subok','Brunei','Brunei Muara','BRUNEI DARUSSALAM','BD2917','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 11:38:52',0,NULL,3,1,3,1,'RA184562677CN\r ','kamal_4773'),(17426,789523975017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',68,'photographyacc','360301','george.georgiadis64@gmail.com','George Georgiadis','74 Cultivation Street','Harrison','Australian Capital Territory','AUSTRALIA','2914','0429552430','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 11:51:40',0,NULL,3,1,3,1,'RA184564046CN\r ','360301\r72mm 转接环'),(17427,789516520017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','staplert','staplor@yahoo.com','Silvio Trovato','16 Renshaw Avenue','Auburn','New South Wales','AUSTRALIA','2144','0297023727','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 11:24:43',0,NULL,3,1,2,1,NULL,'staplert'),(17428,843365782016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','mathiastegtmeier','mtblah@hotmail.com','Mathias Tegtmeier','Kornmodsbakken 40','Aarhus','','DENMARK','8210','29859644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 12:13:16',0,NULL,3,1,4,1,'YW866012281CN ','mathiastegtmeier'),(17429,861216353015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','oprowse','ollieprowse@hotmail.com','Ollie  Prowse','38 Elizabeth Close<br>Ivybridge','Plymouth','Devon','UNITED KINGDOM','PL21 0PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 12:17:43',0,NULL,3,1,2,1,NULL,'oprowse'),(17430,730327888001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',7.2,'hermeshine','arkadiykr','krasnoyarovi@gmail.com','Arkadiy Krasnoyarov','Mangeldina 44- 70','Shymkent','UKO','KAZAKHSTAN','160005','+77057003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 12:22:07',0,NULL,3,1,17,0,' ','arkadiykr'),(17431,733397045018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','1942barry','barry.roennfeldtesq@bigpond.com','Barry Roennfeldt','16 Lake St','Rainbow','Victoria','AUSTRALIA','3424','0353951119','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 12:27:39',0,NULL,3,1,17,0,NULL,'1942barry'),(17432,733398368018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','shreekadel','shree_you@hotmail.com','shree  kadel','8/23 everton road ','strathfield ','New South Wales','AUSTRALIA','2135','0412934222','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 12:30:32',0,NULL,3,1,2,1,NULL,'shreekadel'),(17433,733398229018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT076',53,'photographyacc','1942barry','barry.roennfeldtesq@bigpond.com','Barry Roennfeldt','16 Lake St','Rainbow','Victoria','AUSTRALIA','3424','0353951119','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 12:30:33',0,NULL,3,1,3,1,'RA184562969CN ','1942barry\r除了c 里面的再发\r9个环+两种托架'),(17434,731020856001,110417009256,'NIB TianYa 77mm ND8 filter New 77 Neutral Density Grey',1,'AA2314',7.4,'hermeshine','arkadiykr','krasnoyarovi@gmail.com','Arkadiy Krasnoyarov','Mangeldina 44- 70','Shymkent','UKO','KAZAKHSTAN','160005','+77057003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 12:31:21',0,NULL,3,1,17,0,NULL,'arkadiykr'),(17435,731022278001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','arkadiykr','krasnoyarovi@gmail.com','Arkadiy Krasnoyarov','Mangeldina 44- 70','Shymkent','UKO','KAZAKHSTAN','160005','+77057003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 12:36:08',0,NULL,3,1,2,1,NULL,'arkadiykr\r绿叶 CPL  77mm   1\r天涯 ND8 77mm      1\r绿叶 渐变镜 77mm     1'),(17436,857595587015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','petercoster','dragonslairfilms@yahoo.co.uk','peter  coster','4 chestnut way','bramley','Surrey','UNITED KINGDOM','GU5 0JB','01483893589','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 12:49:13',0,NULL,3,1,3,1,'RA184562589CN\r ','petercoster'),(17437,731017905001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','chencz2010','goomba@email.cz','Jan Lysý','Sokolovská 1530','Sokolov','výchozí','CZECH REPUBLIC','356 05','721290911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 12:21:42',0,NULL,3,1,2,1,NULL,'chencz2010\r灰色'),(17438,731024036001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','fotograf-ssa','ssa@mail.primorye.ru','Sergey A Shuvalov','Oceanskiy pr.  101A - 60','Vladivostok','RUSSIA','RUSSIAN FEDERATION','690002','+7 902 555 2409','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 13:14:10',0,NULL,3,0,3,1,'RA184562819CN\r ','fotograf-ssa\r52 mm - 3pcs\r58 mm - 7pcs\r已入库'),(17439,731041181001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','kyebell','jbell232003@yahoo.com','Janine Belleisle','9306 Sandrock rd','Eden','NY','UNITED STATES','14057-9522','(716) 425-5163','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 13:45:26',0,NULL,3,0,1,1,NULL,'kyebell\r110v 的   已入库'),(17440,773316578002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pilot5253','ravit1020@nana10.co.il','ravit mental','kibuz dgania b<br>kibuz dgania b','kibuz dgania b','israel','ISRAEL','15130','0506274895','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 13:48:04',0,NULL,3,1,3,1,'RA184562751CN\r ','pilot5253'),(17441,789564682017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','shiyam.selvarajah','shiyam@optusnet.com.au','Shiyam Selvarajah','13A Dawn Ave<br>HECTORVILLE','Adelaide','South Australia','AUSTRALIA','5073','0872256553','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 14:00:13',0,NULL,3,1,2,1,NULL,'shiyam.selvarajah'),(17442,843412282016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','rainybaby22','guruprof@gmail.com','Nigel Martin','Merrymeet<br>Kingstreet','Combe Martin','Devon','UNITED KINGDOM','EX34 0DA','01271882819','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-09-30 14:22:27',0,NULL,3,1,4,1,'YW866012255CN ','rainybaby22\r英标'),(17443,731054089001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','xdecarlos','xatxu69@gmail.com','xabier  De Carlos Garcia','san ignacio auzunea portal 2B piso 3D','Durango','País Vasco','SPAIN','48200','685769605','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 14:31:54',0,NULL,3,1,3,1,'RA184562955CN\r ','xdecarlos\r67mm 转接环\r'),(17444,731060595001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','hasarinda','hasarinda86@gmail.com','Hasarinda Thenuwara','28/7B, Katuwawala Gardens,<br>Katuwawala Rd, Maharagama','Colombo','Western','SRI LANKA','CO 10280','0715229514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 14:48:49',0,NULL,3,0,2,1,NULL,'hasarinda'),(17445,861272446015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','cow_rulz','sales@scampc.com.au','Steven Cragg','23 Off Street','Gladstone','Queensland','AUSTRALIA','4680','0749725333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 14:55:13',0,NULL,3,1,2,1,NULL,'cow_rulz'),(17446,733444788018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',78,'photographyacc','cow_rulz','sales@scampc.com.au','Steven Cragg','23 Off Street','Gladstone','Queensland','AUSTRALIA','4680','0749725333','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-09-30 14:59:17',0,NULL,3,1,4,1,'YW866012266CN ','cow_rulz\r澳标\r'),(17447,773197530002,120757500040,'New Rolling Hard Case with Dividers for Photo Equipment',1,'AD1165',125,'hermeshine','nichole.mainville','main3marie@gmail.com','Nichole mainville','491 Scott blvd','Castle Rock','CO','UNITED STATES','80104','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 15:05:40',0,NULL,3,1,4,1,'YW866012292CN ','nichole.mainville'),(17448,773341802002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','rayhopelight','antoinerojak@yahoo.com.sg','Anthony Yap','35, Jalan Tari Zapin','Singapore','NA','SINGAPORE','799071','65-97935473','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 15:09:44',0,NULL,3,1,17,0,NULL,'rayhopelight'),(17449,773343692002,120451406324,'New EyeCup for Nikon D80 D90 D200',1,'AA1203',2.48,'hermeshine','rayhopelight','antoinerojak@yahoo.com.sg','Anthony Yap','35, Jalan Tari Zapin','Singapore','NA','SINGAPORE','799071','65-97935473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 15:15:13',0,NULL,3,1,3,1,'RA184562601CN\r ','rayhopelight\r2云柔    1\r眼罩 D300    1'),(17450,733455582018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','becesafhtx','jcarlosbecerra@yahoo.es','juan carlos becerra becerra','PZA ESPAÑA 12 (oficina de Correos)','zafra','Extremadura','SPAIN','06300','618420892','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 15:31:19',0,NULL,3,1,2,1,NULL,'becesafhtx'),(17451,789605589017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','hachiko777','dushku5x5@hotmail.it','ilaria medda','via emilia levante 34','bologna','Bologna','ITALY','40139','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 15:57:40',0,NULL,3,1,2,1,NULL,'hachiko777'),(17452,789613691017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','angel*creations06','smithangeldawn@hotmail.com','Angel Smith','308 Latham Ln','Scottsboro','AL','UNITED STATES','35768-5555','(256) 587-3448','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 16:19:33',0,NULL,3,1,1,1,NULL,'angel*creations06'),(17453,861312353015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','bulldog045','merisi12@alice.it','Fabio Merisi','Via IV Novembre nr.50','Quarrata','PT','ITALY','51039','0573717672','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 16:25:01',0,NULL,3,1,2,1,NULL,'bulldog045\r地址里电话换成这个\rtel.3313660260\r第一遍单子没打电话   重新打'),(17454,733491400018,280683075819,'Stereo Microphone for DC DV Camcorder 60D 5D II 7D 550D',1,'AA1215',42.99,'photographyacc','xristosdim2011','xristosdimakopoulos@yahoo.gr','xristos dimakopoulos','kurillou arxiepiskopou 56, skagiopoulio<br>skagiopoulio','patras','patras','GREECE','26222','00306942444129','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 17:08:37',0,NULL,3,1,3,1,'RA184562853CN\r ','xristosdim2011'),(17455,730900154001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','oxanagera','oxanagera7599@mail.ru','Alexei Kachurin','Lenina, 6-25','Orsk','Orenburgskay oblast','RUSSIAN FEDERATION','462420','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 17:18:38',0,NULL,3,0,3,1,'RA184562875CN\r ','oxanagera\rxxl 已入库'),(17456,789638848017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.5,'photographyacc','poddanicola','poddanicola@tiscali.it','Nicola Podda','Via Matteotti 61','Sanluri','CA','ITALY','09025','3471111708','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 17:21:17',0,NULL,3,1,2,1,NULL,'poddanicola'),(17457,773391297002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',3,'AKT049',105,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 17:36:37',0,NULL,3,1,3,1,'RA184564797CN ','krisvisual\r6个\r分开发 三个一票   分两票'),(17458,773330158002,120601700730,'TianYa  ND2 Filter for Cokin P Series Neutral Density',1,'AA2323',7.2,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:43:23',0,NULL,3,1,17,0,NULL,'danieke2000'),(17459,773330116002,120462263667,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:43:24',0,NULL,3,1,17,0,NULL,'danieke2000'),(17460,773330137002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:43:24',0,NULL,3,1,17,0,NULL,'danieke2000'),(17461,773330086002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:43:25',0,NULL,3,1,17,0,NULL,'danieke2000'),(17462,773330053002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','danieke2000','daniel_snudeg@hotmail.com','Daniel Mork','Furuvegen 18F','Trondheim','Jakobsli','NORWAY','7058','0047 90047349','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 17:43:26',0,NULL,3,1,3,1,'RA184562972CN ','danieke2000\r天涯方形滤镜  ND2    1\r天涯方形滤镜  渐变棕    1\r天涯方形滤镜  渐变灰    1\r天涯方形滤镜  渐变橙    1\r天涯方形滤镜  渐变蓝     1'),(17463,861354503015,250615144328,'YongNuo Flash Battery Pack 8*AA for Nikon Flash SB800',2,'AB3309',65.98,'hutongstore','lario*2008','doylataguerra@yahoo.es','Alfonso Lario','Batiste mut 18 B8<br>El Campello','Alicante','Comunidad Valenciana','SPAIN','03560','965630925','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 17:53:41',0,NULL,3,1,3,1,'RA184562990CN\r ','lario*2008'),(17464,731131580001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','2d_de','kantakt@hbab.de','Torsten Kant','Königstor 14','Kassel','','GERMANY','34117','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 18:09:58',0,NULL,3,1,2,1,NULL,'2d_de'),(17465,861365904015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','phangazone','phanga@msn.com','Reginaldo Sousa','Rua de Nachingweia Nº487','Maputo','Cidade de Maputo','MOZAMBIQUE','1101','(+258) 823916810','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-09-30 18:14:19',0,NULL,3,1,6,1,'EE495359738CN ','phangazone\r背景布绿色\r欧标'),(17466,843562057016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','lunaloco_be','lunaloco@megarave.com','Kristof Meyssen','Lombardsijdestraat 1 bus 0501','Nieuwpoort','','BELGIUM','8620','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 19:43:04',0,NULL,3,1,3,1,'RA184562561CN ','lunaloco_be'),(17467,789711849017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','andreasvandenhoogen','andreas@vandenhoogen.se','Andreas van den Hoogen','Stängselgatan 10','Göteborg','Västra Götaland','SWEDEN','41728','0735059651','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-09-30 20:00:20',0,NULL,3,1,2,1,NULL,'andreasvandenhoogen'),(17468,861438524015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','martinrenshaw','martinrenshaw@aol.com','Martin Renshaw','Synetrix LTD, E-Innovation Centre<br>Uni Of Wolverhampton, Priorslee','Telford','Shropshire','UNITED KINGDOM','TF2 9FT','07966783439','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 20:26:10',0,NULL,3,1,3,1,'RA184562663CN\r ','martinrenshaw'),(17469,861461080015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','wefixit4u','peter.studd@me.com','Peter Studd-Williams','20 Cavalry Square','Chelsea','LONDON','UNITED KINGDOM','SW34RB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 21:14:40',0,NULL,3,1,3,1,'RA184562915CN\r ','wefixit4u'),(17470,773482240002,120751864132,'Lifei LIFE-160 Studio Strobe flash Light 160W Monolight',2,'AD1153',134,'hermeshine','305marcoscalia','comprase_bay@live.com','INDUSTRIAS SCALIA SA DE CV','7979 NW 21st St<br>SAL 10069','DORAL','FL','UNITED STATES','33122-1630','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-09-30 21:16:25',0,NULL,5,0,18,0,NULL,'305marcoscalia\r咱们没有110v 的\rINDUSTRIAS SCALIA SA DE CV\r7979 NW 21st St \rSAL 10069 \rDORAL FL 33122-1630 \rUnited States'),(17471,731083097001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','vempire-2008','vempire@rambler.ru','Dmitry Krechetov','Bryanskogo Fronta Str.,<br>18/1-27','Bryansk','','RUSSIAN FEDERATION','241037','+79102310846','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 21:52:21',0,NULL,3,1,2,1,NULL,'vempire-2008'),(17472,731219671001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','steve533','comtechplus@comcast.net','Steven Mowles','7834 Locher Way','Citrus Heights','CA','UNITED STATES','95610','','NoPaymentFailure','CheckoutComplete','Other','2011-09-30 22:01:19',0,NULL,3,0,1,1,NULL,'steve533\rXXXL 已入库'),(17473,789768820017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','calatria29','calatria29@yahoo.com.au','Aldo Ierace','5 Pitcairn Ave. Kidman Park','Adelaide','South Australia','AUSTRALIA','5025','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-09-30 22:29:26',0,NULL,3,1,2,1,NULL,'calatria29'),(17474,861497186015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.12,'hutongstore','conjohno','coshea@key-environmental.co.uk','Con O\'Shea','Evergreen<br>44 Captains Hill','Alcester','Warwickshire','UNITED KINGDOM','B49 6QN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-09-30 22:51:58',0,NULL,3,1,2,1,NULL,'conjohno'),(17475,730832533001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-09-30 23:03:51',0,NULL,3,1,8,1,'CP235627578CN ','saud-p\r贴made in china  \r申报实值lighting kit  $200'),(17476,861506008015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',20.99,'hutongstore','dpssy42','antoinedurivaux@gmail.com','antoine durivaux','13 rue destienne dorves','chatillon','Île-de-France','FRANCE','92320','0625650644','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:23:24',0,NULL,3,1,3,1,'RA184589428CN ','dpssy42'),(17477,861505944015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:21',0,NULL,5,1,18,0,NULL,'photosax'),(17478,843650230016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:22',0,NULL,3,1,17,0,NULL,'photosax'),(17479,861504625015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:22',0,NULL,3,1,17,0,NULL,'photosax'),(17480,861496473015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:23',0,NULL,3,1,17,0,NULL,'photosax'),(17481,861505540015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:23',0,NULL,3,1,17,0,NULL,'photosax'),(17482,861505104015,250611204939,'Adjustable Padded shoulder Neck Strap for 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:26:24',0,NULL,3,1,17,0,NULL,'photosax\r'),(17483,731241369001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','pstjean3916','pstjean3916@videotron.ca','Pierre St-Jean','3916 Guenette','Laval','QC','CANADA','H7T 2G1','(514) 467-3265','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-09-30 23:29:04',0,NULL,3,1,2,1,NULL,'pstjean3916'),(17484,731241546001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','givingvalue','jeremiahbarlow@gmail.com','Jeremiah Barlow','PO Box 1855<br>140 W. Township Ave','Colorado City','AZ','UNITED STATES','86021-1855','(435) 467-1271','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-09-30 23:37:17',0,NULL,3,0,3,1,'RA184562650CN\r ','givingvalue\r110v 的  已入库\r四个灯泡'),(17485,843660456016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','56ks','janileink@web.de','Janusz Klosowski','Seilerstr.62a','Würzburg','','GERMANY','97084','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-09-30 23:51:28',0,NULL,3,1,2,1,' ','56ks'),(17486,731248614001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 00:12:24',0,NULL,3,1,17,0,NULL,'ciafquito'),(17487,773527245002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',1,'AC1203',5.6,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 00:12:24',0,NULL,3,1,17,0,NULL,'ciafquito'),(17488,773526630002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1202',12,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 00:12:25',0,NULL,3,1,3,1,' RA184567201CN','ciafquito\r镜头筒 中号    1\r镜头筒 大号     1\r4片装的滤镜袋    3'),(17489,789800260017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','case540','lukecasey2003@yahoo.ca','Luke Casey','13 Boyanda St','Wishart','Queensland','AUSTRALIA','4122','0731629667','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 00:34:42',0,NULL,3,1,2,1,NULL,'case540'),(17490,789768139017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','kewpie_tarako','pochogo@gmail.com','Francisca Garcia Araya','Av. SUECIA 750 DEPTO 1207 PROVIDENCIA','SANTIAGO','METROPOLITANA','CHILE','7510297','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 00:41:32',0,NULL,3,1,17,0,NULL,'kewpie_tarako'),(17491,789804325017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','alan_wks','alan_wks@hotmail.com','Alan K wong','7 washington place','brisbane','Queensland','AUSTRALIA','4116','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 00:53:20',0,NULL,3,1,2,1,NULL,'alan_wks'),(17492,789818608017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','pictrs4u','robboyce67@gmail.com','ROB BOYCE','206 WELLINGTON ST S','GODERICH','ON','CANADA','N7A3T5','(519) 524-0567','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 01:56:02',0,NULL,3,1,2,1,NULL,'pictrs4u'),(17493,733682578018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','manoloau','manoloz@gmail.com','Manolo Gonzalez','9 Hercules Street','Hamilton','Queensland','AUSTRALIA','4009','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-01 03:06:43',0,NULL,3,1,4,1,'YW866012303CN ','manoloau'),(17494,733686307018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','nagaevart','nagaev_art@mail.ru','Artem Nagaev','ul. Lermontovskaya d.125 kv139','Rostov-on-Don','Rostovskaya oblast','RUSSIAN FEDERATION','344010','89198867194','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 03:28:00',0,NULL,3,1,2,1,NULL,'nagaevart'),(17495,733695226018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',36,'photographyacc','wacmwamaudave','wacmwa@hotmail.com','maudave stephan','12 collett pde','parramatta','New South Wales','AUSTRALIA','2150','0435769297','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 04:20:27',0,NULL,3,1,3,1,' RA184589025CN','wacmwamaudave'),(17496,733697405018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','weston35169','pdweston@virginbroadband.com.au','PETER WESTON','1 MANNEVILLE STREET','WENDOUREE','Victoria','AUSTRALIA','3355','0353394569','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 04:48:28',0,NULL,3,1,2,1,NULL,'weston35169'),(17497,773596159002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','obrocanteur','kabbaj.othman@hotmail.com','Kabbaj Othmane','9 rue alexandre cabanel','TOULOUSE','Midi-Pyrénées','FRANCE','31000','0628067900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:08:55',0,NULL,3,1,17,0,NULL,'obrocanteur'),(17498,731315050001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','obrocanteur','kabbaj.othman@hotmail.com','Kabbaj Othmane','9 rue alexandre cabanel','TOULOUSE','Midi-Pyrénées','FRANCE','31000','0628067900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 06:16:09',0,NULL,3,1,17,0,NULL,'obrocanteur'),(17499,731315889001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','obrocanteur','kabbaj.othman@hotmail.com','Kabbaj Othmane','9 rue alexandre cabanel','TOULOUSE','Midi-Pyrénées','FRANCE','31000','0628067900','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-01 06:21:27',0,NULL,3,1,17,0,NULL,'obrocanteur'),(17500,789872891017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','bartong1975','deloceano.photography@gmail.com','Glen Barton and Kristel Rae','6 Domain Road','JAN JUC','Victoria','AUSTRALIA','3228','0352619233','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 06:49:30',0,NULL,3,1,17,0,NULL,'bartong1975'),(17501,773609777002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','jevgenijast','j_steinbe@yahoo.com','Jevgenija Steinberga','Dzelzavas 35 k1, 49','Riga','','LATVIA','LV-1084','+37126454313','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 07:24:04',0,NULL,3,1,2,1,NULL,'jevgenijast'),(17502,773617869002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'',55,'hermeshine','auroralin4','lin4.htun@gmail.com','lin htun','Blk 27, Marsiling Drive, #08-241','default','Singapore','SINGAPORE','730027','6591282999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 08:05:06',0,NULL,3,1,3,1,'RA184562941CN\r ','auroralin4\r新款nikon 皮包     1'),(17503,861631737015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.12,'hutongstore','harislojo','haris_lojo@hotmail.com','Haris Lojo','Köpmangatan 33','Örebro','none','SWEDEN','70223','+46(0)707504966','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 08:21:45',0,NULL,3,0,2,1,NULL,'harislojo'),(17504,733752360018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','francineschaepper','fs@mymakeup.ch','Francine Schaepper','3/70 BArkly Street','St Kilda','Victoria','AUSTRALIA','3182','0449558585','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-01 09:20:06',0,NULL,3,1,3,1,'RA184562734CN\r ','francineschaepper'),(17505,843802477016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','tlec3646','downpatrickfc@me.com','thomas leckey','3 school road killough','downpatrick','Down','UNITED KINGDOM','BT307QL','02844842700','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 09:46:20',0,NULL,3,1,3,1,'RA184562694CN\r ','tlec3646'),(17506,773640171002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','andris601','andris600@inbox.lv','Andris Antoņevičs','Salnas 34-1','Riga','','LATVIA','1021','00371 23456788','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 09:46:41',0,NULL,3,1,3,1,'RA184562685CN\r ','andris601'),(17507,861656198015,250845745737,'New Stainless Steel Spanner Wrenches for lens repair',1,'AD1123',28,'hutongstore','henry_the_b','heiner_blauhorn@web.de','Heiner Blauhorn','Hasslerstrasse 20','Aachen','','GERMANY','52066','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 09:50:12',0,NULL,3,1,3,1,'RA184562513CN ','henry_the_b'),(17508,733793277018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','041-laura','laura.arnaud@uqconnect.edu.au','Michel Arnaud','11 rue Thomas Hickson Val Plaisance','Noumea','','NEW CALEDONIA','98800','687261406','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 12:00:21',0,NULL,3,1,3,1,'RA184562907CN\r ','041-laura'),(17509,861716429015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','lasse.soundtrack','lasse@soundtrack.no','Lasse Gulbrandsen','Trollstien 10','KROKSTADELVA','Buskerud','NORWAY','3055','90927309','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-01 12:53:47',0,NULL,3,1,12,1,'1107585990\r','lasse.soundtrack\r欧标\r燕文已经截下来了  \rCP235627618CN \r实重7.6  泡重9.8\r最终计费： 10.5'),(17510,733818004018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','kimma18','masson_kim_18@hotmail.com','Kim Masson','608, rue Bonaventure','Trois-Rivières','QC','CANADA','G9A 2B7','(819) 386-2491','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 13:25:42',0,NULL,3,0,2,1,NULL,'kimma18\r灰色'),(17511,773713648002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','skinnyjesuslover','daveandrewwilliams@hotmail.com','David Williams','4407 SW 3rd Ave','Amarillo','TX','UNITED STATES','79106','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 14:21:01',0,NULL,3,1,1,1,NULL,'skinnyjesuslover'),(17512,731438568001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','carl-attrezzi','guido.r@libero.it','GUIDO ROCCON','VIA RIVE BET 1B','COLLE UMBERTO','TV','ITALY','31014','+393409095351','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 14:48:32',0,NULL,3,1,3,1,'RA184562725CN\r ','carl-attrezzi\rLight Bulb  $12'),(17513,733849265018,280667759489,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',3.88,'photographyacc','pal996','pal996@maltanet.net','John Joseph Pace','Pace Associates Ltd<br>134, Stefano Zerafa Street','Marsa','Marsa','MALTA','HMR03','99441617','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 15:02:16',0,NULL,3,1,2,1,NULL,'pal996'),(17514,861765536015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','vrframe','plamenw@yahoo.com','Plamen Penev','91, Stara Planina Str.','Tryavna','Gabrovo','BULGARIA','5350','+359887934408','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 15:07:35',0,NULL,3,1,3,1,'RA184562615CN ','vrframe'),(17515,773731811002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','joened','joened29@aol.com','Joseph N. Morefield','1130 Glory Vine Rd','Whitsett','NC','UNITED STATES','27377-9303','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 15:16:26',0,NULL,3,1,3,1,'RA184562748CN\r ','joened'),(17516,733866719018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','ttwinkle2011','ttwinkle7@hotmail.com','Supun Weerasinghe','10/45 Mayura Mawatha<br>Bellanthara Pepiliyana','Boralasgamuwa','COLOMBO','SRI LANKA','00001','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 15:52:55',0,NULL,3,1,3,1,'RA184562867CN\r ','ttwinkle2011\r已入库'),(17517,731476688001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','lrcs','roger.simmons@mail.com','Roger Simmons','9 Joseph St.,  Box 352','Emsdale','ON','CANADA','P0A1J0','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,2,1,NULL,'lrcs\r55mm 转接环'),(17518,861816568015,250746713774,'62mm Graduated Neutral Density Filter Gradual Grey 62',1,'AA3318',5.2,'hutongstore','seachief97','sveihb@gmail.com','Svein Harald Bornø','St. Olavs Gt. 29A','Harstad','','NORWAY','9405','+4791712246','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-01 16:57:25',0,NULL,3,1,2,1,NULL,'seachief97'),(17519,731503893001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','macforeq','mac942tbr@aol.com','Nata Jackson','310 T Elmer Cox Rd','Greeneville','TN','UNITED STATES','37743-6957','(423) 798-0555','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 17:44:53',0,NULL,3,1,1,1,NULL,'macforeq'),(17520,731527190001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','murtadabay','murtada_s@hotmail.com','ITS SP-698288450','310 Patterson Plank Road,','Carlstadt','NJ','UNITED STATES','07072','201 549 1500','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 18:40:17',0,NULL,3,1,1,1,NULL,'murtadabay'),(17521,733958537018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','janturek','jan.turek@gmail.com','Jan Turek','Prazskeho 28/601','Praha 5','','CZECH REPUBLIC','15200','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-01 19:25:40',0,NULL,3,1,2,1,NULL,'janturek'),(17522,731539333001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','dreamstudiosnj','dreamstudios@live.com','NJ Richard','902 7th St','Lafayette','LA','UNITED STATES','70501','(337) 504-3333','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-01 19:27:33',0,NULL,3,0,1,1,NULL,'dreamstudiosnj\r110v 的    已入库'),(17523,731551257001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','andrewtitov','xdiv@lavabit.com','Андрей Титов','Клиническая<br>дом 7 квартира 12','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350042','+79054752330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 19:33:40',0,NULL,3,1,5,1,'CP235627621CN ','andrewtitov'),(17524,773871552002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','clanmcdonald2006','smcdonald@cableplusinc.com','Steven McDonald','2012 Corporate Ln, c/o Cable Plus<br>Ste 116','Naperville','IL','UNITED STATES','60563','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 21:03:40',0,NULL,3,1,1,1,NULL,'clanmcdonald2006'),(17525,844101590016,260810104926,'New 35\" 90cm Studio Flash Reflective Umbrella Softbox',1,'AD1127',13.9,'hutongstore','newey13','lisap@entropie.demon.co.uk','Lisa Phillips','7 Highfield Road<br>wigginton','Tring','Hertfordshire','UNITED KINGDOM','HP236EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 21:33:39',0,NULL,3,1,17,0,NULL,'newey13'),(17526,861956655015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','texessteph','ell.wright@ntlworld.com','ellen wright','48 Hatfield Road<br>Billingham','Stockton-on-Tees','Cleveland','UNITED KINGDOM','TS23 3AL','01642652168','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 21:35:58',0,NULL,3,1,4,1,'YW866012314CN ','texessteph'),(17527,731601067001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','ops4u2','joe.dallacqua@gmail.com','Joe Dallacqua','358 Houston Dr','Thousand Oaks','CA','UNITED STATES','91360-6061','(805) 870-5877','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-01 21:46:47',0,NULL,3,1,3,1,'RA184589051CN ','ops4u2'),(17528,861966252015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','nadoy12010','nadoy1@yahoo.com','Dominador Jadulco','81 Grosvenor tower<br>Broadway','Belfast','Antrim','UNITED KINGDOM','BT12 6DS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-01 21:53:25',0,NULL,3,1,3,1,'RA184562629CN ','nadoy12010'),(17529,731610740001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','obrocanteur','kabbaj.othman@hotmail.com','Kabbaj Othmane','9 rue alexandre cabanel','TOULOUSE','Midi-Pyrénées','FRANCE','31000','0628067900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-01 22:19:31',0,NULL,3,1,4,1,'YW866012325CN ','obrocanteur\r倒影板（白黑）   1\r2b柔     1\r三脚架 伟峰 WF-6663A     1\r圆形柔光棚 60cm    1'),(17530,734055632018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',40,'photographyacc','kimberleyrenee88','kimberleylaudzevics@hotmail.com','Kimberley Laudzevics','26 Hillsdale Rise','Darch','Western Australia','AUSTRALIA','6065','0419996056','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 00:22:55',0,NULL,3,1,17,0,NULL,'kimberleyrenee88'),(17531,734055666018,280689695893,'New Continuous Lighting System umbrella without bulbs',1,'AKT009',85,'photographyacc','kimberleyrenee88','kimberleylaudzevics@hotmail.com','Kimberley Laudzevics','26 Hillsdale Rise','Darch','Western Australia','AUSTRALIA','6065','0419996056','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-02 00:22:56',0,NULL,3,1,4,1,'YW866012351CN ','kimberleyrenee88\r澳标\r除了c 里面的再发\r45w 5500k 灯泡 220v    4 '),(17532,773935543002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','pablocisneros','shantiyogananda@hotmail.com','Pablo Cisneros','Bolivar 20-35 y Quito','Ambato','Tungurahua','ECUADOR','1801','+593 99226730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 00:54:18',0,NULL,3,1,2,1,NULL,'pablocisneros'),(17533,790240803017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','tamb7247','tambler24@hotmail.com','Tatum Ambler','3 Raynes Park Road','Melbourne','Victoria','AUSTRALIA','3188','0395210325','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 01:32:38',0,NULL,3,1,2,1,NULL,'tamb7247'),(17534,8881317531185277,111,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',33,'aliexpress','1004595065','no@no.com','Maksim Ageykin','ul. Lenina, dom 17, kv.58','Kostomuksha	','Karelia','RUSSIAN FEDERATION	','186931','+8 909 5697898',NULL,NULL,NULL,'2011-10-02 04:53:05',0,NULL,3,1,3,1,'RA184562527CN ',NULL),(17535,8881317531366705,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',50,'aliexpress','1004602574','alexsalt@gmail.com','Alexey Saltykov','Zvezdny bulvar 30/2 12','Moscow','','RUSSIAN FEDERATION	','129075','+007 095 6165463',NULL,NULL,NULL,'2011-10-02 04:56:06',0,NULL,3,1,17,0,NULL,''),(17536,731698883001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','jarmila.h','hvezdovaj@centrum.cz','Jarmila Hvezdova','8 Dorunda Avenue','Beachmere','Queensland','AUSTRALIA','4510','00610411202951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 05:02:47',0,NULL,3,1,3,1,'RA184589502CN ','jarmila.h'),(17537,734123273018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','suhadajayamanne','sirimedurapro@gmail.com','suhada jayamanne','no 197/35A,Padri PioMavatha,Taladuwa ,Negombo,','Negombo','western','SRI LANKA','11500','+94 77 3 611 554','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 05:58:55',0,NULL,3,1,3,1,'RA184562884CN\r ','suhadajayamanne'),(17538,731708139001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',14.9,'hermeshine','dannyb_187','dannyb_187@hotmail.com','Daniel Rawlins','20 Bellavista Cresecent','Clayton South','Victoria','AUSTRALIA','3169','0395466970','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 06:02:42',0,NULL,3,1,2,1,NULL,'dannyb_187'),(17539,790294924017,270757371314,'Studio Light 900W Continuous Lighting Complete Kit  ',1,'AKT087',170,'photographyacc','aznmaz','print@easyazprint.com.au','Aaron Womersley~ EASYAZ PRINT','2/132<br>North Road','Warragul','Victoria','AUSTRALIA','3820','0356233261','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-02 06:11:29',0,NULL,3,1,4,1,'YW866012362CN ','aznmaz\r澳标'),(17540,790301608017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',65,'photographyacc','petteram64','pam2@broadpark.no','Petter Amundsen','Hardangervegen 498','Bergen','Haukeland','NORWAY','5268','+4741147897','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 06:34:25',0,NULL,3,1,3,1,'RA184562646CN\r ','petteram64'),(17541,774003380002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','bopps2006','nadinejoh@hotmail.com','Nadine johnson','6/10 Moore Street','Somerton park','South Australia','AUSTRALIA','5044','0883761816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 06:37:08',0,NULL,3,1,2,1,NULL,'bopps2006'),(17542,731715984001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','photopass92','resonans_ntd@yahoo.com','Nikolay Damyanliev','19,allée des Glycines','Rueil Malmaison','Ile-de-France','FRANCE','92500','0628074633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-02 06:43:34',0,NULL,3,1,3,1,'RA184562632CN\r ','photopass92'),(17543,862117104015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','bigscience','michael@trebbien.info','Michael Christensen','Teglbakken 40 B','Hojbjerg','DK','DENMARK','8270','+4527444345','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 07:13:54',0,NULL,3,1,3,1,'RA184562535CN ','bigscience\r申报：15$,gift'),(17544,731726350001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',3,'AA2101',107,'hermeshine','tbaier1','tomaz.baier@gmail.com','Tomaž Baier','Trčova 260','Maribor','Malečnik','SLOVENIA','2229','0038641824993','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-02 07:33:29',0,NULL,3,0,3,1,'RA184562836CN\r\r ','tbaier1\rL  已入库\r！！注意，这3件背心一件一件分开发。\rRA184562822CN\rRA184562840CN'),(17545,734147847018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','yaroslaw1987','yaroslawstirliz@mail.ru','Yaroslaw Isaev','Festivalnaya, 17, 32','Mosow','','RUSSIAN FEDERATION','125195','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 07:54:22',0,NULL,3,1,3,1,'RA184562592CN\r ','yaroslaw1987'),(17546,734181917018,280745347210,'Photo Video Continuous light 5 Head E27 AC Bulb Socket with 60x90 Softbox',1,'AD1191',62,'photographyacc','eclipse-peter','ebay@store.bg','Petar Vanchev','p.o.box 9<br>Store EOOD','Sofia','Sofia','BULGARIA','1309','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 09:41:42',0,NULL,3,1,3,1,'RA184589414CN ','eclipse-peter\r欧标 '),(17547,844335166016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','kawaldidulhan','singhkawal22@googlemail.com','kawal singh','5A Thames Avenue','Guisborough','Cleveland','UNITED KINGDOM','TS14 8AD','01287632380','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 10:48:05',0,NULL,3,1,2,1,NULL,'kawaldidulhan'),(17548,731790061001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1203',10,'hermeshine','raniel22','einar@bkkfiber.no','Einar Langøen','Tjødnavegen 75','Straume','Straume','NORWAY','5353','0047-98236130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 10:54:46',0,NULL,3,1,17,0,NULL,'raniel22'),(17549,734203281018,280678918166,'Neoprene Camera Cover Case for small Canon & semi slr S',1,'AC2303',5.9,'photographyacc','fabiola.medeiros','fabiolamdr@yahoo.com.br','Fabiola Medeiros','12/69 Leichhardt St','Brisbane/ Spring Hill','Queensland','AUSTRALIA','4000','0413812038','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 10:56:35',0,NULL,3,1,2,1,NULL,'fabiola.medeiros'),(17550,774078943002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',2,'AA1315',5.98,'hermeshine','raniel22','einar@bkkfiber.no','Einar Langøen','Tjødnavegen 75','Straume','Straume','NORWAY','5353','0047-98236130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 10:58:36',0,NULL,3,1,2,1,NULL,'raniel22\r6片装的滤镜袋   2\r机身盖/镜头后盖  Canon   2'),(17551,734227033018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','ricangela','ricangel@tpg.com.au','Richard Wong','41 Tamar st , Bayswater','Bayswater','Victoria','AUSTRALIA','3153','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 11:51:42',0,NULL,3,1,2,1,NULL,'ricangela'),(17552,774101421002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','diyanedyna','mailzz09@yahoo.com.sg','Ismail Awang','Room 515A<br>65b Karl Marx Street (Pharmcollege hostel)','Kursk','kursk','RUSSIAN FEDERATION','305029','+79202628971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 12:05:14',0,NULL,3,1,2,1,NULL,'diyanedyna'),(17553,790412257017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',2,'AKT052',85.6,'photographyacc','vmie75','vmie@yahoo.com','RAHIMI RAMLI (s/n:252895)','PO BOX 686,<br>Line Maint,Engg Dept,','Dubai','','UNITED ARAB EMIRATES','_','(971) 503-4428 ext.: 26','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 12:14:14',0,NULL,3,1,3,1,'RA184562558CN ','vmie75\r分开发（那一共几个单号？）'),(17554,734235666018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','dskrt2000','woodysue@live.com.au','Suzanne Denise Thornton','66 Kathleen Crescent<br>Wondunna','Hervey Bay','Queensland','AUSTRALIA','4655','0741242456','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 12:15:21',0,NULL,3,1,2,1,NULL,'dskrt2000'),(17555,790427172017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',4,'AD1168',60,'photographyacc','bartong1975','deloceano.photography@gmail.com','Glen Barton and Kristel Rae','6 Domain Road','JAN JUC','Victoria','AUSTRALIA','3228','0352619233','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 12:52:33',0,NULL,3,1,3,1,'RA184589034CN ','bartong1975\r反光伞110cm    1\r沙袋（大）     4'),(17556,731854249001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','k-dizzle92','kavinda.kottege@gmail.com','Kavinda Kottege','48 Honeyeater Grove','Narre Warren','Victoria','AUSTRALIA','3805','0425719408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 14:07:58',0,NULL,3,1,2,1,NULL,'k-dizzle92'),(17557,774152008002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','katiapechard10','katiapechard@sympatico.ca','katia péchard','7 rue gervais','sainte-martine','QC','CANADA','J0S 1V0','(514) 603-2837','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-02 14:20:02',0,NULL,3,1,5,1,'CP235627533CN ','katiapechard10\r加1.6*2.1白色背景布'),(17558,731864634001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','videokuks','videoksy@gmail.com','Oxana Bogatova','Klimashkina 1-84','Moscow','','RUSSIAN FEDERATION','123557','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-02 14:20:27',0,NULL,3,1,3,1,'RA184562411CN ','videokuks'),(17559,731864672001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1203',15,'hermeshine','skymedic622','michael@dollenberg.org','Michael Dollenberg','PO Box 90439<br>Klein Windhoek','Windhoek','','NAMIBIA','9000','+264 61 271700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 14:23:42',0,NULL,3,1,17,0,NULL,'skymedic622'),(17560,774152155002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','skymedic622','michael@dollenberg.org','Michael Dollenberg','PO Box 90439<br>Klein Windhoek','Windhoek','','NAMIBIA','9000','+264 61 271700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 14:23:42',0,NULL,3,1,2,1,NULL,'skymedic622\r6片装的滤镜袋    3\r4片装的滤镜袋      1'),(17561,774168716002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kwotti','katy.floc@gmail.com','Ekaterina Pisarenkova','Asaf\'eva<br>10/291','Saint-Petersburg','','RUSSIAN FEDERATION','194356','+79111669481','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 14:56:16',0,NULL,3,1,3,1,'RA184562500CN ','kwotti'),(17562,774168831002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','a7om1c','xbarsx@inbox.ru','Konstantin Gerdt','Osloer Str.2','Köln','','GERMANY','50765','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:00:11',0,NULL,3,1,17,0,NULL,'a7om1c'),(17563,774168737002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.9,'hermeshine','a7om1c','xbarsx@inbox.ru','Konstantin Gerdt','Osloer Str.2','Köln','','GERMANY','50765','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:01:42',0,NULL,3,1,4,1,'YW866012454CN ','a7om1c\r闪光的柔光箱   60cm    1\r50-70柔光棚 通用塑料卡口    2'),(17564,774173652002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','dru-panca','andrewpantja@yahoo.com','Andrew Andrew','23 Hollywood Av. Apt# 608','North York','ON','CANADA','M2N7L8','(416) 227-9577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:07:02',0,NULL,3,1,3,1,'RA184562473CN ','dru-panca'),(17565,862329449015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','markhak','mark@hakansson.co.uk','Mark Hakansson','31d hillmarton Rd','London','London','UNITED KINGDOM','N7 9JE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 15:23:34',0,NULL,3,1,2,1,NULL,'markhak'),(17566,734321248018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','medman_500','ville.louko@gmail.com','Ville Louko','Korpiviita 21','SEINAJOKI','','FINLAND','60150','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 15:34:49',0,NULL,3,1,2,1,NULL,'medman_500'),(17567,774196840002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','turiddu9882','salvatoregangemict@gmail.com','salvatore gangemi','viale della gioventu 15/B','giarre','CT','ITALY','95014','3402226652','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 15:54:05',0,NULL,3,1,2,1,NULL,'turiddu9882'),(17568,844494915016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','rhey1727','rebhey@gmail.com','Rebecca Heywood','8 Raleigh Close','Ilkeston','Derbyshire','UNITED KINGDOM','de78yd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-02 16:08:56',0,NULL,3,1,3,1,'RA184562703CN\r ','rhey1727'),(17569,734037666018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','wolfframio','ibanmontero@euskalnet.net','Ivan Montero','San Lorenzo 9 7 G','Erandio','Vizcaya','SPAIN','48950','605720497','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 16:31:23',0,NULL,3,1,2,1,NULL,'wolfframio'),(17570,773453068002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',5,'AKT051',57.5,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+79062678380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 17:00:22',0,NULL,3,1,3,1,'RA184562765CN\r ','igrom78\r注意是10只'),(17571,862511930015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.9,'hutongstore','jvkm0411','jvkm411@hotmail.com','Jeffrey Micallef','46 rue de Mondercange','Ehlerange','Luxembourg','LUXEMBOURG','L-4381','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 19:00:42',0,NULL,3,1,2,1,NULL,'jvkm0411'),(17572,862532064015,250804357708,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',1,'AA1306',1.87,'hutongstore','lk08nch','henrikcheng@live.se','Henrik Cheng','Gustav III:s Boulevard 2','SOLNA','SOLNA','SWEDEN','16972','+46709707078','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 19:24:26',0,NULL,3,1,2,1,NULL,'lk08nch'),(17573,774351852002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jibordie','keyframedesigns@gmail.com','Lincoln Key','110 Wilmont Ave','Washington','PA','UNITED STATES','15301-3527','(724) 288-8991','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-02 19:32:59',0,NULL,3,1,3,1,'RA184562495CN ','jibordie'),(17574,773732957002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','c.rodelas','rodelasg@gmail.com','Carlos Rodelas','Irma Hernandez 14 (els cards)','Barcelona','Cataluña','SPAIN','08812','938963386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-02 19:38:03',0,NULL,3,1,3,1,'RA184562371CN ','c.rodelas'),(17575,734518591018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','lynnechelo','chelolynne@yahoo.com','lynne chelo daguplo','14 Wright Street','Laverton','Victoria','AUSTRALIA','3028','0393609643','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 20:11:34',0,NULL,3,1,2,1,NULL,'lynnechelo'),(17576,790728583017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',2,'AC1301',11.96,'photographyacc','funku28','mustafasakizci@ttnet.net.tr','MUSTAFA SAKIZCI','KORESEHITLERI CD. KAYA ALDOGAN SOK. NO :16 ZINCIRLIKUYU','ISTANBUL','TURKEY','TURKEY','34394','00905318650028','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-02 20:55:55',0,NULL,3,1,2,1,NULL,'funku28'),(17577,862625624015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',3.2,'hutongstore','juliukasb','bacev82@gmail.com','JULIUS BACEVICIUS','Apt. 51 Riversdale<br>Upper Dargle Road','Bray','Wicklow','IRELAND','default','0877749338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 21:39:26',0,NULL,3,1,2,1,NULL,'juliukasb'),(17578,862646856015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','norberterdei','norbert.erdei@gmail.com','Norbert Erdei','47. Szent István str.','Nyíregyháza','','HUNGARY','H-4400','0036703350722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-02 22:25:36',0,NULL,3,1,2,1,NULL,'norberterdei'),(17579,862648546015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','theeb4ymonkey','limpingadam@googlemail.com','Adam Evans','12 Llys Close','OSWESTRY','Shropshire','UNITED KINGDOM','SY112UZ','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-02 22:30:42',0,NULL,3,1,4,1,'YW866012336CN ','theeb4ymonkey\r1.6*2.1黑色+白色背景布'),(17580,734608229018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','museo29','freez_222000@yahoo.com.au','D. Millane','PO BOX 8049','Sumner','Victoria','AUSTRALIA','3057','0419369013','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 23:52:16',0,NULL,3,1,2,1,NULL,'museo29'),(17581,790800084017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','gryawq','andrewgregory81@yahoo.com.au','Andrew Gregory','153 New Mount Pleasant Road','Mount Pleasant','New South Wales','AUSTRALIA','2519','61242850305','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-02 23:59:39',0,NULL,3,1,2,1,NULL,'gryawq'),(17582,734620030018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','gearsau','pjgeran@iinet.net.au','PETER GERAN','The Billabong<br>Unit 63 / 13 Bowden Street','NERANG','Queensland','AUSTRALIA','4211','0406623399','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 00:29:28',0,NULL,3,0,3,1,'RA184562717CN\r ','gearsau\rxxxl   已入库'),(17583,8881317602218589,111,'2m x 3m背景架 de 涨杆',1,'',0,'photographyacc','tracygrosvenor77','tracyandgrant@westnet.com.au','Tracy Grosvenor','PO BOX 443','kalbarri','Western Australia','AUSTRALIA','6536','0899371601',NULL,NULL,NULL,'2011-10-03 00:36:58',0,NULL,3,1,3,1,'RA184564443CN\r ','上一票的坏了，补发。 \r正好发掉多的那套横杆，保护好点'),(17584,774516867002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','joao_guarapari','srjoao@terra.com.br','João Batista Assis de Oliveira','Rua Cachoeiro de Itapemirim, nº 243<br>Belo Horizonte (Meaipe)','Guarapari','Espirito Santo','BRAZIL','29208-230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 02:10:58',0,NULL,3,1,3,1,'RA184562425CN ','joao_guarapari\r灯泡是110v 的 \r'),(17585,790851677017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','greglduke','les@gregorys.net.au','Leslie G Gregory','2 Parkland Avenue','Avondale','New South Wales','AUSTRALIA','2530','0407557179','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 02:17:23',0,NULL,3,1,2,1,NULL,'greglduke'),(17586,734670207018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','vanese01','vanesem@gmail.com','McNeill c/o Bennett','82 Anglers Pde','Fishermans Paradise','New South Wales','AUSTRALIA','2539','0244565721','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 03:15:27',0,NULL,3,0,3,1,'RA184564050CN\r ','vanese01\r两块绿色'),(17607,862885900015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 10:52:20',0,NULL,3,1,4,1,'YW868052173CN ','photosax\r4螺丝井字扳手    1\r反光板 80cm 2合1    1\r反光板 100*150 40*60 5合1    1\rDSLR-Rig   类似间架的那个     1\r肩带 canon      1\r反光板  80cm 5合1    1\r圆形柔光棚 50cm    1'),(17587,774541697002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',3,'AE3101',89.97,'hermeshine','kewpie_tarako','pochogo@gmail.com','Francisca Garcia Araya','Av. SUECIA 750 DEPTO 1207 PROVIDENCIA','SANTIAGO','METROPOLITANA','CHILE','7510297','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 03:44:59',0,NULL,3,1,5,1,'CP235627547CN ','kewpie_tarako\r三脚架 伟峰 EI-717    1\r斜臂      3\r又加了三个斜臂'),(17588,862769953015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','ashtrix517','azameza@hotmail.com','Mohamad Nor Azam Ali','No 2 Lorong 1<br>Taman Tualang Indah','Mentakab','Pahang','MALAYSIA','28400','0199110199','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 03:51:35',0,NULL,3,1,3,1,'RA184562368CN ','ashtrix517'),(17589,774556984002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','jsimard01','jean.simar3d@gmail.com','Jean Simard','328 Avro','Pointe-Claire','QC','CANADA','h9r 5w5','(514) 975-3646','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-03 04:40:31',0,NULL,3,0,3,1,'RA184562796CN\r ','jsimard01\rL 已入库'),(17590,774559077002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','teung','to_aha@yahoo.com','SURASIT HARAMI','1147 Soi samakom2<br>Rd.Lardpaow 71 wangtonglang lardpaow','BANGKOK','','THAILAND','10310','08-4976-8606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 04:52:49',0,NULL,3,1,3,1,'RA184562456CN ','teung'),(17591,733630459018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','clueless_ness','vanque@hotmail.com','Vanessa Quake','3506/22 Jane Bell Lane','Melbourne','Victoria','AUSTRALIA','3000','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-03 06:11:49',0,NULL,3,1,4,1,'YW866012340CN ','clueless_ness\r白色'),(17592,774572239002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','nelliew272','nellie_w@exemail.com.au','Narelle  Wajzer','39 Janamba Avenue<br>Kellyville','Sydney','New South Wales','AUSTRALIA','2155','0296292336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 06:14:26',0,NULL,3,1,2,1,NULL,'nelliew272'),(17593,790906389017,270755020049,'New 800W Red Head for Studio Continuous Light Bulb 220v',1,'AO0015',12,'photographyacc','xmarkesthespot','xavier@chariot.net.au','Xavier Wills','PO Box 21','Sellicks Beach','South Australia','AUSTRALIA','5174','0885574308','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 06:37:02',0,NULL,3,1,2,1,NULL,'xmarkesthespot'),(17594,773979654002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','scanmanndude','wellersick@hawaii.rr.com','Randall Ellersick','582 Pauku St','Kailua','HI','UNITED STATES','96734-3542','(808) 261-4462','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-03 06:41:32',0,NULL,3,1,1,1,NULL,'scanmanndude'),(17595,732279476001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','kingswoodkelly','dockelly@internode.on.net','David Kelly','P.O.Box 50','Mt. Morgan','Queensland','AUSTRALIA','4714','0749381901','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 06:54:58',0,NULL,3,1,2,1,NULL,'kingswoodkelly'),(17596,734712223018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','tiziano975','info@tizianomenabo.com','Tiziano Menabò','via A.Brondi, 37','Ferrara','FE','ITALY','44124','3474269676','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 07:03:48',0,NULL,3,1,3,1,'RA184562442CN ','tiziano975'),(17597,774597005002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','brianphotog','brian@brianwebbphoto.com','Brian Q. Webb','Floor 2<br>461-1 Fu Jin Street','Taipei','','TAIWAN','','(095) 246-4388','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 08:15:57',0,NULL,3,1,2,1,NULL,'brianphotog'),(17598,732301937001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cancan4141','erolyilmaz4141@gmail.com','erol yılmaz-yaşar pekçevik','sera çiçekevi<br>karabaş mah.leyla atakan cad.no:16 -İzmit','KOCAELİ','KOCAELI','TURKEY','41300','05418204141','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-03 08:35:25',0,NULL,3,0,3,1,'RA184562805CN\r ','cancan4141\r2XL  已入库'),(17599,843650822016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','photosax','adrianoborges@terceiracortina.com','Adriano Ferreira Borges','Rua do Outeiro, n.º 21<br>Passos S. Julião','Braga','Braga','PORTUGAL','4705-807','00351963448461','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 08:58:16',0,NULL,3,1,17,0,NULL,'photosax\r'),(17600,774609179002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','istokka','admoccia@alice.it','giuseppe saviano','via Florindo Ferro 49','Frattamaggiore','NA','ITALY','80027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 09:04:30',0,NULL,3,1,3,1,'RA184562938CN\r ','istokka'),(17601,862850258015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','greeceathens','6972999050@mycosmos.gr','GEORGE STRATOS','3 SOURI STREET-EUROBANK<br>Syntagma','ATHENS','Greece','GREECE','10557','+306972999050','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-03 09:16:20',0,NULL,3,1,4,1,'YW866012373CN ','greeceathens\r欧标'),(17602,732320249001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','borisvideo','vladimir-video@mail.ru','Vladimir Paloha','Murinsona 35a,29','Chernigov','','UKRAINE','14017','093-750-30-22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 09:42:07',0,NULL,3,1,2,1,NULL,'borisvideo'),(17603,734755345018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','fozziebearpeter','p_fozzie@hotmail.com','Peter Foster','51 Greenville Drive<br>Grovedale','Geelong','Victoria','AUSTRALIA','3216','0352438770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 09:49:58',0,NULL,3,1,17,0,NULL,'fozziebearpeter'),(17604,734755845018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','fozziebearpeter','p_fozzie@hotmail.com','Peter Foster','51 Greenville Drive<br>Grovedale','Geelong','Victoria','AUSTRALIA','3216','0352438770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 09:51:34',0,NULL,3,1,2,1,NULL,'fozziebearpeter\r方形滤镜接口环 72mm    1\r方形滤镜接口环 77mm    1\r方镜普通托架（三槽）    2'),(17605,774626181002,120761242928,'New 10 pcs for P Series Cokin filter box',2,'AD1170',19.8,'hermeshine','pgdpgd3','dpingard.csp@azurpartner.fr','Damien Pingard','19 rue de Verdun','Claye Souilly','Ile-de-France','FRANCE','77410','0673423661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 10:03:58',0,NULL,3,1,2,1,NULL,'pgdpgd3'),(17606,790968942017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','isk1949','iainlynn@bigpond.net.au','Iain King','P.O.Box 441<br>Currumbin','Gold Coast','Queensland','AUSTRALIA','4223','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 10:30:10',0,NULL,3,1,2,1,NULL,'isk1949'),(17608,862909355015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',2,'AD1125',15.8,'hutongstore','dedeuch6988','mjardot@hotmail.fr','Marc JARDOT','4 rue Jean Jaurès<br>Dernier étage','Pontarlier','Franche-Comté','FRANCE','25300','0633514718','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 11:53:01',0,NULL,3,1,11,1,'BJ01085275 ','dedeuch6988\r需要算运费 '),(17609,732369013001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','evocid','alejandro.gonzalez.gonzalez@gmail.com','Alejandro González','Fuenlabrada 57 3ºA','Parla','Madrid','SPAIN','28981','657081812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:33:53',0,NULL,3,1,3,1,'RA184562310CN ','evocid'),(17610,774668381002,120770714159,'New 400w Photo Studio Mini Flash Kit with Flash Trigger',3,'AKT083',690,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:35:01',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(17611,732367951001,110717822222,'New 35\" 90cm Studio Flash Reflective Umbrella Softbox',4,'AD1127',99.96,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:35:02',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(17612,774671369002,120451406324,'New EyeCup for Nikon D80 D90 D200',2,'AA1203',4.96,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:39:38',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(17613,774672277002,120538959115,'NEW Flash Diffuser for Canon 580EX II',4,'AB3332',10.4,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:41:54',0,NULL,3,1,17,0,NULL,'ahmedphotobh'),(17614,732372626001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 12:45:05',0,NULL,3,0,12,1,'7825471625 ','ahmedphotobh\r灯架  2m     6\r力飞 影视闪光灯 lf200w      6\r影室灯AC引闪器    3\r50-70柔光棚 通用塑料卡口   10\r牛津布大包    3\r眼罩 D300    2\r肥皂盒 柔光罩   580EX   4\r10个橡胶罩 （77mm*2- 52mm*3 -58mm*5）（已入库）\r实重22.265  泡重  20.335'),(17615,774694853002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','glukkot','vesenna7575@mail.ru','Baranova Svetlana','Kuybishev st.  house 56 room 57','Rybinsk','Yaroslavl region','RUSSIAN FEDERATION','152900','(910)9742345','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 13:51:19',0,NULL,3,1,3,1,'RA184562399CN ','glukkot'),(17616,774696865002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','songer888','lady.ninamak2012@yandex.ru','Nina Volkova','11 мк-н, 70 дом, 10 кв-ра','Nefteugansk','Тюменская область','RUSSIAN FEDERATION','628305','89044593015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 14:06:36',0,NULL,3,1,2,1,NULL,'songer888'),(17617,774700689002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','jkwwong84','jkw.wong@live.com','Jason Wong','Block 115 Bukit Batok West Ave 6 #25-200','default','','SINGAPORE','650115','85002809','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 14:08:47',0,NULL,3,1,11,1,' ','jkwwong84'),(17618,862974487015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','azzurra99_it','spezzania@yahoo.com','azzurra benedetto','via cave 14','luserna san giovanni','TO','ITALY','10060','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-03 14:37:04',0,NULL,3,1,6,1,'EX002638351SG','azzurra99_it\r欧标， 背景布是两块，白+黑\r实重7.953  泡重11.15\r1107563575\r 换成ems了'),(17619,862975736015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','azzurra99_it','spezzania@yahoo.com','azzurra benedetto','via cave 14','luserna san giovanni','TO','ITALY','10060','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 14:37:04',0,NULL,3,0,17,0,NULL,'azzurra99_it'),(17620,791056902017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','slowboat02','slowboat@iprimus.com.au','David Rowland','34 Sierra Ave','Bateau Bay','New South Wales','AUSTRALIA','2261','0243331036','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-03 14:48:48',0,NULL,3,1,4,1,'YW866012384CN ','slowboat02'),(17621,724723151001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','jesterjeff69','telefragger@comcast.net','Jeffrey Riggs','205 Green Acre Drive','Williamstown','NJ','UNITED STATES','08094','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'jesterjeff69'),(17622,732419176001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','demongtt','dimka7-1984@rambler.ru','Dmitry Bykov','house 6 block 3 Kashenkin Lug St. apt.243','Moscow','','RUSSIAN FEDERATION','127427','(499)239-0243','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 15:06:09',0,NULL,3,1,3,1,'RA184562408CN ','demongtt'),(17623,732448009001,110414474017,'Remote Cord Shutter Release for Olympus E420 E410 E510',1,'AA3229',4.45,'hermeshine','666damnut','damian.alstrom-regan@ntlworld.com','Damian Alstrom-Regan','20 St Leonards Way','Mansfield','Nottinghamshire','UNITED KINGDOM','NG190GX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 16:20:46',0,NULL,3,1,2,1,NULL,'666damnut'),(17624,732454134001,110618894929,'Pro Photo Vest Blue Nikon Canon Sony Olympus Pentax ',1,'AA2118',32,'hermeshine','steve533','comtechplus@comcast.net','Steven Mowles','7834 Locher Way','Citrus Heights','CA','UNITED STATES','95610','','NoPaymentFailure','CheckoutComplete','Other','2011-10-03 16:35:14',0,NULL,3,0,1,1,NULL,'steve533\r3XL   已入库'),(17625,774756909002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','skorpions2k','ev.safronov@gmail.com','Evgeniy Safronov','Batova, 9-17','Volgograd','RU','RUSSIAN FEDERATION','400015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 16:35:25',0,NULL,3,1,17,0,NULL,'skorpions2k'),(17626,863038138015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','petrov.dimitar','petrov.dimitar@gmail.com','Dimitar Petrov','Smolyanska 24-28 App.18','Sofia','Sofia','BULGARIA','1612','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 16:42:53',0,NULL,3,1,2,1,NULL,'petrov.dimitar'),(17627,732457038001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',8.99,'hermeshine','skorpions2k','ev.safronov@gmail.com','Evgeniy Safronov','Batova, 9-17','Volgograd','RU','RUSSIAN FEDERATION','400015','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 16:43:57',0,NULL,3,1,5,1,'CP235627555CN','skorpions2k \r2b柔      2 \r反光伞     1'),(17628,774797578002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','marijillo','hilfiger_denim@msn.com','mario giugliano','madame bolland 225','Santiago/ La Cisterna','R Metropolitana','CHILE',' 7980634 ','5588027','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 17:56:47',0,NULL,3,1,5,1,'CP235627564CN  ','marijillo\r在地址后面打上\rTAX ID: 17.226.594-4\r'),(17629,845206565016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','serparcel','ines_pavon@hotmail.com','Daniel Gallego Bouzas','Manuel Murguía 6, 3º izquierda','Ourense','Galicia','SPAIN','32005','610663737','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 17:59:02',0,NULL,3,1,3,1,'RA184562487CN ','serparcel'),(17630,791153057017,270748510307,'NIB TianYa Gradual grey Color Filter for Cokin P series',1,'AA2322',7.29,'photographyacc','csananet','csana.mail@gmail.com','Zsolt Csanadi','Budai ut 49-51  505','Szekesfehervar','Fejer','HUNGARY','8000','+36304354833','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 18:05:54',0,NULL,3,1,2,1,NULL,'csananet'),(17631,774830992002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','amfalconer','amfalconer@btinternet.com','Adrian Falconer','57 Smithcourt Drive','Little Stoke Bristol','Avon','UNITED KINGDOM','BS34 8NB','01179792742','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 18:52:55',0,NULL,3,1,3,1,'RA184562385CN ','amfalconer'),(17632,774834094002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','bigfongou','jfrango@sbcglobal.net','John Frangoulis','317 Cornell St','Ottawa','IL','UNITED STATES','61350-3511','','NoPaymentFailure','CheckoutComplete','Other','2011-10-03 18:59:26',0,NULL,3,1,3,1,'RA184562924CN\r ','bigfongou'),(17633,863135568015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38.99,'hutongstore','richardheppinstall-2008','richardheppinstall@btinternet.com','Richard Heppinstall','26 Crawthorne Crescent<br>Deighton','Huddersfield','West Yorkshire','UNITED KINGDOM','HD2 1LB','01484540378','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-03 18:59:49',0,NULL,3,1,4,1,'YW866012410CN ','richardheppinstall-2008'),(17634,732533721001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','l-com.de','ebay@l-com.de','Klaus Lechtenberg','Bahnhofstraße 4','Reken','','GERMANY','48734','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-03 19:06:24',0,NULL,3,0,3,1,'RA184562779CN\r ','l-com.de\r3XL 已入库'),(17635,732543252001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 19:23:07',0,NULL,3,1,3,1,'RA184562544CN ','m.petrosyan'),(17636,732558934001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','williamw9125','williamwilson64@tds.net','William Wilson','5982 S 425 E','Waldron','IN','UNITED STATES','46182','','NoPaymentFailure','CheckoutComplete','Other','2011-10-03 19:52:32',0,NULL,3,1,1,1,NULL,'williamw9125'),(17637,735007197018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','sheralee1975','sherladd@shaw.ca','Sheralee Ladd','4411 49 St<br>Box 486','Hardisty','AB','CANADA','T0B 1V0','(780) 209-2713','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 20:13:17',0,NULL,3,0,2,1,NULL,'sheralee1975\r白色'),(17638,791250824017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',1,'AC2304',5.98,'photographyacc','rdeala','rdeala@yahoo.com','Ronald Deala','Stovner Senter 18<br>Leil. 304','Oslo','','NORWAY','0985','(+47) 99307814','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-03 20:52:58',0,NULL,3,1,2,1,NULL,'rdeala\r申报gift'),(17639,732587565001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','dairis46','dairisv@gmail.com','DAIRIS VILERTS','TEATRA STR.54','JURMALA','','LATVIA','LV-2015','+37128303020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 20:53:52',0,NULL,3,1,2,1,NULL,'dairis46'),(17640,863224819015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','gowiththeflowmo','monique013@hotmail.com','Monique Landzaat','Vogelstraat 34','Wagenberg','','NETHERLANDS','4845 PB','0642886950','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 21:19:46',0,NULL,3,1,4,1,'YW866012421CN ','gowiththeflowmo\r灰色背景布'),(17641,735058647018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','solothecat','solothecat@hotmail.com','Jo Wilson','223 Mundoolun rd','Jimboomba','Queensland','AUSTRALIA','4280','0755477790','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-03 21:46:59',0,NULL,3,0,3,1,'RA184562782CN\r ','solothecat\rxxl 已入库'),(17642,774911351002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-03 21:49:24',0,NULL,3,1,3,1,'RA184562439CN ','mariomarques.com.br'),(17643,863241726015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','oliviloo','freshbits@yahoo.co.uk','Odette Michell','The Chalet<br>Loudwater Farm, Loudwater Lane','Rickmansworth','Hertfordshire','UNITED KINGDOM','WD3 4HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-03 21:55:49',0,NULL,3,1,17,0,NULL,'oliviloo'),(17644,732613657001,110499660483,'YONGNUO 3ft E-TTL(II) Off-Camera Flash Cord for Canon',1,'AB3321',19.99,'hermeshine','11juanjo','soy_juanjo@hotmail.com','juan josé valverde solana','C/ San Carlos de Nicaragua nº4, 2ºb','Albacete','Castilla-La Mancha','SPAIN','02006','678628129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 22:07:33',0,NULL,3,1,2,1,NULL,'11juanjo'),(17645,863257313015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',3,'AC1201',6.54,'hutongstore','joedude30','joedunne30@eircom.net','Joe Dunne','14 Bannow Road<br>Cabra','Dublin','Dublin','IRELAND','7','0872338651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 22:35:32',0,NULL,3,1,2,1,NULL,'joedude30'),(17646,863259036015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.8,'hutongstore','apelz1928','fwapelq@msn.com','Patrick Lantz','2210 Crescent Ave<br>null','Fort Wayne','IN','UNITED STATES','46805-4433','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 22:41:09',0,NULL,3,1,17,0,NULL,'apelz1928'),(17647,863262630015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','apelz1928','fwapelq@msn.com','Patrick Lantz','2210 Crescent Ave<br>null','Fort Wayne','IN','UNITED STATES','46805-4433','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 22:51:23',0,NULL,3,1,1,1,NULL,'apelz1928\r绿叶 UV  67mm   1\r橡胶遮光罩 67mm    1'),(17648,774936810002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','glober471','pedroubaldo@hotmail.com','Pedro Samaniego Arranz','Aldai nº 29 A','Amurrio','País Vasco','SPAIN','01470','660705490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 22:57:05',0,NULL,3,1,17,0,NULL,'glober471'),(17649,774936429002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','glober471','pedroubaldo@hotmail.com','Pedro Samaniego Arranz','Aldai nº 29 A','Amurrio','País Vasco','SPAIN','01470','660705490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-03 22:57:06',0,NULL,3,1,2,1,NULL,'glober471\r方形滤镜接口环 67mm    1\r方镜广角托架（ 一槽）   1\r'),(17650,732639397001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','clement.barthes','clementbarthes@gmail.com','Clement Barthes','2427 8th St','Berkeley','CA','UNITED STATES','94710-2501','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-03 23:42:32',0,NULL,3,1,1,1,' ','clement.barthes\r单轮，不是双轮\r'),(17651,845412118016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',105,'hutongstore','b190152','dazzer@cybercentral.com.au','Darryl Warry','P.O. Box 662','Picton','New South Wales','AUSTRALIA','2571','0414641737','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-03 23:53:43',0,NULL,3,1,4,1,'YW866012395CN ','b190152\r澳标'),(17652,770233166002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','medic21347','paulas@ns.sympatico.ca','Paula Sutherland','10526 Hwy 103 Clyde River<br>P.O. Box 106, Clyde River','Shelburne County','NS','CANADA','B0W 1R0','(902) 637-2408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 00:01:49',0,NULL,3,1,2,1,NULL,'medic21347'),(17653,789763319017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',5,'AA1302',12.5,'photographyacc','jase2010','jason@jnphoto.com.au','Jason Nichol','226 Franklin Street','Matraville','New South Wales','AUSTRALIA','2036','0412241006','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 00:25:25',0,NULL,3,1,3,1,'RA184562460CN ','jase2010'),(17654,845429342016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','lewin5829','m5astt@yahoo.co.uk','michael lewin','38 vernon drive Harefield','uxbridge','Middlesex','UNITED KINGDOM','ub9 6eg','01895824500','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 00:46:02',0,NULL,3,1,17,0,NULL,'lewin5829'),(17655,8881317691271276,111,'115w 5500k 灯泡  220v',1,'',0,'hutongstore','aglo5083','indiorc@gmail.com','Andre Gloria','36 Fernwood<br>Albert Drive, Southfields','Wimbledon','London','UNITED KINGDOM','SW19 6LR','07834988558',NULL,NULL,NULL,'2011-10-04 01:21:11',0,NULL,3,0,3,1,'RA184562323CN ','已入库 '),(17656,863314362015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','alicia0408','missaliciacook@hotmail.com','Jim Kim (Coens Energy)','Ocean Village 5, 370-1, Bangeo Dong<br>Dong-gu','Ulsan','South Korea','KOREA,REPUBLIC OF','682-804','820522303333','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-04 01:23:05',0,NULL,3,1,6,1,'EE495359707CN ','alicia0408\r澳标、欧标都给他一对吧'),(17657,732693743001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','chillidog20051975','peter@iminco.net','Peter Evans','24 Twenty Third Ave','Palm Beach','Queensland','AUSTRALIA','4221','0414498870','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 03:12:45',0,NULL,3,1,4,1,'YW866012406CN ','chillidog20051975\r澳标'),(17658,775005468002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',5,'AA1216',69.5,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+622192659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 03:37:40',0,NULL,3,1,3,1,' RA184562986CN','ivan_ns2\r申报在$50之下'),(17659,791392070017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',6.98,'photographyacc','ngvi','victor.ng@bmw.com.au','Victor ng','C/o BMW Aust Ltd<br>783 Springvale Rd','Mulgrave','Victoria','AUSTRALIA','3170','0392644032','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 04:57:49',0,NULL,3,1,2,1,NULL,'ngvi'),(17660,732713962001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',39.8,'hermeshine','theoldtexan','theoldtexan@yahoo.com','Joseph Wagner White','405 NW 6th St','Tulia','TX','UNITED STATES','79088','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 05:08:07',0,NULL,3,1,3,1,'RA184562337CN ','theoldtexan'),(17661,735174253018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','omarbahra','o.bahra@gmail.com','The Arab Photo','omar Al Bahra UAE University Al Ain P.o.Box15551','Al AIn','Abu Dhabi','UNITED ARAB EMIRATES','15551','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 05:30:59',0,NULL,3,1,2,1,NULL,'omarbahra'),(17662,791412044017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','teresa302009','teresatrojak30@gmail.com','teresa trojak','1/12 clements street','east betleigh','Victoria','AUSTRALIA','3165','0395039486','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 06:50:17',0,NULL,3,1,3,1,'RA184564179CN\r ','teresa302009'),(17663,863408064015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','shaun117','shaunscottuk@yahoo.co.uk','Shaun Scott','48 Newnham Street','Ely','Cambridgeshire','UNITED KINGDOM','CB7 4PE','01353615275','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 07:25:32',0,NULL,3,1,2,1,NULL,'shaun117'),(17664,775057349002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','p.petkow','plamen.petkow@gmail.com','Plamen Dyanov Petkov','24, Dimitar Spisarevski Str.','Sofia','Sofia','BULGARIA','1592','+359883320220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 07:44:18',0,NULL,3,1,17,0,NULL,'p.petkow'),(17665,735203835018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','xdizzee','mitches@gmail.com','Mitch Sansom','57 Willoring Cres','Jamisontown','New South Wales','AUSTRALIA','2750','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 08:09:18',0,NULL,3,1,2,1,NULL,'xdizzee'),(17666,791430944017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','andonstore','info@andoncreative.com','Toni Andonovski','907/ 9 Yarra Street','South Yarra','Victoria','AUSTRALIA','3141','0398260738','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-04 08:20:30',0,NULL,3,1,4,1,'YW866012550CN ','andonstore'),(17667,775069430002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','xisum666','isaakxisum@hotmail.com','isaac perez tortosa','jose maria peman 7-9','onil','Comunidad Valenciana','SPAIN','03430','667751329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 08:57:27',0,NULL,3,1,3,1,'RA184564341CN\r ','xisum666'),(17668,8881317719064354,111,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',95.98,'photographyacc','photo_master.and','andrey.schnell@gmail.com','Andrey Schnell','Beregowaja 41','Aksu','Pawlodar','KAZAKHSTAN','140100','87183733084',NULL,NULL,NULL,'2011-10-04 09:04:24',0,NULL,3,1,8,1,'CP238031073CN\r ','6662a     1\r肩架 * 1 （已入库）\rhermeshine 里的订单'),(17669,775074025002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','p.petkow','plamen.petkow@gmail.com','Plamen Dyanov Petkov','24, Dimitar Spisarevski Str.','Sofia','Sofia','BULGARIA','1592','+359883320220','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:08:53',0,NULL,3,1,5,1,'CP235627595CN ','p.petkow\r2b柔    2'),(17670,8881317719710922,111,'2m 灯架',6,'AE3401',116.79,'photographyacc','1004616365','alexsalt@gmail.com','Alexey Saltykov	','Zvezdny bulvar 30/2 12','Moscow','','RUSSIAN FEDERATION	','129075','+007 095 6165463',NULL,NULL,NULL,'2011-10-04 09:15:10',0,NULL,3,1,5,1,'CP235627604CN ','2m 灯架    7\r反光板支架    1 '),(17671,732764187001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','allmarvin22','msul1@um.edu.mt','Marvin Sultana','Faculty for the Built Environment Building<br>University of Malta','Msida','','MALTA','MSD 2080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:37:00',0,NULL,3,1,2,1,NULL,'allmarvin22\r欧标'),(17672,732765335001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','zissousteve22','vinoddhanda@hotmail.co.uk','Vinod Dhanda','22 rosemary crescent west','wolverhampton','West Midlands','UNITED KINGDOM','wv4 5ap','01902343111','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-04 09:39:14',0,NULL,3,1,3,1,'RA184564390CN\r ','zissousteve22'),(17673,735225772018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','shipep15201','kylejnovak@gmail.com','Ilona Novak','15201 SW 88th Ave','Palmetto Bay','FL','UNITED STATES','33157','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 09:50:51',0,NULL,3,1,3,1,'RA184564029CN\r ','shipep15201\r新地址\rKyle Novak\r116 West 238th Street\rApt 4C\rBronx, NY 10463\rUNITED STATES\r'),(17674,732769663001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','norwegian_thoddi','thor.oliversen@gmail.com','Thor Oliversen','Hamneveien 12','Stavanger','Rogaland','NORWAY','4016','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 09:56:48',0,NULL,3,1,3,1,'RA184564077CN\r ','norwegian_thoddi'),(17675,863457547015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','top-designer-clothing','designer.clothing@hotmail.co.uk','S AND M Clothing (Int\'l)  Co Ltd','Unit 1C Earl Rd<br>Stanley Green Trading Estate','Cheadle','Cheshire','UNITED KINGDOM','SK8 6PT','07867502980','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 10:32:22',0,NULL,3,1,3,1,'RA184564196CN\r ','top-designer-clothing\r4个'),(17676,731025705001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','sergei66','autoekb4@rambler.ru','Сергей Яровиков','Красноармейская д.44','Полевской','Свердловская область','RUSSIAN FEDERATION','623380','(902)8789893','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 10:53:51',0,NULL,3,1,5,1,'CP235627581CN ','sergei66\r欧标\r实重6.82 抛重7.35'),(17677,732784062001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','stratomaster','reidlowe@gmail.com','Reid Lowery','16625 Redmond Way<br>Ste M PMB 246','Redmond','WA','UNITED STATES','98052-4499','(425) 503-3394','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-04 10:55:49',0,NULL,3,1,1,1,NULL,'stratomaster'),(17678,775102838002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tjadoheld','r.held@roac.nl','Richenel Held','Prinsenhove 56','Middelburg','','NETHERLANDS','4336HC','(0118)636117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 11:10:19',0,NULL,3,1,3,1,'RA184564253CN\r ','tjadoheld'),(17679,735260032018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','johnny4389','senzafine1@gmail.com','Johnny Lundgren','Nesbryggeveien 72 B','Nøtterøy, Duken','Vestfold','NORWAY','3133','+4794421419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 11:57:44',0,NULL,3,1,3,1,NULL,'johnny4389'),(17680,735267525018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','jfqueralt','jfqueralt@gmail.com','Jean François Quéralt','Escuela Europea de Alicante<br>Avenida Locutor Vicente Hipólito, S/N','San Juan Playa - Alicante','Comunidad Valenciana','SPAIN','03540','607319864','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 12:23:50',0,NULL,3,1,2,1,NULL,'jfqueralt'),(17681,732817402001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',4,'AA1312',6,'hermeshine','kosraetv','briankosrae@aol.com','Brian Rogers','Box 1248','Phnom Penh','Phnom Penh','CAMBODIA','12000','(855) 773-5953 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:59:58',0,NULL,3,0,17,0,NULL,'kosraetv'),(17682,775133274002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',4,'AO0005',72,'hermeshine','kosraetv','briankosrae@aol.com','Brian Rogers','Box 1248','Phnom Penh','Phnom Penh','CAMBODIA','12000','(855) 773-5953 ext.: 7','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 12:59:59',0,NULL,3,0,3,1,'RA184564369CN\r ','kosraetv\r麂皮     4\r1.6*3 黑色 灰色  绿色 白色\r各一块   是三米的'),(17683,863512498015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','gudowska','annagerasimova@inbox.lv','Anna Gerasimova','Country Products Ltd. Centre Park, Unit 6.<br>Marston Business Park, Tockwith, York','York','North Yorkshire','UNITED KINGDOM','YO26 7QF','07928068081','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 13:03:36',0,NULL,3,1,3,1,'RA184564430CN\r ','gudowska'),(17684,775142311002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','wftallships','wftallships@eircom.net','Michael Murphy','13 Emmet Place','Wexford','Co Wexford','IRELAND','default','05323471','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 13:31:02',0,NULL,3,1,3,1,'RA184564134CN\r ','wftallships\r一定申报为GIFT'),(17685,775147251002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','nidarayburn','nidarayburn@yahoo.com.au','Nida Rayburn','180/6 Soi Sukhumvit 54, Sukhumvit Rd<br>Bangjak, Prakhanong','Bangkok','Bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 13:47:32',0,NULL,3,1,2,1,NULL,'nidarayburn'),(17686,735294658018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','sevagparis','s_kalaydjian@msn.com','Sevag Kalaydjian','35, Quai de Grenelle','Paris','Île-de-France','FRANCE','75015','0619191630','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 13:48:36',0,NULL,3,1,2,1,NULL,'sevagparis'),(17687,732835826001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',5.49,'hermeshine','iwasjustafan','kcr@vailaz.com','KIM KOLBA','19307 S Sonoita Hwy','VAIL','AZ','UNITED STATES','85641','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 14:03:55',0,NULL,3,1,1,1,NULL,'iwasjustafan'),(17688,735307827018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','2011debbieanne','debbieanne2010@hotmail.com','Debbie Anne  Evans','6/240 Lawrence','Alexandria','New South Wales','AUSTRALIA','2015','0292885105','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 14:28:40',0,NULL,3,1,2,1,NULL,'2011debbieanne'),(17689,863554875015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','oliviloo','freshbits@yahoo.co.uk','Odette Michell','The Chalet<br>Loudwater Farm, Loudwater Lane','Rickmansworth','Hertfordshire','UNITED KINGDOM','WD3 4HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 14:49:40',0,NULL,3,1,3,1,'RA184564315CN\r ','oliviloo\r橡胶遮光罩 52mm     1\r反光板支架       1'),(17690,775181606002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jmroldan1982','chemitaxis@gmail.com','Jose Manuel Roldan Marin','C/ Galileo nº44 1º6','Madrid','Madrid','SPAIN','28015','677361536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 15:36:11',0,NULL,3,1,3,1,'RA184564267CN\r ','jmroldan1982'),(17691,775182991002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','enochg','black_907@hotmail.com','izabelle holm Mutumba','larsbergsvägen 27 2 tr','Lidingö','Stockholm','SWEDEN','18138','0737277805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 15:40:11',0,NULL,3,1,2,1,NULL,'enochg'),(17692,863580819015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','sylviedg14','sylviedg@base.be','SYLVIE DE GHESELLE','LA ROUTAINE 78/BTE13<br>VILLAGE DE VACANCES BLOC100/STUDIO24','MEMBRE','','BELGIUM','5550','061/502269','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 15:47:20',0,NULL,3,1,2,1,NULL,'sylviedg14'),(17693,863584520015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','oncle_sioc','bob@altizoom.com','Francois Maury','10 rue Remy Dumoncel','Paris','Ile-de-France','FRANCE','75014','06 71 59 95 33','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 15:55:36',0,NULL,3,1,2,1,NULL,'oncle_sioc'),(17694,775193419002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','michellaframboise','mlaframboise@hotmail.com','Michel Laframboise','189 Du Mont Luc','Gatineau','QC','CANADA','J8V2B5','(819) 561-4118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 16:03:01',0,NULL,3,1,3,1,'RA184564125CN\r ','michellaframboise\r新式云台   '),(17695,863262188015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','alexgerz','alexgerz@mail.ru','Alexandr Gerchikov','3896 Hertford st.','Burnaby','BC','CANADA','V5G 2R4','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-04 16:12:33',0,NULL,3,1,5,1,'CP238030855CN ','alexgerz'),(17696,775198539002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','vekselberg','genavakula@gmail.com','Gennadiy Vakula','427 Doughty Blvd<br>Unit B','Inwood','NY','UNITED STATES','11096-1345','516 612 4917','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-04 16:15:17',0,NULL,3,1,1,1,NULL,'vekselberg'),(17697,775207746002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','orenspl56','orenspl@mail.ru','Ilya Zverev Sergeevich','pr.Gazovikov 24<br>KB 48','Orenburg','Orenburg Area','RUSSIAN FEDERATION','460051','89619439839','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 16:43:47',0,NULL,3,1,2,1,NULL,'orenspl56'),(17698,791601276017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',2,'AD1401',15.6,'photographyacc','slaukelid','slaukelid@hotmail.com','Svein-Egil Laukelid','Ullevålsveien 63a','Oslo','','NORWAY','0454','004793010750','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 17:08:27',0,NULL,3,1,2,1,NULL,'slaukelid'),(17699,735389080018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','merih_akyol','merih.akyol@gmail.com','Merih Akyol','BAYEGAN DIS TIC. A.S.<br>BAYAR CAD. SITMA PINARI SOK. NO:3 KOZYATAGI','ISTANBUL','KOZYATAGI','TURKEY','34738','00905322822100','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 17:53:16',0,NULL,3,0,17,0,NULL,'merih_akyol'),(17700,735390336018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','merih_akyol','merih.akyol@gmail.com','Merih Akyol','BAYEGAN DIS TIC. A.S.<br>BAYAR CAD. SITMA PINARI SOK. NO:3 KOZYATAGI','ISTANBUL','KOZYATAGI','TURKEY','34738','00905322822100','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 17:55:27',0,NULL,3,0,3,1,'RA184564205CN\r ','merih_akyol\r摄影背心（河北，厚）nikon    XXL    1\r摄影背心（河北，厚）nikon  XXXL    1'),(17701,775250392002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mariam_m13','mirijanyan@gmail.com','Mariam Mirijanyan','Gr. Artsruni 10, app.27','Yerevan','','ARMENIA','0012','+37410228859','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 18:16:05',0,NULL,3,1,3,1,'RA184564236CN\r ','mariam_m13'),(17702,845795910016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','lewin5829','m5astt@yahoo.co.uk','michael lewin','38 vernon drive Harefield','uxbridge','Middlesex','UNITED KINGDOM','ub9 6eg','01895824500','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-04 18:41:39',0,NULL,3,1,4,1,'YW866012561CN ','lewin5829\rc型大力夹       1\r150-200cm 5in1 反光板     1\r'),(17703,732949586001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','doorgeshmungur','pigeonz@gmail.com','Doorgesh Mungur','Bois Rouge Road','Goodlands','','MAURITIUS','0000','7732887','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-04 18:49:40',0,NULL,3,1,3,1,'RA184564783CN ','doorgeshmungur'),(17704,863707863015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','gunnersborn','emiratesarsenal@hotmail.com','Rowan Sherrard','79 Carrick Court','Portmarnock','Dublin','IRELAND','default','0851009828','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 19:23:21',0,NULL,3,1,3,1,'RA184564409CN\r ','gunnersborn'),(17705,863724955015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','lilnisse','carina.radenmark@ostra.goteborg.se','Nils Rådenmark','Plantagegatan 11','Gothenburg','Västra Götaland','SWEDEN','41305','0732318741','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-04 19:55:31',0,NULL,3,1,2,1,NULL,'lilnisse'),(17706,791694478017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','thegioblack','sonofraw@hotmail.com','Giovanni Blackburn','14 Rue Balgobin<br>Cite Chebel','Beau Bassin','','MAURITIUS','742CU001','947 3741','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 19:56:48',0,NULL,3,1,2,1,NULL,'thegioblack'),(17707,735468405018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',2,'AA1304',5,'photographyacc','heshdar','saed@optusnet.com.au','Saed Rasouli','19a Cook Street','Baulkham hills','New South Wales','AUSTRALIA','2153','0296868650','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-04 20:19:31',0,NULL,3,1,2,1,NULL,'heshdar'),(17708,775320192002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','sanjin.strukic','sanjininphoto@yahoo.com','Sanjin Strukic','Bademovac 3','Zagreb','Crnomerec','CROATIA','10000','00385916400473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:29:52',0,NULL,3,1,2,1,NULL,'sanjin.strukic'),(17709,775321763002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','fclo7131','tom_cload@msn.com','Fiona Cload','14 Hazelwood Avenue<br>Harwood','Bolton','Lancashire','UNITED KINGDOM','BL2 3NR','01204364050','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:34:29',0,NULL,3,1,3,1,'RA184564240CN\r ','fclo7131'),(17710,775323659002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','revinhood','revinhood@yahoo.es','susana tardio','c/ leñadores blq 8    8-C','puerto real','Andalucía Ceuta y Melilla','SPAIN','11510','625508572','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:37:38',0,NULL,3,1,2,1,NULL,'revinhood'),(17711,845870504016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','carolyn_h66','carolynhunter66@hotmail.com','carolyn hunter','23 Hillhouse Road<br>Head of muir','Denny','Stirling','UNITED KINGDOM','FK6 5PG','01324411292','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 20:39:50',0,NULL,3,1,3,1,'RA184564117CN\r ','carolyn_h66'),(17712,775324925002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','vivanitskiy','vovanya@tut.by','Vladimir Ivanitskiy','Chkalova<br>18/3/51','Minsk','','BELARUS','220039','+375297776771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 20:40:54',0,NULL,3,1,2,1,NULL,'vivanitskiy'),(17713,845881226016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','crafty-chel','craftychel@hotmail.com','Michelle Byrne','Prucklish<br>Newtownforbes','Co Longford','Longford','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-04 20:58:54',0,NULL,3,1,3,1,'RA184564148CN\r ','crafty-chel'),(17714,735489399018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',30,'photographyacc','toadstul59','myxomop.toadstool@gmail.com','Dmitry Medvedev','Cherdinskaya 38 - 172','Perm','perm\'s region','RUSSIAN FEDERATION','614088','89028024955','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 21:04:37',0,NULL,3,1,3,1,'RA184564151CN\r ','toadstul59'),(17715,735490661018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','golfman128','jamesrutsky@nycap.rr.com','James Rutsky','110A East Ave','Saratoga Springs','NY','UNITED STATES','12866','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 21:06:11',0,NULL,3,1,1,1,NULL,'golfman128'),(17716,791754213017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','eperari','necupz@gmail.com','eugenio perez arieta-araunabeña','rodriguez arias 53, 7d','bilbao','Vizcaya','SPAIN','48011','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-04 22:09:33',0,NULL,3,1,2,1,' ','eperari'),(17717,863819071015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','geoffy123','geoff.yates@fabermusic.com','Geoff Yates','Faber Music Ltd.<br>Elizabeth Way','Harlow','Essex','UNITED KINGDOM','CM20 2HX','01279828921','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-04 23:09:10',0,NULL,3,1,3,1,'RA184564094CN\r ','geoffy123'),(17718,733063973001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','charles0591charles','bellicpm@optusnet.com.au','Charles Belli','76 KINTERBURY DRIVE','KINGS PARK','Victoria','AUSTRALIA','3021','0393669908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-04 23:46:46',0,NULL,3,1,2,1,NULL,'charles0591charles'),(17719,791797535017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',5,'AE3301',74,'photographyacc','mart777','martyncobbe@gmail.com','Martyn Cobbe','52 Stanton court','Gisborne','Victoria','AUSTRALIA','3437','0354207795','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 00:42:50',0,NULL,3,1,3,1,'RA184564355CN\r ','mart777\r注意是5个'),(17720,774236234002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','meir_shevach','meshevach@gmail.com','Meir Shevach','P.O.B. 3501','Beer Sheva','','ISRAEL','84135','0546751616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 01:08:47',0,NULL,3,1,3,1,'RA184564085CN\r ','meir_shevach'),(17721,791805575017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',32,'photographyacc','tommie013','tommlyn@live.com.au','Robin Tomlin','38 Otama Crt','Craigmore','South Australia','AUSTRALIA','5114','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 01:10:31',0,NULL,3,1,17,0,NULL,'tommie013'),(17722,791804715017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','tommie013','tommlyn@live.com.au','Robin Tomlin','38 Otama Crt','Craigmore','South Australia','AUSTRALIA','5114','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 01:10:32',0,NULL,3,1,4,1,'YW866012535CN ','tommie013\r澳标\rc里的套装+\r115w 5500k 灯泡  220v      2'),(17723,733239539018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','kaneke_png','kaneke_png@yahoo.com','Daniel Walmsley','2/70 Bali Drive','Quakers Hill','New South Wales','AUSTRALIA','2763','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 01:17:17',0,NULL,3,1,2,1,NULL,'kaneke_png'),(17724,735573585018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','luke-kerri','lukemac83@live.com.au','Kerri Macpherson','7 Francis Street','Melton South','Victoria','AUSTRALIA','3338','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 01:50:08',0,NULL,3,1,4,1,'YW866012546CN ','luke-kerri\r白+黑'),(17725,735588221018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','carolyn03070','carolyn.whamond@telstra.com','Carolyn Whamond','394 Sandy Bay Road','Sandy Bay','Tasmania','AUSTRALIA','7005','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 02:44:58',0,NULL,3,1,2,1,NULL,'carolyn03070'),(17726,791832779017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',4,'AA1306',10,'photographyacc','rudiekuiter339','rudiekuiter@optusnet.com.au','Rudie Kuiter','PO Box 124','Seaford','Victoria','AUSTRALIA','3198','0397664304','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 02:45:28',0,NULL,3,1,2,1,NULL,'rudiekuiter339'),(17727,735591780018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','adeel355','adeel355@yahoo.com','Adeel Arshad','1 Cornbrook Grove, Old Trafford','Manchester','Lancashire','UNITED KINGDOM','M167PQ','01618765805','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 03:01:21',0,NULL,3,1,2,1,NULL,'adeel355'),(17728,791842415017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','doorknocker2','doorknocker1@hotmail.com','frank e. dworning','7745 Jennings Dr','Painesville','OH','UNITED STATES','44077-9381','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 03:27:49',0,NULL,3,1,1,1,NULL,'doorknocker2'),(17729,775447268002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','siampuregems','thuchakon@gmail.com','Thatchakon Kiratisupakun','481/147 Ladprao 94 Rd.','default','BA','THAILAND','10310','66899944594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 03:45:05',0,NULL,3,1,2,1,NULL,'siampuregems'),(17730,735605193018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',9.8,'photographyacc','maidenlover05','lupe.e.rios@gmail.com','Guadalupe Rios','256 Mathilda Dr<br>Apt 13','Goleta','CA','UNITED STATES','93117-2617','(805) 722-5748','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 04:03:00',0,NULL,3,1,1,1,NULL,'maidenlover05'),(17731,733131167001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','roxyphreak','deftoneskat81@aol.com','Roxanne Watson','30830 Lund Ave','Warren','MI','UNITED STATES','48093-2203','(586) 576-1898','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 04:39:05',0,NULL,3,1,1,1,NULL,'roxyphreak'),(17732,775461115002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','goosie*girl','junkmail@goosiegirlboutique.com','H. McKenzie-Niziolek','408 Arbor Ave','West Chicago','IL','UNITED STATES','60185-2150','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 05:01:05',0,NULL,3,1,1,1,NULL,'goosie*girl'),(17733,775472979002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',79,'hermeshine','blondiini','virpi.niskanen@bosis.fi','Virpi Niskanen','Reunatie 8','Lempaala','','FINLAND','37550','35833751492','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-05 06:11:11',0,NULL,3,1,4,1,'YW866012513CN ','blondiini\r欧标'),(17734,791875468017,270742402381,'New IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AA2201',5.48,'photographyacc','explosm','chemicalpicnic@hotmail.com','Lisa','73 Clydesdale St<br>Como','Perth','Western Australia','AUSTRALIA','6152','0414554590','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-05 06:22:33',0,NULL,3,1,2,1,NULL,'explosm'),(17735,735637416018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','davidt9565','davidtulloch@iprimus.com.au','David Tulloch','7 Glentilt Road<br>Glen Iris','Melbourne','Victoria','AUSTRALIA','3146','0402305054','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 07:05:14',0,NULL,3,1,4,1,'YW866012524CN ','davidt9565'),(17736,863950007015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','misty4id','standara@gmail.com','Michal Standara, Dita Mokra','Doslikova 46','Brno','','CZECH REPUBLIC','63600','(420)777941966','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 07:09:16',0,NULL,3,1,2,1,NULL,'misty4id'),(17737,735631758018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',80,'photographyacc','canlens','fbougee@gmail.com','Vladimir Podyukov','Uralskaya ul. 23,<br>korpus 4, kvartira 619','Moscow','','RUSSIAN FEDERATION','107065','8 (926) 0611605','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 06:34:58',0,NULL,3,1,5,1,'CP238031113CN ','canlens'),(17738,846061833016,260817868705,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',20.99,'hutongstore','p.i.k','paulow80@gmail.com','Pawel Wozniak','707 Glashaus Apartments<br>Belgard Square, Tallaght','Dublin','24','IRELAND','24','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 07:12:47',0,NULL,3,1,3,1,'RA184567100CN ','p.i.k'),(17739,733164173001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','gold-archer','eek@goldarcher.com','Ejler E Kohncke','41 Batehaven Street','Loganholme','Queensland','AUSTRALIA','4129','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-05 07:45:33',0,NULL,3,1,3,1,'RA184564307CN\r ','gold-archer\r已入库'),(17740,775495972002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','skunkmaster1','buy@baruch.name','Oran Baruch','Yalag Alley 4 B<br>App 16','Tel Aviv','NA','ISRAEL','64388','972-52-8752211','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 08:10:09',0,NULL,3,1,2,1,NULL,'skunkmaster1'),(17741,775505757002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','faragodeni','dfarago.audiopartner@gmail.com','Audio Partner Ltd. (Daniel Farago)','Epitok utja 2-4.','Budaors','','HUNGARY','H-2040','+36309981900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 08:56:51',0,NULL,3,1,2,1,NULL,'faragodeni'),(17742,842347966016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','k.c.1957','k_a_c@blueyonder.co.uk','kevin  cox','17 Durnford Avenue<br>Ashton','Bristol','Avon','UNITED KINGDOM','bs32al','01179664996','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-05 09:41:59',0,NULL,3,1,4,1,'YW866012174CN  ','k.c.1957\r英标'),(17743,775518785002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','foto14lexa','lea.hult@luukku.com','Lea Hult','Metsänhoitajankuja 1A 6','Vantaa','Oletus','FINLAND','01370','0500658717','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 09:54:42',0,NULL,3,1,2,1,NULL,'foto14lexa'),(17744,733199943001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','181190sb','polipak_sb@mail.ru','Сергей Белоцерковский','Ю.Фучика, 4, 63','Орск','Оренбургская область','RUSSIAN FEDERATION','462403','89123574854','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-05 10:26:19',0,NULL,3,1,5,1,'CP238031060CN ','181190sb\r两个'),(17745,791936389017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',117,'photographyacc','sleeplight','sleeplight@hotmail.com','Tony Taouk','unit 10<br>40 Drummoyne Av','Drummoyne','New South Wales','AUSTRALIA','2047','0420783450','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 10:34:25',0,NULL,3,1,4,1,'YW866012491CN ','sleeplight'),(17746,735689722018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',60,'photographyacc','kimberleyrenee88','kimberleylaudzevics@hotmail.com','Kimberley Laudzevics','26 Hillsdale Rise','Darch','Western Australia','AUSTRALIA','6065','0419996056','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 10:51:25',0,NULL,3,0,17,0,NULL,'kimberleyrenee88\r黑色\r'),(17747,735689604018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','kimberleyrenee88','kimberleylaudzevics@hotmail.com','Kimberley Laudzevics','26 Hillsdale Rise','Darch','Western Australia','AUSTRALIA','6065','0419996056','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 10:51:26',0,NULL,3,1,4,1,'YW866012476CN ','kimberleyrenee88\r2mx3m 背景架     1\r3mx6m 黑色背景布    1'),(17748,775535450002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','lasma_m','lasma.muceniece@gmail.com','Lasma Muceniece','Silmalas 19','Rigas raj.','Garkalnes nov','LATVIA','LV-1024','+37129195875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 11:05:28',0,NULL,3,1,17,0,NULL,'lasma_m'),(17749,775535376002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','lasma_m','lasma.muceniece@gmail.com','Lasma Muceniece','Silmalas 19','Rigas raj.','Garkalnes nov','LATVIA','LV-1024','+37129195875','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 11:05:29',0,NULL,3,1,2,1,NULL,'lasma_m\rcanon 三角包  D3    1\r爵影红外 canon      1'),(17750,8881317813661955,111,'New Phototography Studio Softbox Photo Boom Arm Sandbag',2,'AE3101',0,'photographyacc','rarefishbook','rarefishbooks@iinet.net.au','G Lavender','15 Northampton Crescent','Caroline Springs','Victoria','AUSTRALIA','3023','0393630609',NULL,NULL,NULL,'2011-10-05 11:21:01',0,NULL,3,1,4,1,'YW866012480CN ','重发！ \r是整套斜臂， 不用发沙袋，用燕文吧'),(17751,791950401017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','rodriguez.dennisd','dennisdrodriguez@yahoo.com','Dennis Rodriguez','6/39-41 McMillan St.<br>Labrador','Labrador','Queensland','AUSTRALIA','4215','0410986327','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 11:22:14',0,NULL,3,1,2,1,NULL,'rodriguez.dennisd'),(17752,735700441018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 11:29:23',0,NULL,3,1,6,1,'EE495359698CN ','wikran'),(17753,8881317816330852,111,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','photogrim ','lasgunna@gmail.com','Dmitry Zworykin','--','--','','--','','',NULL,NULL,NULL,'2011-10-05 12:05:30',0,NULL,7,0,18,0,NULL,' '),(17754,733173936001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','nadsatof','c.davarend@tiscali.fr','Christophe DAVAREND','743 ROUTE DU SOUBRAN','BENDEJUN','Provence-Alpes-Côte d\'Azur','FRANCE','06390','0623648927','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 12:14:16',0,NULL,3,0,2,1,NULL,'nadsatof\r黑色'),(17755,8881317816874981,111,'115W 220V 灯泡',1,'AKT041',0,'hutongstore','k.c.1957','k_a_c@blueyonder.co.uk','kevin  cox','17 Durnford Avenue<br>Ashton','Bristol','Avon','UNITED KINGDOM','bs32al','01179664996',NULL,NULL,NULL,'2011-10-05 12:14:34',0,NULL,5,0,18,0,NULL,''),(17756,8881317816954508,111,'115W 220V 灯泡',1,'AKT049',0,'hutongstore','k.c.1957','k_a_c@blueyonder.co.uk','kevin  cox','17 Durnford Avenue<br>Ashton','Bristol','Avon','UNITED KINGDOM','bs32al','01179664996',NULL,NULL,NULL,'2011-10-05 12:15:54',0,NULL,3,1,3,1,'RA184564165CN\r ','C里的东西不对，应该是1个，不是2个。 \r（上一票碎了一个，补发）'),(17757,735714618018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','rossopaolo2411','paolo.co84@tiscali.it','Paolo cotica','via arno N 6','asola(mn)','MN','ITALY','46041','0376-729396','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 12:18:39',0,NULL,3,1,2,1,NULL,'rossopaolo2411'),(17758,791967960017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','tapachai','f-k-s@mail.ru','Konstantin Fedotov','Krasniy pereulok, dom 14, kv.93','Alexandrov','Vladimirskaya oblast','RUSSIAN FEDERATION','601655','+79190252570','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 12:19:17',0,NULL,3,1,5,1,'CP238031095CN ','tapachai'),(17759,735715527018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','terra_operative','jaredcabot@live.com.au','Jared Cabot','37 Condamine Street','Runcorn','Queensland','AUSTRALIA','4113','0412556660','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 12:20:29',0,NULL,3,1,3,1,'RA184564324CN\r ','terra_operative'),(17760,733237143001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','werecat87','alexa8387@aol.com','Alexa Arguello','600 NW 107th Ave<br>Apt 9-B','Miami','FL','UNITED STATES','33172','(786) 546-0259','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-05 12:44:26',0,NULL,3,1,1,1,NULL,'werecat87'),(17761,846172178016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',2,'AC1302',11,'hutongstore','photoizzo','photopano@yahoo.fr','VIDALAINQ','28 RUE DE MONTBUISSON','LOUVECIENNES','FRANCE','FRANCE','78430','0603231999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 13:07:05',0,NULL,3,1,17,0,NULL,'photoizzo'),(17762,846172802016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','photoizzo','photopano@yahoo.fr','VIDALAINQ','28 RUE DE MONTBUISSON','LOUVECIENNES','FRANCE','FRANCE','78430','0603231999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 13:08:38',0,NULL,3,1,3,1,'RA184564338CN\r ','photoizzo\r大号内胆包 无字   2\r闪光的柔光箱   60cm    1'),(17763,733253104001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','zip777dl','zip777@gala.net','Lokshin Dmitriy','Ahi Elat 1<br>3','Kiryat Motskin','Haifa','ISRAEL','26382','054-268-1502','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-05 13:39:01',0,NULL,3,1,3,1,'RA184564721CN \rRA184564718CN','zip777dl\r1.6*2.1黑色+白色 \r分开发'),(17764,733257930001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','almico','acohen123@comcast.net','Alan Cohen','208 State Route 28<br>C/O Bridgewater Collision','Bridgewater','NJ','UNITED STATES','08807-1919','(908) 526-0371','NoPaymentFailure','CheckoutComplete','Other','2011-10-05 13:52:46',0,NULL,3,1,1,1,NULL,'almico'),(17765,735744800018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','alex0212','wmsarig@verizon.net','William Sarigeorgiou','10 Millwood Dr','Middletown','DE','UNITED STATES','19709','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 13:53:00',0,NULL,3,1,1,1,NULL,'alex0212'),(17766,735753692018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',52,'photographyacc','photoizzo','photopano@yahoo.fr','VIDALAINQ','28 RUE DE MONTBUISSON','LOUVECIENNES','FRANCE','FRANCE','78430','0603231999','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 14:19:09',0,NULL,3,1,3,1,'RA184564063CN\r','photoizzo\r'),(17767,735753401018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','gshakwon23','gshakwon@hotmail.com','Gilmore Tana','51  Mirrabooka  Rd','Mirrabooka','New South Wales','AUSTRALIA','2264','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 14:19:15',0,NULL,3,1,3,1,'RA184564103CN\r ','gshakwon23'),(17768,732559590001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',9.19,'hermeshine','fariasgefex','gefex@bol.com.br','GIOVANI FARIAS','RUA ANTONIO BERTONCINI, 547 SALA 03<br>CIDADE ALTA','ARARANGUA','SANTA CATARINA','BRAZIL','88900000','+554835245769','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 14:22:09',0,NULL,3,1,2,1,'','fariasgefex\r52cm UV镜    1\r52cm 遮光罩    1 橡胶罩\r肥皂盒 柔光罩   sb800 sb600   1'),(17769,792010319017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',1,'AB3332',2.9,'photographyacc','paultuklu','paul_burmon@yahoo.com.au','Paul Burmon','20/54 Fairmount Street','Lakemba','New South Wales','AUSTRALIA','2195','0280842716','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-05 14:24:22',0,NULL,3,1,2,1,NULL,'paultuklu'),(17770,864094095015,250845678430,'New Pro Photo Vest for all DSLR fans Mesh-line Size',1,'AA1217',17.6,'hutongstore','romaoalves1','romaolalves@gmail.com','Romão Lourenço Alves','Rua Combatentes da Grande Guerra<br>lote 1 2º esq. 2625-652','Vialonga','Perthshire and Kinross','PORTUGAL','2625-652','936100646','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 14:31:48',0,NULL,3,1,3,1,'RA184564298CN\r ','romaoalves1'),(17771,735758056018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','danevilbkk','dan.evil.bkk@gmail.com','Daniel Kublik','238/432 Srivara Mansion 2<br>Dindaeng, Ratchadapisek road, soi nathong 3','Bangkok','BA','THAILAND','10400','0855535924','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 14:32:25',0,NULL,3,1,3,1,'RA184564032CN\r ','danevilbkk'),(17772,864124754015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','per6240','perkronvold@mail.dk','Per Kronvold','Hogelundvej 42','Give','','DENMARK','7323','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 15:34:36',0,NULL,3,1,2,1,NULL,'per6240'),(17773,733293890001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','ilirq','ilir.qose@gmail.com','Ilir Qose','Co SAILPOST<br>Piazzale Martelli 4/A','Ancona','AN','ITALY','60121','+390712410972','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 15:41:06',0,NULL,3,1,4,1,'YW866012465CN ','ilirq\r欧标'),(17774,735788312018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','thaohoang87','thaohoang1@hotmail.com','Anthony Hoang','Level 10, 200 St. Georges Terrace','Perth','Western Australia','AUSTRALIA','6000','0413836491','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 16:01:01',0,NULL,3,1,17,0,NULL,'thaohoang87'),(17775,735791018018,280667758840,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',3.88,'photographyacc','thaohoang87','thaohoang1@hotmail.com','Anthony Hoang','Level 10, 200 St. Georges Terrace','Perth','Western Australia','AUSTRALIA','6000','0413836491','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 16:06:29',0,NULL,3,1,2,1,NULL,'thaohoang87\r方形滤镜接口环 82mm    1\r方镜普通托架（三槽）   1\r方形滤镜接口环 52mm   1'),(17776,733309385001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','nickpapado','nickppado13@hotmail.com','Nikolaos Papadopoulos','Grigoriou Rakitzi 10-12','Serres','Serres','GREECE','62121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 16:19:51',0,NULL,3,1,2,1,NULL,'nickpapado'),(17777,846269730016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','martagab79','martagabruiz@hotmail.com','marta gabaldon','paseo del doctor vallejo nagera 25<br>madrid','madrid','Madrid','SPAIN','28005','678012639','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 16:53:24',0,NULL,3,1,3,1,'RA184564770CN\r ','martagab79'),(17778,846290446016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','sergiokalei2011','nailskalei@gmail.com','Sergio Kalei Bernaldo de Quirós','Calle Embajadores 216 6ºA','Madrid','Madrid','SPAIN','28045','685742105','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-05 17:28:22',0,NULL,3,1,4,1,'YW866012594CN ','sergiokalei2011\r欧标\r黑色背景布'),(17779,735810094018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','monmendez','remg81@hotmail.com','Ramon Eduardo Mendez Garza','501 N Bridge St<br>Ste 859','Hidalgo','TX','UNITED STATES','78557-2530','(834) 312-8023','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 18:07:21',0,NULL,3,1,1,1,NULL,'monmendez\r Ramon Eduardo Mendez Garza \r501 N Bridge Street Suite 859\r Hidalgo TX 78557-2530 \rUnited States '),(17780,735842428018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','atav7344','nana77426@hotmail.com','antonio tavares','14 oak ridge dr','clinton','MA','UNITED STATES','01510-3126','(978) 618-9896','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 18:09:54',0,NULL,3,0,1,1,NULL,'atav7344\rxxl   已入库'),(17781,864220916015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','andrikos1986','magicsnack@live.com','Andreas Socratous','24 Evagora Papachristoforou','Nicosia','','CYPRUS','2019','35799313163','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-05 18:31:01',0,NULL,3,1,3,1,'RA184564386CN\r ','andrikos1986'),(17782,775731989002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','silvermanfamilyracing','silvermanfamilyracing@hotmail.com','Katherine Silverman','6035 Garcia Blvd<br>Apt A','Joint Base Lewis McChord','WA','UNITED STATES','98433-1504','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-05 19:40:58',0,NULL,3,1,1,1,NULL,'silvermanfamilyracing'),(17783,735902426018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','ghenry3214','ghenry3214@yahoo.com','Greg Henry','220 N Woodhill Dr','Amherst','OH','UNITED STATES','44001-1634','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-05 19:48:27',0,NULL,3,1,3,1,'RA184564015CN\r ','ghenry3214'),(17784,864253171015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','mpeirson','michael.peirson@ntlworld.com','MIKE PEIRSON','15 Redhill Lane<br>Great Shelford','Cambridge','Cambridgeshire','UNITED KINGDOM','CB22 5JR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-05 19:59:08',0,NULL,3,1,2,1,NULL,'mpeirson'),(17785,733424375001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','bgsbest','mgcwy@hotmail.com','YAN WANG','17400 Jane street','kettleby','ON','CANADA','L0G1J0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-05 20:21:18',0,NULL,3,1,5,1,'CP238031100CN ','bgsbest\r黑色+白色'),(17786,735928269018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','netda83','nettiferguson@optusnet.com.au','Annette Ferguson','7/40 Nesca Parade','Newcastle','New South Wales','AUSTRALIA','2300','0249292339','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 20:41:42',0,NULL,3,0,2,1,NULL,'netda83\r白色'),(17787,733450222001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','alconger61','alconger@btinternet.com','alan   jones','24 rock street','holyhead','Isle of Anglesey','UNITED KINGDOM','LL651TF','01407760855','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 21:30:37',0,NULL,3,1,3,1,'RA184564284CN\r ','alconger61'),(17788,846457954016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','aroonis','arunas_kolpertas@yahoo.com','arunas kolpertas','7 Northwood gardens','london','London','UNITED KINGDOM','N12 9DR','07596315464','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-05 22:18:35',0,NULL,3,1,2,1,NULL,'aroonis'),(17789,733471469001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','frankabr.','abramstra@prodigy.net','Frank Abrams','19 N Oak Forest Dr','Asheville','NC','UNITED STATES','28803-3333','(828) 651-8966','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-05 22:28:13',0,NULL,3,1,1,1,NULL,'frankabr.'),(17790,792247356017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','shanetalbot56','shane.talbot@bigpond.com.au','Shane Talbot','8 Yanum Place','Chapel Hill','Queensland','AUSTRALIA','4069','0737200383','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 23:08:17',0,NULL,3,1,2,1,NULL,'shanetalbot56'),(17791,733483668001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','frinkati2','thump@tpg.com.au','CLARE STEELE','11 james st','richmond','Victoria','AUSTRALIA','3121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-05 23:17:28',0,NULL,3,1,4,1,'YW866012605CN ','frinkati2\r澳标\r背景布是绿色的'),(17792,789518840017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',187,'photographyacc','13eddy13','eddydagun@hotmail.com','Eddy Hamra','22 Maria Street Tanunda','Adelaide','South Australia','AUSTRALIA','5352','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-05 23:21:31',0,NULL,3,1,4,1,'YW866012572CN ','13eddy13'),(17793,735989865018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','mikool123','michael199220@hotmail.com','Michael / Kim Nguyen','29 Tamarind street<br>Inala','Brisbane','Queensland','AUSTRALIA','4077','0434410740','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-05 23:45:56',0,NULL,3,1,3,1,'RA184564275CN\r ','mikool123'),(17794,792268528017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','81benjdoc','benjamindsouza@bigpond.com','Benjamin D\'souza','23 R.M. Wiiliams Dr','Walkley Heights','South Australia','AUSTRALIA','5098','0883497346','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-06 00:27:07',0,NULL,3,1,4,1,'YW866012583CN ','81benjdoc\r查到这 王明明'),(17795,864395339015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','smart141olegk','smart141@yandex.ru','Olegk Zaiats','agias paraskevis 36','Thessaloniki','Menemeni','GREECE','56122','2310724595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 00:35:55',0,NULL,3,1,3,1,'RA184564219CN\r ','smart141olegk'),(17796,775840453002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bigtoefootball','rodt187@yahoo.com','Rodney s Thomas','3919 Guildford Ln','Williamsburg','Va','UNITED STATES','23188-6629','','NoPaymentFailure','CheckoutComplete','Other','2011-10-06 01:10:28',0,NULL,3,0,1,1,NULL,'bigtoefootball\rXL  已入库'),(17797,792288722017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','xburningkoala','kingxkhun@yahoo.com','Khun Long Chung','4238 Arden Dr','El Monte','CA','UNITED STATES','91731-1953','(626) 408-2622','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 01:40:11',0,NULL,3,1,1,1,NULL,'xburningkoala'),(17798,8881317866917937,111,'lenspen  x    1',1,'AA1310',0,'photographyacc','photogrim ','lasgunna@gmail.com','Dmitry Zworykin','Paustovskogo, 4-305','Moscow','','RUSSIA','117463 RU','+7-916-248-38-05',NULL,NULL,NULL,'2011-10-06 02:08:37',0,NULL,3,1,2,1,NULL,NULL),(17799,775880721002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','onlineshoppingmissy','dangdiaz@yahoo.com','Diaz Armida','260 Orchard Road<br>#11-01/09 The Heeren','Singapore','','SINGAPORE','238855','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 03:37:30',0,NULL,3,1,11,1,'BJ01085280 ','onlineshoppingmissy'),(17800,775888599002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pipcolorado','pipito1963@hotmail.es','Pipo Daniel Santana Bonill','C/ Jose Antonio 114-portal10-3A','Arrecife','Canarias','SPAIN','35500','616888325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 04:17:26',0,NULL,3,1,3,1,'RA184564222CN\r ','pipcolorado'),(17801,736056202018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',6,'AE3104',53.94,'photographyacc','candlewd','kitchbain@bigpond.com','Kitch Bain','18 Omara Blvde','Iluka','Western Australia','AUSTRALIA','6028','0893042349','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 04:24:25',0,NULL,3,1,3,1,'RA184564562CN ','candlewd'),(17802,792340708017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','theprofessor_8176','chemiluminescence@msn.com','Tim Duong','6 Baxter Ave','Kogarah','New South Wales','AUSTRALIA','2217','0295539559','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 05:42:04',0,NULL,3,1,2,1,NULL,'theprofessor_8176'),(17803,736077174018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',3,'AD1169',19.2,'photographyacc','audiotuning11','gigna@gmx.ch','Hermon Habte','Tiefenaustrasse 117','Bern','','SWITZERLAND','3004','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 06:20:05',0,NULL,3,1,2,1,NULL,'audiotuning11'),(17804,792349831017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',125,'photographyacc','keam73','gargstefa@libero.it','Stefano Gargiulo','Via Ugo Foscolo 5','Bergamo','BG','ITALY','24127','3384320556','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 06:31:25',0,NULL,3,1,12,1,'1107563586\r ','keam73\r欧标\r实重4.31 泡重5.79\r最终计费 6kg'),(17805,792363623017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','peterbayblue','peterp@ashburn.com.au','peter philpott','24 Doonkuna Avenue','CAMBERWELL','Victoria','AUSTRALIA','3124','0398307820','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 07:35:35',0,NULL,3,1,2,1,NULL,'peterbayblue'),(17806,864506319015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','lievensr','ronny.lievens@pandora.be','Ronny Lievens','Bosbesstraat 2','Westerlo','','BELGIUM','2260','0498693162','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 07:47:20',0,NULL,3,1,2,1,NULL,'lievensr'),(17807,792367947017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',1,'AA1305',2.5,'photographyacc','shed0801','rebecca_sgyc@hotmail.com','Jessica Burrowes','23 Brown Street','Leongatha','Victoria','AUSTRALIA','3953','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 07:55:05',0,NULL,3,1,2,1,' ','shed0801'),(17808,775927029002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dw4rf_il','dw4rfs@gmail.com','Vadim Toptunov','Haharzit 10a','Maalot','','ISRAEL','21054','(972)052-6039320','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 07:58:52',0,NULL,5,1,18,0,NULL,'dw4rf_il'),(17809,736124523018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 09:56:14',0,NULL,3,1,4,1,'YW866012502CN ','brunos_92\r反光板 100*150 40*60 5合1    3\r发3个给他'),(17810,846653731016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','newey13','lisap@entropie.demon.co.uk','Lisa Phillips','7 Highfield Road<br>wigginton','Tring','Hertfordshire','UNITED KINGDOM','HP236EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 10:39:09',0,NULL,3,1,17,0,NULL,'newey13'),(17811,864551197015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',1,'AO0018',40,'hutongstore','newey13','lisap@entropie.demon.co.uk','Lisa Phillips','7 Highfield Road<br>wigginton','Tring','Hertfordshire','UNITED KINGDOM','HP236EB','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-06 10:39:11',0,NULL,3,0,17,0,NULL,'newey13'),(17812,864550806015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','newey13','lisap@entropie.demon.co.uk','Lisa Phillips','7 Highfield Road<br>wigginton','Tring','Hertfordshire','UNITED KINGDOM','HP236EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 10:39:10',0,NULL,3,0,4,1,'YW868052140CN ','newey13\r反光伞棚90cm     1  （这个退钱给他）今天发走其他的\r2mx1.5m 背景板（黑，白）    1\r3m x 6m背景布 白色\r1.6*2.1粉红背景布\r闪光灯D座     1\r反光伞棚如果有一个就发给他');
INSERT INTO `hmsh_ebay_transaction` VALUES (17813,775967506002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','massimo2680','surya1@tiscali.it','orlando cicala','via caserta 17','grottaglie','TA','ITALY','74023','3355810774','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 10:57:52',0,NULL,3,1,2,1,NULL,'massimo2680'),(17814,864563436015,250845745737,'New Stainless Steel Spanner Wrenches for lens repair',1,'AD1123',28,'hutongstore','debdoodles2005','debbiefranklin2005@yahoo.co.uk','Deborah  Franklin','8 Normans Close','Gravesend','Kent','UNITED KINGDOM','DA110EX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 10:59:11',0,NULL,3,1,3,1,'RA184564681CN\r ','debdoodles2005'),(17815,733634417001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mi-hoosier','jack@mustangjack.com','Jack Wolff','2304 Meadowglen Dr NE','Grand Rapids','MI','UNITED STATES','49505','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 10:59:40',0,NULL,3,1,1,1,NULL,'mi-hoosier'),(17816,733638762001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','messier51dimitris','messier51@hotmail.com','Dimitris Mislis','Flat 2 Springfield Court<br>Chesterton Road','Cambridge','Cambridgeshire','UNITED KINGDOM','CB4 1UL','0223335728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:16:36',0,NULL,3,1,3,1,'RA184564655CN ','messier51dimitris'),(17817,733638956001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','moby_nc','mobync@yahoo.fr','DICKES Jean Bernard','41 rue du commandant Rougy','Noumea','','NEW CALEDONIA','98 800','03.21.83.54.36','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-06 11:18:20',0,NULL,3,1,3,1,'RA184564752CN ','moby_nc'),(17818,733640606001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','ant3774','ant3774@yahoo.com','Antonio Pistillo (06863880966)','Viale elvezia 14','Monza','MB','ITALY','20052','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:28:41',0,NULL,3,1,4,1,'YW868052221CN\r','ant3774'),(17819,733639219001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:36:05',0,NULL,3,1,8,1,'CP238031087CN\r ','saud-p\r除了c 里面的再发  \r3m 横杆（通用3节）  1\r贴made in china  \r申报实值lighting kit  $220'),(17820,733637771001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 11:36:06',0,NULL,3,1,17,0,NULL,'saud-p'),(17821,736160010018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','katiekatieface','ohai.katieface@hotmail.com','katie meyers','27 Franleigh drive','Narre Warren','Victoria','AUSTRALIA','3805','0387747223','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 12:07:18',0,NULL,3,0,2,1,NULL,'katiekatieface\r白色'),(17822,846707880016,260660050217,'Aluminium Ultra Lightweight 71\" Camera Monopod 3wayhead',1,'AE1603',21.99,'hutongstore','wcfpk67','pk_wcf@yahoo.co.uk','paul kendrick','26 eccleston street','wigan','Lancashire','UNITED KINGDOM','wn1 2ay','01977594616','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 13:11:47',0,NULL,3,1,3,1,'RA184564647CN ','wcfpk67'),(17823,736183328018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',3,'AE1203',16.5,'photographyacc','francodesiderio','diving.dept@hotmail.it','DAVINCI Srl','Cso. Umberto I, 391','Montesilvano','PE','ITALY','65015','085-4483014','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 13:22:21',0,NULL,3,1,3,1,'RA184564766CN ','francodesiderio\r加一条肩带 nikon \r新地址\rMario Desiderio \rc/o DAVINCI Srl Cso. Umberto I, 391 \r Montesilvano PE 65015\r Italia'),(17824,736188185018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','april42587','conmark43213@yahoo.com','conalyn matheny','863 Dimson Dr E','columbus','OH','UNITED STATES','43213-2465','(614) 866-8642','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 13:37:20',0,NULL,3,1,1,1,NULL,'april42587\r白  +  黑'),(17825,864633064015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',120,'hutongstore','safronenok2309','safronenok@inbox.lv','Mihails Safronovs','Vienibas gatve 192/2 - 40','Riga','','LATVIA','Lv - 1058','27004800','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 14:07:23',0,NULL,3,1,5,1,'CP238061375CN\r ','safronenok2309\r欧标\rc里面的不对是绿色背景布\r实重9.7 抛重13.7'),(17826,792482244017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',58,'photographyacc','nikofishhunter','fishhunter888@gmail.com','Nikolay Golubev','Tulenina street.10','Almaty','KZ','KAZAKHSTAN','050007','+77017226113','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 14:29:41',0,NULL,3,1,3,1,'RA184564633CN ','nikofishhunter'),(17827,735468616018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','titaan2000','sennh@live.nl','Anke Werter','Martenstraat 1','GRONINGEN','','NETHERLANDS','9724LA','0622697167','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 14:37:45',0,NULL,3,0,3,1,'RA184564678CN ','titaan2000\rXXL  已入库'),(17828,733702300001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','cepn85','serious.pet@gmail.com','Sergey Peterman','Nastavnikov st. 42 - 70','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','195279','+7-911-977-1-977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 15:01:29',0,NULL,3,1,2,1,NULL,'cepn85'),(17829,8881317913990147,111,'77mm 接口环   ',1,'AA2214',0,'hutongstore','david.j.mancey','david_mancey@yahoo.co.uk','David Mancey','5 Cocokhall Close<br>Litlington','Royston','Hertfordshire','UNITED KINGDOM','SG80RB','01763852863',NULL,NULL,NULL,'2011-10-06 15:13:10',0,NULL,3,0,3,1,'RA184564664CN ',NULL),(17830,776045974002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','ezhamid','segunmaru@gmail.com','hamid segunmaru','1 Sandspring Dr<br>330 Cambridge hall','frostburg','MD','UNITED STATES','21532-3104','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-06 15:21:08',0,NULL,3,1,4,1,'YW868052232CN\r','ezhamid'),(17831,864666766015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.9,'hutongstore','basin-city-stomper','clivecarol@btinternet.com','Clive Robb','Oval Circle<br>3 Wishart gardens','Montrose','Angus','UNITED KINGDOM','DD10 8SJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 15:24:51',0,NULL,3,1,2,1,NULL,'basin-city-stomper'),(17832,8881317915008682,111,'斜臂里的轮 （单）',1,'AD1180',0,'hermeshine','clement.barthes','clementbarthes@gmail.com','Clement Barthes','2427 8th St','Berkeley','CA','UNITED STATES','94710-2501','',NULL,NULL,NULL,'2011-10-06 15:30:08',0,NULL,5,0,18,0,NULL,' 问问之前那票发的是反光板支架里那种，还是斜臂里那种，我当时c里的写成“斜臂的夹子（双轮）” 了，如果发错了，就重发一下，是要单轮'),(17833,792509600017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',19.99,'photographyacc','fabri0-10','fabrizioc72@hotmail.com','FABRIZIO COCCIA','ISNELLO 43','CASTELBUONO','PA','ITALY','90013','3204824444','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 15:41:06',0,NULL,3,0,3,1,'RA184564749CN ','fabri0-10\r1.6*3 黑色背景布 '),(17834,846775009016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','shorty_butler-2007','shorty_butler@hotmail.co.uk','Lee Butler','21 School Rd','Silver End','Essex','UNITED KINGDOM','CM8 3RZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-06 15:44:26',0,NULL,3,1,2,1,NULL,'shorty_butler-2007'),(17835,776059714002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','bolivarporto2008','bolivarporto@hotmail.com','Bolivar Porto','Caixa Postal, 330','Campo Grande','Mato Grosso do Sul','BRAZIL','79002-970','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 15:59:45',0,NULL,3,1,3,1,'RA184570554CN\r ','bolivarporto2008\r申报：$45'),(17836,733730149001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 16:06:02',0,NULL,3,1,2,1,NULL,'viong'),(17837,736253872018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','makobite','davidangler@libero.it','DAVIDE MARCONI','VIA NEGROTTO 38','MILANO','MI','ITALY','20157','+390238003800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 16:38:32',0,NULL,3,1,2,1,NULL,'makobite'),(17838,864701443015,250599976878,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D UK',1,'AC2305',4.5,'hutongstore','rakinah23','rakinahallie@gmail.com','Rakinah Mohamed Ali','Blk 473 Sembawang Drive #01-353','default','','SINGAPORE','750473','93872414','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 16:40:09',0,NULL,3,1,11,1,NULL,'rakinah23'),(17839,864708014015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','goldenbu','etirgus@gmail.com','Aigars Reinholds','Viduscels - 10','Ventspils','','LATVIA','LV 3601','29177548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 16:51:05',0,NULL,3,1,3,1,' RA184564412CN','goldenbu'),(17840,733752085001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','fabian612011','fabian61_60@hotmail.com','fabian maldonado loyola','calle 27 #212 jardines de santa clara<br>ecatepec estado de mexico','ecatepec estado de mexico','estado de mexico','MEXICO','55450','57797534','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 17:04:51',0,NULL,3,1,2,1,NULL,'fabian612011'),(17841,776097289002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','juant5','juansanchezt5@hotmail.com','Juan  A Sánchez Rodríguez','C/ Mallorca Nº52<br>Belicena','GRANADA','Andalucía Ceuta y Melilla','SPAIN','18101','663665421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 17:32:21',0,NULL,3,1,3,1,'RA184564559CN ','juant5'),(17842,776109513002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','sidwemn','martin.sidwell@ntlworld.com','Martyn N Sidwell','119 Coniston Grove, Acklam','Middlesbrough','Cleveland','UNITED KINGDOM','TS5 7DF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 17:58:56',0,NULL,3,1,3,1,' RA184564465CN','sidwemn'),(17843,733792831001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','crravell','ravello.cesar@gmail.com','Cesar Ravello','Artemio Gutierrez 2531<br>San Joaquin','Santiago','Region Metropolitana','CHILE','8940713','25569337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 18:28:10',0,NULL,3,1,3,1,'RA184564474CN ','crravell'),(17844,733801727001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sebastian-dsm','sherb-b@ya.ru','Ivan Yakovlev','Leningradsky prospectus 48-84','Moscow','','RUSSIAN FEDERATION','125167','+79263843737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 18:45:29',0,NULL,3,1,2,1,NULL,'sebastian-dsm'),(17845,792597700017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','akravchile','akrav@chile.com','Daniel Alejandro Cea Cifuentes','Ricardo Maragaño # 176-D.','Puerto Williams','XII Región de Magallanes','CHILE','8340518','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 18:47:34',0,NULL,3,1,2,1,NULL,'akravchile'),(17846,733816629001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','eclipse-peter','ebay@store.bg','Petar Vanchev','p.o.box 9<br>Store EOOD','Sofia','Sofia','BULGARIA','1309','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 19:14:49',0,NULL,3,1,3,1,'RA184564488CN ','eclipse-peter'),(17847,736339291018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','--moe--','morgan_harwell@alumni.stanford.edu','Morgan Harwell, The Boeing Co.','PO Box 3452<br>884 Hermosa Ct.','Sunnyvale','CA','UNITED STATES','94088-3452','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 19:30:44',0,NULL,3,1,1,1,NULL,'--moe--'),(17848,776168509002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','raniel22','einar@bkkfiber.no','Einar Langøen','Tjødnavegen 75','Straume','Straume','NORWAY','5353','0047-98236130','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 19:55:06',0,NULL,3,1,2,1,NULL,'raniel22'),(17849,776174289002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','klaussitos','klaussito@sbcglobal.net','Klaus P Schneider','3070 Spring Cir','SILVER SPRINGS','NV','UNITED STATES','89429-7319','(775) 577-4927','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-06 20:06:44',0,NULL,3,1,1,1,NULL,'klaussitos'),(17850,776177508002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','filipswan','filipdizdar@yahoo.com','filip dizdar','Punta 14','Sukošan','Sukošan','CROATIA','23206','098 693 944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 20:13:53',0,NULL,3,1,3,1,'RA184564735CN ','filipswan\r欧标'),(17851,736362995018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','maty2558','marta.cannes@interia.pl','MARTA TYL','6/8 AVENUE DES HESPERIDES<br>RES. ARMORIAL C','CANNES','Provence-Alpes-Côte d\'Azur','FRANCE','06400','06.63.40.43.81','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 20:18:34',0,NULL,3,1,2,1,NULL,'maty2558'),(17852,736373835018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','imagen3','arcosfilm@msn.com','Vega Maroto J.Carlos','Avda de Europa 20','Sonseca','Toledo','SPAIN','45100','617822725','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-06 20:35:58',0,NULL,3,1,2,1,NULL,'imagen3'),(17853,863650831015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',57.98,'hutongstore','mctarakan','oportunity@mail.ru','Sergei Mistsuk','99 the Paddocks<br>Westbury','Limerick','Limerick','IRELAND','LK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-06 20:36:07',0,NULL,3,1,4,1,'YW868052335CN\r','mctarakan\r牛津布大包     1\r1.6*3 黑色+白色背景布  \r3m 横杆（通用3节）    1\r已入库'),(17854,733885064001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','cazalla2011','albertocazalla@hotmail.com','francisco alberto cazalla feria','calle santa maria magdalena 58 3 izq<br>calle santa maria magdalena n58 3 izq','dos hemanas (sevilla)','Andalucía Ceuta y Melilla','SPAIN','41700','955660061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 21:54:08',0,NULL,3,1,17,0,NULL,'cazalla2011'),(17855,733886205001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','cazalla2011','albertocazalla@hotmail.com','francisco alberto cazalla feria','calle santa maria magdalena 58 3 izq<br>calle santa maria magdalena n58 3 izq','dos hemanas (sevilla)','Andalucía Ceuta y Melilla','SPAIN','41700','955660061','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 21:56:57',0,NULL,3,1,4,1,'YW868052324CN\r\r ','cazalla2011\r爵影红外 5 in 1     1\r三脚架 伟峰 WF-6663A     1'),(17856,736408327018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','anthony4acre','anthony4acre@hotmail.com','Anthony Fouracre','83 Bong Bong Rd','Mittagong','New South Wales','AUSTRALIA','2575','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-06 22:01:37',0,NULL,3,1,3,1,'RA184564491CN ','anthony4acre'),(17857,864890779015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','jcleetography','jc-leepalmer@hotmail.co.uk','jordan forse','29 pardoe cresent','barry','The Vale of Glamorgan','UNITED KINGDOM','cf62 8er','4478557204','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-06 22:13:57',0,NULL,3,1,4,1,'YW868052243CN\r\r ','jcleetography\r黑色+白色'),(17858,736415272018,280675004468,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop Blue/Green',1,'AC3304',62,'photographyacc','bushy_dave','dave.f@ihug.com.au','David Field','32 Corinth Road<br>Heathcote','Sydney','New South Wales','AUSTRALIA','2233','0295209236','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-06 22:23:22',0,NULL,3,1,3,1,'RA184564426CN ','bushy_dave'),(17859,733895214001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','kita450','land.77@live.ca','Léo Laniel','1815, rue Nielsen','Saint-Hubert','QC','CANADA','J4T 1P1','(450) 926-2618','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-06 22:27:10',0,NULL,3,1,2,1,NULL,'kita450'),(17860,847000692016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','heyanthony90','antonio.dicarlo@hotmail.it','Antonino Di Carlo','via strada I s.n.','San Lucido','CS','ITALY','87038','3404835402','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-06 22:37:12',0,NULL,3,1,4,1,'YW868052254CN\r','heyanthony90\r欧标\r实重9.48 泡重12.24'),(17861,733915496001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',2,'AO0012',67.98,'hermeshine','ed1515nyc','ed123nyc@msn.com','Eddie Rosario','7942 W Bell Rd<br># 292 Ste C5','Glendale','AZ','UNITED STATES','85308-8710','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-06 23:53:28',0,NULL,3,1,3,1,'RA184567087CN ','ed1515nyc'),(17862,776250257002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','78rpm2011','cosas_variadas@live.com.ar','Florencia Pacienzia','Montevideo 2735<br>1 B','Rosario','Santa Fe','ARGENTINA','2000','+543416847533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 00:00:43',0,NULL,3,1,2,1,NULL,'78rpm2011'),(17863,864926492015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','tohr88888888','jwmpayne2007@hotmail.com','John Paredes','19 LIOS NA RI,SMITHSROAD<br>CHARLEVILLE','Charleville','Cork','IRELAND','default','0862680275','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 00:05:48',0,NULL,3,1,4,1,'YW868052265CN\r','tohr88888888\r黑色+白色'),(17864,736452092018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','greenlightconsulting','denny@totcs.com.au','Denny Cheung','8 /15 Howleys Road','Notting Hill','Victoria','AUSTRALIA','3168','0395433312','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 00:49:31',0,NULL,3,1,3,1,'RA184564505CN ','greenlightconsulting'),(17865,864942634015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','spresv','spresv@gmail.com','Stavros Presvytis','Dardanellion 10','Athens','Egaleo','GREECE','12243','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-07 00:58:09',0,NULL,3,1,4,1,'YW868052276CN\r','spresv\r▲燕文告知由于地址问题  件在当地邮局  需联系客户\r已发信'),(17866,776282567002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','aabsdb','sdbaab@gmail.com','Stephen Braam','3801 N Meridian St<br>Apt 1809','Indianapolis','IN','UNITED STATES','46208-4031','(816) 591-1120','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-07 02:06:04',0,NULL,3,1,1,1,' ','aabsdb'),(17867,733946993001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','colzie72','tickle_pink@hotmail.com','Ann Coles','26 Pembroke Rd','Stratford','Taranaki','NEW ZEALAND','4332','0273215692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 02:07:29',0,NULL,3,1,2,1,NULL,'colzie72'),(17868,733958880001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','k_hagiri_11','hagiri_11@hotmail.com','Hanafi bin Yusop','Environment Unit, TNB Research Sdn. Bhd,<br>No 1, Lorong Air Hitam, Kawasan Institusi Penyelidikan Bangi','Kajang','Selangor','MALAYSIA','43000','0123230419','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-07 02:56:16',0,NULL,3,1,3,1,'RA184564580CN ','k_hagiri_11'),(17869,776296017002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',10.34,'hermeshine','nicksquire','myabsolutevodka@yahoo.co.uk','Nick Amanda','KOMPLEK ANGKASA PURA BLOK P NO. 3<br>RT 014 RW 06 KEMAYORAN JAKARTA PUSAT','DKI JAKARTA','JK','INDONESIA','10630','628170727266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 03:03:23',0,NULL,3,1,2,1,NULL,'nicksquire'),(17870,776306625002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','servac1972','servac@mail.ru','Sergey Pak','Dzerjinskogo, 40-68','Nakhodka','','RUSSIAN FEDERATION','692900','+79025258060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 04:01:22',0,NULL,3,1,3,1,'RA184564593CN ','servac1972'),(17871,724723151001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','jesterjeff69','telefragger@comcast.net','Jeffrey Riggs','205 Green Acre Drive','Williamstown','NJ','UNITED STATES','08094','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-07 04:33:10',0,NULL,3,1,1,1,NULL,'jesterjeff69'),(17872,776317475002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','chengric0','chengric@yahoo.com','Richard Cheng','523 - 88 Arbour Lake Road N.W.','Calgary','AB','CANADA','T3G 0C2','(403) 241-5508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 04:56:39',0,NULL,3,1,3,1,'RA184564602CN ','chengric0'),(17873,792797550017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','jaadmc123','jaadmcnaught@yahoo.com.au','Jaad McNaught','4 Hobbits Glen','Werrington Downs','New South Wales','AUSTRALIA','2747','0449148212','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 05:00:03',0,NULL,3,1,2,1,NULL,'jaadmc123'),(17874,736508342018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',36.8,'photographyacc','john010676','chaillet@iprimus.com.au','Melissa','17 Josephine Avenue','Cranbourne North','Victoria','AUSTRALIA','3977','0359914310','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 05:06:33',0,NULL,3,1,3,1,'RA184564514CN ','john010676'),(17875,847118139016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','eeroratas','eero@taig.ee','Eero Ratas','Tallinna mnt 22','Rapla','Raplamaa','ESTONIA','79512','3725142252','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-07 05:50:03',0,NULL,3,1,5,1,'CP238061353CN\r ','eeroratas\r欧标\r实重7.2 泡重9.1'),(17876,733990874001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mygiftmatters','cdp.cilantro@googlemail.com','COLLIN.D.PEREIRA','35A-MARLDON AVENUE','PAIGNTON','Devon','UNITED KINGDOM','TQ33NY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 06:00:52',0,NULL,3,0,2,1,NULL,'mygiftmatters\r白色'),(17877,776342168002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','inspire336','corey.mcivor@gmail.com','corey or michelle','211 benara road<br>closest cross street sturtridge, if too large leave inside gate','beechboro','Western Australia','AUSTRALIA','6063','61417921934','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 07:15:41',0,NULL,3,1,3,1,'RA184564528CN ','inspire336\r澳标'),(17878,736538546018,280740691257,'New Profession​al Tripod Ball Head  KS-0  + Quick Release Plate for Benro/Manfro',1,'AD1187',36.8,'photographyacc','galex-7','gavrilov_a@kstu.ru','Alexandr Gavrilov','Absalyamova, 18 - 33','Kazan','Tatarstan','RUSSIAN FEDERATION','420124','89274100145','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 07:49:34',0,NULL,3,1,17,0,NULL,'galex-7'),(17879,736537811018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',80,'photographyacc','galex-7','gavrilov_a@kstu.ru','Alexandr Gavrilov','Absalyamova, 18 - 33','Kazan','Tatarstan','RUSSIAN FEDERATION','420124','89274100145','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 07:49:33',0,NULL,3,1,17,0,NULL,'galex-7'),(17880,736538879018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','galex-7','gavrilov_a@kstu.ru','Alexandr Gavrilov','Absalyamova, 18 - 33','Kazan','Tatarstan','RUSSIAN FEDERATION','420124','89274100145','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 07:49:33',0,NULL,3,1,5,1,'CP238061367CN\r ','galex-7\rks-0 III (白盒）    1\r三脚架 伟峰 WF-6663A    1\r独脚架  伟峰 WT-1005    1'),(17881,736546922018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','speciesaravidis','aravidis@optusnet.com.au','tony aravidis','fact 19, 94-102 keys road','Cheltenham','Victoria','AUSTRALIA','3192','0390044924','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 08:23:42',0,NULL,3,1,2,1,NULL,'speciesaravidis'),(17882,847157732016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','9197geoffreyw','geoffwest9@talktalk.net','Mr Geoff West','110 Bancroft<br>Glascote Heath','Tamworth','Staffs','UNITED KINGDOM','B77 2ET','01827304983','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-07 08:29:00',0,NULL,3,1,2,1,' ','9197geoffreyw'),(17883,865065571015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','cajones26','caj001@hotmail.co.uk','Cherie Jones','26 The Crescent','Westbury','Wiltshire','UNITED KINGDOM','BA133HE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 08:56:15',0,NULL,3,1,2,1,' ','cajones26'),(17884,734029472001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','jayuser21','roqueodelfinee@gmail.com','Roque Jr Delfin','Powercon Switchgear Factory<br>Al qusais Industrial 1','Dubai','Dubai','UNITED ARAB EMIRATES','237891','(050)9431083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 09:13:39',0,NULL,3,0,17,0,NULL,'jayuser21'),(17885,776368052002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','lovelight7070','lovelight@dreamwiz.com','sungwon Kim','102ho, 700-9, choji-dong, danwon-gu','ansan-si','kyunggi-do','KOREA,REPUBLIC OF','425-866','821026167784','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 09:14:50',0,NULL,3,1,3,1,'RA184564531CN ','lovelight7070'),(17886,734030710001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','jayuser21','roqueodelfinee@gmail.com','Roque Jr Delfin','Powercon Switchgear Factory<br>Al qusais Industrial 1','Dubai','Dubai','UNITED ARAB EMIRATES','237891','(050)9431083','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 09:17:38',0,NULL,3,0,3,1,'RA184564576CN ','jayuser21\r天涯方形滤镜渐变 ND4  　２\r52mm 接口环    1\r普通托架    2\r58mm 接口环    1 \r已入库\r\r'),(17887,792849882017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','invader11','jon.reader@bigpond.com','Jon Reader','406 Ballarat Road','Sunshine','Victoria','AUSTRALIA','3020','0397437073','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 09:27:16',0,NULL,3,1,2,1,NULL,'invader11'),(17888,736565353018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','i-spy29','fina77c@msn.com','Alfina Chamberlain','58 Nymboida Cresent','Ruse','New South Wales','AUSTRALIA','2560','0298245068','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 09:42:14',0,NULL,3,1,3,1,'RA184564545CN ','i-spy29'),(17889,736565203018,280709593667,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',36,'photographyacc','leameslinnette','leames@aapt.net.au','linnette eames','4 Amaral Ave','Dapto','New South Wales','AUSTRALIA','2530','0242611448','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-07 09:42:45',0,NULL,3,1,3,1,'RA184567095CN ','leameslinnette'),(17890,736594039018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','kafsid','nefsad@gmail.com','Mustafa Karakaya','Yeni Mah. Lale Cad. Yavuz Kolukisa is Merkezi<br>Kat:2 No:68','Nevsehir','','TURKEY','50100','+905325878141','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 11:31:30',0,NULL,3,1,3,1,'RA184567229CN\r ','kafsid'),(17891,847217815016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','tolpuddlemartyrs','norbut01@hotmail.com','Norman Butler','8 Thornlea Lodge, 24 Edge Lane<br>Chorlton','Manchester','Greater Manchester','UNITED KINGDOM','m21 9jf','01618620297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 11:41:23',0,NULL,3,1,2,1,NULL,'tolpuddlemartyrs'),(17892,865143280015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertváros street 59','Budapest','Hungary','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 12:49:49',0,NULL,3,1,2,1,NULL,'garyshark024'),(17893,730588944001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','aspasia1310','aspasia@fastwebnet.it','Federica Cioccoloni','via Casale Radicelli, 67','Roma','Roma','ITALY','00134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 13:04:14',0,NULL,3,1,2,1,NULL,'aspasia1310'),(17894,776446209002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','caperkid','ve1mos@ns.sympatico.ca','Norman G. MacKinnon','P.O. Box 187','Guysborough','NS','CANADA','B0H 1N0','(902) 533-2573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 13:59:44',0,NULL,3,1,3,1,'RA184564620CN ','caperkid'),(17895,776509731002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','3c_elite','3celite@gmail.com','Andy Liu','17/28 Cadell Street','Toowong','Queensland','AUSTRALIA','4066','0421386466','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 16:51:40',0,NULL,3,1,2,1,NULL,'3c_elite'),(17896,736072703018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','aleksey_efimov','fokus_studio@mail.ru','Aleksey Efimov','Dagestanskay 4 68','Yekaterinburg','Sverdlovskay obl','RUSSIAN FEDERATION','620010','+7-912-2849044','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 17:08:32',0,NULL,3,1,2,1,NULL,'aleksey_efimov'),(17897,865255015015,250599955564,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',98,'hutongstore','aguera272','aguera272@hotmail.com','juan manuel gutierrez aguera','provisional hierro uno, número 21, bloque 4, piso 4º A','madrid','Madrid','SPAIN','28045','606097973','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 17:10:06',0,NULL,3,1,4,1,'YW868052280CN\r','aguera272'),(17898,776518827002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','citto51','concettofichera@inwind.it','Concetto Fichera','Via Luigi Pirandello 23','Acireale','CT','ITALY','95024','3287298005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 17:13:48',0,NULL,3,1,2,1,NULL,'citto51'),(17899,865343021015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','pinkalmc','mccaffley@aol.com','alexandra mccaffley','189, sandy lane','lydiate','liverpool','UNITED KINGDOM','L31 2LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 19:35:58',0,NULL,3,1,17,0,NULL,'pinkalmc'),(17900,865343022015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','pinkalmc','mccaffley@aol.com','alexandra mccaffley','189, sandy lane','lydiate','liverpool','UNITED KINGDOM','L31 2LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-07 19:35:59',0,NULL,3,1,2,1,NULL,'pinkalmc\r橡胶遮光罩 72mm    1\r橡胶遮光罩 77mm      1'),(17901,776444349002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','piter915','schreibikus69@gmail.com','Yury Terenya','Lipovskaya str., <br>6, 14','Lipetsk','','RUSSIAN FEDERATION','398002','89038641650','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 20:09:59',0,NULL,3,1,2,1,NULL,'piter915'),(17902,865366173015,250635196516,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',2.79,'hutongstore','r1kman','riku.toivanen@saunalahti.fi','Aki Vuorinen','Ohratie 22','Järvenpää','-','FINLAND','04410','0505912356','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 20:20:59',0,NULL,3,1,2,1,NULL,'r1kman'),(17903,793151208017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',4,'AD1125',50,'photographyacc','i_am_bill','iambillwatson@gmail.com','Bill Watson','2 / 22 Llewellyn street<br>New Farm','Brisbane','Queensland','AUSTRALIA','4005','0430941679','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-07 22:10:22',0,NULL,3,1,3,1,'RA184564616CN ','i_am_bill'),(17904,734311584001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','nativeideas','masterwaki@hotmail.com','Robert Cooper','14 damson place<br>bucklands beach','Auckland','Akl','NEW ZEALAND','2012','2645924','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-07 22:58:55',0,NULL,3,1,6,1,'EE495359675CN\r ','nativeideas\r布换成绿色的\r澳标\r实重9.7 抛重13.77'),(17905,734312826001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','phayes1961','hayes1961@comcast.net','Paul Hayes','1366 Deerfield Rd','Washington','PA','UNITED STATES','15301','','NoPaymentFailure','CheckoutComplete','Other','2011-10-07 23:01:09',0,NULL,3,0,1,1,NULL,'phayes1961\rXL 已入库'),(17906,734313906001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','demtasos2009','demtasos@gmail.com','Anastasios Dempelas','97 Ethnikis Antistasis Str.','KOUFALIA','Thessaloniki','GREECE','57100','2391051618','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-07 23:05:30',0,NULL,3,1,2,1,NULL,'demtasos2009'),(17907,793172102017,270806201214,'Photo Studio Table Light 40cm Cube Kit Box Tent Set',1,'',85,'photographyacc','purplesoul9','egosney74@gmail.com','Emma Gosney','2/44 Ella Grove','Chelsea','Victoria','AUSTRALIA','3196','0419649977','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-07 23:22:15',0,NULL,3,0,4,1,'YW868052291CN\r\r ','purplesoul9\r澳标\r40cm 圆形柔光棚    1\r桌面灯 澳标   2\r38cm 灯架    2\r45w220v   灯泡     2\r已入库'),(17908,736873229018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','diggy653','mikeandhisplants@yahoo.ca','Michael Dahms','1209 Richmond St. #1409','London','ON','CANADA','N6A 3L7','(519) 642-2024','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-07 23:34:07',0,NULL,3,1,2,1,NULL,'diggy653'),(17909,793183773017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','henrikpfeiffer','henrik.pfeiffer@gmail.com','henrik pfeiffer','Ilevollen 22','Trondheim','Trondheim','NORWAY','7018','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 00:09:29',0,NULL,3,1,2,1,NULL,'henrikpfeiffer'),(17910,736876811018,280689694480,'New Continuous Lighting System umbrella with bulbs',1,'AKT068',115,'photographyacc','kilshaugen','roger@kilshaugen.no','Roger Mikalsen','Kil','Naustbukta','','NORWAY','7990','+4799113938','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 00:22:27',0,NULL,3,1,5,1,'CP238061384CN\r ','kilshaugen\r欧标\r实重4.61\r泡重6.07'),(17911,776676413002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','rbefly','rmefrbe@aol.com','Ron Evans','1262 Elizabeth St<br>Apt 204','Denver','CO','UNITED STATES','80206-3249','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-08 00:27:20',0,NULL,3,1,1,1,NULL,'rbefly'),(17912,793199902017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','aronov_artur','aladinboy@gmail.com','artur aronov','malkey israel 147/9','kiryat gat','','ISRAEL','82093','+972542446639','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 01:24:27',0,NULL,3,1,11,1,'BJ01085273 ','aronov_artur'),(17913,734346484001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','x0mandiy','mandiy@live.ca','Amanda Blackport','208-380 Adelaide Street N','London','ON','CANADA','N6B3P6','(226) 235-4523 ext.: 2262347832','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'x0mandiy\r'),(17914,734348897001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','catcraker22','cracker@astound.net','Russell Graham','8627 Thors Bay Rd','El Cerrito','CA','UNITED STATES','94530-2568','','NoPaymentFailure','CheckoutComplete','Other','2011-10-08 01:48:23',0,NULL,3,1,1,1,NULL,'catcraker22'),(17915,776707352002,120566694530,'Neoprene Protector Camera Cover  for Nikon Size: Large ',1,'AC1303',7.5,'hermeshine','djcrystal2525','djcrystal@gmail.com','Ratirat  Boonrak','P.O. Box 4','Muang','Buriram','THAILAND','31000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 02:51:08',0,NULL,3,1,2,1,NULL,'djcrystal2525'),(17916,736925110018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','kiahandcharlie','tom-kez@bigpond.net.au','Kerry Devereaux','4 Whiteley Circuit','Baranduda','Victoria','AUSTRALIA','3691','0260208300','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-08 03:33:12',0,NULL,3,1,4,1,'YW868052302CN\r\r ','kiahandcharlie'),(17917,736940645018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','superbichito','fernapere@yahoo.com.ar','FERNANDO DANIEL PEREZ','SAN LORENZO 589','TANDIL','BUENOS AIRES','ARGENTINA','B7000AEK','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 05:02:49',0,NULL,3,1,3,1,' RA184564695CN\r','superbichito'),(17918,793255472017,270758475500,'Photo Studio translucent white umbrella soft 85cm /33\" ',1,'AD1402',7.8,'photographyacc','samruttyn8r57','samruttyn@hotmail.com','Sam Ruttyn','2 Holt St','Surry Hills','New South Wales','AUSTRALIA','2010','0414743326','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-08 05:58:57',0,NULL,3,1,2,1,NULL,'samruttyn8r57'),(17919,793043540017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',6,'AC2305',71.76,'photographyacc','edc-01e','bc-nc39@nifty.com','Akira Nakano','311 Aza-higashimyoudenchi, Rokugouhigashine,','Misato-chou, Senboku-gun,','Akita','JAPAN','019-1403','090-4425-5200','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 06:27:16',0,NULL,3,1,3,1,'RA184564704CN\r ','edc-01e\r中号内胆包 canon      6\r中号内胆包 nikon     6   （已入库）'),(17920,8881318056007512,111,'2m灯架+斜臂+60cm 闪光灯棚',1,'AKT084',0,'photographyacc','roides42','slateside@hotmail.com','Robert Mora','54 hotham st.','collingwood,','Melbourne Victoria','AUSTRALIA','3066','',NULL,NULL,NULL,'2011-10-08 06:40:07',0,NULL,3,1,4,1,'YW868052313CN\r',NULL),(17921,734316374001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','bitsobo','lisagranger08@gmail.com','Lisa Granger','31 Hyde Park Street','Gateshead','Tyne and Wear','UNITED KINGDOM','NE8 4QB','1914775360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 07:47:27',0,NULL,3,1,2,1,NULL,'bitsobo'),(17922,776765062002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','kowloon71','tomko@mail.com','Thomas Ko','5149 S Graham St','Seattle','WA','UNITED STATES','98118-2938','(206) 359-0254','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-08 08:06:25',0,NULL,3,1,1,1,NULL,'kowloon71'),(17923,736956398018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','cquattro128','comp_si@optushome.com.au','Chris Thanh Quach','83 Stella St<br>Fairfield Heights','Sydney','New South Wales','AUSTRALIA','2165','0283326625','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-08 08:22:22',0,NULL,3,1,4,1,'YW868052346CN\r ','cquattro128'),(17924,776769232002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','allex1978','alex78@ukr.net','Olexandr  Kotovskyi','vul. Kutuzova 4 kv2.','Vyshneve','Kyivska obl','UKRAINE','08133','+380674034555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 08:22:49',0,NULL,3,1,2,1,NULL,'allex1978'),(17925,8881318062736802,111,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',69.47,'aliexpress','1004645101','roman@rndlug.ru','Roman Nikitin	','Zorge 60/1, ap.86','Rostov-on-Don	','Russia','RUSSIAN FEDERATION	','344103','+7 863 2188877',NULL,NULL,NULL,'2011-10-08 08:32:16',0,NULL,3,1,5,1,'CP238061438CN ',NULL),(17926,865577005015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dangermouse631','bart45@btinternet.com','Michael Bartlett','45 Fairmount Road','Brixton Hill','London','UNITED KINGDOM','SW22BJ','02082443591','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 08:44:53',0,NULL,3,1,3,1,'RA184564908CN ','dangermouse631'),(17927,734453437001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','geostrigr','strigaris@gmail.com','George Strigaris','Antoniou Pelekanou 8','Aegina','Attica Greece','GREECE','18010','302297025627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 10:25:32',0,NULL,3,1,17,0,NULL,'geostrigr'),(17928,776801806002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','geostrigr','strigaris@gmail.com','George Strigaris','Antoniou Pelekanou 8','Aegina','Attica Greece','GREECE','18010','302297025627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 10:25:33',0,NULL,3,1,17,0,NULL,'geostrigr'),(17929,734453438001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','geostrigr','strigaris@gmail.com','George Strigaris','Antoniou Pelekanou 8','Aegina','Attica Greece','GREECE','18010','302297025627','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 10:25:34',0,NULL,3,1,3,1,'RA184567135CN ','geostrigr\r80cm5和1 反光板     1\r柔光箱 50-70cm 单灯头欧标   1\r大力夹   1'),(17930,734454056001,110469599322,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.99,'hermeshine','arnelcindy','arnelm2000@yahoo.com','Arnel Macababbad','16 St Vincent Way','Caroline Springs','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-08 10:28:32',0,NULL,3,1,17,0,NULL,'arnelcindy'),(17931,776803091002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','arnelcindy','arnelm2000@yahoo.com','Arnel Macababbad','16 St Vincent Way','Caroline Springs','Victoria','AUSTRALIA','3023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 10:30:39',0,NULL,3,1,2,1,NULL,'arnelcindy\r双灯头  澳标    1\rc型大力夹     1'),(17932,865612839015,250599941151,'55mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1302',2.26,'hutongstore','barbaraa7307','ba@calartha.plus.com','Barbara Armstrong','10 Calartha Terrace<br>Pendeen','Penzance','Cornwall','UNITED KINGDOM','TR19 7DX','01736788413','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 10:30:41',0,NULL,3,1,17,0,NULL,'barbaraa7307'),(17933,865612398015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','barbaraa7307','ba@calartha.plus.com','Barbara Armstrong','10 Calartha Terrace<br>Pendeen','Penzance','Cornwall','UNITED KINGDOM','TR19 7DX','01736788413','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 10:30:42',0,NULL,3,1,2,1,NULL,'barbaraa7307\r橡胶遮光罩 55mm    1\r橡胶遮光罩 52mm    1'),(17934,776807181002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-08 10:45:53',0,NULL,3,1,3,1,'RA184567158CN ','leifs123\r是4个\r申报：$30'),(17935,776819508002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','julesholling123','julesholling123@yahoo.co.uk','Julian Hollingshead','Nikon UK Ltd<br>380 Richmond Road','Kingston upon Thames','Surrey','UNITED KINGDOM','KT2 5PR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 11:26:17',0,NULL,3,1,2,1,NULL,'julesholling123'),(17936,793359217017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','moitib','xu10j4rs@hotmail.fr','hervé odilon','6 rue de la fontaine','brue-auriac','Provence-Alpes-Côte d\'Azur','FRANCE','83119','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 12:12:28',0,NULL,3,1,2,1,NULL,'moitib'),(17937,776841154002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tankards','finearts@vaxxine.com','Josiah Grimmitt','5, Garrison Village Drive','Niagara on the Lake','ON','CANADA','L0S 1J0','(905) 468-1744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 12:34:19',0,NULL,3,1,3,1,'RA184564823CN ','tankards'),(17938,734500490001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','toribiopantalone','luis.martinezsaiz@free.fr','Luis MARTINEZ SAIZ','34 allée Alphonse Daudet','Noisy le Grand','Ile-de-France','FRANCE','93160','0668886894','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 12:59:55',0,NULL,3,1,3,1,'RA184564810CN ','toribiopantalone'),(17939,737063252018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',2,'AB3329',97.98,'photographyacc','kiisumiisu123','virginia.kanosin@hot.ee','Virginia Kullasepp','Ringi 1a-3','Sindi city','Pärnumaa','ESTONIA','86703','(372)56313303','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 13:01:32',0,NULL,3,1,5,1,'CP238061424CN','kiisumiisu123\r是两个'),(17940,865677323015,250599978042,'Neoprene Camera Cover for Nikon D50 D70s D80 D90',1,'AC2304',4.5,'hutongstore','andrea.tripaldi','andrea.tripaldi@libero.it','Andrea Tripaldi','Via Sottomonte, 15','Trieste','TS','ITALY','34135','+393495605897','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-08 13:11:32',0,NULL,3,1,2,1,NULL,'andrea.tripaldi'),(17941,734490261001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','sean.oz','seanoz@msn.com','Sean R O\'Sullivan','167 Wells St','SPRINGFIELD','New South Wales','AUSTRALIA','2250','0243234444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 13:30:30',0,NULL,3,1,2,1,NULL,'sean.oz'),(17942,734512507001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','santiagoresgate','diretoria@resgate.com.br','CLEI WANDESON FERREIRA SANTIAGO','Rua Dom Pedro II, 549 room 107 Ed.<br>Center Gloria Shopping - Gloria','Vila Velha','ES','BRAZIL','29122-300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-08 13:34:15',0,NULL,3,0,3,1,'RA184564899CN ','santiagoresgate\r3XL   已入库'),(17943,847807062016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gionnymix','gildone79@hotmail.com','Vito Melillo','Corso Dauno Irpino 37','Rocchetta S. Antonio','FG','ITALY','71020','349-0809266','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-08 14:21:23',0,NULL,3,1,4,1,'YW868052195CN ','gionnymix\r欧标\r电话 0039 349 0809266\r'),(17944,793454733017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','alex62420','pklo62@hotmail.com','Alexandre Dlubala','8 rue Jeanne D\'arc','Billy Montigny','Nord-Pas-de-Calais','FRANCE','62420','0645265395','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 16:06:36',0,NULL,3,1,2,1,NULL,'alex62420'),(17945,734574272001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','+79214501223','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-08 16:11:43',0,NULL,3,1,17,0,NULL,'dm-pal'),(17946,776927074002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','+79214501223','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-08 16:15:19',0,NULL,3,1,17,0,NULL,'dm-pal'),(17947,776928673002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186220','+79214501223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:17:33',0,NULL,3,1,3,1,'RA184567127CN ','dm-pal\r配50-70棚的4灯头伞孔   欧标   1\r115w 5500k 灯泡  220v    2\r普通有线快门线C3    1'),(17948,776940690002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','rey0161','alvarezreinaldo@yahoo.es','Reinaldo Alvarez','Pericle 5','Milano','MI','ITALY','20126','+393394725358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:50:23',0,NULL,3,1,17,0,NULL,'rey0161'),(17949,776938607002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',4,'AE3104',38.72,'hermeshine','rey0161','alvarezreinaldo@yahoo.es','Reinaldo Alvarez','Pericle 5','Milano','MI','ITALY','20126','+393394725358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:50:24',0,NULL,3,1,17,0,NULL,'rey0161'),(17950,734589105001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','rey0161','alvarezreinaldo@yahoo.es','Reinaldo Alvarez','Pericle 5','Milano','MI','ITALY','20126','+393394725358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:50:24',0,NULL,3,1,17,0,NULL,'rey0161'),(17951,734588301001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',2,'AD1180',27.8,'hermeshine','rey0161','alvarezreinaldo@yahoo.es','Reinaldo Alvarez','Pericle 5','Milano','MI','ITALY','20126','+393394725358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 16:50:25',0,NULL,3,1,3,1,'RA184567113CN ','rey0161\r沙袋（普通）    2\rc型大力夹     4\r反光板支架的夹子（双轮）   1\r斜臂的夹子（单轮）    2'),(17952,776952453002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','maximiliano1977','mpell@maxpell.com.ar','Maximiliano Pell','Mitre 348 - Piso 9 - Departamento 3','Rosario','Santa Fe','ARGENTINA','2000','0054 341 4498039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 17:08:47',0,NULL,3,1,3,1,'RA184567060CN ','maximiliano1977'),(17953,734607686001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','hub779','rgibhamsa@hotmail.com','Richard Gibson','555 Redondo Ave<br>Apt 302','Long Beach','CA','UNITED STATES','90814-5194','(562) 343-1130','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-08 17:21:57',0,NULL,3,1,1,1,NULL,'hub779'),(17954,776972111002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','madzo007','juraj.madzunkov@gmail.com','Juraj Madzunkov','Apt.9 Block A,Baileys court (PHONE 0864001142)<br>Summerhill','Dublin 1','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 17:49:44',0,NULL,3,1,2,1,NULL,'madzo007'),(17955,847927004016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','mr.greengrass','greenasgrass@live.co.uk','Mr C J Smith','34 Weldon Avenue<br>Weston Coyney','Stoke-on-Trent','Staffordshire','UNITED KINGDOM','ST3 6PN','01782546309','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 17:56:01',0,NULL,3,1,2,1,NULL,'mr.greengrass'),(17956,865828939015,250599949620,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',17,'hutongstore','jodulo','lonny@blueyonder.co.uk','John Lonican','64 Patterdale Ave.','Blackpool','Lancashire','UNITED KINGDOM','FY39QU','01253767191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 17:56:10',0,NULL,3,1,17,0,NULL,'jodulo'),(17957,865826270015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',2.25,'hutongstore','jodulo','lonny@blueyonder.co.uk','John Lonican','64 Patterdale Ave.','Blackpool','Lancashire','UNITED KINGDOM','FY39QU','01253767191','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-08 17:56:10',0,NULL,3,1,3,1,'RA184567073CN ','jodulo\r天涯方形滤镜  ND2   1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  ND8     1\r方形滤镜接口环 58mm   1 \r方镜广角托架（一槽）     1\r方形滤镜接口环 77mm    1'),(17958,776983023002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','awickedwit','catbyerly@gmail.com','Cathy A. Byerly','493 American Way S','Carmel','IN','UNITED STATES','46032-7621','(317) 705-1539','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-08 18:12:21',0,NULL,3,1,1,1,NULL,'awickedwit'),(17959,737224493018,280674081169,'New 67mm Snap-on Front Lens Cap for Nikon 67 mm lenscap',1,'AA1307',2.5,'photographyacc','henrikpfeiffer','henrik.pfeiffer@gmail.com','henrik pfeiffer','Ilevollen 22','Trondheim','Trondheim','NORWAY','7018','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 18:51:56',0,NULL,3,1,2,1,NULL,'henrikpfeiffer'),(17960,734607209001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','matushkin123','matushkin@gmail.com','Alexey  Matushkin','Kosmonavtov street, 25-12','Rostov-on-Don','rnd','RUSSIAN FEDERATION','344113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 20:07:30',0,NULL,3,1,5,1,'CP238061398CN ','matushkin123'),(17961,737262253018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','danilo6601','ddalfonso@libero.it','Danilo D Alfonso','Via macallè N°12','Ascoli Piceno','AP','ITALY','63100','392-7286766','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-08 20:08:07',0,NULL,3,1,4,1,'YW868052206CN ','danilo6601'),(17962,777070467002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','aviadn','aviad87@gmail.com','Aviad Notrica','Nahalat Tzvi 59','Petah-Tiqwa','','ISRAEL','49421','0544892242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 21:28:47',0,NULL,5,0,18,0,' ','aviadn'),(17963,734737147001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1203',10,'hermeshine','miguelcabrita','white.devil2@hotmail.com','Miguel Cabrita','Carrasqueira 156x<br>S.B.Messines','S.B.Messines','Algarve','PORTUGAL','8375-023','+351966166601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 22:24:34',0,NULL,3,1,2,1,NULL,'miguelcabrita'),(17964,737331280018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','rd5970','rieck.dalal@yahoo.com.au','Rieck Dalal','Alcon Laboratories (Australia) Pty Ltd<br>10 / 25 Frenchs Forest Rd East','Frenchs Forest','New South Wales','AUSTRALIA','2086','0294529302','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-08 23:19:47',0,NULL,3,1,2,1,NULL,'rd5970'),(17965,777108300002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tnttamu','onlyu_dip@hotmail.com','Deepak Gurung','15/6-8 Belmore street','Burwood','New South Wales','AUSTRALIA','2134','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-08 23:44:56',0,NULL,3,1,2,1,NULL,'tnttamu'),(17966,793672697017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',1,'AA1305',2.5,'photographyacc','dwinnah','mikew@hbni.net','Mike Waldner','PO Box 259','Pembina','ND','UNITED STATES','58271-0259','(204) 353-2251','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 00:40:44',0,NULL,3,1,1,1,NULL,'dwinnah'),(17967,793684537017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','lipczak2607','nikoline@lipczak.dk','Nikoline Lipczak Hansen','21/725 Wellington Street','Perth','Western Australia','AUSTRALIA','6000','0420207739','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 01:26:36',0,NULL,3,1,2,1,NULL,'lipczak2607'),(17968,737369225018,280696883124,'New Pro Photo Vest for all DSLR fans Mesh-line ',1,'AA1217',24,'photographyacc','hannerilou','hannah_yous1988@hotmail.com','Hannah Yousiph','8 Seidel Place Abbotsbury','Sydney','New South Wales','AUSTRALIA','2176','0296105650','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 01:49:45',0,NULL,3,1,3,1,'RA184567144CN ','hannerilou'),(17969,866056418015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','thai-store11','thaithaistore11@hotmail.com','Rujirat Teanpradubchok','170/34 Aukanivat Road<br>T.Bangprachoi','Muang','Chon Buri','THAILAND','20000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 03:02:42',0,NULL,3,1,2,1,' ','thai-store11'),(17970,737399625018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','ruben3320','romanempire.xxiv@gmail.com','Roman Lah','11446 Polo Club Ct','South Jordan','UT','UNITED STATES','84095-8300','(801) 673-9404','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 04:09:59',0,NULL,3,1,3,1,'RA184567215CN\r ','ruben3320'),(17971,737401090018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',80,'photographyacc','jsamcer','orbs87@hotmail.com','Julio Samamé','Jr. Las Micas 270<br>Urb. Las Flores 78. San Juan de Lurigancho','LIMA','LIMA','PERU','Lima 36','(511) 458-0831','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 04:17:39',0,NULL,3,1,5,1,'CP238061407CN ','jsamcer'),(17972,734799794001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',41.9,'hermeshine','clevercardgranada','clever@granadafilmes.com.br','clever Cardoso Teixeira','Rua Haddock Lobo, 988 atp. 33, Bl. 02, Ed. Danielle, Jardins','São Paulo','Sao Paulo','BRAZIL','01414-000','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-09 04:30:37',0,NULL,3,1,3,1,'RA184564845CN ','clevercardgranada'),(17973,777172225002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','oakpho','oaktreephoto@comcast.net','Aaron Yurkanin','314 bridge st','peckville','PA','UNITED STATES','18452','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-09 04:33:28',0,NULL,3,1,3,1,'RA184567011CN ','oakpho'),(17987,734896016001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','mattclarkemedia','matt@mattclarkemedia.com.au','Matthew Clarke Media','Office 109, 48 Atchison Street','St Leonards','New South Wales','AUSTRALIA','2065','0299013339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 09:50:36',0,NULL,3,1,3,1,'RA184567334CN\r ','mattclarkemedia'),(17974,737423628018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','bitomco','azberman@gmail.com','Mort Berman','19818 N VALENCIA CT','Surprise','AZ','UNITED STATES','85374','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 06:30:39',0,NULL,3,1,1,1,NULL,'bitomco'),(17975,737425213018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','mummytunney','d.murray2@bigpond.com','debra murray','15 mitchell street','merewether','New South Wales','AUSTRALIA','2291','0249634917','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 06:37:05',0,NULL,3,1,3,1,'RA184567192CN\r ','mummytunney'),(17976,793510540017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',146.8,'photographyacc','vincent6306','vobernardin@aim.com','Vincent Bernardin VIAPASS','105, Boulevard de la Republique','Cannes','Alpes Maritimes','FRANCE','06400','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 06:46:24',0,NULL,3,1,4,1,'YW868052184CN ','vincent6306\r45w 220v    4\r115w 220v     2\r单灯头 欧标    1\r40cm 棚     1\r桌面灯   欧标    2\r38cm 灯架      2\r已入库\r\r\r'),(17977,777203370002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','candy_engel','candyschartz@yahoo.co.uk','Candy Schartz-Engel','131 Claremont Avenue','New Malden','Surrey','UNITED KINGDOM','KT3 6QR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 07:15:38',0,NULL,3,1,2,1,NULL,'candy_engel\r英标'),(17978,777205986002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','sixties-and-seventies','adnan_pamukcu@hotmail.com','Adnan Pamukçu','Caferaga Mah. Yaver Bey Sok. No. 2/2<br>Moda-Kadiköy','Istanbul','-','TURKEY','34710','902164186956','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 07:27:14',0,NULL,3,1,5,1,'CP238061469CN ','sixties-and-seventies'),(17979,8881318146443490,111,'45w 220v   x     1',1,'AO0003',0,'hutongstore','c6bon','lens444@yahoo.fr','Jean Louis Carrasco','57 rue du Moulin Vert','PARIS','PARIS','FRANCE','75014','+33611183830',NULL,NULL,NULL,'2011-10-09 07:47:23',0,NULL,3,1,3,1,'RA184567189CN\r ','9月12日补发的碎了，再次补发，所以包装尽可能结实些。 '),(17980,777223550002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','patrickkoh118','hbkoh118@yahoo.com','PATRICK KOH','23 JALAN PB 8/3F<br>PUTRA HEIGHTS','SUBANG JAYA','SELANGOR','MALAYSIA','47650','0193223306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 08:32:39',0,NULL,3,1,2,1,NULL,'patrickkoh118'),(17981,737456698018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','moheagan','ramztek@tpg.com.au','Ramzi Wanna','34 Omeally street<br>Prairiewood','Sydney','New South Wales','AUSTRALIA','2176','0296046507','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 08:36:01',0,NULL,3,1,3,1,'RA184567175CN\r ','moheagan\r已入库'),(17982,737460440018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','lucasofty','lucafranceschiph@gmail.com','luca','franceschi<br>via gorizia 70','reggio emilia','RE','ITALY','42124','3490560645','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 08:47:37',0,NULL,3,1,3,1,'RA184567161CN\r ','lucasofty\rSoft Box  $12'),(17983,737461208018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','kamalko','dr.malko@gmail.com','Damir Kudyakov','Timiryazev str.30a,app.23','Almaty','','KAZAKHSTAN','050040','(707) 837-8775','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 08:49:11',0,NULL,3,1,3,1,'RA184567232CN\r ','kamalko'),(17984,793775654017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','abishek2010','avishekj@hotmail.com','Abishek Joshi','Unit 15,27 Queen Victoria St.','Bexley','New South Wales','AUSTRALIA','2207','0434536550','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 08:57:20',0,NULL,3,1,2,1,NULL,'abishek2010'),(17985,777235845002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27.8,'hermeshine','upswerner2008','peter_werner@telia.com','Peter Werner','Tyringegatan 252','Helsingborg','Skåne','SWEDEN','25276','+46707360905','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 09:11:08',0,NULL,3,1,2,1,NULL,'upswerner2008'),(17986,734889880001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','charnescas','spiritofwhitewidow@hotmail.com','Luis Gutierrez Gonzalez','C/San Pedro Nº3 Escalera 6 3ºA','Leganes','Madrid','SPAIN','28917','656997311','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 09:33:01',0,NULL,3,1,4,1,'YW866012616CN','charnescas'),(17988,866175369015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','ed9911','echivers@ozemail.com.au','Ed Chivers','34 Balemo St','Minyama','Queensland','AUSTRALIA','4575','0754777651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 09:51:20',0,NULL,3,1,17,0,NULL,'ed9911'),(17989,866174533015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','ed9911','echivers@ozemail.com.au','Ed Chivers','34 Balemo St','Minyama','Queensland','AUSTRALIA','4575','0754777651','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 09:51:20',0,NULL,3,1,3,1,'RA184567780CN ','ed9911\r除了c 里面的再发\r透明10片装盒    1\r接口环是67mm'),(17990,777256010002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','andriy_k','andriy.koretsky@gmail.com','Andriy Koretsky','ul. Pozharskogo 1, kv. 114','Kiev','','UKRAINE','02094','+380505433772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:07:09',0,NULL,3,1,17,0,NULL,'andriy_k'),(17991,777257414002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','andriy_k','andriy.koretsky@gmail.com','Andriy Koretsky','ul. Pozharskogo 1, kv. 114','Kiev','','UKRAINE','02094','+380505433772','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:07:09',0,NULL,3,1,3,1,'RA184567303CN\r ','andriy_k\rc型大力夹    2\r大力夹    2'),(17992,734907735001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','eugenmal','evmalev@gmail.com','Nadezhda Pashskaya','Detskoselskij, 7 - 17<br>Pushkin','Sankt-Peterburg','','RUSSIAN FEDERATION','196605','+7 931 244 7 022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 10:20:02',0,NULL,3,1,2,1,NULL,'eugenmal'),(17993,737383121018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','alxx09','alexwongyh@yahoo.com','Wong Yin Hon','Bangunan NSSDC, Batu 8 1/2,<br>Jalan Seremban-Mantin,','Mantin','Negeri Sembilan','MALAYSIA','71700','016-2059977','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 10:23:31',0,NULL,3,1,2,1,NULL,'alxx09'),(17994,737497570018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','gods_gift1993','gods_gift93@hotmail.com','Aaron Marr','12  Smith  St','Reservoir','Victoria','AUSTRALIA','3073','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 10:21:26',0,NULL,3,1,4,1,'YW866012620CN ','gods_gift1993'),(17995,848306509016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','aamirhch313','aamirhch@hotmail.com','Aamir Chaudhry','23- woodlands Court<br>91-Woodvale','London','London','UNITED KINGDOM','SE23 3DP','02086935507','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 11:06:09',0,NULL,3,1,2,1,NULL,'aamirhch313'),(17996,793851305017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',58,'photographyacc','eringraceb','eringrace.b@hotmail.com','Erin Blackford','25 Bambridge Street','Chester Hill','New South Wales','AUSTRALIA','2162','0217256904','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 11:21:57',0,NULL,3,1,4,1,'YW866012631CN ','eringraceb'),(17997,793855953017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','k_thats_it','odrykar@yahoo.com','Karl Odry','5/55 Manson Road<br>Strathfield','Sydney','New South Wales','AUSTRALIA','2135','6145054395','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-09 11:32:51',0,NULL,3,1,2,1,NULL,'k_thats_it'),(17998,737530900018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','gabehulk','gabemouawad@gmail.com','Gabriel Mouawad','6/127 Greenacre DV','ARUNDEL','Queensland','AUSTRALIA','4214','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 11:42:50',0,NULL,3,1,3,1,'RA184567294CN\r ','gabehulk'),(17999,848337502016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','shchukins2010','shchukin.s@gmail.com','Sergey Shchukin','Vorovskogo 38<br>FGU GB MSE','Kingisepp','Leningradskaya oblast','RUSSIAN FEDERATION','188480','+79118446416','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 12:10:44',0,NULL,3,1,2,1,NULL,'shchukins2010'),(18000,793891089017,270755378942,'4 Bulb Stocks with 24x24\"/60x60cm Folding Easy Soft box',1,'AE2201',42,'photographyacc','karlacosmetica','karlawong.88@gmail.com','Karla Wong','129 Blackburn rd, Blackburn','Blackburn','Victoria','AUSTRALIA','3130','6141168137','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 12:52:21',0,NULL,3,1,17,0,' ','karlacosmetica'),(18001,737562166018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','dudusalasmolina','eduardosalasmolina@gmail.com','Eduardo Salas Molina','C/Centro<br>3-3º-3ª','Gavà Barcelona','Cataluña','SPAIN','08850','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 12:53:46',0,NULL,3,1,3,1,'RA184567285CN\r ','dudusalasmolina'),(18002,737562603018,280685221276,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm ',1,'AE3403',38,'photographyacc','karlacosmetica','karlawong.88@gmail.com','Karla Wong','129 Blackburn rd, Blackburn','Blackburn','Victoria','AUSTRALIA','3130','6141168137','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 12:55:16',0,NULL,3,1,4,1,'YW866012642CN ','karlacosmetica\r柔光箱 60-60cm  四灯头  澳标  1\r注意有个60*60的柔光棚\r2m 弹簧灯架    1\r'),(18003,848386156016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','markro01','rolmark@inbox.lv','Rolands Markuns','Niederlenzer Kirchweg 5c<br>(Gleis 2)','Lenzburg','','SWITZERLAND','5600','0041079903697','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 13:35:11',0,NULL,3,1,2,1,NULL,'markro01'),(18004,734987494001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','lennartlemajo','lebj@telia.com','Lennart Björkegren','Björkåsvägen 20','Karlstad','','SWEDEN','65342','004554568484','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-09 13:36:30',0,NULL,3,1,17,0,NULL,'lennartlemajo'),(18005,734991369001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','lennartlemajo','lebj@telia.com','Lennart Björkegren','Björkåsvägen 20','Karlstad','','SWEDEN','65342','004554568484','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 13:45:21',0,NULL,3,1,4,1,'YW868052114CN ','lennartlemajo\r背景架2mx2m  + 3个夹子    1\r1.6*2.1黑色+白色背景布  \r镜头筒 小号    1'),(18006,735000679001,110544334378,'JueYing Lambency Flash Diffuser 4 SB26 F56AM EF500 P3',1,'AB3310',22,'hermeshine','brandy64bob','blueberry76my@hotmail.com','Bob  Ahlwat','30777<br>Cardinal ave','Abbotford','BC','CANADA','V2t 6w7','(604) 723-4487','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-09 14:10:09',0,NULL,3,1,17,0,NULL,'brandy64bob'),(18007,777350102002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','brandy64bob','blueberry76my@hotmail.com','Bob  Ahlwat','30777<br>Cardinal ave','Abbotford','BC','CANADA','V2t 6w7','(604) 723-4487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 14:10:11',0,NULL,3,1,5,1,'CP238061441CN ','brandy64bob\r2 b 柔      2\r爵影碗罩P3      1  '),(18008,737645470018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','properexposure57','dtbramadat@mts.net','Derek Bramadat','18 Normandy Drive','Winnipeg','MB','CANADA','R2Y 1H9','(204) 889-4428','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 15:35:25',0,NULL,3,1,5,1,'CP229939758CN','properexposure57\rCP238061455CN换为CP229939758CN  面单破损\r'),(18009,777422693002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','vieux-motard89','jean-noel.lobjoit@wanadoo.fr','Jean-Noel LOBJOIT','3 grande rue<br>BARRAULT','THORIGNY SUR OREUSE','Bourgogne','FRANCE','89260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 16:00:45',0,NULL,3,1,2,1,NULL,'vieux-motard89'),(18010,735051508001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','bamrudj','jan.erik@bamrud.no','Jan Erik Bamrud','Vinkelveien 18','Hokksund','','NORWAY','3300','+47 99251450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 16:06:20',0,NULL,3,1,3,1,'RA184567277CN\r ','bamrudj\r四个'),(18011,737676804018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',22,'photographyacc','emzuy','emzzzuy@yahoo.com','Emerie Uy','C/O Rogelio Uy, High-way Maguikay<br>Near Profoods, Beside Breeders','Mandaue City','Cebu','PHILIPPINES','6014','9228185827','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 16:21:36',0,NULL,3,1,17,0,NULL,'emzuy'),(18012,737677002018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','emzuy','emzzzuy@yahoo.com','Emerie Uy','C/O Rogelio Uy, High-way Maguikay<br>Near Profoods, Beside Breeders','Mandaue City','Cebu','PHILIPPINES','6014','9228185827','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 16:21:36',0,NULL,3,1,3,1,'RA184567317CN ','emzuy\r圆形柔光棚 40cm    1\r倒影板（白黑）    1\r客户想挂号   钱已经付了\r'),(18013,866428475015,250634555406,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'AA2203',2.75,'hutongstore','ichigoten','anthonynoel@live.fr','Anthony Noel','15 rue Michatel','Toul','Lorraine','FRANCE','54200','0649403710','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 16:57:12',0,NULL,3,1,2,1,NULL,'ichigoten'),(18014,794047960017,270777060056,'Studio Continuous Light Kit 23\' SoftBox 4 output 45w x8',1,'AKT039',170,'photographyacc','hagan_art','hagan_6@hotmail.com','Graeme Hagan','430/27 Moo 9 Soi Arunothai','Nongprue Pattaya','Banglamung Chonburi','THAILAND','20260','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 17:09:38',0,NULL,3,1,6,1,'EE491015811CN ','hagan_art\r\r\r\r'),(18015,735116513001,110419713533,'52mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1301',3.15,'hermeshine','jalmeidaa','jalmeidaa@gmail.com','João Carlos de Aquino Almeida','Av. Alberto Lamego 2000<br>LFBM - CBB - UENF','Campos dos Goytacazes','RJ','BRAZIL','28013602','552135217778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 17:12:38',0,NULL,3,1,2,1,NULL,'jalmeidaa'),(18016,777480075002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','oran_jerry','home@dannymol.co.uk','Danny Molyneux','9 Patch Croft Road','Manchester','Greater Manchester','UNITED KINGDOM','M22 5JG','01614372067','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:17:12',0,NULL,3,1,3,1,'RA184567802CN ','oran_jerry'),(18017,777482106002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.95,'hermeshine','2869olivier','leroyantossian1@free.fr','leroy olivier','1 Rue Daniel Fery','Brest','Bretagne','FRANCE','29200','0611419829','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:20:12',0,NULL,3,1,3,1,'RA184567263CN\r ','2869olivier'),(18018,794062842017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',5.48,'photographyacc','niftyspiel','niftyspiel+ebay@gmail.com','Simi Pop','3/71 Mccquarie str','Camira','Queensland','AUSTRALIA','4300','6173389178','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 17:27:45',0,NULL,3,1,2,1,NULL,'niftyspiel'),(18019,777497979002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','rorich_cz','rorich@seznam.cz','Yekaterina Tichshenko','Kardasovska 625/3<br>Praha 9','Prague','Czech Republic','CZECH REPUBLIC','19800','(+420) 775909434','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 17:37:08',0,NULL,3,1,2,1,NULL,'rorich_cz'),(18020,735150813001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','frank-clemson','frankclemson@yahoo.com','Frank Clemson','55 stopes brow<br>Lower Darwen','Darwen','Lancashire','UNITED KINGDOM','BB3 0QP','0125456106','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-09 17:52:44',0,NULL,3,1,2,1,NULL,'frank-clemson'),(18021,866527865015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','cabardass','cabardass@inbox.lv','Girts Balodis','Malkalnes prosp. 26-13','Ogre','LV','LATVIA','5003','(371) 29422795','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 18:15:14',0,NULL,3,1,3,1,'RA184567351CN\r ','cabardass'),(18022,737807716018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÚMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 18:45:27',0,NULL,3,1,3,1,'RA184567325CN\r ','gerson0909'),(18023,735231012001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','alfayeza1409','alfayez2010@hotmail.com','Abdulrahman Alfayez','80 street 0540444704<br>KING ABDULAZIZ STREET','Buraydah','ALQASSIM','SAUDI ARABIA','51421','(009) 665-4044 ext.: 4704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 19:20:09',0,NULL,3,1,2,1,NULL,'alfayeza1409'),(18024,737897761018,280727897663,'400w Studio Strobe Kit flash+ 2m stand + soft umbrella',1,'AKT079',199,'photographyacc','rajnaig','gabriella.rajnai@gmail.com','Gabriella Rajnai','Attila u. 21','Budapest','','HUNGARY','1183','+36-20-249-7124','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 20:47:48',0,NULL,3,1,17,0,NULL,'rajnaig'),(18025,737896414018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',69,'photographyacc','rajnaig','gabriella.rajnai@gmail.com','Gabriella Rajnai','Attila u. 21','Budapest','','HUNGARY','1183','+36-20-249-7124','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 20:47:48',0,NULL,3,1,12,1,'1107587132\r ','rajnaig\r背景架 2mx3m 河北 + 1.6x3m 白 +夹子  1\r（注意！！背景布加长到3m）\r灯架  2m    2\r力飞 影视闪光灯 lf200w 欧标    2\r柔光伞    2\r灯架包     1\r实重：7.92\r泡重：9.21\r最终计费 8.5\r'),(18026,737902762018,280680835308,'YongNuo Wireless Studio Flash Camera Trigger CTR-301P',1,'AKT013',25.8,'photographyacc','goyoh','goyohpablo@hotmail.com','GREGORIO HERNANDEZ PABLO','SANTADER MEDITERRANEO Nº19 4º D','CALATAYUD','Zaragoza','SPAIN','50300','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-09 20:51:30',0,NULL,3,1,3,1,'RA184565545CN\r ','goyoh'),(18027,866693969015,250600475807,'New Rainproof & Warm Protector for 7D 550D 5D D700 D90',1,'AA3102',12.99,'hutongstore','fuffy11','karlgjordan@gmail.com','Karl Jordan','\"Ellesmere\", Crosthwaite Park West','Dunlaoghaire','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-09 21:18:34',0,NULL,3,1,2,1,NULL,'fuffy11'),(18028,735327419001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','pepesz','pakula38@zonnet.nl','Lukasz Pakula','Mekelweg 4<br>HB13.130 EWI/EI','DELFT','','NETHERLANDS','2628CD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-09 22:41:25',0,NULL,3,1,3,1,'RA184567348CN\r ','pepesz'),(18029,794295728017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','r_dickson','pjvs@optusnet.com.au','Rory Dickson','IBM Centre, Level 27, 60 City Road','Southbank','Victoria','AUSTRALIA','3006','61431891814','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-09 23:00:20',0,NULL,3,1,2,1,NULL,'r_dickson'),(18030,735396556001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','titleist-dave','dan06@bigpond.net.au','David McMullen','7 Chiffley Place','Arundel','Queensland','AUSTRALIA','4214','0755715915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 01:50:05',0,NULL,3,1,2,1,NULL,'titleist-dave'),(18031,735409705001,110717023826,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',223.2,'hermeshine','mandymahn-2009','mandymahn@bigpond.com','Mandy Mahn','12 The Sanctuary','Westleigh','New South Wales','AUSTRALIA','2120','0299805150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 02:44:56',0,NULL,3,1,4,1,'YW868052125CN ','mandymahn-2009'),(18032,738042207018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','skehan123','sandrasmac@bigpond.com','Sandra Skehan','40 Brown Road,','Pakenham','Victoria','AUSTRALIA','3810','0359411266','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 03:38:17',0,NULL,3,1,2,1,NULL,'skehan123'),(18033,738046233018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','jennieheart','myebayforsale@gmail.com','Michelle Richter','11 Findon Crescent','Kew','Victoria','AUSTRALIA','3101','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 03:56:35',0,NULL,3,1,2,1,NULL,'jennieheart'),(18034,794396635017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','spineshank_15','trout@playful.com','Robert Pontini','31 Thomson St Northcote','Melbourne','Victoria','AUSTRALIA','3070','0409852124','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 04:07:04',0,NULL,3,1,2,1,NULL,'spineshank_15'),(18035,777810450002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','woo46304763','woo4630@gmail.com','Fook Leong Woo','Blk 107 Aljunied Crescent #12-04','default','','SINGAPORE','380107','96844763','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 04:29:57',0,NULL,3,1,3,1,'RA184567731CN ','woo46304763'),(18036,738055674018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',4,'AKT025',99.6,'photographyacc','soda_photo','e.resera@curtin.edu.au','Eddie Resera','Curtin University, School of Design & Art<br>Kent St','Bentley','Western Australia','AUSTRALIA','6102','0892661664','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 04:47:19',0,NULL,3,1,3,1,'RA184567405CN ','soda_photo\r注意是4套'),(18037,777816598002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','masitsit','masitsit@comcast.net','Dave Burchett','3474 16th Cir','Boulder','CO','UNITED STATES','80304','(303) 875-2416','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 05:03:28',0,NULL,3,1,1,1,NULL,'masitsit'),(18038,738058873018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','luvabargain10','dnkpacey@bigpond.com','Kate Pacey','Po Box  568','Tully','Queensland','AUSTRALIA','4854','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 05:04:25',0,NULL,3,0,2,1,NULL,'luvabargain10\r白色'),(18039,794422559017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','shamozeepep','wil.normyle@gmail.com','john Normyle','52 caledonia st','paddington','New South Wales','AUSTRALIA','2021','0423007278','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 06:47:26',0,NULL,3,1,2,1,NULL,'shamozeepep'),(18040,738081214018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','spedee2ride','spedee@sympatico.ca','Gordon K Matthews','717 Spragge Cres.','Cobourg','ON','CANADA','K9A2T6','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 07:04:47',0,NULL,3,1,2,1,NULL,'spedee2ride'),(18041,738084043018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','joshwallace','loudog679@hotmail.com','Kate Szepanowski','9 oriole close','flinders view','Queensland','AUSTRALIA','4305','0732887985','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 07:20:52',0,NULL,3,1,2,1,NULL,'joshwallace'),(18042,735469343001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','santakirill','santa_obuv@mail.ru','Kirill Kazancev','Kochubea 7-29','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630129','8-923-248-5768','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-10 07:43:48',0,NULL,3,1,3,1,'RA184567590CN ','santakirill'),(18043,777304383002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','rex893','rex_auzzie@hotmail.com','Rex Pratt','20/386 Toorak Road','South Yarra','Victoria','AUSTRALIA','3141','030433144134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 07:46:33',0,NULL,3,1,2,1,NULL,'rex893'),(18044,777851004002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','evo8wannabe','bob_french8@hotmail.com','darren hill','p.o box 384<br>enfield plaza','adelaide','South Australia','AUSTRALIA','5085','0882603473','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 08:05:46',0,NULL,3,1,2,1,NULL,'evo8wannabe'),(18045,735460217001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','mwngz9wz','autohelp.volg@mail.ru','YURIY YURASOV','64 Armii dom 67, kv. 14','Volgograd','Russian Federation','RUSSIAN FEDERATION','400059','8 8442 449122','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-10 08:10:28',0,NULL,3,1,5,1,'CP238061472CN ','mwngz9wz\r白 +  黑'),(18046,738104327018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','australien_urlaub','friedel_peters@optusnet.com.au','Friedel Peters','67 Edward Street','Langwarrin','Victoria','AUSTRALIA','3910','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 08:44:03',0,NULL,3,0,3,1,'RA184567572CN ','australien_urlaub\rxxl   已入库'),(18047,738105183018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','ibedo75','aliibedo@gmail.com','ALI IBEDO','ABU DHABI - AL SAADA STREET','ABU DHABI','ABU DHABI','UNITED ARAB EMIRATES','31414','00971508198689','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 08:48:29',0,NULL,5,1,3,1,'RA184567572CN ','ibedo75\r已入库\r已发货\r'),(18048,735490935001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','captainn2','sencer_korkmaz@hotmail.com','sencer korkmaz','kozyatağı mahallesi. korkut sokak. alper ap. no:3/24 üstbostancı<br>istanbul','istanbul','istanbul','TURKEY','34742','905322459913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 09:07:29',0,NULL,3,1,3,1,'RA184567657CN ','captainn2'),(18049,794464930017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','mikey_g88','mikey_g88@hotmail.com','Kannika Untun','22/28 M.4 T.Chalong<br>A.Muang','Phuket','','THAILAND','83100','66894477862','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 09:21:35',0,NULL,3,1,2,1,NULL,'mikey_g88'),(18050,738114600018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-0507254189','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 09:23:02',0,NULL,3,1,3,1,'RA184567855CN ','amnon064'),(18051,777874786002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','promogiantworm','dneprofan@gmail.com','Alexander Monagarov','Kosmonavta Volkova st, 20/2','Dnipropetrovsk','Dnipropetrovsk','UKRAINE','49112','+380935792460','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 09:38:35',0,NULL,3,1,3,1,'RA184567793CN ','promogiantworm\r欧标'),(18052,738122301018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','2011alexg84','agurcinovski@gmail.com','Alex Gurcinovski','1/62 rattray rd','montmorency','Victoria','AUSTRALIA','3094','0304354607','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-10 09:50:32',0,NULL,3,1,2,1,NULL,'2011alexg84'),(18111,8881318323212895,111,'背景布 ',3,'',39.98,'hermeshine','cousin_avy','av.i@seznam.cz','Igor Averin','Voronezska 16','Brno','','CZECH REPUBLIC','61600','+420 776652142',NULL,NULL,NULL,'2011-10-11 08:53:32',0,NULL,3,1,3,1,'RA184565069CN\r ','1.6x2.1m * 2 * US$10.99 (黑 白) \r1.6x3.0m * 1 * US$18 (灰) \r '),(18053,735508337001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','zzmingr','snottun@yahoo.co.uk','Nicholas Sutton','74 Layton Road','Gosport','Hampshire','UNITED KINGDOM','PO13 0JQ','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-10 10:09:54',0,NULL,3,1,3,1,'RA184567833CN ','zzmingr\r已入库'),(18054,735511526001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','lebrock76','jamvls76@gmail.com','Juan Antonio Martin Vares','Kempinski Hotel Bahia Estepona (Conserjeria)<br>Ctra. Cadiz, km. 159','Estepona','Andalucía Ceuta y Melilla','SPAIN','29680','952807238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 10:22:22',0,NULL,3,1,3,1,' RA184567728CN','lebrock76'),(18055,794497846017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','evgeny1958.137','e.scherbakov@mail.ru','Evgeny Scherbakov','Vosstania str., 42-12','Sankt Petersburg','Russia','RUSSIAN FEDERATION','191123','+7(911) 920-09-90','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 11:08:56',0,NULL,3,1,2,1,NULL,'evgeny1958.137'),(18056,794500105017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','5495ray','ray@hollywoodst.com.au','RAY SCHEMBRI','56-58 boronia street','WENTWORTHVILLE','New South Wales','AUSTRALIA','2145','0298960955','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-10 11:16:55',0,NULL,3,1,4,1,'YW868052383CN ','5495ray\r150-200cm 5in1 反光板   1\r反光板支架的夹子（双轮）   2'),(18057,738149296018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','5495ray','ray@hollywoodst.com.au','RAY SCHEMBRI','56-58 boronia street','WENTWORTHVILLE','New South Wales','AUSTRALIA','2145','0298960955','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 11:21:37',0,NULL,3,1,4,1,'YW868052372CN ','5495ray'),(18058,738151441018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',2,'AD1179',29.98,'photographyacc','5495ray','ray@hollywoodst.com.au','RAY SCHEMBRI','56-58 boronia street','WENTWORTHVILLE','New South Wales','AUSTRALIA','2145','0298960955','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 11:28:08',0,NULL,3,1,17,0,NULL,'5495ray\r'),(18059,738165097018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','jim201253','jimgeary@bigpond.net.au','Jim Geary','5 Morilla Place','Warrandyte North','Victoria','AUSTRALIA','3113','0409594254','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-10 12:10:35',0,NULL,3,1,4,1,'YW868052394CN ','jim201253'),(18060,867001256015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.12,'hutongstore','chocolatebrownies-ummm','steve.spooner@hotmail.co.uk','Stephen Spooner','31 IRIS ROAD<br>BASSETT','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO16 3GU','07772552256','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 12:10:41',0,NULL,3,1,2,1,NULL,'chocolatebrownies-ummm'),(18061,777926117002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','tinemarie2010','tinelitta@hotmail.com','tine marie olsen','asdalstrand 92','stathelle','telemark','NORWAY','3960','99429086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 12:33:18',0,NULL,3,1,4,1,'YW868053433CN\r ','tinemarie2010\r1.6*2.1白色'),(18062,867013134015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','sysdump.txt','patrik.et@gmail.com','Patrik Eriksson Thelin','Oriongatan 3','Alingsås','','SWEDEN','44136','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 12:38:40',0,NULL,3,1,3,1,'RA184567881CN ','sysdump.txt'),(18063,735558790001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1308',7.8,'hermeshine','greigmccolm','greigm@yahoo.com','Greig McColm','c/o sjoa rafting','Heidal','Sel','NORWAY','2676','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 13:01:00',0,NULL,3,1,2,1,NULL,'greigmccolm'),(18064,777936164002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','fullerphoto66','fullerphoto@me.com','Simon Fuller','332/80 Floor 7, Life@Ratchada-Suthisarn<br>Ratchada rd. Samsennok Hui-Kwang.','Dindaeng','Bangkok','THAILAND','10310','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 13:05:15',0,NULL,3,1,11,1,NULL,'fullerphoto66'),(18065,738187774018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','rodells','rodelio.sayao@gmail.com','Rodelio Sayao','Level 2<br>4 Dawn Fraser Avenue','Sydney Olympic Park','New South Wales','AUSTRALIA','2127','0420833132','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 13:19:23',0,NULL,3,1,17,0,NULL,'rodells'),(18066,794541448017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'AKT081',28,'photographyacc','rodells','rodelio.sayao@gmail.com','Rodelio Sayao','Level 2<br>4 Dawn Fraser Avenue','Sydney Olympic Park','New South Wales','AUSTRALIA','2127','0420833132','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 13:19:23',0,NULL,3,1,3,1,'RA184567820CN ','rodells\r除了c 里面的再发 \r9个环+两种托架'),(18067,867036494015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','seriously!','clive_r2001@yahoo.co.uk','Clive Rosso','13, Puers Field<br>Jordans','Beaconsfield','Bucks','UNITED KINGDOM','HP9 2TF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 13:33:12',0,NULL,3,1,2,1,NULL,'seriously!'),(18068,777992231002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','borisvideo','vladimir-video@mail.ru','Vladimir Paloha','Murinsona 35a,29','Chernigov','','UKRAINE','14017','093-750-30-22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 15:35:53',0,NULL,3,1,5,1,'CP238090394CN\r ','borisvideo\r白色背景布'),(18069,867109993015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','donlegend10','donlegend09@hotmail.com','Don Legend','Blk 120 Bukit Merah View<br>#12-12','default','SC','SINGAPORE','152120','94340434','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 16:05:12',0,NULL,3,1,9,1,'10423111101100001\r ','donlegend10\r英标'),(18070,778027760002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','teung','to_aha@yahoo.com','SURASIT HARAMI','1147 Soi samakom2<br>Rd.Lardpaow 71 wangtonglang lardpaow','BANGKOK','','THAILAND','10310','08-4976-8606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 16:54:56',0,NULL,3,1,3,1,'RA184567714CN ','teung'),(18071,867139773015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','bettiboop627','andrewrapley@hotmail.co.uk','Mr Andrew Rapley','25 Seaton Road','Gillingham','Kent','UNITED KINGDOM','ME7 4BJ','07525376579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 16:56:46',0,NULL,3,1,2,1,NULL,'bettiboop627'),(18072,735673474001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','vsk25nov','mariofino@hotmail.com','mario fino','193 bellair flat 2<br>vjal indipendenza','zurrieq','','MALTA','zrq 2337','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 17:37:24',0,NULL,3,1,2,1,' ','vsk25nov'),(18073,778050822002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',2,'AC2304',12.48,'hermeshine','frolov888','serborjunk@inbox.ru','SERGIY KONDRENKO','Sokolova st., house 29, flat №35','Kharkov','','UKRAINE','61007','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 17:40:29',0,NULL,3,1,2,1,NULL,'frolov888'),(18074,867047277015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',3,'AE3301',97.38,'hutongstore','humanprofile','filippotoso@libero.it','Filippo Toso','Via Dante, 1/b','Palmanova','UD','ITALY','33057','3483406175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 17:45:21',0,NULL,3,1,4,1,'YW868052405CN ','humanprofile\r45w 220灯泡    4\r115w  220v  灯泡   4\r一转四 灯头    3\r已入库'),(18075,867177076015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','mattfraser2002','mattfraser@hotmail.com','Matthew R Fraser','40 Tyzack Road','High Wycombe','Buckinghamshire','UNITED KINGDOM','HP13 7PU','07789260699','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-10 17:50:37',0,NULL,3,1,4,1,'YW868052350CN ','mattfraser2002\r、黑色+白色'),(18076,735683710001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','fenix7510','fenix.zoom@gmail.com','Taras Shevchenko','Nagorniy bulv., d.15, kv.28','Moscow','','RUSSIAN FEDERATION','117186','+79161037949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 17:55:26',0,NULL,3,1,5,1,'CP238061486CN ','fenix7510'),(18077,738326948018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','dlcntn2010','deluca.antonio48@gmail.com','antonio de luca','strada fonte borea 101','pescara','PE','ITALY','65125','3386403992','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 18:22:24',0,NULL,3,1,2,1,NULL,'dlcntn2010'),(18078,867220234015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.79,'hutongstore','makhmur','vincent.monet@free.fr','Sophie ROUDIL & Vincent MONET','74 Les Vergers - Square Michel Ange','BOUC BEL AIR','Provence-Alpes-Côte d\'Azur','FRANCE','13320','0442941625','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 18:45:52',0,NULL,3,1,2,1,NULL,'makhmur'),(18079,778093726002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','manuelvf89','manuelon.v.f@gmail.com','Manuel Velásquez Figueroa','Gregorio Gelati 99 interior 1002<br>Colonia San Miguel Chapultepec','México Distrito Federal','México Distrito Federal','MEXICO','11850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 18:50:45',0,NULL,3,1,3,1,'RA184567745CN \rRA184567674CN','manuelvf89\r分开发'),(18080,778093442002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','manuelvf89','manuelon.v.f@gmail.com','Manuel Velásquez Figueroa','Gregorio Gelati 99 interior 1002<br>Colonia San Miguel Chapultepec','México Distrito Federal','México Distrito Federal','MEXICO','11850','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 18:50:45',0,NULL,3,1,3,1,'RA184567776CN ','manuelvf89\r'),(18081,735753137001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','rodmalomar','omar.rodmal@gmail.com','Omar Rodriguez','Urb. Villas de Juan #722 calle Riachuelo','Ponce','PR','UNITED STATES','00716','(787) 233-1533','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-10 19:53:04',0,NULL,3,1,1,1,NULL,'rodmalomar'),(18082,867280703015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','tube-snake','kai.h.jakobsen@vkbb.no','Kai-Hugo Jacobsen','Sannan','Alsvaag','','NORWAY','N8432','+4776131328','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 20:05:51',0,NULL,3,1,3,1,'RA184567759CN ','tube-snake'),(18083,849373034016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','mv-2','batesvyse@aol.com','melissa vyse','42 Forbes Avenue','Potters Bar','Hertfordshire','UNITED KINGDOM','EN6 5NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-10 20:19:06',0,NULL,3,1,3,1,'RA184565832CN\r ','mv-2'),(18084,867308537015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','weslianna','anna.fucikova@email.cz','Anna Fucikova','Pokoj 115B/III, Kolej Na Vetrniku<br>Na Vetrniku 1933','Prague 6','Czech Republic','CZECH REPUBLIC','162 00','0420607641599','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-10 20:49:02',0,NULL,3,1,2,1,NULL,'weslianna'),(18085,738442039018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','innindic','markus.miedla@gmail.com','MIEDLA Markus','Muehlfeldgasse 4/8','Wien','','AUSTRIA','1020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-10 21:53:52',0,NULL,3,1,2,1,NULL,'innindic'),(18086,738460018018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','tatt62000red','tenterrorists@hotmail.com','Adam Tatt','75 john st','Singleton','New South Wales','AUSTRALIA','2330','0265715155','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-10 22:49:19',0,NULL,3,1,4,1,'YW868052361CN ','tatt62000red\r黑色+白色'),(18087,738149283018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','craftyman76','tim_harradine@hotmail.com','Tim Harradine','4 Hepburn Close','Wakerley','Queensland','AUSTRALIA','4154','0738904311','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 23:05:40',0,NULL,3,1,3,1,'RA184567665CN ','craftyman76'),(18088,794827657017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','llewsid','lleeew@hotmail.com','llew goodwin','57 Boundary St','Clovelly','New South Wales','AUSTRALIA','2031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-10 23:07:26',0,NULL,3,1,2,1,NULL,'llewsid'),(18089,735837108001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','vivekgiri','vivek_giri@hotmail.com','bivek giri','10/1 whitehall court caulfield north','melbourne','Victoria','AUSTRALIA','3161','0426245731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 23:36:28',0,NULL,3,1,2,1,NULL,'vivekgiri'),(18090,735840174001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','mrspiffy18','arsenaultnick@hotmail.com','nicholas arsenault','23 clarwood drive','quispamsis','NB','CANADA','E2E4K4','(506) 847-5775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-10 23:49:04',0,NULL,3,1,2,1,NULL,'mrspiffy18\r转接环 52mm'),(18091,778234957002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>São Cristovão','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920-280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 00:22:20',0,NULL,3,1,3,1,'RA184567847CN ','mariomarques.com.br'),(18092,735856928001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','everready3048','kennyg30@shaw.ca','Ken Gordon','3580 150th Street','Surrey','BC','CANADA','v3s 0t5','(604) 536-1880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 01:00:03',0,NULL,3,1,3,1,'RA184567762CN ','everready3048'),(18093,738507016018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','tinorama1971','tinorama@gmail.com','Agustin Llorens','Moreno 950 3 D','Buenos Aires','BA','ARGENTINA','1091','(541) 143-4550 ext.: 26','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 01:37:21',0,NULL,3,1,2,1,NULL,'tinorama1971'),(18094,738506438018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','kupuvach32','iradobroskok@yahoo.com.au','Ira Dobroskok','24 Yarraville st','Robina','Queensland','AUSTRALIA','4226','0414566867','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 01:43:52',0,NULL,3,1,17,0,NULL,'kupuvach32'),(18095,738504428018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','kupuvach32','iradobroskok@yahoo.com.au','Ira Dobroskok','24 Yarraville st','Robina','Queensland','AUSTRALIA','4226','0414566867','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 01:43:52',0,NULL,3,1,4,1,'YW868052151CN ','kupuvach32\r反光板支架     1\r闪光的柔光箱   60cm    1'),(18096,777372137002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27.8,'hermeshine','tungtnt','tung.tnt@gmail.com','Nguyen Thanh Tung','Information Technology Block<br>4th floor, Baoviet Training Center building, 71 Ngo Sy Lien st.','Hanoi','Dongda dist','VIET NAM','084','(094) 246 - 1357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 02:20:53',0,NULL,3,1,17,0,NULL,'tungtnt'),(18097,777371827002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tungtnt','tung.tnt@gmail.com','Nguyen Thanh Tung','Information Technology Block<br>4th floor, Baoviet Training Center building, 71 Ngo Sy Lien st.','Hanoi','Dongda dist','VIET NAM','084','(094) 246 - 1357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 02:20:54',0,NULL,3,1,17,0,NULL,'tungtnt\r'),(18126,778381821002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',3,'AA1216',41.7,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:58:54',0,NULL,3,1,3,1,'RA184565449CN ','happyjaya'),(18098,735882538001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','receptiondianne','reception@ascs.com.au','Dianne Hurley','Australian Satellite Services<br>49 Port Road','Thebarton','South Australia','AUSTRALIA','5031','0884439844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 02:32:50',0,NULL,3,1,2,1,NULL,'receptiondianne'),(18099,735746135001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','rladams7767','rladams7767@gmail.com','Richard Adams','10 Sundown Dr','Trabuco Canyon','CA','UNITED STATES','92679-5301','(949) 709-1977','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-11 04:39:10',0,NULL,3,1,3,1,'RA184565090CN\r ','rladams7767'),(18100,8881318308381092,111,'1.6x3m 背景布',2,'',33.98,'aliexpress','1004711416','mandic007@gmail.com','Dejan Mandic','Alvsborgsgatan 17 b, lgh 1102','Gothenburg	','','SWEDEN','414 52','+046 0735 843606',NULL,NULL,NULL,'2011-10-11 04:46:21',0,NULL,3,1,3,1,'RA184565571CN ',' 白 + 黑'),(18101,867476207015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','doart','doapostolova@gmail.com','Dora Apostolova','Svoboda 43','Plovdiv','Plovdiv','BULGARIA','4002','0878 245722','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 05:01:17',0,NULL,3,1,2,1,' ','doart'),(18102,777652484002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',4,'AKT014',147.8,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','sadeq tawfeek','Qatif','tarout','QATIF','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 05:15:38',0,NULL,3,1,8,1,'CP238061628CN ','tawfeekmohammed'),(18103,735919693001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','5253martinn','robmar555@yahoo.com.au','Martin Neville','45 Hollywood Avenue<br>Bondi Junction','Sydney','New South Wales','AUSTRALIA','2022','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 05:51:00',0,NULL,3,1,2,1,NULL,'5253martinn'),(18104,8881318314330936,111,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',32.99,'aliexpress','1004720187','big_jim83@bigpond.com','Kevin Smith','11 School Drive','Banksia Park	','South Australia	','AUSTRALIA	','5091','+61 08 82643427',NULL,NULL,NULL,'2011-10-11 06:25:30',0,NULL,3,1,3,1,'RA184567878CN ',NULL),(18105,735933147001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','jonnyhyde','jonnyhyde@hotmail.com','Jonathan Hyde','40/13-15 Gerrale St','Cronulla','New South Wales','AUSTRALIA','2230','0413473654','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 07:30:36',0,NULL,3,1,2,1,NULL,'jonnyhyde'),(18106,738583257018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','butch_ru','borenty@gmail.com','Boris Chernykh','\"CROC\" 5 block 1<br>Volochaevskaya street','Moscow','Moscow','RUSSIAN FEDERATION','111033','+79169929264','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 07:39:42',0,NULL,3,1,2,1,NULL,'butch_ru'),(18107,794959910017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','azliraja','rajaazli@hotmail.com','Raja Azli Raja Sulaiman','7-2A, Ukay Boulevard<br>Jalan Lingkaran Tengah 2, Hulu Klang','Ampang','Selangor','MALAYSIA','68000','0132366536','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 08:14:09',0,NULL,3,1,2,1,NULL,'azliraja'),(18108,738591490018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','xsamuell','luk.pertl@gmail.com','Lukas Pertl','Vrazkov 97','Roudnice nad Labem','Czech Republic','CZECH REPUBLIC','41301','+420605584313','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 08:15:58',0,NULL,3,0,3,1,'RA184565109CN\r ','xsamuell\rXXL 已入库'),(18109,794963905017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','ardietriz','aeanton2@bechtel.com','Arnel Antonio','Saudi Arabian Bechtel Co., P.O. Box 1840<br>Oasis Garden Compound','Al-Khobar','Eastern Province','SAUDI ARABIA','31952','(966) 508-925626','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 08:28:52',0,NULL,3,1,2,1,NULL,'ardietriz'),(18110,867526901015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','phil010_5','phillimbert@gmail.com','Philip Limbert','28 Portland Close, Mickleover','Derby','Derbyshire','UNITED KINGDOM','DE39BQ','01332729009','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 08:32:49',0,NULL,3,1,2,1,'\\  ','phil010_5'),(18112,867535366015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','euro-gold-design','euro-discount@hotmail.co.uk','Alan McManus','31 Ivor Road','Wallasey','Merseyside','UNITED KINGDOM','CH44 1DT','01516388490','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 09:01:25',0,NULL,3,1,3,1,'RA184565347CN ','euro-gold-design'),(18113,738606741018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','nic.007','tim.christian@bigpond.com','Nicole Christian','Three<br>Wood St.','Warracknabeal','Victoria','AUSTRALIA','3393','0353982576','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 09:19:03',0,NULL,3,1,2,1,NULL,'nic.007\r白色'),(18114,867539384015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','kenandbarbs','kenny.mullan@btinternet.com','Kenny Mullan','10 Marshal Drive<br>California','Falkirk','Scotland','UNITED KINGDOM','FK1 2AB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 09:34:08',0,NULL,3,1,3,1,'RA184565466CN\r ','kenandbarbs'),(18115,738615633018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','danimalaga2006','dharma.infografia@gmail.com','Daniel Ortiz Díaz','Urb. Jardines del Golf. Añoreta. 5ª Fase. Blq.1 Bajo E','Rincón de la Victoria - Málaga','Andalucía Ceuta y Melilla','SPAIN','29730','662157818','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 09:54:35',0,NULL,3,1,4,1,'YW868053606CN ','danimalaga2006'),(18116,778367356002,120758268927,'Camera protector case bag f Nikon D200 D300s D700 XL',1,'AD1174',12.99,'hermeshine','tungtnt','tung.tnt@gmail.com','Nguyen Thanh Tung','Information Technology Block<br>4th floor, Baoviet Training Center building, 71 Ngo Sy Lien st.','Hanoi','Dongda dist','VIET NAM','084','(094) 246 - 1357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:05:32',0,NULL,3,1,3,1,'RA184565395CN ','tungtnt\rHB-7 花瓣     3   \r新款内胆包 XL  Nikon      1'),(18117,735980615001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','shonkydog','paul@imagemill.com.au','Paul Munnings','59 Buena Vista Drive','Montmorency','Victoria','AUSTRALIA','3094','0394390266','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 10:29:20',0,NULL,3,1,2,1,NULL,'shonkydog'),(18118,866992930015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','buzzcph','buzzmartin@mail.dk','Martin kent  Andersen','Ryesgade 67, 5 floor','Copenhagen','Copenhagen','DENMARK','2100','+4525128214','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 10:32:01',0,NULL,3,1,3,1,'RA184565378CN ','buzzcph'),(18119,738630243018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',70,'photographyacc','onno26','onno@cistron.nl','onno hooft','hobbemakade 130','Amsterdam','','NETHERLANDS','1071 XW','0031654710051','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 10:45:24',0,NULL,3,1,17,0,NULL,'onno26'),(18120,738628653018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',76,'photographyacc','onno26','onno@cistron.nl','onno hooft','hobbemakade 130','Amsterdam','','NETHERLANDS','1071 XW','0031654710051','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 10:45:25',0,NULL,3,1,4,1,'YW868053610CN ','onno26\r反光板支架    2  重量1.791\r反光板 100*150 5合1      2  重量2.370\r燕文一票两件  ▲\r\r单子贴在反光板上 '),(18121,735984042001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','gengxin_he','jason_he@yahoo.com','Gengxin He','13A Kenneth Ave, Baulkham Hills','Sydney','New South Wales','AUSTRALIA','2153','0296397754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:52:11',0,NULL,3,1,17,0,NULL,'gengxin_he'),(18122,735982804001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','gengxin_he','jason_he@yahoo.com','Gengxin He','13A Kenneth Ave, Baulkham Hills','Sydney','New South Wales','AUSTRALIA','2153','0296397754','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 10:52:10',0,NULL,3,1,2,1,NULL,'gengxin_he\r绿叶 渐变镜 77mm    1\rCANON 镜头盖  77mm   1'),(18123,738627469018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','mountainbikespezi','info@andreasbrandl.at','Intercar Austria / Andreas Brandl','Vogelweiderstrasse 75','Salzburg','','AUSTRIA','5021','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 10:52:42',0,NULL,3,1,2,1,NULL,'mountainbikespezi'),(18124,738631506018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1301',33.6,'photographyacc','diegoarcas','darcas@ono.com','diego arcas ivorra','c/ pintor sorolla, nº 18, pta. 16','museros (valencia)','Comunidad Valenciana','SPAIN','46136','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 10:52:54',0,NULL,3,1,3,1,'RA184565355CN ','diegoarcas\r欧标'),(18125,738632155018,280685221276,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm ',1,'AE3403',38,'photographyacc','mujtaba_999','ya_allah_999@hotmail.com','MUJTABA AL-NEDHAM','P.O.Box 773<br>Saihat 31972','Saihat','Eastern Province','SAUDI ARABIA','31972','+966505970282','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 10:53:10',0,NULL,3,1,3,1,NULL,'mujtaba_999'),(18127,735989897001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',59.98,'hermeshine','otcccp08','cretes.david@wanadoo.fr','David Truillard','4, rue du Foivre','Wignicourt','Champagne-Ardenne','FRANCE','08270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 11:04:46',0,NULL,3,1,3,1,'RA184565421CN ','otcccp08\r1.828'),(18128,778389828002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','davidatmemorylane','david@memorylane.ie','David Lane','Poms Cottage<br>Caherline, Caherconlish','Caherconlish','Limerick','IRELAND','1','0874197878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 11:27:48',0,NULL,3,1,17,0,NULL,'davidatmemorylane'),(18129,778390824002,120752248934,'33\" double layers reflective and translucent umbrella',2,'AD1156',41.98,'hermeshine','davidatmemorylane','david@memorylane.ie','David Lane','Poms Cottage<br>Caherline, Caherconlish','Caherconlish','Limerick','IRELAND','1','0874197878','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 11:31:00',0,NULL,3,1,4,1,'YW868053595CN ','davidatmemorylane\r2B柔   2\r85cm 两用伞     2'),(18130,734702549018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','hymyp','john.morelius@gmail.com','John Morelius','Kavaljeerinkuja 12 E','ESPOO','','FINLAND','02940','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 11:35:01',0,NULL,3,1,3,1,'RA184565483CN ','hymyp'),(18131,738645535018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','hudla_cz','hudla@hudla.cz','Jaroslav Rulíšek','Hybešova 5','Šumperk','','CZECH REPUBLIC','787 01','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 11:35:46',0,NULL,3,1,2,1,NULL,'hudla_cz\r'),(18132,849668108016,260660051651,'Neoprene Camera Cover for Canon 500D 450D 400D 1000D S',1,'AC2305',4.5,'hutongstore','sebgot1910','sebgot1979@gmail.com','Sebastian Gotkowicz','78 Brooklands Road','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk2 2rn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 11:40:33',0,NULL,3,1,2,1,NULL,'sebgot1910'),(18133,738643531018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','rosina0599','timathos@bigpond.net.au','Tim O\'Sullivan','5 Cornuta Crt','Caboolture','Queensland','AUSTRALIA','4510','0754952962','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 11:41:30',0,NULL,3,1,2,1,NULL,'rosina0599'),(18134,736000921001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','mikaren2009','mikaren15@yahoo.com','Karen Azatyan','apt.10, Garegin Njdeh Ave. 8','Yerevan','','ARMENIA','0006','374-148-9182','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 11:43:57',0,NULL,3,1,2,1,NULL,'mikaren2009'),(18135,778396745002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','caliseanna','darkqueen76@hotmail.it','L\'alveare di Osterini Marcella','via porto, 8 (tel 3282213706)','ischia','NA','ITALY','80077','081983420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 11:51:40',0,NULL,3,1,2,1,NULL,'caliseanna'),(18136,849689714016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','newey13','lisap@entropie.demon.co.uk','Lisa Phillips','7 Highfield Road<br>wigginton','Tring','Hertfordshire','UNITED KINGDOM','HP236EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 12:39:19',0,NULL,3,1,17,0,NULL,'newey13'),(18137,736015664001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','evgenia_shagieva','evgeniashagieva@gmail.com','Evgeniya Shagieva','15 Lva Tolstogo str. app. 114','Khabarovsk','Khabarovskiy kray','RUSSIAN FEDERATION','680000','89241189116','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 12:35:27',0,NULL,3,1,3,1,'RA184565452CN ','evgenia_shagieva'),(18138,736021912001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','s_lim_007','mutagennix@gmail.com','Serge Limontov','6/139 Bronte Rd Waverley','Sydney','New South Wales','AUSTRALIA','2024','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 12:55:54',0,NULL,3,1,3,1,'RA184565435CN ','s_lim_007'),(18139,736022614001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','09ravil','bashkeer@gmail.com','RAVIL SHAYMARDANOV','ZAPADNAYA 1','LYSVA','PERMSKIJ KRAY','RUSSIAN FEDERATION','618900','9194991778','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 13:01:39',0,NULL,3,1,5,1,'CP238061526CN ','09ravil'),(18140,795042979017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.59,'photographyacc','sanjotsonalkar','sanjot@aol.in','Sanjot Sonalkar','14, Vinay (Chakala) CHS,<br>Chakala, 95/5, Andheri (E),','Mumbai','MH','INDIA','400099','9820347078','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 13:01:57',0,NULL,3,1,2,1,NULL,'sanjotsonalkar'),(18141,735985539001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','jasmine-sin','eos-eminoktaysoyler@hotmail.com','emin oktay soyler','fevziçakmak bulvarı bulvar apt. 72/9 şehitkamil','gaziantep','','TURKEY','27090','0342 3211709','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 14:07:01',0,NULL,3,1,3,1,'RA184565276CN ','jasmine-sin\r已入库'),(18142,795072224017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','ocecat2004','hylaicalvin@hotmail.com','Hei Yeung Calvin Lai','1/8 Clyde Road','Herston','Queensland','AUSTRALIA','4006','0413415567','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 14:21:33',0,NULL,3,1,2,1,NULL,'ocecat2004'),(18143,849744302016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0023',169,'hutongstore','cameraweasel','nick@nickwebster.com','Nick Webster','49 Ashlea Drive','Ballymoney','Antrim','UNITED KINGDOM','BT53 7BY','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-11 14:50:48',0,NULL,3,1,17,0,NULL,'cameraweasel'),(18144,867666777015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','cameraweasel','nick@nickwebster.com','Nick Webster','49 Ashlea Drive','Ballymoney','Antrim','UNITED KINGDOM','BT53 7BY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 14:50:48',0,NULL,3,1,4,1,'YW868053621CN ','cameraweasel\r三脚架 伟峰 EI-717  180     1\r伟峰 717 快装板     1\r申报$45'),(18145,849745467016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','nvir6886','nisha.virdi@gmail.com','Nisha Virdi','6 Brandwood Grove','Birmingham','West Midlands','UNITED KINGDOM','B14 6BU','07977217046','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 14:53:24',0,NULL,3,1,17,0,NULL,'nvir6886'),(18146,867667970015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','nvir6886','nisha.virdi@gmail.com','Nisha Virdi','6 Brandwood Grove','Birmingham','West Midlands','UNITED KINGDOM','B14 6BU','07977217046','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 14:53:25',0,NULL,3,1,4,1,'YW868053396CN\r ','nvir6886\r2B 柔    1\r2mx1.5m 背景板（黑，白）   1\r燕文一票两件\r单子贴在背景板上    '),(18147,736062414001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','jmpparis75','jmprovent@gmail.com','Jean-Marc PROVENT - convergence','40, rue d\'Hauteville<br>2ème étage','PARIS','Ile-de-France','FRANCE','75010','0609035348','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 15:01:48',0,NULL,3,1,3,1,'RA184565381CN ','jmpparis75'),(18148,778460608002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','guardianzs','slava@doza.ru','Slava Chernishev','Zelenograd<br>1113 - 20','Moscow','Moscow (Russia)','RUSSIAN FEDERATION','124460','+7 806 7938980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 15:08:02',0,NULL,3,1,18,1,'CP238090403CN\r ','guardianzs\r白色'),(18149,736070939001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','rafaellopes2010','rafael.mlopes@hotmail.com','Rafael Lopes','Rua: Alcides Gaboardi nº 130<br>Bairro: Meu Postinho','São Cristovão do Sul','Santa Catarina','BRAZIL','89533-000','49 91179515','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 15:25:39',0,NULL,3,1,2,1,NULL,'rafaellopes2010\r欧标'),(18150,738728618018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',6.2,'photographyacc','vitorwood','vmcm@ci.uc.pt','Vítor M. C. Madeira','Centro de Neurociências, Univ. Coimbra<br>L. M. Pombal','Coimbra','','PORTUGAL','3004-517','+351239714759','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 15:37:25',0,NULL,3,1,2,1,NULL,'vitorwood'),(18151,867703556015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','ginger1880','ginger1880@hotmail.com','Karen McGuinness','292 Grieve Road','Greenock','Inverclyde','UNITED KINGDOM','PA16 7AN','07818023685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-11 16:12:46',0,NULL,3,0,3,1,'RA184565554CN\r ','ginger1880\r黑色+白色'),(18152,778486213002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',25,'hermeshine','melanietitus2010','melanie.titus@gmail.com','Melanie Titus','14-3594 St Pauls Street','Halifax, Nova Scotia','NS','CANADA','B3K 3P9','(902) 403-8787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 16:14:13',0,NULL,3,1,3,1,'RA184565418CN ','melanietitus2010'),(18153,738745762018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',36.8,'photographyacc','michaeljsanderson','michaeljohnsanderson@gmail.com','Michael Sanderson','Backershagenlaan 32','Wassenaar','','NETHERLANDS','2243 AD','0611804843','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 16:23:26',0,NULL,3,1,3,1,'RA184565364CN ','michaeljsanderson'),(18154,777851930002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','winnerkz','mrak_666_@mail.ru','Yevgeniy Beloussov','Esenberlina 30 kv.8','Astana','KZ','KAZAKHSTAN','010011','(701)749-9606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 17:00:58',0,NULL,3,1,5,1,'CP238090465CN ','winnerkz'),(18155,736120101001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','atrazsk8','atrazsk8@tin.it','Andrea Schiavone','Via Abruzzi 87','Campi Salentina','LE','ITALY','73012','3401299787','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 17:23:38',0,NULL,3,1,17,0,NULL,'atrazsk8\r欧标'),(18156,795151066017,270777060056,'Studio Continuous Light Kit 23\' SoftBox 4 output 45w x8',1,'AKT039',170,'photographyacc','atrazsk8','atrazsk8@tin.it','Andrea Schiavone','Via Abruzzi 87','Campi Salentina','LE','ITALY','73012','3401299787','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 17:25:44',0,NULL,3,1,4,1,'YW868053422CN\r ','atrazsk8\r欧标\r柔光箱 60-60cm  四灯头  * 2\r2m 灯架  * 2\r45w 220v 灯泡  * 8\r灯架包  * 1\r配50-70棚的4灯头伞孔  * 1\r实重7.14\r泡重9.33\r'),(18157,736124941001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','quetecuen68','juanangel68@yahoo.es','Juan Angel Tirado Castillo','Plaza Jose Maria Unceta, 4 (Polideportivo)','Torrelodones','Madrid','SPAIN','28250','608311595','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 17:34:27',0,NULL,3,0,3,1,'RA184565293CN ','quetecuen68\rXL 已入库'),(18158,866228013015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',61.99,'hutongstore','pratheesh17','prath33sh@gmail.com','pratheesh suntharalingam','bekkestien 14','jessheim','','NORWAY','2050','+47 46698587','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-11 18:01:52',0,NULL,3,1,4,1,'YW868053632CN ','pratheesh17\r黑色+白色\r牛津布大包     1'),(18159,736136297001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','cofredeltesoro1984','cofredeltesoro@hotmail.es','Angel Viana Sosa','Colegio Naval Sacramento 3 3º A','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','686615883','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 18:03:49',0,NULL,3,1,4,1,'YW868053643CN ','cofredeltesoro1984'),(18160,778544843002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','gena66','vartush1470@yandex.ru','genadi levin','ehud 7/1','ashkelon','','ISRAEL','78578','0526082058','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 18:18:25',0,NULL,3,1,2,1,NULL,'gena66'),(18161,736161911001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','petter.e','black_eagle_61@hotmail.com','petter eliassen','alveveien 21','sandnes','','NORWAY','4314','93206827','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 18:51:05',0,NULL,3,1,5,1,'CP238090451CN ','petter.e\r黑色\r欧标\r发河北背景架  \r实重8.1  泡重11.1 '),(18162,778566931002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'',85,'hermeshine','inilova','nilova777@gmail.com','Ilona Nilova','19 Osberstown drive','Sallins','Kildare','IRELAND','default','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 18:59:17',0,NULL,3,0,4,1,'YW868053654CN ','inilova\r40cm 圆形柔光棚   1\r桌面灯 英标    2\r38cm 灯架    2\r45w220v 灯泡    2\r已入库'),(18163,733404478001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','interfun23','interpan23@gmail.com','Panayot Paunov','erimi,pafou 13 photo christodoulos avraam','erimi','limasol','CYPRUS','4630','(00357)96381798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 19:32:46',0,NULL,3,0,3,1,'RA184565333CN ','interfun23\r1.6*2.1黑色+白色'),(18164,778591044002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','pepesz','pakula38@zonnet.nl','Lukasz  Pakula','Mekelweg 4, EWI/EI, HB13.130','Delft','','NETHERLANDS','2628CD','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 19:42:57',0,NULL,3,1,3,1,'RA184565470CN ','pepesz\r欧标'),(18165,795299138017,270797800419,'Super clamp all metal 15kg capacity for flash, backdrop',2,'AD1177',70,'photographyacc','icieling','icie.eici@gmail.com','Isaac M Leung','3 Foxwood Way','Cherrybrook','New South Wales','AUSTRALIA','2126','0419043563','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-11 21:57:10',0,NULL,3,1,3,1,'RA184565506CN ','icieling'),(18166,795298250017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',6,'AA1202',17.4,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:14',0,NULL,8,1,17,0,NULL,'diogodrigo2009'),(18167,738913765018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:14',0,NULL,8,0,17,0,NULL,'diogodrigo2009'),(18168,738913522018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',5,'AC1304',34.9,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:15',0,NULL,8,1,17,0,NULL,'diogodrigo2009'),(18169,738912907018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',4,'AKT025',99.6,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:15',0,NULL,8,1,17,0,NULL,'diogodrigo2009'),(18170,795296967017,270753948851,'Bounce Flash Diffuser for Speedlight Flash Canon 580EX ',8,'AB3332',23.2,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:16',0,NULL,8,1,17,0,NULL,'diogodrigo2009'),(18171,738914347018,280683870477,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',8,'AB3331',23.2,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:16',0,NULL,8,1,17,0,NULL,'diogodrigo2009'),(18172,795298146017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',6,'AA1203',17.4,'photographyacc','diogodrigo2009','diogodrigo@hotmail.com','Diogo Drigo','Av Padre Manoel da Nobrega, 620<br>apto. 161','Santo Andre','Sao Paulo','BRAZIL','09080-140','(11) 2325-0419','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:00:17',0,NULL,3,1,5,1,'CP238090275CN ','diogodrigo2009\r眼罩 40D/50D    6\r摄影背心（河北，厚）canon xxl    1\r大号内胆包canon    5\r4套 9个环+两种托架  （注意是四套）\r肥皂盒 柔光罩   580EX      8\r肥皂盒 柔光罩  430EX      8\r眼罩 D300     6\r\r超了 2.5了'),(18173,738919424018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','munny0014','munsy07@hotmail.com','Simon Munn','39 Mitchell St Seaview Downs','Adelaide','South Australia','AUSTRALIA','5049','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 22:06:25',0,NULL,3,1,3,1,'RA184565316CN ','munny0014'),(18174,778661208002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','otromathias','mathiasfloras@gmail.com','Mathias Floras','Haiti 1991','Montevideo','Montevideo','URUGUAY','12800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 22:19:25',0,NULL,3,1,2,1,NULL,'otromathias'),(18175,738924164018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',26,'photographyacc','musttii84','bruceakbarber@shaw.ca','Bruce Barber','1412 Cummings Street','Thunder Bay','ON','CANADA','P7C1P5','(807) 577-1601','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-11 22:20:19',0,NULL,3,1,3,1,'RA184565404CN ','musttii84'),(18176,736251462001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','oluwafemiainajohnson','omolaraainajohnson@hotmail.co.uk','OMOLARA AINA-JOHNSON','47,  ASHBROOK','ORANMORE','GALWAY','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-11 22:22:50',0,NULL,3,1,2,1,NULL,'oluwafemiainajohnson'),(18177,778675977002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','je5200','opemus6@hotmail.es','juan antonio escudero morales','francisco gomez nª9 5ctr','barakaldo','País Vasco','SPAIN','48901','615784186','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-11 23:09:30',0,NULL,3,0,3,1,'RA184565894CN\r','je5200\r3XL  已入库\r客户要4XL,已经去信确认。'),(18178,738943968018,280680264184,'New Camera Bag Cover for Canon EOS 7D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','9cowan','lauren_cowan@hotmail.com','lauren cowan','18 sunset cres','grange','South Australia','AUSTRALIA','5022','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-11 23:30:07',0,NULL,3,1,2,1,NULL,'9cowan'),(18179,778717291002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',3,'AKT051',34.5,'hermeshine','lordreesmogg','lindsay.allen@outgun.com','lindsay allen','PO BOX 761','GOULBURN','New South Wales','AUSTRALIA','2580','0404553590','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 01:38:42',0,NULL,3,1,3,1,'RA184565320CN ','lordreesmogg'),(18180,736325054001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','aalmalki2011','di7mi_a@hotmail.com','Abdulrahman Almalki','3 New Pennywell Road<br>Apt# 205','St.John\'s','NL','CANADA','A1B 4E4','(709) 769-0107','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-12 02:36:25',0,NULL,3,1,5,1,'CP238061509CN ','aalmalki2011\r黑色+白色'),(18181,738994809018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','montex124','iroc@adam.com.au','ROBERT MONTELEONE','12 HEATHER ROAD','ALDGATE','South Australia','AUSTRALIA','5154','0883708120','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 02:57:40',0,NULL,3,1,17,0,NULL,'montex124'),(18182,738994257018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','montex124','iroc@adam.com.au','ROBERT MONTELEONE','12 HEATHER ROAD','ALDGATE','South Australia','AUSTRALIA','5154','0883708120','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 02:57:41',0,NULL,3,1,2,1,NULL,'montex124\r绿叶 渐变镜 72mm    1\r新款内胆包 L  Nikon     1'),(18183,8881318393080512,111,'背景布&斜臂',1,'',240,'hermeshine','spy*c','LogansPhotography@hotmail.com','Natalie Higgins','1047 Escott Court','Pickering','Ontario','CANADA','L1X 1P3','905-837-0234',NULL,NULL,NULL,'2011-10-12 04:18:00',0,NULL,3,1,5,1,'CP238061490CN ','背景布 3.0x6.0m *2  (黑、白)\r背景布 1.6x3.0m *3  (绿、粉、蓝)\r斜臂  *2\rTotal: $240 '),(18184,739018512018,280673081548,'67mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 67 mm',2,'AB1305',10.18,'photographyacc','surfingart66','pete@surfingart.com.au','Peter Gibney','PO Box 812','Mullumbimby','New South Wales','AUSTRALIA','2482','0266841805','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 04:39:17',0,NULL,3,1,2,1,NULL,'surfingart66'),(18185,778770850002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','cindystrappazzon','studiocindys@gmail.com','Cindy Strappazzon','Ugab 23,Vineta, Swakopmund<br>box 4747, vineta','swakopmund','Namibia','NAMIBIA','9000','00264812310936','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 05:48:12',0,NULL,3,1,2,1,NULL,'cindystrappazzon'),(18188,739048003018,280685224536,'50x70cm 20\"x28\" Folding Easy Soft box  E27 Bulb Socket',1,'AE2401',35,'photographyacc','shaunmailbox2008','shaunmailbox@gmail.com','shaun treble','601/38 college st','darlinghurst','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 08:13:37',0,NULL,3,1,17,0,NULL,'shaunmailbox2008'),(18186,8881318400217409,111,'柔光伞 110cm ',4,'AD11225',46,'photographyacc','tokarev24','verakot@gmail.com','Alexey Tokarev','Akademgorodok str., 18D, 15','Krasnoyarsk','','RUSSIAN FEDERATION','660036','',NULL,NULL,NULL,'2011-10-12 06:16:57',0,NULL,3,1,3,1,'RA184565585CN\r ',NULL),(18187,736378292001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','william_walters','fichboy@gmail.com','Benjamin Smith','2101/109 Clarendon Street<br>Southbank','Melbourne','Victoria','AUSTRALIA','3006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 07:16:44',0,NULL,3,1,2,1,NULL,'william_walters'),(18189,739038315018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','shaunmailbox2008','shaunmailbox@gmail.com','shaun treble','601/38 college st','darlinghurst','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 08:13:38',0,NULL,3,1,3,1,'RA184565599CN\r ','shaunmailbox2008\r柔光箱 50-70cm 单灯头 澳标   1\r热靴保护盖  普通    1\r'),(18190,795454469017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.59,'photographyacc','343309','nathanrossignoli@hotmail.com','Nathan Rossignoli','4 fair st','shepparton','Victoria','AUSTRALIA','3630','0358215465','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 08:15:58',0,NULL,3,1,2,1,NULL,'343309'),(18191,795455854017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','7846paulm','paulmashford@optusnet.com.au','paul mashford','10 forsyth place ','oatlands','New South Wales','AUSTRALIA','2117','0296133462','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-12 08:22:06',0,NULL,3,1,4,1,'YW868053536CN ','7846paulm'),(18192,868131595015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','barturelo','barturen@euskalnet.net','Igor Barturen','Errementariñe 14, 3ºA','Urduliz','País Vasco','SPAIN','48610','658704214','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 10:08:36',0,NULL,3,1,2,1,NULL,'barturelo'),(18193,795485779017,270751510931,'YongNuo 10m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3326',45,'photographyacc','ct1205','tmc.777@bigpond.com','Carmel Taylor','4/10 Horizon Drive','Maribyrnong','Victoria','AUSTRALIA','3032','0438674386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 10:12:18',0,NULL,5,0,18,0,NULL,'ct1205'),(18194,735606116018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','mdmm09','mdmm_09@hotmail.com','Megan Muir','41 Williamson rd','Gembrook','Victoria','AUSTRALIA','3783','0401497556','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 10:15:09',0,NULL,3,0,2,1,NULL,'mdmm09\r白布 '),(18195,739114184018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','stoshus1','stooshc@gmail.com','Charles Mistica','Jenny Craig<br>2/468 St Kilda Road','Melbourne','Victoria','AUSTRALIA','3004','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-12 11:29:36',0,NULL,3,1,4,1,'YW868053525 ','stoshus1\r1.6*2.1绿色背景布\r新地址\rCharles Mistica\rJenny Craig\r6/464 St Kilda Road\rMelbourne Victoria 3004\rAustralia\r'),(18196,795515260017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','cavog','caverswall01@bigpond.com','Graeme A Caverswall','38 Kooringal Drive Jindalee','Brisbane','Queensland','AUSTRALIA','4074','0733760071','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 11:54:53',0,NULL,3,1,17,0,NULL,'cavog'),(18197,739119787018,280670179714,'Green.L Premium Quality 52mm CPL Circular Polarizer New',1,'AA3308',6.2,'photographyacc','cavog','caverswall01@bigpond.com','Graeme A Caverswall','38 Kooringal Drive Jindalee','Brisbane','Queensland','AUSTRALIA','4074','0733760071','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 11:54:54',0,NULL,3,1,17,0,NULL,'cavog'),(18198,795514890017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','cavog','caverswall01@bigpond.com','Graeme A Caverswall','38 Kooringal Drive Jindalee','Brisbane','Queensland','AUSTRALIA','4074','0733760071','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 11:54:55',0,NULL,3,1,17,0,NULL,'cavog'),(18199,795515066017,270746361857,'52mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 52 mm',1,'AB1301',5.09,'photographyacc','cavog','caverswall01@bigpond.com','Graeme A Caverswall','38 Kooringal Drive Jindalee','Brisbane','Queensland','AUSTRALIA','4074','0733760071','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 11:54:55',0,NULL,3,1,17,0,NULL,'cavog'),(18200,795518212017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','cavog','caverswall01@bigpond.com','Graeme A Caverswall','38 Kooringal Drive Jindalee','Brisbane','Queensland','AUSTRALIA','4074','0733760071','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 11:57:37',0,NULL,3,1,3,1,'RA184565687CN\r ','cavog\r肩带 nikon     1\r绿叶 CPL  52mm    1\r绿叶 UV  52mm    1\r橡胶遮光罩 52mm    1\r镜头笔     1\r气吹 + 布    1'),(18201,778859872002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dooshiant','dooshiant@dooshiant.net','T Dyall','76 Addison Road','Reading','Berkshire','UNITED KINGDOM','RG1 8EG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 12:01:23',0,NULL,3,1,2,1,NULL,'dooshiant'),(18202,739137100018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','osetia1','art-osetia@mail.ru','SERGEY SALMANOV','59 Vladikavkazskaya Street,  Appartment 175','Vladikavkaz','Republic of North Ossetia-Alania','RUSSIAN FEDERATION','362045','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 12:42:42',0,NULL,3,0,2,1,NULL,'osetia1\r灰色'),(18203,795533630017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','pasifikprodaktion','nkg85@hotmail.com','Nathan Goodin','15 Freda St','Upper Mount Gravatt','Queensland','AUSTRALIA','4122','0423218552','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 12:47:11',0,NULL,3,1,2,1,NULL,'pasifikprodaktion'),(18204,739147622018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','kilk3nnie','aiirashi_love@hotmail.com','kenny toh','3, Kosky St','Sunshine West','Victoria','AUSTRALIA','3020','0423296618','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 13:15:43',0,NULL,3,1,3,1,'RA184565673CN\r ','kilk3nnie'),(18205,778885292002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','myyyre','buh@at-kom.ru','Stanislav Lilyen','Rachkova, 7-31','Kstovo','Nijegorodskaya','RUSSIAN FEDERATION','607657','7920048115','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-12 13:21:22',0,NULL,3,1,17,0,NULL,'myyyre'),(18206,778882057002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','stekkerfreak','ccvanduren@gmail.com','Constantijn van Duren','Achterweg 21','Haarlem','','NETHERLANDS','2023 VE','0620544439','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 13:21:48',0,NULL,3,1,4,1,'YW868053551CN ','stekkerfreak'),(18207,736475515001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','myyyre','buh@at-kom.ru','Stanislav Lilyen','Rachkova, 7-31','Kstovo','Nijegorodskaya','RUSSIAN FEDERATION','607657','7920048115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:24:26',0,NULL,3,1,17,0,NULL,'myyyre'),(18208,736475552001,110757249196,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',225,'hermeshine','yakuzacub','yakuzacub@yahoo.com','Fletcher Yeung','Unit 10/ 95-103 Sandringham St','Sans Souci','New South Wales','AUSTRALIA','2219','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:24:41',0,NULL,3,1,17,0,NULL,'yakuzacub'),(18209,736475433001,110734167587,'NEW PRO LED 312 Panel Camera & Camcorde​r Light 5600k',1,'AD1150',230,'hermeshine','yakuzacub','yakuzacub@yahoo.com','Fletcher Yeung','Unit 10/ 95-103 Sandringham St','Sans Souci','New South Wales','AUSTRALIA','2219','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:24:42',0,NULL,3,1,4,1,'YW868053400CN\r ','yakuzacub\r利帅LED系列 312AS     1\r利帅LED系列 312A    1'),(18210,739151615018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','senioraqua','flacrockers@gmail.com','Scott Crocker','15711 Almondwood Dr.','Tampa','FL','UNITED STATES','33613','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 13:26:20',0,NULL,3,1,1,1,NULL,'senioraqua'),(18211,778887187002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','myyyre','buh@at-kom.ru','Stanislav Lilyen','Rachkova, 7-31','Kstovo','Nijegorodskaya','RUSSIAN FEDERATION','607657','7920048115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:27:01',0,NULL,3,1,17,0,NULL,'myyyre'),(18212,778887954002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',218,'hermeshine','myyyre','buh@at-kom.ru','Stanislav Lilyen','Rachkova, 7-31','Kstovo','Nijegorodskaya','RUSSIAN FEDERATION','607657','7920048115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:29:27',0,NULL,3,1,5,1,'CP238090346CN\rCP238090377CN\r\r\r ','myyyre\r欧标\r除了c 里面的再发 \r2.4x3m背景架+ 白布     1\r5灯头+60-90棚  欧标    1\r灯架  2m    1\r绿叶 UV  72mm     1\r分两票sal 发   背景架发一票  其他的发一票\r'),(18213,778888839002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','myyyre','buh@at-kom.ru','Stanislav Lilyen','Rachkova, 7-31','Kstovo','Nijegorodskaya','RUSSIAN FEDERATION','607657','7920048115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:31:34',0,NULL,3,1,5,1,'','myyyre\r'),(18214,778891131002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','zotas2010','lmbfigo@gmail.com','Luis Millano','c/ guadarrama 13 portal 2 1ºA','colmenarejo','Madrid','SPAIN','28270','616498150','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 13:38:22',0,NULL,3,0,3,1,' RA184565996CN\r','zotas2010\r1.6*3 白色背景布    1'),(18215,850315404016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','peekachu777','die2self777@yahoo.com.sg','Peerapun Chutatape','Block322A Jurong East St.31 #06-252','default','','SINGAPORE','601322','96493985','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-12 14:48:53',0,NULL,3,1,3,1,'RA184565695CN\r ','peekachu777'),(18216,868257729015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','binarywareapplications','mike@onesandnoughts.com','Mike McCusker','Fairway<br>20 Padgbury Lane','Congleton','Cheshire','UNITED KINGDOM','CW12 4LP','01260290061','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-12 15:16:29',0,NULL,3,1,3,1,'RA184565656CN\r ','binarywareapplications'),(18217,778928280002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',2,'AKT058',59.98,'hermeshine','jdes3277','dinjadeb@gmail.com','Jonathan Desbiens','4800 ste-catherine east Studio A','Montreal','QC','CANADA','H1V 1Z4','(514) 526-5683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 15:22:26',0,NULL,3,1,3,1,'RA184565611CN\r ','jdes3277\r10个'),(18218,778930562002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',51,'hermeshine','crizm76','crizmmm@yahoo.com.au','Chris Mercado','193 Popondetta Rd','Blackett','New South Wales','AUSTRALIA','2770','0424292499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 15:29:25',0,NULL,3,1,3,1,'RA184565934CN\r ','crizm76\r接口环换成67cm 的'),(18219,736538836001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','huppy42','t_elofson@hotmail.com','herbert elofson','1330 Thornton Dr','Sequim','WA','UNITED STATES','98382-8088','(360) 582-0373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 16:18:08',0,NULL,3,1,1,1,NULL,'huppy42'),(18220,739230058018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','klaussitos','klaussito@sbcglobal.net','Klaus P Schneider','3070 Spring Cir','SILVER SPRINGS','NV','UNITED STATES','89429-7319','(775) 577-4927','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 16:47:19',0,NULL,3,1,1,1,NULL,'klaussitos'),(18221,739244657018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',36.8,'photographyacc','compuny.cz','jiri.velebny@compuny.cz','Jiri Velebny','Lesní 296','Sokolec u Poděbrad','CZECH REP','CZECH REPUBLIC','290 01','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 17:20:41',0,NULL,3,1,3,1,'RA184565625CN\r ','compuny.cz'),(18222,778987299002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',36,'hermeshine','vlad_molodtsov','molodtsovv@yandex.ru','Vladimir Molodtsov','St. Chernyshevskogo 29','Mineralnye Vody','Stavropol region','RUSSIAN FEDERATION','357209','+78792264285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:37:46',0,NULL,3,0,17,0,NULL,'vlad_molodtsov'),(18223,739253206018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','gcleica','studioleica@gmail.com','George Christofi','Griva Digeni 85 shop 1-2<br>Agios Nikolaos','Limassol','< Studio  Leica >','CYPRUS','3101','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 17:38:33',0,NULL,3,1,2,1,NULL,'gcleica'),(18224,736560932001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','anadenn777','anadenn@rambler.ru','Anastasiya Dolgova','Vorushin street 6,apartment 10','Pavlodar','','KAZAKHSTAN','140000','+77015019202','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:05:32',0,NULL,3,1,5,1,'CP238061530 ','anadenn777'),(18225,778983527002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','vlad_molodtsov','molodtsovv@yandex.ru','Vladimir Molodtsov','St. Chernyshevskogo 29','Mineralnye Vody','Stavropol region','RUSSIAN FEDERATION','357209','+78792264285','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-12 17:30:53',0,NULL,3,1,5,1,'CP238061543CN ','vlad_molodtsov\r1.6*2.1白色背景布   1\r1.6*3 绿色+黑色背景布'),(18226,778988710002,120770714159,'New 400w Photo Studio Mini Flash Kit with Flash Trigger',1,'AKT083',230,'hermeshine','gfregonara','gianninafregonara@hotmail.com','Giannina Fregonara','Av. Macul 4919<br>Dpto 2','Region Metropolitana','Santiago / Macul','CHILE','7821081','56-02-2214032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:51:18',0,NULL,3,1,5,1,'CP238090434CN ','gfregonara\r欧标\r影闪器是DC的\r普通包'),(18227,850419798016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','rittervonzalewski','mrmzalewski@hotmail.com','Maciej Zalewski','Flat 2D<br>16 Bridge Street','Aberdeen','Aberdeen City','UNITED KINGDOM','AB11 6JJ','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-12 17:56:49',0,NULL,3,1,4,1,'YW868053562CN ','rittervonzalewski'),(18228,736574498001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','stuartplenty','stuart-plenty@hotmail.co.uk','stuart plenty','8 St Martins Crescent<br>Nantybwch','Tredegar','Blaenau Gwent','UNITED KINGDOM','NP22 3SS','01495722561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 17:33:48',0,NULL,3,1,2,1,NULL,'stuartplenty'),(18229,795671218017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',228,'photographyacc','murzins','lamursa@hotmail.com','Willem Versteegen','Abdijstraat 37','Hamont','','BELGIUM','3930','0473-118313','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-12 18:02:39',0,NULL,3,1,4,1,'YW868053514CN ','murzins'),(18230,736621965001,110665009924,'New Camera bag topload D3 for Sony A550 A330',1,'AD1102',9,'hermeshine','rmelanson94dbb','rmelanson9@yahoo.com','roderic melanson','38 Timber Ln','newcastle','me','UNITED STATES','04553-3322','(207) 563-1356','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-12 19:03:23',0,NULL,3,1,1,1,NULL,'rmelanson94dbb'),(18231,736626873001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','picturelizard','ebay@picturelizard.co.uk','Peter Townsend Picturelizaerd','Unit 2<br>Cobhan Centre','Swindon','Wiltshire','UNITED KINGDOM','SN5 7UJ','08454747842','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-12 19:12:18',0,NULL,3,1,4,1,'YW868053385CN\r ','picturelizard\r英标'),(18232,850475127016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','xevicax','evica@hotmail.de','Éva Bognárné R.','Szegfü utca 19','Dunakeszi','','HUNGARY','2120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-12 19:16:44',0,NULL,3,1,2,1,NULL,'xevicax'),(18233,795815903017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',3,'AO0005',50.97,'photographyacc','fast_fashion_delivered','famousfarley@yahoo.com.au','Farley Ward','PO BOX 1071','Maleny','Queensland','AUSTRALIA','4552','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-12 22:48:20',0,NULL,3,0,3,1,'RA184565965CN\r ','fast_fashion_delivered\r1.6*3 蓝色+粉色+黄色'),(18234,779157983002,120752153194,'Photo Studio Background Support Carrying Carry Bag',2,'AD1129',19.8,'hermeshine','madsmaurstad','ebay@madsmaurstad.net','Mads Maurstad','Vestre Torggate 12','Bergen','','NORWAY','5015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 00:09:49',0,NULL,3,1,2,1,NULL,'madsmaurstad'),(18235,850634152016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','peternikon','peepboon@hotmail.com','Peter Hong','049.4 Severn Point<br>13 Llys Y Gored Ddu','Cardiff','Cardiff','UNITED KINGDOM','cf10 3ex','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 01:09:34',0,NULL,3,1,2,1,NULL,'peternikon'),(18236,739438976018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','medully','priya_aarti@yahoo.com','Sam Samau','4/26 Hall Street','Northgate','Queensland','AUSTRALIA','4013','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 01:16:22',0,NULL,3,1,3,1,'RA184565639CN\r ','medully'),(18237,779193088002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','niceng84_123','niceng84@yahoo.gr','nick englezopoulos','Dilinon 8','athens','Ag Stefanos','GREECE','14565','+306936569468','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-13 02:18:23',0,NULL,3,1,4,1,'YW868053584CN ','niceng84_1234\r\r白布  '),(18238,850656291016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','brangaung','brangaung@yahoo.co.uk','Brang Aung Tun  D.','13A<br>BOSTON ROAD','LONDON','Middlesex','UNITED KINGDOM','W7 3SJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 02:18:51',0,NULL,3,1,3,1,'RA184565568CN\r ','brangaung'),(18239,739463754018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',60,'photographyacc','silverspirit-au','silverspirit.au@gmail.com','Timothy Milford','PO Box 2681','Bowral','New South Wales','AUSTRALIA','2576','0412611361','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 02:30:16',0,NULL,3,1,3,1,'RA184565700CN\r ','silverspirit-au'),(18240,779196719002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','vardasys','nasirdec@gmail.com','Muhammad Ali','30-3250 Bentley Drive','Mississauga','ON','CANADA','L5M0P7','(647) 996-3737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 02:32:53',0,NULL,3,1,17,0,NULL,'vardasys'),(18241,779198113002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','vardasys','nasirdec@gmail.com','Muhammad Ali','30-3250 Bentley Drive','Mississauga','ON','CANADA','L5M0P7','(647) 996-3737','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 02:37:48',0,NULL,3,1,3,1,'RA184565642CN\r ','vardasys\r爵影红外 canon    1\r三脚架  伟峰 WF-6662A   1'),(18242,739478639018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','atav7344','nana77426@hotmail.com','antonio tavares','14 oak ridge dr','clinton','MA','UNITED STATES','01510-3126','(978) 618-9896','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 03:38:01',0,NULL,3,0,1,1,NULL,'atav7344\rxxl   已入库'),(18243,739482711018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','aloke972','mgrosdes@wanadoo.fr','GROS-DESORMEAUX LOUIS','28 LOTISSEMENT LES HORIZONS<br>ACAJOU','LE LAMENTIN','Martinique','FRANCE','97232','0696286137','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 03:53:59',0,NULL,3,1,5,1,'aloke972','aloke972'),(18244,795910381017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','godunk','sebastian.r@live.co.uk','sebastian rungan','68 montclair road<br>montclair','durban','kzn','SOUTH AFRICA','4011','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 04:48:49',0,NULL,3,1,2,1,NULL,'godunk'),(18245,779231895002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','noscoo17','noscoo@freemail.hu','Norbert Antal','Nagyvölgyi út 47.','Ózd','','HUNGARY','3661','0036-30-349-1837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 05:32:25',0,NULL,3,1,17,0,NULL,'noscoo17'),(18246,779234454002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','noscoo17','noscoo@freemail.hu','Norbert Antal','Nagyvölgyi út 47.','Ózd','','HUNGARY','3661','0036-30-349-1837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 05:46:45',0,NULL,3,1,5,1,'CP238061557 ','noscoo17\r灯架  2m    1\r斜臂     1\r闪光的柔光箱   60cm    1\r85cm 两用伞      1'),(18247,739511928018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','arsew82','egokberk@gmail.com','Erkan gökberk','mehmet ali paşa mah.zincirlikuyu cad.çakar sok no:36/1<br>bekirpaşa','kocaeli','TURKEY','TURKEY','41000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 06:42:08',0,NULL,3,1,2,1,NULL,'arsew82'),(18248,779245765002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','1947sunday','chrishschan@yahoo.ca','Chris Chan','9620 Bissett Place','Richmond','BC','CANADA','V7A4L4','(604) 377-9198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 06:46:14',0,NULL,3,1,2,1,NULL,'1947sunday'),(18249,739520893018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','the_person_who','willwong09@gmail.com','William Wong','90 Wellington Road','East Lindfield','New South Wales','AUSTRALIA','2070','0294169083','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 07:20:37',0,NULL,3,1,3,1,'RA184565815CN\r ','the_person_who'),(18250,779255607002,120758268927,'Camera protector case bag f Nikon D200 D300s D700 XL',1,'AD1174',12.99,'hermeshine','artmarg123','mmu55481@bigpond.net.au','marg munro','9 Esther Place','Gosnells','Western Australia','AUSTRALIA','6110','0892707020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 07:36:11',0,NULL,3,1,2,1,NULL,'artmarg123'),(18251,8881318493352005,111,'大沙袋 x6',6,'AD1168',0,'photographyacc','a1mikeo','eyecraft1@gmail.com','Antoine Mouawad','88 Cambridge st ','Lidcombe 2141','NSW','AUSTRALIA',' 2141','',NULL,NULL,NULL,'2011-10-13 08:09:12',0,NULL,3,1,3,1,'RA184565829CN\r ',NULL),(18252,779260920002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','maximusgama','olcayhan@hotmail.com','Binnur Odabas','Cakmak Mahallesi Balkan Cad No: 49 Umraniye,','ISTANBUL','UMRANIYE','TURKEY','34774','+90 555 255 71 26','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 08:10:21',0,NULL,3,1,3,1,'RA184563258CN ','maximusgama'),(18253,739538566018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','claudiolittlehorse','cabacaba@hotmail.it','CAVALLIN PIO','Via Montù, 35','Chieri','TO','ITALY','10023','347-8103206','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 08:40:16',0,NULL,3,1,2,1,NULL,'claudiolittlehorse\r欧标'),(18254,779026687002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','milanrush','harvey101@eircom.net','mark english','19 glen ellan court','swords','Dublin','IRELAND','default','018402357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 09:14:37',0,NULL,3,1,17,0,NULL,'milanrush'),(18255,795717500017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','milanrush','harvey101@eircom.net','mark english','19 glen ellan court','swords','Dublin','IRELAND','default','018402357','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 09:16:03',0,NULL,3,1,2,1,NULL,'milanrush\r方形滤镜接口环 77mm   1\r肥皂盒 sb800 sb600     1'),(18256,868694596015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',22.99,'hutongstore','trw_mavrik','trw_mavrik@yahoo.com','Terence Wright','8 Otters Bank','WInsford','Cheshire','UNITED KINGDOM','CW7 2TU','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-13 09:20:09',0,NULL,3,1,3,1,'RA184563425CN\r ','trw_mavrik'),(18257,739551329018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',1,'AA1204',2.5,'photographyacc','kuzhimdmitry','kuzhim@te.net.ua','Dmitry Kuzhym','Levitana st, 110, 3.','Odessa','','UKRAINE','65114','+380 (048) 7001000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 09:32:49',0,NULL,3,1,17,0,NULL,'kuzhimdmitry'),(18258,795971811017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','kuzhimdmitry','kuzhim@te.net.ua','Dmitry Kuzhym','Levitana st, 110, 3.','Odessa','','UKRAINE','65114','+380 (048) 7001000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 09:32:50',0,NULL,3,1,2,1,NULL,'kuzhimdmitry\r热靴保护盖  普通   1\r眼罩 D300       1'),(18259,739554304018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','raptor002z','ncr@freemail.hu','Zoltan Jakab','Czobor utca 5/6','Budapest','','HUNGARY','1147','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 09:43:53',0,NULL,3,1,3,1,'RA184563200CN\r ','raptor002z'),(18260,779288715002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','aticam','aticam3@inmail.sk','Attila Toth','Zeliarsky svah 27','Sturovo','Slovakia  /EU/','SLOVAK REPUBLIC','943 01','00421918184521','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 10:01:38',0,NULL,3,1,3,1,'RA184563235CN ','aticam'),(18261,796011753017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','jontaine','taunoa7@hotmail.com','donna taunoa','48 hunter avenue','hoppers crossing','Victoria','AUSTRALIA','3029','0433767053','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 11:49:03',0,NULL,3,1,2,1,NULL,'jontaine'),(18262,795516533017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','greeneyedi','dianna.fogarty@three.com.au','Dianna Fogarty','19 Conn Street','Brighton','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 12:01:42',0,NULL,3,1,2,1,NULL,'greeneyedi'),(18263,736902891001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','pavlakis1983','pauldragoumis@gmail.com','Paul Dragoumis','Nikis 28','Koufalia','','GREECE','57100','2391052375','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 12:19:47',0,NULL,3,1,3,1,'RA184563195CN\r ','pavlakis1983'),(18264,739601457018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','mr_irresi8ble','hungtrinh@live.com.au','Hung Trinh','7/166-168 Meadows Road','Mount Pritchard','New South Wales','AUSTRALIA','2170','0423060919','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 12:33:12',0,NULL,3,1,3,1,'RA184563244CN\r ','mr_irresi8ble'),(18265,796028571017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','dr.ben.jansen','dr.ben.jansen@gmail.com','Ben Jansen','75 Southlake Drive<br>Varsity Lakes','Gold Coast','Queensland','AUSTRALIA','4227','0421 520299','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-13 12:48:16',0,NULL,3,1,2,1,NULL,'dr.ben.jansen'),(18266,736916774001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','burrianaparisylondres','burrianaparisylondres@yahoo.es','Alberto Navarro Cantavella','C/ Europa 3, 1ºB IZ','Burriana','Comunidad Valenciana','SPAIN','12530','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 13:06:29',0,NULL,3,1,4,1,'YW868053492CN\r ','burrianaparisylondres'),(18267,736929583001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','wwaallllyy','rodrigoleporto@hotmail.fr','Guillaume Maillet-Rodrigues','74 rue du Rempart','NIORT','Poitou-Charentes','FRANCE','79000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-13 13:49:31',0,NULL,3,1,3,1,'RA184563187CN\r ','wwaallllyy'),(18268,795059971017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','bvj-snoopy','brando_vj@yahoo.com.au','Brando Juguilon','26 Burra Street','Pendle Hill','New South Wales','AUSTRALIA','2145','61405058671','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 13:55:37',0,NULL,3,1,2,1,NULL,'bvj-snoopy'),(18269,739616076018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','werdna_esor','adrose85@yahoo.com.au','Andrew Rose','\'Brookside Park\'<br>356 Holmes Road','Brookstead','Queensland','AUSTRALIA','4364','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 14:11:34',0,NULL,3,1,2,1,NULL,'werdna_esor\r白色'),(18270,739640203018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','+79232892744','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 14:31:44',0,NULL,3,1,5,1,'CP238090425CN ','zenitar16'),(18271,868819963015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','jocky76uk','jocky76uk@yahoo.co.uk','graham bennett','43 cambrian lane','rugeley','Staffordshire','UNITED KINGDOM','ws15 2xh','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-13 14:57:20',0,NULL,3,1,4,1,'YW868053503CN\r ','jocky76uk\r等下午的架子吧\r白+黑'),(18272,736960674001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','passatmaxxx','lvesquemaxime@gmail.com','Maxime Levesque','8525 Les Prevoyants','Montreal','QC','CANADA','H1P2S8','(514) 323-4595 ext.: 1','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-13 15:19:23',0,NULL,3,1,3,1,'RA184563227CN ','passatmaxxx'),(18273,779390656002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','halcb','ngo7952@yahoo.com','hau ngo','4319 tiger trace ct','houston','TX','UNITED STATES','77066-4047','(832) 249-7141','NoPaymentFailure','CheckoutComplete','Other','2011-10-13 15:31:10',0,NULL,3,1,1,1,NULL,'halcb'),(18274,779364788002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','a.molina.ibanez','amolina2003@hotmail.com','Antonio Miguel Molina Ibáñez','Andrés de Urdaneta<br>6 D 1 A','Madrid','Madrid','SPAIN','28045','665901560','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 15:50:13',0,NULL,3,1,3,1,'RA184563160CN ','a.molina.ibanez'),(18275,850969122016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','alexandrecassidori','fabiocassidori@yahoo.com.br','Fabio Oliveira Couto','72A Brigstock Road','Thornton Heath','London','UNITED KINGDOM','CR7 7JA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-13 17:47:10',0,NULL,3,1,2,1,NULL,'alexandrecassidori'),(18276,779452552002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','yosicom','yosi_gruber@yahoo.com','Joseph Gruber','Hashomer 16','Kiriat Bialik','Haifa','ISRAEL','27237','972522419040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 17:54:25',0,NULL,3,1,2,1,NULL,'yosicom'),(18277,868913899015,250692237371,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',6.8,'hutongstore','63fab','fabrizio.mion@tin.it','Fabrizio Mion','Montenegro 23','Maniago','PN','ITALY','33085','042772836','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 17:55:32',0,NULL,3,1,2,1,' ','63fab'),(18278,739752059018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',2,'AA3315',12.4,'photographyacc','slinkii19','slinkii19@hotmail.com','Mélanie Blanchard','558 Des Grands-Prés','Terrebonne','QC','CANADA','J6V0B2','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 18:40:56',0,NULL,3,1,2,1,NULL,'slinkii19'),(18279,737072694001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','allonesoap','kevinroanoke@yahoo.com','Kevin Cook','5801 Rexroth Ave','Bakersfield','CA','UNITED STATES','93306','(661) 301-7781','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 19:22:50',0,NULL,3,1,1,1,NULL,'allonesoap'),(18280,796230678017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','arribalafaja','arribalafaja@yahoo.es','Alberto Nalda Capetillo','Avda/ Atxabiribil nº20 A, 1º izda','Sopelana','País Vasco','SPAIN','48600','652750321','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 20:03:13',0,NULL,3,1,2,1,NULL,'arribalafaja'),(18281,796238862017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','oidude','paco_maaskant@hotmail.com','Paco Maaskant','Mathenesserdijk 279A','Rotterdam','','NETHERLANDS','3026GA','+31653611345','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 20:21:32',0,NULL,3,1,4,1,'YW868053470CN\r ','oidude'),(18282,796243546017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','skaw80','skawi@yahoo.com','Sebastian Kawahira','Concepcion Arenal 2978, PB \"D\"','Colegiales, Capital Federal','Buenos Aires, Argentina','ARGENTINA','1426','5411 4777 7564','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-13 20:31:25',0,NULL,3,1,2,1,NULL,'skaw80\r欧标 '),(18283,739829814018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','rasheemsaini','blah_blah_blah_001@hotmail.com','Rasheem Saini','29<br>Lord Castlereagh Circuit','Macquarie Links','New South Wales','AUSTRALIA','2565','0296059807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-13 21:05:58',0,NULL,3,1,2,1,NULL,'rasheemsaini'),(18284,779559006002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','elshypav','imsuchtherockstar@yahoo.com','Elizabeth Pavkov','6654 Leland Way<br>Apt 102','Hollywood','CA','UNITED STATES','90028-3805','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-13 21:24:38',0,NULL,3,1,4,1,'YW868053481CN\r ','elshypav'),(18285,779562771002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','cliff_bga','cher332@tx.rr.com','Cliff Baise','2308 Yale Dr','Arlington','TX','UNITED STATES','76015','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-13 21:35:19',0,NULL,3,1,1,1,NULL,'cliff_bga'),(18286,737021154001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','videomanspainsam','videomanspain@gmail.com','Loli','General Mola 8, 1ºF','Malaga','Andalucía Ceuta y Melilla','SPAIN','29010','615657922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-13 21:37:38',0,NULL,3,1,2,1,' ','videomanspainsam'),(18287,869084097015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','homezd8000','andrew_tihi@yahoo.com','Tihi Andrei','Calle Belice , Nr  1','Roquetas de Mar','Andalucía Ceuta y Melilla','SPAIN','04740','642878685','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-13 23:41:18',0,NULL,3,1,3,1,'RA184563111CN\r ','homezd8000'),(18288,739913929018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','cal_nextsong','raphael.song@att.net','Raphael W. Song','38 Egret Ln','Aliso Viejo','CA','UNITED STATES','92656-1759','(949) 306-9314','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 01:47:30',0,NULL,3,1,3,1,'RA184563173CN ','cal_nextsong'),(18289,8881318557654079,111,'背景布 1.6x2.1 棕色',1,'',0,'hermeshine','johnc9964','donodo@btinternet.com','John Carter','40 Robertson Creasent<br>Kiess','Wick, ','Caithness, Highland','UNITED KINGDOM','KW1 4XA','donodo@btinternet.com',NULL,NULL,NULL,'2011-10-14 02:00:54',0,NULL,3,0,2,1,NULL,NULL),(18290,8881318558293249,111,'影闪器DC  x   3',3,'',0,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239<br>Kiess','alduraz','alduraz','BAHRAIN','973','0097339747573',NULL,NULL,NULL,'2011-10-14 02:11:33',0,NULL,3,0,12,1,'1107479682 ',' 实重 537\r泡重    663\r最终计费 1'),(18291,8881318559068095,111,'1.6x3m 灰色背景布',1,'',0,'hermeshine','spy*c','LogansPhotography@hotmail.com','Natalie Higgins','1047 Escott Court<br>Kiess','Pickering','Ontario','CANADA','L1X 1P3','905-837-0234',NULL,NULL,NULL,'2011-10-14 02:24:28',0,NULL,3,1,3,1,'RA184563394CN\r ',NULL),(18292,737215160001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','adowey80','dowey@tpg.com.au','Andrew Dowey','2 Delauret Square','Waratah West','New South Wales','AUSTRALIA','2298','0249600896','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 02:44:15',0,NULL,3,1,2,1,NULL,'adowey80'),(18293,8881318563358263,111,'河北背心 黑色 无子  xxl',1,'',0,'hermeshine','caczerny','carlos.czerny@gmail.com','Carlos Victor Czerny','Peru 160 Piso 5to sistemas (int. 4145)<br>Kiess','Ciudad autonoma de Buenos Aires','','ARGENTINA','C1067AAD','+5491150193614',NULL,NULL,NULL,'2011-10-14 03:35:58',0,NULL,3,0,3,1,'RA184570191CN\r ','重量别超过500g，超过了和我说一声 \r黑色  厚的\r577'),(18294,739941600018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','apchoo','albert.choo@oakton.com.au','Albert Choo','13 Bemboka Court','Wantirna South','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 03:45:45',0,NULL,3,1,2,1,NULL,'apchoo'),(18295,739961010018,280685239247,'Pro Spanner Wrench For Lens Repair Tool Stainless Steel',1,'AA2401',42,'photographyacc','fubarjim','paypal1@brodie-tyrrell.org','William Brodie-Tyrrell','31 Lema Ave','Fairview Park','South Australia','AUSTRALIA','5126','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 05:31:22',0,NULL,3,1,3,1,'RA184563417CN  ','fubarjim'),(18296,734910822001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','eugenmal','evmalev@gmail.com','Nadezhda Pashskaya','Detskoselskij, 7 - 17<br>Pushkin','Sankt-Peterburg','','RUSSIAN FEDERATION','196605','+7 931 244 7 022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 06:18:02',0,NULL,3,1,2,1,NULL,'eugenmal'),(18297,796417703017,270753948303,'Bounce Flash Diffuser for Speedlight Flash SB800 SB600',1,'AB3330',2.9,'photographyacc','greystoke0','cesteil@tpg.com.au','Cameron Steil','19 Jacaranda Drive','Jerrabomberra','New South Wales','AUSTRALIA','2619','0262558874','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-14 06:52:59',0,NULL,3,1,2,1,NULL,'greystoke0'),(18298,739969058018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','kasparov_ksa85','kasparov_ksa@hotmail.com','Ali Al-Shammasi','P.O.box 310','Qatif','Eastern province','SAUDI ARABIA','31911','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 06:19:20',0,NULL,3,1,3,1,'RA184563505CN ','kasparov_ksa85'),(18299,869238340015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','diegoarcas','darcas@ono.com','diego arcas ivorra','c/ pintor sorolla, nº 18, pta. 16','museros (valencia)','Comunidad Valenciana','SPAIN','46136','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 08:13:37',0,NULL,3,1,4,1,'YW868053455CN\r ','diegoarcas\r白布'),(18300,779710732002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','txelas','javi_mad02@hotmail.com','Javier Barciela Salcedo','c/ Maria Moliner nº9, Portal 4, 1ºB','San Sebastian de los Reyes (Madrid)','Madrid','SPAIN','28702','608249762','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 08:16:14',0,NULL,3,1,4,1,'YW868053466CN\r ','txelas\r背景布是蓝色的'),(18301,8881318581012901,111,'6663a配件',1,'',0,'hermeshine','13mixmaslab','mixmaslab@gmail.com','Vitaly Yavorsky','Lenina 13,kv 5<br>Kiess','Kozyatyn','Vinnickaya oblast','UKRAINE','22100','+380632665598',NULL,NULL,NULL,'2011-10-14 08:30:12',0,NULL,3,1,3,1,'RA184563496CN  ',NULL),(18302,8881318581482753,111,'312led里的柔光板',1,'',0,'hermeshine','mikeraj88','mikeraj@streamyx.com','Michael Raj Marks','16 Taman Putra, Kelang Lama<br>Kiess','Kulim','Kedah','MALAYSIA','09000','0124315187',NULL,NULL,NULL,'2011-10-14 08:38:02',0,NULL,3,0,3,1,'RA184563482CN  ',NULL),(18303,8881318583557460,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',23.99,'aliexpress','1004754592','irill@linuxhome.ru','Kiryl Habeyeu','Geroev Panfilovcev 7/6-157','Moscow','Moscow','RUSSIAN FEDERATION	','125480','+7 495 5857237',NULL,NULL,NULL,'2011-10-14 09:12:37',0,NULL,5,0,18,0,NULL,''),(18304,8881318584072113,111,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',69.48,'aliexpress','1004756877','ayarmots@gmail.com','Alexey Yarmots	','Nekrasova, 19D, 40','Kamyshin','Volgogradskaya','RUSSIAN FEDERATION	','403877','+7 927 5230935',NULL,NULL,NULL,'2011-10-14 09:21:12',0,NULL,3,1,5,1,'CP238090385CN\r ',''),(18305,740017498018,280673080792,'58mm 3-Stage Collapsible 3-in-1 Rubber Lens Hood 58 mm',1,'AB1303',5.09,'photographyacc','colfishingcol','colyk52@hotmail.com','col knight / boral concrete pty ltd','208 curtain ave west, eagle farm','brisbane','Queensland','AUSTRALIA','4009','0414617269','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 09:48:04',0,NULL,3,1,2,1,NULL,'colfishingcol'),(18306,739572528018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',78,'photographyacc','essiejim','alexmaeella@bigpond.com','Wendy McSween','30 Laricina Cct<br>Forest Lake','Brisbane','Queensland','AUSTRALIA','4078','0738790914','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-14 11:00:48',0,NULL,3,1,4,1,'YW868053352CN\r ','essiejim'),(18307,736958889001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','kierov','jdecarie@rocketmail.com','JOANNIE SURPRENANT','1-5536 9EME AVENUE','MONTREAL','QC','CANADA','H1Y 2J8','(514) 667-3383 ext.: 272','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 11:44:10',0,NULL,3,1,5,1,'CP238090350CN\r ','kierov\r灯泡换成110v 的 \r布是绿色的'),(18308,737344495001,110540530076,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',95.8,'hermeshine','victoriasvirtuality','vctrrowland@yahoo.com.au','victoria rowland','86 Boggy Creek Road','Bellingen','New South Wales','AUSTRALIA','2454','0266578029','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-14 12:41:09',0,NULL,3,1,4,1,'YW868053363CN\r ','victoriasvirtuality\r白+ 黑'),(18309,779785558002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','juno01','junofrancoise@yahoo.com','deodoro centeno','# 2 s fonacier st, barangay 14','laoag','ilocos norte','PHILIPPINES','2900','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 13:02:43',0,NULL,3,0,3,1,'RA184563933CN\r ','juno01\r摄影包 canon M2   1'),(18310,869338125015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','althalus100','milamber@ntlworld.com','Simon J Morgan','32 Sommerset Road','Newport','Newport','UNITED KINGDOM','NP197GA','01633667586','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 13:09:08',0,NULL,3,0,2,1,NULL,'althalus100\r黑色'),(18311,851411752016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','soul.of.music','justukas4u@yahoo.com','Andrej Ivanov','flat 3 stonebridge house<br>81 Silver Royd Hill','Leeds','West Yorkshire','UNITED KINGDOM','LS12 4QQ','07533856762','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-14 14:00:38',0,NULL,3,1,2,1,NULL,'soul.of.music'),(18312,851427852016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-14 14:40:41',0,NULL,3,1,3,1,'RA184563920CN\r ','oren_keller\r'),(18313,869375096015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 14:40:42',0,NULL,8,1,17,0,NULL,'oren_keller'),(18314,869375097015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 14:40:43',0,NULL,3,1,3,1,'RA184569825CN\r ','oren_keller\r圆形柔光棚 50cm    1\r倒影板（白黑）       1\r'),(18315,869375098015,250692239955,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',23,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 14:40:44',0,NULL,3,1,17,0,NULL,'oren_keller'),(18316,869375099015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-14 14:40:44',0,NULL,3,1,3,1,'RA184563765CN\r  ','oren_keller\r反光板支架    1\r反光伞110cm     1\r\r'),(18317,851427855016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-14 14:40:45',0,NULL,3,1,3,1,'RA184569162CN\r','oren_keller\r\r\r'),(18318,740114346018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','fly_boy748','andrew_k@aunix.com.au','Andrew Kovacs','P O Box 2004','Mount Isa','Queensland','AUSTRALIA','4825','61747438863','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 15:01:13',0,NULL,3,1,3,1,'RA184563862CN\r ','fly_boy748'),(18319,779825782002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','natinyp','talktonati@gmail.com','nati yehezkel','hanarkisim<br>63','atlit','','ISRAEL','30300','+972-52-8743232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:01:56',0,NULL,3,1,2,1,NULL,'natinyp'),(18320,779825698002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','mudi57','didier.neglot@modulonet.fr','didier neglot','4 rue des genets','marly','Lorraine','FRANCE','57155','0675803747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:03:21',0,NULL,3,1,2,1,NULL,'mudi57'),(18321,779833137002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','hills5985','angiewillwait@gmail.com','Angela Hills','3/10 Crawford Avenue','Stafford','Queensland','AUSTRALIA','4053','0403704748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:22:44',0,NULL,3,1,2,1,NULL,'hills5985'),(18322,8881318606485866,111,'2300w 套装',1,'AKT068',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-10-14 15:34:45',0,NULL,5,0,18,0,NULL,NULL),(18323,8881318606615857,111,'2300w 套装 ',1,'AKT041',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-10-14 15:36:55',0,NULL,3,1,12,1,'1107470335\r ','C里的套装 +  45w 110v 灯泡 x 2\r灯泡是110v的\r实重7.92 泡重9.79\r最终计费 9.5'),(18324,8881318606935245,111,'45w 220v  1',1,'',0,'hutongstore','suzy9882','suzy.wilson17@googlemail.com','Luca Romita','ECMWF<br>Shinfield Park, Shinfield','READING','Berkshire','UNITED KINGDOM','RG2 9AX','07984103682',NULL,NULL,NULL,'2011-10-14 15:42:15',0,NULL,3,0,3,1,'RA184563672CN\r ',NULL),(18325,851460791016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',62,'hutongstore','serge6ka_11','serge6ka@inbox.lv','Sergejs Masko','83A Clitterhouse Crescent','London','Middlesex','UNITED KINGDOM','NW2 1DB','07955867000','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-14 15:52:23',0,NULL,3,1,4,1,'YW868053330CN\r ','serge6ka_11'),(18326,737408987001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','300671igor','sizov71@yandex.ru','IGOR SIZOV','LV-1029<br>ROSTOKAS STREET 16-18','RIGA','','LATVIA','LV-1029','+37129110168','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 15:55:25',0,NULL,3,0,3,1,'RA184563726CN\r ','300671igor\rL  （已入库）'),(18327,737410884001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','al6000','alex.esselin@free.fr','Alex ESSELIN','1 rue des violettes','Illkirch','Alsace','FRANCE','67400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 15:59:59',0,NULL,3,1,3,1,'RA184563624CN\r ','al6000'),(18328,779847844002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','napong22','napong2@yahoo.com','napong phaeoponsong','110/5 moo 17 Mrittrapab Rd<br>Maung khonkaen','default','KK','THAILAND','40000','6643224347','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 16:01:34',0,NULL,3,1,2,1,NULL,'napong22'),(18329,796604698017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','mctarakan','oportunity@mail.ru','Sergei Mistsuk','99 the Paddocks<br>Westbury','Limerick','Limerick','IRELAND','LK','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 16:53:29',0,NULL,3,1,2,1,NULL,'mctarakan'),(18330,869456472015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',49,'hutongstore','scamps120287','sammie_camps@hotmail.co.uk','Samantha Camps','1 oak cottages<br>oak street','oswestry','Shropshire','UNITED KINGDOM','sy11 1ll','07515572398','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-14 17:22:09',0,NULL,5,1,4,1,'YW868053341CN\r ','scamps120287\r白+黑\r已经发货了   但是点不了 '),(18331,737445427001,110428262891,'TianYa 6 pcs filters for cokin p seriers w filter bag',1,'AKT008',42.99,'hermeshine','edesio_jr','jrconegundes@gmail.com','Edésio Martins Conegundes Júnior','Av. Afonso Pena, N° 1500, 14° andar, NEAD','Belo Horizonte','Minas Gerais','BRAZIL','30130-005','+55 31 88474537','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 17:26:02',0,NULL,3,1,3,1,'RA184563712CN\r ','edesio_jr'),(18332,737453630001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','alix','alix@sappho.com','Alexandria North','3544 Windmill Way','Concord','CA','UNITED STATES','94518','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-14 17:48:29',0,NULL,3,1,3,1,'RA184563902CN\r ','alix'),(18333,740195750018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','idl1976','imani_54@yahoo.com.au','mehdi imani','MOOROOLBARK DENTURE CLINIC<br>shop 13 ,No 91 Brice AVE','Mooroolbark','Victoria','AUSTRALIA','3138','0413623824','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-14 18:07:27',0,NULL,3,1,3,1,'RA184563553CN\r ','idl1976'),(18334,740192844018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','yong2x*','yongmagallanes@yahoo.com','jonathan magallanes','2004 weir cook dr','yorktown','IN','UNITED STATES','47396-6849','(765) 749-7137','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 18:00:47',0,NULL,3,1,1,1,NULL,'yong2x*'),(18335,779907019002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','loko_paul','paul.lokomotiv@gmail.com','Pavel Pesternikov','Komissara Utrobina 7 - 75','Kirovo-Chepetsk','Kirovskaya oblast','RUSSIAN FEDERATION','613051','7-83361-63445','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 18:21:41',0,NULL,3,1,2,1,NULL,'loko_paul'),(18336,779923867002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','luisveramontes2011','luisveramontes@hotmail.com','Luis Enrique Vera Montes','Av. Manco Capac 168 - dpto 212<br>La Victoria','Lima','Lima / Lima','PERU','Lima 13','51-1-945087533','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-14 18:55:24',0,NULL,3,1,3,1,'RA184564001CN\r ','luisveramontes2011'),(18337,737492579001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',28.5,'hermeshine','bender_124','viktor_zakurdayev@mail.ru','Viktor Zakurdayev','Gagarina, 294/3, 58','Almaty','','KAZAKHSTAN','050060','+7 777 5641007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-14 19:03:51',0,NULL,3,1,2,1,NULL,'bender_124\r欧标'),(18338,740257224018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','carnacki','ghostfinder@carnacki.com','JeanPascal CODINE','60 rue de Montreuil','Vincennes','Ile-de-France','FRANCE','94300','01.77.21.91.03','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 20:08:23',0,NULL,3,1,2,1,NULL,'carnacki'),(18339,737534571001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','topropebeltscom','koolwater69@hotmail.com','Top Rope Belts','2292 W US Highway 64','Lexington','NC','UNITED STATES','27295-5532','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-14 20:34:11',0,NULL,3,1,1,1,NULL,'topropebeltscom\r110v'),(18340,779973751002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','utahlax','cogrady@xmission.com','Claudia O\'Grady','977 S. Windsor St','Salt Lake City','UT','UNITED STATES','84105','(801) 450-1029','NoPaymentFailure','CheckoutComplete','Other','2011-10-14 20:40:31',0,NULL,3,1,3,1,'RA184563540CN\r ','utahlax'),(18341,795362295017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','1001wonderboy','iimpact1001@yahoo.com','ROLLE LEON','2210 Gail ave','ALBANY','GA','UNITED STATES','31707-2416','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-14 20:50:50',0,NULL,3,1,1,1,NULL,'1001wonderboy'),(18342,736760852001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','elizeucine','elizeumol@hotmail.com','elizeu mol','rua 05 de maio, 6 b<br>centro','Timóteo','Minas Gerais','BRAZIL','35180036','3138493361','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-15 00:30:01',0,NULL,3,1,3,1,'RA184563774CN\r ','elizeucine'),(18343,740361875018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',70,'photographyacc','**t-1000**','loganis@shaw.ca','Logan Rode','2640 Asquith St','Victoria','BC','CANADA','V8R3Y3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 02:00:26',0,NULL,3,1,3,1,'RA184563791CN\r ','**t-1000**'),(18344,796839925017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','viciouz_devil','w.ly@optusnet.com.au','Winnie Ly','70 Chancery St','Canley Vale','New South Wales','AUSTRALIA','2166','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-15 03:29:03',0,NULL,3,1,2,1,NULL,'viciouz_devil'),(18345,851766553016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','farc8257','gooroondilbaa@bigpond.com','Frank Archer','P.O. Box 179','Gisborne','Victoria','AUSTRALIA','3437','030427315573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 04:23:04',0,NULL,3,1,2,1,NULL,'farc8257'),(18346,780125434002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','sa555sss','sa555sss@tiscali.co.uk','SALEEM AMIN','210A, LADY MARGARET ROAD','SOUTHALL','MIDDX','UNITED KINGDOM','UB1 2RU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 07:33:55',0,NULL,3,1,3,1,'RA184563686CN\r ','sa555sss'),(18347,737685049001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','rafalus79','easy2write@yahoo.co.uk','Rafal Biernat','1 Coventry Gardens','North Shields','Tyne and Wear','UNITED KINGDOM','NE29 6BE','01912575635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 07:44:52',0,NULL,3,0,2,1,NULL,'rafalus79\r黑色 '),(18348,740428755018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','czartandras','andrewcz@freemail.hu','Andras Czart','Nieuwe Binnenweg 96-2L','Rotterdam','','NETHERLANDS','3015BD','+31633615118','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 07:52:51',0,NULL,3,1,2,1,NULL,'czartandras'),(18349,737693407001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','txapeldum','aayusom@euskalnet.net','ALBERTO AYUSO MORENO','J.M. DE BARANDIARÁN, Nº 6, ENTPL. 1ª','SANTURCE','País Vasco','SPAIN','48980','629358084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 08:22:35',0,NULL,3,1,2,1,NULL,'txapeldum'),(18350,737717502001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','blackermoon','blackermoon@gmail.com','Marco Solleveld','Blauwe reiger 3','Rozenburg','','NETHERLANDS','3181KA','0618049505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 10:05:42',0,NULL,3,1,2,1,NULL,'blackermoon'),(18351,869816310015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','andyclive1974','andy@mdt-products.com','Andy Sharpe','3 Hannam Close','Cheltenham','Gloucestershire','UNITED KINGDOM','GL53 9AS','01242511506','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 10:21:53',0,NULL,3,1,2,1,NULL,'andyclive1974'),(18352,869817285015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','houssier2006','cococicinenelle@hotmail.com','houssier thierry','rue crapoto 5','ragnies','','BELGIUM','6532','071534996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 10:25:01',0,NULL,3,1,2,1,NULL,'houssier2006'),(18353,796941379017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','danyossi','yossi70ed@gmail.com','Yossi Daniel','Nativ-hen 19A','Haifa ISRAEL','ISRAEL','ISRAEL','32242','972544446168','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 10:48:07',0,NULL,3,1,2,1,NULL,'danyossi'),(18354,737750763001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-15 11:52:46',0,NULL,3,1,17,0,NULL,'icreates_meenu'),(18355,780195909002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 12:00:17',0,NULL,3,1,17,0,NULL,'icreates_meenu'),(18356,737753584001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 12:03:15',0,NULL,3,1,6,1,'EE491016105CN\r ','icreates_meenu\r背景架2mx2m  + 3个夹子    1\r1.6*2.1黑色+白色\r2单反     1\r柔光箱 50-70cm 单灯头    1\r'),(18357,740514000018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','sveinungj','sveinungjavnes@live.no','Arnt Øyvind Javnes','Sukkerheia 10','Kolbjørnsvik','','NORWAY','4816','90676421','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 12:40:15',0,NULL,3,1,2,1,NULL,'sveinungj'),(18358,851923282016,260660051675,'Neoprene Camera Cover for Nikon D50 D70s D80 D90 M',1,'AC2304',4.5,'hutongstore','alfredoz61','alfredo.zorani@alice.it','Alfredo Zorani','Via della Poiana 27','Roma','RM','ITALY','00169','06262460','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 13:13:18',0,NULL,3,1,2,1,NULL,'alfredoz61'),(18359,851924907016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','kiril_fmi','cyril.cyrov@gmail.com','Kiril Kirov','bl. 38, entrance 4 (\"G\"), floor 3, ap. 56','Sofia','Drujba 1','BULGARIA','1592','+359 892 466 082','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 13:13:34',0,NULL,3,1,2,1,NULL,'kiril_fmi'),(18360,851915358016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','talianich','anatolij.chomko@mail.ru','Anatolij Chomko','Shannon view<br>Glasson','Athlone','Westmeath','IRELAND','090','0877732742','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-15 13:36:22',0,NULL,3,0,3,1,'RA184569661CN\r ','talianich\r1.6m x 3m 背景布    2\r黄色   蓝色\r'),(18361,737791119001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','katobit','tong-64@hotmail.com','panupong kaensiri','14/11 tanintron seekan donmuang','bangkok','bangkok','THAILAND','10210','0852158838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 13:57:03',0,NULL,3,1,2,1,NULL,'katobit'),(18362,780274204002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','daggesz','mihalek@chello.hu','Zsolt Michalek','Kossuth Street 1','Vértesszőlős','Komárom-Esztergom','HUNGARY','2837','0036303553528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 15:39:31',0,NULL,3,1,3,1,'RA184563893CN\r ','daggesz'),(18363,869953763015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','mystik021','bfenech@gmail.com','Benjamin Fenech','The Arup Campus<br>Blythe Valley Park','Solihull','West Midlands','UNITED KINGDOM','B90 8AE','07944320534','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 15:44:14',0,NULL,3,1,3,1,'RA184563536CN\r ','mystik021'),(18364,737587161001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','renzlazarte','renzoy03@yahoo.com','Lorenzo Rommell Lazarte','105 Greenwood street','steinbach','MB','CANADA','R5G2C3','(120) 434-6593 ext.: 2','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 16:50:58',0,NULL,3,1,2,1,NULL,'renzlazarte'),(18365,737886417001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','rtrevelar','rrevelar@shaw.ca','Richard T. Revelar','140 Panamount Manor NW','Calgary','AB','CANADA','T3K 6H8','(403) 619-1831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 17:42:25',0,NULL,3,1,3,1,'RA184563828CN ','rtrevelar'),(18366,780398054002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','patoh-half','milunauna@yahoo.com','Hilda Pato Krol','203 Lafayette Ln','Fayetteville','NY','UNITED STATES','13066-1417','(315) 637-0182','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-15 19:59:39',0,NULL,3,1,1,1,NULL,'patoh-half'),(18367,870121000015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','thomasyr','thomasyroe@hotmail.com','Thomas Yong Roe','Buskerudveien 79B','Drammen','Buskerud','NORWAY','3024','0047 94897308','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-15 20:23:06',0,NULL,3,1,5,1,'CP238090244CN','thomasyr\r欧标\r实重   7.67   泡重10.1'),(18368,780426551002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','jomp500jorge','jomp500@gmail.com','Jorge Miras Pouso','Av. Pio XII, 30, esc. izq., 2º A','Pamplona','Navarra','SPAIN','31008','639845086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 21:04:54',0,NULL,3,1,2,1,NULL,'jomp500jorge'),(18369,780429234002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','57shoebox','jtompkins2@austin.rr.com','Jim B. Tompkins','1901 Brentwood St','Austin','TX','UNITED STATES','78757-2803','(512) 912-3679','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-15 21:12:54',0,NULL,3,1,1,1,NULL,'57shoebox'),(18370,870153653015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','k.c.1957','k_a_c@blueyonder.co.uk','kevin  cox','17 Durnford Avenue<br>Ashton','Bristol','Avon','UNITED KINGDOM','bs32al','01179664996','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-15 21:21:23',0,NULL,3,1,3,1,'RA184569176CN\r ','k.c.1957'),(18371,797237566017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',6.98,'photographyacc','gerrit9893','gerritmestdagh@hotmail.com','gerrit MESTDAGH','TER RIVIERENLAAN 48','DEURNE','','BELGIUM','2100','0495507210','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 21:47:59',0,NULL,3,1,2,1,NULL,'gerrit9893'),(18372,780446406002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','matti3650','masapirhonen@dnainternet.net','Matti Pirhonen','Tiirankatu 13','Lohja','','FINLAND','08150','+358445056886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 21:58:27',0,NULL,3,1,2,1,NULL,'matti3650'),(18373,740767025018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',63,'photographyacc','kobus_schoeman','schoeman.kobus@yahoo.com','Kobus Schoeman','23A Telstar Place<br>Beach Haven','Auckland','Auckland','NEW ZEALAND','0626','+64211586541','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 22:07:56',0,NULL,3,1,6,1,'EE491016114CN\r ','kobus_schoeman'),(18374,739841081018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',2,'AA3314',14.4,'photographyacc','myisr','gold.david@gmail.com','David Goldenshluger','Adar 16/6<br>Rova Yud-Bet','Ashdod','Israel','ISRAEL','77300','+972-545-597-941','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-15 22:42:30',0,NULL,3,1,2,1,NULL,'myisr'),(18375,738012169001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','maxalanya','munir@altioglu.com','MUNIR ALTIOGLU','GULLERPINARI MAH. KIYMALI SOK.<br>H.GULLU APT. 2024','ALANYA','ANTALYA','TURKEY','07400','00905362234330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-15 22:43:58',0,NULL,3,1,5,1,'CP238090363CN\r ','maxalanya'),(18376,797262524017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','viktor6255','ruthjbarnett@hotmail.com','Ruth J Eszenyi','25A Marchamley Street','Carlisle','Western Australia','AUSTRALIA','6101','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-15 23:01:58',0,NULL,3,1,2,1,NULL,'viktor6255'),(18377,780487231002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','neptunian76','magabel08@hotmail.com','toni raper','19 fairy st<br>moorooka','brisbane','Queensland','AUSTRALIA','4105','0737005351','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 00:23:42',0,NULL,3,1,3,1,'RA184563522CN\r ','neptunian76'),(18378,780496285002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','abid2003','abidullahjan@gmail.com','Abid Ullah Jan','4016 Canyon Walk Drive','Ottawa','ON','CANADA','k1V 1X3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 01:00:18',0,NULL,3,1,3,1,'RA184570545CN\r ','abid2003'),(18379,740817330018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','sydneyview','jandmpass@gmail.com','John Passmore','18 Woodstock Road','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 01:05:09',0,NULL,3,0,3,1,'RA184563743CN\r ','sydneyview\rxxxl 已入库'),(18380,740833435018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','echonky','gaglan@ozemail.com.au','Nundah Village Dental','1182 Sandgate Rd<br>( PO box 179 )','Nundah','Queensland','AUSTRALIA','4012','0732606200','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 02:14:00',0,NULL,3,1,2,1,NULL,'echonky'),(18381,738064516001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','vinnyvinz','v_desjardins@hotmail.com','Vincent Desjardins','155 ave Champlain','Rouyn-Noranda','QC','CANADA','J9X1J9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 02:15:48',0,NULL,3,1,2,1,NULL,'vinnyvinz'),(18382,740838562018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','jukebox71','jukesy71@gmail.com','Jukes Campbell','249 Edwards Street','Sunshine Beach','Queensland','AUSTRALIA','4567','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 02:43:25',0,NULL,3,1,3,1,'RA184563859CN\r ','jukebox71'),(18383,797329111017,270833010437,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','obmit2011','tim.nicol@internode.on.net','Tim Nicol','17 Rudolph court','Bakewell','Northern Territory','AUSTRALIA','0832','0889329707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 03:21:18',0,NULL,3,1,2,1,NULL,'obmit2011'),(18384,738080915001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','kingtread','mboily@videotron.ca','Mario Boily','1923 Des Hiboux<br>Unit # 105','Chicoutimi','QC','CANADA','G7H7S3','(418) 543-1215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 03:34:03',0,NULL,3,0,3,1,'RA184563709CN\r ','kingtread\rXL  已入库'),(18385,780544229002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','justwait982011','justwait98@yahoo.com.tw','文彬 林','新北市三重區中正北路276巷1號','default','','TAIWAN','24162','0910999181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 04:44:27',0,NULL,3,1,2,1,NULL,'justwait982011'),(18386,740874203018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','chrisflud','christianfludder@yahoo.com','Christian Fludder','7 Gagarra St','Eight Mile Plains','Queensland','AUSTRALIA','4113','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 05:51:02',0,NULL,3,1,3,1,'RA184563845CN ','chrisflud'),(18387,740880713018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','hpal1573','hj.palmer@bigpond.com','Helen Palmer','6 Oakbank Terrace','Murwillumbah','New South Wales','AUSTRALIA','2484','0409310014','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-16 06:29:59',0,NULL,3,1,4,1,'YW868053315CN\r ','hpal1573\r黑+白'),(18388,740891655018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',16.8,'photographyacc','bgre8906','bgandtg@bigpond.com','Bryan Greene','10 Briarwood Crt','Croydon','Victoria','AUSTRALIA','3136','0397232883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 07:18:02',0,NULL,3,1,2,1,NULL,'bgre8906\r澳标'),(18389,737341067001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','motonatrum','touret.michel@gmail.com','TOURET MICHEL','7 RUE HYACINTHE GLOTIN','LORIENT','Bretagne','FRANCE','56100','0297217484','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 07:36:01',0,NULL,3,1,3,1,'RA184563669CN\r ','motonatrum'),(18390,870341581015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','kaikkoja','jkaikkon@luukku.com','Jarmo Kaikkonen','Juvansyrjä 7B','Espoo','Uusimaa','FINLAND','02920','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 08:07:59',0,NULL,3,1,3,1,'RA184563757CN\r ','kaikkoja\r4个'),(18391,738148994001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','onurguler86','poseidonur@yahoo.com','onur güler','yoruk mah 383 sok no:13/9','salihli','manisa','TURKEY','45300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 08:55:06',0,NULL,3,1,2,1,NULL,'onurguler86'),(18392,738150693001,110756717212,'New Twin Flash Bracket for Nikon  D700  SB900 SB800 Canon 7D 5DII  580EX C-Shape',1,'AD1193',18.99,'hermeshine','grouch_king','gandsdesign@googlemail.com','Graham King','5 Kingston Circuit<br>Seaford Rise','Adelaide','South Australia','AUSTRALIA','5169','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 08:57:04',0,NULL,3,1,3,1,'RA184563947CN\r ','grouch_king'),(18393,780612186002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','micha_de','micha@ubootmodell.de','Michael Weidner','Fritz-Thomas-Str. 8','Marktredwitz','','GERMANY','95615','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 09:23:19',0,NULL,3,0,3,1,'RA184569128CN\r ','micha_de\r3XL   已入库'),(18394,869419830015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0005',15.98,'hutongstore','gxyzod2','gxyzodatwork@yahoo.it','Sasa Maric','EFSA - Largo Palli 5/A','Parma','PR','ITALY','43100','3470069038','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 10:24:23',0,NULL,3,0,3,1,'RA184563575CN\r ','gxyzod2\r1.6*2.1粉红+红色'),(18395,740973182018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','harryhonky','sfels@adam.com.au','Scott Fels','20 Ronald Road','Redwood Park','South Australia','AUSTRALIA','5097','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-16 11:02:55',0,NULL,3,1,2,1,NULL,'harryhonky'),(18396,852487042016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',40,'hutongstore','dou_cheang','dou_cheang@yahoo.com','Douglas Cheang','5, Jln Kg. Cina,','Pantai Remis','Perak','MALAYSIA','34900','012-5012666','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 11:57:06',0,NULL,3,1,3,1,'RA184563876CN\r ','dou_cheang\r环是62cm 的 \r托架换成广角的\r已入库'),(18397,740999506018,280667384536,'43\" 110CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3401',26,'photographyacc','shamansh','radioactive666@mail.ru','Kostia Gdalevitch','Hanaviim 27/8','Bat Yam','','ISRAEL','59674','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 11:57:55',0,NULL,3,1,3,1,'RA184563598CN\r ','shamansh'),(18398,780685904002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','roxaz112','roxaz911@gmail.com','Kristina Kymantaitė','Ežero 29-115','Šiauliai','','LITHUANIA','76285','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 12:25:18',0,NULL,3,1,2,1,NULL,'roxaz112'),(18399,797256258017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','robertobag89','robertobag@msn.com','Roberto Baglivo','Giuseppe  Bentivogli 111','Bologna','BO','ITALY','40138','3896806605','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 12:26:06',0,NULL,3,1,2,1,NULL,'robertobag89'),(18400,797505982017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','alessiopietro','alessiofacchin@libero.it','Alessio Facchin c/o Ottica Facchin','Via Roma 5','Biandronno','Varese','ITALY','21024','0332766053','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 12:38:48',0,NULL,3,1,2,1,NULL,'alessiopietro'),(18401,741033778018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','crayxxx','raywong1xxx@yahoo.ie','Chi Wing Wong','Room 334, Laurus Wing, Ursula Hall<br>50 Daley Road, Acton, The Australian National University','Canberra','Australian Capital Territory','AUSTRALIA','2601','0413002975','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 13:14:06',0,NULL,3,1,4,1,'YW868053326CN\r ','crayxxx'),(18402,738261305001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','alb344','alb148@tesco.net','Adele Bossons, Hans Lingl Limited','3rd Ave, Radnor Park Ind Estate<br>Back Lane','Congleton','Cheshire','UNITED KINGDOM','CW12 4UW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 13:21:47',0,NULL,3,0,2,1,' ','alb344\r黑色'),(18403,738268548001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','ginger975bora','borahirsova@yahoo.com.tr','Bora HIRSOVA','Sarayardi Cad. No:92/8<br>Hasanpasa/ Kadikoy','Istanbul','','TURKEY','34722','(90) 216 - 3496126','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 13:41:24',0,NULL,3,1,3,1,'RA184563788CN\r ','ginger975bora'),(18404,738269365001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',5,'AC1301',31.2,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 13:47:18',0,NULL,3,1,3,1,'RA184563730CN\r ','mariomarques.com.br'),(18405,741093149018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',52,'photographyacc','eggyloom','eggyloom@hotmail.com','Egert Lehtla','Tähe 86-1','Tartu','Tartu','ESTONIA','50107','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 15:03:05',0,NULL,3,1,3,1,'RA184563916CN\r ','eggyloom'),(18406,870580219015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','meitydachner','meitydachner2@gmail.com','ari dachner','2 greencroft way','manchester','Greater Manchester','UNITED KINGDOM','m7 2gj','01617089907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-16 15:29:10',0,NULL,3,1,2,1,NULL,'meitydachner'),(18407,738337777001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','muvarem','vakanjac@yahoo.com','Zvonimir Vakanjac','O.Kersovanija 10','Osijek','croatia','CROATIA','31000','++385 99 2175476','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 15:44:26',0,NULL,3,1,2,1,NULL,'muvarem'),(18408,852667468016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','agata12311','surmikovaa@yahoo.com','Agata Surmikova','72 City Road<br>Beeston','Nottingham','Nottinghamshire','UNITED KINGDOM','NG9 2LQ','07928305139','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-16 16:27:09',0,NULL,3,1,4,1,'YW868053411CN\r ','agata12311'),(18409,741154111018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','kirubesh','kirubesh@hotmail.com','KIRUBESHWARAN','30 RETREAT ROAD','COLOMBO','WESTERN','SRI LANKA','00400','+94776521321','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 16:31:13',0,NULL,3,1,2,1,NULL,'kirubesh'),(18410,737473045001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','saintflorian2010','feuerman13121@gmail.com','Aleksandr Piskunov','Metallurgov 11 k.74','Zaporizhya','UA','UKRAINE','69032','380952345543','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 17:06:01',0,NULL,3,1,3,1,'RA184563831CN\r ','saintflorian2010'),(18411,741216812018,280745347210,'Photo Video Continuous light 5 Head E27 AC Bulb Socket with 60x90 Softbox',1,'AD1191',62,'photographyacc','flis8820','sg15@libero.it','Fernando Lisci','via Nazionale, 232','Serrenti','CA','ITALY','09027','3408917977','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 17:36:46',0,NULL,3,1,3,1,'RA184563995CN\r ','flis8820\r欧标'),(18412,780889237002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','ibico1974','kenneth.augdal@gmail.com','Kenneth Augdal','Ishavsvegen 69B','Tromsø','Troms','NORWAY','9010','004741267856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 18:16:53',0,NULL,3,1,3,1,'RA184563690CN\r ','ibico1974'),(18413,780937861002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dlessard_iotm','iotm@rogers.com','Daniel Lessard','2508 Spruce Nedle dr.','mississauga','ON','CANADA','L5L 1M6','(905) 608-1755','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-16 18:29:55',0,NULL,3,0,3,1,'RA184563805CN\r ','dlessard_iotm\rL  已入库'),(18414,870841554015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','crus9100','ck.rushmer@tiscali.co.uk','CLIVE RUSHMER','34 POST OFFICE CLOSE<br>LINGWOOD','NORWICH','Norfolk','UNITED KINGDOM','NR13 4EW','01603715846','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-16 19:18:43',0,NULL,3,1,2,1,NULL,'crus9100'),(18415,780996750002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','il-fede','contatta.federico@email.it','Caprioli Maria','Via Pastrengo 26','Rho','MI','ITALY','20017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 19:36:08',0,NULL,3,1,2,1,NULL,'il-fede\r欧标'),(18416,738559013001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','myfashionspotcom','esales@mistyusa.com','TINDER CO., INC.','9323 Rush St','SOUTH EL MONTE','CA','UNITED STATES','91733-2523','(626) 329-0308','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-16 19:59:28',0,NULL,3,1,1,1,' ','myfashionspotcom'),(18417,781009394002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','cristinastephenscristina','cristina.stephens@gmail.com','cristina stephens','25602 Celtic Terrace dr','Katy','TX','UNITED STATES','77494-5352','(713) 503-4048','NoPaymentFailure','CheckoutComplete','Other','2011-10-16 19:53:05',0,NULL,3,1,3,1,'RA184563519CN\r ','cristinastephenscristina'),(18418,781018440002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 20:05:35',0,NULL,3,1,3,1,'RA184563638CN\r ','dominiquej999\r放布'),(18419,741364656018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','dorgivalalvesmendes','dorgivalalves2@hotmail.com','DORGIVAL ALVES MENDES FILHO','ESTR.CAMPOS DO JORDAO KM101, 4584 BUQUIRINHA','SÃO JOSÉ DOS CAMPOS','SÃO PAULO','BRAZIL','12213-840','551239482591','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 20:13:24',0,NULL,3,1,3,1,'RA184563615CN\r ','dorgivalalvesmendes'),(18420,870945802015,250692239955,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',23,'hutongstore','reuben15','visdarene@aol.com','Ireneo Visda','28 Shirehall Road','Sheffield','South Yorkshire','UNITED KINGDOM','S50GJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-16 21:25:41',0,NULL,3,1,3,1,'RA184563814CN\r ','reuben15'),(18421,741401187018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','soapbox4032','design@soapboxcreative.com.au','Lee Pinwill','54 Redruth Road<br>Alexandra Hills','Brisbane','Queensland','AUSTRALIA','4161','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 21:15:13',0,NULL,3,1,3,1,'RA184563880CN ','soapbox4032'),(18422,852985970016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','anikokovacs13','kovacsaniko13@hotmail.com','Aniko Kovacs Szolcsakne','Flat 3, 5 Cargreen Road South Norwood','Surrey','London','UNITED KINGDOM','SE25 5AD','07511426585','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-16 21:51:38',0,NULL,3,1,4,1,'YW868053293CN\r ','anikokovacs13'),(18423,738621267001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1308',7.8,'hermeshine','rwed19','rwedinger@aol.com','richard wedinger','11 devonshire cot.','middletown','NJ','UNITED STATES','07748','(201) 333-0300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-16 21:59:04',0,NULL,3,1,1,1,NULL,'rwed19'),(18424,781079801002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','umistef','umilianistefano@gmail.com','stefano umiliani','via marza n.47','montegrotto terme','PD','ITALY','35036','049 8910814','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-16 22:00:55',0,NULL,3,1,3,1,'RA184570537CN\r ','umistef'),(18425,797933648017,270777060056,'Studio Continuous Light Kit 23\' SoftBox 4 output 45w x8',1,'AKT039',170,'photographyacc','sistemis','paolo.gargini@gmail.com','Paolo Gargini','Degli Olmetti 18 B1/A','Formello','RM','ITALY','00060','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 22:27:29',0,NULL,5,1,4,1,'YW868053304CN\r ','sistemis\r欧标\r除了c 里面的再发\r独脚架  伟峰 WT-1005    1\r点不了已发货'),(18426,741430516018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','sistemis','paolo.gargini@gmail.com','Paolo Gargini','Degli Olmetti 18 B1/A','Formello','RM','ITALY','00060','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-16 22:27:30',0,NULL,3,1,17,0,NULL,'sistemis'),(18427,853019814016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','bossfunk','anti_chris@hotmail.com','Christopher Dwyer','Jung-ang Middle School, 1st Floor Teacher\'s Room<br>Yeon-dong 323-14','Jeju City','Jeju Special Governing Province','KOREA,REPUBLIC OF','690-815','(010) 960-1197 ext.: 3','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-16 23:08:43',0,NULL,3,1,3,1,'RA184563655CN\r ','bossfunk'),(18428,797958207017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','rutgers_photos','julie@wirf.com.au','Julie rutgers','12 koorana rd<br>mullaloo','perth','Western Australia','AUSTRALIA','6027','0894016236','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-16 23:27:37',0,NULL,3,1,2,1,NULL,'rutgers_photos'),(18429,778292174002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',68.8,'hermeshine','613angel76','jenjen.chicabonita@yahoo.com','jenny thistlethwaite','46<br>pinkwood st.','bellbowrie','Queensland','AUSTRALIA','4070','6132025679','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-16 23:40:03',0,NULL,3,0,4,1,'YW868053271CN\r ','613angel76'),(18430,741465956018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','dirtyrider1963','dirtyrider63@yahoo.com.au','Chris Huddy','9 Ti Tree Cresent','Berowra','New South Wales','AUSTRALIA','2081','0294566221','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 00:08:23',0,NULL,3,1,3,1,'RA184563584CN\r\r ','dirtyrider1963'),(18431,741473964018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',21.5,'photographyacc','katherinevel','info@stylistix.com.au','Katherine  Bowden','2 / 2-6 Koorabel Avenue','Gymea','New South Wales','AUSTRALIA','2227','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-17 00:31:28',0,NULL,3,1,3,1,'RA184563567CN\r ','katherinevel'),(18432,741474665018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','1529sarah','sarahmouatt@hotmail.com','Sarah Mouatt','44 Grosvenor Rd, Lindfield','Sydney','New South Wales','AUSTRALIA','2070','0294165864','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 00:33:21',0,NULL,3,1,2,1,NULL,'1529sarah'),(18433,8881318813830078,111,'58-58 双阳环',1,'AA1212',0,'hermeshine','jesterjeff69','telefragger@comcast.net','Jeffrey Riggs','205 Green Acre Drive','Williamstown','NJ','UNITED STATES','08094','',NULL,NULL,NULL,'2011-10-17 01:10:30',0,NULL,3,0,1,1,NULL,'需要检查 \rLK068818977CN   '),(18434,8881318814907475,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',6,'AE3401',122.94,'aliexpress','1004787801','asmarshkov@gmail.com','Andrey Smarshkov	','Leninsky pr. 93-2-110','Saint-Pitersburg	','','RUSSIAN FEDERATION	','198330','+7 921 7422426',NULL,NULL,NULL,'2011-10-17 01:28:27',0,NULL,3,1,5,1,'CP238090417CN\r ',NULL),(18435,798005339017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','rocksprinkle','sekarvuthyvong@yahoo.com','Monasekar Vuthyvong','21 Wambool Street<br>Bulimba','Brisbane','Queensland','AUSTRALIA','4171','0424771225','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 01:38:31',0,NULL,3,1,2,1,NULL,'rocksprinkle'),(18436,781177635002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',13.98,'hermeshine','ed2222','eddie5262@hotmail.com','Edward W. Abrao','1210 Aldrich Ct NW','Salem','OR','UNITED STATES','97304-2401','(503) 989-9455','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 02:42:55',0,NULL,3,1,1,1,NULL,'ed2222'),(18437,798032173017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','derekd004','derek681@gmail.com','Derek Dadswell','PO Box 5213','Robina Town Centre','Queensland','AUSTRALIA','4230','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-17 02:52:41',0,NULL,3,1,6,1,'EE645715131CN\r ','derekd004\rYW868053282CN'),(18438,781186448002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','isa1976450','isa__1976@hotmail.com','isabelle julien','572 louis-riel','st-lin-laurentides','QC','CANADA','j5m0b7','(450) 439-2076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 03:13:31',0,NULL,3,1,2,1,NULL,'isa1976450'),(18439,741540508018,280680835308,'YongNuo Wireless Studio Flash Camera Trigger CTR-301P',1,'AKT013',25.8,'photographyacc','freshisbest_renee','renee8089@yahoo.com.au','renee diaz','24 Collett AVe','Mount Barker','South Australia','AUSTRALIA','5251','0404128089','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 04:18:42',0,NULL,3,1,3,1,'RA184563955CN\r ','freshisbest_renee'),(18440,738743754001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','xiqu2011','xiqu071764@yahoo.com','Xi Qu','4432 Calle Mar de Armonia','San Diego','CA','UNITED STATES','92130-2680','(858) 245-8309','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 05:03:57',0,NULL,3,1,1,1,NULL,'xiqu2011'),(18441,853160515016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','lorson2011','megalav@gmail.com','Aleksey Liforov','Karla Marksa str. 50, app 19','Nizhny Novgorod','RU','RUSSIAN FEDERATION','603159','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 06:58:42',0,NULL,3,1,2,1,NULL,'lorson2011'),(18442,741578688018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','davidle1980','davidle80@gmail.com','Hai Nguyen','8847 Spectrum Center Blvd<br>Apt 6311','san diego','CA','UNITED STATES','92123-1486','(858) 405-1820','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 07:40:58',0,NULL,3,1,1,1,NULL,'davidle1980'),(18443,741589837018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','rachelc1990','rachel.clark@student.bond.edu.au','Rachel Clark','43 Larch Street','Tallebudgera','Queensland','AUSTRALIA','4228','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 08:28:31',0,NULL,3,1,4,1,'YW868052420CN ','rachelc1990'),(18444,8881318840167291,111,'2m灯架 下面的托x  2',2,'',0,'hermeshine','nativeideas','masterwaki@hotmail.com','Robert Cooper','14 damson place<br>bucklands beach','Auckland','Akl','NEW ZEALAND','2012','2645924',NULL,NULL,NULL,'2011-10-17 08:29:27',0,NULL,3,0,3,1,'RA184569848CN\r ',NULL),(18445,738790530001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','lac2105','vinczuska@gmail.com','Laszlo Vincze','Szolo u 1','Nemesgulacs','','HUNGARY','8284','06703145148','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 08:54:10',0,NULL,3,1,2,1,NULL,'lac2105'),(18446,871182301015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','jpanni1977','btigriss@freemail.hu','Jakab Annamaria','Szocs Aron utca 12-16. IV/405.','Budapest','','HUNGARY','1152','+36209838636','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 09:11:38',0,NULL,3,1,17,0,NULL,'jpanni1977'),(18447,871183442015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','jpanni1977','btigriss@freemail.hu','Jakab Annamaria','Szocs Aron utca 12-16. IV/405.','Budapest','','HUNGARY','1152','+36209838636','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 09:15:04',0,NULL,3,1,5,1,'CP238090315CN ','jpanni1977\r再加2个2m 灯架'),(18448,738797257001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','evocid','alejandro.gonzalez.gonzalez@gmail.com','Alejandro González','Fuenlabrada 57 3ºA','Parla','Madrid','SPAIN','28981','657081812','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 09:22:04',0,NULL,3,1,3,1,'RA184569882CN\r ','evocid'),(18449,741604676018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','pieruccioni','info@pieruccioni.it','Mirko Pieruccioni','via  brancola n.8','lido di camaiore','LU','ITALY','55043','3289628456','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 09:24:13',0,NULL,3,1,2,1,NULL,'pieruccioni'),(18450,871186953015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','chegz11','geoff@lawrencegodfrey.co.uk','Geoff Lawrence','59 Albion Streeet','Rowhedge','Essex','UNITED KINGDOM','CO5 7ER','01206728386','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 09:26:00',0,NULL,3,1,2,1,NULL,'chegz11'),(18451,8881318848574324,111,'40D眼罩',1,'AA1202',0,'photographyacc','josephsondan','josephson.dan@gmail.com','Dan Josephson','Hannasi Shazar 17','Mazkeret Batya','','ISRAEL','76804','',NULL,NULL,NULL,'2011-10-17 10:49:34',0,NULL,3,1,3,1,'RA184569613CN\r ',NULL),(18452,781297177002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',2,'AB1305',7.58,'hermeshine','etuban','ersin@kamyo.net','Ersin Tuban','Bulgurlu Mah., Gurpinar Cad.<br>Masaldan Is Merkezi, G Blok, Kat:3 Uskudar','ISTANBUL','','TURKEY','34696','+905323937944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 11:24:07',0,NULL,3,1,2,1,NULL,'etuban'),(18453,798170068017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','zexzus','zexz@xairo.com','Dmitri Mosco','sos. Muncesti 176, ap 90','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','2002','+373 68636301','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 12:03:13',0,NULL,3,0,2,1,NULL,'zexzus'),(18454,781312652002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','mephotographer','mephotographer1@yahoo.com','Jeff Robey','307 N Broad St','lancaster','OH','UNITED STATES','43130-3004','(740) 654-6527','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 12:15:09',0,NULL,3,1,17,0,NULL,'mephotographer'),(18455,781314387002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','mephotographer','mephotographer1@yahoo.com','Jeff Robey','307 N Broad St','lancaster','OH','UNITED STATES','43130-3004','(740) 654-6527','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-17 12:21:15',0,NULL,3,1,1,1,NULL,'mephotographer\r绿叶 CPL 72mm    1\r绿叶 CPL  67mm     1'),(18456,781316290002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','dai_fabio_dai','fabioborra@alice.it','Fabio Borra','via sabin<br>24','Cattolica','RN','ITALY','47841','3334772527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:26:06',0,NULL,3,1,17,0,NULL,'dai_fabio_dai'),(18457,781316906002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','dai_fabio_dai','fabioborra@alice.it','Fabio Borra','via sabin<br>24','Cattolica','RN','ITALY','47841','3334772527','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:28:20',0,NULL,3,1,3,1,'RA184569701CN\r ','dai_fabio_dai\r2b柔   1\r1.6x 3m 黑色   1\r看看有没有超2kg\r\rlighting kit $18'),(18458,781318801002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','stevicam','stevica@gmail.com','Loza Picuric','Bul. Zorana Djindjica 199<br>Apt 16','New Belgrade','Serbia','SERBIA','11070','+38163223884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 12:36:39',0,NULL,3,1,3,1,'RA184569635CN\r ','stevicam'),(18459,738855439001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','juspremrov','jus.premrov@gmail.com','Jus Premrov','Stefanova 9','Ljubljana','','SLOVENIA','1000','(00386) 41229797','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-17 12:50:04',0,NULL,3,1,3,1,'RA184569644CN\r ','juspremrov'),(18460,741670850018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','harrywalter2011','fotoharry@live.no','Harry Johansson','Poul Rønnsgt 10','Gml Fredrikstad','Fredrikstad','NORWAY','1636','45807800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 13:01:01',0,NULL,3,1,5,1,'CP238090329CN ','harrywalter2011'),(18461,871295647015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','csigangfan2001','apaterson@wightcablenorth.net','alan paterson','20 longrow gardens lawthorn<br>Irvine','Ayrshire','North Ayrshire','UNITED KINGDOM','ka11 2dp','01294235185','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-17 14:08:43',0,NULL,3,1,3,1,'RA184570815CN ','csigangfan2001\r接口环式67mm的\r已入库'),(18462,8881318861140623,111,'一堆东西',1,'',0,'photographyacc','riccardo-ugo','riccardougo@yahoo.it','Rimoldi Ugo','Piazza del Filatoio','Orsenigo','CO','ITALY','22030','348-3583121',NULL,NULL,NULL,'2011-10-17 14:19:00',0,NULL,3,0,12,1,'1107476440\r','Lenspen   1\rcanon logo 中号内胆包 1\r灯架包  薄的， 长的    1\r大沙袋     1\r717 快装板   3\r717AH    2\r已入库\r泡重3.88 实重3.55\r110CM 5IN1  反光板   1 单发 国内小包挂号\rRA184570090CN\r最终计费 4\r\r \r\r'),(18464,8881318861909969,111,'45w 220v   1',1,'',0,'photographyacc','vincent6306','vobernardin@aim.com','Vincent Bernardin VIAPASS','105, Boulevard de la Republique','Cannes','Alpes Maritimes','FRANCE','06400','',NULL,NULL,NULL,'2011-10-17 14:31:49',0,NULL,3,1,17,0,NULL,'已入库 '),(18463,781355730002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','bencejoe','bencejoe@yahoo.com','Gerry  Tracey','18 HILLVIEW AVE<br>PREHEN','LONDONDERRY','Londonderry','UNITED KINGDOM','BT472NU','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 14:22:04',0,NULL,3,1,2,1,NULL,'bencejoe'),(18465,8881318862746478,111,'6160H   球台   1',1,'',0,'hermeshine','cofredeltesoro1984','cofredeltesoro@hotmail.es','Angel Viana Sosa','Colegio Naval Sacramento 3 3º A','San Fernando','Andalucía Ceuta y Melilla','SPAIN','11100','686615883',NULL,NULL,NULL,'2011-10-17 14:45:46',0,NULL,3,1,3,1,'RA184569851CN\r ',NULL),(18466,798230942017,270822547911,'4 pcs Lens Pouch s:70mm x 100mm m:85mm x 150mm l:90mm x 180mm xl:95mm x 230mm',1,'AKT086',18.5,'photographyacc','vincent6306','vobernardin@aim.com','Vincent Bernardin VIAPASS','105, Boulevard de la Republique','Cannes','Alpes Maritimes','FRANCE','06400','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 14:52:41',0,NULL,3,1,3,1,'RA184569896CN\r ','vincent6306\rc里的4个镜头筒\r+ 45w 220v 灯泡    1\r'),(18467,738625945001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','shelbello4','sspan006@odu.edu','Shelley Spangler','5828 Longbow Ln','New Kent','VA','UNITED STATES','23124-2968','(804) 356-1804','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-17 14:57:04',0,NULL,3,0,1,1,NULL,'shelbello4\r黄色  '),(18468,781375431002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','justwait982011','justwait98@yahoo.com.tw','文彬 林','新北市三重區中正北路276巷1號','default','','TAIWAN','24162','0910999181','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 15:18:55',0,NULL,3,1,12,1,'1107476436\r ','justwait982011\r110V\r实重  12.15  泡重13.98\rjustwait982011\rNo.1, Ln. 276, Zhongzheng N. Rd., \rSanchong Dist., \rNew Taipei City\r24162, \rTaiwan (R.O.C.)\r+886910999181\r最终计费 13.5\r'),(18469,741732538018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','reanimation_sergey','reanimation.c@gmail.com','Sergey Rufanov','ul. Baltiyskaya  d.29, kv.56','Petrozavodsk','Karelia','RUSSIAN FEDERATION','185026','89602100354','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 15:43:57',0,NULL,3,1,2,1,NULL,'reanimation_sergey'),(18470,853396664016,260814164713,'QR Quick Release Plate For Fancier FT-6663A Head 6160H',1,'AB1203',4.85,'hutongstore','comtezero2010','kata.neuro@gmail.com','Emmanuel Faure','9 Allée des tulipiers<br>La Pascale','Les Tourrettes','Rhône-Alpes','FRANCE','26740','0611440125','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-17 16:48:21',0,NULL,3,1,2,1,NULL,'comtezero2010'),(18471,575598926003,130494881082,' IR Remote Control for Nikon D80 D5000 D90  ',1,'AA2201',3.5,'hermeshine','daedalusxxi','daedalusxxi@gmail.com','Emilio Gómez Lázaro','C Cuatro Vientos 47','Albacete','Castilla-La Mancha','SPAIN','02006','687889881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:05:44',0,NULL,3,1,17,0,NULL,'daedalusxxi'),(18472,741767698018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',62,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 17:06:19',0,NULL,3,1,17,0,NULL,'ddt251'),(18473,781428255002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','bassajbdude','alastair_jb@hotmail.co.uk','Ali Jerome-Ball','39 Braybrooke Road<br>Wargrave','Reading','Berkshire','UNITED KINGDOM','Rg10 8DU','01189403035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:14:34',0,NULL,3,1,2,1,NULL,'bassajbdude'),(18474,741777557018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 17:19:10',0,NULL,3,1,17,0,NULL,'ddt251'),(18475,781431212002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','tm360titakashi','t-saka@mtg.biglobe.ne.jp','TAKASHI SAKAMOTO','Tnnouzu Veiw Tower #2107<br>Higashi-Shinagawa 2-5-6','Shinagawa-ku','Tokyo','JAPAN','#140-0002','+81-90-1387-6244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:20:38',0,NULL,3,1,3,1,'RA184569675CN\r ','tm360titakashi'),(18476,798301108017,270750652394,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200 ',1,'AC1204',7.99,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 17:21:53',0,NULL,3,1,17,0,NULL,'ddt251'),(18477,735657056001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','daedalusxxi','daedalusxxi@gmail.com','Emilio Gómez Lázaro','C Cuatro Vientos 47','Albacete','Castilla-La Mancha','SPAIN','02006','687889881','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 17:05:43',0,NULL,3,1,4,1,'YW868052431CN ','daedalusxxi\r爵影红外 nikon     1\r三脚架 伟峰 WF-6663A     1'),(18478,741780607018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 17:25:08',0,NULL,3,1,4,1,'YW868052442CN ','ddt251\r2mx1.5m 背景板（黑，白）    1\r小号内胆包 Nikon     1\r镜头筒 xl 大号    1\r大号内胆包 无字     1'),(18479,741784664018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','sibirjak72','lencom98@yahoo.de','Leonid Frank','Siriusweg31','Bad Oeynhausen','','GERMANY','32549','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-17 17:32:37',0,NULL,3,1,3,1,'RA184569658CN\r ','sibirjak72\r已入库'),(18480,871423982015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','davebulow','dave@davebulow.com','David Bulow-Osborne','Brenor, Church Hill<br>Burstall','Ipswich','Suffolk','UNITED KINGDOM','IP8 3DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-17 18:00:05',0,NULL,3,1,3,1,'RA184569627CN\r ','davebulow'),(18481,781478048002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','trackermikel','michelc60@hotmail.com','Michel Cyr','10 Place de la Bourgade','Chateauguay','QC','CANADA','J6K4Z5','(450) 691-9834','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-17 18:41:24',0,NULL,3,0,3,1,'RA184569560CN\r ','trackermikel\rL   已入库'),(18482,739036745001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','jsch29185','jessica.schuster@hotmail.com','Jessica Schuster','5 Taunus Court','Bowmanville','ON','CANADA','L1C4H5','(905) 623-5324','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-17 19:35:01',0,NULL,3,1,2,1,NULL,'jsch29185'),(18483,739036661001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','demon-ace','demonase@yandex.ru','Dmitry Aseev','Zeleniy prospekt, dom 40, korpus 2, kvartira 136','Moscow','','RUSSIAN FEDERATION','111396','+7-905-735-3407','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-17 19:38:13',0,NULL,3,1,3,1,'RA184569750CN\r ','demon-ace'),(18484,739038744001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','thiagocontemplare','thiagomail2@gmail.com','Thiago Monteiro','Rua Mato Grosso, 1265 - 201<br>Santo Agostinho','Belo Horizonte','MG','BRAZIL','30190-081','(31) 3337-1794','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 19:41:02',0,NULL,3,1,5,1,'CP238090332CN ','thiagocontemplare'),(18485,781552475002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'',85,'hermeshine','nadinamif','nadina_@msn.com','Nadine Mifsud','Misty Meadows<br>Danny Cremona Street','Kirkop','','MALTA','KKP 1701','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-17 20:55:18',0,NULL,3,1,3,1,'RA184570126CN\r ','nadinamif\rRA184570069CN\r'),(18486,737553188001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',2,'AA1211',5.98,'hermeshine','olezganych','megazoom@bigmir.net','Fartushko Oleg','Gv. Shironintsev 49<br>Kv. 165','Kharkov','','UKRAINE','61170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 21:13:02',0,NULL,3,1,2,1,NULL,'olezganych'),(18487,781579200002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','844-223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 21:59:21',0,NULL,3,1,3,1,'RA184569905CN\r ','denisdryashkin\r欧标'),(18488,739120112001,110731646314,'New 200w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT078',108,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 22:56:12',0,NULL,5,0,18,0,NULL,'ravirep1'),(18489,781597304002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-17 22:58:34',0,NULL,3,0,17,0,NULL,'ravirep1'),(18490,871612752015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','bocsijanos','iringo0426@yahoo.com','János Bócsi (Marika Csemege)','Szent István str. 6.','Nyírtelek','Szabolcs-Szatmár-Bereg','HUNGARY','H-4461','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-17 23:08:32',0,NULL,3,1,17,0,NULL,'bocsijanos'),(18491,853628505016,260677473285,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',5.9,'hutongstore','bocsijanos','iringo0426@yahoo.com','János Bócsi (Marika Csemege)','Szent István str. 6.','Nyírtelek','Szabolcs-Szatmár-Bereg','HUNGARY','H-4461','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-17 23:10:10',0,NULL,3,1,3,1,'RA184569834CN\r ','bocsijanos\r大力夹   1\r2B柔     1'),(18492,798498613017,270833010437,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','cheapsk8ing','dhuynhco@gmail.com','Denny Huynh','17-23 Nissan Dr.','Dandenong','Victoria','AUSTRALIA','3175','0422109102','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-17 23:51:30',0,NULL,3,1,2,1,NULL,'cheapsk8ing'),(18493,853654292016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','sharon21040','svincentgallagher@hotmail.co.uk','sharon gallagher','22 Killybearn Road','Cookstown','Tyrone','UNITED KINGDOM','bt80 8sz','02886757313','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 00:31:22',0,NULL,3,1,2,1,NULL,'sharon21040'),(18494,739147717001,110756717212,'New Twin Flash Bracket for Nikon  D700  SB900 SB800 Canon 7D 5DII  580EX C-Shape',1,'AD1193',18.99,'hermeshine','charrua65','dongamboa@gmail.com','Fernando Gamboa','33 Wyong Street','Oatley','New South Wales','AUSTRALIA','2223','0295944725','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-18 00:53:01',0,NULL,3,1,3,1,'RA184569817CN\r ','charrua65'),(18495,8881318901237365,111,'canon 棒球帽',1,'AD1189',0,'photographyacc','canon7dpeter','pstepien@aol.com','Peter Stepien','77 Sterling St','Worcester','MA','UNITED STATES','01610-2144','(508) 755-7261',NULL,NULL,NULL,'2011-10-18 01:27:17',0,NULL,3,1,1,1,NULL,' LK078551774CN '),(18496,798516100017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','colasli7','colasli@gmail.com','Nicolas Li','PO BOX 4566<br>Robina Town Centre','Robina','Queensland','AUSTRALIA','4230','0412713068','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 01:43:51',0,NULL,3,1,17,0,NULL,'colasli7'),(18497,741996390018,280719730281,'New Flash Umbrella Holder Mount aluminum metal N',1,'AD1167',16,'photographyacc','colasli7','colasli@gmail.com','Nicolas Li','PO BOX 4566<br>Robina Town Centre','Robina','Queensland','AUSTRALIA','4230','0412713068','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 01:43:52',0,NULL,3,1,2,1,NULL,'colasli7\r柔光伞110cm     1\r铝合金灯座（N）   1'),(18498,8881318902347128,111,'AKT085',1,'AKT085',0,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','',NULL,NULL,NULL,'2011-10-18 01:45:47',0,NULL,3,1,4,1,'YW867739995CN ','C里的东西再加上\r1.6x3m 背景布 白色 \rDC影闪器    1'),(18499,741999335018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',1,'AE2316',12.9,'photographyacc','brenny2011','sharbren@westnet.com.au','Mr Brendan W Howes','Unit 2 / 5 Wight Street','Kensington','Victoria','AUSTRALIA','3031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 01:53:59',0,NULL,3,1,2,1,NULL,'brenny2011'),(18500,8881318903994922,111,'3m伸缩横杆里的2个螺丝',1,'',0,'hutongstore','p.i.k','paulow80@gmail.com','Pawel Wozniak','707 Glashaus Apartments<br>Belgard Square, Tallaght','Dublin','24','IRELAND','24','',NULL,NULL,NULL,'2011-10-18 02:13:14',0,NULL,3,1,3,1,'RA184570157CN\r ',NULL),(18501,739173404001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','udjus','lopatinna@gmail.com','Nikita Lopatin','Khantayskaya 19 - 64','Norilsk','RU','RUSSIAN FEDERATION','663319','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 02:18:01',0,NULL,3,1,2,1,NULL,'udjus'),(18502,739181767001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','terrymac17','terrymac17@hotmail.com','Terry McEachern','208 Forest Ave','Rockville','MD','UNITED STATES','20850-1819','(949) 933-2351','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-18 02:49:23',0,NULL,3,1,3,1,'RA184569803CN\r ','terrymac17'),(18507,8881318920374937,111,'1600W KIT + 斜臂 x 2',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-10-18 06:46:14',0,NULL,3,1,12,1,'1107477652\r ','灯泡是110v\rc里的再加上2个斜臂 \r实重7.6  泡重9.6\r最终计费 9.5'),(18503,781689787002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','jiri5718','jaravul@hotmail.com','Jiri Fintes','12 Columbia court','Deer Park','Victoria','AUSTRALIA','3023','0418310686','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 05:05:41',0,NULL,3,1,2,1,NULL,'jiri5718'),(18504,739208464001,110469599855,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',17.98,'hermeshine','danny1280','dare_devil_dc1413@hotmail.com','Daniel Schuller','128 ivanhoe parade<br>Ivanhoe','Melbourne','Victoria','AUSTRALIA','3079','610411105096','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 05:38:33',0,NULL,3,1,11,1,NULL,'danny1280'),(18505,739215962001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','frankkarlsen','fraka113@gmail.com','Frank Karlsen','Bønesheien 226','default','Bønes','NORWAY','5154','+4795940054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 05:55:12',0,NULL,3,1,3,1,'RA184570143CN\r ','frankkarlsen'),(18506,738855508001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','beavispits','scott.beavis@btinternet.com','Scott Beavis','Capital Capture, Churchill House<br>142-146 Old Street','London','London','UNITED KINGDOM','EC1V 9BW','07909873137','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2011-10-18 06:04:00',0,NULL,3,1,2,1,NULL,'beavispits'),(18508,8881318920522904,111,'5个内胆包',1,'',0,'hermeshine','alesabha','alucha78@hotmail.com','Maria Alejandra Sabha','Junin 605 <br>7mo piso  -  Dpto. \"A\"','San Miguel de Tucuman','Tucuman','ARGENTINA','4000','0381-4211063',NULL,NULL,NULL,'2011-10-18 06:48:42',0,NULL,3,0,3,1,'RA184570072CN\r ','新款内胆包 M  Nikon     2 \r新款内胆包 S  Nikon     3\r已入库'),(18509,739228716001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','randall9433','randy_turner21@yahoo.com','Randall Turner','4925 Signature Dr<br>Apt 201','Myrtle Beach','SC','UNITED STATES','29579-0996','(304) 654-6214','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-18 07:07:29',0,NULL,3,1,1,1,NULL,'randall9433'),(18510,739229482001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:11:59',0,NULL,3,1,3,1,'RA184570205CN\r ','icreates_meenu'),(18511,739230667001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','bidcom2k','ebayguy2k@yahoo.ca','ricky chan','2 ravengloss dr.','thornhill','ON','CANADA','l3t4c9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:17:13',0,NULL,3,1,2,1,NULL,'bidcom2k'),(18512,739231147001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','jordi_bv','jbarredo@axisestudio.com','Jordi Barredo Vegas','Calle Dalmases 42 Bajos<br>Area Oftalmologica Avanzada','Barcelona','Cataluña','SPAIN','08017','605044177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:20:06',0,NULL,3,1,3,1,'RA184570086CN\r ','jordi_bv'),(18513,780233151002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','sybnios','synbios1982@yahoo.com','Chris Makridis','Andromaxis 192','Athens','Kallithea','GREECE','17674','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-18 07:25:09',0,NULL,3,1,3,1,'RA184570112CN\r ','sybnios'),(18514,781720780002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','professionista','margiottaalessandro@yahoo.it','Alessandro Margiotta','via sant\'anna n°86','Vernole','LE','ITALY','73029','0832891143','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:52:04',0,NULL,3,1,3,1,'RA184570130CN\r ','professionista'),(18515,8881318925148985,111,'新款内胆包 小号 nikon',1,'AD1171',0,'aliexpress',' kristoffersen202  ','verkrist@hotmail.com','Veronica Kristoffersen','Torvmarkene 30','Bergen Strusshamn','','NORWAY','5302','',NULL,NULL,NULL,'2011-10-18 08:05:48',0,NULL,5,1,18,0,NULL,NULL),(18516,781726126002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','oren1975','oren@cigarmag.co.il','Oren Kfir','4th Hasahlav','Raanana','Israel','ISRAEL','43394','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:17:06',0,NULL,3,1,3,1,'RA184570188CN\r ','oren1975'),(18517,798620425017,270747044999,'New 72mm Snap-on Front Lens Cap for Nikon 72 mm lenscap',1,'AA1308',2.5,'photographyacc','trace_w','trace.mckeown@gmail.com','Tracey McKeown','40 Howitt Ave','Bairnsdale','Victoria','AUSTRALIA','3875','0351532716','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 08:22:24',0,NULL,3,1,2,1,NULL,'trace_w'),(18518,781720604002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','kristoffersen202','verkrist@hotmail.com','Veronica Kristoffersen','Torvmarkene 30','Bergen','Strusshamn','NORWAY','5302','+47 93417825','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 07:52:07',0,NULL,3,1,2,1,NULL,'kristoffersen202'),(18519,739242359001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',2,'AC1202',10.8,'hermeshine','bopps2006','nadinejoh@hotmail.com','Nadine johnson','6/10 Moore Street','Somerton park','South Australia','AUSTRALIA','5044','0883761816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 08:14:34',0,NULL,3,1,2,1,NULL,'bopps2006'),(18520,739253085001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','rus.mukhamedov','predictor@yandex.ru','Ruslan Mukhamedov','ul. KARLA ILMERA, 1/88','Tomsk','','RUSSIAN FEDERATION','634057','79069592369','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 09:03:26',0,NULL,3,0,2,1,NULL,'rus.mukhamedov\r灰色'),(18521,871783886015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','aredjazzone','normanmail@btinternet.com','Norman Reid','37 Lindfield Road','Ealing','London','UNITED KINGDOM','W51QS','02082489084','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 09:18:02',0,NULL,3,1,3,1,'RA184570174CN\r ','aredjazzone'),(18522,781744987002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','aleultraz','ultrazappy@gmail.com','alex zappaterra','via bologna 1259','montalbano','FE','ITALY','44124','3934287060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 09:37:18',0,NULL,3,1,3,1,'RA184570333CN ','aleultraz'),(18523,798647833017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','80evad','davidbongers@amnet.net.au','David Bongers','45 Henry St','East Cannington','Western Australia','AUSTRALIA','6107','0893562419','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 10:04:20',0,NULL,3,1,2,1,NULL,'80evad'),(18524,739273099001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',5,'AA1211',14.95,'hermeshine','sensemusic','ekkischaedel@aol.com','Ekki Schädel','Bellealliancestr. 56','Hamburg','','GERMANY','20259','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 10:22:38',0,NULL,3,1,3,1,'RA184570276CN ','sensemusic'),(18525,781763554002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','onurkaan32','gungor928@hotmail.com','GÖKHAN GÜNGÖR','Club Magic Life Belek İmperial Hotel<br>(Doctor Office) İlerıbası mevkıı  Belek-SERIK','ANTALYA','','TURKEY','07500','00905307879736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 10:44:48',0,NULL,3,1,2,1,NULL,'onurkaan32'),(18526,781768062002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','qualitefrancaise','maponline@gmail.com','ALVAREZ-PEREYRE Michael and Lea','Shimoni 30b<br>(Apt. #2)','Jerusalem','','ISRAEL','92623','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 11:00:02',0,NULL,3,1,3,1,'RA184570320CN ','qualitefrancaise'),(18527,739296087001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','photo-orel','photoplus-orel@rambler.ru','Alexey Melkov','Priborostroitelnaya st. 55-24','Orel','','RUSSIAN FEDERATION','302020','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-18 11:46:05',0,NULL,3,1,5,1,'CP238090301CN ','photo-orel'),(18528,871845270015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','brano_m13','branom13@gmail.com','Brano Meres - BME Design s.r.o.','Lipova 4','Tlmace','','SLOVAK REPUBLIC','93521','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-18 12:12:35',0,NULL,3,1,3,1,'RA184570347CN ','brano_m13'),(18529,781808561002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','crizm76','crizmmm@yahoo.com.au','Chris Mercado','193 Popondetta Rd','Blackett','New South Wales','AUSTRALIA','2770','0424292499','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 13:11:06',0,NULL,3,1,2,1,NULL,'crizm76'),(18530,739326032001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',6,'AC2301',37.26,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 13:24:38',0,NULL,3,1,3,1,'RA184570280CN ','mariomarques.com.br'),(18531,853888751016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','eggyloom','egert.lehtla@gmail.com','Egert Lehtla','Tähe 86-1','Tartu','Tartu','ESTONIA','50107','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-18 13:25:06',0,NULL,3,1,2,1,NULL,'eggyloom'),(18532,853897454016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','xulanas','ricardoisaa@gmail.com','ricardo isaá','rua maria fernanda toscano rico, nº 30','portel','portel','PORTUGAL','7220','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 13:45:34',0,NULL,3,1,2,1,NULL,'xulanas'),(18533,871885161015,250600315208,'Flash Softbox Diffuser for external flash SB800 580EX ',1,'AB3302',8.8,'hutongstore','tim_warnock','timwarnock0033@live.com','tim warnock','81 miller street','chermside','Queensland','AUSTRALIA','4032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 13:54:01',0,NULL,3,1,17,0,NULL,'tim_warnock'),(18534,871883811015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.96,'hutongstore','tim_warnock','timwarnock0033@live.com','tim warnock','81 miller street','chermside','Queensland','AUSTRALIA','4032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 13:54:01',0,NULL,3,1,2,1,NULL,'tim_warnock\rNG200 柔光罩     1\r3片装的滤镜袋     2'),(18535,781838842002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','alcon11','albertnever@yahoo.it','Piccin Alberto','via della Calle, 4','Vallà','TV','ITALY','31030','328 8249736','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-18 14:41:00',0,NULL,3,1,3,1,'RA184570355CN ','alcon11\r本身是英标  放英标转欧标'),(18536,734346484001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','x0mandiy','mandiy@live.ca','Amanda Blackport','208-380 Adelaide Street N','London','ON','CANADA','N6B3P6','(226) 235-4523 ext.: 2262347832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 14:46:05',0,NULL,3,0,2,1,NULL,'x0mandiy\r黑色'),(18537,739372371001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.1,'hermeshine','ngut1462','angel.gj@ono.com','angel gutierrez jenaro','c/ La Gloria 70  5º-A','Santander','Cantabria','SPAIN','39012','657652996','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 15:35:34',0,NULL,3,1,2,1,NULL,'ngut1462'),(18538,739377090001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','kisjassy2','mr.andris@freemail.hu','Kis András','Dobó Katica u. 2.','Budapest','Budapest','HUNGARY','1191','0036205220638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 15:48:38',0,NULL,3,1,2,1,NULL,'kisjassy2'),(18539,781882949002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','rphoto11','ishrod@gmail.com','Ishai Rodríguez Rodríguez','C/ Lugo y Herrera Nº8, Bajo 7, La Laguna, Santa Cruz de Tenerife','La Laguna','Canarias','SPAIN','38320','651117974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 16:31:38',0,NULL,3,1,2,1,NULL,'rphoto11\r欧标'),(18540,853976922016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','puchok0846','puchok0846@mail.ru','Alexey Matveev','9/1 Tsiolkovskogo str., appt 27','Tyumen','','RUSSIAN FEDERATION','625002','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 16:32:26',0,NULL,3,1,3,1,'RA184570395CN ','puchok0846\r地址里加电话：\r+79222653113'),(18541,739391143001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','bigtoefootball','rodt187@yahoo.com','Rodney s Thomas','3919 Guildford Ln','Williamsburg','Va','UNITED STATES','23188-6629','','NoPaymentFailure','CheckoutComplete','Other','2011-10-18 16:35:53',0,NULL,3,0,1,1,NULL,'bigtoefootball\rXXL  已入库'),(18542,872011312015,250848949434,'600w lighting kit with 3mx6m backdrop & 2mx3m support ',1,'AKT037',130,'hutongstore','supermattocks','mattocks75@hotmail.com','Brian Mattocks','Gröna gatan 14A','Sodertalje','Sthlm','SWEDEN','15132','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-18 17:50:20',0,NULL,3,1,4,1,'YW868053190CN ','supermattocks\r欧标\r发信问客户换自己组的那个背景架可以吗 需要改模版'),(18543,781923750002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tamir-bisan','tmer_d300@hotmail.com','tamir bisan','no street address<br>Mailbox 7 - Postal code : 25251','jatt Galilee Village','israel','ISRAEL','25251','050-9804-223','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 17:55:36',0,NULL,3,1,3,1,'RA184570404CN ','tamir-bisan'),(18544,872051032015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','gatopatato','germanando@hotmail.com','Germán Antón Dopazo','C/ San Leandro 21 Bajo','Alicante','Comunidad Valenciana','SPAIN','03004','607319268','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 18:46:45',0,NULL,3,1,4,1,'YW868053245CN ','gatopatato\r白布'),(18545,739460013001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','rbrt6000','signrite@bellnet.ca','Robert Lozier','21 Hart Road','Elliot Lake','ON','CANADA','P5A1P7','(705) 461-1204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 18:47:52',0,NULL,3,1,2,1,NULL,'rbrt6000'),(18546,781963079002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','saphotoatthebeach','sebastien@saphoto.ca','SAphoto','12 Beech Avenue','Toronto','ON','CANADA','M4E 3H2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 19:04:20',0,NULL,3,1,2,1,NULL,'saphotoatthebeach'),(18547,739485397001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','elinmaxterri','elin.k.tvete@live.no','Elin Tvete','Nordre Toppen 3','Fredrikstad','Østfold','NORWAY','1615','69310280','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 19:26:25',0,NULL,3,1,2,1,NULL,'elinmaxterri'),(18548,739489010001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',3,'AA1201',7.44,'hermeshine','guromo2010','g-mom@online.no','Guro Momrak','Holteveien 1 D','1580 Rygge','Rygge','NORWAY','1580','+47 93461023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 19:34:29',0,NULL,3,1,2,1,NULL,'guromo2010'),(18549,781983478002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',65,'hermeshine','billywhizz0_2','wqmcc@hotmail.com','Billy McCullins','5 Parkland Drive','Lisburn','Co Antrim','UNITED KINGDOM','BT28 3JR','07711853335','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-18 19:40:53',0,NULL,3,1,3,1,'RA184570259CN ','billywhizz0_2\rL'),(18550,739511711001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','replay_111','replay_111@hotmail.com','Jesse Dang','7415 40 Av','Edmonton','AB','CANADA','T6K 0W8','(780) 490-1279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 20:16:47',0,NULL,3,1,2,1,NULL,'replay_111'),(18551,854156924016,260814164713,'QR Quick Release Plate For Fancier FT-6663A Head 6160H',1,'AB1203',4.85,'hutongstore','ceballut_1983','paulino56@telefonica.net','PAULINO MARTIN LORENZO','CALLE ROCA, 27 BAJOS 2ª','SABADELL','Cataluña','SPAIN','08208','669683638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-18 21:09:30',0,NULL,3,1,2,1,NULL,'ceballut_1983'),(18552,872149623015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','manutdred1968','trevor.chapman1962@gmail.com','Trevor Chapman','19 Westmoreland Street','DARLINGTON','Durham','UNITED KINGDOM','DL30NX','01325489338','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-18 21:11:44',0,NULL,3,1,2,1,NULL,'manutdred1968'),(18553,739543372001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','fuzzioniam','mojobiri@gmail.com','Denis Kostromitskiy','ul. Dm. Ulyanova, dom 34 kv. 21','Simferopol','Crimea','UKRAINE','95013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 21:25:36',0,NULL,3,1,2,1,NULL,'fuzzioniam'),(18554,742439735018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','pashada22','pashada2@gmail.com','Pavel Davydov Sergeevich','Akademgorodok 12 -52','Krasnoyarsk Krasnoyarsky Kray 660036','','RUSSIAN FEDERATION','660036','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-18 23:14:29',0,NULL,3,1,2,1,NULL,'pashada22'),(18555,739573528001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','11ron1960','ron.vdbosch@live.nl','Ron van den Bosch','Purmerweg 26','Amsterdam','','NETHERLANDS','1023BA','06-54207805','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-18 23:29:10',0,NULL,3,1,2,1,NULL,'11ron1960'),(18556,742445791018,280680835308,'YongNuo Wireless Studio Flash Camera Trigger CTR-301P',1,'AKT013',25.8,'photographyacc','freshisbest_renee','renee8089@yahoo.com.au','Tiffany Selzer','7 Collett AVe','Mount Barker','South Australia','AUSTRALIA','5251','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 23:35:56',0,NULL,3,1,3,1,'RA184570262CN ','freshisbest_renee'),(18557,742448354018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','smalltimejackson','grevzin@hotmail.com','Gennady Revzin','6/61 Ormond Road','Elwood','Victoria','AUSTRALIA','3184','0399390730','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 23:45:12',0,NULL,3,1,2,1,NULL,'smalltimejackson'),(18558,742452040018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','sausage_1','debral@iprimus.com.au','John Baxter','3 Ingram Street','Wyong','New South Wales','AUSTRALIA','2259','02407435699','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-18 23:57:29',0,NULL,3,1,3,1,'RA184570316CN ','sausage_1\r1000'),(18559,782109028002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','jz1515','jz3@comcast.net','Amtek Tool','535 E 10 Mile Rd<br>Attn: Jon Zmudka','Madison Heights','MI','UNITED STATES','48071','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 01:14:12',0,NULL,3,1,1,1,NULL,'jz1515'),(18560,739632619001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','zdiddy2003','zepher.p@gmail.com','Zepher Potrafka','1527 Berkhard Dr','Columbus','OH','UNITED STATES','43223-3388','(757) 593-3396','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 02:34:21',0,NULL,3,1,1,1,NULL,'zdiddy2003'),(18561,854310735016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','qsh-off','shkalar@tut.by','Aleh Krautsou','1 Vokzal\'niy pereulok 14a','Buda-Koshelevo','Gomel\'skaya','BELARUS','247350','+375259727843','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-19 04:26:26',0,NULL,3,1,3,1,'RA184570523CN ','qsh-off\r申报$20  Background board '),(18562,739658421001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','bkharabe','bhushan.kharabe@gmail.com','Bhushan Kharabe','2311 willow dr','Ocean','NJ','UNITED STATES','07712','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 04:37:52',0,NULL,3,1,1,1,NULL,'bkharabe'),(18564,8881319003432496,111,'肩架配件',1,'',0,'hermeshine','laheradehielo','cbhera33@yahoo.ca','Arturo Hernandez','2313 Islington Ave Apt 112','Etobicoke','ON','CANADA','M9W3X1','',NULL,NULL,NULL,'2011-10-19 05:50:32',0,NULL,3,0,3,1,'RA184570510CN ','在101 '),(18563,854315955016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','andonigruevski','deepandblue9@gmail.com','andoni gruevski','marrbella 20 piso 2 puerta 209','palma del mallorca','Baleares','SPAIN','07610','608246136','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 04:51:03',0,NULL,3,1,4,1,'YW868053234CN\r ','andonigruevski'),(18565,782193952002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','gulbrandtang','gulbrand.tangen@c2i.net','Gulbrand Tangen','Brennivegen 45','Algarheim','','NORWAY','2056','+4763976867','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 07:39:52',0,NULL,3,0,3,1,'RA184570611CN ','gulbrandtang'),(18566,742559836018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',14,'AD1169',89.6,'photographyacc','torview04','dominodesign@optusnet.com.au','Colin Trethewey','11 Torview Street,<br>Rochedale South,','Brisbane.','Queensland','AUSTRALIA','4123','0734110380','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 07:42:18',0,NULL,3,1,3,1,'RA184570761CN\r ','torview04'),(18567,8881319011759971,111,'一堆东西',1,'',250,'hutongstore','chpetris','antikgr@yahoo.gr','Kiriakos Chatzipetris','EPIMENIDOU 22','HERAKLION/KRETA','','GREECE','71202','',NULL,NULL,NULL,'2011-10-19 08:09:19',0,NULL,3,0,4,1,'YW868052464CN ','2mx3m 背景架    1\r3mx6m 白色 背景布   1\r3mx6m 绿色 背景布   1\r 2m灯架   2\r双灯头 英标    2\r反光伞   2\r柔光伞   2\r45w 220v    4\r包   1\r58mm 橡胶罩   1\r闪光灯D座      2\r60cm 闪光灯棚    2\r100-150 5in1 反光板   1\r未入库\r\r\r\r\r\r'),(18568,782209878002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','kool-koala-bear','beautifulphotos@gmx.net','Tanja Rankin','114 Weller Street','Geelong West','Victoria','AUSTRALIA','3218','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 08:52:28',0,NULL,3,1,2,1,NULL,'kool-koala-bear'),(18569,739719936001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','irjaannikki','irja.koho@pp.inet.fi','Irja Koho','Vimpelinkatu 8','Kajaani','Oulun lääni','FINLAND','87150','0504900276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-19 09:41:39',0,NULL,3,0,3,1,'RA184570775CN\r ','irjaannikki\rL  已入库'),(18570,780570244002,120605585602,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',68.8,'hermeshine','babybutchers','sarb07@isynergy.com.au','sarah butcher','20 pelican ave<br>condon','townsville','Queensland','AUSTRALIA','4815','0419763383','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-19 10:42:42',0,NULL,3,0,4,1,'YW868053201CN ','babybutchers\r3mx6m 粉色'),(18571,742610237018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','samehcoptic','samehyounan@yahoo.com','Sameh Younan','166 Forest Road<br>Hurstville','Sydney','New South Wales','AUSTRALIA','2220','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 10:51:12',0,NULL,3,1,4,1,'YW868053175CN ','samehcoptic'),(18572,742607395018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','laughinglories','kelbelz81@bigpond.com','Kelly McEwan Photography','93 Alawoona Circle','Bullsbrook','Western Australia','AUSTRALIA','6084','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 11:15:47',0,NULL,3,1,4,1,'YW868053186CN ','laughinglories'),(18573,782262240002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','bobco9876','bobco@ix.netcom.com','bob palmer','338 Beacon St','boston','MA','UNITED STATES','02116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 12:01:01',0,NULL,3,1,17,0,NULL,'bobco9876'),(18574,782262241002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','bobco9876','bobco@ix.netcom.com','bob palmer','338 Beacon St','boston','MA','UNITED STATES','02116','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 12:01:02',0,NULL,3,1,1,1,NULL,'bobco9876\rCANON 镜头盖  72mm   1\r绿叶 UV  72mm     1\r'),(18575,799223797017,270755020049,'New 800W Red Head for Studio Continuous Light Bulb 220v',2,'AO0015',24,'photographyacc','gadgeteer101','amilev1@gmail.com','A Levartovsky','2/39 Helen St','Lane Cove','New South Wales','AUSTRALIA','2066','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 13:11:29',0,NULL,3,1,2,1,NULL,'gadgeteer101'),(18576,782288355002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','best54_b','best54_b@hotmail.com','Antoine Chiac','32 rue Paul Bert','Laxou','Meurthe et Moselle','FRANCE','54520','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 13:22:00',0,NULL,3,1,3,1,'RA184570789CN\r ','best54_b'),(18577,738733650001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','igreenhalgh1975','iangreenhalgh1@sky.com','Ian Greenhalgh','162 Albert Street','Millom','Cumbria','UNITED KINGDOM','LA18 4AB','0441229772282','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 14:07:47',0,NULL,3,1,2,1,NULL,'igreenhalgh1975'),(18578,872495388015,250606686795,'IR Remote Control 4 Canon RC-5 EOS 500D 350D 400D 450D',1,'AA2202',2.75,'hutongstore','dominiquej999','cbrdoom@free.fr','Dominique julian','4, place des lilas','Montpellier','Languedoc-Rousillon','FRANCE','34070','06 62 62 96 22','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 14:22:41',0,NULL,3,1,2,1,NULL,'dominiquej999'),(18579,782316351002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','mike39chef','michaelkennedy39@hotmail.com','michael kennedy','364 Roxdale ave.','ottawa','ON','CANADA','K1E1V4','(613) 830-3302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 14:46:46',0,NULL,3,1,2,1,NULL,'mike39chef'),(18580,782325620002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','serge6ka_11','serge6ka@inbox.lv','Sergejs Masko','83A Clitterhouse Crescent','London','Middlesex','UNITED KINGDOM','NW2 1DB','07955867000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:06:47',0,NULL,3,1,3,1,'RA184570792CN\r ','serge6ka_11'),(18581,742703446018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','maddo45','maddo65@bigpond.com','michael maddison','1 Tempest place ','Waikiki','Western Australia','AUSTRALIA','6169','0895921620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 15:14:30',0,NULL,3,1,4,1,'YW868053153CN ','maddo45'),(18582,854526509016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','bejozsolt','zsbejo@gmail.com','Zsolt Bejó','Dózsa György út 15.','Pilismarót','alapértelmezés','HUNGARY','2028','36702722043','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 15:24:48',0,NULL,3,1,2,1,NULL,'bejozsolt'),(18583,782335743002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rudon2010','rudon@rambler.ru','Rustam Shafiev','ulica Vikulova, 33/3-8','Yekaterinburg','RU, Sverdlovskaya oblast','RUSSIAN FEDERATION','620131','+79045443950','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 15:31:11',0,NULL,3,1,2,1,NULL,'rudon2010'),(18584,781721440002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','frunze.i','ifrunze@yandex.ru','Timukin Alexander','UL. Nizhegorodskaya d.29 kv.37','Novosibirsk','','RUSSIAN FEDERATION','630009','89139210636','NoPaymentFailure','CheckoutComplete','Other','2011-10-19 15:38:18',0,NULL,3,1,3,0,'RA184570801CN\r ','frunze.i'),(18585,854532547016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','0712alessandro','quattrini.arm@libero.it','ALESSANDRO QUATTRINI','Via della Valle<br>N°28','FANO','Pesaro','ITALY','61032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 15:41:06',0,NULL,3,1,2,1,NULL,'0712alessandro'),(18586,739843250001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','29hclmb611','gingelittle@tiscali.co.uk','Mark Little','29<br>Harding Close','Boverton','The Vale of Galmorgan','UNITED KINGDOM','CF61 1GX','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-19 16:03:54',0,NULL,3,0,3,1,'RA184570850CN\r ','29hclmb611\rxl    已入库'),(18587,872618215015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','mmatysekk','matejm@centrum.cz','Martin MATEJ','Prachaticka 1196/19','Ceske Budejovice','Czech republic','CZECH REPUBLIC','37005','775168588','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-19 18:02:00',0,NULL,3,1,2,1,NULL,'mmatysekk'),(18588,782430526002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','carlomicio','carlomicio@tin.it','gatti carlo c/o agazziplast','l. da vinci 10','cassina de pecchi','MI','ITALY','20060','3384660940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 18:44:06',0,NULL,3,1,2,1,NULL,'carlomicio'),(18589,854699706016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','pkir71','rockakias@hotmail.com','Peter Kyriazis','Taygetou 37','Athens','Attica','GREECE','16561','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-19 19:58:16',0,NULL,3,1,4,1,'YW868053164CN ','pkir71\r欧标'),(18590,742859290018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','isfaaq7','isfaaqaafsi@yahoo.com','Isfaaq Caunhye','84, Philippe Rousset St<br>Plaine - Lauzun','Port - Louis','','MAURITIUS','00230','+2307037260','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-19 20:04:42',0,NULL,3,1,3,1,'RA184570758CN\r ','isfaaq7'),(18591,742866812018,280683073882,'16\" / 40cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3327',38.99,'photographyacc','miltao2010','currogiovanni@gmail.com','Giovanni Currò','via luigi fulci N° 36','milazzo','ME','ITALY','98057','3288153689','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-19 20:20:12',0,NULL,3,1,3,1,'RA184570744CN\r ','miltao2010\r放布'),(18592,742877793018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',18,'photographyacc','shadyezz50','shadyezz@netspace.net.au','steve power','18 sibyl avenue','Frankston South','Victoria','AUSTRALIA','3199','0397879216','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 20:38:43',0,NULL,3,1,2,1,NULL,'shadyezz50'),(18593,739996376001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','xblade2342','macmo@live.nl','Mohammed Eshagh','De Wingerd 20','Blerick','','NETHERLANDS','5925GJ','0620959103','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-19 21:04:17',0,NULL,3,0,3,1,'RA184570727CN\r ','xblade2342\rxxxl   （已入库）'),(18594,782505736002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','frank3845','frank3845@hotmail.com','Frank Mitman','2200 W Hamilton St<br>Digital Photo Imaging # L-1','Allentown','PA','UNITED STATES','18104','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-19 21:06:46',0,NULL,3,1,1,1,NULL,'frank3845'),(18595,740004699001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1307',5.2,'hermeshine','dlop7','dlop29@hotmail.com','Lucruz Dunlop','6280 Wild Swan Way','Columbia','MD','UNITED STATES','21045-7417','(410) 205-5223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-19 21:23:12',0,NULL,3,1,1,1,NULL,'dlop7'),(18596,782512039002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 21:35:06',0,NULL,3,1,17,0,NULL,'lufox77'),(18597,782520135002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 21:39:44',0,NULL,3,1,17,0,NULL,'lufox77'),(18598,782520936002,120618815391,'TianYa 67mm ND8 filter New 67 Neutral Density Grey NIB',1,'AA2312',7.4,'hermeshine','lufox77','desenhado@gmail.com','Luciano Alves','Rua Rego Freitas, 355 ap64','Sao Paulo','Sao Paulo','BRAZIL','01220010','55 11 9400-3437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 21:41:06',0,NULL,3,1,3,1,'RA117766709CN\r ','lufox77\r橡胶遮光罩 67mm    1\r绿叶 CPL  67mm       1\r绿叶 ND8 67mm       1\r这票货重发一次\r\r'),(18599,742907964018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','jontaine','taunoa7@hotmail.com','donna taunoa','48 hunter avenue','hoppers crossing','Victoria','AUSTRALIA','3029','0433767053','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 21:43:33',0,NULL,8,1,17,0,NULL,'jontaine'),(18600,742908750018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','jontaine','taunoa7@hotmail.com','donna taunoa','48 hunter avenue','hoppers crossing','Victoria','AUSTRALIA','3029','0433767053','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-19 21:45:11',0,NULL,3,1,2,1,NULL,'jontaine\rMini 红外  canon    1\r机身盖/镜头后盖  Canon    1'),(18601,799498614017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','knorren123bank','johnny@jibe.se','Johnny Birgersson','Kvarnvagen 21','Trollhattan','','SWEDEN','46158','+46703765535','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-19 22:20:23',0,NULL,3,1,4,1,'YW868053142CN ','knorren123bank'),(18602,782555019002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','bgeng2009','geng.brian@gmail.com','YIBING GENG','766 HUNTINGWOOD DR','TORONTO','ON','CANADA','m1t2l4','(416) 856-6887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-19 23:31:51',0,NULL,3,1,3,1,'RA184570735CN\r ','bgeng2009'),(18603,742958921018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','kaymax1611955','kaymax161@hotmail.com','Karen Maxwell','15 Lancelot Grove','Burton','South Australia','AUSTRALIA','5110','0439878007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 00:34:34',0,NULL,3,1,2,1,NULL,'kaymax1611955'),(18604,782579172002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','tanguero79','anitastacey@hotmail.com','A Stacey','Beach Road Surgery<br>42 Beach Road','CHRISTIES BEACH','South Australia','AUSTRALIA','5165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 01:01:30',0,NULL,3,1,2,1,NULL,'tanguero79'),(18605,782586061002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','petrbaev','kvazar@gmail.com','Petr Baev','Borisenko, d. 76, kv. 15','Vladivostok','Primorsky kray','RUSSIAN FEDERATION','690080','7-902-557-95-82','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 01:25:37',0,NULL,3,1,2,1,NULL,'petrbaev'),(18606,8881319081918791,111,'test',1,'',0,'aliexpress','test','test','test','test','test','','TEST','','',NULL,NULL,NULL,'2011-10-20 03:38:38',0,NULL,5,0,18,0,NULL,NULL),(18607,8881319082042889,111,'test',1,'',0,'photographyacc','test','test','test','test','test','','TEST','','',NULL,NULL,NULL,'2011-10-20 03:40:42',0,NULL,5,0,18,0,NULL,NULL),(18608,8881319082090684,111,'背景布等',1,'',0,'photographyacc','flamefox850','notes','notes','notes','notes','','NOTES','','',NULL,NULL,NULL,'2011-10-20 03:41:30',0,NULL,3,0,6,1,'EE491015895CN ',' '),(18609,782617594002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',10.34,'hermeshine','celtic_flowerchild','flowerchildgypsy@yahoo.com.au','Ian Campbell','3 Armstrong Ave','Parafield Gardens','South Australia','AUSTRALIA','5107','0421796655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 03:54:51',0,NULL,3,1,2,1,' ','celtic_flowerchild'),(18610,743010163018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','davidmagak','dmagakian@gmail.com','David Magakian','60 Nellida cres','Hamilton','ON','CANADA','l9c7p9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 04:05:42',0,NULL,3,1,3,1,'RA184570829CN ','davidmagak'),(18611,740100025001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',2,'AO0018',132,'hermeshine','siziksizik','sizik@inbox.ru','Vyacheslav Sizov','Pesochnaya street, 1/4, 4','Bezhetsk','Tver region','RUSSIAN FEDERATION','171984','+7 920 682 1600','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 04:17:47',0,NULL,3,0,5,1,'CP238090289CN ','siziksizik'),(18612,743015636018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',84.5,'photographyacc','vyea9561','cadencepark@live.com','Vicki Yeates','294B Wattelup Road','Wattelup','Western Australia','AUSTRALIA','6166','0894100047','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-20 04:36:40',0,NULL,3,1,4,1,' ','vyea9561\r白+黑'),(18613,734811642001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',2,'AA3405',19.98,'hermeshine','mightydcollector63','mightyd63@msn.com','John Ramos','12661 17th St','Chino','CA','UNITED STATES','91710-3612','(909) 628-4118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 04:38:09',0,NULL,5,0,18,0,NULL,'mightydcollector63'),(18614,734808438001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',2,'AA3405',19.98,'hermeshine','mightydcollector63','mightyd63@msn.com','John Ramos','12661 17th St','Chino','CA','UNITED STATES','91710-3612','(909) 628-4118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 04:38:10',0,NULL,3,1,1,1,NULL,'mightydcollector63'),(18615,782639807002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','muk7en','muk_7en@yahoo.com','Muhammad Mukrim Salleh','RHB Bank Bhd, No 9<br>Jalan Abdullah','Muar','Johor','MALAYSIA','84000','0126690402','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 05:46:08',0,NULL,3,1,6,1,'EE491015887CN ','muk7en'),(18616,743029410018,280666849251,'New Camera shoulder bag A1 for Sony Dslr a500 a33 a580',1,'AO0028',25.8,'photographyacc','pandaguch','paulguch@live.com','Paul Guch','87 Anderson St Yarraville','Melbourne','Victoria','AUSTRALIA','3013','0413373396','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 05:57:36',0,NULL,3,1,3,1,'RA184570832CN ','pandaguch\r'),(18617,740133145001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mandldarko','darkomandl@yahoo.com','Darko Mandl','Mencingerjeva<br>4','Krsko','','SLOVENIA','8270','386 40 667 865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 06:30:25',0,NULL,3,1,2,1,NULL,'mandldarko'),(18618,8881319092233264,111,'2云柔',1,'AKT052',0,'photographyacc','vmie75','vmie@yahoo.com','RAHIMI RAMLI (s/n:252895)','PO BOX 686,<br>Line Maint,Engg Dept,','Dubai','','UNITED ARAB EMIRATES','_','(971) 503-4428 ext.: 26',NULL,NULL,NULL,'2011-10-20 06:30:33',0,NULL,3,0,3,1,'RA184570846CN ','已入库 \r2云柔   1'),(18619,743036720018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','xspimages','7robby7@cox.net','Lisa Berard','20 Hall Ave','Newport','RI','UNITED STATES','02840-2141','(401) 849-7739','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,7,1,18,1,'','xspimages\r'),(18620,740135877001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','spingpong','sjosanto@hotmail.com','Stefanus Josanto','14 Dargan Street','YAGOONA','New South Wales','AUSTRALIA','2199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 06:44:23',0,NULL,3,1,2,1,NULL,'spingpong\r黑色'),(18621,782654231002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','ibid0955','martin_200bar@live.com','Martin Edwards','Poste Restante<br>Post Office - Ao Nang','Krabi','','THAILAND','00056','0888312418','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 07:08:08',0,NULL,3,1,2,1,NULL,'ibid0955'),(18622,782658137002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','0204whiteshark','andrei.tserednik@gmail.com','Andrei Tserednik','Karukella 12-29','Tallinn','Harjumaa','ESTONIA','12015','+3725168307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 07:33:09',0,NULL,3,1,3,1,'RA184571254CN ','0204whiteshark\r白色'),(18623,872942900015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',120,'hutongstore','franca.s123','mitsuhashi1993@hotmail.it','franca secci','frutti d\'oro la vigna 2 strada n°71','capoterra','CA','ITALY','09012','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 07:56:32',0,NULL,3,1,4,1,'YW867739940CN ','franca.s123\r布是要绿色的\r欧标'),(18624,740152262001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','pekkakaukaloinen','vaikeetaon@gmail.com','Tomi Korhonen','pirtapolku 38','kajaani','Mansaari','FINLAND','87700','0505887454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 08:08:02',0,NULL,3,1,3,1,'RA184571183CN ','pekkakaukaloinen'),(18625,740152728001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','apomulti','pobrie@exemail.com.au','Philip O\'Brien','Civic Centre<br>25 Ferres Boulevard','South Morang','Victoria','AUSTRALIA','3752','0392172557','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 08:10:36',0,NULL,3,1,3,1,'RA184571064CN ','apomulti\r'),(18626,782667115002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','revikom','revikom1@gmail.com','Yevgeny German','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 329-0334','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-10-20 08:20:48',0,NULL,3,1,3,1,'RA184571166CN ','revikom\r转欧标， 需要看一下可能要发那个大的转换头'),(18627,799660427017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','slava7554','slava54@mail.ru','Vjacheslav Gubenin','Mikronnaya, 9, 46','Barnaul','Altaisky kray','RUSSIAN FEDERATION','656011','79619770516','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 09:18:23',0,NULL,3,1,2,1,NULL,'slava7554\r欧标'),(18628,740177572001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','makino.h','makino.hironori@gmail.com','Hironori Makino','Dept. of Human and Information Science at TOKAI Univ.<br>Kitakaname 4-4-1','Hiratsuka','Kanagawa','JAPAN','259-1207','+81-90-6488-9647','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 09:58:46',0,NULL,3,1,3,1,'RA184571152CN ','makino.h'),(18629,743087004018,280666852926,'Photo Studio Light Stand Heavy Duty Clamp Copper head  ',1,'AE3102',10,'photographyacc','wtrio','wtrioebay@yahoo.com.au','Widjaja','3 /  1-7 PELICAN ST<br>SURRYHILLS','SYDNEY','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-20 10:09:30',0,NULL,3,1,2,1,' ','wtrio'),(18630,743088435018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',2,'AKT056',110,'photographyacc','my850','egtasker@hotmail.com','Eric Tasker','PO Box 390','Calwell','Australian Capital Territory','AUSTRALIA','2905','0417650524','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 10:17:38',0,NULL,3,1,17,0,NULL,'my850'),(18631,743087654018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','my850','egtasker@hotmail.com','Eric Tasker','PO Box 390','Calwell','Australian Capital Territory','AUSTRALIA','2905','0417650524','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 10:17:38',0,NULL,3,1,6,1,'EE617288582CN','my850\rYW867740006CN换单重发，新单号为：EE617288582CN'),(18632,743076818018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','flybuys123','christopher_tan@hotmail.com','Christopher Tan','4, Chloride St','Broken Hill','New South Wales','AUSTRALIA','2880','0880873620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 10:44:29',0,NULL,3,1,2,1,NULL,'flybuys123'),(18633,740193709001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','evgene19119','evgenelmanova@mail.ru','Гегин Антон','Новороссийская, 5, 204','Волгоград','Волгоградская область','RUSSIAN FEDERATION','400131','(904) 775-0969','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 11:05:59',0,NULL,3,1,5,1,'CP238090258CN ','evgene19119\r白+黑'),(18634,740198657001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wshemais1973','wshemais@hotmail.com','Niso Wael','160 W 28th St','New York','NY','UNITED STATES','10001-6101','(201) 929-8848 ext.: 3','NoPaymentFailure','CheckoutComplete','Other','2011-10-20 11:20:23',0,NULL,3,0,3,1,'RA184571149CN ','wshemais1973\rXXL  (已入库）'),(18635,740209100001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','medicenelcuchi','oavazquez@gmail.com','Oscar Vazquez','Timoteo Gordillo 5697','Capital Federal','Ciudad de Buenos Aires','ARGENTINA','C1439GKA','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 11:55:32',0,NULL,3,1,2,1,NULL,'medicenelcuchi'),(18636,782727500002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','pepe_gal','jlopezc@udc.es','José Fernando López Castro','Pza. Cormelana 6, 6º','A Coruña','Galicia','SPAIN','15003','649270459','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 12:05:24',0,NULL,3,1,4,1,'YW867739973CN ','pepe_gal'),(18637,740219576001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','1973*2009','paulic.igor@gmail.com','Igor Paulic','Osojnaki 32','Matulji','Matulji','CROATIA','51211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 12:31:27',0,NULL,3,1,3,1,'RA184571104CN ','1973*2009\r包好重量；315'),(18638,743132399018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',20,'photographyacc','trotinsky','trotinskymail@iprimus.com.au','Lucas Bowers','71 Chatsworth Road<br>Highgate','Perth','Western Australia','AUSTRALIA','6003','61892280556','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 12:42:58',0,NULL,3,1,3,1,'RA184571135CN ','trotinsky'),(18639,873050082015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',5,'AKT007',64.95,'hutongstore','moonmen51','moonmen@op.pl','Szymon Wnetrzak','glebemount 17','wicklow town','wicklow co','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 13:13:01',0,NULL,3,1,4,1,'YW867739984CN ','moonmen51\r注意是10个'),(18640,873053586015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','carlosjpferreira','carlos_clone@hotmail.com','Carlos Ferreira','INUAF – Instituto Superior Dom Afonso III<br>Rua Vasco da Gama, 6 8100-718 LOULÉ','LOULÉ','Portugal','PORTUGAL','8100-718','(+351) 963661196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 13:21:42',0,NULL,3,1,3,1,'RA184571197CN\rRA184571206CN ','carlosjpferreira\r分开发'),(18641,799749777017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','murzins','lamursa@hotmail.com','Willem Versteegen','Abdijstraat 37','Hamont','','BELGIUM','3930','0473-118313','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 14:04:14',0,NULL,3,1,4,1,'YW867739951CN ','murzins'),(18642,8881319121671384,111,'河北背心 nikon xxl',1,'AD1137',0,'photographyacc','nikonwoman1947','nikonman@live.com.au','Dr R Johnson','5 Helena Street','Biggera Waters','Queensland','AUSTRALIA','4216','0412011140',NULL,NULL,NULL,'2011-10-20 14:41:11',0,NULL,3,0,3,1,'RA184571081CN ','xxl  （已入库） \r提醒我看一下xxl的尺寸'),(18643,782785813002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','rgbphoto','rgbphoto@sbcglobal.net','Rod Boren','165 Edwards St','Cottage Hills','IL','UNITED STATES','62018-1122','(618) 258-7319','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-20 15:04:59',0,NULL,3,1,1,1,NULL,'rgbphoto'),(18644,855098547016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','maurys85','mauro.deluca85@gmail.com','ristorante alfredo Mauro De Luca','viale mazzini, 1','tivoli','RM','ITALY','00019','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-20 15:29:12',0,NULL,3,1,4,1,'YW867739962CN ','maurys85\r欧标  布是绿色'),(18645,873115567015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','markfpt','marcofaria81@gmail.com','Marco Faria (Bragaconta)','Av. 31 de Janeiro, Nº18','Braga','Braga','PORTUGAL','4715-052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 15:42:11',0,NULL,3,1,17,0,NULL,'markfpt'),(18646,873115568015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','markfpt','marcofaria81@gmail.com','Marco Faria (Bragaconta)','Av. 31 de Janeiro, Nº18','Braga','Braga','PORTUGAL','4715-052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 15:42:12',0,NULL,3,1,17,0,NULL,'markfpt'),(18647,873115569015,250600523459,'Shutter Release Remote Cord For Canon 500D 450D RS-60E3',1,'AA3210',2.98,'hutongstore','markfpt','marcofaria81@gmail.com','Marco Faria (Bragaconta)','Av. 31 de Janeiro, Nº18','Braga','Braga','PORTUGAL','4715-052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-20 15:42:12',0,NULL,3,1,17,0,NULL,'markfpt'),(18648,873115570015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','markfpt','marcofaria81@gmail.com','Marco Faria (Bragaconta)','Av. 31 de Janeiro, Nº18','Braga','Braga','PORTUGAL','4715-052','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-20 15:42:13',0,NULL,3,1,12,1,'1107467001','markfpt\rc里的东西，再加上\r欧标\r橡胶遮光罩 58mm   1\r带水平仪 热靴保护盖     1\r普通有线快门线C1      1\r\rgift  $20'),(18649,799800700017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',1,'AB3314',6.69,'photographyacc','iliadiving','izdania@ya.ru','Ilya Zdanovich','Sovetskaya 69-16','Lipetsk','','RUSSIAN FEDERATION','398001','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 16:09:28',0,NULL,3,1,2,1,NULL,'iliadiving'),(18650,782814530002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','lellupi','mrbathnwells@gmail.com','anthony mitchell','45 charles adams close','leiston','Suffolk','UNITED KINGDOM','ip16 4lp','01728635873','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 16:20:49',0,NULL,3,1,2,1,NULL,'lellupi'),(18651,782844324002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','drole33','mdrolets@hotmail.com','Michel Drolet','1920 Spirerock Path','Colorado Springs','CO','UNITED STATES','80919-2915','(719) 265-6050','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-20 17:29:26',0,NULL,3,1,1,1,NULL,'drole33'),(18652,782851688002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','strangelman','suuhlem@gmail.com','Håkon Melhuus','Ladeveien 22','Trondheim','ST','NORWAY','7041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 17:44:19',0,NULL,3,1,2,1,NULL,'strangelman'),(18653,740343258001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','maurca22','mauricart@libero.it','Maurizio Carta','G.Deledda 11','Iglesias','CA','ITALY','09016','0781/23942','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 18:02:38',0,NULL,3,1,3,1,'RA184571055CN ','maurca22\r欧标\rlight head $15'),(18654,799900905017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.5,'photographyacc','pirogovsky','196460@gmail.com','Peter pirogovsky','Moshe Kairi 40/11','Beer Sheva','--','ISRAEL','84718','0578167833','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 19:14:28',0,NULL,3,1,2,1,NULL,'pirogovsky'),(18655,782906382002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','nayariddims','justfriendshere@live.fr','Yann Girault','6 rue d\'Estienne d\'Orves','Talant','Bourgogne','FRANCE','21240','0633016852','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-20 19:28:58',0,NULL,3,0,3,1,'RA184571170CN ','nayariddims\r欧标\r重量；\r1.75'),(18656,782915182002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','jagjitdhillon','monty.dhillon77@gmail.com','jagjit dhillon','3605, 12th Street NW','Edmonton','AB','CANADA','T6T0G2','(780) 803-3551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 19:46:29',0,NULL,3,1,2,1,NULL,'jagjitdhillon'),(18657,799944311017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','8571stephen','jeccless@ozemail.com.au','stephen fitzmaurice','27 hilltop road, clareville','sydney','New South Wales','AUSTRALIA','2107','0299182448','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 20:30:48',0,NULL,3,1,2,1,NULL,'8571stephen'),(18658,743352282018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','puddinhouse','jamesdreyes@rogers.com','James Reyes','87 Telegraph Drive','Whitby','ON','CANADA','L1P 1S4','(905) 444-9435','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 20:50:27',0,NULL,3,1,2,1,NULL,'puddinhouse'),(18659,799994523017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','matthijs.v.g','matthijs.v.g@orange.nl','Matthijs Gooswilligen, van','Torenmolen 30','PAPENDRECHT','','NETHERLANDS','3352VG','078-6182866','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 22:27:04',0,NULL,3,1,2,1,NULL,'matthijs.v.g'),(18660,800000475017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','1jgp','info@sayit.com','John Pauls','12780 Sylvan Meadows Dr','Colorado Springs','CO','UNITED STATES','80908','(719) 495-6299','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 22:53:43',0,NULL,3,1,1,1,NULL,'1jgp'),(18661,782988781002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-20 22:55:15',0,NULL,3,1,3,1,'RA184571118CN ','ramitetro'),(18662,800009257017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','benku01','bchmulk@adam.com.au','Ben Mulkerin','8 Glandore Ave<br>Clovelly Park','Adelaide','South Australia','AUSTRALIA','5042','0883574717','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-20 23:12:15',0,NULL,3,1,2,1,NULL,'benku01'),(18663,743416365018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','hfxgumby','gumby@hfx.eastlink.ca','Darryl Main','30 Chipstone Close<br>apt.126','Halifax','NS','CANADA','B3M 4H5','(902) 446-0185','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-20 23:48:55',0,NULL,3,1,3,1,'RA184571121CN ','hfxgumby'),(18664,8881319160434314,111,'NEW Photo Softbox Light Tent Cube Soft Box 16\" 40cm four background included',1,'AC2401',18.58,'aliexpress','1004614731','mini@vilor-dv.ru','Igor Minaevskiy	','Okeansky prospekt 76 - 10','Vladivostok','Russia','RUSSIAN FEDERATION	','690002','+7 4232 66-555-6',NULL,NULL,NULL,'2011-10-21 01:27:14',0,NULL,3,1,3,1,'RA184571078CN\r ','金额不大，先发货吧。 '),(18665,783042624002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',2,'AKT051',23,'hermeshine','curtis648','kac472@sbcglobal.net','Kim Curtis','4532 Hickory Rd<br>Apt 1B','Mishawaka','IN','UNITED STATES','46545-2415','(574) 247-3069','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 02:05:39',0,NULL,3,1,1,1,NULL,'curtis648'),(18666,743461444018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','seeseechan','sisechan2005@gmail.com','Samuel  Chan','7 Garden Grove Dr','Daly City','CA','UNITED STATES','94015','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 02:42:59',0,NULL,3,1,1,1,NULL,'seeseechan'),(18667,8881319165595376,111,'1003 独脚架   1',1,'AE1602',0,'photographyacc','marialuciaph','marianaphph@yahoo.com.br','maria lucia','rua retiro dos artistas <br>1081','rio de janeiro','rio de janeiro','BRAZIL','22770104','2132566257',NULL,NULL,NULL,'2011-10-21 02:53:15',0,NULL,3,1,3,1,'RA184571095CN ',NULL),(18668,740541406001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','bradprimmer','bradprimmer@yahoo.com','Brad Primmer','21 Windsor','Corner Brook','NL','CANADA','A2H6S3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-21 03:50:05',0,NULL,3,1,2,1,NULL,'bradprimmer'),(18669,783076529002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','sanne1527','sanne1527@yahoo.com','DUYEN DO','35316 23 MILE RD','NEW BALTIMORE','MI','UNITED STATES','48047-4435','(586) 202-6590','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-21 04:42:34',0,NULL,3,1,3,1,'RA184571356CN ','sanne1527'),(18670,800094521017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','tamsewn','hiretamsin@hotmail.com','Tamsin Grove','24 Lake Rd','Cambridge','ON','CANADA','n3c 2v4','(519) 658-4956','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 04:47:04',0,NULL,3,1,2,1,NULL,'tamsewn'),(18671,743290186018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',21.5,'photographyacc','mjw7371','zerman@iprimus.com.au','Michael Wostmann','P.O Box 2043','Southport','Queensland','AUSTRALIA','4215','0415119765','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-21 05:08:22',0,NULL,3,1,3,1,'RA184571342CN ','mjw7371'),(18672,740555995001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','pucinskas','saulius.pucinskas@gmail.com','Saulius Pucinskas','Klevu 6-12','Siauliai','','LITHUANIA','76339','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 05:15:23',0,NULL,3,1,2,1,NULL,'pucinskas'),(18673,783082665002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','hilllo','h.lo@comcast.net','Hillman K. Lo','2556 Sherborne Dr','Belmont','CA','UNITED STATES','94002-2921','(650) 312-7449','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-21 05:18:32',0,NULL,3,1,1,1,NULL,'hilllo'),(18674,743494966018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','nikvlad2001nikolay','nikvlad2001@mail.ru','Nikolay Kondrashkin','63 Koshevogo strit<br>Korenovskiy raion,  stanisa Platnirovskaia','stanisa Platnirovskaia','Korenovskiy raion,  Krasnodarskiy kray','RUSSIAN FEDERATION','353177','+7-918-37-53-195','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 05:31:44',0,NULL,3,1,3,1,'RA184571268CN ','nikvlad2001nikolay'),(18675,855473421016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','paknip','mthanif@yahoo.co.uk','Hanif Mohamed Talha','Flat 31C, Bowsden Court<br>South Gosforth','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE3 1RR','07592610147','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-21 06:37:51',0,NULL,3,1,2,1,NULL,'paknip'),(18676,740572681001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','purplemonkeydiver','paul@pauldorrell.co.uk','Paul Dorrell','Flat 34, Building 49<br>Argyll Road','Woolwich','London','UNITED KINGDOM','SE186XB','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 06:53:02',0,NULL,3,1,2,1,' ','purplemonkeydiver'),(18677,743516468018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','megan4350','megan4350@bigpond.com','Megan Mahon','PO Box 1069','Toowong DC','Queensland','AUSTRALIA','4066','0410577811','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-21 07:25:13',0,NULL,3,1,2,1,NULL,'megan4350'),(18678,740589395001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','paulklo','paulk123@gmail.com','Paul Klõšeiko','Õismäe tee 5-4','Tallinn','Harjumaa','ESTONIA','13514','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 08:16:50',0,NULL,3,1,3,1,'RA184570228CN\r ','paulklo'),(18679,743529275018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','digiozz','sean_breadsell@hotmail.com','Sean Breadsell','c/o Chevron Australia Pty Ltd<br>Level 14//250 St Georges Tce','Perth','Western Australia','AUSTRALIA','6000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-21 08:21:21',0,NULL,3,1,3,1,'RA184570231CN\r ','digiozz'),(18680,873531174015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','photoreemshot','reemshot@free.fr','JUZAC ALEXANDRE','33 Chemin des sautes<br>Res. Lucie Aubrac','Bauvin','Nord-Pas-de-Calais','FRANCE','59221','06.64.11.82.13','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-21 09:20:06',0,NULL,3,1,4,1,'YW867738175CN ','photoreemshot\r2b柔   1\r6662a    1\rNIKON 镜头盖 67mm    1\r'),(18681,873531140015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','photoreemshot','reemshot@free.fr','JUZAC ALEXANDRE','33 Chemin des sautes<br>Res. Lucie Aubrac','Bauvin','Nord-Pas-de-Calais','FRANCE','59221','06.64.11.82.13','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-21 09:20:05',0,NULL,3,1,17,0,NULL,'photoreemshot'),(18682,873533714015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',1.87,'hutongstore','photoreemshot','reemshot@free.fr','JUZAC ALEXANDRE','33 Chemin des sautes<br>Res. Lucie Aubrac','Bauvin','Nord-Pas-de-Calais','FRANCE','59221','06.64.11.82.13','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 09:20:06',0,NULL,3,1,17,0,NULL,'photoreemshot'),(18683,8881319188931799,111,'1600w 套装',1,'AKT039',0,'photographyacc','shabelski77','delian@hot.ee','Anton Sabelski','Heki tee 4-57','Haabneeme alevik, Viimsi vald','Harjumaa','ESTONIA','74001','+37256281095',NULL,NULL,NULL,'2011-10-21 09:22:11',0,NULL,3,1,12,1,'1107467104 ','申报 lighting kit  $50 '),(18684,740618059001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',4.18,'hermeshine','kyyyyylie','kar89@live.com.au','Kylie Anderson-Reeves','1/34 Kruseana Avenue','Goonellabah','New South Wales','AUSTRALIA','2480','0423006298','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 10:16:17',0,NULL,3,1,2,1,NULL,'kyyyyylie'),(18685,855569719016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 11:53:29',0,NULL,3,1,3,1,'RA184571594CN ','ilhadastartarugas'),(18686,740685186001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','hogtro','tron@getmail.no','Tron Høgvold','Traverveien 42','Oslo','Oslo','NORWAY','0588','97084490','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 14:05:39',0,NULL,3,1,2,1,NULL,'hogtro\r77mm  接口环  已入库'),(18687,783214187002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','mijabaja','dudas.tamas2@gmail.com','Maria Mayer and Tamas Dudas','Egressy ut 1/J 3/2','Budapest','','HUNGARY','1149','+36 20 9813 084','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 14:07:37',0,NULL,3,1,3,1,'RA184571603CN ','mijabaja'),(18688,783223878002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','pierbettoni','pierangelo.bettoni@gmail.com','Piarengelo, Cavalli Strumenti','artigiani, 1','castrezzato','BS','ITALY','25030','+393396539106','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 14:39:29',0,NULL,3,1,3,1,'RA184571651CN ','pierbettoni'),(18689,873663355015,250848949434,'600w lighting kit with 3mx6m backdrop & 2mx3m support ',1,'AKT037',130,'hutongstore','cs101022','corne.schipper@gmail.com','corne schipper','acacistraat 8','oud-Beijerland','','NETHERLANDS','3261RC','0628137771','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-21 14:57:27',0,NULL,3,1,4,1,'YW867738186CN ','cs101022\r欧标'),(18690,873673009015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',2,'AKT015',98,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 15:17:16',0,NULL,3,1,5,1,'CP238090010CN ','leifs123\r白+黑\r申报 £20'),(18691,873676829015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','rmcleod_bigbob','b16rml@aol.com','Robert McLeod','16 Park Road<br>Chryston','Glasgow','North Lanarkshire','UNITED KINGDOM','G69 9DS','01417792669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-21 15:25:12',0,NULL,3,1,3,1,'RA184571563CN ','rmcleod_bigbob'),(18692,783242221002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',218,'hermeshine','cachorroz','ermakova.sve@gmail.com','Svetlana Ermakova','Metallyrgov 62-16','Moscow','Moscow','RUSSIAN FEDERATION','111399','+79055355396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 15:27:13',0,NULL,3,1,5,1,'CP238090023CN ','cachorroz\r欧标\r包是牛津布的包'),(18693,743660615018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','dudilevilevilevi','itay__levy@hotmail.com','Itay Levy','Ginzburg 6 a','Tel Aviv','Israel','ISRAEL','67896','0504406206','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 15:27:20',0,NULL,3,1,2,1,NULL,'dudilevilevilevi'),(18694,783265914002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','candy_engel','candyschartz@yahoo.co.uk','Candy Schartz-Engel','131 Claremont Avenue','New Malden','Surrey','UNITED KINGDOM','KT3 6QR','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 16:27:45',0,NULL,3,1,2,1,NULL,'candy_engel\r英标'),(18695,740740624001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','felix-c86','felix329@gmail.com','Srecko Centrih','debro 8','Lasko 3270','Slovenia','SLOVENIA','00386','031686647','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 16:31:05',0,NULL,3,1,2,1,NULL,'felix-c86'),(18696,740739077001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',4.96,'hermeshine','likaworld','milan.krznaric@gmail.com','Milan Krznaric','Frankopanska 40','Otocac','','CROATIA','53220','+385 53 772 409','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 16:31:36',0,NULL,3,1,2,1,NULL,'likaworld'),(18697,855693038016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','cantabria3154','angelantonio3154@hotmail.com','ANGEL ANTONIO FERNANDEZ GOMEZ','Avda de los Castros Nº 57-- 5º A','SANTANDER','Cantabria','SPAIN','39005','620 289921','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-21 16:38:29',0,NULL,3,1,3,1,'RA184571577CN ','cantabria3154\r欧标'),(18698,800308579017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',58,'photographyacc','chto72223','christer@torget2.se','Christer Tornkvist','Torget 2','STROMSHOLM','Vastmanland','SWEDEN','SE73494','+4622041194','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 16:41:00',0,NULL,3,1,17,0,NULL,'chto72223'),(18699,783279059002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','pro100lena','elena_sidorenko@ua.fm','Elena Sydorenko','Srybnokilska 4, 206','Kyiv','Kyiver','UKRAINE','02068','0030445721670','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 17:00:05',0,NULL,3,1,17,0,NULL,'pro100lena'),(18700,740753232001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','pro100lena','elena_sidorenko@ua.fm','Elena Sydorenko','Srybnokilska 4, 206','Kyiv','Kyiver','UKRAINE','02068','0030445721670','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-21 17:00:06',0,NULL,3,1,5,1,'CP238090054CN ','pro100lena\r背景架2mx2m  + 3个夹子   1\r1.6x2.1 背景布   2   白+黑\rlenspen    2\r'),(18701,783284206002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','adob7487','anna.dobrenski@gmail.com','Anna Dobrenski','261 Erica Way','Portola Valley','CA','UNITED STATES','94028','(415) 518-8880','NoPaymentFailure','CheckoutComplete','Other','2011-10-21 17:06:43',0,NULL,3,1,3,1,'RA184571585CN ','adob7487'),(18702,855723299016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','althalus100','milamber@ntlworld.com','Simon J Morgan','32 Sommerset Road','Newport','Newport','UNITED KINGDOM','NP197GA','01633667586','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-21 17:34:22',0,NULL,3,0,3,1,'RA117778154CN\r ','althalus100\r白色'),(18703,740784570001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','gastair','fabrice.janitor@orange.fr','Fabrice JANITOR','Av Marcel Hoareau<br>Bt 03 Appt 311 résidence Galliéni','Sainte-Clotilde','','REUNION','97490','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 18:24:49',0,NULL,3,1,3,1,'RA184571679CN ','gastair'),(18704,783340442002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','johnsharrock','sharrock@sympatico.ca','John Sharrock','792 Grierson St','Oshawa','ON','CANADA','L1G 5J7','(905) 728-2314','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 19:06:11',0,NULL,3,1,2,1,NULL,'johnsharrock'),(18705,783341411002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','aygua','canalhipica@gmail.com','Juan Francisco Ayguavives Caldevilla','Urbanizacion El Couto 68','Narón (La Coruña)','Galicia','SPAIN','15570','670754381','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 19:07:46',0,NULL,3,1,4,1,'YW867738190CN ','aygua'),(18706,740813983001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','alanslotus','alan.paterson5@ntlworld.com','Alan   Paterson','13 Littlefield Close, Ash','Aldershot','Hampshire','UNITED KINGDOM','GU12 6TH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 19:09:01',0,NULL,3,1,3,1,'RA184571696CN ','alanslotus'),(18707,800395876017,270753945148,'Lambency Flash Diffuser for SB26/27/28 F56AM EF500 P3 ',1,'AB3310',21.5,'photographyacc','pe_ricles','jarranz2@gmail.com','Jesus  Arranz','Carlos Martin Alvarez, 72','Madrid','Madrid','SPAIN','28018','91-4771141','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 19:33:05',0,NULL,3,1,3,1,'RA184571912CN ','pe_ricles\r新地址：\rJesús Arranz Sanz\rC/ Ruidera, 28\r28053 Madrid\rSPAIN\r91-4771141\r'),(18708,740834651001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','kazak00','bikeyev@gmail.com','Yerkanat Bikeyev','26 Bogdan Khmelnitsky str. App. 8','Karaganda','','KAZAKHSTAN','10012','+7 (7212) 563224','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-21 20:02:31',0,NULL,3,1,5,1,'CP238090068CN ','kazak00\r\r'),(18709,743841302018,280674081169,'New 67mm Snap-on Front Lens Cap for Nikon 67 mm lenscap',3,'AA1307',7.5,'photographyacc','tdunniganjr','dunniganphoto@gmail.com','TC Dunnigan','524 N Main St','niles','OH','UNITED STATES','44446-5147','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 21:56:06',0,NULL,3,1,1,1,NULL,'tdunniganjr'),(18710,740889127001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','pask99','b.photo@videotron.ca','pascal baldini','109 frontenac','sherbrooke','QC','CANADA','J1H 1J7','(819) 562-0900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-21 22:11:56',0,NULL,3,1,3,1,'RA117761318CN\r ','pask99'),(18711,743852356018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',22,'photographyacc','asiabirdiamonds','asi@asiabir.com','Asi  Abir','1 Jabutinsky Rd. Maccabi Blding','Ramat-Gan','','ISRAEL','52526','972-54-397-0606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 22:29:22',0,NULL,3,1,17,0,NULL,'asiabirdiamonds'),(18712,743853569018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',4,'AE3104',35.96,'photographyacc','farsaba','armin341@ymail.com','Armin Saba','8020 Minler Rd','Richmond','BC','CANADA','V7C 3T7','(604) 447-0657','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-21 22:33:34',0,NULL,3,1,3,1,'RA184571705CN ','farsaba'),(18713,8881319240866257,111,'B座',1,'AB2301',0,'hermeshine','valentinagilyadova','valelik18@yandex.ru','valentina schlesinger','7060 county road 21','alliston','ON','CANADA','l9r1v2','(647) 892-1881',NULL,NULL,NULL,'2011-10-21 23:47:46',0,NULL,3,1,3,1,'RA184571617CN ',NULL),(18714,783474035002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tirilhjelm','tiril.hjelmeland@gmail.com','Tiril Hjelmeland','Kalfarveien 58','Bergen','Bergen','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 01:53:06',0,NULL,3,1,3,1,'RA117778137CN\r ','tirilhjelm\r+1.6x3m 灰色背景布'),(18715,743903923018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','hollywoodhoward','brad@bradleyj.tv','Bradley Howard','P.O Box 745<br>Everton Park','Brisbane','Queensland','AUSTRALIA','4053','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-22 02:01:19',0,NULL,3,1,3,1,'RA184571625CN ','hollywoodhoward'),(18716,783482408002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','djandsonsailing','djwebb@rogers.com','Douglas Webb','171 McKee Ave.','Toronto','ON','CANADA','M2N4C6','(416) 250-7843','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-22 02:31:40',0,NULL,3,0,3,1,'RA184571634CN ','djandsonsailing\rL  已入库'),(18717,783507004002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+622192659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 04:44:21',0,NULL,3,1,2,1,NULL,'ivan_ns2'),(18718,8881319260236060,111,'1600w 套装 + 45w 110v  2',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-10-22 05:10:36',0,NULL,3,1,12,1,'1733148675 ','C里的东西 灯泡是110v的\r+ 45w 110v 灯泡  2个\r 实重；6.5\r抛重；9.72'),(18719,743942136018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',87,'photographyacc','chto72223','christer@torget2.se','Christer Tornkvist','Torget 2','STROMSHOLM','Vastmanland','SWEDEN','SE73494','+4622041194','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 05:28:21',0,NULL,3,1,4,1,'YW867738201CN ','chto72223\r加1个斜臂'),(18720,743942316018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','taushablaksley','t_blaksley@yahoo.com','Tausha Blaksley','403 163rd St S','Spanaway','WA','UNITED STATES','98387-8600','(253) 536-3884','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 05:32:23',0,NULL,3,0,1,1,NULL,'taushablaksley\r白色'),(18721,800476140017,270766501591,'New 115w x 2 Daylight Bulb for Photograph​y 5500K Light',1,'AKT049',32,'photographyacc','asiabirdiamonds','asi@asiabir.com','Asi  Abir','1 Jabutinsky Rd. Maccabi Blding','Ramat-Gan','','ISRAEL','52526','972-54-397-0606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 05:39:33',0,NULL,3,1,3,1,'RA184571648CN ','asiabirdiamonds'),(18722,743947568018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','pedrosy','pedrosy@yahoo.com','peter sy','2314 Vista Moora Ave','Chino Hills','CA','UNITED STATES','91709-4340','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 06:05:09',0,NULL,3,1,1,1,NULL,'pedrosy'),(18723,743953484018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','doctorianc','ian.chambers@bigpond.com','IAN CHAMBERS','10 SHEARWATER CT','LAKE CATHIE','New South Wales','AUSTRALIA','2445','0265854786','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-22 06:47:05',0,NULL,3,0,3,1,'RA184571515CN ','doctorianc\rXXL  已入库'),(18724,783529419002,120605577790,'New thicken Non Woven Fabric Backdrop 3m x 2m(10 x7 ft)',1,'AO0018',35,'hermeshine','fryzelka','fryzelka@seznam.cz','Lukas Fryzelka','K. Michla 937','Dobruska','','CZECH REPUBLIC','518 01','+420603540555','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 06:58:46',0,NULL,3,0,3,1,'RA117778145CN\r ','fryzelka\r白色\r3mx2m 白色  需要裁一下'),(18725,874076584015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','brandtime','sikorska.pl@interia.pl','Magdalena Sikorska','11 Sandy Hill','Newry','Down','UNITED KINGDOM','BT35 6BJ','02830825540','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-22 09:12:30',0,NULL,3,1,12,1,' 1733148686','brandtime\r英标   背景布：白色\r实重  6.865\r泡重7.4'),(18726,783569868002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','glenford72','antileecher2004@yahoo.co.uk','Glenford Russell','89 Mill Lane<br>Wednesfield','Wolverhampton','West Midlands','UNITED KINGDOM','wv11 1db','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 09:45:18',0,NULL,3,1,4,1,'YW867738212CN ','glenford72'),(18727,780622182002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 09:58:57',0,NULL,3,0,3,1,'RA117778066CN\r ','gedrasas\r1.6x3m 白色'),(18728,874098526015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 10:13:21',0,NULL,3,1,17,0,NULL,'humanprofile'),(18729,874098535015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','humanprofile','filippotoso@libero.it','Filippo Toso','Borgo Acquileia 3/f<br>c/o Creative Park Srl','Palmanova','UD','ITALY','33057','348 3406175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 10:13:21',0,NULL,3,1,4,1,'YW867738223CN ','humanprofile\r手动升降背景架     1\r2.4x3m背景架+ 白布     1\r\r'),(18730,744009488018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',60,'photographyacc','t-lee91','lilhursty@hotmail.com','teagen-lee rees','3 casterley road<br>Elizabeth north','adelaide','South Australia','AUSTRALIA','5113','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-22 10:14:46',0,NULL,3,0,4,1,'YW867738234CN ','t-lee91\r白色'),(18731,873940531015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',49,'hutongstore','noemar53','noemar53@yahoo.com','noel keegan','53 dingle road<br>cabra west','dublin ','Dublin','IRELAND','7','018384336','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 10:46:44',0,NULL,3,1,4,1,'YW867738245CN ','noemar53\r白色\r需要补发黑色背景布'),(18732,741057879001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','ya_maska09','ya_maska@hotmail.com','Oksana Iskusnova','st. B.Galushkina, 17-317','Moscow','','RUSSIAN FEDERATION','129301','8-916-353-35-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:17:02',0,NULL,3,1,17,0,NULL,'ya_maska09'),(18733,741052321001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','ya_maska09','ya_maska@hotmail.com','Oksana Iskusnova','st. B.Galushkina, 17-317','Moscow','','RUSSIAN FEDERATION','129301','8-916-353-35-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:17:02',0,NULL,3,1,17,0,NULL,'ya_maska09'),(18734,741052657001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','ya_maska09','ya_maska@hotmail.com','Oksana Iskusnova','st. B.Galushkina, 17-317','Moscow','','RUSSIAN FEDERATION','129301','8-916-353-35-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:17:03',0,NULL,3,1,17,0,NULL,'ya_maska09'),(18735,741052963001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','ya_maska09','ya_maska@hotmail.com','Oksana Iskusnova','st. B.Galushkina, 17-317','Moscow','','RUSSIAN FEDERATION','129301','8-916-353-35-42','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:17:03',0,NULL,3,1,3,1,'RA184571529CN ','ya_maska09\r麂皮     1\r倒影板（白黑）     1\r圆形柔光棚 40cm    1\r45w 5500k 灯泡 220v     1\r\r'),(18736,783606480002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','antonio_polo','antonio_polo_32@hotmail.com','Antonio Polo Suarez','C/ Sant Francesc Xavier , nº 26 (Bar Canarias)<br>Esplugas de Llobregat','Barcelona','Cataluña','SPAIN','08950','607213193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 11:51:21',0,NULL,3,1,2,1,NULL,'antonio_polo'),(18737,800680211017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','bart1628','btw_lee@hotmail.com','Bert Lee','5577 Argyle Street','Vancouver','BC','CANADA','V5P3J5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 12:27:20',0,NULL,3,1,2,1,NULL,'bart1628'),(18738,874153945015,250599955564,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',98,'hutongstore','krullida','lidakrul@hotmail.com','Lida Krul','Orteliusstraat 280 II','Amsterdam','','NETHERLANDS','1056 PM','06 42055173','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 12:51:26',0,NULL,3,1,4,1,'YW867738256CN ','krullida'),(18739,783628303002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','diablo13666','diablo13@yandex.ru','Dubov Sergey','Asaf Simchoni 15/6','Petach Tiqwa','','ISRAEL','49534','+972547400514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 12:55:30',0,NULL,3,1,2,1,NULL,'diablo13666'),(18740,8881319288182746,111,'1.6x2.1 背景布 ',2,'',0,'hermeshine','ashaker11','ahmed.shaker@inbox.com','Ahmed Shaker','Olaya Road, North - Morooj District<br>P.O. Box 87925 Riyadh 11652 Saudi Arabia','Riyadh','Riyadh','SAUDI ARABIA','11652','966569169710',NULL,NULL,NULL,'2011-10-22 12:56:22',0,NULL,3,1,3,1,'RA184571532CN ','白色 + 绿色 '),(18741,874166504015,250599384655,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3307',3.2,'hutongstore','brother_shipton','rich.greaves@hotmail.co.uk','Richard Greaves','81 Leasowe Road','Leeds','West Yorkshire','UNITED KINGDOM','LS10 2EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 13:05:50',0,NULL,3,1,17,0,NULL,'brother_shipton'),(18742,874166506015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',4.5,'hutongstore','brother_shipton','rich.greaves@hotmail.co.uk','Richard Greaves','81 Leasowe Road','Leeds','West Yorkshire','UNITED KINGDOM','LS10 2EY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-22 13:05:52',0,NULL,3,1,2,1,NULL,'brother_shipton\r绿叶 UV  77mm    1\r绿叶 CPL  77mm   1\r'),(18743,744070148018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','microscopic_milton','gervais69@hotmail.com','Luc Gervais','26 Simard St.','Port-Cartier','QC','CANADA','G5B2V6','(418) 766-9558','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 13:17:48',0,NULL,3,1,17,0,NULL,'microscopic_milton'),(18744,800699345017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','microscopic_milton','gervais69@hotmail.com','Luc Gervais','26 Simard St.','Port-Cartier','QC','CANADA','G5B2V6','(418) 766-9558','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 13:19:07',0,NULL,3,1,3,1,'RA184571546CN ','microscopic_milton\r沙袋（普通）     2\r沙袋（大）       2\r'),(18745,874172224015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','cupmens','ro@402.lv','Rolands Jaunalksnis','Lāčplēša 52/54 - 43','Rīga,','','LATVIA','LV 1011','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-22 13:20:57',0,NULL,3,1,3,1,'RA184571550CN ','cupmens\rgift $18'),(18746,741102833001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','drive_eddie_green','forbiddenfilms@hotmail.com','Jeffrey Norris','5/35 Waxman Parade','Brunswick West','Victoria','AUSTRALIA','3055','0393841183','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 13:34:30',0,NULL,3,1,2,1,NULL,'drive_eddie_green'),(18747,741105682001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','rotanirim','muschroom@seznam.cz','Miroslav Samsula','Hradecka 1124','Hradec Kralove','Czech Republic','CZECH REPUBLIC','50003','00420775165432','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 13:41:07',0,NULL,3,1,2,1,NULL,'rotanirim'),(18748,744085636018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','osetia1','art-osetia@mail.ru','SERGEY SALMANOV','59 Vladikavkazskaya Street,  Appartment 175','Vladikavkaz','Republic of North Ossetia-Alania','RUSSIAN FEDERATION','362045','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 14:00:22',0,NULL,3,0,2,1,NULL,'osetia1\r绿色'),(18749,783689173002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-22 15:33:20',0,NULL,3,1,3,1,'RA184571461CN ','fa636739'),(18750,800778865017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',228,'photographyacc','murzins','lamursa@hotmail.com','Willem Versteegen','Abdijstraat 37','Hamont','','BELGIUM','3930','0473-118313','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 16:21:54',0,NULL,3,1,4,1,'YW867738260CN ','murzins'),(18751,874265714015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38.99,'hutongstore','neil_farrugia','neilfarrugia@gmail.com','Neil Farrugia','Beatrice<br>Sejba Rd.','Mqabba','Malta','MALTA','MQB1616','(00356)7960 2433','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 16:28:07',0,NULL,3,1,3,1,'RA184571475CN','neil_farrugia'),(18752,744159794018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',87,'photographyacc','demeterlaquesis','javiermazzeo2002@yahoo.com.ar','Javier Mazzeo','Carrer d\'Angel Guimerà  Nº 21    1º 2ª','Banyoles','Cataluña','SPAIN','17820','661994147','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 16:46:01',0,NULL,3,1,4,1,'YW867738271CN ','demeterlaquesis\r给我一个最终包好的重量\r重量；3.1'),(18753,741193296001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','paliykolya','kolya_video@mail.ru','Kolya Paliy','skaleckogo 38a - 77','Vinnitsa','Vinnitskaya','UKRAINE','21018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-22 17:12:49',0,NULL,3,1,3,1,'RA184571489CN ','paliykolya'),(18754,783739074002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bohals2009','bohals@online.no','Børge Halseth','Langgilan 24','Gjølme','','NORWAY','7310','+4741852450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:16:53',0,NULL,3,1,17,0,NULL,'bohals2009'),(18755,783739076002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','bohals2009','bohals@online.no','Børge Halseth','Langgilan 24','Gjølme','','NORWAY','7310','+4741852450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:16:54',0,NULL,3,1,17,0,NULL,'bohals2009'),(18756,783739075002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','bohals2009','bohals@online.no','Børge Halseth','Langgilan 24','Gjølme','','NORWAY','7310','+4741852450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:16:54',0,NULL,3,1,17,0,NULL,'bohals2009'),(18757,783739077002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','bohals2009','bohals@online.no','Børge Halseth','Langgilan 24','Gjølme','','NORWAY','7310','+4741852450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:16:55',0,NULL,3,1,17,0,NULL,'bohals2009'),(18758,741196776001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','bohals2009','bohals@online.no','Børge Halseth','Langgilan 24','Gjølme','','NORWAY','7310','+4741852450','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 17:16:55',0,NULL,3,1,5,1,'CP238090071CN ','bohals2009\rc外（欧标）：\rlenspen    1\r绿叶 渐变镜 58mm    1\r绿叶 渐变镜 62mm    1\r4个镜头筒  s m l xl   一套\r\r\r\r'),(18759,800815096017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','aviabramovitchgmailcom','avi.abramovitch@gmail.com','avi abramovitch','harry markovitch 7','rishon lezion','','ISRAEL','75793','972-52-6080257','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 17:31:04',0,NULL,3,1,11,1,NULL,'aviabramovitchgmailcom'),(18760,741221328001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','cicoreno','martin.uhlik@hotmail.com','Martin Uhlík','Majerská 179/6','Lednické Rovne','Púchov','SLOVAK REPUBLIC','02061','0907748961','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-22 18:07:55',0,NULL,3,1,5,1,'CP238090085CN ','cicoreno'),(18761,741270214001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','mikesad2011','mikesad@mail.ru','Mikhail Sadomtsev','Likhachevskiy prospekt 70<br>1 bld, 181 apt','Dolgoprudniy','Moscow region','RUSSIAN FEDERATION','141707','9163958215','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-22 19:45:26',0,NULL,3,1,5,1,'CP238090099CN ','mikesad2011\r欧标'),(18762,856380586016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','trocadero2010','san61@list.ru','Sergey Nikitin','Kantemirovskaya d.14.kor.2 kv. 61','Moscow','Moscow','RUSSIAN FEDERATION','115522','+79166024770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 20:08:58',0,NULL,3,1,2,1,NULL,'trocadero2010'),(18763,741291953001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','yaronharel','yaron@technion.ac.il','Yaron Harel','p.o.box 574','Ramat Yishai','','ISRAEL','30095','972 52 8977929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 20:33:50',0,NULL,3,1,17,1,NULL,'yaronharel'),(18764,874171053015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','iw0elf','iw0elf@yahoo.it','Michele Sabia','Via Montebuono, 33','Roma','RM','ITALY','00199','3382489379','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-22 21:39:21',0,NULL,3,1,2,1,NULL,'iw0elf'),(18765,783868642002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','whatehdeal','randlkuehn@hotmail.com','CRAFT NOOK','195 WELLINGTON ST UNIT 3<br>ATTN: RANDY','Bracebridge','ON','CANADA','P1L1C2','(705) 645-6231','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 21:47:22',0,NULL,3,1,2,1,NULL,'whatehdeal'),(18766,741161746001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','deniswdion','dwdion@gmail.com','Denis Dion','Mellingerstrasse 156','Baden','','SWITZERLAND','5400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-22 21:53:21',0,NULL,3,1,3,1,'RA184571501CN ','deniswdion'),(18767,744337449018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','clay5saddle','clay-ej@telusplanet.net','Elaine R V Clay','Box 1252','Claresholm','AB','CANADA','T0L 0T0','(403) 625-2562','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 23:17:54',0,NULL,3,1,2,1,NULL,'clay5saddle'),(18768,744342413018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','brockusn','brockusn@msn.com','D. Brockschmidt','6331 Grandridge Dr SE','Port Orchard','WA','UNITED STATES','98367-9542','(360) 874-8963','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-22 23:38:28',0,NULL,3,0,3,1,'RA184571413CN ','brockusn\rXXXL   (已入库）'),(18769,741362664001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mrsgoo1','mrsgoo1@msn.com','Monica Brown','7177 Brockton Ave<br>Ste 105','Riverside','CA','UNITED STATES','92506','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 00:16:25',0,NULL,3,1,1,1,NULL,'mrsgoo1'),(18770,744355956018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',1,'AD1170',8.99,'photographyacc','jimcr2009','springcreekphoto@shaw.ca','Jim Ryerson','453 Head St.','Victoria','BC','CANADA','V9A 5S1','(250) 889-2979','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 00:27:54',0,NULL,3,1,2,1,NULL,'jimcr2009'),(18771,800998550017,270751504530,'YongNuo Flash Battery Pack for Canon 580EXII CP-E4 /8AA',1,'AB3307',52,'photographyacc','scotth3268','scotthu55@fastmail.fm','you hua hu','206 Beales Rd<br>Greensborough','Melbourne','Victoria','AUSTRALIA','3088','0394447082','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 00:34:22',0,NULL,3,1,3,1,'RA184571435CN ','scotth3268'),(18772,801021816017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',2,'AA1305',5,'photographyacc','tonybirds','akirkby@vtown.com.au','Tony Kirkby','20 Buckingham Rd Kelmscott','perth','Western Australia','AUSTRALIA','6111','0893902013','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 02:04:08',0,NULL,3,1,2,1,NULL,'tonybirds'),(18773,741405422001,110615425081,'Original Nikon Photo Vest for D60 D80 D90 D5000 D700',1,'AA2111',59,'hermeshine','aplesq','aplesq@aol.com','arthur lindars','514 S Citrus St','west covina','CA','UNITED STATES','91791-2112','(909) 762-7640','NoPaymentFailure','CheckoutComplete','Other','2011-10-23 03:25:37',0,NULL,3,0,1,1,NULL,'aplesq\r75th 周年那款  XXL  (已入库）'),(18774,744399800018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','tonkavan','andrewteakle@bigpond.com','Andrew Teakle Photography','6 Kai Court','Cashmere','Queensland','AUSTRALIA','4500','0408746869','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 03:36:52',0,NULL,3,1,3,1,'RA184571444CN ','tonkavan'),(18775,783968872002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','dbto_edm','boyd.tolton@synodon.com','Boyd Tolton','#401, 532 - 5 Ave NE','Calgary','AB','CANADA','T2E 0L2','(403) 561-9198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 04:19:41',0,NULL,3,1,5,1,'CP238090108CN ','dbto_edm'),(18776,744409544018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','derbarrett','bigdaddy2927@yahoo.com','Derrick Barrett','920 Memorial Dr SE<br>Unit 5','Atlanta','GA','UNITED STATES','30316-1480','(704) 779-7914','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 04:26:48',0,NULL,3,1,3,1,'RA184571458CN ','derbarrett'),(18777,744410903018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','essential78','kongvue@yahoo.com','Kong Vue','8215 Gwinhurst Cir','Sacramento','CA','UNITED STATES','95828-7550','(916) 290-2118','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 04:35:23',0,NULL,3,1,1,1,NULL,'essential78'),(18778,741419023001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','3ntreri','dave.nunez@gmail.com','David Nunez','750 Saint Andrews Street','Nanaimo','BC','CANADA','V9S 1S6','(250) 751-3827','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 04:41:52',0,NULL,3,1,2,1,NULL,'3ntreri'),(18779,744423589018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','elenaclaudia09','elenahierro1@hotmail.com','Elena Hierro Rubio','c/zabala, n65, 2d','bilbao','País Vasco','SPAIN','48003','688677879','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 05:50:42',0,NULL,3,1,2,1,' ','elenaclaudia09\r白色'),(18780,741440969001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',2,'AD1195',58,'hermeshine','mariana5689','mariana_timova@hotmail.com','Mariana Trajkovski','1601/3 Rockdale Plaza Drive','Rockale','New South Wales','AUSTRALIA','2216','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 06:52:31',0,NULL,3,1,3,1,'RA184571682CN ','mariana5689'),(18781,744440729018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','centrino75','renard151@gmail.com','sgobba stephanie ou caissier','Parking Saint-Paul<br>Place Saint-Paul 3B','Liege','','BELGIUM','4000','0475866855','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 07:17:15',0,NULL,3,1,3,1,'RA184571427CN ','centrino75\r申报  reflector holder $15'),(18782,874621197015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','gemunit','gemmaulivi@yahoo.co.uk','Flt Lt O Peters','Officers Mess<br>RAF Marham','Kings Lynn','Norfolk','UNITED KINGDOM','PE33 9NP','','PayPalPaymentInProcess','CheckoutComplete','UK_ExpeditedShippingFromOutside','0000-00-00 00:00:00',0,NULL,7,1,18,1,'','gemunit\r英标  白色'),(18783,801107271017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','amira567','amira.sarusi@gmail.com','amira sarusi ganz','bet gan<br>54','yavneel','IN','ISRAEL','15225','04-6708641','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 08:27:12',0,NULL,3,1,11,1,NULL,'amira567'),(18784,744463591018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','pics35','cheryl_smith30@hotmail.com','cheryl smith','1 Alma Road','Parkdale','Victoria','AUSTRALIA','3195','0395876367','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 08:34:14',0,NULL,3,1,2,1,NULL,'pics35'),(18785,779950322002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','paulant28','kajzar@tiscali.it','Paula Kajzar','Via Spagnolio 11a','Reggio Calabria','RC','ITALY','89128','3488252892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 08:53:55',0,NULL,3,0,2,1,NULL,'paulant28\r欧标'),(18786,784041620002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',4,'AA1216',55.6,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 09:26:28',0,NULL,3,1,3,1,'RA184571387CN ','happyjaya'),(18787,784067582002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',16.9,'hermeshine','74bluesnow','vanessaneill@westnet.com.au','vanessa Neill','37 Davis st','Rockhampton','Queensland','AUSTRALIA','4700','0749227508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 10:30:43',0,NULL,3,1,2,1,NULL,'74bluesnow'),(18788,856706540016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','lairdofglencairn2010','lairdofglencairn@gmx.co.uk','Christian Hacker','4A Seafield Lane','Dundee','Dundee (City of)','UNITED KINGDOM','DD1 4JZ','01382862406','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 11:37:22',0,NULL,3,1,2,1,NULL,'lairdofglencairn2010'),(18789,744544169018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',4.5,'photographyacc','teepee0409','njbrownlie@yahoo.com.au','Natalia Brownlie','5016 Gregory Highway<br>PO Box 2546','Emerald','Queensland','AUSTRALIA','4720','0749822289','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 11:47:50',0,NULL,3,0,2,1,NULL,'teepee0409'),(18790,744441413018,280666917737,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',65,'photographyacc','tanyasargeant','mhazell60@hotmail.com','Michael Hazell','26 Carrington Street','Deakin','Australian Capital Territory','AUSTRALIA','2600','0262889305','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 12:05:20',0,NULL,3,1,4,1,'YW867738293CN ','tanyasargeant'),(18791,784111515002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','cwdosman','info@smile-connection.ch','Michael Kuhn','Ruetistrasse 11','Zollikon','','SWITZERLAND','8702','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-23 12:14:58',0,NULL,3,0,17,0,NULL,'cwdosman'),(18792,741559000001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cwdosman','info@smile-connection.ch','Michael Kuhn','Ruetistrasse 11','Zollikon','','SWITZERLAND','8702','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-23 12:20:34',0,NULL,3,0,3,1,'RA184571395CN ','cwdosman\r摄影背心 Canon  老款    L      1\r摄影背心 Nikon  老款  L          1\r已入库'),(18793,874767555015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT076',29,'hutongstore','erax1','erax@iinet.net.au','Michael Goh','9 Smoothstone Court','Joondalup','Western Australia','AUSTRALIA','6027','0893000338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 12:39:53',0,NULL,3,1,3,1,'RA117779526CN\r ','erax1'),(18794,784129381002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','robal_de','suwalski@online.de','Robert Suwalski','Kleiststr.18','Singen','','GERMANY','78224','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 12:55:19',0,NULL,3,0,2,1,NULL,'robal_de\r欧标'),(18795,784163618002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','yaronharel','yaron@technion.ac.il','Yaron Harel','p.o.box 574','Ramat Yishai','','ISRAEL','30095','972 52 8977929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 14:07:28',0,NULL,3,1,3,1,'RA117779530CN\r','yaronharel\r反光板支架     1\r斜臂       1\r'),(18796,874831749015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','stats94','matthew.d.williamson@btinternet.com','Matthew Williamson','39 St. Johns street','Crowthorne','Berkshire','UNITED KINGDOM','RG457NQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 14:27:00',0,NULL,3,1,3,1,'RA184571957CN ','stats94'),(18797,741646035001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','kamarbh11','kamarbh@gmail.com','KAMARUL BAHARI ADAM','NO 5 , TAMAN INTAN 2 , KAMPUNG LIMBUNG , PAKA, DUNGUN ,','MALAYSIA','terengganu','MALAYSIA','23100','098275785','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-23 15:18:00',0,NULL,3,1,17,0,NULL,'kamarbh11'),(18798,784204492002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','kamarbh11','kamarbh@gmail.com','KAMARUL BAHARI ADAM','NO 5 , TAMAN INTAN 2 , KAMPUNG LIMBUNG , PAKA, DUNGUN ,','MALAYSIA','terengganu','MALAYSIA','23100','098275785','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 15:20:18',0,NULL,3,1,3,1,'RA184571943CN ','kamarbh11\r摄影背心 绿色薄 canon xl    1\r爵影红外 canon     1\r\r'),(18799,784217427002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','hurley_1101','hurley_1101@hotmail.com','Jayme Ford','171 Metcalf Avenue','Red Deer','AB','CANADA','T4R 1W9','(403) 505-9628','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-23 15:40:31',0,NULL,3,1,3,1,'RA184571400CN ','hurley_1101'),(18800,741649034001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1307',5.2,'hermeshine','pientje2009','nienepientje@gmail.com','Janine Tepper','Romeinenlaan 40','Apeldoorn','','NETHERLANDS','7312kz','0645632640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 15:43:29',0,NULL,3,1,2,1,NULL,'pientje2009'),(18801,744688396018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','nasmnto','nasmnto@cogeco.ca','andrew nascimento','2284 Foxfield Rd','oakville','ON','CANADA','L6M 4C9','(905) 465-2106','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 16:10:38',0,NULL,3,1,2,1,NULL,'nasmnto'),(18802,741711822001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','lemirearts','lemireart@me.com','QAI Att: Alain Lemire','329 de la Commune West #300','Montreal','QC','CANADA','H2Y 2E1','(514) 499-3000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 16:49:10',0,NULL,3,1,2,1,NULL,'lemirearts'),(18803,784323418002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','eye-am-who-eye-am','pawlyschyn@gmail.com','Peter Pawlyschyn','5419 Hollywood Blvd.<br>Suite# C707','Los Angeles','CA','UNITED STATES','90027','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-23 17:49:59',0,NULL,3,1,1,1,NULL,'eye-am-who-eye-am'),(18804,875058569015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','mwar7954','marjorieward2@aol.com','Marjorie Ward','38 The Paddock<br>Thorley','Bishops Stortford','Hertfordshire','UNITED KINGDOM','CM23 4JN','01279505203','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-23 18:23:10',0,NULL,3,1,2,1,NULL,'mwar7954'),(18805,741821708001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','sim_pakost','sim_pakost24@hotmail.com','SIME JADRESIN','Rue du cimetiere 11','ARLON','','BELGIUM','6700','0496384993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 18:41:47',0,NULL,3,1,2,1,NULL,'sim_pakost'),(18806,741853176001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','tubio06fernando','tubio06@yahoo.com.ar','fernando tubio','davila, 1192<br>1192','ciudad autonoma de buenos aires','buenos aires','ARGENTINA','1406','540111569907336','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-23 19:18:03',0,NULL,3,0,3,1,'RA184571930CN ','tubio06fernando\rXXL   (已入库）\r帮我看一下库存是不是发完就没有了\r不是，还有8件\r'),(18807,784455895002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','matti3650','masapirhonen@dnainternet.net','Matti Pirhonen','Tiirankatu 13','Lohja','','FINLAND','08150','+358445056886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 20:16:23',0,NULL,3,1,2,1,NULL,'matti3650'),(18808,784482199002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','carcasg','carcasg@terra.es','JOSE CARLOS CASTRO GARCIA','C/ABANDOLA, 2, 1ºB','VELEZ-MALAGA','Andalucía Ceuta y Melilla','SPAIN','29700','652837198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 20:58:40',0,NULL,3,1,3,1,'RA184571373CN ','carcasg'),(18809,744931808018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','jlowtwo330','jlove@sssnet.com','Jane Love','9342 Paulding St NW','Massillon','OH','UNITED STATES','44646-9361','(330) 408-7255','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 20:43:53',0,NULL,3,1,3,1,'RA184571360CN ','jlowtwo330'),(18810,801613766017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','kenegil','kenen@online.no','Ken Egil Nesse','Opstadfjellet 16','Greaaker','','NORWAY','1719','+4769129455','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 21:11:53',0,NULL,3,1,2,1,NULL,'kenegil'),(18811,857197518016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','gillespinault','gilles@banana2000.net','softkinetic (gilles pinault)','15 boulevard de la plaine','Ixelles','','BELGIUM','1050','0479593228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-23 21:27:20',0,NULL,3,1,4,1,'YW867738304CN ','gillespinault\rlighting kit  $20\r欧标'),(18812,741945973001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','carcasg','carcasg@terra.es','JOSE CARLOS CASTRO GARCIA','C/ABANDOLA, 2, 1ºB','VELEZ-MALAGA','Andalucía Ceuta y Melilla','SPAIN','29700','652837198','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-23 21:47:51',0,NULL,3,1,3,1,'RA184571926CN ','carcasg\r\r'),(18813,801658613017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','rgrossod','webmaster@cuidanet.com','Ramon Grosso Dolarea','Lomo La Plana 14 3, 3 A','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35019','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-23 22:53:32',0,NULL,3,1,2,1,NULL,'rgrossod'),(18814,744996139018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','pezhy187','pezh.moradi@gmail.com','Pezh Moradi','14 Talinga Place','Cherrybrook','New South Wales','AUSTRALIA','2126','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-23 23:02:25',0,NULL,3,1,4,1,'YW867739936CN\r','pezhy187\r2m 灯架   1\r反光板支架    1\r大力夹云台    1'),(18815,744996597018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',13,'photographyacc','pezhy187','pezh.moradi@gmail.com','Pezh Moradi','14 Talinga Place','Cherrybrook','New South Wales','AUSTRALIA','2126','','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-23 23:03:37',0,NULL,3,1,17,0,NULL,'pezhy187'),(18816,801664505017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','pezhy187','pezh.moradi@gmail.com','Pezh Moradi','14 Talinga Place','Cherrybrook','New South Wales','AUSTRALIA','2126','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-23 23:08:45',0,NULL,3,1,4,1,'YW867738326CN ','pezhy187'),(18817,741994060001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','broncobob1957','bronco_bob1957@msn.com','BOB Cothran','650 S Clinton St<br>Apt 6C','denver','CO','UNITED STATES','80247-1544','(303) 915-2618','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 00:06:24',0,NULL,3,1,1,1,NULL,'broncobob1957'),(18818,784566949002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','nesqa','anrylka@yahoo.com','Anna Nowicka','188 Basswood Dr','Elk Grove Village','IL','UNITED STATES','60007-1718','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-24 00:35:27',0,NULL,3,1,1,1,NULL,'nesqa'),(18819,801746191017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','oh_monika','monika-milanovic@hotmail.com','Arsenia Milanovic','34/53 Portland crescent','Maroubra','New South Wales','AUSTRALIA','2035','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 03:01:02',0,NULL,3,1,2,1,NULL,'oh_monika'),(18820,875403205015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',26.9,'hutongstore','keleung','kennyleung@gmail.com','Leung Kenny','3 Clarke Place, Killara','Sydney','New South Wales','AUSTRALIA','2071','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 04:17:38',0,NULL,3,1,3,1,'RA117779472CN\r ','keleung'),(18821,875403154015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','thomasineivey','lizzy.thomasine.ivey@gmail.com','liz ivey','23 milverton court','southampton','Hampshire','UNITED KINGDOM','so18 6sg','02380466466','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 04:17:48',0,NULL,3,1,3,1,'RA117779628CN\r ','thomasineivey'),(18822,783425830002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','tirilhjelm','tiril.hjelmeland@gmail.com','Tiril Hjelmeland','Kalfarveien 58','Bergen','Bergen','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 04:36:48',0,NULL,3,0,17,0,NULL,'tirilhjelm'),(18823,875419494015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','pushtunas1','pushtunas@gmail.com','Edvardas Giedrys','V. Kreves pr. 53-249','Kaunas','','LITHUANIA','LT-50358','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 05:32:31',0,NULL,3,1,2,1,NULL,'pushtunas1'),(18836,742171190001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','19camquilty89','camquilty@hotmail.com','Cameron   Quilty','2/56 Portland Crescent','Maroubra','New South Wales','AUSTRALIA','2035','0412655760','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 12:06:20',0,NULL,3,1,2,1,NULL,'19camquilty89'),(18824,745122551018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',89.5,'photographyacc','marie_louise28','mystina21@hotmail.com','Marie-Louise Collins','202-4505 Grange Street','Burnaby','BC','CANADA','V5H 1P7','(604) 910-5684','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 07:07:42',0,NULL,3,1,5,1,'CP238090010CN ','marie_louise28\r白 +  黑'),(18825,745122919018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',60,'photographyacc','infrcs','morjanoff@yahoo.com.au','Paul Morjanoff','13 Elizabeth St Avalon','Sydney','New South Wales','AUSTRALIA','2107','0299188647','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 07:11:43',0,NULL,3,1,17,0,NULL,'infrcs'),(18826,745123222018,280745347210,'Photo Video Continuous light 5 Head E27 AC Bulb Socket with 60x90 Softbox',1,'AD1191',62,'photographyacc','infrcs','morjanoff@yahoo.com.au','Paul Morjanoff','13 Elizabeth St Avalon','Sydney','New South Wales','AUSTRALIA','2107','0299188647','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 07:11:43',0,NULL,3,1,17,0,NULL,'infrcs'),(18827,801796826017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','infrcs','morjanoff@yahoo.com.au','Paul Morjanoff','13 Elizabeth St Avalon','Sydney','New South Wales','AUSTRALIA','2107','0299188647','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 07:11:44',0,NULL,3,1,17,0,NULL,'infrcs'),(18828,745122741018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',20,'photographyacc','infrcs','morjanoff@yahoo.com.au','Paul Morjanoff','13 Elizabeth St Avalon','Sydney','New South Wales','AUSTRALIA','2107','0299188647','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 07:11:44',0,NULL,3,1,4,1,'YW867739914CN ','infrcs\r45w 5500k 灯泡 220v      2\r115w 5500k 灯泡  220v    4\r5灯头+60-90棚      1\r一转四 灯头      2\r\r'),(18829,875446293015,250895544246,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',56.99,'hutongstore','ferrro123','ferri@pobox.sk','Frantisek Harangozo','Lomnícka 12','Nitra','Nitra','SLOVAK REPUBLIC','94901','00421905321308','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 07:27:56',0,NULL,3,1,3,1,'RA117779591CN\r ','ferrro123'),(18830,742107623001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','kirstie_babe','little_miss_kirstie@hotmail.com','Kirstie McLellan','22 Laanecoorie Drive','Lysterfield','Victoria','AUSTRALIA','3156','0458063508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 07:54:10',0,NULL,3,1,3,1,'RA117779512CN\r ','kirstie_babe'),(18831,745144206018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','kewday_8','kewday_8@yahoo.com','Raymond Hui','26, Azzure St','Eight Mile Plains','Queensland','AUSTRALIA','4113','61412495883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 08:44:17',0,NULL,3,1,3,1,'RA117779662CN\r ','kewday_8'),(18832,745144992018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','seventeenseventeen','djseventeen@hotmail.com','Danielle Jones','23 Island Outlook Ave<br>Thornlands','Brisbane','Queensland','AUSTRALIA','4164','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-24 08:49:27',0,NULL,3,1,4,1,'YW867739925CN ','seventeenseventeen'),(18833,875472206015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','ian_webster','ebay@mrwebster.co.uk','Ian Webster','Select Appointments<br>Regent Court, Laporte Way','Luton','Beds','UNITED KINGDOM','LU4 8SB','01582811685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 08:55:59',0,NULL,3,1,3,1,'RA117779543CN\r ','ian_webster'),(18834,742124757001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','jackngizmo','gizmo.jack@bigpond.com','Sarah Gardner','PO BOX 1249','Toodyay','Western Australia','AUSTRALIA','6566','0895745675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 09:10:57',0,NULL,3,1,3,1,'RA117779588CN\r ','jackngizmo'),(18835,784714339002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','afro-xmkx','mar.malinowski@gmail.com','CSI, dla: Marcin Malinowski','ul. Balicka 12A/B3','KRAKOW','małopolskie','POLAND','30149','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 10:22:35',0,NULL,3,1,2,1,NULL,'afro-xmkx\r欧标'),(18837,784752083002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','thewrongbananas','david_horwich@yahoo.co.uk','Collage Arts - f.a.o. The London Packshot Company','The Chocolate Factory 2<br>4 Coburg Road','London','London','UNITED KINGDOM','n22 6uj','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 12:33:42',0,NULL,3,1,3,1,'RA117779702CN\r ','thewrongbananas'),(18838,784040268002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','aganan','astiafaya@hotmail.com','Domingo Sosa de la fuente','C/. Héctor nº10','Santa Cruz de Tenerife','Canarias','SPAIN','38160','922597803','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 12:34:24',0,NULL,3,1,2,1,NULL,'aganan'),(18839,857507580016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','dearjym','rossintx@yahoo.com','Emirates Airlines Service Delivery','POBox # 36050 - Archana Nambiar Parakat<br>MailBox #413 (ph.04-441-3695)','Dubai','Dubai','UNITED ARAB EMIRATES','Stf#250331','00971-4-441-3695','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 12:37:32',0,NULL,3,1,2,1,NULL,'dearjym'),(18840,742187622001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','abdullah5050','xx_w2002@hotmail.com','abdullah alshehri','BALADEHAT AL MAJAREDAH - 072812656<br>0592555253','ALMAJAREDAH','ASIR','SAUDI ARABIA','61937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 12:54:55',0,NULL,3,1,2,1,NULL,'abdullah5050'),(18841,784759814002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','barykind2011','barykind@yandex.ru','Dmitriy Barykin','Radiozavodskaja st. 1-1-44','Ryazan','RU','RUSSIAN FEDERATION','390027','79209545796','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 12:58:56',0,NULL,3,1,5,1,'CP238090111CN ','barykind2011'),(18842,745221552018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','benia13','capitanzibbo@hotmail.com','ITALMARITTIMA SRL presso Enrica Pastorino','via savona 1/11','Genova','GE','ITALY','16129','3475391199','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 13:03:21',0,NULL,3,1,2,1,NULL,'benia13'),(18843,741183935001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','vierwols','javierbolea@yahoo.es','Javier Bolea (bei Karagöl)','Eisenbahnstraße 44, 1-OG','Berlin','','GERMANY','10997',' 01788032570','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 13:20:55',0,NULL,3,1,2,1,NULL,'vierwols'),(18844,745229979018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.98,'photographyacc','pahanapp','alex_sachik@list.ru','Oleksandr Sachyk','P.O. Box 139','Kiev','','UKRAINE','03150','0990608090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 13:28:55',0,NULL,3,1,2,1,NULL,'pahanapp'),(18845,875578784015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','vocesspa','borjacarrera_321@hotmail.com','Alejandro Carrera','Oporto Nº 71','Madrid','Madrid','SPAIN','28514','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-24 13:38:59',0,NULL,3,1,4,1,'YW867739892CN','vocesspa'),(18846,745243961018,280696883124,'New Pro Photo Vest for all DSLR fans Mesh-line ',1,'AA1217',24,'photographyacc','hobbybay2005','stasmail@gmail.com','Stanislav Chutko','Shderot James de Rothschild 10b/5','Haifa','','ISRAEL','35151','+(972)545315852','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 14:07:55',0,NULL,5,1,3,1,NULL,'hobbybay2005\r已经发货  没单号\r这个单号丢了   账单上也找不到'),(18847,742214029001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','kasperjuhlkjems','kasperkjems@hotmail.com','Kasper Kjems','Danmarksgade 51, 2. tv.','Aalborg','','DENMARK','9000','004527592934','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 14:18:08',0,NULL,3,1,3,1,'RA117779565CN\r ','kasperjuhlkjems\r新地址\rKasper Juhl Kjems\rBeethovensvej 11, 1. tv.\r2450 Kbh. sv.\rDENMARK\r004527592934\r'),(18848,742229362001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','bingbing88','kelven_wong@hotmail.com','Kelven Wong','14987 59 Avenue','Surrey','BC','CANADA','V3S4S6','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-24 14:57:42',0,NULL,3,1,2,1,NULL,'bingbing88'),(18849,875602626015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','ivxma','andouta@gmail.com','Todorov (kod Perosic)','Trnjanska cesta 7','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 14:31:56',0,NULL,3,1,5,1,'CP238090125CN ','ivxma'),(18850,742237251001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','maxboum2001','maxime_bouchard1@hotmail.com','Maxime Bouchard','1435 rue de Léry','Québec','QC','CANADA','G1J 4X5','(418) 931-4795','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-24 15:19:40',0,NULL,3,1,5,1,'CP238090235CN ','maxboum2001\r白+黑'),(18851,784816631002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','videoupa','clipmakerleha@gmail.com','Aleksey Milanichev','9a Revolucye Str.App.28','Perm','Permskiy kray','RUSSIAN FEDERATION','614007','7(342)2170224','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-24 15:35:07',0,NULL,3,1,3,1,'RA117779486CN\r ','videoupa\r欧标'),(18852,745307508018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',52,'photographyacc','ddaihun','ddai@citromail.hu','Dávid Németh','Fő u. 150.','Sopron-Balf','','HUNGARY','9494','06204558796','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 16:56:41',0,NULL,3,1,17,0,NULL,'ddaihun'),(18853,745306957018,280717920072,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',28,'photographyacc','ddaihun','ddai@citromail.hu','Dávid Németh','Fő u. 150.','Sopron-Balf','','HUNGARY','9494','06204558796','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-24 16:56:41',0,NULL,3,1,5,1,'CP238014013CN ','ddaihun\r蜂窝      1\r70x100cm通用卡口柔光箱     1\rRA117779680CN换大包 新单号 CP238014013CN\r'),(18854,784855766002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','yigal79','yigal1979@bezeqint.net','igal drogobetski','kdushey kair 42','akko','israel','ISRAEL','24663','97249912932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 17:05:00',0,NULL,3,1,2,1,NULL,'yigal79'),(18855,784858087002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','tawfeekmohammed','momaezz@hotmail.com','Fatimah Al-Kabaz','Taruot','Qatif','TAROUT','SAUDI ARABIA','31911','966540616582','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 17:08:22',0,NULL,3,1,3,1,'RA117779676CN\r ','tawfeekmohammed'),(18856,742293835001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','peternikon','peepboon@hotmail.com','Peter Hong','049.4 Severn Point<br>13 Llys Y Gored Ddu','Cardiff','Cardiff','UNITED KINGDOM','cf10 3ex','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 17:24:38',0,NULL,3,0,2,1,NULL,'peternikon\r黑色 '),(18857,875698264015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',2,'AD1126',15.2,'hutongstore','welcomefree','internetlevel@gmail.com','Lorant Kovacs','30/A Nagyvathy Street','Keszthely','','HUNGARY','8360','+36704071599','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 17:26:01',0,NULL,3,1,11,1,NULL,'welcomefree\r110cm 反光伞（黑色的）   2'),(18858,742299189001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','angeldazie','jamie@colorsplashstudio.com','Cindy Brokus','3169 Melodee Park Dr','Allegan','MI','UNITED STATES','49010-9776','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 17:34:34',0,NULL,3,1,3,1,'RA117779614CN\r ','angeldazie'),(18859,742335787001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','obiwanhav001','obiwanhavanese@gmail.com','Roger Hur','1022 Nanaimo Street','New Westminster','BC','CANADA','V3M 2E6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 18:38:29',0,NULL,3,1,2,1,NULL,'obiwanhav001'),(18860,875762984015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','lilnisse','carina.radenmark@ostra.goteborg.se','Carina Rådenmark','Plantagegatan 11','Göteborg','','SWEDEN','41305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 19:07:52',0,NULL,3,1,17,0,NULL,'lilnisse'),(18861,875770741015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','lilnisse','carina.radenmark@ostra.goteborg.se','Carina Rådenmark','Plantagegatan 11','Göteborg','','SWEDEN','41305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 19:07:53',0,NULL,3,1,2,1,NULL,'lilnisse\r肥皂盒 柔光罩   sb800 sb600    2'),(18862,856840182016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','sivanovai','sivanovai@abv.bg','Ivan Ivanov','Graf Ignatiev Str.36,Entr.0, Apt.5','Stara Zagora','','BULGARIA','6000','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-24 19:14:38',0,NULL,3,1,3,1,'RA117779693CN\r ','sivanovai\r欧标'),(18863,857799720016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','0170david4444','david_maintenance@hotmail.com','lyndsey armstrong','11 higher lane haslingden<br>rossendale lancs','haslingden','Lancashire','UNITED KINGDOM','bb4 5rd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 21:05:12',0,NULL,3,1,3,1,'RA117779659CN\r ','0170david4444'),(18864,784998316002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','locknet','kent.tu@sbcglobal.net','Kent Tu','7941 E Elderwood Ave','Orange','CA','UNITED STATES','92869','(714) 744-6167','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 21:25:31',0,NULL,3,1,3,1,'RA117779469CN\r ','locknet'),(18865,875881509015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','jpuddy','jdpuddy@gmail.com','John Puddy','26 Lakewood Road<br>Henleaze','Bristol','Avon','UNITED KINGDOM','BS10 5HH','07970069226','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-24 21:54:32',0,NULL,3,1,3,1,'RA117779557CN\r ','jpuddy'),(18866,875905472015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','vanbus','denu@melbpc.org.au','Dennis Edwards','5 Lombard Road','Vermont','Victoria','AUSTRALIA','3133','0398743649','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-24 22:56:16',0,NULL,3,1,2,1,NULL,'vanbus'),(18867,742460400001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','cepbac','makarov_sergey@inbox.lv','Sergejs Makarovs','Marsa g. 4-110','Riga','Rigas raj','LATVIA','LV-1082','+(371) 28350613','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-24 23:19:54',0,NULL,3,1,2,1,NULL,'cepbac'),(18868,741379214001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',2,'AE1502',159.92,'hermeshine','falt8550','francoisealteus@yahoo.com','francoise alteus','750 NE 142nd St','North Miami','FL','UNITED STATES','33161-3238','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-24 23:36:59',0,NULL,3,1,4,1,'YW867739903CN ','falt8550\r两个'),(18869,745510156018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','fernandita-photographer','ferne_millen@yahoo.com.au','Ferne Millen','9 Windarra Grove','Jan Juc','Victoria','AUSTRALIA','3228','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-24 23:53:44',0,NULL,3,1,3,1,'RA117779645CN\r ','fernandita-photographer'),(18870,785052152002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','zoethebrave','zoethebrave@mac.com','Zoe Gemelli','313-135 Bleecker St.','Toronto','ON','CANADA','M4X 1X2','(647) 955-6271','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 00:15:53',0,NULL,3,1,2,1,NULL,'zoethebrave'),(18871,745518631018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','ferryan_kodhiat','ferryan_k@hotmail.com','ferryan kodhiat','1 Malcolm Court','Melbourne','Victoria','AUSTRALIA','3149','6141379569','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-25 00:25:34',0,NULL,3,1,2,1,NULL,'ferryan_kodhiat'),(18872,785054131002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 00:31:42',0,NULL,3,1,17,0,NULL,'jackchan1974'),(18873,785057802002,120601700851,'TianYa New Graduated Blue Filter for Cokin P Series ',1,'AA2320',7.2,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 00:36:20',0,NULL,3,1,17,0,NULL,'jackchan1974'),(18874,742482673001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,','Tawau','Sabah','MALAYSIA','91007','6089772277','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 00:43:13',0,NULL,3,1,2,1,NULL,'jackchan1974\r天涯方形滤镜  渐变橙    1\r天涯方形滤镜  渐变蓝    1\r天涯方形滤镜  渐变棕     1'),(18875,742467906001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','fitchboy804','bidbuy.fitchboy@gmail.com','Bidbuy Inc.','7050 Village Dr<br># F-100','Buena Park','CA','UNITED STATES','90621-2277','','NoPaymentFailure','CheckoutComplete','Other','2011-10-25 02:17:45',0,NULL,3,0,1,1,NULL,'fitchboy804\r客户要在包装外写他的ebay 号 \rItem Id: 110529627228\r还要一张发票（发票已打）\r新地址\rBidbuy Inc.\r7050 Village Drive #F-100 \rBuena Park, CA 90621\rUNITED STATES\r'),(18876,785093246002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','boam8292','sanfordlouis@gmail.com','Louis Sanford','2020 N Ensenada Ln','Casa Grande','AZ','UNITED STATES','85122-6542','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-25 02:57:35',0,NULL,3,1,1,1,NULL,'boam8292'),(18877,785114532002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','azza_112','ras281@gmail.com','Rasanoor Azza Samsudin','Blok \'A\' Tingkat 6 No:4<br>Apartment Tasek','Jalan Tasek Lama','Bandar Seri Begawan','BRUNEI DARUSSALAM','BS8311','+6738845736','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 04:24:31',0,NULL,5,1,18,0,NULL,'azza_112'),(18878,742542318001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','bill_and_sue','xtcbill@bigpond.com','Bill Duhig','4 Kensington Way<br>Pearsall','Perth','Western Australia','AUSTRALIA','6065','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 05:09:26',0,NULL,3,1,2,1,NULL,'bill_and_sue'),(18879,857977818016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','andy_gp1','andy@gock.net','Andy Gock','PO Box 371','Cardiff','New South Wales','AUSTRALIA','2285','0413710964','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-25 06:34:58',0,NULL,3,1,3,1,'RA117779574CN\r ','andy_gp1'),(18880,742556782001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',2,'AO0033',13.98,'hermeshine','markoosh','mark@aboxford.com.au','Mark Fleiszig','1 Hume Road','North Laverton','Victoria','AUSTRALIA','3026','0392404040','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 06:35:01',0,NULL,3,1,2,1,NULL,'markoosh'),(18881,742558838001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',5.49,'hermeshine','orhanavci39','avci39@hotmail.com','Orhan Ogurcu','22 Stawell street','Coburg','Victoria','AUSTRALIA','3058','0426269060','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 06:47:45',0,NULL,3,1,2,1,' ','orhanavci39'),(18882,785148159002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'',85,'hermeshine','kauffman2835','kauffman238@gmail.com','Stanislav Nikolaev','ul. Sharikopodshipnikovskaya 12, kv. 125','Moscow','','RUSSIAN FEDERATION','115088','9262102947','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 07:30:32',0,NULL,3,1,5,1,'CP238090173CN\r ','kauffman2835\r欧标\r桌面灯  2\r38cm 灯架   2\r45w220v  灯泡  2\r40cm 圆形柔光棚   1\r肥皂盒 柔光罩  430EX   1\rlenspen   1\r气吹 + 布   1'),(18883,742569278001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','kauffman2835','kauffman238@gmail.com','Stanislav Nikolaev','ul. Sharikopodshipnikovskaya 12, kv. 125','Moscow','','RUSSIAN FEDERATION','115088','9262102947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 07:42:26',0,NULL,3,1,17,0,NULL,'kauffman2835'),(18884,785151579002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','kauffman2835','kauffman238@gmail.com','Stanislav Nikolaev','ul. Sharikopodshipnikovskaya 12, kv. 125','Moscow','','RUSSIAN FEDERATION','115088','9262102947','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 07:45:10',0,NULL,3,1,17,0,NULL,'kauffman2835'),(18885,745619872018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','mickschoonen44','mickschoonen@hotmail.com','Mick Schoonen','7 spencer street','Lawnton','Queensland','AUSTRALIA','4501','0423552685','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-25 08:06:37',0,NULL,3,1,3,1,'RA117761176CN\r ','mickschoonen44'),(18886,742592096001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',45.99,'hermeshine','kinguiorasta','netolauro@yahoo.com.br','Dirlene Gomes','Rua 7 de setembro, 55.<br>Bairro: Tabuleiro dos Martins.','Maceió','Alagoas','BRAZIL','57061-140','55-82-33241676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 09:17:28',0,NULL,3,1,3,1,'RA117761202CN\r ','kinguiorasta'),(18887,876097365015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','susiesheepskin','susiedeadman@hotmail.com','susannah deadman','46 firle crescent','lewes','East Sussex','UNITED KINGDOM','bn7 1qg','07916119285','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 10:01:40',0,NULL,3,1,3,1,'RA117761065CN\r ','susiesheepskin'),(18888,876105656015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','plumedecume','denisblemont@free.fr','blemont denis','residence belle plaine bat bleuet','la ciotat','Provence-Alpes-Côte d\'Azur','FRANCE','13600','0442717911','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 10:57:30',0,NULL,3,1,2,1,NULL,'plumedecume'),(18889,876120111015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','7153lindal','llavin61@msn.com','kenneth davies','2,fairysfield<br>saxby-all-saints','brigg','Lincolnshire','UNITED KINGDOM','DN20 0QD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 11:07:14',0,NULL,3,1,3,1,'RA117761012CN\r ','电话是：\r01652 618531'),(18890,742622120001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','mad_legion','dj_burns@hotmail.co.uk','Gordon Burns','216 Weedington Road','London','London','UNITED KINGDOM','nw5 4qq','07854915112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 11:10:22',0,NULL,3,1,2,1,NULL,'mad_legion'),(18891,742626350001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','vinhchau2011','qvchau@gmail.com','vinh chau','100 willys avenue','keilor downs','Victoria','AUSTRALIA','3038','030413002070','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 11:24:49',0,NULL,3,0,3,1,'RA117761030CN\r ','vinhchau2011\rXL 已入库'),(18892,742639275001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','jkmat5','jkmateomartinez@hotmail.com','JOSEBA KOLDO MATEO MARTINEZ','LANDETXOS 11,  4º DCHA<br>n/a','MUNGUIA','País Vasco','SPAIN','48100','657735511','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 12:06:30',0,NULL,3,1,2,1,NULL,'jkmat5'),(18893,785224074002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','danielyu2010','danielyu2009@me.com','Danke Yu','34 Belinda Crescent','Wheelers Hill','Victoria','AUSTRALIA','3150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 12:22:27',0,NULL,3,1,3,1,'RA117761114CN\r ','danielyu2010'),(18894,858098448016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','utilityw','ebayuk@adrian.nelson.name','Adrian Nelson','Quest Systems Development<br>Millpool House, Mill Lane','Godalming','Surrey','UNITED KINGDOM','GU7 1EY','01483427317','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 12:50:28',0,NULL,3,1,2,1,NULL,'utilityw'),(18895,802406211017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',25,'photographyacc','microlab629648','witazzew@yandex.ru','Maria Kharchevnikova','Orehoviy proezd-9 kv.228','Moscow','','RUSSIAN FEDERATION','115573','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-25 12:53:53',0,NULL,3,1,2,1,NULL,'microlab629648'),(18896,785240146002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ak585','m.cozzolino@email.it','COZZOLINO Massimo','Brottu Sarippa, 4 ( Ottava )','SASSARI','SS','ITALY','07100','329 3503721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:12:49',0,NULL,3,1,17,0,NULL,'ak585'),(18897,745713008018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','blooddropcookies','jessica.day23@gmail.com','Day Jessica','3/108 Bridge Street','Port Macquarie','New South Wales','AUSTRALIA','2444','0265844715','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-25 13:24:09',0,NULL,3,1,3,1,'RA117761131CN\r ','blooddropcookies'),(18898,785245034002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','ak585','m.cozzolino@email.it','COZZOLINO Massimo','Brottu Sarippa, 4 ( Ottava )','SASSARI','SS','ITALY','07100','329 3503721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:26:41',0,NULL,3,1,2,1,NULL,'ak585\rHB-7 花瓣    1\rNIKON 镜头盖 77mm   1'),(18899,785245334002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bigbadben333','ben.ceponkus@gmail.com','Ben Ceponkus','P.O. Box 329','Metcalfe','ON','CANADA','K0A 2P0','(613) 445-5419','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 13:29:47',0,NULL,3,0,3,1,'RA117761026CN\r ','bigbadben333\r3XL  已入库'),(18900,785244302002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','maikel.mek','maikel.winkelmann@gmail.com','maikel winkelmann','Rua senador pinheiro machado 1248','santa cruz do sul','Rio grande do sul - RS','BRAZIL','96810-136','05130562487','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 13:34:07',0,NULL,3,1,3,1,'RA117761128CN\r ','maikel.mek'),(18901,745731702018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','elhb','lhwpg@yahoo.com','LOUIS HOLZTRAGER','527 Waterfront Drive','WINNIPEG','MB','CANADA','R3B 0G8','(204) 942-4701','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-25 14:16:52',0,NULL,3,1,5,1,'CP238090195CN','elhb'),(18902,742588713001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','2010*adalberto','adalberto.miranda@yahoo.com.br','Ivone Zoglio','Rua Sebastião Fabiano Dias 233/1103A Belvedere','Belo Horizonte','Minas Gerais','BRAZIL','30320-690','031-32817337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 14:53:44',0,NULL,3,1,2,1,NULL,'2010*adalberto\r欧标'),(18903,742695538001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cannelllechristine','cannellle@msn.com','christine boulay','78 place de la paix','repentigny','QC','CANADA','j6a5b3','(514) 912-4856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 14:56:51',0,NULL,3,1,2,0,NULL,'cannelllechristine\r1.6x2.1 蓝色'),(18904,743036720018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','xspimages','7robby7@cox.net','Lisa Berard','20 Hall Ave','Newport','RI','UNITED STATES','02840-2141','(401) 849-7739','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-25 15:07:05',0,NULL,3,0,3,1,'RA184570903CN  ','xspimages\rxxxl   （已入库）'),(18905,785285293002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pask99','b.photo@videotron.ca','pascal baldini','109 frontenac','sherbrooke','QC','CANADA','J1H 1J7','(819) 562-0900','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 15:18:38',0,NULL,3,0,3,1,'RA117761105CN\r ','pask99\rL  已入库'),(18906,742705262001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','xomatos','misthah_@hotmail.com','Ibrahim Misthah','Melavahi<br>Raiyvilla Hingun','Male\'','Henveiru','MALDIVES','20050','(+960) 9993777','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:21:06',0,NULL,3,1,2,1,NULL,'xomatos'),(18907,742659222001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','olegstriped','oleg.striped@gmail.com','Oleg Oparanyuk','Sobranecka, 4','Uzhgorod','Zakarpatska','UKRAINE','88000','+380990592898','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:24:33',0,NULL,3,1,17,0,NULL,'olegstriped'),(18908,785293355002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','jon0032','rmjt32@optusnet.com.au','Here There','20 Rubeo Ave altona meadows','Melbourne','Victoria','AUSTRALIA','3028','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:38:42',0,NULL,3,1,2,0,NULL,'jon0032'),(18909,742713083001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','leifklasson','leif_klasson@hotmail.com','Leif Klasson','Opalgangen 27','Tyreso','Tyreso','SWEDEN','S13549','+46733982501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:40:03',0,NULL,3,1,17,0,NULL,'leifklasson'),(18910,785294279002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','leifklasson','leif_klasson@hotmail.com','Leif Klasson','Opalgangen 27','Tyreso','Tyreso','SWEDEN','S13549','+46733982501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:40:05',0,NULL,3,1,17,0,NULL,'leifklasson'),(18911,785294277002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','leifklasson','leif_klasson@hotmail.com','Leif Klasson','Opalgangen 27','Tyreso','Tyreso','SWEDEN','S13549','+46733982501','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 15:40:04',0,NULL,3,1,4,1,'YW867739870CN','leifklasson\r灯架  2m    1\r单灯头  欧标    2\r115w 5500k 灯泡  220v    2'),(18912,785296507002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','theskyspy','trevordmatthews@gmail.com','Trevor Matthews','175 Braintree Ccres','Winnipeg','MB','CANADA','R3J1E4','(204) 832-8329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 15:46:35',0,NULL,3,1,2,1,NULL,'theskyspy'),(18913,785305455002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','giannifero','giannifero@tiscali.it','Gianni Mameli','Via Canalis 10','Oristano','OR','ITALY','09170','0783299046','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 16:07:05',0,NULL,3,1,2,0,NULL,'giannifero'),(18914,876252636015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','carnage19','kbourdiec90@hotmail.com','karl bourdiec','91 harton lane','south shields','Tyne and Wear','UNITED KINGDOM','ne34 0pp','01914563936','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-10-25 16:11:17',0,NULL,3,1,3,1,'RA117761159CN\r ','carnage19'),(18915,785308072002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nera1726','nce25@yahoo.com','Narciso Erandio, Duplicating Services','FMC Law, Toronto-Dominion Centre<br>77 King Street West, Suite 400','Toronto','ON','CANADA','M5K0A1','(647) 863-4528','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,1,18,0,NULL,'nera1726'),(18916,742771055001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','stephstar.22','stephstar22@gmail.com','Stephanie Mareina','18992 Florida St<br>Apt C11','Huntington Beach','CA','UNITED STATES','92648-1978','(714) 791-1559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 17:47:45',0,NULL,3,1,1,1,NULL,'stephstar.22'),(18917,742771674001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','genchiku','gutvenko@gmail.com','Utvenko Gennadiy','mkr. Kommunar<br>Centralnaya str, 17-61','Vladimir','RU','RUSSIAN FEDERATION','600023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 17:48:41',0,NULL,3,1,5,1,'CP238090200CN','genchiku'),(18918,785361259002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','santonu1654','santonu.ghosh@gmail.com','Dr. Santonu Ghosh','Room No 108c, department of materials<br>Loughborough University','Loughborough','Leicestershire','UNITED KINGDOM','LE11 3TU','07809406820','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 18:02:10',0,NULL,3,0,3,1,'RA117761057CN\r ','santonu1654\rL  已入库'),(18919,742794831001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','shakesperus','sergey.gulida@gmail.com','Sergey Gulida','Sibirskaya street, 111 - 168','Tomsk','','RUSSIAN FEDERATION','634021','7-3822-452390','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 18:30:17',0,NULL,3,1,3,1,'RA117761145CN\r ','shakesperus'),(18920,876349963015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','tabs4life','tab4lifes@gmail.com','Denis Vesely','Sevcenkova 19','Bratislava','','SLOVAK REPUBLIC','851 01','00421 908 636 785','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 18:42:16',0,NULL,3,1,2,1,NULL,'tabs4life'),(18921,742802013001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 18:43:58',0,NULL,3,1,2,1,NULL,'solsuny\rSoledad Ruiz y Blanco\rMonroe 4050 1º B\r1430 Ciudad de Buenos Aires Ciudad de Buenos Aires\rArgentina\r'),(18922,745752290018,280697484052,'Studio 24\"x35\"/60x90cm Softbox Universal Mount 4 strobe',1,'AD1140',42,'photographyacc','olegstriped','oleg.striped@gmail.com','Oleg Oparanyuk','Sobranecka, 4','Uzhgorod','Zakarpatska','UKRAINE','88000','+380990592898','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-25 18:48:48',0,NULL,3,1,3,1,'RA117761091CN\r ','olegstriped\r蜂窝      1\r60x90cm 通用卡口柔光箱     1'),(18923,785388858002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','nuvola_rossa74','nuvola_rossa74@yahoo.it','Rossella Zinnarosu','Via Tana di lu Mazzoni Tr. A 15','Sassari','SS','ITALY','07100','079260398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 18:51:50',0,NULL,3,1,2,1,NULL,'nuvola_rossa74'),(18924,870581067015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','meitydachner','meitydachner2@gmail.com','ari dachner','2 greencroft way','manchester','Greater Manchester','UNITED KINGDOM','m7 2gj','01617089907','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 19:30:12',0,NULL,3,1,2,1,NULL,'meitydachner'),(18925,876410716015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','jennisnead','mike.snead@tiscali.co.uk','Lee Snead','Church Cottage<br>Tyberton','Hereford','uk','UNITED KINGDOM','HR2 9PU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-25 20:07:17',0,NULL,3,1,3,1,'RA117761193CN\r ','jennisnead'),(18926,742862363001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','sksilje','silje90@live.no','Silje Skjaerseth','Knutshaug','Dolmoey','Norway','NORWAY','7252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 20:35:23',0,NULL,3,1,2,0,NULL,'sksilje'),(18927,785456297002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','cedricsauchen','nether.sauchen@virgin.net','Ken Fraser','c/o Ramsay and Chalmers<br>18 Chattan Place','Aberdeen','Aberdeen','UNITED KINGDOM','AB10 6RD','01224560709','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 20:57:11',0,NULL,3,1,2,1,NULL,'cedricsauchen'),(18928,742875057001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','leon_nanaki','p_colpin@yahoo.com','Philippe Colpin','9307 rue rancourt','Montreal','QC','CANADA','H1Z 2P2','(514) 260-4482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 21:02:10',0,NULL,3,1,17,0,NULL,'leon_nanaki'),(18929,742875761001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',7.2,'hermeshine','leon_nanaki','p_colpin@yahoo.com','Philippe Colpin','9307 rue rancourt','Montreal','QC','CANADA','H1Z 2P2','(514) 260-4482','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 21:03:44',0,NULL,3,1,2,1,NULL,'leon_nanaki\r绿叶 渐变镜 77mm    1\r绿叶 CPL  77mm    1'),(18930,785467045002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','6499*torreira','mtorreira@hotmail.com','Manuel Torreira Camacho','Calle Arcos nº50','Jerez de de la Frontera','Andalucía Ceuta y Melilla','SPAIN','11401','649953964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 21:20:54',0,NULL,3,1,2,1,NULL,'6499*torreira'),(18931,742886523001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','eclipse-peter','ebay@store.bg','Petar Vanchev','p.o.box 9<br>Store EOOD','Sofia','Sofia','BULGARIA','1309','(359) 283-2008 ext.: 8','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 21:29:35',0,NULL,3,1,3,1,'RA117761088CN\r ','eclipse-peter'),(18932,785472413002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','dada224224','tribiany65@yahoo.fr','Gaits Sylvain','4 Allée du Lieutenant Lucien Lafay<br>Résidence Le Mandarin, Bat. B2','Toulouse','Midi-Pyrénées','FRANCE','31400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 21:32:10',0,NULL,3,0,3,1,'RA117761180CN\r ','dada224224\r1.6*3白色背景布  1'),(18933,742881798001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','pitbullzk2005a9ua','mkennedy@i-55.com','Kevin  Kennedy','28494 Church Of God Rd','Springfield','LA','UNITED STATES','70462-9034','(225) 294-3540','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-25 21:39:40',0,NULL,3,1,4,1,'YW867739881CN','pitbullzk2005a9ua'),(18934,876466770015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',3,'AC1201',6.54,'hutongstore','rev_jim_619','fabio.giraldi.fano@gmail.com','Fabio Giraldi','Via Del Colle, 16','Fano','Pesaro','ITALY','61032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-25 21:42:21',0,NULL,3,1,2,1,NULL,'rev_jim_619'),(18935,742903539001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','gk2344','georgioskollidas@yahoo.co.uk','Georgios Kollidas','Konstantinoupoleos 61','Athens','Moschato','GREECE','18344','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-25 22:16:46',0,NULL,3,1,2,1,NULL,'gk2344'),(18936,742930179001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','jongstra123','jongstra@gmail.com','Thomas Jongstra','H.J.E. Wenckebachweg 1812','Amsterdam','','NETHERLANDS','1096DG','(+31)653297128','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-25 23:47:43',0,NULL,3,1,3,1,'RA117761074CN\r ','jongstra123'),(18937,858448881016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','toto191111','ventaydespacho@gmail.com','Fernando Fuentes','Los Prados 1924','Santiago','Lo Barnechea','CHILE','','74764431','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-26 00:12:28',0,NULL,3,1,5,1,'CP238090213CN','toto191111\r欧标'),(18938,742941722001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','obximus','mclarenfasst@aol.com','William Hutton','113 Court St','Carnegie','PA','UNITED STATES','15106-2412','(412) 276-2749','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-26 00:29:12',0,NULL,3,1,1,1,NULL,'obximus'),(18939,876533875015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','pcorralpcorral','657242929@terra.es','PEDRO-CRUZ CORRAL SOLAETA','C/JOSE BERGAMIN 10, 4ºA','MADRID','Madrid','SPAIN','28030','657242929','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 00:38:20',0,NULL,3,1,2,1,' ','pcorralpcorral'),(18940,742957158001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','goon6034','goon6034@hotmail.com','Glen Collins','wangrah Martindale rd','Denman','New South Wales','AUSTRALIA','2328','0433913394','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 01:25:08',0,NULL,3,0,3,1,'RA117761043CN\r ','goon6034\r3XL   已入库'),(18941,785556335002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','gerel125','gerry.leonardo@yahoo.com','GERARDO Leonardo','177B Mall Street<br>C-308 Pacific Towers','Tamuning','GU','UNITED STATES','96913','(671) 649-4547','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-26 01:58:15',0,NULL,3,1,1,1,NULL,'gerel125'),(18942,802759675017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','blkfxx113','blkfxx@hotmail.com','Daniel Dullaard','222 Cox\'s River Road','Little Hartley','New South Wales','AUSTRALIA','2790','0263552205','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'blkfxx113'),(18943,8881319596584900,111,'Stand 84cm / 32\" for back light studio',1,'AE3501',19.6,'aliexpress','1004921927','info@worldchamp.jp','HYUSIK KIM','3F Ngamune Building, 1-9-16, Shimosuyoshi, Tsurumi-Ku','Yokohama, Kanagawa-Ken','','JAPAN','230-0012','+81 45 582-7706',NULL,NULL,NULL,'2011-10-26 02:36:24',0,NULL,8,1,17,0,NULL,NULL),(18944,746046258018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','atav7344','nana77426@hotmail.com','antonio tavares','14 oak ridge dr','clinton','MA','UNITED STATES','01510-3126','(978) 618-9896','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 03:05:33',0,NULL,3,0,1,1,NULL,'atav7344\rxxl   已入库  '),(18945,8881319598437953,111,'Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',28.99,'aliexpress','1004921926','info@worldchamp.jp','HYUSIK KIM','3F Ngamune Building, 1-9-16, Shimosuyoshi, Tsurumi-Ku','Yokohama, Kanagawa-Ken','','JAPAN','230-0012','+81 45 582-7706',NULL,NULL,NULL,'2011-10-26 03:07:17',0,NULL,8,1,17,0,NULL,NULL),(18946,8881319598558625,111,'Photo Studio Background Support (7ft x 7ft) + Free Backdrop',1,'AO0009',69.99,'aliexpress','1004921925','info@worldchamp.jp','HYUSIK KIM','3F Ngamune Building, 1-9-16, Shimosuyoshi, Tsurumi-Ku','Yokohama, Kanagawa-Ken','','JAPAN','230-0012','+81 45 582-7706',NULL,NULL,NULL,'2011-10-26 03:09:18',0,NULL,3,1,6,1,'EE491015621CN\r ','背景架2mx2m  + 3个夹子 * 1\r1.6x2.1m 背景布  * 1 （白色）\r柔光箱 50-70cm 单灯头 * 1\r灯架 84cm * 1'),(18947,746063744018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','thaihandicraft2010','sincehot@gmail.com','Widhit Luengwitayakorn','28 Malonga Drive','Burnie','Tasmania','AUSTRALIA','7320','0487807291','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 04:30:34',0,NULL,3,1,2,1,NULL,'thaihandicraft2010'),(18948,785594944002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','geksea','nhlmaster007@hotmail.com','pui man lee','532 grove ave.<br>basement','burnaby','BC','CANADA','v5b4g3','(604) 961-2238','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 04:46:46',0,NULL,3,1,2,1,NULL,'geksea'),(18949,746092311018,280688709225,'New Studio Flash Strobe Lighting Set Carry Bag  75x15cm',1,'AD1128',25,'photographyacc','riccardo-ugo','riccardougo@yahoo.it','Rimoldi Ugo','Piazza del Filatoio','Orsenigo','CO','ITALY','22030','348-3583121','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 07:03:42',0,NULL,3,1,3,1,'RA117761383CN\r ','riccardo-ugo\r灯架包厚     1\rlenspen      1\r老款大号内胆包  canon    1\r'),(18950,743042237001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ibuylotsashit','hutchinsjames@bigpond.com','james hutchins','1691 Channel Highway<br>Margate','Hobart','Tasmania','AUSTRALIA','7054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 07:54:58',0,NULL,3,1,2,1,NULL,'ibuylotsashit'),(18951,785633830002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','9163905606','nerudo@gmail.com','Pavel Yudaev','24 Akademika Vargi Str., Apt.19','Moscow','','RUSSIAN FEDERATION','117133','+7-916-390-56-06','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 08:05:04',0,NULL,3,1,2,1,NULL,'9163905606'),(18952,876669810015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','frostingptyltd','jomari59@hotmail.com','john Ricketts','12 padauk dr','nerang','Queensland','AUSTRALIA','4211','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 08:46:11',0,NULL,3,1,2,1,NULL,'frostingptyltd'),(18953,746116020018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','orions-galaxy','pcdr@optusnet.com.au','Ian A Anderson','7A Baldwin Av','Noble Park','Victoria','AUSTRALIA','3174','0409025813','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 08:48:22',0,NULL,3,0,17,0,NULL,'orions-galaxy'),(18954,746115681018,280667309914,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',7.8,'photographyacc','orions-galaxy','pcdr@optusnet.com.au','Ian A Anderson','7A Baldwin Av','Noble Park','Victoria','AUSTRALIA','3174','0409025813','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 08:48:23',0,NULL,3,1,17,0,NULL,'orions-galaxy'),(18955,746115264018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',20,'photographyacc','orions-galaxy','pcdr@optusnet.com.au','Ian A Anderson','7A Baldwin Av','Noble Park','Victoria','AUSTRALIA','3174','0409025813','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 08:48:23',0,NULL,3,1,3,1,'RA117761556CN\r ','orions-galaxy\r帽子 canon     1\r伟峰 6663A 快装板     1\r摄影背心（河北，厚）canon   xxxl  1  (已入库） '),(18956,743055961001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','denisyana','polinadana@mail.ru','Denis Rebro','HANASI<br>80 / 11','Hadera','israel','ISRAEL','38387','0547263700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 08:55:25',0,NULL,3,1,11,1,NULL,'denisyana\r欧标'),(18957,746119956018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','joshmazz93','joshmuhfuka@hotmail.com','Josh Mazzeo','338 Hamilton Road','Spearwood','Western Australia','AUSTRALIA','6163','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 09:02:03',0,NULL,3,1,2,1,NULL,'joshmazz93\r白色'),(18958,743067313001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','mattbenedict','mattanbenedict@gmail.com','Mattan Benedict','Leon Blum Street number 66, Entrence number 4, Appartment number 1','Holon','Israel','ISRAEL','58376','972-54-6244161','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 09:44:13',0,NULL,3,1,2,1,NULL,'mattbenedict'),(18959,746133382018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','walbecke','a.hasenkamp@web.de','Andreas Hasenkamp','Bahnhofstraße 8','Sendenhorst','','GERMANY','48324','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 09:52:04',0,NULL,3,1,2,1,NULL,'walbecke'),(18960,785662440002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','krussell12','timbarra15@yahoo.com.au','ken d russell','15 timbarra drv','Bairnsdale','victoria','AUSTRALIA','3875','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 09:56:43',0,NULL,3,1,2,1,NULL,'krussell12'),(18961,743072309001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','tundrik10','karmancheg@gmail.com','Anatolij  Dergachev','Energetikov, 53-42','Tyumen','Tyumenskaya obl','RUSSIAN FEDERATION','625013','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 09:58:44',0,NULL,3,1,3,1,'RA117761499CN ','tundrik10'),(18962,785664039002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','leolaw_be','rudi.lauwers@telenet.be','Lauwers Rudi','Frans de L\'arbelaan 23','Antwerpen-Merksem','','BELGIUM','2170','0495576116','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 10:02:33',0,NULL,3,1,3,1,'RA117761485CN ','leolaw_be\rlight stand  $10'),(18963,746147785018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','8mds8','michael@suprana.com','Michael Suprana','119 Benhiam St','Calamvale','Queensland','AUSTRALIA','4116','61424269918','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 10:43:39',0,NULL,3,1,3,1,'RA117761471CN\r ','8mds8'),(18964,746159340018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','ninilovemummy','lovemummysomuch@gmail.com','Nina Navrotskaya','Индустриальная д. 9 кв. 86','Щербинка','Московская','RUSSIAN FEDERATION','142171','+7(915)002-80-97','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 11:21:28',0,NULL,3,1,3,1,'RA117761366CN ','ninilovemummy\r'),(18965,743096891001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','ninilovemummy','lovemummysomuch@gmail.com','Nina Navrotskaya','Индустриальная д. 9 кв. 86','Щербинка','Московская','RUSSIAN FEDERATION','142171','+7(915)002-80-97','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 11:26:25',0,NULL,3,1,3,1,'RA117761542CN\r ','ninilovemummy'),(18966,876735839015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'',25,'hutongstore','adrastus13','j_man_268@hotmail.com','James Taylor-Meme','23<br>Hale Road','Farnham','Surrey','UNITED KINGDOM','GU99QQ','01252719920','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 11:56:46',0,NULL,3,0,3,1,'RA117761539CN\r ','adrastus13\r老款背心Nikon  M    1 ( 已入库）'),(18967,743114547001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',28.49,'hermeshine','rnlsales','ebay@styxdecals.com','Ray Boyle','78<br>Harrow St','Rockhampton','Queensland','AUSTRALIA','4700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 12:25:38',0,NULL,3,1,3,1,'RA117761454CN\r ','rnlsales'),(18968,746184245018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','shepardo69','shepalicious@hotmail.com','Justin Shepherd','6 Alan Street','Port Noarlunga','South Australia','AUSTRALIA','5167','610437658850','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-26 12:40:22',0,NULL,3,1,2,1,NULL,'shepardo69'),(18969,785727369002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','selcankurt85','selcanaydinli@gmail.com','SELCAN KURT','sevgi mah. 663 sok<br>18/101 gaziemir - aydinli eczanesi','izmir','izmir / Gaziemir / sevgi mah','TURKEY','35410','05356278598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 13:37:37',0,NULL,3,1,3,1,'RA117761423CN ','selcankurt85'),(18970,743144365001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','electrofanaticss','okanuygun@gmail.com','Okan Uygun','YALI MAH. YONCA SOK. NO:1/1','Kartal','İstanbul','TURKEY','34873','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 14:01:59',0,NULL,3,1,5,1,'CP238090227CN ','electrofanaticss\r欧标\r申报\r$46\r\r'),(18971,858713897016,260660054917,'YongNuo SF-18 Flash Battery Pack 8*AA Canon 580EXII 550',1,'AB3307',32.99,'hutongstore','adsayer','adsayer_uk@yahoo.com','Adam Sayer','13AB02 (Enflo Research)<br>University of Surrey','Guildford','Surrey','UNITED KINGDOM','GU2 7XH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 14:10:23',0,NULL,3,1,3,1,'RA117761437CN\r ','adsayer'),(18972,743155843001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','hazzarama','pornstar@hazzarama.com','Harry Tan','1 Aldenham Drive<br>Southern River','Perth','Western Australia','AUSTRALIA','6110','0893983508','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 14:31:42',0,NULL,3,1,3,1,'RA117761587CN ','hazzarama\r澳标'),(18973,8881319639766603,111,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',87.98,'aliexpress','1004941068','alex_zhukov@inbox.ru','Alexander Zhukov','Stremajnnaja str. 3, apt. 18','Saint-Petersburg	','','RUSSIAN FEDERATION	','191025','79219380410',NULL,NULL,NULL,'2011-10-26 14:36:06',0,NULL,3,1,5,1,'CP238061565CN ','欧标'),(18974,876805776015,250599931920,'New TianYa Star 8 points filters for Cokin P Series',1,'AE2317',6.7,'hutongstore','neilshaw11','neilshaw1001@yahoo.co.uk','Neil Shaw','22<br>Buckingham road','Cadishead','Greater Manchester','UNITED KINGDOM','M44 5HG','01617750205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 14:41:48',0,NULL,3,1,2,1,NULL,'neilshaw11'),(18975,785751661002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','neilshaw11','neilshaw1001@yahoo.co.uk','Neil Shaw','22<br>Buckingham road','Cadishead','Greater Manchester','UNITED KINGDOM','M44 5HG','01617750205','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 14:43:55',0,NULL,3,1,2,1,NULL,'neilshaw11'),(18976,858745170016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','the_stone_rose','isla23@hotmail.com','Isla Goldie','19 Morven Drive<br>Westhill','Aberdeen','Aberdeenshire','UNITED KINGDOM','ab32 6ue','07752820394','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-26 15:24:10',0,NULL,3,1,3,1,'RA117761410CN ','the_stone_rose'),(18977,785798060002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','alexamst','angela079@mail.ru','Mescheryakov Aleksandr','ul. Tolbuhina d.2 \"b\"','Rossosh','The Voronezh region','RUSSIAN FEDERATION','396653','+79518613561','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 16:49:46',0,NULL,3,1,5,1,'CP238090187CN\r ','alexamst\r布是黑色的'),(18978,785826401002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','design.shoes','elisio.simao@hotmail.com','Elisio Simão Cardoso','Rua de Penoucos n. 100','Fiães','Santa Maria da Feira','PORTUGAL','4505-308','(00351) 919745677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 17:39:28',0,NULL,3,1,4,1,'YW867739855CN\r ','design.shoes\r欧标\r实重7.69\r泡重9.27'),(18979,746306861018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','tomhun75','t.szalay@vipmail.hu','Tamas Szalay','Krizantém u. 2. fszt. 2.','Budapest','','HUNGARY','1214','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 17:45:52',0,NULL,3,1,3,1,'RA117761573CN ','tomhun75'),(18980,876920708015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 18:08:24',0,NULL,3,1,5,1,'CP238090139CN\r ','leifs123\r欧标\r申报$20'),(18981,785848373002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','pasha-v','pasha-v@yandex.ru','Vlasov Pavel','2 pr. Uritskogo, 3','Nakhabino, Moscow region','RUSSIAN FEDERATION','RUSSIAN FEDERATION','143430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 18:19:39',0,NULL,3,1,2,1,NULL,'pasha-v'),(18982,785845218002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','cathylovesmark','markwinston60@googlemail.com','Mark Winston','43 mill farm drive<br>randlay','telford','shropshire','UNITED KINGDOM','tf3 2na','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 18:12:49',0,NULL,3,1,2,1,NULL,'cathylovesmark'),(18983,785879981002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','susan2630','hopesmith@y7mail.com','SUSAN HOPESMITH','PO BOX 230','QUEANBEYAN','New South Wales','AUSTRALIA','2620','0407523883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 19:15:43',0,NULL,3,1,2,1,NULL,'susan2630'),(18984,876970447015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','deenreeb','scalaapex@aol.com','thomas s scala','102 Sweet Tart Ln','Apex','NC','UNITED STATES','27502-1396','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 19:17:31',0,NULL,3,1,1,1,NULL,'deenreeb'),(18985,743282318001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','sledman_33','lostboyatzoo@hotmail.com','Paul Gazsi','126 Emery st west','london','ON','CANADA','N6J1S1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 19:03:14',0,NULL,3,1,2,1,NULL,'sledman_33'),(18986,743316319001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','daragott','nobel131_qc@hotmail.com','Normand Bellemare','230 Bellemare','Yamachiche','QC','CANADA','G0X3L0','(819) 979-0441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 20:06:36',0,NULL,3,1,5,1,'CP238090142CN\r ','daragott'),(18987,743301962001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','vonkuttenberg','commander@tiscali.cz','Martin Klimpar','Letohradska 19<br>(PHONE NUMBER +420777174155)','Praha 7','','CZECH REPUBLIC','17000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 20:08:24',0,NULL,3,1,3,1,'RA117761508CN\r ','vonkuttenberg'),(18988,746371649018,280666892339,'New Green.L 62mm  Gradual Grey ND4 Filter 2-Stop 62 mm',1,'AA3318',6.6,'photographyacc','66davegfootball','dave.gillett5@btinternet.com','David Gillett','27 Magnolia Rise','Calne','Wiltshire','UNITED KINGDOM','SN11 0QL','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 20:20:33',0,NULL,3,1,2,1,NULL,'66davegfootball'),(18989,743324546001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',2,'AA2120',64,'hermeshine','patu70','danilo.patuzzi@alice.it','danilo patuzzi','via foppa 46','montirone','BS','ITALY','25010','3495744340','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 20:21:57',0,NULL,3,1,3,1,'RA117761468CN\r ','patu70\r已入库  \r两件'),(18990,877037217015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','psicologalara','lauraspiezia@libero.it','laura spiezia','Andrea Torrente 14','casoria','NA','ITALY','80026','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-26 21:03:09',0,NULL,3,1,2,1,NULL,'psicologalara'),(18991,743349674001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','saskatchewan_military','aelc@sasktel.net','Angela Clements','805 Isabelle Street','Estevan','SK','CANADA','S4A 1R1','(306) 421-3681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 21:17:07',0,NULL,3,1,2,1,NULL,'saskatchewan_military'),(18992,858969116016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','fizzcotts','fizz@iolfree.ie','Finbarr Cotter','42 Cherbury Park Road<br>Lucan','Co. Dublin','','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-26 21:31:37',0,NULL,3,1,2,1,NULL,'fizzcotts'),(18993,743364958001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 22:08:55',0,NULL,3,1,3,1,'RA117761445CN ','arnorolf10'),(18994,746443335018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','crb14','cbisson@gninc.ca','Claude Bisson','Box 40','Brunkild','MB','CANADA','R0G 0E0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-26 22:18:22',0,NULL,3,1,2,1,NULL,'crb14'),(18995,785977611002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','electrofanaticss','okanuygun@gmail.com','ZEHRA UYGUN','YALI MH.YONCA SK. NO:1<br>KARTAL','ISTANBUL','','TURKEY','34873','00905554851454','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-26 23:04:44',0,NULL,3,1,3,1,'RA117760105CN\r ','electrofanaticss\r申报$23'),(18996,877080069015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dainxd','dain4g@gmail.com','Dani Campos Hernandez','c/Bac de roda nº99 ,bajos 1ª','Sabadell','Cataluña','SPAIN','08204','617989843','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-26 22:35:43',0,NULL,3,1,3,1,'RA117761397CN ','dainxd'),(18997,785980486002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','fotografia_video_weeding','pc.zanela@hotmail.com','Paulo Cesar Morelli Zanela','Rua dos Aliados, 264<br>Campos Elíseos','Ribeirao Preto','São Paulo','BRAZIL','14080-570','16 3628 2598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 23:17:40',0,NULL,3,1,3,1,'RA117761370CN\r ','fotografia_video_weeding'),(18998,785989752002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','1979luisfernandoluis','1979.luis.fernando@gmail.com','Luis Fernando','R. Lourdes Lopes Sanches 100 Bloco 11 Ap 23A','Guarulhos','Sao Paulo','BRAZIL','07190033','55-11-93238496','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-26 23:51:43',0,NULL,3,1,2,1,NULL,'1979luisfernandoluis'),(18999,746472163018,280761998164,'Studio Continuous lighting kit 5 output light 45w bulbs x 10 equals 2000W output',1,'',245,'photographyacc','don21q0','don@faroc.com.au','Don Pugh','17 Irvine St','Peppermint Grove','Western Australia','AUSTRALIA','6011','61893849043','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-27 00:03:23',0,NULL,5,0,4,1,'YW867739866CN\r ','don21q0\r已入库\r2m 灯架    2\r5灯头 +60-90棚   2 （本身是英标放英转澳标）\r45w 220v   10\r灯架包    1\r实重：7.23\r泡重：10.15（或者9.5到10之间 因为这个有个地方是凸起的下次也许不会）\r已发货\r'),(19000,785993395002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',10,'AD1169',68.8,'hermeshine','bryonyhunter','mirandad@netconnect.com.au','Miranda Donald','675 Pryors Road','Durham Lead','Victoria','AUSTRALIA','3352','0353413536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 00:05:27',0,NULL,3,1,3,1,'RA117761525CN\r ','bryonyhunter\r10个'),(19001,746485384018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','denny8150','tracy.marie2@bigpond.com','Tracy Jago','7 WaterLoo Street<br>Ravenswood','Launceston','Tasmania','AUSTRALIA','7250','0363394980','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-27 00:54:49',0,NULL,3,1,2,1,NULL,'denny8150'),(19002,786017750002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','dcalbrecht','dave@dcdadvancedtech.com','Dave Albrecht','14 Hudson Dr','New Windsor','NY','UNITED STATES','12553-7427','(914) 455-4243','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 01:36:54',0,NULL,3,1,1,1,NULL,'dcalbrecht'),(19003,786018745002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','lucseguin','luc.seguin@videotron.ca','Luc Séguin','388 des Erables','Brownsburg-Chatham','QC','CANADA','J8G 2Y3','(450) 533-5830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-27 01:41:33',0,NULL,3,1,3,1,'RA117761406CN ','lucseguin\r放英转美标'),(19004,746509356018,280680267419,'New Neoprene Camera Cover for Nikon D80 D5000 +18-55mm',1,'AC1305',9.99,'photographyacc','fuzs7556','frankuzsoki@optusnet.com.au','frank uzsoki','9a mcneilage st.spotswood','melb.','Victoria','AUSTRALIA','3015','0393915503','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-27 02:28:27',0,NULL,3,1,2,1,NULL,'fuzs7556'),(19005,743451043001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','steamone13','wielka458@gmail.com','  M .MARKOWSKI -SIGNALEX INC.','5617 MC.ADAM RD','MISSISSAUGA','ON','CANADA','L4Z 1N4','(905) 568-2711','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-27 03:39:07',0,NULL,3,1,2,1,NULL,'steamone13'),(19006,8881319688697360,111,'大力夹球台',1,'AE3103',0,'hermeshine','everready3048','kennyg30@shaw.ca','Ken Gordon','3580 150th Street','Surrey','BC','CANADA','v3s 0t5','(604) 536-1880',NULL,NULL,NULL,'2011-10-27 04:11:37',0,NULL,3,1,3,1,'RA117761511CN\r ',NULL),(19007,746533589018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','sbalkhi','said.balkhi@cba.com.au','Said Balkhi','6/76-78 Mountford Ave','Guildford','New South Wales','AUSTRALIA','2161','0412212243','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-27 05:47:43',0,NULL,3,1,3,1,'RA117761595CN\r ','sbalkhi'),(19059,803790258017,270744171606,'49mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT053',4.19,'photographyacc','lteck73','lteck@hotmail.com','Andrew Lam','62 Carpmael Road','default','','SINGAPORE','429798','+6598717371','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 06:27:52',0,NULL,3,1,11,1,NULL,'lteck73'),(19008,746543589018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','alibe3','chilio@sky.com','Adrian Line','RTC Europe, Eurolink Industrial Estate<br>Castle Road','Sittingbourne, Kent','Kent','UNITED KINGDOM','ME10 3RN','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-27 05:47:14',0,NULL,3,1,3,1,'RA117761600CN\r ','alibe3'),(19009,803227968017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','antt74','anton_grlic@hotmail.com','suzi grlic','barr-smith ave','bonython','Australian Capital Territory','AUSTRALIA','2905','0262939338','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-27 06:35:48',0,NULL,5,1,4,1,'YW867739844CN\r ','antt74\r澳标\r已发货'),(19010,786079774002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','buyedv','u-need_pro@hotmail.com','wuttikrai sritawai','20 soi.6<br>Ratyindee Road.','hadyai','songkhla','THAILAND','90110','+66869622227','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 07:03:47',0,NULL,3,1,6,1,'EE491015666CN\r ','buyedv'),(19011,743490698001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','activeelectrics','ebayuk@prowww.co.uk','Justin Clapham','Le Terrasse<br>Le Chemin des Moulins','St Lawrence, Jersey','Channel Islands','UNITED KINGDOM','JE3 1HY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 07:31:24',0,NULL,3,1,17,0,NULL,'activeelectrics'),(19012,743490585001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','activeelectrics','ebayuk@prowww.co.uk','Justin Clapham','Le Terrasse<br>Le Chemin des Moulins','St Lawrence, Jersey','Channel Islands','UNITED KINGDOM','JE3 1HY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 07:31:25',0,NULL,3,1,3,1,'RA117761613CN ','activeelectrics\r一转四 灯头    2'),(19013,743493837001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1308',5.2,'hermeshine','ayukov','asv@ayukov.com','Sergey Ayukov','ul. Krzhizhanovskogo, d.5, korp.1, kv.54','Moscow','','RUSSIAN FEDERATION','117292','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 07:45:56',0,NULL,3,1,2,1,NULL,'ayukov'),(19014,786096871002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','yaa_fap','fpa@bk.ru','Pavel Filimonov','Raboche-Krestyanskaya st. 30/105','Perm','RU','RUSSIAN FEDERATION','614007','+79028354776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 08:25:39',0,NULL,3,1,2,1,NULL,'yaa_fap'),(19015,859157492016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','gkaisin','gkaisin@gmail.com','Geoffroy Kaisin','Rue des Vingt-Deux, 9','Liège','','BELGIUM','4000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 08:33:44',0,NULL,3,1,3,1,'RA117761701CN ','gkaisin'),(19016,743525712001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','alojzy23','alojzy23@wp.pl','Lukasz Gazda','Granny Flat<br>Ballard Road','Miltown Malbay','Clare','IRELAND','default','0861286419','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 10:05:37',0,NULL,3,1,2,1,NULL,'alojzy23'),(19017,743534469001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','sajikwt','sajid.dxb@gmail.com','Sajid Ahmed','Post Box 2713<br>Qatar University','Doha','Qatar','QATAR','000000','(974) 558 558 35','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 10:45:55',0,NULL,3,1,2,1,NULL,'sajikwt'),(19018,746617412018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','esilbaa','nadozhe@gmail.com','Alexandr Budko','Lenina 30 - 5','Karaganda','Karagandinskaja obl','KAZAKHSTAN','100012','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-27 10:55:00',0,NULL,3,0,2,1,NULL,'esilbaa\r绿色'),(19019,858080064016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',36,'hutongstore','northenashnia','nicola.fletcher@hotmail.com','Nicola Fletcher','6 Eades Street<br>Salford','Manchester','Greater Manchester','UNITED KINGDOM','M6 6PG','01617363922','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 11:56:14',0,NULL,3,0,3,1,'RA117761794CN\r ','northenashnia\r确认颜色   同时他想买三块布\r颜色  白，黑， 和 蓝\r'),(19020,803390259017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',125,'photographyacc','fkweb159','fissunix@gmail.com','Frédéric Kempf','28 rue rené Paquet','Metz','Lorraine','FRANCE','57050','03.87.32.90.69','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-27 12:10:35',0,NULL,3,1,4,1,'YW867738396CN ','fkweb159\r欧标\r泡重4.2实重5.7'),(19021,876053805015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',2.25,'hutongstore','t_baeff','tbaeff@gmail.com','Tihomir Baev','ul. Bitolia 1A, Pikadili, Otdel reklama','Varna','Varna','BULGARIA','9002','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 12:12:41',0,NULL,3,1,2,1,NULL,'t_baeff'),(19022,786156717002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','lindsey7705','lindseylife@btinternet.com','Douglas Lunn','19, Horncastle Road','Boston','Lincolnshire','UNITED KINGDOM','PE21 9BU','01205362009','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 12:15:04',0,NULL,3,1,2,1,NULL,'lindsey7705'),(19023,743560446001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','volos49','grigoris@nikosxp.com','Gregory Gavriniotis','38 Gosport Street','Hemmant','Queensland','AUSTRALIA','4174','0422449741','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-27 12:15:20',0,NULL,3,1,3,1,'RA117761746CN\r ','volos49'),(19024,746658123018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','barryartie','barryjprior@bigpond.com','Barry Prior','17 Delma Pde','Warners Bay','New South Wales','AUSTRALIA','2282','0249486228','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-27 13:04:23',0,NULL,3,1,3,1,'RA117761729CN\r ','barryartie'),(19025,859249976016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',65.98,'hutongstore','nalioutz','nalioutz@msn.com','Lea DORDOLO','3, rue de la ville','Couvin','','BELGIUM','5660','3260344388','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 13:14:37',0,NULL,3,1,4,1,'YW867738330CN ','nalioutz\r两套\r申报Reflector Holder   $25'),(19026,746673680018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','christelley07','christelle_01@hotmail.com','Christelle Yacoub','16 Winifred St, Essendon','Melbourne','Victoria','AUSTRALIA','3040','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-27 13:51:42',0,NULL,3,1,4,1,'YW867738341CN ','christelley07'),(19027,746686705018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','urbanroofer','urbanroofonline@yahoo.com.au','Stephen Cole','22 hilltop place','Kelmscott','Western Australia','AUSTRALIA','6111','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-10-27 14:29:38',0,NULL,3,1,4,1,'YW867738352CN ','urbanroofer'),(19028,743418889001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','tvpmtorr','mtvpro@msn.com','PEDRO HENRIQUE MONTEIRO FABRINO','RUA ATILIO SPERANDIO, 140<br>JOANA DARC','VITORIA','ES','BRAZIL','29048-040','(313) 231-2550','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 14:59:45',0,NULL,3,1,3,1,'RA117761750CN\r ','tvpmtorr'),(19029,743618908001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','jensen792011','jensen@inderoy.com','John-Martin Jensen','Bartnesvegen 28','Inderoy','','NORWAY','7670','+4798636666','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 15:13:58',0,NULL,3,1,12,1,'1733178171\r ','jensen792011\r欧标\r申报$36\r实重6.8  泡重7.35'),(19030,743620447001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','michalkls','mksbill@gmail.com','Michal Klein','43 Hatichon St.','haifa','','ISRAEL','32292','052-7467408','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 15:16:15',0,NULL,3,1,2,1,NULL,'michalkls'),(19031,746709612018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','kevachen','eva.frey@klavier.de','Eva Frey','1605/5 York Street','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-27 15:32:29',0,NULL,3,1,2,1,NULL,'kevachen'),(19032,877418587015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','carcasg','carcasg@terra.es','JOSE CARLOS CASTRO GARCIA','C/ABANDOLA, 2, 1ºB','VELEZ-MALAGA','Andalucía Ceuta y Melilla','SPAIN','29700','652837198','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 16:11:21',0,NULL,3,1,4,1,'YW867738363CN ','carcasg\r黑+白'),(19033,746743263018,280761998164,'Studio Continuous lighting kit 5 output light 45w bulbs x 10 equals 2000W output',1,'AKT090',245,'photographyacc','ajeje456','jeje@libero.it','Carmelo Arigò','Maria Margotti,49','Filo','FE','ITALY','44010','3498640842','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-27 16:52:56',0,NULL,3,1,4,1,'YW867738374CN ','ajeje456\r英转欧标\r实重：7.28\r泡重：10.08'),(19034,786273317002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','marenscloset','bnhaskell@msn.com','Brooke Haskell','375 E Overpeck Rd','Mooresville','IN','UNITED STATES','46158-6313','(317) 682-7100','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 17:27:11',0,NULL,3,1,1,1,NULL,'marenscloset'),(19035,877462851015,250680618364,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',27,'hutongstore','nenomart2010','mail@desenho3d.com','Nelson Martins','Rua Silvério Raposo - 59, 2º Dto','Alcobaça','Leiria','PORTUGAL','2460 075','962335529','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 17:30:27',0,NULL,3,1,3,1,'RA117761803CN\r ','nenomart2010\r欧标'),(19036,877097393015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',146.69,'hutongstore','skylight_superstar','skylight.ebay@gmail.com','SKYLIGHT DI RINALDI LIA','VIA MADONNINA 2','fumane','Verona','ITALY','37022','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 18:10:22',0,NULL,3,1,6,1,'EX002621299SG\r ','skylight_superstar\r双灯头  欧标     1\r斜臂   1\r115w 220v灯泡     4\r85cm柔光伞      1\r2m 灯架     2\r50-70柔光棚   欧标    2\r灯架包     1\r已入库\r实重6.6  泡重9.7\r1733178182 换成 EX002621299SG\r'),(19037,786302273002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','icecube_666','wolf.icecube.666@gmail.com','Ting Yu Chien','C/ Camino de las Viñas 37','Torrejon de la Calzada','Madrid','SPAIN','28991','695613945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 18:36:00',0,NULL,3,1,17,0,NULL,'icecube_666'),(19038,786300382002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','icecube_666','wolf.icecube.666@gmail.com','Ting Yu Chien','C/ Camino de las Viñas 37','Torrejon de la Calzada','Madrid','SPAIN','28991','695613945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-27 18:36:01',0,NULL,3,1,3,1,'RA117761661CN\r ','icecube_666\r肩带 无字    1\r2云柔    1'),(19039,743722032001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','slemak','slemak@aol.com','Stephen Lemak','159 Prairie View Lane','Mickleton','NJ','UNITED STATES','08056','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-27 18:56:08',0,NULL,3,1,1,1,NULL,'slemak'),(19040,743751903001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','doyoupb','brian@cxbl.ca','Brian Tavares','3505 Cote-Vertu','St-Laurent','QC','CANADA','H4R1R2','(514) 595-5993','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-27 19:51:19',0,NULL,3,1,2,1,NULL,'doyoupb'),(19041,743772069001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cruxado','joelrodz@gmail.com','Joel E Rodriguez-Ramos','PO Box 377','Mercedita','PR','UNITED STATES','00715-0377','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-27 20:35:35',0,NULL,3,0,1,1,NULL,'cruxado\r要的是绿色的'),(19042,743765811001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','ricbuchner','ricardobuchner@hotmail.com','Ricardo Ferreira','Rua Pindorama, 26<br>Chacara da Barra','Campinas','Sao Paulo','BRAZIL','13.090-660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 20:21:30',0,NULL,3,1,3,1,'RA117761675CN\r ','ricbuchner\r四节'),(19043,743800236001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','atrazsk8','atrazsk8@tin.it','Andrea Schiavone','Via Abruzzi 87','Campi Salentina','LE','ITALY','73012','3401299787','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-27 21:39:46',0,NULL,3,1,3,1,'RA117760140CN\r ','atrazsk8\rLight Bulb  $15'),(19044,877606571015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','andreash110380','andreash1@mailbox.gr','Andrea Shkreli','Platonos 21','Thessaloniki','Greece','GREECE','54631','00306942889910','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-27 22:03:08',0,NULL,3,1,3,1,'RA117763415CN\r','andreash110380'),(19045,877649462015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','33zog','daclem95@googlemail.com','david clements','4 st. Colmans Gardens','Rostrevor / Newry','Down','UNITED KINGDOM','BT34 3EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-27 22:44:33',0,NULL,3,1,3,1,'RA117761689CN\r ','33zog'),(19046,877655640015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','jncruz72','jn.cruz@gmail.com','João Cruz','Carlos Marnoto, 36','Ílhavo','','PORTUGAL','3830-120','00351234326476','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-27 23:00:08',0,NULL,3,1,4,1,'YW867738385CN ','jncruz72\r欧标'),(19047,743847901001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','ihti','ihti@ureach.com','Ehtisham ul Haq','7655 Terrasse Saint Roch # 5','Montreal','QC','CANADA','H3N 1Z6','(514) 270-1276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-28 00:28:02',0,NULL,3,1,3,1,'RA117761692CN\r ','ihti\r申报$15'),(19048,786447474002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','janisrossa','janilsonrossa@gmail.com','Janilson A Rossa','Av Rio Branco, 405 Centro','Florianopolis','Santa Catarina, Brazil','BRAZIL','88015-201','+55 048 9923 1533','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 00:29:14',0,NULL,3,1,2,1,NULL,'janisrossa'),(19049,743862974001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.89,'hermeshine','gakodomi','qhxhdsla@naver.com','Rara Gye','234 Bronte Rd<br>Waverley','Sydney','New South Wales','AUSTRALIA','2024','0415140999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 01:30:18',0,NULL,3,1,2,1,NULL,'gakodomi'),(19050,786490769002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','vivianephotographyprops','vivianephotography@hotmail.com','Viviane Schuindt','95 Audubon Rd<br>Apt 302','Wakefield','MA','UNITED STATES','01880-1269','(978) 332-4818','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-10-28 03:17:49',0,NULL,3,1,1,1,NULL,'vivianephotographyprops'),(19051,786487092002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',27,'hermeshine','ekimsey','ekimsey@sbcglobal.net','Eugene E Kimsey','10127 Silver Park','San Antonio','TX','UNITED STATES','78254-6003','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-28 03:01:53',0,NULL,3,1,1,1,NULL,'ekimsey'),(19052,743898850001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 04:11:49',0,NULL,3,1,17,0,NULL,'shadowsing11'),(19053,786500380002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 04:11:50',0,NULL,3,1,17,0,NULL,'shadowsing11\r'),(19054,877741404015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','nellasbst','nellas@maltanet.net','patrick spiteri','block B1, Flat 1<br>Watar Street','Ta Xbiex','Malta','MALTA','XBX 1396','00356 21330042','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 03:43:53',0,NULL,3,1,3,1,'RA117760017CN\r ','nellasbst\r分开发\rRA117760096CN\r'),(19055,743898608001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','shadowsing11','leon03310@hotmail.com','Kong Wei','1 Ang Mo Kio Street 63<br>Kenwood Electronics Technologies','default','','SINGAPORE','569110','94595468','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 04:11:49',0,NULL,3,1,3,1,'RA117761715CN\r ','shadowsing11\r6片装的滤镜袋    1\r天涯方形滤镜系列  CPL   1\r方形滤镜接口环 67mm    1\r方镜普通托架（三槽）   1'),(19056,743903425001,110469599322,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',17.99,'hermeshine','xxrandell','xrandell@live.com.au','Caleb','Unit 4/178 Lower Heidelberg Road East Ivanhoe','Melbourne','Victoria','AUSTRALIA','3079','61433222060','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-28 04:42:49',0,NULL,3,1,2,1,NULL,'xxrandell\r澳标'),(19057,786507066002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',2,'AA3211',8.36,'hermeshine','sunsun70','melkonians@mail.ru','Alexander Melkoniants','proezd Vorobieva 11/11 kvartira 108','Astrakhan','Astrakhan','RUSSIAN FEDERATION','414057','927-285-3306','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 04:46:37',0,NULL,3,1,2,1,NULL,'sunsun70'),(19058,8881319782188272,111,'EW-73B',1,'AA3408',0,'hermeshine','janpmunk1','jan_petter85@hotmail.com','Jan Petter Munkvold','Sørkedalsveien 3C','Oslo','','NORWAY','0369','',NULL,NULL,NULL,'2011-10-28 06:09:48',0,NULL,3,1,3,1,'RA117760025CN\r ',NULL),(19060,8881319783469391,111,'中号内胆包 nikon logo',1,'AC2304',0,'photographyacc','mamat80','mamat80@wanadoo.fr','NOWINSKI MATTHIEU','14 rue de Navarre','PENLY','Haute-Normandie','FRANCE','76630','0667386742',NULL,NULL,NULL,'2011-10-28 06:31:09',0,NULL,3,1,3,1,'RA117760034CN\r ',NULL),(19061,8881319784403902,111,'SONY 红外',3,'AA2203',0,'hermeshine','budda001','isaev.foto@gmail.com','Jastrebov Dmitry Nikolaevich','Molodejny d.28 kv.48','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','',NULL,NULL,NULL,'2011-10-28 06:46:43',0,NULL,3,1,3,1,'RA117760082CN\r ',NULL),(19062,786360996002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','daniv2011','danielvalero1970@hotmail.com','Daniel Valero Soler','Avenida Libertad nº 47 2º2ª','Mollet del Valles','Cataluña','SPAIN','08100','931805240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 07:32:56',0,NULL,3,1,3,1,'RA117760065CN ','daniv2011'),(19063,786537591002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','bod864','stuart@dodson.org.uk','Stuart Dodson','17 Finlay Road','Warrawee','New South Wales','AUSTRALIA','2074','0291447801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 07:36:34',0,NULL,3,1,2,1,NULL,'bod864'),(19064,743942491001,110531023633,'TianYa Gradual Brown tobacco Filter for Cokin P Series ',1,'AA2321',7.2,'hermeshine','sarul84','szbenut@gmail.com','Mohd Shahrulnizam Noordin','AND Johor Utara, TM Batu Pahat,<br>Jalan Rahmat','Batu Pahat','Johor','MALAYSIA','83000','0133801887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:10:35',0,NULL,3,1,2,1,NULL,'sarul84'),(19065,786551812002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','istokka','admoccia@alice.it','martina saviano','via florindo ferro 51','frattamaggiore','NA','ITALY','80027','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 08:39:31',0,NULL,3,1,3,1,'RA117763509CN\r ','istokka\rsoftbox  $12\r放布'),(19066,743956468001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','malinbjo','malinbjorhovde@hotmail.com','Malin Bjørhovde','Vik','Vestre Vinnesvåg','Hordaland','NORWAY','5396','004790114954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 09:10:15',0,NULL,3,0,2,1,NULL,'malinbjo\r黑色'),(19067,747061432018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',8.99,'photographyacc','sergey659','heliosa@rambler.ru','Sergey Bogachev','Tupoleva st. 1/1 kv1<br>Moskovskay oblast','Domodedovo','RU','RUSSIAN FEDERATION','142007','7-9153347410','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 09:35:59',0,NULL,3,1,2,1,NULL,'sergey659'),(19068,877415340015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','wincollec','wincollec@wanadoo.fr','reynier vincent','6 avenue de l\'ermitage','Espaly St Marcel','Auvergne','FRANCE','43000','04.71.07.92.81','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-28 10:15:06',0,NULL,3,1,3,1,'RA117760184CN ','wincollec'),(19069,743973058001,110760258379,'7\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1194',28,'hermeshine','karindeklerk','deklerk@fullerfilm.com','Karin De Klerk','1 Betty Place','Glenashley','KwaZulu Natal','SOUTH AFRICA','4051','+27824326013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 10:20:19',0,NULL,3,1,3,1,'RA117760330CN\r ','karindeklerk'),(19070,743992575001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','alfonsas67','alfmazz@gmail.com','Alfonsas Mazunas','Kauno 7-88','Klaipeda','Lithuania','LITHUANIA','91155','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 11:34:41',0,NULL,3,0,2,1,NULL,'alfonsas67\r黑色'),(19071,747121172018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','tamago4jp','tamago4jp@gmail.com','Bobby Jiang','580 Canning Hwy','Attadale','Western Australia','AUSTRALIA','6156','0893173342','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-28 12:56:31',0,NULL,3,1,3,1,'RA117760272CN\r ','tamago4jp'),(19072,744025278001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','jazz41','rachelgr@nb.sympatico.ca','Rachel Robichaud','946 Francois Street','Beresford','NB','CANADA','E8K 1L3','(506) 543-4386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 13:27:04',0,NULL,3,1,17,0,NULL,'jazz41'),(19073,877921026015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 13:45:58',0,NULL,3,1,17,0,NULL,'yveskwijibo74'),(19074,877922010015,250599986868,'Large size Neoprene Lens Pouch Case 90mm x 220mm',1,'AC1203',3.28,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 13:45:57',0,NULL,3,1,17,0,NULL,'yveskwijibo74'),(19075,877919623015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.68,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 13:45:58',0,NULL,3,1,17,0,NULL,'yveskwijibo74'),(19076,877920198015,250599391718,'62mm CPL Circular Polarizing Filter 62 CPL Green.L New',1,'AA3311',3.92,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 13:45:59',0,NULL,3,1,17,0,NULL,'yveskwijibo74'),(19077,859816144016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 13:45:59',0,NULL,3,1,3,1,'RA117760290CN ','yveskwijibo74\r镜头筒 小号     1\r镜头筒 大号     1\r绿叶 CPL  52mm    1\r绿叶 CPL  62mm     1\r绿叶 CPL  67mm   1\rfilters  $15\r\r'),(19078,874621197015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','gemunit','gemmaulivi@yahoo.co.uk','Flt Lt O Peters','Officers Mess<br>RAF Marham','Kings Lynn','Norfolk','UNITED KINGDOM','PE33 9NP','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-28 13:22:58',0,NULL,3,0,4,1,'YW867738282CN  ','gemunit英标  白色'),(19079,744078317001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jazz41','rachelgr@nb.sympatico.ca','Rachel Robichaud','946 Francois Street','Beresford','NB','CANADA','E8K 1L3','(506) 543-4386','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 15:54:35',0,NULL,3,0,3,1,'RA117760241CN\r ','jazz41\r反光板 110cm 5合1    1\r1.6*2.1白色背景布    1'),(19080,803966639017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',2,'AA1202',5.8,'photographyacc','elilev-7073','elilev@gmail.com','Eli Levin','Ben Tzvi Shimon 57','Givataiym','Israel','ISRAEL','53631','972-3-5717073','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 15:59:53',0,NULL,3,1,2,1,NULL,'elilev-7073'),(19081,747219783018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',69,'photographyacc','babylove1964','tipuceron22@hotmail.com','doris lavoie','1400 st-albert<br>l\'ancienne-lorette','quebec','QC','CANADA','G2E1P6','(418) 871-4924','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 17:17:35',0,NULL,3,1,5,1,'CP238090292CN','babylove1964'),(19082,804046464017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','jmakkinga','johan@makkinga.com','Johan Makkinga','Laan van Soestbergen 37','Utrecht','','NETHERLANDS','3582ST','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 18:41:30',0,NULL,3,1,2,1,NULL,'jmakkinga\r新地址：\rJohan Makkinga\rCremerstraat 80, \r3532BG, Utrecht\rNETHERLANDS'),(19083,859970585016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','waisum2011','waisumtang@hotmail.com','Sum Tang','laanstraat 3B','hilversum','','NETHERLANDS','1211hg','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 18:53:02',0,NULL,8,0,17,0,NULL,'waisum2011'),(19084,878075758015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','waisum2011','waisumtang@hotmail.com','Sum Tang','laanstraat 3B','hilversum','','NETHERLANDS','1211hg','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-28 18:53:03',0,NULL,8,1,17,0,NULL,'waisum2011'),(19085,859969068016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','waisum2011','waisumtang@hotmail.com','Sum Tang','laanstraat 3B','hilversum','','NETHERLANDS','1211hg','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-28 18:53:04',0,NULL,3,1,4,1,'YW867739833CN ','waisum2011\rc里再加\r欧标\r背景架2mx2m  + 3个夹子   1\r1.6x2.1  白色    1\r1.6x3m 黑色    1\r实重10.1 泡重11.1'),(19086,859979886016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','enterprise1955','frankie.williams@ntlworld.com','Frankie Edward Williams','14 Whatton Oaks','Rothley','Leicestershire','UNITED KINGDOM','LE77QE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-28 19:01:32',0,NULL,3,1,2,1,NULL,'enterprise1955'),(19087,786778485002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','adancing1982','alain.aouad@gmail.com','Roger Al Halaby','Mansourieh<br>Tel. +9613739339','El Metn','','LEBANON','P.O. Box 120','+9613739339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 19:24:02',0,NULL,3,1,5,1,'CP240320391CN\r','adancing1982CP238061574CN\r货退回来了，客户问起就退款\r\r11.27 重发一次'),(19088,786834494002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','teasider','teasider@gmail.com','Eran Solomon','Shvidelson 3<br>Appartment 15','Herzeliya','Israel','ISRAEL','46807','972-050-7851801','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 21:34:14',0,NULL,3,1,2,1,NULL,'teasider'),(19089,744252766001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','fmicheviz','nando_micheviz@yahoo.com.br','Fernando Micheviz','Doutor Francisco Soares 73 CS<br>Novo Mundo','Curitiba','Paraná','BRAZIL','81030-450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 22:54:52',0,NULL,3,1,3,1,'RA117763322CN\r ','fmicheviz'),(19090,804160712017,270744171606,'49mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT053',4.19,'photographyacc','peacok6843','yutulbo@yahoo.com','chea yu','12823 catfish rd','hesperia','ca','UNITED STATES','92345','(760) 389-2355','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-28 23:04:47',0,NULL,3,1,1,1,NULL,'peacok6843'),(19091,744255662001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','fmicheviz','nando_micheviz@yahoo.com.br','Fernando Micheviz','Doutor Francisco Soares 73 CS<br>Novo Mundo','Curitiba','Paraná','BRAZIL','81030-450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 23:06:00',0,NULL,3,1,3,1,'RA117763319CN\r','fmicheviz\r'),(19092,786876093002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','www_en-or_com','zerailkiller@hotmail.com','Aurelien Benadiba','43 Avenue MAIGNAN appt. 3','TOULOUSE','Midi-Pyrénées','FRANCE','31200','0658685921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 23:53:17',0,NULL,3,1,17,0,NULL,'www_en-or_com'),(19093,744264034001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','www_en-or_com','zerailkiller@hotmail.com','Aurelien Benadiba','43 Avenue MAIGNAN appt. 3','TOULOUSE','Midi-Pyrénées','FRANCE','31200','0658685921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 23:53:18',0,NULL,3,1,17,0,NULL,'www_en-or_com'),(19094,744266795001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','www_en-or_com','zerailkiller@hotmail.com','Aurelien Benadiba','43 Avenue MAIGNAN appt. 3','TOULOUSE','Midi-Pyrénées','FRANCE','31200','0658685921','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-28 23:53:18',0,NULL,3,1,3,1,'RA117760269CN\r ','www_en-or_com\r反光板 60cm 2合1      1\r倒影板（白黑）    1\r1.6*2.1黑色背景布    1'),(19095,744268844001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','rmendes2007','lasersetubal@hotmail.com','Rui Mendes','Rual Almeida Garret nº 7 B','Setúbal','Setúbal','PORTUGAL','2900-212','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 00:02:47',0,NULL,3,1,2,1,NULL,'rmendes2007'),(19096,744276942001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','shylevy','slevy1@univ.haifa.ac.il','Shy Levy','59,Zalman Shneor str.','Haifa','Israel','ISRAEL','32545','972526178283','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 00:38:14',0,NULL,3,1,2,1,NULL,'shylevy\r欧标'),(19097,744280158001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','camarda76','gugamillet@gmail.com','Guga Millet','R. do Jequitibá, 1/202 BL1<br>Gávea','Rio de Janeiro','RJ','BRAZIL','22470-110','021 22746578','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 00:53:08',0,NULL,3,1,2,1,NULL,'camarda76'),(19098,744280738001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','hjp3321','6322406@hanafos.com','Hun Jin Park','79-26 Dae 2 Dong Dongku','Daejeon','','KOREA,REPUBLIC OF','300 810','82 426322406','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-29 00:55:41',0,NULL,3,1,3,1,'RA117760286CN\r ','hjp3321\r\r\r'),(19099,744280678001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','oomfmick','dektarium@hotmail.com','Gustavo Mercado','9418 23rd Ave','East Elmhurst','NY','UNITED STATES','11369-1242','(718) 424-2122','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-29 01:02:47',0,NULL,3,1,1,1,NULL,'oomfmick'),(19100,804205358017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','315skidoo22','hparson2@twcny.rr.com','Heather Parsons','7601 Merritt dr','Baldwinsville','NY','UNITED STATES','13027-9412','(315) 246-1307','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-29 02:06:59',0,NULL,3,1,1,1,NULL,'315skidoo22'),(19101,747414783018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','sancheezpro','pohan_sancheez@live.com','Pohan Sancheez','Jl. Lubuk Baja Blok A No. 1 - 2<br>Komplek Bumi Indah','Batam','Riau','INDONESIA','29432','001628127004286','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-29 02:21:54',0,NULL,3,1,6,1,'EE491015670 CN ','sancheezpro\r'),(19102,747440246018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT064',78,'photographyacc','edward8047','edwardjq@optusnet.com.au','Edward Quiring','PO Box 186','Condell Park','New South Wales','AUSTRALIA','2200','0419444434','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-29 04:36:00',0,NULL,3,1,4,1,'YW867738422CN\r ','edward8047\r澳标\rEdward Quiring\r898 Henry Lawson Drive\rPicnic Point NSW 2213\rAustralia\r0419444434\r'),(19103,747443982018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','jmal9073','jandjmallett@gmail.com','John Mallett','Unit 78<br>175 Kelletts Road','Rowville','Victoria','AUSTRALIA','3178','0397533705','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-29 05:00:38',0,NULL,3,1,4,1,'YW867738433CN ','jmal9073'),(19104,786944012002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','john_galindez','galindez.john@yahoo.com','John Galindez','Urb. Luchetti Calle Virgilio del Pozo # 11','Manati','PR','UNITED STATES','00674','(787) 962-0758','NoPaymentFailure','CheckoutComplete','Other','2011-10-29 05:36:46',0,NULL,3,0,1,1,NULL,'john_galindez\r2XL   已入库'),(19105,744338066001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','saintmoz','saintmoz@gmail.com','Anthony W Moran','14 Sale Rd','Maffra','Victoria','AUSTRALIA','3860','0351472747','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 06:11:46',0,NULL,3,1,3,1,'RA117760459CN\r ','saintmoz'),(19106,860199641016,260768456440,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',1,'AA1309',1.87,'hutongstore','smileylandgifts','info@golanus.com','Ron Golan','12 tzofit<br>Haifa','Haifa','','ISRAEL','32994','972505907050','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 06:12:20',0,NULL,3,1,2,1,NULL,'smileylandgifts'),(19107,786963292002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','hawking_it','nicolabs@libero.it','Nicola Bissi','via dei ciliegi, 10','Ravenna','Ravenna','ITALY','48100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 07:27:01',0,NULL,3,1,2,1,NULL,'hawking_it'),(19108,744241024001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','parusatv','t9162100661@gmail.com','Юрий Клыков','Оболенский пер., дом 7, кв. 36','Москва','','RUSSIAN FEDERATION','119021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 07:40:16',0,NULL,3,1,5,1,'CP238061591CN','parusatv\r欧标'),(19109,744371737001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','kiberan','gaelgonzalezalonso@gmail.com','gael gonzalez alonso','calle del conde n 17 casa','vigo','Galicia','SPAIN','36210','600409192','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-29 08:51:55',0,NULL,3,1,4,1,'YW867738444 CN','kiberan'),(19110,786996750002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','francom.j','francom.j@tiscali.it','Franco Mascioli','via Ettore Majorana, 16','Monte Porzio Catone','RM','ITALY','00040','069447428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 09:44:20',0,NULL,3,1,2,1,NULL,'francom.j'),(19111,860259672016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','1708marek','marekkuras@btinternet.com','MAREK KURAS','79 LUCAS COURT<br>STRASBURG ROAD','LONDON','London','UNITED KINGDOM','SW11 5JG','07971093484','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 09:49:42',0,NULL,3,1,3,1,'RA117760414CN ','1708marek'),(19112,747506761018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','fivegrains','l5grains@bigpond.com.au','Laurie Cinquegrana','3 Bogey Crt','Dingley Village','Victoria','AUSTRALIA','3172','0395512065','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-29 09:52:04',0,NULL,3,1,3,1,'RA117760326CN\r ','fivegrains'),(19113,878379698015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','kenalste','mmayo@winnebago.com.au','Max Mayo','10 Merelynne Ave','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 10:01:44',0,NULL,3,1,2,1,NULL,'kenalste'),(19114,787022804002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','shraja','shaukatraja@yahoo.com','Shaukat Hayat','31B Riley Road','Riverton','Western Australia','AUSTRALIA','6148','0892590989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 11:18:10',0,NULL,3,1,2,1,NULL,'shraja'),(19115,860344470016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','gerard9937','burdinte@burdeyron.fr','BURDEYRON Gerard','21 rue PAPILLON','VILLEURBANNE','RHONE','FRANCE','69100','06 89 12 10 33','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-29 13:27:48',0,NULL,3,1,2,1,NULL,'gerard9937'),(19116,787073219002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','alex-ktv','ostapok@hotmail.com','Alexey Ostapok','140/59 Kosmonavtiv str/','Mykolayiv','Mykolayivska oblast','UKRAINE','54031','+380675122689','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 13:49:41',0,NULL,3,1,2,1,NULL,'alex-ktv'),(19117,878382202015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','glittergraces','jmccahon@btinternet.com','J McCahon','47 Edenmore Crescent<br>Bendooragh','Ballymoney','Antrim','UNITED KINGDOM','BT53 7RE','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-29 14:38:28',0,NULL,3,1,4,1,'YW867738455 CN','glittergraces\r英标'),(19118,878521488015,250848949434,'600w lighting kit with 3mx6m backdrop & 2mx3m support ',1,'AKT037',130,'hutongstore','ryaner_90','ryaner90@hotmail.com','shane ryan','42 daletree view<br>ballycullen','firhouse','Dublin','IRELAND','24','0878702182','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-10-29 15:33:41',0,NULL,3,1,4,1,'YW867738466CN ','ryaner_90\r英标\r2m*3m 背景架+夹子     1（自己配的那个）\r2m 灯架     2\r双灯头 英标    2\r反光伞   2\r3m*6m 白色背景布    1\r45w220v灯泡     4\r灯架包      1'),(19119,744510689001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','zeroflux-vii','xylonmaster@gmail.com','Isaac Henry','380 Alexander Ave','Howell','NJ','UNITED STATES','07731-8953','(732) 557-1992','NoPaymentFailure','CheckoutComplete','Other','2011-10-29 15:51:25',0,NULL,3,1,1,1,' ','zeroflux-vii'),(19120,804472065017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','gilberto_1969','gilberto@ya.com','Gilberto Pedreira','C/Barco, 45, piso 4º A<br>Madrid','Madrid','Madrid','SPAIN','28004','647622668','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-29 16:42:11',0,NULL,3,1,2,1,NULL,'gilberto_1969'),(19121,744539299001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','kwoods001','keithwoods@shaw.ca','Keith Woods','427-581 Cardero St','Vancouver','BC','CANADA','V6G3L3','(604) 724-2600','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-29 16:50:24',0,NULL,3,1,3,1,'RA117760480CN\r ','kwoods001'),(19122,747684626018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','bariscay1234','bcay1234@yahoo.com','Baris Cay','Topcular mah. Baris konaklari blok I-1 degirmendere golcuk','kocaeli','kocaeli','TURKEY','41950','05355208802','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-29 17:20:03',0,NULL,3,1,2,1,NULL,'bariscay1234'),(19123,787186761002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sa555sss','sa555sss@tiscali.co.uk','saleem amin','210a, lady magaret road. southall','london','Middlesex','UNITED KINGDOM','ub1 2ru','07931783419','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-29 17:57:30',0,NULL,3,0,3,1,'RA117760122CN\r ','sa555sss\rL   已入库'),(19124,744622307001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','dnw3039','dnwilson@bigpond.com','David Wilson','5 Capulet Street','Moonee Ponds','Victoria','AUSTRALIA','3039','0393707928','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 19:30:16',0,NULL,3,1,2,1,NULL,'dnw3039'),(19125,786799461002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','pmon3344','peremonteis@gmail.com','Pere Monteis','Ctra.Barcelona, 5, Esc.dcha, 3-2','Sabadell','Cataluña','SPAIN','08201','630651266','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 20:06:29',0,NULL,3,1,2,1,NULL,'pmon3344'),(19126,803656818017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','evensoul','mya_raven@yahoo.com','Gerardo Aguilar','Las Heras 1809, apto 001<br>CH 77, 5968B, senda 1, block O1, apto 001','Montevideo','Montevideo','URUGUAY','11600','096777300','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-29 20:31:31',0,NULL,3,1,3,1,'RA117760198CN ','evensoul'),(19127,878739235015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'AA3203',12.7,'hutongstore','grahamfaulkner1','elise.faulkner495@gmail.com','Graham Faulkner','26 Northgate','Hornsea','East Riding of Yorkshire','UNITED KINGDOM','HU18 1ES','01964532245','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 21:34:18',0,NULL,3,1,2,1,NULL,'grahamfaulkner1'),(19128,744674446001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','urakoff','darkbox@mail.ru','Olga Sidorova','50 Pirogova st.','Yoshkar-Ola','Mari El','RUSSIAN FEDERATION','424003','(902)744 4440','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 21:34:39',0,NULL,3,1,3,1,'RA117760391CN ','urakoff'),(19129,878740246015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','natalier8795','nat-rich@hotmail.co.uk','Natalie Rich','27a Hoe Lane','Nazeing','Essex','UNITED KINGDOM','EN9 2RQ','07598276235','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 21:36:40',0,NULL,3,1,3,1,'RA117760136CN ','natalier8795'),(19130,744689660001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','fabri0-10','fabrizioc72@hotmail.com','FABRIZIO COCCIA','ISNELLO 43','CASTELBUONO','PA','ITALY','90013','3204824444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 22:13:40',0,NULL,3,1,2,1,NULL,'fabri0-10'),(19131,744690250001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','ker0z3n','dufresne_jf@videotron.ca','Jean-Francois Dufresne','149, Colbert','Le Gardeur','QC','CANADA','J5Z4L9','(450) 582-2299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-29 22:16:14',0,NULL,3,1,3,1,'RA117760374CN\r ','ker0z3n'),(19132,860652515016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','ulsterlassy','emma.1976@hotmail.co.uk','Sara Duffin','22 Dereham Close<br>Layer Road','Colchester','Essex','UNITED KINGDOM','CO2 7JD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-29 22:53:50',0,NULL,3,1,2,1,NULL,'ulsterlassy'),(19133,744703435001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','brents40','balinke@bigpond.com','Brenton A Linke','38 Elgin Way','Flagstaff Hill','South Australia','AUSTRALIA','5159','0882704735','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-29 22:56:36',0,NULL,3,1,2,1,NULL,'brents40'),(19134,747889589018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','angelarobinsen','a_robinsen@hotmail.com','Angela Robinsen','1 Hangan Street','Bucasia','Queensland','AUSTRALIA','4750','0423350690','NoPaymentFailure','CheckoutComplete','AU_Other','2011-10-30 02:14:55',0,NULL,3,1,17,0,NULL,'angelarobinsen'),(19135,747888592018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT076',53,'photographyacc','angelarobinsen','a_robinsen@hotmail.com','Angela Robinsen','1 Hangan Street','Bucasia','Queensland','AUSTRALIA','4750','0423350690','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-30 02:14:55',0,NULL,3,1,3,1,'RA117760365CN\r ','angelarobinsen\r除了c 里面的再发\rNG128 柔光罩    1'),(19136,744757161001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','drsbs61','smitshab@yahoo.com','shawn smith','125 Lucas Cir','Lafayette','LA','UNITED STATES','70508-4615','(337) 839-0504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 02:41:32',0,NULL,3,1,17,0,NULL,'drsbs61'),(19137,744757162001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','drsbs61','smitshab@yahoo.com','shawn smith','125 Lucas Cir','Lafayette','LA','UNITED STATES','70508-4615','(337) 839-0504','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 02:41:33',0,NULL,3,1,1,1,NULL,'drsbs61\rNIKON 镜头盖 62mm    1\rNIKON 镜头盖 52mm    1'),(19138,744764865001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','richerwithout1985','richerwithout@gmail.com','Kelly Holliday','5 Farmer Way','Parmelia','Western Australia','AUSTRALIA','6167','0430107225','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-30 03:19:52',0,NULL,3,1,2,1,NULL,'richerwithout1985'),(19139,744778045001,110757249196,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',225,'hermeshine','mpeter*2010','pmullins19@hotmail.com','Peter Mullins','1 saunders street<br>pyrmont','sydney','New South Wales','AUSTRALIA','2009','0466149913','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 04:42:55',0,NULL,3,1,4,1,'YW867738470CN ','mpeter*2010'),(19140,744784504001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','striker_oo','standbypro@gmail.com','Johnny Obeid','unit 1/ 49 Loughnan Road','Ringwood','Victoria','AUSTRALIA','3134','0433943326','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 05:24:12',0,NULL,3,1,3,1,'RA117760215CN\r ','striker_oo'),(19141,860760567016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','goodgood123','p.lords@hotmail.co.uk','Wenham','4 Hurworth Ave','Langley','Berkshire','UNITED KINGDOM','SL3 7FE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 05:50:26',0,NULL,3,0,3,1,'RA117760493CN\r ','goodgood123\r白色 1.6*3  '),(19142,747930906018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','rpev6657','rpevzner@gmail.com','Roman Pevzner','Dept. of Exploration Geophysics, Curtin,<br>ARRC, 26 Dick Perry Ave,','Kensington','Western Australia','AUSTRALIA','6151','0435997051','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-30 05:54:21',0,NULL,3,1,2,1,NULL,'rpev6657'),(19143,744794279001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','guripon','josemac01@hotmail.com','jose manuel araujo castilla','C/ pagador Nº 25; 1º F.','puerto de santa maria','Andalucía Ceuta y Melilla','SPAIN','11500','625727501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 06:22:19',0,NULL,3,1,3,1,'RA117760119CN ','guripon'),(19144,747939302018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','mdzak','mdzaki@bezeqint.net','Zaki Assi','P.O.B 8928','Haifa','','ISRAEL','31090','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-30 06:53:24',0,NULL,3,1,3,1,'RA117760445CN ','mdzak'),(19145,804777037017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','sidmichael','msragonton@yahoo.com','michael ragonton','2/54 crinan street,','hurlstone park','New South Wales','AUSTRALIA','2193','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-30 07:51:54',0,NULL,3,1,2,1,NULL,'sidmichael'),(19146,744813878001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','teung','to_aha@yahoo.com','SURASIT HARAMI','1147 Soi samakom2<br>Rd.Lardpaow 71 wangtonglang lardpaow','BANGKOK','','THAILAND','10310','08-4976-8606','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 07:54:41',0,NULL,3,1,3,1,'RA117760343CN\r ','teung'),(19147,744817269001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','itayl2007','il.1985@hotmail.com','itay levi','sderot yacov 29','rishon lezion','israel','ISRAEL','75539','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 08:06:58',0,NULL,3,1,2,1,NULL,'itayl2007'),(19148,746097118018,280666901655,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',8.99,'photographyacc','tuctucak','garfield.sleepyhead@gmail.com','Alena Rezankova','Zazvorkova 2004/12<br>schranka c. 17','Praha 13','Luziny','CZECH REPUBLIC','15500','+420724119102','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-30 09:19:08',0,NULL,3,1,2,1,NULL,'tuctucak'),(19149,744849841001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','johnwade64','janwad@hotmail.no','Jan Øystein Wad','Barlinveien 30','Holmestrand','Norway','NORWAY','3080','04733053693','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 09:37:45',0,NULL,3,1,4,1,'YW867738481 CN','johnwade64'),(19150,860573688016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','doli-mixtures','dolimixtures@hotmail.co.uk','stephen dolman','38 tweedale wharf<br>madeley','Telford','shropshire','UNITED KINGDOM','tf74ew','01952583481','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 09:43:21',0,NULL,3,1,2,1,NULL,'doli-mixtures'),(19151,860857206016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','rundkas','jorn.rundkas@gmail.com','Jørn Rundkås','Laurits Hervigsvei 88e','Drammen','Buskerud','NORWAY','3035','004797757015','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 10:20:31',0,NULL,8,1,17,0,NULL,'rundkas'),(19152,878981932015,250599383719,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3305',2.8,'hutongstore','rundkas','jorn.rundkas@gmail.com','Jørn Rundkås','Laurits Hervigsvei 88e','Drammen','Buskerud','NORWAY','3035','004797757015','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 10:24:32',0,NULL,3,1,2,1,NULL,'rundkas\rCANON 镜头盖  67mm    1\r绿叶 UV  67mm     1'),(19153,787431248002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','leiramsiul','leiram.siul@hotmail.com','Luis Mariel Sendon','SETE Energy Saudia Ltd. Al Mohamadiyah, Malek Road, South Obhur<br>PO Box 5166','Jiddah','Makkah','SAUDI ARABIA','21422','+966509028727','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 11:14:32',0,NULL,3,1,2,1,NULL,'leiramsiul'),(19154,787535632002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','gizbart972','gizbart@gmail.com','Almog Halili','Harkabi 19','Tel aviv','Israel','ISRAEL','67329','+972544936353','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 12:15:28',0,NULL,3,1,3,1,'RA117760357CN ','gizbart972'),(19155,860925164016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','ewel8252','e.welch40@btinternet.com','Elizabeth Welch','6 Thakeham Close<br>Goring by Sea','Worthing','West Sussex','UNITED KINGDOM','BN12 5BA','01903246796','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-30 12:27:05',0,NULL,3,0,3,1,'RA117760309CN\r ','ewel8252\r1.6*3白色'),(19156,879084200015,250600475233,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','tj_montana','tonioflaherty@telstra.com','S.Coles','1 Rosewood  Lane','Cairnlea','Victoria','AUSTRALIA','3023','0413569525','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 13:29:48',0,NULL,3,1,2,1,NULL,'tj_montana'),(19157,582385586003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','christie_por','christie.por@gmail.com','Neang Por','8140 Marie-Lefranc','Laval','QC','CANADA','H7Y2B4','(450) 627-2786','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 13:46:54',0,NULL,3,1,5,1,'CP238061605CN','christie_por'),(19158,861002104016,260661685518,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',9.2,'hutongstore','xarcoiris','johnny.neira@gmail.com','Johnny Neira','8, Av du President Kennedy<br>studio 124','Le Pecq','Ile-de-France','FRANCE','78230','0618171515','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 14:39:08',0,NULL,3,1,2,1,NULL,'xarcoiris'),(19159,745020705001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','blues63reha','rehaozel@hotmail.com','Reha ÖZEL','TPAO Araştırma Merkezi 2180 cad no:86<br>Söğütözü Çankaya','Ankara','','TURKEY','06100','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-30 15:42:08',0,NULL,3,1,2,1,NULL,'blues63reha'),(19160,805004756017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','spansun','spanman21@hotmail.com','Mr  M, J.  THOMAS','EDRIN,<br>21,  High Street,','PORTHMADOG','Gwynedd,','UNITED KINGDOM','LL49 9LR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-30 15:43:44',0,NULL,3,1,2,1,NULL,'spansun'),(19161,877811875015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','birol33','studyobirol@windowslive.com','birol altmer','8819 sokak No;26/B<br>Stüdyo birol','izmir','çiğli-egekent','TURKEY','35610','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 18:46:45',0,NULL,3,1,5,1,'CP238061614CN ','birol33\r加1.6*2.1蓝布'),(19162,861298723016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','marsam511','mario@msammut.com','Mario Sammut','Ballaman<br>98 Triq Domenico Cachia','Birkirkara.','','MALTA','BKR1014','(356) 21496188','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 19:33:57',0,NULL,8,1,17,0,NULL,'marsam511'),(19163,879428448015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','marsam511','mario@msammut.com','Mario Sammut','Ballaman<br>98 Triq Domenico Cachia','Birkirkara.','','MALTA','BKR1014','(356) 21496188','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 19:33:58',0,NULL,8,1,17,0,NULL,'marsam511'),(19164,745236705001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:18',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19165,787856247002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',10.34,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:18',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19166,787853287002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:19',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19167,745237242001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:20',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19168,745238747001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:21',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19169,879449007015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','werner197531','wernercornelissen@vodamail.co.za','Werner Cornelissen','Hoofstraat 15','Keimoes','','SOUTH AFRICA','8860','+27828901183','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 19:57:22',0,NULL,3,1,3,1,'RA117760405CN ','werner197531\r分开发 \rRA117760312CN'),(19170,879428446015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','marsam511','mario@msammut.com','Mario Sammut','Ballaman<br>98 Triq Domenico Cachia','Birkirkara.','','MALTA','BKR1014','(356) 21496188','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 19:33:57',0,NULL,3,1,2,1,NULL,'marsam511\r镜头笔     1\r大号灰卡    1\r带水平仪 热靴保护盖    1'),(19171,787855221002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',2,'AA1301',5.2,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:20',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19172,787863457002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','debint21','rostapetr@gmail.com','Rostislav Petr, Mindshare','Rozkosneho 5','Praha 5/Prague 5','','CZECH REPUBLIC','150 00','723-753-142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:56:58',0,NULL,3,1,3,1,'RA117760431CN ','debint21'),(19173,745239218001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:17',0,NULL,3,1,17,0,NULL,'lindalinda1927'),(19174,787855527002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','lindalinda1927','l_gordon@sympatico.ca','Linda Gordon','56 bellerose est<br>apt 114','Laval','QC','CANADA','H7K 1S7','(450) 667-4316','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 19:51:19',0,NULL,3,1,3,1,'RA117760224CN\r ','lindalinda1927\r普通有线快门线C1    1\rNG128 柔光罩   1\r机身盖/镜头后盖  Canon   1\r橡胶遮光罩 58mm    2\r麂皮    2\rCANON 镜头盖  58mm     2\rGGS 550D    1\r镜头筒 小号    1\r镜头筒 中号      1\r镜头筒 大号        1\r镜头筒 xl 大号      1\r'),(19175,787892495002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','slowcasthomi','harri.homi@gmail.com','Harri Homi','Mäkelänkatu 25 b 11','Helsinki','Etelä-Suomenlääni','FINLAND','00550','041-5176640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 20:37:18',0,NULL,8,1,17,0,NULL,'slowcasthomi'),(19176,745274437001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','slowcasthomi','harri.homi@gmail.com','Harri Homi','Mäkelänkatu 25 b 11','Helsinki','Etelä-Suomenlääni','FINLAND','00550','041-5176640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 20:37:19',0,NULL,8,1,17,0,NULL,'slowcasthomi'),(19177,745274438001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','slowcasthomi','harri.homi@gmail.com','Harri Homi','Mäkelänkatu 25 b 11','Helsinki','Etelä-Suomenlääni','FINLAND','00550','041-5176640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 20:37:19',0,NULL,3,1,2,1,NULL,'slowcasthomi\r机身盖/镜头后盖  Canon    1\rNIKON 镜头盖 72mm     1\r肥皂盒   sb800       1 '),(19178,805250278017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','doleczki','iwona.lyszczek@op.pl','Iwona Lyszczek','23 Chancery Hall<br>Ellis Quay','Dublin','Dublin','IRELAND','7','3538517072','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-30 20:09:49',0,NULL,3,1,2,1,NULL,'doleczki'),(19179,745275264001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','ihti','ihti@ureach.com','Ehtisham ul Haq','7655 Terrasse Saint Roch # 5','Montreal','QC','CANADA','H3N 1Z6','(514) 270-1276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-30 20:40:00',0,NULL,3,1,3,1,'RA117760428CN\r ','ihti\r4灯头 灯头 孔 配50-70的棚    \r申报$15'),(19180,787414710002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','ivosisko','ivo@jen.cz','Ivo Broz','Mlynska 3','Ostrava 1','','CZECH REPUBLIC','702 00','608409822','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 22:00:46',0,NULL,3,1,3,1,'RA117760255CN ','ivosisko'),(19181,879533986015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','2011mukeshguru','hppy.guru@yahoo.com','mukesh guru','11 BAKER STREET','SUNSHINE','Victoria','AUSTRALIA','3020','0401600180','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-30 21:52:10',0,NULL,3,1,3,1,'RA117760502CN ','2011mukeshguru'),(19182,745339889001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.2,'hermeshine','0s0*ok','ntandsj@bigpond.net.au','Sue Perkins','69 Moore Street','Colac','Victoria','AUSTRALIA','3250','0352314171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 22:57:55',0,NULL,8,1,17,0,NULL,'0s0*ok'),(19183,787962897002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','0s0*ok','ntandsj@bigpond.net.au','Sue Perkins','69 Moore Street','Colac','Victoria','AUSTRALIA','3250','0352314171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 23:01:59',0,NULL,8,1,17,0,NULL,'0s0*ok'),(19184,745341735001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','0s0*ok','ntandsj@bigpond.net.au','Sue Perkins','69 Moore Street','Colac','Victoria','AUSTRALIA','3250','0352314171','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-30 23:00:01',0,NULL,3,1,2,1,NULL,'0s0*ok\r镜头筒 xl 大号    1\r大号内胆包 无字    1\r小号内胆包 无字    1'),(19185,745350074001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','tstabil','firefight87@gmail.com','Tyler Stabile','149 S Enterprise St','Bowling Green','OH','UNITED STATES','43402-2913','(330) 391-1038','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-10-30 23:25:06',0,NULL,3,1,1,1,NULL,'tstabil'),(19186,748506739018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','larrucea_1977','nacho.larrucea@gmail.com','IGNACIO LARRUCEA RIBOT','C/ IBIZA, 66 8ºA','MADRID','Madrid','SPAIN','28009','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-30 23:21:31',0,NULL,3,1,2,1,NULL,'larrucea_1977'),(19187,879599553015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','bonzaibenjamin','belonibenjamin@gmail.com','Benjamin Beloni','108 Midenhall rd','Birmingham','West Midlands','UNITED KINGDOM','B42 2PQ','07580379381','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-31 00:10:06',0,NULL,3,1,4,1,'YW867738400CN','bonzaibenjamin\r1.6*2.1白+黑背景布'),(19188,788002277002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','kristina_imogen','kristinaimogen@hotmail.com','Kristina Frey','2/22 Beach Street','Kingscliff','New South Wales','AUSTRALIA','2487','0266742186','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 00:48:02',0,NULL,3,1,2,1,NULL,'kristina_imogen'),(19189,805386826017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','goyoh','goyohpablo@hotmail.com','GREGORIO HERNANDEZ PABLO','SANTADER MEDITERRANEO Nº19 4º D','CALATAYUD','Zaragoza','SPAIN','50300','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 00:50:30',0,NULL,3,1,3,1,'RA117760207CN ','goyoh'),(19190,745390096001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','guywithdog','kannan.pagalam@gmail.com','Kannan Pagalam','6519 Wellwood Street','Greely','ON','CANADA','K4P 1G2','(613) 619-4868','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 01:15:06',0,NULL,3,1,2,1,NULL,'guywithdog'),(19191,8881320025503798,111,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',12.51,'aliexpress','1004982165','jandow@live.dk','Jan Dow','Fuglevaenget 72h','Grenaa','grenaa','DENMARK','8500','+45 5014 4092',NULL,NULL,NULL,'2011-10-31 01:45:03',0,NULL,3,1,3,1,'RA117760388CN\r ',NULL),(19192,788023736002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','truhlik_fredy','anton.krug@gmail.com','Anton Krug','196 Hennessy\'s Road','Waterford','Waterford','IRELAND','default','0863300562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 01:46:28',0,NULL,3,1,2,1,' ','truhlik_fredy'),(19198,788047834002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','pet1706','pmil58@bigpond.com','PETER MILARAS','52 Balaclava Rd Earlville','CAIRNS','Queensland','AUSTRALIA','4870','0418384933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 03:12:54',0,NULL,3,1,2,1,' ','pet1706'),(19193,8881320026410436,111,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',10.55,'aliexpress','1004991734','ssv2021l@yandex.ru','Elena Rozhdestvenskaya	','kvartal 15, house 10, flat 66','Samara','Samarskaya region	','RUSSIAN FEDERATION	','443107','+8 927 2603078',NULL,NULL,NULL,'2011-10-31 02:00:10',0,NULL,3,1,3,1,'RA117760175CN ','2云柔 * 1\rE27单灯头 *  1（欧标） '),(19194,8881320026652071,111,'New Photo Studio Light Stand Umbrella Flash C Mount set',1,'AKT052',42.99,'aliexpress','1004991734','ssv2021l@yandex.ru','Elena Rozhdestvenskaya	','kvartal 15, house 10, flat 66','Samara','Samarskaya region	','RUSSIAN FEDERATION	','443107','+8 927 2603078',NULL,NULL,NULL,'2011-10-31 02:04:12',0,NULL,3,1,17,0,NULL,'（订单ID应该是 ： 1004991733 ） '),(19195,8881320026766518,111,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',10.55,'aliexpress','1004991842','ssv2021l@yandex.ru','Elena Rozhdestvenskaya	','kvartal 15, house 10, flat 66','Samara','Samarskaya region	','RUSSIAN FEDERATION	','443107','+8 927 2603078',NULL,NULL,NULL,'2011-10-31 02:06:06',0,NULL,7,0,18,0,NULL,NULL),(19196,8881320026828558,111,'New Photo Studio Light Stand Umbrella Flash C Mount set',1,'AKT052',42.99,'aliexpress','1004991841 ','ssv2021l@yandex.ru','Elena Rozhdestvenskaya	','kvartal 15, house 10, flat 66','Samara','Samarskaya region	','RUSSIAN FEDERATION	','443107','+8 927 2603078',NULL,NULL,NULL,'2011-10-31 02:07:08',0,NULL,7,0,18,0,NULL,''),(19197,8881320027473063,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft',2,'AO0005',33.98,'aliexpress','1004998237','oboroten71@gmail.com','Victor Goncharov	','ul. Arsenalnaya, dom 24, kv. 21','Tula','Tulskay','RUSSIAN FEDERATION	','300044','+7 961 1500174',NULL,NULL,NULL,'2011-10-31 02:17:53',0,NULL,3,1,3,1,'RA117763279CN\r ','1.6x3.0m 背景布 * 2 （蓝、灰）'),(19199,748588839018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','audmdc5r','b12b2@hotmail.com','Eddie Phan','333 Alexander Drive, Dianella','Perth','Western Australia','AUSTRALIA','6059','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-31 03:40:50',0,NULL,3,1,3,1,'RA117760238CN\r ','audmdc5r'),(19200,745431816001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','chenlg','chenlgyq@hotmail.com','Ligong Chen','1014 Julian Pl','Rockville','MD','UNITED STATES','20852','','NoPaymentFailure','CheckoutComplete','Other','2011-10-31 03:41:29',0,NULL,3,1,1,1,NULL,'chenlg'),(19201,748593409018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','purplerushton','helen.rushton1@gmail.com','Helen Rushton','277 Congarinni Road south','Macksville','New South Wales','AUSTRALIA','2447','0265682375','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-31 04:03:55',0,NULL,3,1,3,1,'RA117760167CN ','purplerushton'),(19208,805506717017,270750638809,'Neoprene Protector Camera Cover 4 Nikon D700 D300s L ',1,'AC1303',6.98,'photographyacc','bonbon081','bonbon081@yahoo.com.au','Bonita Holmes','65 Ullora Close<br>n/a','Nelson Bay','New South Wales','AUSTRALIA','2315','0438607627','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-31 09:09:47',0,NULL,3,1,2,1,NULL,'bonbon081'),(19202,748603600018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','gunter_f_g','g_girke@hotmail.com','Gunter Girke','4 Clementine Close','Lysterfield','Victoria','AUSTRALIA','3156','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-31 05:04:05',0,NULL,3,1,2,1,NULL,'gunter_f_g'),(19203,745456168001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','pra123456','prabath_udayanga@yahoo.com','Prabhath Gunawardhana','No. 3/79, Pasal Mawatha,<br>Talahena,','Malabe','Malabe','SRI LANKA','CO	10115','0772078393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 06:24:03',0,NULL,3,1,2,1,NULL,'pra123456'),(19204,861582523016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','saiyogi','gnanes@gmail.com','Mr G Maheswaran','28E 8th Lane','Colombo','','SRI LANKA','03','94112580399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 06:34:57',0,NULL,3,1,2,1,NULL,'saiyogi'),(19205,788087383002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','theedna','storeytime101@hotmail.com','Shannon Storey','2-3030 Trethewey St','Abbotsford','BC','CANADA','V2T4N2','(604) 859-1155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 06:43:29',0,NULL,3,1,5,1,'CP238126536CN ','theedna'),(19206,748634241018,280709593667,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',36,'photographyacc','scrappyscrappylu','lu2d2@hotmail.com','Alita Champion','4<br>Cole Court','Morphett Vale','South Australia','AUSTRALIA','5162','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-10-31 08:20:13',0,NULL,3,1,3,1,'RA117763353CN\r ','scrappyscrappylu'),(19207,8881320049950570,111,'Studio Light 2300W Continuous Lighting Kit Set (The default backdrop replaced by 5m black backdrop)',1,'AKT041',0,'hermeshine','agnes.karasek','anezka.karaskova@gmail.com','Anežka Karásková','Zelená 34','Prague','','CZECH REPUBLIC','16000','',NULL,NULL,NULL,'2011-10-31 08:32:30',0,NULL,3,1,5,1,'CP238126902CN ','背景布换成1.6x5m 黑色 '),(19209,745274864001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','anzorthedragon','t.kimm.10@scu.edu.au','Teresa Kimm-Stoten','38 Margaret Street','Glen Innes','New South Wales','AUSTRALIA','2370','0410176024','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 09:09:48',0,NULL,3,1,2,1,NULL,'anzorthedragon'),(19210,788118303002,120758268927,'Camera protector case bag f Nikon D200 D300s D700 XL',1,'AD1174',12.99,'hermeshine','palbote','palbote@ono.com','Juan M Leria','General Lacy, 1','Madrid','Madrid','SPAIN','28045','609243236','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 09:10:13',0,NULL,3,1,2,1,NULL,'palbote'),(19211,748652892018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','gsha8723','graham.sharpe2@gmail.com','Graham Sharpe','PO Box 671','Clermont','Queensland','AUSTRALIA','4721','4027784124','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-10-31 09:24:49',0,NULL,3,1,3,1,'RA117763282CN\r ','gsha8723'),(19212,745513291001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','jvcsamelli','info@jerusalemvideoconference.com','Sam Elli Glass','4 Rechov Hoshea','Geula','Jerusalem','ISRAEL','95784','9722- 537-6550','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-31 10:38:34',0,NULL,3,1,3,1,'RA117763296CN\r ','jvcsamelli'),(19213,745522587001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:25',0,NULL,3,1,17,0,NULL,'jonmensa'),(19214,745522588001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:26',0,NULL,3,1,17,0,NULL,'jonmensa'),(19215,788150900002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:26',0,NULL,3,1,17,0,NULL,'jonmensa'),(19216,745522589001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-31 11:11:27',0,NULL,3,1,17,0,NULL,'jonmensa'),(19217,745522590001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:27',0,NULL,3,1,17,0,NULL,'jonmensa'),(19218,745522591001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:28',0,NULL,3,1,17,0,NULL,'jonmensa'),(19219,788150902002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:29',0,NULL,3,1,17,0,NULL,'jonmensa'),(19220,745522593001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','jonmensa','jonmensa@hotmail.com','Jonathan  Mendez Sanchez','Trafalgar, 3, 2B','Madrid','Madrid','SPAIN','28010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:11:29',0,NULL,3,1,3,1,'RA117763945CN ','jonmensa\rc 里面的接口环换成52的  \r然后除了c 里面的再发\r反光板  80cm 5合1    1\r镜头筒 小号     1\r带水平仪 热靴保护盖     1\rEW-78D    1\r橡胶遮光罩 52mm     1\rcanon 反接环  52mm    1\r方形滤镜接口环 72mm    1'),(19221,788148847002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','danudura','dhanushkadura@yahoo.com','MURKKUWA DURA DHANUSHKA','TOKYOTO,SHIBUYAKU,TOMIGAYA<br>2-2-20 SAKURA HOUSE TOMIGAYA APARTMENT (201)','SHIBUYA','Tokyo','JAPAN','151-0063','(090) 6035-8187','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:30:19',0,NULL,3,1,3,1,'RA117763340CN\r ','danudura'),(19222,788161590002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','iamfakeman','ofirbensh@gmail.com','ophir benshimon','Ra\'anan 32/4 Tel aviv','Tel-aviv','','ISRAEL','66096','+972-50-687744','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 11:48:43',0,NULL,3,1,2,1,NULL,'iamfakeman'),(19223,788115429002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tim27ht-08','tim27ht@gmail.com','Tim Hutabarat','KANWIL BRI Banjarmasin<br>Jl. Ahmad Yani KM 3,5 No. 151, lt. 3','Banjarmasin','Kalimantan Selatan','INDONESIA','70429','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 12:20:25',0,NULL,3,1,2,1,NULL,'tim27ht-08'),(19224,861695688016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','mari.nka-2008','mari.nka@mail.ee','Marina Suvorova','Karukella tee 2-8','Tallinn','Harjumaa','ESTONIA','12015','+3725134903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 12:36:40',0,NULL,3,1,3,1,'RA117763588CN\r ','mari.nka-2008'),(19225,786165854002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','bern1962','yaakovbe1@bezeqint.net','yaakov bernard','Hemek ahula 97/2','Modiin','israel','ISRAEL','71700','+97289704239','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 12:42:58',0,NULL,3,1,2,1,NULL,'bern1962'),(19226,861727161016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','thatuseridisntavailable','patrinamail@gmail.com','Tamara Patrina','Meiju celsh 30-58','Jelgava','Zemgale','LATVIA','LV-3007','+371-2-9793171','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-10-31 13:55:37',0,NULL,3,1,5,1,'CP238126540CN ','thatuseridisntavailable\r申报 lighting kit  $30'),(19227,788218973002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','studmaks','cheaterrr@list.ru','Maxim Studenikin','8 microrayon, 80 -12','Temirtau','Karaganda','KAZAKHSTAN','101400','8-7213-93-89-02','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 14:41:39',0,NULL,3,1,2,1,NULL,'studmaks'),(19228,788222617002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','kuanseongsg','shamanyeoh@hotmail.com','Yeoh Kuan Seong','Blk 625a, Woodlands Drive 52<br>#07-57','default','','SINGAPORE','731625','+65-96317480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 14:49:12',0,NULL,3,1,11,1,NULL,'kuanseongsg'),(19229,745593445001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','picturelizard','ebay@picturelizard.co.uk','Peter Townsend Picturelizaerd','Unit 2<br>Cobhan Centre','Swindon','Wiltshire','UNITED KINGDOM','SN5 7UJ','08454747842','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-31 14:50:57',0,NULL,3,1,4,1,'YW867660011CN ','picturelizard\r英标'),(19230,748770155018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','phantaman-949266','matteofantolini@hotmail.com','Dott.sa Luisa Maccari','Corso Torino 196<br>c/o Farmacia San Lazzaro','Pinerolo','TO','ITALY','10064','+393479077219','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 15:19:52',0,NULL,3,1,4,1,'YW867660022CN ','phantaman-949266'),(19231,805686831017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','freenoo','freeno@me.com','Assan Njie/ Njie Group AB','Wadmansgatan 6','Gothenburg','','SWEDEN','41253','0046739725999','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 17:24:57',0,NULL,3,1,4,1,'YW867660055CN ','freenoo'),(19232,788301301002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','aryetrtn56','aryetrtn@012.net.il','Arie Trachtenberg','Atzmon 18B','Ness Ziona','','ISRAEL','74090','972-777887882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 17:56:06',0,NULL,3,1,2,1,NULL,'aryetrtn56'),(19233,748878101018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',7,'AE1203',38.5,'photographyacc','lea.nena','72leati@email.it','Mario Desiderio c/o DAVINCI','Cso. Umberto I, 391','Montesilvano','PE','ITALY','65015','0854483014','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 19:06:31',0,NULL,3,1,3,1,'RA117760895CN\r ','lea.nena\r'),(19234,788349089002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','red3d','peter@antfarm.se','peter narkiniemi','skomakarvägen 2h','Eskilstuna','','SWEDEN','63223','+46708601350','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 19:26:07',0,NULL,3,1,2,1,NULL,'red3d'),(19235,745734329001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','olea_matis','victormatisiuc@gmail.com','Victor Matisiuc','Mircea cel Batrin 4 ap. 133','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','MD-2044','373-69596649','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 19:52:09',0,NULL,3,1,17,0,NULL,'olea_matis'),(19236,745735535001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','olea_matis','victormatisiuc@gmail.com','Victor Matisiuc','Mircea cel Batrin 4 ap. 133','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','MD-2044','373-69596649','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 19:54:27',0,NULL,3,1,2,1,NULL,'olea_matis\rNIKON 镜头盖 67mm    1\rNIKON 镜头盖 72mm    1'),(19237,788366318002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-31 20:01:06',0,NULL,3,0,3,1,'RA117763407CN\r ','cajaibamarcos\r3XL   已入库 \r'),(19238,788369228002,120758268927,'Camera protector case bag f Nikon D200 D300s D700 XL',1,'AD1174',12.99,'hermeshine','pablocisneros','shantiyogananda@hotmail.com','Pablo Cisneros','Bolivar 20-35 y Quito','Ambato','Tungurahua','ECUADOR','1801','+593 99226730','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 20:05:42',0,NULL,3,1,2,1,NULL,'pablocisneros'),(19239,745748235001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','sexy_cat_1986','mpp_51@hotmail.com','Miriam Pérez Pérez','C/ Guzmán el Bueno, 18 -1ºB','Palencia','Castilla y León','SPAIN','34004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 20:19:42',0,NULL,3,1,2,1,' ','sexy_cat_1986'),(19240,741851438001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','10chedey10','chedey10@gmail.com','chedey cerpa','camino cerro de los gamos 3','pozuelo de alarcón','Madrid','SPAIN','28224','637574920','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-10-31 20:24:24',0,NULL,3,1,4,1,'YW867660066CN ','10chedey10'),(19241,745750796001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','2010fms1983','sashafms@gmail.com','alexander krasilshchekov','hazit 4/12','tirat karmel','','ISRAEL','30200','0546265553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 20:25:38',0,NULL,3,1,2,1,NULL,'2010fms1983'),(19242,880118631015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','knutter999','ar.se20@ymail.com','andrew rose','hillside<br>whitehall','stronsay','Orkney','UNITED KINGDOM','kw17 2ar','01857616277','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-10-31 21:21:19',0,NULL,3,1,2,1,NULL,'knutter999'),(19243,744394438001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.99,'hermeshine','vincetoro','viciotoro@gmail.com','Vincenzo Santoro','Via Paladini 280','Caltanissetta','CL','ITALY','93100','336271837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 21:25:27',0,NULL,3,1,3,1,'RA117763398CN\r ','vincetoro\r欧标   两个店 分开发  '),(19244,878383521015,250600488479,'New Hairlight  photostudio boom arm and Light stand ',1,'AKT030',32.8,'hutongstore','vincetoro','viciotoro@gmail.com','Vincenzo Santoro','Via Paladini 280','Caltanissetta','CL','ITALY','93100','336271837','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-10-31 21:28:00',0,NULL,3,1,3,1,'RA117763336CN\r ','vincetoro\r两个店分开发 '),(19245,788413286002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','ksenthuran','senthurank@hotmail.co.uk','Senthuran Kulasingam','16, College gradens','Newmalden','London','UNITED KINGDOM','KT3 6NT','07507131372','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 21:40:13',0,NULL,3,1,12,1,'1733196264\r ','ksenthuran\r英标\r实重   5.94  泡重  7.7'),(19246,745797277001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','territerri86','t.welsh86@yahoo.co.uk','terriann welsh','4 DUNDRENNAN COTTAGES','edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH165RG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 22:15:27',0,NULL,3,0,3,1,'RA117763305CN\r ','territerri86\r白+黑'),(19247,805844083017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 22:24:10',0,NULL,3,1,17,0,NULL,'ddt251'),(19248,805845797017,270750651332,'New Large size Neoprene Lens Pouch / Case 90mm x 220mm ',1,'AC1203',4.99,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 22:28:04',0,NULL,3,1,17,0,NULL,'ddt251'),(19249,805848236017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','ddt251','davide.dortona@tiscali.it','davide silvano d\'ortona','via verdi, 58','bollate','MI','ITALY','20021','347-2201022','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-10-31 22:34:47',0,NULL,3,1,2,1,' ','ddt251\r眼罩 D300    1\r镜头筒 大号     1\r镜头筒 小号     1'),(19250,745806715001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','falconetti10','falcondiets@yahoo.co.uk','Pedro Falcon Marrero','Calle del cedro, 12<br>La Jaca','Arico','Santa Cruz de Tenerife','SPAIN','38588','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-10-31 22:41:41',0,NULL,3,1,4,1,'YW867660070CN ','falconetti10'),(19251,862026698016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','weregame2010','robbhamish@yahoo.com','Hamish Robb','Ivy lodge<br>Ivy walk','Newton of Falkland','Fife','UNITED KINGDOM','KY15 7RZ','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-10-31 23:04:10',0,NULL,3,1,4,1,'YW867660081CN ','weregame2010'),(19252,8881320110349507,111,'Light Stand 84cm / 32\" for back light studio',1,'AE3501',19.6,'aliexpress','1005010238','collezione@yandex.ru','Tetyushina Ninel	','Kominterna 54 kor.3 kv.39','Moscow','Moscow','RUSSIAN FEDERATION	','129346','+7 926 5393061',NULL,NULL,NULL,'2011-11-01 01:19:09',0,NULL,7,0,18,0,NULL,NULL),(19253,8881320110363057,111,'Light Stand 84cm / 32\" for back light studio',1,'AE3501',19.6,'aliexpress','1005010238','collezione@yandex.ru','Tetyushina Ninel	','Kominterna 54 kor.3 kv.39','Moscow','Moscow','RUSSIAN FEDERATION	','129346','+7 926 5393061',NULL,NULL,NULL,'2011-11-01 01:19:09',0,NULL,3,1,3,1,'RA117760754CN ',''),(19254,8881320110363057,111,'Light Stand 84cm / 32\" for back light studio',1,'AE3501',19.6,'aliexpress','1005010238','collezione@yandex.ru','Tetyushina Ninel	','Kominterna 54 kor.3 kv.39','Moscow','Moscow','RUSSIAN FEDERATION	','129346','+7 926 5393061',NULL,NULL,NULL,'2011-11-01 01:19:09',0,NULL,7,0,18,0,NULL,NULL),(19255,8881320110692122,111,'10 pcs color filters ring holder box for cokin p series',1,'AKT076',45.95,'aliexpress','1005013884','govorai@yandex.ru','Aleksey Govorushkin	','Kozlova str. house 23/2, apart.32','Saint-Petersburg	','Leningradskaya obl.	','RUSSIAN FEDERATION	','198260','+7 921 3307929',NULL,NULL,NULL,'2011-11-01 01:24:52',0,NULL,3,1,3,1,'RA117763565CN\r ','转接环 72mm'),(19256,745856727001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','rv-8a_builder','loemker@att.net','Christopher Loemker','20 Burdick Creek Rd','Collinsville','IL','UNITED STATES','62234-6800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 01:46:41',0,NULL,3,1,17,0,NULL,'rv-8a_builder'),(19257,788489514002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','rv-8a_builder','loemker@att.net','Christopher Loemker','20 Burdick Creek Rd','Collinsville','IL','UNITED STATES','62234-6800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 01:46:42',0,NULL,3,1,17,0,NULL,'rv-8a_builder'),(19258,788489513002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rv-8a_builder','loemker@att.net','Christopher Loemker','20 Burdick Creek Rd','Collinsville','IL','UNITED STATES','62234-6800','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 01:46:41',0,NULL,3,1,1,1,NULL,'rv-8a_builder\rCANON 镜头盖  67mm    1\rCANON 镜头盖  77mm      1\rCANON 镜头盖  58mm    1'),(19259,788497543002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','mlkt2308','mariathompson23@gmail.com','Maria Thompson','17 Ormiston Gardens, Clarkson','Perth','Western Australia','AUSTRALIA','6030','0893044609','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 02:18:56',0,NULL,3,1,2,1,NULL,'mlkt2308'),(19260,802759675017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','blkfxx113','blkfxx@hotmail.com','Daniel Dullaard','222 Cox\'s River Road','Little Hartley','New South Wales','AUSTRALIA','2790','0263552205','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-01 02:26:35',0,NULL,3,1,2,1,NULL,'blkfxx113'),(19265,745895601001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','jrumal','jayamunirs@gmail.com','Rumal Jayamuni','PMB 938<br>185 Loch St.','Derby','Western Australia','AUSTRALIA','6728','61400518833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 05:29:01',0,NULL,3,1,17,0,NULL,'jrumal'),(19261,745878012001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',35.99,'hermeshine','dominic69690','gsavard@hotmail.com','genevieve savard','2052 Lamartine','quebec','QC','CANADA','G3J 0C3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 03:27:33',0,NULL,3,1,3,1,'RA117763265CN\r ','dominic69690'),(19262,805937661017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','mpg007','mpg007@aol.com','Martin Galen','300 Ridge Rd','Dayton','NJ','UNITED STATES','08810-1506','(732) 406-2233','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 03:58:15',0,NULL,3,1,1,1,NULL,'mpg007'),(19263,788525148002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','properexposure57','dtbramadat@mts.net','Derek Bramadat','18 Normandy Drive','Winnipeg','MB','CANADA','R2Y 1H9','(204) 889-4428','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 04:40:22',0,NULL,3,1,2,1,NULL,'properexposure57'),(19264,744314846001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',116.63,'hermeshine','takechiyo','go.george2@gmail.com','George Go','1140-1185 West Georgia Street','Vancouver','BC','CANADA','V6E 4E6','(604) 303-7700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 04:44:21',0,NULL,3,0,5,1,'CP238126553CN ','takechiyo\r2m 灯架     2\r反光板支架      1\r110cm5和1      1\r小号灰卡      1\r已入库  申报 light stand  $20'),(19266,745895603001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','jrumal','jayamunirs@gmail.com','Rumal Jayamuni','PMB 938<br>185 Loch St.','Derby','Western Australia','AUSTRALIA','6728','61400518833','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-01 05:29:02',0,NULL,3,1,17,0,NULL,'jrumal'),(19267,745895604001,110454864267,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',7.89,'hermeshine','jrumal','jayamunirs@gmail.com','Rumal Jayamuni','PMB 938<br>185 Loch St.','Derby','Western Australia','AUSTRALIA','6728','61400518833','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 05:29:03',0,NULL,3,1,3,1,'RA117763574CN\r ','jrumal\r帽子 canon      1\r背心绿色薄 canon  XL   1\r肩带 无字     1'),(19268,745078378001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','link130786','watsup86@mail.ru','Sergey Burlakov','50 Let Magnitki 32/3 67','Magnitogorsk','Chelyabinskaya oblast\'','RUSSIAN FEDERATION','455051','89030906976','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 05:47:47',0,NULL,3,1,2,1,NULL,'link130786\r欧标'),(19269,880299365015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','kholymm','kholymm@hotmail.com','J. Javier Mejías M.','c/ Ecuador nº13','Alcalá de Guadaíra','Sevilla','SPAIN','41500','676388888','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 07:48:16',0,NULL,3,1,4,1,'YW867660114CN ','kholymm'),(19270,749110490018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','monster_1976','angie.m@exemail.com.au','Angie J Martin','10 Weddell Close','Canning Vale','Western Australia','AUSTRALIA','6155','0894560070','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-01 08:48:45',0,NULL,3,1,4,1,'YW867660125CN ','monster_1976'),(19271,736666431001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 09:23:32',0,NULL,3,1,17,0,' ','saud-p\r'),(19272,745940874001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','physiocut7','physiomurray@gmail.com','Murray Thompson','20 Birdrock Ave','Mount Martha','Victoria','AUSTRALIA','3934','0359757012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 09:29:57',0,NULL,3,1,17,0,NULL,'physiocut7'),(19273,745942004001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','physiocut7','physiomurray@gmail.com','Murray Thompson','20 Birdrock Ave','Mount Martha','Victoria','AUSTRALIA','3934','0359757012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 09:33:30',0,NULL,3,1,17,0,NULL,'physiocut7'),(19274,880330487015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','vjannus','vjannus@gmail.com','Veres János','Kerepesi 132-134 III/38','Budapest','Budapest','HUNGARY','1144','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 09:35:13',0,NULL,3,1,5,1,'CP238126567CN ','vjannus\rgift  $10\r白+灰'),(19275,745943816001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',6.3,'hermeshine','physiocut7','physiomurray@gmail.com','Murray Thompson','20 Birdrock Ave','Mount Martha','Victoria','AUSTRALIA','3934','0359757012','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 09:39:44',0,NULL,3,1,2,1,NULL,'physiocut7\r橡胶遮光罩 58mm     2\r绿叶 UV  58mm    2'),(19276,862190667016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','joyx81','lo__straniero@hotmail.com','Loforese  Antonietta','via Fratelli Cervi 3','Bitritto','BA','ITALY','70020','3315843933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 09:42:31',0,NULL,3,1,2,1,NULL,'joyx81'),(19277,806013712017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','ppip36','panuccio36@gmail.com','Panu Puustinen','Rantavitikantie 4 as 23','Rovaniemi','Lappi','FINLAND','96300','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 10:07:02',0,NULL,3,1,2,1,NULL,'ppip36'),(19278,806024208017,270751511455,'YongNuo 3m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3325',28.99,'photographyacc','leonino11','j.franciscoperie@gmail.com','Oscar Leonardo Amarilla','Avenida Cordoba 1554<br>Piso 6 Depto B','Ciudad Autónoma de Buenos Aires','Buenos Aires','ARGENTINA','1055','(011) 4816-7288','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 10:38:03',0,NULL,3,1,3,1,'RA117760900CN\r ','leonino11\r▲'),(19279,806025488017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','fabiodcg','fabiodcg@hotmail.com','Fabio Del Core Gomes','Rodovia Rio Teresópolis BR116 Km127,3<br>Suruí','Magé','Rio de Janeiro','BRAZIL','25900000','21 26470515','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 10:45:01',0,NULL,3,1,2,1,NULL,'fabiodcg'),(19280,788602311002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','sdjaques','stevedjaques@aol.com','stephen jaques','E H THOMPSON<br>HALLSFORD BRIDGE IND EST','STONDON ROAD','ONGAR ESSEX','UNITED KINGDOM','CM5 9RB','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-01 10:56:21',0,NULL,3,0,3,1,'RA117760808CN\r ','sdjaques\r2XL  已入库'),(19281,749153296018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','roman_magpie','roman_soroka@hotmail.com','Roman Soroka','15 Nina Jones Crescent','CHISHOLM','Australian Capital Territory','AUSTRALIA','2905','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-01 11:08:25',0,NULL,3,1,2,1,NULL,'roman_magpie'),(19282,880378105015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','jdmhusky','4jdmpower@gmail.com','Matevz Rus','Godic 80h','Kamnik','Stahovica','SLOVENIA','1242','031842341','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-01 11:36:24',0,NULL,3,1,3,1,'RA117760710CN\r ','jdmhusky'),(19283,745984607001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',2,'AC3301',31.96,'hermeshine','tomasvoim','tomivoim@gmail.com','Tomáš Képeš','Jána Hunyadiho<br>1','Moldava nad Bodvou','','SLOVAK REPUBLIC','04501','+4210907372391','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 12:04:49',0,NULL,3,1,3,1,'RA117760785CN\r ','tomasvoim'),(19284,745994267001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','shafz007','shafeeq.tayob@gmail.com','Shafeeq Tayob','Po Box 854<br>Crown Mines','Johannesburg','Gauteng','SOUTH AFRICA','2025','27829052221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 12:27:57',0,NULL,3,1,2,1,NULL,'shafz007'),(19285,788642011002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','ringo5a','ringo5@sky.com','shaun ringland','90 bromford road<br>hodge hill','birmingham','West Midlands','UNITED KINGDOM','b36 8tg','01213276076','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:01:30',0,NULL,3,1,2,1,NULL,'ringo5a'),(19286,746018704001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','dvdelgadof','dvdelgadof@gmail.com','Domingo Valentin Delgado Fernandez','Antonio Gaudi, 13','Alcala de Henares','Madrid','SPAIN','28806','918029807','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 13:41:12',0,NULL,3,1,2,1,NULL,'dvdelgadof'),(19287,880476931015,250895608807,'Promotions! DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D',1,'AD1188',48,'hutongstore','achr4988','davina5@hotmail.co.uk','Allia Christie','56 Marlborough Road<br>Chingford','London','London','UNITED KINGDOM','E49AL','02085273934','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-01 15:24:31',0,NULL,3,1,3,1,'RA117760745CN\r ','achr4988'),(19288,746075122001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','photo_master.and','andrey.schnell@gmail.com','Andrey Schnell','Beregowaja 41','Aksu','Pawlodar','KAZAKHSTAN','140100','87183733084','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 16:12:40',0,NULL,3,1,8,1,'CP238126893CN ','photo_master.and\r欧标'),(19289,788718148002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','lcmf4785','lutimelhado@gmail.com','luiz carlos melhado filho','ALAMEDA LUXEMBURGO,418<br>ALPHAVILLE 1','BARUERI- SÃO PAULO','SÃO PAULO','BRAZIL','06474200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 16:22:13',0,NULL,3,1,2,1,NULL,'lcmf4785'),(19290,788722477002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','polyakov2011','igpol04@rambler.ru','Игорь Поляков','ул.красная 97/1 кв.116','ст.динская','Краснодарский край','RUSSIAN FEDERATION','353200','8918-99-87-232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 16:32:37',0,NULL,3,1,3,1,'RA117760839CN\r ','polyakov2011'),(19291,862366668016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',2.25,'hutongstore','sun.piper','dfrew@btinternet.com','Darren Frew','43 Portna Road<br>Kilrea','Coleraine','Londonderry','UNITED KINGDOM','BT51 5SW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-01 16:36:50',0,NULL,3,1,2,1,NULL,'sun.piper'),(19292,788745147002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','friendlybiz','aedefensor@gmail.com','Angelo Defensor','6 King Edward Court','Middlesex','London','UNITED KINGDOM','ha9 7dq','02087955556','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:20:09',0,NULL,3,1,3,1,'RA117760842CN\r ','friendlybiz'),(19293,736141299001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 17:45:41',0,NULL,3,1,17,0,NULL,'saud-p'),(19294,746120317001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','sirius063','e.vatolin@mail.ru','Evgeniy Vatolin','Sportivnaya 8-122','Togliatti','Samarskaya obl','RUSSIAN FEDERATION','445057','8482363234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 17:46:12',0,NULL,3,1,2,1,NULL,'sirius063'),(19295,746139346001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','1058terri','teresa.merola@virgilio.it','Teresa Merola','via terragrande<br>49','curti','CE','ITALY','81040','0823811752','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 18:18:50',0,NULL,3,1,2,1,NULL,'1058terri'),(19296,749329340018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',2,'AD1180',29.8,'photographyacc','soktwo','soktwo@hotmail.com','Claudio Balas','Rua da Industria nº37, 2º Esq','Lisboa','','PORTUGAL','1300-302','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 18:24:17',0,NULL,3,1,3,1,'RA117760723CN\r ','soktwo'),(19297,880587869015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','philh61','p.j.hawkins@live.co.uk','philip hawkins','28 omer avenue<br>cliftonville','margate','Kent','UNITED KINGDOM','ct9 3bx','01843280981','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-01 18:31:46',0,NULL,3,1,2,1,NULL,'philh61'),(19298,736141609001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-01 18:33:21',0,NULL,3,1,17,0,NULL,'saud-p'),(19299,746182639001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-01 19:49:48',0,NULL,3,1,17,0,NULL,'saud-p'),(19300,746160116001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',2,'AKT005',370,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 19:49:49',0,NULL,3,1,17,0,NULL,'saud-p'),(19301,746163008001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 19:49:51',0,NULL,3,1,12,1,'1733187540\r ','saud-p\r灯架  2m    12\r斜臂       2\r柔光箱 50-70cm 单灯头    12\r115w 5500k 灯泡  220v     12\r灯架包      5\r3m 横杆（通用4节）     1\r1.6*2.1黑色      1\r1.6*2.1白色背景布      4\r背景架2mx 2m+ 3个夹子      4\r贴made in china  \r申报实值lighting kit  $1000\r实重38.026  泡重98*36*55=194040/5000=38.808'),(19302,746199631001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','elenaclaudia09','elenahierro1@hotmail.com','Elena Hierro Rubio','c/zabala, n65, 2d','bilbao','País Vasco','SPAIN','48003','688677879','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 20:06:08',0,NULL,3,0,2,1,NULL,'elenaclaudia09\r1.6*2.1黑色'),(19303,746229605001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','il_nero','maxmobnet@gmail.com','Ferenc Fekete','Gyongyvirag u. 30.','Nagykovacsi','EU','HUNGARY','2094','+36203404974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 21:03:45',0,NULL,3,1,3,1,'RA117760799CN\r ','il_nero'),(19304,749421383018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',63,'photographyacc','mr_compras','javier@thesmile.tv','Javier Lamaignere Weber','Llull 70-72<br>2 6','Barcelona','Cataluña','SPAIN','08005','667838742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-01 21:23:34',0,NULL,3,1,4,1,'YW867660103CN ','mr_compras'),(19305,806340851017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','trinjty10','anhtrinh108@hotmail.com','anh trinh','shop8-9 fairfield forum shopping centre station st<br>fairfield','sydney','New South Wales','AUSTRALIA','2165','0297260046','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-11-01 21:48:49',0,NULL,3,1,4,1,'YW867660092CN ','trinjty10'),(19306,746274390001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','r412wei','e2011.wei@gmail.com','Tianwen Wei','Residence Camus, R 412<br>Cite Scientifique','Villeneuve d\'ASCQ','Nord-Pas-de-Calais','FRANCE','59650','06 68 63 51 04','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-01 22:48:10',0,NULL,3,1,2,1,NULL,'r412wei'),(19307,788913146002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','01photostore','andyadam@sky.com','ANDREW ADAM','16 GREENBANK DRIVE','COWDENBEATH','Fife','UNITED KINGDOM','KY49RP','01383514593','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-01 22:49:08',0,NULL,3,0,3,1,'RA117760825CN\r ','01photostore\r2XL  已入库'),(19308,746278249001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','sergiy1371','bolotnikov@comcast.net','Sergiy Bolotnikov','1471 S Macon Ct','Aurora','CO','UNITED STATES','80012-4132','(303) 368-0932','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-01 22:58:29',0,NULL,3,1,1,1,NULL,'sergiy1371'),(19309,746303646001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','audialearn','timm2006@gmail.com','Tim Maclachlan','Digits Industries Ltd, Office 4,<br>Universal Marina, Crableck Lane','Sarisbury Green, Southampson','Hampshire','UNITED KINGDOM','SO31 7ZN','01489889900','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 00:17:25',0,NULL,3,1,3,1,'RA117760737CN\r ','audialearn\r已入库'),(19310,749505113018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','collerampa','carlosoma@teletu.it','Carlo Somà','Via Aniene 26','Guidonia','RM','ITALY','00012','3339762333','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 00:52:51',0,NULL,3,1,17,0,NULL,'collerampa'),(19311,806408092017,270748975009,'Hot Shoe Protector Cover Cap for Sony Alpha A550 A900',1,'AA1205',2.5,'photographyacc','collerampa','carlosoma@teletu.it','Carlo Somà','Via Aniene 26','Guidonia','RM','ITALY','00012','3339762333','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 00:52:51',0,NULL,3,1,2,1,NULL,'collerampa\rNG128 柔光罩    1\r热靴保护盖  sony   1'),(19312,746315537001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','knewkidd','evangee@hotmail.com','Bill Griffiths','62 Brisco Street<br>Basement','Brampton','ON','CANADA','L6V1W8','(647) 377-3826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 00:56:37',0,NULL,3,1,2,1,NULL,'knewkidd'),(19313,746322703001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','smort04','threetanks@gmail.com','clement ireland','19 walmer crescent','wentworth falls','New South Wales','AUSTRALIA','2782','0448539560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 01:19:21',0,NULL,3,1,3,1,'RA117760768CN\r ','smort04'),(19314,8881320197072631,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',18.58,'aliexpress','1005030815','sebastian.sendler@thaiwaterproof.com','Ms. Ploenchit Nualinn	','Ocean Plaza Bangla, Underground Floor, Thaiwaterproof Shop 31 Bangla Road','Patong Beach, Kratu	','Phuket','THAILAND','83150','+66 81 3401444',NULL,NULL,NULL,'2011-11-02 01:24:32',0,NULL,3,1,3,1,'RA117763818CN ',''),(19315,8881320200944928,111,'补发2m灯架配件',1,'',0,'hermeshine','ginger975bora','borahirsova@yahoo.com.tr','Bora HIRSOVA','Sarayardi Cad. No:92/8<br>Hasanpasa/ Kadikoy','Istanbul','','TURKEY','34722','(90) 216 - 3496126',NULL,NULL,NULL,'2011-11-02 02:29:04',0,NULL,3,0,3,1,'RA117760771CN\r ',NULL),(19316,8881320200991902,111,'补发1.6*2.1黑色背景布',1,'',0,'hutongstore','noemar53','noemar53@yahoo.com','noel keegan','53 dingle road<br>cabra west','dublin ','Dublin','IRELAND','7','018384336',NULL,NULL,NULL,'2011-11-02 02:29:51',0,NULL,3,0,3,1,'RA117760811CN\r ',NULL),(19317,789012510002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',1,'AC1203',5.6,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 04:45:31',0,NULL,3,1,17,0,NULL,'ciafquito'),(19318,746369645001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',2,'AC1204',14.4,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde C','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 04:45:32',0,NULL,3,1,2,1,NULL,'ciafquito\r镜头筒 大号    1\r镜头筒 xl 大号     2'),(19319,746387179001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','remiandreheggen','remiandre80@hotmail.com','Remi Andre Heggen','Slattum Terrasse 29A<br>1480 Slattum','Slattum','Slattum','NORWAY','1480','004748482808','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 06:30:32',0,NULL,3,1,2,1,NULL,'remiandreheggen'),(19320,746239756001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',74.97,'hermeshine','gabord7','gaborkiss0222@gmail.com','Gabor Kiss','123 The Hardwicke<br>North Brunswick','Dublin 7','Dublin','IRELAND','D7','0851709399','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 07:17:45',0,NULL,3,0,3,1,'RA117763781CN ','gabord7\r1.6mx2.1m 背景布  2  白 + 黑\r3m 伸缩横杆    1\r倒影板     1\r申报：   accessories   $24\r已入库\r\r'),(19321,746400433001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','harterfunk','daslaute@gmx.de','Henning Groß','Scherenbergstr. 24','Berlin','','GERMANY','10439','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 07:47:58',0,NULL,3,1,3,1,'RA117763906CN ','harterfunk'),(19322,746423239001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','air_bike','air.bike.ebay@gmail.com','Suvorov Vitaly','A. Glushko 28<br>kv. 13','Taganrog','Rostovskaya obl','RUSSIAN FEDERATION','347900','315117','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 09:32:51',0,NULL,3,1,3,1,'RA117763883CN ','air_bike'),(19323,862791769016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','fst1979gib','francistrenado@yahoo.co.uk','Francis Stephen Trenado','9 Evening Primrose House<br>Waterport Terraces','Gibraltar','Gibraltar','GIBRALTAR','n/a','0035058008860','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-02 10:25:29',0,NULL,3,1,17,0,NULL,'fst1979gib'),(19324,880945600015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','fst1979gib','francistrenado@yahoo.co.uk','Francis Stephen Trenado','9 Evening Primrose House<br>Waterport Terraces','Gibraltar','Gibraltar','GIBRALTAR','n/a','0035058008860','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-02 10:25:30',0,NULL,3,1,17,0,NULL,'fst1979gib'),(19325,862791768016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','fst1979gib','francistrenado@yahoo.co.uk','Francis Stephen Trenado','9 Evening Primrose House<br>Waterport Terraces','Gibraltar','Gibraltar','GIBRALTAR','n/a','0035058008860','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 10:25:31',0,NULL,3,1,5,1,'CP239126598CN ','fst1979gib\r2m 灯架  7\r3m 通用横杆 （4节）   1\r背景布 3x6 绿色     1\r薄灯架包   1\r柔光箱 50-70cm 单灯头  5  欧标\r115w 5500k 灯泡  220v   5\r斜臂    1\r灯架包   3\r'),(19326,789100197002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','olegluft','olegl72@gmail.com','Oleg Luft','Ezra Sofer 17/4','Ashdod','','ISRAEL','77468','0508116967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 11:36:06',0,NULL,3,1,3,1,'RA117763852CN ','olegluft'),(19327,789101739002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','lucazz85hz','lucazzo8tt8@tin.it','Luca Tarondi','via Centrale 4/3','Tavagnacco','UD','ITALY','33010','3451830283','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 11:42:10',0,NULL,3,1,4,1,'YW867660136CN ','lucazz85hz'),(19328,806258603017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','osmanovicd','dino.osmanovic@gmail.com','Meho Dugonjic or Midhat Osmanovic','Carsijska BB','Puracic/Lukavac','TK','BOSNIA AND HERZEGOVINA','75305','38761333735','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 12:26:44',0,NULL,3,1,2,1,NULL,'osmanovicd'),(19329,746479808001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','karbosof','trash33@yandex.ru','Sergey Mironov','Vrachebniy proezd 6-2-32','Moscow','','RUSSIAN FEDERATION','125367','+79164991378','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 12:49:29',0,NULL,3,1,5,1,'CP238126607CN ','karbosof'),(19330,789126875002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','keharv1970','ketilharvey@yahoo.no','ketil harvey','Pettersand 83','Fredrikstad','','NORWAY','1614','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 13:02:55',0,NULL,3,1,3,1,'RA117763835CN ','keharv1970'),(19331,749675861018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','voltjr','voltairejr@gmail.com','Voltaire Vargas','Rua Radio TV Gaúcha nr 189','Porto Alegre','RS','BRAZIL','90850080','51 84339820','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 12:51:53',0,NULL,3,1,2,1,NULL,'voltjr'),(19332,879804723015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',27.98,'hutongstore','mirko_exe5','mirko_exe5@yahoo.it','Domenico Sergi','del Santo 221 A','Messina','ME','ITALY','98148','3405708830','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 13:37:16',0,NULL,3,1,2,1,NULL,'mirko_exe5\rc 里面的东西已经发过了  \r再发下面的\r牛津布大包     1\r大号内胆包canon     1\r热靴保护盖  普通      1'),(19333,749694429018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',60,'photographyacc','evalue100','ashaenterprises10@gmail.com','Inder Mehandiratta','16 Iluka Link','Noosaville','Queensland','AUSTRALIA','4566','0403827788','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-02 13:42:59',0,NULL,3,1,3,1,'RA117763866CN ','evalue100'),(19334,746504954001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','pavbear75','pnazarov@land.ru','Pavel Nazarov','Sovetskaya 92-99','Dobryanka','Perm','RUSSIAN FEDERATION','618740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:04:37',0,NULL,3,1,17,0,NULL,'pavbear75'),(19335,789148079002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','pavbear75','pnazarov@land.ru','Pavel Nazarov','Sovetskaya 92-99','Dobryanka','Perm','RUSSIAN FEDERATION','618740','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:04:36',0,NULL,3,1,3,1,'RA117763870CN ','pavbear75\r3m 横杆（通用4节）     1\r斜臂     1'),(19336,789165991002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','maxwailou','duval_maxime@hotmail.com','Maxime DUVAL','1 rue Frantz Despagnet<br>Appartement D01','BORDEAUX','Aquitaine','FRANCE','33000','0607106915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 14:55:26',0,NULL,3,1,3,1,'RA117763821CN ','maxwailou'),(19337,789180133002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','terry2631','tjdp@btinternet.com','Terence Parker','6 Grange Avenue<br>Waterside','Londonderry','Londonderry','UNITED KINGDOM','BT47 5YN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 15:33:02',0,NULL,3,1,2,1,NULL,'terry2631'),(19338,746543763001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','usuriysky_hedgehog','sergsd007@gmail.com','Sergiy Dyagilyev','23 August str. 43A -15','Kharkov','','UKRAINE','61103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 15:52:03',0,NULL,3,1,3,1,'RA117763778CN ','usuriysky_hedgehog'),(19339,789208689002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','dpolushkin','dmtr-plsh@rambler.ru','Дмитрий Полушкин','Калинина, 401, 12','Арзамас','Нижегородская область','RUSSIAN FEDERATION','607220','89506279924','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 16:47:10',0,NULL,3,1,5,1,'CP238126575CN ','dpolushkin\r欧标'),(19340,789214417002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','ethem_ayaz28','ethemayaz@hotmail.com','ibrahim ethem ayaz','yeşilova mh.aziz sk.no:19/2','küçükçekmece','istanbul','TURKEY','34295','05339318526','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 17:02:06',0,NULL,3,1,5,1,'CP238126584CN ','ethem_ayaz28\r欧标\r如果不超过2KG就发小包'),(19341,789218737002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','sylviechampagne2010','s.champagne@cgocable.ca','Sylvie Champagne','140, 8e avenue Sud','East Broughton','QC','CANADA','G0N 1H0','(418) 427-4832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:05:46',0,NULL,3,1,2,1,NULL,'sylviechampagne2010'),(19342,746577523001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','geebob69','geebob@brownsphoto.com','Bob Brown','6 Red Oaks Shopping Ctr<br>Browns Photography','Ronceverte','WV','UNITED STATES','24970-1348','(304) 645-4940','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 17:09:54',0,NULL,3,1,1,1,NULL,'geebob69'),(19343,785308072002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nera1726','nce25@yahoo.com','Narciso Erandio, Duplicating Services','FMC Law, Toronto-Dominion Centre<br>77 King Street West, Suite 400','Toronto','ON','CANADA','M5K0A1','(647) 863-4528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:40:46',0,NULL,3,0,2,1,NULL,'nera1726'),(19344,789243171002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','leocompras','jagy2023@yahoo.es','J A G Y','C/ Murgis, 51 - 3º - G','El Ejido','Almeria','SPAIN','04700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 17:56:05',0,NULL,3,1,2,1,NULL,'leocompras'),(19345,789256919002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','lili1232000','sansfaute@rogers.com','Elizabeth O\'Neill','153 Highland Drive','Hampton','NB','CANADA','E5N 5C6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 18:22:27',0,NULL,3,1,2,1,NULL,'lili1232000'),(19346,789258831002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','lili1232000','sansfaute@rogers.com','Caroline O\'Neill','1-489A Whitmore Avenue','Toronto','ON','CANADA','M6E 2N9','(416) 602-0430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 18:27:31',0,NULL,3,1,2,1,NULL,'lili1232000'),(19347,789278532002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',2,'AB1306',7.58,'hermeshine','alienbunny','steffen-klemz@gmx.de','Steffen Klemz','Bei den Zelten 5','Hamburg','','GERMANY','22111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:01:11',0,NULL,3,1,17,0,NULL,'alienbunny'),(19348,746637572001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',2,'AB1302',6.68,'hermeshine','alienbunny','steffen-klemz@gmx.de','Steffen Klemz','Bei den Zelten 5','Hamburg','','GERMANY','22111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:03:47',0,NULL,3,1,2,1,NULL,'alienbunny\r橡胶遮光罩 72mm     2\r橡胶遮光罩 55mm     2'),(19349,789286962002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','xe-dingo','ericrisa.mail@gmail.com','Eric Risa','Såtaveien 2','Figgjo','','NORWAY','4332','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 19:16:12',0,NULL,3,1,3,1,'RA117763954CN ','xe-dingo'),(19350,863064687016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','zullo2000','sonitas2004@tiscali.co.uk','Helder Matias','5 Ash Drive','Cullompton','Devon','UNITED KINGDOM','ex151su','0188434847','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-02 19:23:49',0,NULL,3,1,2,1,NULL,'zullo2000'),(19351,746678032001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+79062678380','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 20:19:03',0,NULL,3,1,3,1,'RA117763897CN ','igrom78'),(19352,749916766018,280666892339,'New Green.L 62mm  Gradual Grey ND4 Filter 2-Stop 62 mm',1,'AA3318',6.6,'photographyacc','zamataj','zamataj@gmail.com','Anatolijs Zamatajs','Sniega 3/2 - 5','Riga','Riga','LATVIA','LV-1015','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 21:27:32',0,NULL,3,1,2,1,NULL,'zamataj'),(19353,806849578017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',2,'AA1309',5,'photographyacc','freespiritinese','inmoore@hotmail.com','Inese Moore','35 Temple Rd','Dobbs Ferry','NY','UNITED STATES','10522-1311','(914) 694-5915','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 21:36:28',0,NULL,3,1,1,1,NULL,'freespiritinese'),(19354,806855900017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','gzarch','zielinski.greg@gmail.com','gregory zielinski','218 Hampton Cir','Jupiter','FL','UNITED STATES','33458','(561) 373-0900','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 22:08:52',0,NULL,5,0,18,0,NULL,'gzarch'),(19355,806847557017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','gzarch','zielinski.greg@gmail.com','gregory zielinski','218 Hampton Cir','Jupiter','FL','UNITED STATES','33458','(561) 373-0900','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 22:08:53',0,NULL,3,1,1,1,NULL,'gzarch\r碗罩  P4   1\r永诺万用罩     1  （已入库）'),(19356,881329567015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','xapixapo123','iban.ospital@gmail.com','Iban ospital','1 lot Irigoin Ttipi','Itxassou','Aquitaine','FRANCE','64250','0559295143','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-02 22:19:42',0,NULL,3,1,3,1,'RA117763764CN ','xapixapo123'),(19357,746748784001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','ketfi1669','ricky227_1@hotmail.com','ketfi mostefa','6439a rue des portes','montréal','QC','CANADA','H1T3T9','(514) 256-4005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 22:57:04',0,NULL,3,1,2,1,' ','ketfi1669'),(19358,746749797001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','americanbulldogbully007','americanbulldogbully@gmail.com','Wilhelmus Neggers','21674 E 39th Pl S','Broken Arrow','OK','UNITED STATES','74014-1897','(201) 658-7601','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-02 22:59:46',0,NULL,3,1,1,1,NULL,'americanbulldogbully007'),(19359,789400669002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-02 23:28:13',0,NULL,3,1,17,0,NULL,'ravirep1\r布换成黑色的'),(19360,789397205002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','essencyeee','essencyee@yahoo.com','Sandra Ngo','526 Calle Marina<br>Coco Beach','Rio Grande','PR','UNITED STATES','00745-4636','(701) 509-0539','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-02 23:30:14',0,NULL,3,1,4,1,'YW867660140CN ','essencyeee'),(19361,746763133001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 23:41:51',0,NULL,3,1,17,0,NULL,'ravirep1'),(19362,746763230001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-02 23:43:18',0,NULL,3,1,4,1,'YW867660151CN ','ravirep1\r背景架 2mx3m 河北 + 1.6x2.1 黑 +夹子  1\r橡胶遮光罩 55mm    1\rEW-73B      1'),(19363,749971389018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','bmkiesel','bmkiesel@yahoo.com','Brian M. Kiesel','233 E Hillcrest St','Altamonte Springs','FL','UNITED STATES','32701-7632','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-02 23:51:30',0,NULL,3,1,1,1,NULL,'bmkiesel'),(19364,863219590016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.62,'hutongstore','cordyattheshops','cordy@homecall.co.uk','paul cordukes','club cottage,<br>main street','endmoor,Nr kendal','Cumbria','UNITED KINGDOM','LA8 0EU','01539567695','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-03 00:19:09',0,NULL,3,1,2,1,NULL,'cordyattheshops'),(19365,789424584002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','receptiondianne','reception@ascs.com.au','Dianne Hurley','Australian Satellite Services<br>49 Port Road','Thebarton','South Australia','AUSTRALIA','5031','0884439844','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 00:46:52',0,NULL,3,1,2,1,' ','receptiondianne'),(19366,789429632002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','picsou112009','labrecm@dr.cgocable.ca','Michele Labrecque','790, 111e Avenue','Drummondville','QC','CANADA','J2B 4L2','(819) 472-2244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 01:01:10',0,NULL,3,1,2,1,NULL,'picsou112009'),(19367,746793753001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','alpete6248','alpete@tds.net','Alfred Peterson','4203 Major Ave','Madison','WI','UNITED STATES','53716-1618','(608) 695-5311','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 01:34:18',0,NULL,3,1,17,0,NULL,'alpete6248'),(19368,750009358018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','ianmel01','meliantransport@bigpond.com','Melissa Hawes','30 The Boulevard','Allbany Creek','Queensland','AUSTRALIA','4035','0732646151','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-03 02:05:54',0,NULL,3,1,4,1,'YW867660162CN ','ianmel01'),(19369,8881320285967130,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',18.58,'aliexpress','1005054897','rebecca@beccadesign.se','Rebecca Martinsson	','Seglaregatan 19 EORI: SE8501184983','Gothemburg','Sweden','SWEDEN','41457','+0046 31 3607880',NULL,NULL,NULL,'2011-11-03 02:06:07',0,NULL,3,1,3,1,'RA117762208CN ',NULL),(19370,789458602002,120486836916,'Flash Softbox Diffuser for internal flash of DSLR',1,'AB3304',10.34,'hermeshine','alpete6248','alpete@tds.net','Alfred Peterson','4203 Major Ave','Madison','WI','UNITED STATES','53716-1618','(608) 695-5311','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 02:47:27',0,NULL,3,1,17,0,NULL,'alpete6248'),(19371,746813191001,110414374077,'55mm 55 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT019',4.1,'hermeshine','alpete6248','alpete@tds.net','Alfred Peterson','4203 Major Ave','Madison','WI','UNITED STATES','53716-1618','(608) 695-5311','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 02:47:28',0,NULL,3,1,1,1,NULL,'alpete6248\r方形滤镜接口环 77mm    1\r方镜普通托架（三槽）     2\rNG128 柔光罩      1\r方形滤镜接口环 55mm     1  '),(19372,750035927018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','kettikco','kettikmaps@gmail.com','Saravana Kumar','New no 6/Old no 4B, Rathna Nagar<br>Virugambakkam','Chennai','TN','INDIA','600092','9632277929','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 03:59:42',0,NULL,3,1,2,1,NULL,'kettikco'),(19373,806985847017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',58,'photographyacc','mbosmann','mbosmann@att.net','Michael Bosmann','11314 4th Ave W<br>Ste 206','Everett','WA','UNITED STATES','98204-6926','(425) 353-3010','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 05:07:09',0,NULL,3,1,17,0,NULL,'mbosmann'),(19374,750046322018,280680102028,'YongNuo Flash Battery Pack for 580EXII CP-E4 /6AA SF-17',1,'AB3313',42,'photographyacc','mbosmann','mbosmann@att.net','Michael Bosmann','11314 4th Ave W<br>Ste 206','Everett','WA','UNITED STATES','98204-6926','(425) 353-3010','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 05:07:10',0,NULL,3,1,4,1,'YW867660173CN ','mbosmann\r灯架  2m     1\r斜臂      1\r永诺 SF17- CANON     1'),(19375,746840014001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','pridery','maovato@gmail.com','mauricio valenzuela','cll 163a #14d-21 int 5 apt 304 balcones del palmar','bogota','','COLOMBIA','110131','+573105797032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 05:18:51',0,NULL,3,1,3,1,'RA117762097CN ','pridery'),(19376,789488757002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',1,'AKT009',95,'hermeshine','maesro110','maestro110@mail.ru','Roman Platok','60 Bilu str.','Rehovot','Shfela','ISRAEL','76442','972508493010','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 05:34:46',0,NULL,3,1,3,1,'RA117762018CN ','maesro110\r分两票发  \rRA117762106CN '),(19377,750052251018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','andy_gp1','andy@gock.net','Andy Gock','PO Box 371','Cardiff','New South Wales','AUSTRALIA','2285','0413710964','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-03 05:44:58',0,NULL,3,1,3,1,'RA117762035CN ','andy_gp1'),(19378,746843874001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','ralph.1957','ralph.barbieri@gmail.com','Ralph Barbieri','8 Pontiac Court','Athelstone','South Australia','AUSTRALIA','5076','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-03 05:48:34',0,NULL,3,1,17,0,NULL,'ralph.1957'),(19379,789491067002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','ralph.1957','ralph.barbieri@gmail.com','Ralph Barbieri','8 Pontiac Court','Athelstone','South Australia','AUSTRALIA','5076','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-03 05:50:48',0,NULL,3,1,3,1,'RA117762021CN ','ralph.1957\r永诺 SF18- NIKON SB900    1\r永诺 SF18- NIKON SB800     1'),(19380,746750863001,110757249196,'NEW PRO LED 312 Panel Camera&Camcorde​r Light 3200&5600',1,'AD1149',225,'hermeshine','jusuel','pegajosu@gmail.com','Josué Manzano Mayoral','C/Martinez Oviol Nº37 BjºC','Madrid','Madrid','SPAIN','28021','678524681','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 06:51:05',0,NULL,3,1,4,1,'YW867660184CN ','jusuel'),(19381,746859244001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','selcankurt85','selcanaydinli@gmail.com','SELCAN KURT','sevgi mah. 663 sok<br>18/101 gaziemir - aydinli eczanesi','izmir','izmir / Gaziemir / sevgi mah','TURKEY','35410','05356278598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 07:33:47',0,NULL,3,1,5,1,'CP238126615CN ','selcankurt85'),(19382,750069579018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','medrdo','tadeurdo@hotmail.com','Tadeu Reis de Oliveira','Rua Torres Homem 104 A<br>Boqueirao','Santos','São Paulo','BRAZIL','11025-020','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 07:35:55',0,NULL,3,1,5,1,'CP238126624CN ','medrdo\r申报$39'),(19383,789507494002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','selcankurt85','selcanaydinli@gmail.com','SELCAN KURT','sevgi mah. 663 sok<br>18/101 gaziemir - aydinli eczanesi','izmir','izmir / Gaziemir / sevgi mah','TURKEY','35410','05356278598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 07:38:48',0,NULL,3,1,3,1,'RA117762083CN ','selcankurt85'),(19384,789510404002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','lifeofme','shopgirl1884@hotmail.com','Gina Gustan','Elzenlaan 143','Groningen','','NETHERLANDS','9741 ND','0619580069','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 07:50:31',0,NULL,3,1,2,1,NULL,'lifeofme'),(19385,750076360018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',2,'AB3304',22,'photographyacc','shellkursk','shelline@mail.ru','Andrian Shelest (Андриан Шелест)','4kvartal, dom18, kv14 (4-й квартал, дом18, кв14)<br>Imeni Marshala Gukova (имени Маршала Жукова)','Kursk (Курск)','Kurskaya (Курская обл)','RUSSIAN FEDERATION','305502','+79202653837','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 08:20:01',0,NULL,3,1,2,1,NULL,'shellkursk'),(19386,750094111018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',2,'AKT025',49.8,'photographyacc','boris_mamlin','borismamlin@gmail.com','boris mamlin','Sovietskaya 7-13','Novosibirsk','Novosibirsk oblast','RUSSIAN FEDERATION','630007','79039010169','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 09:26:21',0,NULL,3,1,3,1,'RA117762110CN ','boris_mamlin\r两套'),(19387,789532442002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','subliminal.bliss','amyishness@gmail.com','amy shi','47a rodd st','birrong','New South Wales','AUSTRALIA','2143','0296451529','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 09:37:20',0,NULL,3,1,2,1,NULL,'subliminal.bliss\r新地址：\rCityU Student Residence\r701B, Hall 5 22 Cornwall Street\rKowloon Tong, Kowloon \rHong Kong.\r\r'),(19388,750111843018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','letusmix','info@mediamixer.co.uk','Mickey Lee','17A Streatley Road','London','London','UNITED KINGDOM','NW6 7LJ','07947324335','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 10:33:06',0,NULL,3,1,2,1,NULL,'letusmix'),(19389,863383610016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','charlescharleso','charlesolay@yahoo.com','charles olaoye','12, Steerscroft<br>Stockbridge Village','Liverpool','Merseyside','UNITED KINGDOM','L28 8AG','07979723129','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-03 10:48:49',0,NULL,3,1,4,1,'YW867660195CN ','charlescharleso\r英标'),(19390,789555769002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','machtus','maxrus@rambler.ru','Maxim Tarasov','Naberezhnaya 16a - 43','Chelyabinsk','','RUSSIAN FEDERATION','454084','+79222314865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 11:03:27',0,NULL,3,1,3,1,'RA117762239CN ','machtus'),(19391,789565851002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','yozef_hu','yozef@freemail.hu','Jozsef Szlobodnik','Arpad 80','Miskolc','BAZ','HUNGARY','3535','+36702872740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 11:41:38',0,NULL,3,1,2,1,NULL,'yozef_hu'),(19392,789576733002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 12:14:04',0,NULL,3,1,3,1,'RA117762225CN ','icreates_meenu'),(19393,789597845002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','cortomatese','josephmelin@gmail.com','Joseph Melin','99 rue du Faubourg du Temple<br>4 cour de Bretagne','Paris','FR','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 13:22:09',0,NULL,3,1,2,1,NULL,'cortomatese'),(19394,750167083018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','melodylion','philipp.christoph@gmail.com','Christoph Philipp','Wehntalerstrasse 229','Zürich','','SWITZERLAND','8057','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 13:41:10',0,NULL,3,1,3,1,'RA117762123CN ','melodylion\r\r\r'),(19395,881649972015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',11,'hutongstore','oldcrow*','daidelgas@libero.it','Orsi Alessio','via Carreggia, 117','Cardano al Campo','Varese','ITALY','21010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 15:30:38',0,NULL,3,1,17,0,NULL,'oldcrow*'),(19396,881649277015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','oldcrow*','daidelgas@libero.it','Orsi Alessio','via Carreggia, 117','Cardano al Campo','Varese','ITALY','21010','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-03 15:30:39',0,NULL,3,1,17,0,NULL,'oldcrow*'),(19397,746995886001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mageprokia','goh_hong_jie@hotmail.com','Jared Goh Hong Wei','Block 90 Tanglin Halt Road #18-332','default','','SINGAPORE','141090','98375735','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-03 15:31:41',0,NULL,3,1,11,1,NULL,'mageprokia'),(19398,750218194018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','kripstian','dominguez752@hotmail.com','Cristian Dominguez rein-loring','Alameda Urquijo 102 1º puerta 6','Bilbao','País Vasco','SPAIN','48013','663532984','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 15:53:09',0,NULL,3,1,4,1,'YW867660206CN ','kripstian'),(19399,881659693015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','oldcrow*','daidelgas@libero.it','Orsi Alessio','via Carreggia, 117','Cardano al Campo','Varese','ITALY','21010','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-03 15:30:37',0,NULL,3,1,4,1,'YW867660210CN ','oldcrow*\r反光伞    2\r2B柔     2'),(19400,747034479001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','oren1975','oren@cigarmag.co.il','Oren Kfir','4th Hasahlav','Raanana','Israel','ISRAEL','43394','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 17:02:34',0,NULL,3,1,3,1,'RA117762145CN ','oren1975'),(19401,806634198017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','aliyestudio','drunkyrabbit@yandex.ru','Aliya Pavroz','63, 6, Gorkogo','Aprelevka','Moscow region','RUSSIAN FEDERATION','143360','79264678414','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-03 18:17:19',0,NULL,3,1,2,1,' ','aliyestudio'),(19402,789719018002,120752153194,'Photo Studio Background Support Carrying Carry Bag',2,'AD1129',19.8,'hermeshine','sjadow','fvopstal@hotmail.com','Frank  van Opstal','Boris Pasternakerf 307','Dordrecht','','NETHERLANDS','3315BW','0627336393','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 18:21:36',0,NULL,3,1,2,1,NULL,'sjadow'),(19403,881763254015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','willywurzel','wilma.mccurrach@ntlworld.com','Wilma McCurrach','29A The Hyde','Stevenage','Hertfordshire','UNITED KINGDOM','SG2 9SD','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-03 18:35:43',0,NULL,3,1,4,1,'YW867660221CN ','willywurzel\r黑+白 '),(19404,789732354002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','eenfoto','eenevskie@gmail.com','Evgeniy Nevskiy','124 Octyabrskiy pr., App.103','Kirov','Kirovskaya oblast','RUSSIAN FEDERATION','610001','909-717-6383','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 18:49:13',0,NULL,3,1,5,1,'CP238126638CN ','eenfoto\r1.6*2.1灰布'),(19405,747091470001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','yason58','andron58@gmail.com','Andrey Ryzhenkov','Zarechnaya<br>8-65','Zarechnyi city','Penza region','RUSSIAN FEDERATION','442964','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-03 18:56:17',0,NULL,3,1,5,1,'CP238126641CN ','yason58'),(19406,747107280001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','tinylamb08','sarah.williamson2008@gmail.com','Sarah Williamson','2750 E Dry Creek Rd','Phoenix','AZ','UNITED STATES','85048','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-03 19:24:04',0,NULL,3,1,1,1,NULL,'tinylamb08'),(19407,881867181015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','samslow','sam_anslow@hotmail.com','Sam Anslow','119 sandon road','Stafford','Staffordshire','UNITED KINGDOM','ST16 3HF','01785258067','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-03 21:11:04',0,NULL,3,1,2,1,NULL,'samslow'),(19408,789825034002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','kmahnet','kruno.mahnet@gmail.com','Kruno Mahnet','Kozincev 1. odvojak 3','Zagreb','Croatia','CROATIA','10 090','00385915007337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 21:48:40',0,NULL,3,1,2,1,NULL,'kmahnet'),(19409,747199316001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','mooneyes1956','matejtresnak@gmail.com','Matej Tresnak','U Smaltovny 19','Praha','PRAHA','CZECH REPUBLIC','17000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-03 22:35:37',0,NULL,3,1,3,1,'RA117762256CN ','mooneyes1956'),(19410,863759583016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','oliveiraa1981','oliveiraa81@gmail.com','André Oliveira','Rua Monte da Mina, 4583','Leça do Balio','Matosinhos','PORTUGAL','4465-695','00351916258596','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-03 23:04:11',0,NULL,3,1,2,1,NULL,'oliveiraa1981'),(19411,747213545001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','mohan06','mohdhungana@yahoo.com','Mohan Dhungana','32 Merrick Crescent<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0430656677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-03 23:15:38',0,NULL,3,1,3,1,'RA117762185CN ','mohan06'),(19412,881957448015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','ashbur7','ashburley7@gmail.com','Ashley Burley','84Douglas Road','Hornchurch','Essex','UNITED KINGDOM','RM111AR','07961376174','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-04 00:17:05',0,NULL,3,1,3,1,'RA117762242CN ','ashbur7'),(19413,750470005018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',4.5,'photographyacc','pettitpoly','paula@pdbweb.com','Paula De Barros','PO BOX 3397','Parramatta','New South Wales','AUSTRALIA','2124','0415636769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 01:29:08',0,NULL,3,1,17,0,NULL,'pettitpoly'),(19414,807435107017,270758475500,'Photo Studio translucent white umbrella soft 85cm /33\" ',1,'AD1402',7.8,'photographyacc','pettitpoly','paula@pdbweb.com','Paula De Barros','PO BOX 3397','Parramatta','New South Wales','AUSTRALIA','2124','0415636769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 01:29:08',0,NULL,3,1,17,0,NULL,'pettitpoly'),(19415,807434522017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','pettitpoly','paula@pdbweb.com','Paula De Barros','PO BOX 3397','Parramatta','New South Wales','AUSTRALIA','2124','0415636769','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 01:29:09',0,NULL,3,1,2,1,NULL,'pettitpoly\rMini 红外  nikon    1\r柔光伞    1\r反光伞      1'),(19416,8881320373719238,111,'4个夹子',1,'',0,'hutongstore','supermattocks','mattocks75@hotmail.com','Brian Mattocks','Gröna gatan 14A','Sodertalje','Sthlm','SWEDEN','15132','',NULL,NULL,NULL,'2011-11-04 02:28:39',0,NULL,3,0,3,1,'RA117762137CN ',NULL),(19417,789915484002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','nueve2000','jjosserme@gmail.com','Jorge Josserme','San Lorenzo 3887','Olivos','Buenos Aires','ARGENTINA','B1636ERU','5491147040210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 02:38:54',0,NULL,3,1,2,1,NULL,'nueve2000\r欧标 '),(19418,8881320374546338,111,'天涯 渐变灰  2',2,'',0,'hermeshine','jayuser21','roqueodelfinee@gmail.com','Roque Jr Delfin','Powercon Switchgear Factory<br>Al qusais Industrial 1','Dubai','Dubai','UNITED ARAB EMIRATES','237891','(050)9431083',NULL,NULL,NULL,'2011-11-04 02:42:26',0,NULL,3,0,3,1,'RA117762199CN ','已入库 '),(19419,787219323002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','carlos3bkrew','amhi2003@aol.com','carlos david castañeda castro','Ezequiel Chavez 43A','Naucalpan','Estado de México','MEXICO','53100','!01)5553 - 730431','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 03:23:16',0,NULL,3,1,3,1,'RA117762171CN ','carlos3bkrew'),(19420,747304544001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.9,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:55:32',0,NULL,3,1,17,0,NULL,'franznawrath'),(19421,789952986002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:55:32',0,NULL,3,1,17,0,NULL,'franznawrath'),(19422,747304545001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:55:33',0,NULL,3,1,17,0,NULL,'franznawrath'),(19423,747304546001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',7.2,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:55:33',0,NULL,3,1,17,0,NULL,'franznawrath'),(19424,789952987002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 05:55:34',0,NULL,3,1,3,1,'RA117762432CN ','franznawrath\r绿叶 UV  77mm    1\r绿叶 UV  72mm      1\r6片装的滤镜袋    1\r绿叶 CPL  77mm    1\r绿叶 CPL 72mm     1'),(19425,807507964017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','rljones5','rljones5@bigpond.net.au','Reg Jones','9 ING PLACE<br>NORANDA','PERTH','Western Australia','AUSTRALIA','6062','0893752226','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 06:48:58',0,NULL,3,1,2,1,NULL,'rljones5'),(19426,882060032015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','chaddocks','thehaydocks@btinternet.com','Lee Haydock','4 Bluebell Way<br>Upton','Pontefract','West Yorkshire','UNITED KINGDOM','WF9 1NE','01977641990','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-04 06:57:32',0,NULL,3,1,4,1,'YW867660232CN ','chaddocks\r黑+白  '),(19427,881007383015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','mamsen_1','mamsen1@tele2.se','Ewa Janeman','Tunnbindargatan 25','Habo','sverige','SWEDEN','56631','0707297245','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-04 07:25:51',0,NULL,3,1,4,1,'YW867660243CN ','mamsen_1\r黑+白 '),(19428,807523827017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','anminhdang','jbandang@optusnet.com.au','An Dang','33 Haddrill St.','Bayswater','Western Australia','AUSTRALIA','6053','0420264057','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 08:05:11',0,NULL,3,1,2,1,NULL,'anminhdang\r澳标'),(19429,750555826018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','lukes-pins','sales@aviation-center.biz','Luke Hopkins','PO Box 255','Warburton','Victoria','AUSTRALIA','3799','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-04 08:43:11',0,NULL,3,1,2,1,NULL,'lukes-pins'),(19430,790018618002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','florinciulache2605','florinciulache@yahoo.com','ciulache florin','roma str. , no. 62.','Bucharest.','','ROMANIA','011775','0040723594244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 11:05:56',0,NULL,3,1,2,1,NULL,'florinciulache2605'),(19431,790022156002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','matt131084','matty131084@hotmail.com','Matthew  Murray','278<br>conadilly Street','Gunnedah','New South Wales','AUSTRALIA','2380','0267423944','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 11:19:44',0,NULL,3,1,2,1,NULL,'matt131084'),(19432,807577792017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','mr_compras','javier@thesmile.tv','Javier Lamaignere Weber','Llull 70-72<br>2 6','Barcelona','Cataluña','SPAIN','08005','667838742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-04 11:20:42',0,NULL,3,1,2,1,NULL,'mr_compras'),(19433,747375566001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','krammy10','ano_k1@yahoo.com','Mark Edward Melegrito','40 south eaton place<br>Belgravia','London','London','UNITED KINGDOM','SW1W9JJ','02077303128','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-04 11:23:31',0,NULL,3,1,3,1,'RA117762640CN\r ','krammy10'),(19434,747385302001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','giormicu','giorgio.micucci@alice.it','Giorgio Micucci','Via A. Manzoni, 22','Castelfidardo','AN','ITALY','60022','3388851129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 11:59:47',0,NULL,3,1,17,0,NULL,'giormicu'),(19435,790032187002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','giormicu','giorgio.micucci@alice.it','Giorgio Micucci','Via A. Manzoni, 22','Castelfidardo','AN','ITALY','60022','3388851129','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 11:59:47',0,NULL,3,1,2,1,NULL,'giormicu\rGGS 550D     1\r爵影红外 canon     1'),(19436,746972792001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','cadatad','cadadat@sbcglobal.net','courtney andrews','7134 Farley Ave','Saint Louis','MO','UNITED STATES','63121-2709','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 14:14:30',0,NULL,3,1,1,1,NULL,'cadatad'),(19437,807656139017,270758683063,'New Photo Studio Background Support Stand Carry Bag',2,'AD1129',19.6,'photographyacc','havalon09','havalon@telefonica.net','Alberto Blanco Arroyo','C/Pisuerga Nº41 1ºB','Arroyo de la Encomienda','Castilla y León','SPAIN','47195','676083700','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-04 14:58:55',0,NULL,3,1,2,1,NULL,'havalon09'),(19438,790107604002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','ben7154','freefeeling@gmail.com','Ben Baur','Kibbutz Ramat Hashofet<br>off','Kibbutz Ramat Hashofet','ISRAEL','ISRAEL','19238','97249898536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 15:31:49',0,NULL,3,1,17,0,NULL,'ben7154'),(19439,790107605002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','ben7154','freefeeling@gmail.com','Ben Baur','Kibbutz Ramat Hashofet<br>off','Kibbutz Ramat Hashofet','ISRAEL','ISRAEL','19238','97249898536','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 15:31:50',0,NULL,3,1,2,1,NULL,'ben7154\r4片装的滤镜袋    1\r双灯头       1'),(19440,747481756001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','bkr5000','bkr5000@yahoo.com','BRIAN RHODES','7607 Fawn Terrace Dr','HOUSTON','TX','UNITED STATES','77071-2716','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 16:28:00',0,NULL,3,1,1,1,NULL,'bkr5000'),(19441,790139384002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',103,'hermeshine','sonia892','richardneron@gmail.com','Richard Neron','3208 Clemence-Sabatte','Chambly','QC','CANADA','j3l 0b2','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-04 16:50:44',0,NULL,3,1,3,1,'RA117762582CN\r ','sonia892'),(19442,747494384001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','cdaz1693','kongorza@hotmail.com','CRISTIAN DÍAZ HIGUERUELA','C/ SIERRA DEL QUINTANAR 12 Bº IZDA','MADRID','Madrid','SPAIN','28018','687626585','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 16:57:24',0,NULL,3,1,4,1,'YW867660291CN ','cdaz1693'),(19443,750744454018,280676580312,'Male 58mm-58mm 58-58 mm Macro Reverse Ring / reversing',1,'AA1213',3.6,'photographyacc','ploum4','ploum2006@free.fr','HEDE Frédéric','Collège Molliet<br>rue du collège','BOEGE','Rhône-Alpes','FRANCE','74420','0450319960','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-04 17:45:33',0,NULL,3,1,17,0,NULL,'ploum4'),(19444,750751358018,280676580312,'Male 58mm-58mm 58-58 mm Macro Reverse Ring / reversing',1,'AA1213',3.6,'photographyacc','ploum4','ploum2006@free.fr','HEDE Frédéric','Collège Molliet<br>rue du collège','BOEGE','Rhône-Alpes','FRANCE','74420','0450319960','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-04 17:59:51',0,NULL,3,1,2,1,NULL,'ploum4\r58-58mm 双阳环     2'),(19445,864157982016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',2,'AE2202',31.18,'hutongstore','cantabria3154','angelantonio3154@hotmail.com','ANGEL ANTONIO FERNANDEZ GOMEZ','Avda de los Castros Nº 57-- 5º A','SANTANDER','Cantabria','SPAIN','39005','620 289921','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-04 18:16:08',0,NULL,3,1,4,1,'YW867660302CN ','cantabria3154\r欧标'),(19446,882356405015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-04 18:54:22',0,NULL,3,1,3,1,'RA117762517CN\r ','shayanshiraz'),(19447,747565585001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',4,'AC1301',24.96,'hermeshine','camaliboo','cveravidal@gmail.com','Camila Vera','Luz 2929 departamento 116','Santiago','Metropolitana','CHILE','7550035','569982291218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 19:25:34',0,NULL,3,1,17,0,NULL,'camaliboo'),(19448,790215287002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',2,'AC1302',15,'hermeshine','camaliboo','cveravidal@gmail.com','Camila Vera','Luz 2929 departamento 116','Santiago','Metropolitana','CHILE','7550035','569982291218','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 19:29:07',0,NULL,3,1,3,1,'RA117762548CN\r ','camaliboo\r中号内胆包 无字    4\r大号内胆包 无字   2'),(19449,747591370001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','sam34290','samirquarcia81@msn.com','samir quarcia','les 4 vents chemins des serres','montblanc','Languedoc-Rousillon','FRANCE','34290','0467390291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-04 20:14:32',0,NULL,3,1,4,1,'YW867660313CN ','sam34290'),(19450,882434051015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','annmarieludwig','annmariegrech@gmail.com','Ann Marie Grech','45, \"Casa Grech\"<br>Fort Street','Mosta','Malta','MALTA','MST 1854','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-04 20:58:31',0,NULL,3,1,2,1,NULL,'annmarieludwig'),(19451,790282065002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',2,'AO0014',15.8,'hermeshine','gianelly21','gianvillegas25@hotmail.com','Giancarlos Villegas','321 NW 61st Ave','Hollywood','FL','UNITED STATES','33024','(954) 934-7316','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-04 21:51:06',0,NULL,3,1,1,1,NULL,'gianelly21\r一共是俩个  110v 的  '),(19452,805946029017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.99,'photographyacc','art4kino','art4kino@paran.com','Kil Won Yu','421 Girard Blvd SE','Albuquerque','NM','UNITED STATES','87106-2233','(714) 469-2544','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-04 22:06:30',0,NULL,3,1,1,1,NULL,'art4kino'),(19453,790304878002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tcby7718','comax_one@hotmail.com','Ying Chen','1601 Acacia<br>Apt 2','ALHAMBRA','CA','UNITED STATES','91801-3113','(626) 688-3336','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-04 22:49:47',0,NULL,3,1,1,1,NULL,'tcby7718'),(19454,747677121001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','xavieryu','xyyufamily@gmail.com','Xavier Yu','8715 155 ST NW','Edmonton','AB','CANADA','T5R 1W1','(780) 484-5899','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-04 23:53:36',0,NULL,3,0,3,1,'RA117762809CN\r ','xavieryu\r3XL   已入库'),(19455,882529083015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','lisamorris*2010','lisamorris3@hotmail.co.uk','morris','24 wester inshes place','inverness','Highland','UNITED KINGDOM','iv2 5hz','07872499479','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-05 00:39:50',0,NULL,3,1,4,1,'YW867660324CN ','lisamorris*2010\r黑+白\r▲'),(19456,750929828018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','773freebeer','freebeer773@gmail.com','Nick Costa','9 Tullamarine park road','Tullamarine','Victoria','AUSTRALIA','3043','0383366423','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-05 01:14:23',0,NULL,3,1,3,1,'RA117762551CN\r ','773freebeer'),(19457,790365386002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','pal5958','albert55@hotmail.co.uk','PRINCE ALBERTpaso OBIRI','94 DEBDENHOUSE<br>GLOUCESTER ROAD','TOTTENHAM','London','UNITED KINGDOM','N17 6LF','02088019691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 02:27:38',0,NULL,3,1,4,1,'YW867660335CN ','pal5958\r英标\r▲'),(19458,747728616001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:18',0,NULL,3,1,17,0,NULL,'deliusbrazil-10'),(19459,747728617001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:19',0,NULL,3,1,17,0,NULL,'deliusbrazil-10'),(19460,747728618001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:19',0,NULL,3,1,17,0,NULL,'deliusbrazil-10'),(19461,790379113002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:20',0,NULL,3,1,17,0,NULL,'deliusbrazil-10'),(19462,790379114002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:21',0,NULL,3,1,17,0,NULL,'deliusbrazil-10'),(19463,790379115002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 03:31:21',0,NULL,3,1,3,1,'RA117762565CN ','deliusbrazil-10\r眼罩 450D/500D    1\r普通有线快门线C1    1\r大力夹云台     1\rc型大力夹     1\r反光伞110cm     1\r灯架包薄    1'),(19464,790409498002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tkemaly','nonstop_kb@mail.ru','Alexandr Koryvanov','Turgeneva str 6-20','Stupino','Moscow region','RUSSIAN FEDERATION','142800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 06:49:59',0,NULL,3,1,2,1,NULL,'tkemaly'),(19465,790419444002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',4,'AD1169',27.52,'hermeshine','biketrial100','peterkalina@gmail.com','Peter Kalina','44 Mabel Street<br>North Perth','Perth','Western Australia','AUSTRALIA','6006','610402922044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 08:10:44',0,NULL,3,1,2,1,NULL,'biketrial100'),(19466,790434631002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','spetsnaz80','aragornestel22@gmail.com','Ze\'ev Vladimir Levin','Haportzim<br>28','Holon','','ISRAEL','58235','+972(54)5292586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 08:58:42',0,NULL,3,1,3,1,'RA117762790CN ','spetsnaz80'),(19467,882670936015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','marc_49_fr','nucourt.2008@orange.fr','Gérard Marc','5, rue du puits','Nucourt','Île-de-France','FRANCE','95420','01.34.67.44.28','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 09:53:54',0,NULL,3,1,2,1,NULL,'marc_49_fr'),(19468,808055927017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','k57g09','tchitchoufou@hotmail.com','Eric LA BARBERA','route de Ferney 159 C','Grand-Saconnex','','SWITZERLAND','1218','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-05 10:33:17',0,NULL,3,1,3,1,'RA117762715CN\r ','k57g09'),(19469,747814906001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','moonlady007','wendyhutcheson@blueyonder.co.uk','Wendy Hutcheson','19 Park Avenue','Gillingham','Kent','UNITED KINGDOM','ME74AS','01634572229','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 10:46:23',0,NULL,3,1,3,1,'RA117762596CN\r ','moonlady007'),(19470,584475255003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','jvf1958','jesusvillaplana@gmail.com','JESUS VILLAPLANA FERRER','C/ PARANIMF 1','Grao de Gandia','Comunidad Valenciana','SPAIN','46730','676366028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 12:01:02',0,NULL,3,1,4,1,'YW867660346CN ','jvf1958\r▲'),(19471,790517734002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','piglet863','piglet8863@cox.net','Nancy Surgenor','4671 W Park Dr','Fairview Park','OH','UNITED STATES','44126-2347','(440) 333-9532','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 13:23:39',0,NULL,3,1,3,1,'RA117762786CN ','piglet863'),(19472,790519600002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','khanduterio','mario.revuelta.benaque@gmail.com','Mario Revuelta Benaque','Avd Juan Carlos I, 84<br>Planta 3, Oficina 23 (Fontventa S.L.)','Leganes','Madrid','SPAIN','28916','616228598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 13:29:01',0,NULL,3,1,4,1,'YW867660276CN ','khanduterio\r▲'),(19473,864644489016,260856847288,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',25,'hutongstore','maskare','teemu.p.saarinen@gmail.com','Teemu Saarinen','Lahdensivuntie 31<br>A 11','Hämeenlinna','','FINLAND','13100','+358415076144','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-05 15:42:58',0,NULL,3,1,3,1,'RA117762653CN\r ','maskare'),(19474,790585880002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','edkolb','edkolb@comcast.net','Wesley Kolb','3301 Topaz Rd','Normal','IL','UNITED STATES','61761-9478','(309) 454-8170','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-05 16:03:49',0,NULL,3,1,1,1,NULL,'edkolb'),(19475,747951549001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-05 16:41:18',0,NULL,3,1,3,1,'RA117762675CN\r ','krisvisual'),(19476,751212235018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.99,'photographyacc','ruben3320','miidiadevices@gmail.com','Ruben Lah','11308 Soldier Creek Ln','south jordan','UT','UNITED STATES','84095','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-05 17:16:49',0,NULL,3,1,3,1,'RA117762579CN\r ','ruben3320'),(19477,747994170001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT057',130,'hermeshine','ryste3d','contact@ryste3d.com','Staale Pedersen','Indrehovdevejen 56','Hovdebygda','non','NORWAY','6160','70060002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 17:58:40',0,NULL,3,1,17,0,NULL,'ryste3d'),(19478,747988631001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','ryste3d','contact@ryste3d.com','Staale Pedersen','Indrehovdevejen 56','Hovdebygda','non','NORWAY','6160','70060002','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 17:58:41',0,NULL,3,1,5,1,'CP238126655CN ','ryste3d\r欧标  除了c里面的再发\r800w红头灯      1\r800w  220v 灯泡    1\r2.8m 弹簧灯架     1'),(19479,790654156002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','cincam67','cinziacamela@libero.it','Cinzia Camela','Bezzecca, 31','San Benedetto del Tronto','AP','ITALY','63039','349-0651651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 18:20:19',0,NULL,3,1,3,1,'RA117762741CN ','cincam67\rboom arm   $15'),(19480,790701298002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','mor133','morshlomi1@gmail.com','shlomi mor','118 uziel street','ramat gan','','ISRAEL','52302','972-54-6820055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 19:54:06',0,NULL,3,1,2,1,NULL,'mor133'),(19481,790727733002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',16.9,'hermeshine','marioheusser','mario.heusser@calama.tv','Mario Heusser Alarcón','Avda. Tocopilla 2786','Calama','Región de Antofagasta','CHILE','1390000','78450032','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 20:49:41',0,NULL,3,1,2,1,NULL,'marioheusser'),(19482,748085587001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','mrkpahl','mrkpahl@yahoo.ca','Kevin Pahl','423 Tyee Dr<br># 499','Point Roberts','WA','UNITED STATES','98281-8901','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-05 21:07:50',0,NULL,3,1,1,1,NULL,'mrkpahl'),(19483,751347158018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','spookyer','strider@bigpond.net.au','Brett Parnell','46 Enbrook St Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-05 21:50:35',0,NULL,3,1,3,1,'RA117762503CN\r ','spookyer'),(19484,864876639016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','walidsbx','walidb1234@gmail.com','Walid Butt','34 Horwood House<br>19 Paveley Street','London','London','UNITED KINGDOM','NW8 8TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-05 22:14:35',0,NULL,3,1,2,1,NULL,'walidsbx'),(19485,790752700002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','enriqueprofefoto','enrimoralesfd@gmail.com','Enrique Morales Fernández','C. Cerro Viejo n 16, 3 B','Mairena del Aljarafe, Sevilla','Andalucía Ceuta y Melilla','SPAIN','41927','639231514','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-05 23:09:15',0,NULL,3,1,2,1,' ','enriqueprofefoto'),(19486,808428996017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',2,'AD1190',32,'photographyacc','2010blackvelvet','fslappe2002@hotmail.com','Francis Lappe','PO Box 543','Banora Point','New South Wales','AUSTRALIA','2486','0755248836','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 00:11:18',0,NULL,3,1,17,0,NULL,'2010blackvelvet'),(19487,751398703018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','2010blackvelvet','fslappe2002@hotmail.com','Francis Lappe','PO Box 543','Banora Point','New South Wales','AUSTRALIA','2486','0755248836','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 00:11:18',0,NULL,3,1,3,1,'RA117762605CN\r ','2010blackvelvet\r帽子 nikon     2\r摄影背心（河北，厚）nikon xl    1'),(19488,790808690002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','murdoch13','rebeccamurdoch@hotmail.com','Rebecca Murdoch','35B Lakeview Dr','Trout Lake','NT','CANADA','X0E1Z0','(867) 206-2977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 00:25:33',0,NULL,3,1,3,1,'RA184573604CN ','murdoch13\r灯泡是110v 的  放欧转美标'),(19489,883142185015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','palma_alexander','palma_alexander@hotmail.com','Vincent Palma','Shugakuinn Tsuboecho14 Sejurusaginomori 201<br>Sakyoku','Kyoto','Kyoto','JAPAN','606-8075','08044228919','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-06 01:37:38',0,NULL,3,1,17,0,NULL,'palma_alexander'),(19490,748192461001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','alejandroriverosw','ariverosw@ufl.edu','Alejandro Riveros Walker','368 Maguire Vlg<br>Apt 5','Gainesville','FL','UNITED STATES','32603-2011','(352) 846-5390','NoPaymentFailure','CheckoutComplete','Other','2011-11-06 02:30:07',0,NULL,3,1,1,1,NULL,'alejandroriverosw'),(19491,751440524018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','gear_junkie21','ajtruloff@yahoo.com.au','Andrew Truloff','8 Vivian Hancock Drive','North Booval','Queensland','AUSTRALIA','4304','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 02:44:54',0,NULL,3,1,17,0,NULL,'gear_junkie21'),(19492,751439625018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','gear_junkie21','ajtruloff@yahoo.com.au','Andrew Truloff','8 Vivian Hancock Drive','North Booval','Queensland','AUSTRALIA','4304','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 02:44:55',0,NULL,3,1,2,1,NULL,'gear_junkie21\r6片装的滤镜袋    2'),(19493,748219104001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','don606','donabraham.ebay@gmail.com','Don Abraham','Suite #201<br>9768 - 170 Street NW','Edmonton','AB','CANADA','T5T 5L4','(780) 266-4404','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 04:40:05',0,NULL,3,1,2,1,NULL,'don606'),(19494,751464914018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','hannahds1980','hdalt4@eq.edu.au','Hannah Dalton-Strong','11 Coonan St','Toowoomba','Queensland','AUSTRALIA','4350','0746396474','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-06 04:54:57',0,NULL,3,1,4,1,'YW867660280CN ','hannahds1980\r▲'),(19495,748228922001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','zenn65','zenn@exemail.com.au','Zoran Nekic','3 Goodenia Place','Hillside','Victoria','AUSTRALIA','3037','0394492242','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 05:41:50',0,NULL,3,1,2,1,NULL,'zenn65'),(19496,748253323001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','kevintahiti12','kevintahitimail@gmail.com','Kevin KWANG','BP: 3088 TAHITI','PAPEETE','DOM-TOM','FRENCH POLYNESIA','98714','+689293422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 08:02:43',0,NULL,5,1,18,0,NULL,'kevintahiti12'),(19497,790928605002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',245,'hermeshine','kevintahiti12','kevintahitimail@gmail.com','Kevin KWANG','BP: 3088 TAHITI','PAPEETE','DOM-TOM','FRENCH POLYNESIA','98714','+689293422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 09:18:21',0,NULL,5,1,18,0,NULL,'kevintahiti12\r除了c 里面的再发\r牛津布大包   1\r要240v 的灯泡'),(19498,751535782018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','edserio','rvedser@gmail.com','Ross Edser','15a Kate Street','Toowoomba','Queensland','AUSTRALIA','4350','0746325159','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 09:54:33',0,NULL,3,1,3,1,'RA117762415CN\r ','edserio'),(19499,865104927016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','deniswdion','dwdion@gmail.com','Denis Dion','Mellingerstrasse 156','Baden','','SWITZERLAND','5400','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-06 10:12:27',0,NULL,3,1,2,1,NULL,'deniswdion\r算算运费'),(19500,790949804002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 10:13:30',0,NULL,3,1,17,0,NULL,'emuexport81'),(19501,790948581002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 10:13:31',0,NULL,3,1,3,1,'RA117762684CN\r ','emuexport81\r沙袋（普通）     1\r反光板 100*150 40*60 5合1   1'),(19502,790947648002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 10:13:31',0,NULL,3,1,4,1,'YW867660254CN ','emuexport81\r▲'),(19503,748304842001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','slavik_by','slav701@gmail.com','VIACHASLAU RUSETSKI','Y.Mavra str., 18-102','Minsk','by','BELARUS','220092','+375296642264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 10:28:26',0,NULL,3,1,2,1,NULL,'slavik_by'),(19504,751563191018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','steffanscy','krzysztoff_stefanski@wp.pl','Krzysztof Stefanski - Head Chef','Morehampton Road<br>The Royal Hospital Donnybrook','Dublin','Dublin','IRELAND','4','0851200872','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 10:56:58',0,NULL,3,1,4,1,'YW867660265CN ','steffanscy\r▲'),(19505,790974230002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',2,'AD1128',45.8,'hermeshine','tugezu','tukezu@gmail.com','Tuomas Hämäläinen','Vanha Tapanilantie 62 C26','Helsinki','Uusimaa','FINLAND','00730','+358407030125','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 11:07:51',0,NULL,3,1,17,0,NULL,'tugezu'),(19506,748322299001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','tugezu','tukezu@gmail.com','Tuomas Hämäläinen','Vanha Tapanilantie 62 C26','Helsinki','Uusimaa','FINLAND','00730','+358407030125','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 11:07:51',0,NULL,3,1,4,1,'YW868052486CN','tugezu\r灯架包厚     2\r灯架  2m      2  ▲\r上次的货被燕文搞错了YW867660350CN，再发一次\r之前燕文的单号   '),(19507,751597568018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','johanng8255','johann.datacare@gmail.com','Johann Gerber (0825531110)','PO Box 36351<br>Menlopark','Pretoria','Gauteng','SOUTH AFRICA','0102','+27 (082) 553 1110','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 12:15:58',0,NULL,3,1,3,1,'RA117762636CN ','johanng8255'),(19508,748223550001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','saltjunksarah','bauple58@gmail.com','Mark Clayton','Faculty of Arts (Q310), University of Southern QLD<br>West Street','Toowoomba','Queensland','AUSTRALIA','4350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 12:42:26',0,NULL,3,1,2,1,NULL,'saltjunksarah'),(19509,747708653001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','derekjames2011','derekmcgrath2011@gmail.com','derek james mcgrath','17 comeragh park lismore heights','waterford','Waterford','IRELAND','','0862692324','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 13:27:13',0,NULL,3,1,2,1,NULL,'derekjames2011'),(19510,751647580018,280719730281,'New Flash Umbrella Holder Mount aluminum metal N',2,'AD1167',32,'photographyacc','demeterlaquesis','javiermazzeo2002@yahoo.com.ar','Javier Mazzeo','Carrer d\'Angel Guimerà  Nº 21    1º 2ª','Banyoles','Cataluña','SPAIN','17820','661994147','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 13:51:47',0,NULL,3,1,3,1,'RA117762622CN\r ','demeterlaquesis'),(19511,865234997016,260660051871,'New 3 pcs filters for Cokin System P Series',1,'AKT062',13.8,'hutongstore','reading65','home@barrellclan.wanadoo.co.uk','Roger Barrell','1 Spanbies Road Stratford St Mary','Colchester','Essex','UNITED KINGDOM','CO7 6YH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 13:57:47',0,NULL,3,1,2,1,' ','reading65'),(19512,791054794002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jeremyk2001','jeremykuzub@gmail.com','jeremy kuzub','811-124 springfield rd','ottawa','ON','CANADA','k1m2c8','(613) 797-3447','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:01:10',0,NULL,3,1,3,1,'RA117762755CN ','jeremyk2001'),(19513,791076158002,120343540553,'YONGNUO 16CH WIRELESS REMOTE CORD FOR SONY RM-S1AM',1,'AA3214',18,'hermeshine','charted48','charted48@gmail.com','Ted Volf','35 Dartmoor St','Sugar Land','TX','UNITED STATES','77479-2904','(281) 980-4443','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 14:41:19',0,NULL,3,1,1,1,NULL,'charted48'),(19514,791080203002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','vilarod10','vilarod@hotmail.com','Alfred Rodriguez Vila','Provença 111-113 Aticº1 esc.Izq','Barcelona','Cataluña','SPAIN','08029','660166971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 14:45:58',0,NULL,3,1,3,1,'RA117762463CN\r ','vilarod10'),(19515,791086423002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','freimanofer','oferfreiman@gmail.com','ofer freiman','Kibbuz kfar sold','rural delivery Galil Elyon','israel','ISRAEL','04','+972-54-7531077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 15:06:37',0,NULL,3,1,3,1,'RA117762477CN\r ','freimanofer'),(19516,748452486001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','gapjohn','gapjohn@comcast.net','John Gateley','6251 NE 184th St','Kenmore','WA','UNITED STATES','98028','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-06 15:28:22',0,NULL,3,1,1,1,NULL,'gapjohn'),(19517,751703304018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','123-v-meyer','vincent.normandie@hotmail.com','NORMANDIE MEYER','11 Poonda street<br>Newman','WA','Western Australia','AUSTRALIA','6753','0891778041','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 15:35:50',0,NULL,3,1,2,1,NULL,'123-v-meyer'),(19518,791135806002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','aniki.0098','anmalinova@yandex.ru','Anna Malinova','Erevanskaya str. 6-3-77','Moscow','Moscow','RUSSIAN FEDERATION','115304','+79160940098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 16:12:34',0,NULL,3,1,2,1,NULL,'aniki.0098'),(19519,748517753001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','orchidjewels','poseidon1203@hotmail.com','Sang Min Bae','SHIS Qi 26 Cj 8 Cs 12<br>LAGO SUL','Brasilia','DF','BRAZIL','71670-080','(619) 966-0312','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 17:05:22',0,NULL,3,1,3,1,'RA117762485CN\r ','orchidjewels'),(19520,751781600018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','deus.ua','deus.ukraine@gmail.com','Sergiy Savchenko','6055 Floyd pl','Milford','OH','UNITED STATES','45150-2209','(513) 410-4303','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 17:12:09',0,NULL,3,1,1,1,NULL,'deus.ua'),(19521,748537387001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','rmcaudio1','rmartinezc@udd.cl','Rodrigo Martínez','ibsen 6445 departamento 24<br>comuna: Las Condes','Santiago','Región metropolitana','CHILE','7550000','56 99170124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 17:21:06',0,NULL,3,1,5,1,'CP238126669CN ','rmcaudio1\r欧标'),(19522,791186177002,120601699308,'JueYing Lambency Flash Diffuser 4 Nikon SB600 SB800 P1',1,'AB3306',22,'hermeshine','arulvani','arulvani22@yahoo.co.uk','narayanan rubananthan','flat 7 capri house<br>4 darndale close','wolthamstow','London','UNITED KINGDOM','E17 5LH','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 17:29:26',0,NULL,3,1,3,1,'RA117762534CN\r ','arulvani'),(19523,791222550002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','venezuela_magazines','rockenfantasia@gmail.com','José Fernández','Apartado Postal 117','Valencia','Carabobo','VENEZUELA','2001','04144384932','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 17:55:44',0,NULL,3,1,5,1,'CP238126672CN ','venezuela_magazines'),(19524,748587676001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','k-rose05','pinkrebel1@hotmail.com','Kristina Rose','5, The Green<br>Brockley','Bury St Edmunds','Suffolk','UNITED KINGDOM','IP29 4AN','07879330850','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:12:57',0,NULL,3,0,2,1,NULL,'k-rose05\r黑色'),(19525,791248126002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','752br','bertrand.rigobert@hotmail.fr','bertrand rigobert','443 route d etienville','leubringhen','Nord-Pas-de-Calais','FRANCE','62250','0321337694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:18:28',0,NULL,3,1,3,1,'RA117762619CN\r ','752br'),(19526,808914001017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','richardw4403','richard-white@fsmail.net','Richard White','16 Poachers Hide, Gosberton','Spalding','Lincolnshire','UNITED KINGDOM','PE11 4PF','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 18:28:48',0,NULL,3,1,2,1,NULL,'richardw4403'),(19527,791277114002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',2,'AE3102',15.78,'hermeshine','ashtonfoto','peter@ashtonlamont.co.uk','Peter Riding','7 Chervil Way, Burghfield Common','Reading','Berkshire','UNITED KINGDOM','RG73YX','01189834240','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 18:46:39',0,NULL,3,1,2,1,NULL,'ashtonfoto'),(19528,751892870018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','ryanadams15','ryankadams@yahoo.com','Ryan Adams','4809 Fawn Run Dr','Yukon','OK','UNITED STATES','73099','(405) 570-7873','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-06 19:04:27',0,NULL,3,1,1,1,NULL,'ryanadams15'),(19529,883806473015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','bethany10_1','julieann.falco@btinternet.com','julie ann falco','20 barleyfield<br>langtoft','peterborough','Lincolnshire','UNITED KINGDOM','pe6 9rf','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-06 20:19:36',0,NULL,3,1,4,1,'YW867660361CN ','bethany10_1\r白色背景布  \r▲'),(19530,748727487001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','gerryarne123','gerryab@gmail.com','Gerry Arne Birkeland','Glasskaraasen 16','Bergen','Oevre Ervik','NORWAY','N-5106','+47 90868753','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-06 20:36:19',0,NULL,3,1,4,1,'YW867660372CN ','gerryarne123\r▲'),(19531,883873847015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','jm782','jeff.mapps@virgin.net','Jeff Mapps','2 Parc Bryn, Pontllanfraith','Blackwood','Caerphilly','UNITED KINGDOM','NP122RA','07812100782','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 21:30:50',0,NULL,3,1,2,1,NULL,'jm782'),(19532,748790284001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','f1efq','f1efq@free.fr','DOCTISSIMO / Olivier SANTIANO','9 place Marie-Jeanne Bassot','Levallois-Perret','Ile-de-France','FRANCE','92300','+33621052981','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 22:21:26',0,NULL,3,1,3,1,'RA117762707CN ','f1efq'),(19533,883925558015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','mintybhoys','davemurray16@hotmail.com','David Murray','11 shoveller Drive<br>Apley','Telford','Shropshire','UNITED KINGDOM','TF1 6GQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 22:48:54',0,NULL,3,1,3,1,'RA117762698CN\r ','mintybhoys'),(19534,791462789002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',22.99,'hermeshine','h20melon-80','neil@koonawarrabaysc.org.au','Neil Waterman','Pretty Swish<br>Shop 2, 223 Gipps Road','Keiraville','New South Wales','AUSTRALIA','2500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 22:52:03',0,NULL,3,1,17,0,NULL,'h20melon-80'),(19535,748803863001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','h20melon-80','neil@koonawarrabaysc.org.au','Neil Waterman','Pretty Swish<br>Shop 2, 223 Gipps Road','Keiraville','New South Wales','AUSTRALIA','2500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 22:52:03',0,NULL,3,1,2,1,NULL,'h20melon-80\r圆形柔光棚 50cm    1\r肥皂盒 柔光罩  430EX      1'),(19536,748825409001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','kulcsar.balazs','kulcsarb@gmail.com','Kulcsár Balázs','Farkas-erdő utca 23. 8.em 46.','Budapest','PEST','HUNGARY','H-1046','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-06 23:34:15',0,NULL,3,1,2,1,NULL,'kulcsar.balazs'),(19537,809164422017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.88,'photographyacc','inspirationforthesoul','info@lovethismoment.com','Lisa Frost','24 Natan Rd','Mudgeeraba','Queensland','AUSTRALIA','4213','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-06 23:49:00',0,NULL,3,1,2,1,NULL,'inspirationforthesoul'),(19538,883960399015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','mathinik_26','adrianduria@yahoo.com','adrian duria','flat 6 tressillian house, dukes ride','crowthorne','Berkshire','UNITED KINGDOM','rg45 6ds','01344750848','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-06 23:55:55',0,NULL,3,1,3,1,'RA117762738CN ','mathinik_26'),(19539,752103783018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','gwmalan','gmalan@gmconsult.com.au','Gerhard Malan','PO Box 820','Newport Beach','New South Wales','AUSTRALIA','2106','0299860438','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-07 00:23:15',0,NULL,3,1,3,1,'RA117762667CN\r ','gwmalan'),(19540,791515367002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','perezfreytes','miguel.ruiznazario@gmail.com','Miguel Ruiz','263 Calle M Perez Freytes','Arecibo','PR','UNITED STATES','00612-4647','(787) 878-1995','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-07 00:52:06',0,NULL,3,1,1,1,NULL,'perezfreytes'),(19541,748858543001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','ironreaversoulstealer','kyothecat@yahoo.com','Steve Nakatani','3801 Mission Trace Blvd<br>Apt E5','Tallahassee','FL','UNITED STATES','32303-2855','(850) 980-5339','NoPaymentFailure','CheckoutComplete','Other','2011-11-07 01:03:57',0,NULL,3,1,1,1,NULL,'ironreaversoulstealer'),(19542,8881320629078117,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',18.58,'aliexpress','1005103237','ni-elena@mail.ru','Elena Nikolaeva	','Naberegnay Privolzhskogo Zatona 15/2 apartment 16','Astrakhan','Russian','RUSSIAN FEDERATION	','414024','89053609932',NULL,NULL,NULL,'2011-11-07 01:24:38',0,NULL,3,1,17,0,NULL,''),(19543,8881320629218220,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft',1,'AO0005',16.99,'aliexpress','1005103237','ni-elena@mail.ru','Elena Nikolaeva	','Naberegnay Privolzhskogo Zatona 15/2 apartment 16','Astrakhan','Russian','RUSSIAN FEDERATION	','414024','89053609932',NULL,NULL,NULL,'2011-11-07 01:26:58',0,NULL,3,1,3,1,'RA184573581CN ','款清再发  \r（订单号应该是1005103238）\r圆形柔光棚 60cm * 1\r背景布 1.6x3.0m * 1 （白色）\r'),(19544,791548196002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',3,'AKT055',189,'hermeshine','ktriscrew','alzota@hotmail.com','emile gbaka','27 rue de marseille','EPINAY SUR SEINE','Ile-de-France','FRANCE','93800','0664352329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 02:17:28',0,NULL,3,1,4,1,'YW867660383CN ','ktriscrew\r本身应该就是欧标\r▲'),(19545,748889700001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','prof.valter','valter.patrial@gmail.com','Valter Patrial Jr','Rua Antônio Bicudo Nº 229 Apto 22T Bloco 6','Campo Grande','Mato Grosso do Sul','BRAZIL','79041-320','155-067-3025-3936','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 02:30:55',0,NULL,3,1,2,1,NULL,'prof.valter'),(19546,752172222018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','girl_nextdoor','jamiec@alumni.yorku.ca','Jamie Cartujano','338 Brookside Road','Richmond Hill','ON','CANADA','L4C 0G6','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 04:01:19',0,NULL,3,1,2,1,NULL,'girl_nextdoor'),(19547,748917978001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','vincentlap09','vincentlap09@hotmail.com','vincent lapalme','3720, place la fayette est','boisbriand','QC','CANADA','j7h1n6','(450) 821-0922','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 04:19:48',0,NULL,3,1,2,1,NULL,'vincentlap09'),(19548,884078655015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','palma_alexander','palma_alexander@hotmail.com','Vincent Palma','Shugakuinn Tsuboecho14 Sejurusaginomori 201<br>Sakyoku','Kyoto','Kyoto','JAPAN','606-8075','08044228919','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 05:29:30',0,NULL,3,1,6,1,'EE645650078CN ','palma_alexander\r2B柔    1\r2云柔     1'),(19549,8881320645098742,111,'绿色薄款 佳能背心 XXXL',1,'',0,'hermeshine','tubio06fernando','tubio06@yahoo.com.ar','fernando tubio','davila, 1192<br>1192','ciudad autonoma de buenos aires','buenos aires','ARGENTINA','1406','540111569907336',NULL,NULL,NULL,'2011-11-07 05:51:38',0,NULL,3,0,3,1,'RA184573564CN ','发 黑色 薄款 canon XXXL \r已入库'),(19550,8881320647009070,111,'77mm 镜头盖 nikon',1,'AA1309',0,'hutongstore','deenreeb','scalaapex@aol.com','thomas s scala','102 Sweet Tart Ln','Apex','NC','UNITED STATES','27502-1396','',NULL,NULL,NULL,'2011-11-07 06:23:29',0,NULL,3,1,1,1,NULL,' 11-07改一个  \rLK106612352CN '),(19551,8881320647854375,111,'灯架下面的配件',1,'',0,'hermeshine','nativeideas','masterwaki@hotmail.com','Robert Cooper','14 damson place<br>bucklands beach','Auckland','Akl','NEW ZEALAND','2012','2645924',NULL,NULL,NULL,'2011-11-07 06:37:34',0,NULL,3,1,3,1,'RA184573343CN ',NULL),(19552,752203885018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','griffin2332','ebgriff@q.com','Eugene Griffin','10420 N Thornydale Rd','Tucson','AZ','UNITED STATES','85742-9644','(520) 579-3000','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 06:57:07',0,NULL,3,1,1,1,NULL,'griffin2332'),(19553,865914321016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','bjreed2010','bjreed100@gmail.com','Brian reed','34 cornwall st<br>grangetown','cardiff','Cardiff','UNITED KINGDOM','cf116sq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 07:39:35',0,NULL,3,1,2,1,NULL,'bjreed2010'),(19554,748959498001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','styleworkprod','spary@seanpary.com','Sean Pary','36 Halpin Street','Brunswick West','Victoria','AUSTRALIA','3055','0425754088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:39:01',0,NULL,3,1,3,1,'RA184573445CN ','styleworkprod'),(19555,748961522001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','khanduterio','mario.revuelta.benaque@gmail.com','Mario Revuelta Benaque','Avd Juan Carlos I, 84<br>Planta 3, Oficina 23 (Fontventa S.L.)','Leganes','Madrid','SPAIN','28916','616228598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:42:32',0,NULL,3,1,2,1,NULL,'khanduterio'),(19556,748964777001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','stesmith01','smith.stephengeorge@gmail.com','steve smith','59 Cardinal Avenue<br>Beecroft','Sydney','New South Wales','AUSTRALIA','2119','6142566882461425668824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:47:48',0,NULL,3,1,3,1,'RA184573476CN ','stesmith01'),(19557,791632366002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','yaronharel','yaron@technion.ac.il','Yaron Harel','p.o.box 574','Ramat Yishai','','ISRAEL','30095','972 52 8977929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:54:42',0,NULL,3,1,2,1,NULL,'yaronharel'),(19558,748965986001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','asgar_d','5845@bk.ru','Anton Alexandrov','Bol\'shaja akademicheskaja  39b, kv. 53','Moscow','Moscow','RUSSIAN FEDERATION','125008','79250625845','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 08:55:35',0,NULL,3,1,2,1,NULL,'asgar_d'),(19559,752231487018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','myeversale','ryosaven@hotmail.com','George  Mathew','15 Gladman Way','Karrinyup','Western Australia','AUSTRALIA','6018','0610415346629','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-07 09:07:07',0,NULL,3,1,4,1,'YW867660394CN ','myeversale\r▲'),(19560,748981282001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',39.8,'hermeshine','ktriscrew','alzota@hotmail.com','emile gbaka','27 rue de marseille','EPINAY SUR SEINE','Ile-de-France','FRANCE','93800','0664352329','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 09:56:50',0,NULL,3,1,2,1,NULL,'ktriscrew'),(19561,884131638015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','stanketto468','darses@gmail.com','Giovanni Sessa','Via Centenate 35','Varese','VA','ITALY','21100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 09:57:13',0,NULL,3,1,3,1,'RA184573374CN ','stanketto468\rLight Bulb   $10'),(19562,865945188016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','mikey2k02','mikey@paragon.freeserve.co.uk','Michael Evans Pinpoint Marketing','St Michaels House<br>Hale Road','Widnes','Cheshire','UNITED KINGDOM','WA8 8XL','07712429871','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 09:30:45',0,NULL,3,1,3,1,'RA184573547CN ','mikey2k02'),(19563,865960867016,260660056626,'Adjustable Padded shoulder Neck Strap for D90 D300 D700',1,'AB1403',2.99,'hutongstore','djtomosullivan','djtomos07@yahoo.co.uk','Thomas O\'Sullivan','9 Huyton Hey Road, Huyton','Liverpool','Merseyside','UNITED KINGDOM','L36 5SF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 10:17:09',0,NULL,3,1,2,1,NULL,'djtomosullivan\r发白色字的 '),(19564,752252201018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','ajhaynes-2009','manna94@bigpond.com','Amanda Haynes-Meyer','8 Jacob Ct','Berwick','Victoria','AUSTRALIA','3806','0397026382','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-07 10:21:27',0,NULL,3,0,2,1,NULL,'ajhaynes-2009\r绿色'),(19565,748995793001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','eshop_masenka','miroslavhorak.nb@seznam.cz','Lucie Horakova','Jiriho Wolkera 1888','Nymburk','ČR','CZECH REPUBLIC','28802','+420608140139','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 10:51:06',0,NULL,3,0,2,1,NULL,'eshop_masenka\r黑色\r\r'),(19566,748958858001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','buckyballs_com_au','drbuckyballs@gmail.com','Thomas Zulliger','c/o UG Manufacturing<br>27 Baines Crt','Torquay','Victoria','AUSTRALIA','3228','0413000055','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 10:55:09',0,NULL,3,1,3,1,'RA184573459CN ','buckyballs_com_au'),(19567,791672872002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','semey1979','dsepbosynov@gmail.com','Dulat Sepbosynov','15 A Internacionalnaya Street<br>«Alliance Bank» JSC','Semey','','KAZAKHSTAN','071400','+77015200079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 11:28:53',0,NULL,3,1,2,1,NULL,'semey1979'),(19568,791678302002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','jomargo1','joaquinhuelva@hotmail.com','Joaquín Martínez Gómez','c/ Moncayo 8, 2º dcha','Huelva','Huelva','SPAIN','21006','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-07 11:43:39',0,NULL,3,1,3,1,'RA184573312CN ','jomargo1'),(19569,791684969002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pinpinivaiva','pavlin_dorovski@abv.bg','IVELINA DONEVA','c. Borell 6, 1-1','MOLLET DEL VALLES','Cataluña','SPAIN','08100','608621031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 12:10:55',0,NULL,3,1,17,0,NULL,'pinpinivaiva'),(19570,791686177002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','pinpinivaiva','pavlin_dorovski@abv.bg','IVELINA DONEVA','c. Borell 6, 1-1','MOLLET DEL VALLES','Cataluña','SPAIN','08100','608621031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 12:10:56',0,NULL,3,1,17,0,NULL,'pinpinivaiva'),(19571,749017768001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','pinpinivaiva','pavlin_dorovski@abv.bg','IVELINA DONEVA','c. Borell 6, 1-1','MOLLET DEL VALLES','Cataluña','SPAIN','08100','608621031','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 12:10:55',0,NULL,3,1,3,1,'RA184573431CN ','pinpinivaiva\r反光板 80cm 2合1    1\r2B柔    1\r橡胶遮光罩 52mm     1'),(19572,809391335017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',2,'AA1309',5,'photographyacc','kafka88f','kafka88@seznam.cz','Filip Laureys','Nad Liskami 28','Brno','','CZECH REPUBLIC','62400','00420606408354','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 13:05:24',0,NULL,3,1,2,1,NULL,'kafka88f'),(19573,749053921001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','jazziestgirl','jazzical_expressions@hotmail.com','Tracy Abernathy','463 Cleveland St','Masury','OH','UNITED STATES','44438-1019','(330) 766-8798','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 13:58:28',0,NULL,3,1,1,1,NULL,'jazziestgirl'),(19574,791723932002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','predatortommy','tommy.drees@hotmail.com','tommy drees','driehoevenstraat 55','genk','','BELGIUM','3600','089384668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 14:01:05',0,NULL,3,1,2,1,NULL,'predatortommy'),(19575,752326361018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',8,'AA1210',38.8,'photographyacc','zxcv7895','info@king-2.co.jp','osamu inoue','I 222-25 Yachimata','Yachimata-Si','Chiba','JAPAN','2891143','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 14:05:56',0,NULL,3,1,3,1,'RA184573649CN ','zxcv7895'),(19576,791736437002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','bcavrag','borna.cavrag@gmail.com','Borna Cavrag','Za gaj 3, mala rakovica','Samobor','','CROATIA','10430','0038513324518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 14:35:37',0,NULL,3,1,3,1,'RA184573388CN ','bcavrag'),(19577,884256817015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',3,'AB1202',12.6,'hutongstore','nikolaydobrovolski','ndobrovolski@yahoo.com','NIKOLAY DOBROVOLSKI','2 Alikhanyan Brothers St.','Yerevan','','ARMENIA','0036','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 14:41:49',0,NULL,3,1,2,1,NULL,'nikolaydobrovolski'),(19578,749077231001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',2,'AD1180',27.8,'hermeshine','mbarb64','m.barbuto@mattbarbuto.com','matt barbuto','1615 genesee st','utica','NY','UNITED STATES','13501-4745','(315) 292-3007','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 15:04:25',0,NULL,3,1,1,1,NULL,'mbarb64'),(19579,752378220018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','elilev-7073','elilev@gmail.com','Eli Levin','Ben Tzvi Shimon 57','Givataiym','Israel','ISRAEL','53631','972-3-5717073','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 16:20:36',0,NULL,3,1,2,1,NULL,'elilev-7073'),(19580,791786591002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','visvx','keithrembisz@comcast.net','Keith Rembisz','4 Sapphire Ave<br>Apt B','Hampton','NH','UNITED STATES','03842-4227','(978) 828-5244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-07 16:40:13',0,NULL,3,1,3,1,'RA184573520CN ','visvx'),(19581,791796922002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','littlemoo2007','hannahdoyle2001@yahoo.com','Hannah Doyle','Valhalla Coolgreany rd<br>Arklow','Co.Wicklow','Wicklow','IRELAND','default','0879551953','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-07 17:09:14',0,NULL,3,1,4,1,'YW867660405CN ','littlemoo2007\r白布\r▲'),(19582,866154563016,260880900498,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2106',25,'hutongstore','lellupi','mrbathnwells@gmail.com','anthony mitchell','45 charles adams close','leiston','Suffolk','UNITED KINGDOM','ip16 4lp','01728635873','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 17:36:21',0,NULL,3,0,3,1,'RA184573578CN ','lellupi\rXXL   已入库'),(19583,883975291015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','maxmillion76','dwaynetyou@hotmail.com','Dwayne Timmons','PCD TRANSPORT LIMITED<br>GORTLUM BRITTAS CO DUBLIN D24','Dublin','Dublin','IRELAND','d24','0857283770','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-07 17:53:07',0,NULL,3,1,4,1,'YW867660416CN ','maxmillion76\r英标\r▲'),(19584,884386114015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','tommyvolvo','bobkatten@spray.se','Tommy Karlsson','Östra torggatan 2','Teckomatorp','Skåne','SWEDEN','26871','0046 730241720','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 18:30:45',0,NULL,3,1,4,1,'YW867660420CN ','tommyvolvo\r黑+白\r▲'),(19585,791844214002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','ayyouy','ayahamdar@yahoo.com','aya hamdar','3-5  Atkinson  St<br>unit 2','Liverpool','New South Wales','AUSTRALIA','2170','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 18:32:24',0,NULL,3,1,2,1,NULL,'ayyouy'),(19586,809549226017,270767170462,'100% Cotton Photo Vest for Sony a200 a300 a700 a900user',1,'AA2113',29.99,'photographyacc','dariolandi','dariolandi@tiscali.it','Dario Landi','Armellini N°12','Nibbiaia','LI','ITALY','57016','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 18:47:29',0,NULL,3,1,3,1,'RA184573493CN ','dariolandi\r Photo Vest   $12'),(19587,749208138001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','ukli83','ukli@gmx.at','Lukas Wonesch','Arnethgasse 60/33','Wien','','AUSTRIA','1160','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-07 19:31:06',0,NULL,3,1,3,1,'RA184573502CN ','ukli83'),(19588,749218700001,110426879616,'JJC JN-22 Neoprene Lens Case 95x150mm for 28-85 lens',1,'AC2202',8.99,'hermeshine','kgalagadi1994','imagenes_vivas@yahoo.es','Oriol Alamany','Llull, 182, P1','Barcelona','Cataluña','SPAIN','08005','933008228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:47:35',0,NULL,3,1,17,0,NULL,'kgalagadi1994'),(19589,791891137002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',4.18,'hermeshine','kgalagadi1994','imagenes_vivas@yahoo.es','Oriol Alamany','Llull, 182, P1','Barcelona','Cataluña','SPAIN','08005','933008228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:47:35',0,NULL,3,1,17,0,NULL,'kgalagadi1994'),(19590,791891138002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','kgalagadi1994','imagenes_vivas@yahoo.es','Oriol Alamany','Llull, 182, P1','Barcelona','Cataluña','SPAIN','08005','933008228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:47:36',0,NULL,3,1,17,0,NULL,'kgalagadi1994'),(19591,791891139002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','kgalagadi1994','imagenes_vivas@yahoo.es','Oriol Alamany','Llull, 182, P1','Barcelona','Cataluña','SPAIN','08005','933008228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:47:37',0,NULL,3,1,17,0,NULL,'kgalagadi1994'),(19592,791622218002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jrosales1984','jcrch84@hotmail.com','Julio Rosales','Calle Estrada Casa#307<br>De la casa de Sor Maria 75 mts al este','Granada','Granada','NICARAGUA','505','+50586047201','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 20:07:58',0,NULL,3,1,3,1,'RA184573326CN ','jrosales1984'),(19593,791891140002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','kgalagadi1994','imagenes_vivas@yahoo.es','Oriol Alamany','Llull, 182, P1','Barcelona','Cataluña','SPAIN','08005','933008228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 19:47:37',0,NULL,3,1,3,1,'RA184573595CN ','kgalagadi1994\rJJC 镜头筒 JN22    1\r普通有线快门线C3    1\r机身盖/镜头后盖  Canon     1\r方形滤镜接口环 77mm    1\r方镜广角托架（ 一槽）    1'),(19594,884475242015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','g_p_archer','geoffreyphiliparcher@yahoo.co.uk','Geoff  Archer','35 William Street<br>North Skelton','Saltburn by the Sea','Cleveland','UNITED KINGDOM','TS12 2AX','07891606422','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 20:26:29',0,NULL,3,1,3,1,'RA184573330CN ','g_p_archer'),(19595,752524398018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','tridvuong','tri.vuong@gmail.com','Tri  Vuong','4715 N Racine Ave<br>Apt 306','Chicago','IL','UNITED STATES','60640-4062','(217) 721-6094','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 20:37:07',0,NULL,3,1,17,0,NULL,'tridvuong'),(19596,752525368018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.9,'photographyacc','tridvuong','tri.vuong@gmail.com','Tri  Vuong','4715 N Racine Ave<br>Apt 306','Chicago','IL','UNITED STATES','60640-4062','(217) 721-6094','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-07 20:38:25',0,NULL,3,1,1,1,NULL,'tridvuong\r3片装的滤镜袋   1\r4片装的滤镜袋     1'),(19597,791938363002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','adeleanddave123','aburry_23@hotmail.com','Adele Burry','Box 819','Balcarres','SK','CANADA','S0G 0C0','(306) 334-2323','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 21:08:06',0,NULL,3,1,2,1,NULL,'adeleanddave123'),(19598,749266841001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','fabri0-10','fabrizioc72@hotmail.com','FABRIZIO COCCIA','ISNELLO 43','CASTELBUONO','PA','ITALY','90013','3204824444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 21:13:00',0,NULL,3,1,3,1,'RA184573428CN ','fabri0-10'),(19599,749270530001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','krumeline72','lkaarboe@online.no','Linda Sandven Kaarbø','Gjethushaugen 7','Kolltveit','Kolltveit','NORWAY','5360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 21:22:25',0,NULL,3,0,3,1,'RA184573480CN ','krumeline72\r黑+白+棕'),(19600,749281082001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','demo154','orthodem@cytanet.com.cy','Demetris Orthodoxou','Michali Vrachimi 39<br>7520 Xylophagou','Larnaca','','CYPRUS','CYP','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 21:40:26',0,NULL,3,1,2,1,NULL,'demo154'),(19601,884510296015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','minni-2003','aashild.skurve@gmail.com','Aashild Skurve','Vetestovegen 9','Fjell','','NORWAY','5357','91366903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 21:16:55',0,NULL,3,1,2,1,NULL,'minni-2003'),(19602,791970736002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','karmi_a','karmi.avi@gmail.com','Avi Karmi','Hagefen st. 28','Haifa','','ISRAEL','35053','+972-54-7430175','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:11:31',0,NULL,8,1,17,0,NULL,'karmi_a'),(19603,791971416002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','karmi_a','karmi.avi@gmail.com','Karin Bensaid','Amnon Ve Tamar 12, Ramat Poleg','Netanya','','ISRAEL','42202','+972506844467','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:13:31',0,NULL,3,1,2,1,NULL,'karmi_a\r中号内胆包 canon    2'),(19604,749298161001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','fancontroller','mike.goulden@earth247.co.uk','Mike Goulden','Unit 11 Four-Soft UK Ltd<br>Matchworks Estate, Speke Road','Liverpool','Merseyside','UNITED KINGDOM','L19 2RF','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 22:19:05',0,NULL,3,1,2,1,NULL,'fancontroller'),(19605,752582958018,280666916076,'New Fancier Complete Tripod 531BT with Ball head 531BH',1,'AE1102',65,'photographyacc','lyssa_grl','alyssa.hardy@gmail.com','Alyssa Hardy','13 Cooks St','Kaleen','Australian Capital Territory','AUSTRALIA','2617','0262428974','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-07 22:27:44',0,NULL,3,1,4,1,'YW867660431CN ','lyssa_grl\r▲'),(19606,866357144016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','agou8387','goulda7@aol.com','Anthony Gould','116 Whitaker road','Derby','Derbyshire','UNITED KINGDOM','De236ap','07894633395','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-07 22:27:02',0,NULL,3,0,3,1,'RA184573365CN ','agou8387\r1.6*3白色  '),(19607,884564427015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','hugoruivinho','hugo.chaosbringer@gmail.com','Hugo Jose Ruivinho','Avenida de Moscavide 34, 1esquerdo','Lisboa','Moscavide','PORTUGAL','1885-061','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-07 22:52:05',0,NULL,3,1,3,1,'RA184573414CN ','hugoruivinho'),(19608,749315191001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',5,'AC1301',31.2,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 23:03:20',0,NULL,3,1,3,1,'RA184573391CN ','mariomarques.com.br'),(19609,749331098001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',5,'AB1303',16.7,'hermeshine','rmcaudio1','rmartinezc@udd.cl','Rodrigo Martínez','ibsen 6445 departamento 24<br>comuna: Las Condes','Santiago','Región metropolitana','CHILE','7550000','56 99170124','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-07 23:50:44',0,NULL,3,1,3,1,'RA184573405CN ','rmcaudio1'),(19610,792031296002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sstruik','simonstruik@msn.com','Simon Struik','Via Airolo 33','MILANO','Milano','ITALY','20159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 01:02:55',0,NULL,3,1,3,1,'RA184573516CN ','sstruik'),(19611,792034378002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','sstruik','simonstruik@msn.com','Simon Struik','Via Airolo 33','MILANO','Milano','ITALY','20159','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 01:12:34',0,NULL,3,1,3,1,'RA184573555CN ','sstruik'),(19612,809765179017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','0428colyer0428','gollygogle@live.com.au','glenn colyer','16 loveday st','whyalla','South Australia','AUSTRALIA','5608','0428447029','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-08 02:21:00',0,NULL,3,1,3,1,'RA184573533CN ','0428colyer0428'),(19613,8881320721815695,111,'LENSPEN X 2',1,'AKT051',0,'hermeshine','curtis648','kac472@sbcglobal.net','Kim Curtis','4532 Hickory Rd<br>Apt 1B','Mishawaka','IN','UNITED STATES','46545-2415','(574) 247-3069',NULL,NULL,NULL,'2011-11-08 03:10:15',0,NULL,3,1,1,1,NULL,'LENSPEN   X  2 \r改一个 \rLK004437595CN    '),(19614,749407324001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','kostya_on','bk@admcher.ru','Konstantin Bratsihin','Belinskogo 26/1','Cheremhovo','Irkutskaya oblast','RUSSIAN FEDERATION','665415','+7(908)6425421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 04:49:50',0,NULL,3,1,5,1,'CP238126686CN ','kostya_on'),(19615,744308891001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','enjex','frieda.kanahau@gmail.com','Frieda Kanahau','Komp. Patria Jaya 3 A No 40<br>Rt.003 Rw.13 Kel. Jatirahayu Kec. Pondok Melati','default','JI','INDONESIA','17414','6281510097667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 05:26:12',0,NULL,3,1,2,1,NULL,'enjex'),(19616,792107182002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+622192659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 06:41:06',0,NULL,3,1,2,1,NULL,'ivan_ns2'),(19617,807576387017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','tenzaroman','moi_rap@mail.ru','Roman Buzov','Mayra 37-48','Pavlodar','Pavlodarskaya Oblast','KAZAKHSTAN','140000','(701) 883 - 8344','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-08 07:00:04',0,NULL,3,1,8,1,'CP238126690CN ','tenzaroman'),(19618,792108679002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','tomtuul-76','tomi.tuuliranta@gmail.com','TeliaSonera/Tomi Tuuliranta','Vapaudenkatu 49<br>40100 Jyväskylä','Jyväskylä','','FINLAND','40100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 07:03:35',0,NULL,3,1,3,1,'RA184573462CN ','tomtuul-76'),(19619,792121784002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','svyatoslavmax','svyatmax@mail.ru','Svyatoslav Listratov','Tenisty proezd 2-1-138','Moscow','','RUSSIAN FEDERATION','129329','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 08:07:56',0,NULL,3,1,2,1,NULL,'svyatoslavmax'),(19620,752730877018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','sweben53','sweben53@yahoo.com.au','STEVEN BROADBENT','1021 GROSE VALE RD KURRAJONG','SYDNEY','New South Wales','AUSTRALIA','2758','0405003446','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-11-08 08:08:23',0,NULL,3,1,4,1,'YW867661971CN ','sweben53\r▲'),(19621,792151186002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','maykovrs2011','maykovrs@gmail.com','Роман Майков','Автостроителей 25 -236','Тольятти','Самарская область','RUSSIAN FEDERATION','445030','+79179650831','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 10:01:40',0,NULL,3,1,2,1,NULL,'maykovrs2011'),(19622,884771815015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','leo140485','leo_hoang@hotmail.com','Leo Hoang','53 Galgate Close','Wimbledon','London','UNITED KINGDOM','SW19 6ET','07535651273','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-08 10:20:56',0,NULL,3,1,3,1,'RA184572100CN ','leo140485'),(19623,866585609016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','vilmabet','eva.larsson@swebowl.se','Eva Larsson','Lindvägen 41','Anderstorp','Småland','SWEDEN','33433','070-8184481','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 10:59:38',0,NULL,3,1,2,1,NULL,'vilmabet'),(19624,809900783017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','hitecelvis','dlucy@bigpond.net.au','David Lucy','5 Fagans rd','Arcadia','New South Wales','AUSTRALIA','2159','0414445521','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-08 11:35:03',0,NULL,3,1,2,1,NULL,'hitecelvis'),(19625,792205022002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','james.jjs','james.jjs@gmail.com','James S','Blk 84 Commonwealth Close<br>#10-81','default','','SINGAPORE','140084','+6590259065','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-08 13:05:47',0,NULL,3,1,9,1,'10423111110900004\r ','james.jjs\r放英标 \r给我各最终的重量\r实重3..303   泡重6.28'),(19626,884832437015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',120,'hutongstore','go2he11','shutnik.08@mail.ru','Utegenov Sagadat','Bekhozhina 15-164','Pavlodar','','KAZAKHSTAN','140000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 13:05:50',0,NULL,3,1,8,1,'CP235618735CN ','go2he11\r欧标'),(19627,790454204002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','n_vdovin','n_vdovin@mail.ru','Nikita Vdovin','Borisovskiy proezd, d. 22, k.1, kv.24','Moscow','Moscow','RUSSIAN FEDERATION','115563','8(916)551-45-84','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 13:12:14',0,NULL,3,1,2,1,NULL,'n_vdovin'),(19628,792204472002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','tersfilms','filmsandweapons@yahoo.com','Terry O\'Dell','720 W ONeil Dr<br>Apt 2237','Casa Grande','AZ','UNITED STATES','85122-4150','(520) 518-5725','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 13:29:08',0,NULL,3,1,1,1,NULL,'tersfilms'),(19629,749535799001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','mr_moocow','metcalfe.andrew@gmail.com','Andrew Metcalfe','Unit 1, 18 Broughton Avenue','CROYDON','Victoria','AUSTRALIA','3136','0417121005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 13:42:31',0,NULL,3,1,17,0,NULL,'mr_moocow'),(19630,884848144015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','goran.mattson','goran@tvc.no','Gøran Mattson','Osterhausgata 16a','Oslo','oslo','NORWAY','0183','92827971','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-08 13:43:31',0,NULL,3,1,17,0,NULL,'goran.mattson'),(19631,866631129016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','goran.mattson','goran@tvc.no','Gøran Mattson','Osterhausgata 16a','Oslo','oslo','NORWAY','0183','92827971','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-08 13:43:32',0,NULL,3,1,5,1,'CP238126876CN ','goran.mattson\r欧标\r2个背景板单发，其他看能不能发dhl，先估一下，不合适就所有的一起发\r除了c 里面的再发如下\r2.4x3m背景架+ 白布    1\r实重10.426   泡重11.69'),(19632,749533044001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','mr_moocow','metcalfe.andrew@gmail.com','Andrew Metcalfe','Unit 1, 18 Broughton Avenue','CROYDON','Victoria','AUSTRALIA','3136','0417121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 13:44:08',0,NULL,3,1,17,0,NULL,'mr_moocow'),(19633,749532907001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','mr_moocow','metcalfe.andrew@gmail.com','Andrew Metcalfe','Unit 1, 18 Broughton Avenue','CROYDON','Victoria','AUSTRALIA','3136','0417121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 13:44:08',0,NULL,3,1,3,1,'RA184572263CN ','mr_moocow\r独脚架  伟峰 WT-1003    1\r绿叶 UV  58mm     1\r绿叶 渐变镜 52mm    1'),(19634,809948838017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',5,'AD1168',75,'photographyacc','bootlace007','ben@benmedia.com','Ben Lynch','Shop 4<br>72 Church St','Mudgee','New South Wales','AUSTRALIA','2850','0404466236','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-08 13:52:36',0,NULL,3,1,3,1,'RA184572113CN ','bootlace007'),(19635,884264774015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','bradburyeger','balazs.csaba.eger@gmail.com','Balázs Csaba','Napsugár út 4.','Eger','Heves Megye','HUNGARY','3300','+36709462100','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 14:05:47',0,NULL,3,1,2,1,NULL,'bradburyeger'),(19636,866645674016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','goran.mattson','goran@tvc.no','Gøran Mattson','Osterhausgata 16a','Oslo','oslo','NORWAY','0183','92827971','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-08 13:37:35',0,NULL,3,1,5,1,'CP238126880CN ','goran.mattson\r2mx1.5m 背景板（蓝，绿）  1\r2mx1.5m 背景板（黑，白）    1'),(19637,884862706015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','goran.mattson','goran@tvc.no','Gøran Mattson','Osterhausgata 16a','Oslo','oslo','NORWAY','0183','92827971','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-08 14:16:51',0,NULL,3,1,17,0,NULL,'goran.mattson\r'),(19638,792230449002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','gmanzanoa','gmanzanoa@hotmail.com','GUSTAVO MANZANO','CALLE 30 #8 COLONIA CENTRO','CHAMPOTON','CAMPECHE','MEXICO','24400','9821037673','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 14:19:39',0,NULL,3,1,3,1,'RA184572127CN ','gmanzanoa'),(19639,792236897002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','burinbabe','derekdaphne@eastlink.ca','Daphne Roberts','19 Terraview Dr','Glovertown','NL','CANADA','A0G2L0','(709) 533-9721','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 14:37:21',0,NULL,3,1,3,1,'RA184572073CN ','burinbabe'),(19640,748167922001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','collegegraduate2007','shopdropnblow@aol.com','Jessica Stannard','993 Middlefield Rd','Cherry Valley','NY','UNITED STATES','13320-3233','(607) 264-8073','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 14:44:05',0,NULL,3,0,1,1,NULL,'collegegraduate2007\r黑色 '),(19641,792241084002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','steinarness','steinar@creativeness.no','steinar ness','pinebergveien 17b','trondheim','','NORWAY','n-7045','73990624','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 14:49:32',0,NULL,3,1,12,1,'1733209800\r ','steinarness\r欧标\r实重13.1 泡重13.61'),(19642,792250377002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','nmljoel','toledodesign@gmail.com','joel garcia','berget8','4400','flekkefjord','NORWAY','4400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 15:12:36',0,NULL,3,1,17,0,NULL,'nmljoel'),(19643,792250378002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',245,'hermeshine','nmljoel','toledodesign@gmail.com','joel garcia','berget8','4400','flekkefjord','NORWAY','4400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 15:12:38',0,NULL,3,1,17,0,NULL,'nmljoel'),(19644,752864557018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','gcscsales2011','pnembree@yahoo.com','Phillip Embree','110 Thames Dr','Goose Creek','SC','UNITED STATES','29445-7183','(843) 696-5005','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-08 15:20:49',0,NULL,3,0,1,1,NULL,'gcscsales2011\rxxxl   已入库'),(19645,792254402002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','domthewizard','dom_the_wizard@hotmail.it','Domenico Marzocchella','Via A. Diaz, 1','Sant\'Antimo','NA','ITALY','80029','3402849949','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 15:25:19',0,NULL,3,1,2,1,NULL,'domthewizard'),(19646,749568088001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','nmljoel','toledodesign@gmail.com','joel garcia','berget8','4400','flekkefjord','NORWAY','4400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 15:12:37',0,NULL,3,1,12,1,'1733209811\r ','nmljoel\r欧标 c 里面的白布换成绿色的\r 除了c 里面的再发\r斜臂     1\r灯架  2m    2\r5灯头+60-90棚（放澳转欧标）    2\r45w 5500k 灯泡 220v    10\r灯架包       1\r实重17.15  泡重23.04'),(19647,749587294001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','kri-kri2010','gemito7@yahoo.com','George Grande','Starrmyra 10','7091-Tiller','Trondhejm','NORWAY','7091','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-08 16:01:46',0,NULL,3,1,2,1,NULL,'kri-kri2010'),(19648,749587816001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','andryxa_rus','foto-80@yandex.ru','Andrey Lubichin','st Menjinskogo 10 - 26','Bryansk','Bryanskaya','RUSSIAN FEDERATION','241020','(919) 299-24-59','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 16:09:32',0,NULL,3,1,2,1,NULL,'andryxa_rus'),(19649,749637328001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','tkv1984','tkv1984@yandex.ru','Konstantin Teremkov','Osennie bulvar 16-1-154','Moscow','Moscow','RUSSIAN FEDERATION','121614','+7-926-296-0412','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-08 17:51:10',0,NULL,3,1,5,1,'CP238126859CN ','tkv1984\r欧标'),(19650,792334053002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','lakshila','lakshilaj@gmail.com','Dr. Lakshila Sampath Jayawardhana','Apollo Pharmacy,  No, 7<br>Mangala Road','Gampaha','Sri Lanka','SRI LANKA','11000','+94772920899','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 18:20:52',0,NULL,3,1,3,1,'RA184572135CN ','lakshila\r申报gift $10'),(19651,749656505001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','ilya79','ilyapetrenko@yahoo.com','ilya petrenko','hanegev str 2/5','nahariya','','ISRAEL','22222','0544494807','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-08 18:28:11',0,NULL,3,1,3,1,'RA184572095CN ','ilya79'),(19652,749680230001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','sonykanet','infor_print@yahoo.es','Manuel Perez Calzado','Calle Las Mieses nº 7','Lucena','Andalucía Ceuta y Melilla','SPAIN','14900','692027750','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 19:10:41',0,NULL,3,1,3,1,'RA184572351CN ','sonykanet'),(19653,792365731002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','crravell','ravello.cesar@gmail.com','Cesar Ravello','Artemio Gutierrez 2531<br>San Joaquin','Santiago','Region Metropolitana','CHILE','8940713','25569337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 19:14:12',0,NULL,3,1,3,1,'RA184572042CN\r ','crravell'),(19654,749683851001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','workanddesign','avramov29@hotmail.com','rafael avramovich','166 Berry St','Brooklyn','NY','UNITED STATES','11249-3111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-08 19:20:14',0,NULL,3,1,4,1,'YW867661982CN ','workanddesign\r▲'),(19655,749691262001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',25.99,'hermeshine','krish156','kriss1566@yahoo.com','krishna','8/50 rich street','melbourne','Victoria','AUSTRALIA','3174','61385100967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 19:31:30',0,NULL,3,1,3,1,'RA184572025CN ','krish156'),(19656,749693112001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','calleja71','sand71@hotmail.com','ALEXANDRA CALLEJA','SUNSET 7<br>TRIQ L-GHAKKIES','NAXXAR','','MALTA','NXR 05','0356 99895998','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-08 19:33:10',0,NULL,3,0,3,1,'RA184572011CN ','calleja71\rL  已入库'),(19657,809763050017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'AKT081',61.87,'photographyacc','shapow162','pow162@live.com','Sharon Power','29 Haslingden Street','Moruya','New South Wales','AUSTRALIA','2537','0244740090','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-08 20:59:08',0,NULL,3,1,3,1,'RA184572039CN ','shapow162\r除了c 里面的再发\rcanon 机身后盖     3\r9个环+两种托架   1套 \r已入库'),(19658,749377079001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','jaber*2010','jmmedshel@hotmail.com','jaber mabrouk medshel','aljalawya,p.o box 15270','addammam','Eastern Region','SAUDI ARABIA','31444','(009) 665-0684 ext.: 0502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 21:06:25',0,NULL,3,1,2,1,NULL,'jaber*2010'),(19659,885151610015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','millakrogh','camgalou@gmail.com','Camilla Galountzis','Læssøegade 111','Odense M','Fyn','DENMARK','5230','004526839869','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-08 22:06:38',0,NULL,3,1,4,1,'YW867661956CN ','millakrogh\r欧标\r▲'),(19660,753080978018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','hennie88','henriette_slettvold@hotmail.com','Henriette Slettvold','Aursnesvegen 11','Sykkylven','','NORWAY','6230','98451112','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-08 22:14:13',0,NULL,3,0,2,1,NULL,'hennie88\r白 '),(19661,749791520001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',53.98,'hermeshine','roger1968moore','rsmoore60@yahoo.co.uk','Roger Moore','1, Sompting court<br>St giles close','Shoreham-by-sea','West sussex','UNITED KINGDOM','BN43 6GY','01273462398','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-08 22:39:49',0,NULL,3,1,3,1,'RA184572060CN ','roger1968moore'),(19662,792483471002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','davidpmarques','davidpmarques@gmail.com','David Marques','Rua Abel Manta Lote 6 Loja 1','Mem Martins','','PORTUGAL','2725-604','+351938837661','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 22:57:50',0,NULL,3,1,4,1,'YW867661960CN ','davidpmarques\r▲'),(19663,749819358001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','orest.zaremba','orko.zaremba@gmail.com','Orest Zaremba','46/5, Hotkevicha str.,','Lviv','Lviv reg,','UKRAINE','79070','0979076623','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-08 23:59:03',0,NULL,3,1,3,1,'RA184572144CN ','orest.zaremba'),(19664,749851725001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','zah_dmc590','zhealthcare@gmail.com','Zahidur Rahman','8866 Baron St','Woodridge','IL','UNITED STATES','60517','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 01:50:12',0,NULL,3,1,3,1,'RA184572087CN ','zah_dmc590'),(19665,749864623001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 02:38:34',0,NULL,3,1,3,1,'RA184572158CN ','deliusbrazil-10\r申报gift  $35.99'),(19666,885261874015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','aaronspaded','fringsfamilyforever@gmail.com','aaron frings','808 Sutter Ave<br>Apt C','modesto','CA','UNITED STATES','95351-3866','(209) 589-6595','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 02:40:38',0,NULL,3,1,1,1,NULL,'aaronspaded'),(19667,8881320806706306,111,'套装',1,'',0,'hutongstore','andreassoufis','andreassikkis@gmail.com;','Andreas Sikkis','Georgiou pop 9','Athens','Attica ','GREECE','11525','',NULL,NULL,NULL,'2011-11-09 02:45:06',0,NULL,3,0,5,1,'\rCP240514477CN','2m 灯架   3\r斜臂   1\r4灯头 伞孔   3  欧标 \r85cm 反光伞    2\r配4灯头的50-70cm 柔光箱  1\r已入库\r实重7.26  泡重7.87\r我召回了，过几天德邦到付。\r申报$70 发SAL\r之前ＤＨＬ的单号\r1733209796'),(19668,8881320807492953,111,'套装',1,'AKT037',0,'hutongstore','karburatorik','brano@kraus.sk','Branislav Kraus','Dukelska 12<br>Nove Mesto nad','Vahom, Slovakia','','SLOVAKIA','91501','',NULL,NULL,NULL,'2011-11-09 02:58:12',0,NULL,3,1,5,1,'CP238126862CN ','c里的再加上   布是白色的\r欧标\r2m 灯架    1\r斜臂            1     已入库\r '),(19669,753182509018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','p.hai','hai.pham@yahoo.com','Hai Pham','17 Dantum Grove Braybrook','Melbourne','Victoria','AUSTRALIA','3019','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-09 03:36:06',0,NULL,3,1,2,1,NULL,'p.hai'),(19670,8881320815697227,111,'天涯 渐变橙',1,'AA2317',0,'hermeshine','jackchan1974','jackcpl1974@hotmail.com','Jacqueline Chan','Teck Guan Regency, 318 Jalan St.Patrick, Off Jalan Belunu,<br>Nove Mesto nad','Tawau','Sabah','MALAYSIA','91007','6089772277',NULL,NULL,NULL,'2011-11-09 05:14:57',0,NULL,3,1,3,1,'RA184572201CN\r ',' 检查一下，上一片有划痕，这是补发'),(19671,810384953017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.8,'photographyacc','chocklips69','krewsin@hotmail.com','Chip Mooney','31 Amaroo Drive','Chelsea Heights','Victoria','AUSTRALIA','3196','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-09 08:34:07',0,NULL,3,1,2,1,NULL,'chocklips69'),(19672,885355143015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',2,'AC1204',8.76,'hutongstore','1860_relaxing','shwtd2640@msn.com','Habari Designer Boutique','35557 Trevino Trl','Beaumont','CA','UNITED STATES','92223-6203','(951) 845-1860','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 08:54:18',0,NULL,3,1,1,1,NULL,'1860_relaxing'),(19673,885359348015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','kliim','niels@lk5.dk','niels kliim','bakkevej 8','birkerød','','DENMARK','3460','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 09:07:17',0,NULL,3,1,3,1,'RA184572630CN ','kliim'),(19674,867154380016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','kliim','niels@lk5.dk','niels kliim','bakkevej 8','birkerød','','DENMARK','3460','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 09:07:17',0,NULL,3,1,4,1,'YW867660453CN ','kliim\r放澳转欧标\r▲\r'),(19675,753250520018,280697484052,'Studio 24\"x35\"/60x90cm Softbox Universal Mount 4 strobe',1,'AD1140',42,'photographyacc','tagov','tagov@telefonica.net','SANTIAGO VITORES TOLEDO','PLAZA DOCTOR LAGUNA, 9, 8ºB','MADRID','Madrid','SPAIN','28009','630097749','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 09:08:05',0,NULL,3,1,3,1,'RA184572325CN ','tagov'),(19676,749882448001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',6.99,'hermeshine','greselle908','greselle_cya@yahoo.com','Greselle Sia','Calinan Skylight Hardware<br>R.Magsaysay St., Calinan','Davao City','Davao del Sur','PHILIPPINES','8000','9393533339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 09:31:27',0,NULL,3,1,2,1,NULL,'greselle908\r麂皮     1\rlenspen    1'),(19677,867168246016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','fandressouza2011','fandressouza@gmail.com','felipe souza alarcon','sobo cafe-pearse dart station, westland row','dublin 2','Dublin','IRELAND','default','858208369','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-09 09:45:39',0,NULL,3,1,12,1,'1733226526\r ','fandressouza2011\r英标\r实重   7.2    泡重8.36'),(19678,885397856015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','ppar9744','deepa85@live.ie','Piradeepa Paranthaman','40 Queenborough Gaedens','Ilford','Essex','UNITED KINGDOM','IG2 6XZ','02085510365','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-09 11:06:16',0,NULL,3,1,4,1,'YW867661890CN ','ppar9744\r白布  \r▲'),(19679,810437532017,270757831585,'ProHeavy Video Camera Tripod EI-717 1.33m 4.4ft version',1,'AO0001',190,'photographyacc','murzins','lamursa@hotmail.com','Willem Versteegen','Abdijstraat 37','Hamont','','BELGIUM','3930','0473-118313','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 11:38:11',0,NULL,3,1,4,1,'YW867661901CN ','murzins\r▲'),(19680,749984746001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','imangro','mangro@mail.ru','Valeria Titova','Eremenko st., 60/10, 136','Rostov-on-Don','','RUSSIAN FEDERATION','344015','79043400474','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 11:46:20',0,NULL,3,1,5,1,'CP238126831CN ','imangro\r黑+白  '),(19681,792681545002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','vladxc2010','vladxc@gmail.com','Vlad Sabau','Str. Parang, Nr. 17, Bl H10, Apt 56','Cluj - Napoca','Cluj','ROMANIA','400552','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 12:09:57',0,NULL,3,1,3,1,'RA184572382CN ','vladxc2010'),(19682,809529342017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',10,'AC2305',59.8,'photographyacc','edc-01e','bc-nc39@nifty.com','Akira Nakano','311 Aza-higashimyoudenchi, Rokugouhigashine,','Misato-chou, Senboku-gun,','Akita','JAPAN','019-1403','090-4425-5200','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 12:31:57',0,NULL,3,1,3,1,'RA184572317CN ','edc-01e'),(19683,749934837001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',82,'hermeshine','soulforsoup','justintmk@hotmail.com','Justin Tan','Blk 330 Clementi Ave 2 #08-182<br>Singapore','default','','SINGAPORE','120330','81899967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 12:50:11',0,NULL,3,1,9,1,'10423111111000002\r ','soulforsoup\r实重2.76  泡重3.83'),(19684,753323516018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','stonefam4','stonefam_5@yahoo.ca','Dawn  Villers','5 Sparrow Ct','Little Brittain','ON','CANADA','K0M2C0','(705) 786-9250','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 13:16:26',0,NULL,3,0,3,1,'RA184572405CN ','stonefam4\r蓝+黑+粉'),(19685,753331580018,280666901043,'New Camera bag topload D3 for Nikon D80 D60 D5000',1,'AO0035',8.99,'photographyacc','fabri0-10','fabrizioc72@hotmail.com','FABRIZIO COCCIA','ISNELLO 43','CASTELBUONO','PA','ITALY','90013','3204824444','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 13:39:18',0,NULL,3,1,2,1,NULL,'fabri0-10'),(19686,750033681001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','legend330','emjaywells@hotmail.com','michael wells','24 ringinglow village','sheffield','south yorkshire','UNITED KINGDOM','s117ts','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 14:20:19',0,NULL,3,0,3,1,'RA184572453CN ','legend330\rXXXL  已入库'),(19687,792728924002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','alienbunny','steffen-klemz@gmx.de','Steffen Klemz','Bei den Zelten 5','Hamburg','','GERMANY','22111','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 14:30:38',0,NULL,3,1,2,1,NULL,'alienbunny'),(19688,750063182001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','aleks0378','aleksandra.szwedo@op.pl','Aleksandra Szwedo','49 College Orchard','Newbridge','Kildare','IRELAND','default','0857475716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 15:38:06',0,NULL,3,0,3,1,'RA184572436CN\r ','aleks0378\r灰色 棕色'),(19689,753384067018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','pornocha','grasslandkayfer@gmail.com','Lourdes Sanchez','luis petralanda 8 bajo','basauri','País Vasco','SPAIN','48970','647833906','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 16:07:21',0,NULL,3,0,2,1,NULL,'pornocha'),(19690,753395584018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','vlad2010pilot','tempered_by_fire@mail.ru','Denis Dryuchin','Teatralnaya 5, kv. 70','Orenburg','','RUSSIAN FEDERATION','460044','89228186744','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 16:45:59',0,NULL,3,0,3,1,'RA184572379CN ','vlad2010pilot\r白色  绿色'),(19691,792783736002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',3,'AD1169',20.64,'hermeshine','ukb1ll','bill@radiobangkok.net','William Hammerton','99/12 Soi Watcharathit Ahtit Soi 3<br>Soi 101/1 Bang Jak Prakanong','Bangkok','BA','THAILAND','10260','0839237779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 16:46:41',0,NULL,3,1,2,1,NULL,'ukb1ll'),(19692,792802904002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','braysteven','braysteven@hotmail.com','STEVEN BRAY','8 FURNESS DENE<br>MONK BRETTON','BARNSLEY','South Yorkshire','UNITED KINGDOM','S71 2RG','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 17:25:38',0,NULL,3,0,3,1,'RA184572365CN\r ','braysteven\rXL  已入库'),(19693,753429221018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','jj-jeldes','rabotek@hotmail.com','FRANCISCO COCA GUTIERREZ','C Villa de Marin 8 6 A','Madrid','Madrid','SPAIN','28029','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 17:35:56',0,NULL,3,0,2,1,NULL,'jj-jeldes\r白色  '),(19694,885608067015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','gintoxfashion','beogustafsson@telia.com','Bengt-Olof Gustafsson','Saltvägen 18','Falkenberg','Europe','SWEDEN','31192','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 18:25:26',0,NULL,3,1,17,0,NULL,'gintoxfashion'),(19695,885608068015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','gintoxfashion','beogustafsson@telia.com','Bengt-Olof Gustafsson','Saltvägen 18','Falkenberg','Europe','SWEDEN','31192','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 18:25:27',0,NULL,3,1,17,0,NULL,'gintoxfashion'),(19696,885608069015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','gintoxfashion','beogustafsson@telia.com','Bengt-Olof Gustafsson','Saltvägen 18','Falkenberg','Europe','SWEDEN','31192','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-09 18:25:28',0,NULL,3,1,4,1,'YW867661912CN ','gintoxfashion\r欧标   \r除了c 里面的再发   ▲\r倒影板（白黑）      1\r45w 5500k 灯泡 220v      2\r客户确认收到了1124'),(19697,750155135001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','veloliza','dmitrevna@ukr.net','Elizaveta Tomashevska','Timoshenko 4, 74','Kiev','','UKRAINE','04212','+380 664835091','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 18:50:49',0,NULL,3,1,5,1,'CP238126845CN ','veloliza\r黑+白 '),(19698,885653102015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','joaovarelacarreco','joao.var@gmail.com','João Varela Carreço','Av. Gomes Pereira nº18, 1º Esquerdo','Lisbon','Lisbon','PORTUGAL','1500-330','(+351) 96 58 31 400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 19:27:19',0,NULL,3,1,3,1,'RA184572334CN ','joaovarelacarreco'),(19699,750180613001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','hliobressanvendas','bressanvendas@gmail.com','Hélio Bressan','Rua Dr Candido Espinheira 396<br>perdizes','São Paulo','São Paulo','BRAZIL','05004-000','1196973610','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-09 19:34:58',0,NULL,3,1,5,1,'CP238126814CN ','hliobressanvendas'),(19700,792883256002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','neclem0826','neclem@ymail.com','Nesby Clemons','7124 Old Canton Rd','Ridgeland','MS','UNITED STATES','39157-1037','(601) 519-0826','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-09 19:48:53',0,NULL,3,1,1,1,NULL,'neclem0826'),(19701,885704529015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','1954gregory','migrego@otenet.gr','Grigorios Michailidis','Ivis 136','Glyfada , Athens','','GREECE','16561','0030  2109626883','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-09 20:32:49',0,NULL,3,1,2,1,NULL,'1954gregory'),(19702,810690290017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','miss1605','cassey.neely@hotmail.com','CaseDan','182 Third Ave','Narromine','New South Wales','AUSTRALIA','2831','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-09 20:32:49',0,NULL,3,1,2,1,NULL,'miss1605'),(19703,750217879001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','chophopper842','pristupa_oleg@mail.ru','Oleg Pristupa','Molodezhnaya Street 12 app.36','Novorossiysk','Krasnodar region','RUSSIAN FEDERATION','353925','+79189642758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:34:49',0,NULL,3,1,17,0,NULL,'chophopper842'),(19704,792901204002,120757472199,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT074',310,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:53:30',0,NULL,3,1,5,1,'CP238126828CN ','serqwer\r欧标   除了c 里面的再发\r防雨罩    1\r柔光伞      1\rlenspen       1\r双灯头  欧标     1\r45w 5500k 灯泡 220v     2'),(19705,750209067001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:53:31',0,NULL,3,1,17,0,NULL,'serqwer'),(19706,750220305001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','dpturnbullthehat','davidpaulturnbull@yahoo.com','d p turnbull','316<br>winslow road','bromyard','Herefordshire','UNITED KINGDOM','hr7 4tx','07855354505','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:58:11',0,NULL,3,1,2,1,NULL,'dpturnbullthehat'),(19707,792902028002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:58:44',0,NULL,3,1,17,0,NULL,'serqwer'),(19708,792902308002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:58:45',0,NULL,3,1,17,0,NULL,'serqwer'),(19709,792902156002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:58:45',0,NULL,3,1,17,0,NULL,'serqwer'),(19710,792902394002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','serqwer','3993593@gmail.com','Sergey Karyshev','Kashirskoe shosse, 146, 2, 443','Moscow','Moskovskaya Oblast`','RUSSIAN FEDERATION','115582','89262965336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 20:58:46',0,NULL,3,1,17,0,NULL,'serqwer'),(19711,792927462002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','chophopper842','pristupa_oleg@mail.ru','Oleg Pristupa','Molodezhnaya Street 12 app.36','Novorossiysk','Krasnodar region','RUSSIAN FEDERATION','353925','+79189642758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 21:03:56',0,NULL,3,1,17,0,NULL,'chophopper842'),(19712,750235822001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.95,'hermeshine','mk_hamer','mkkuzmenko@gmail.com','Mihail Kuz\'menko','30 let pobedy st.42 app.499<br>Cherkassy','Cherkassy','UA','UKRAINE','18029','+38 (067) 4706667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 21:05:27',0,NULL,3,1,17,0,NULL,'mk_hamer'),(19713,810713137017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',73,'photographyacc','golubtsovandriy','g_andriy_i@ukr.net','Andriy Golubtsov','Marusi Churay 20a/1','Rivne','Rivne','UKRAINE','33025','(063)9407970','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 21:06:43',0,NULL,3,1,5,1,'CP238126791CN ','golubtsovandriy\r欧标   '),(19714,750230919001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','chophopper842','pristupa_oleg@mail.ru','Oleg Pristupa','Molodezhnaya Street 12 app.36','Novorossiysk','Krasnodar region','RUSSIAN FEDERATION','353925','+79189642758','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 21:01:52',0,NULL,3,1,5,1,'CP238126805CN ','chophopper842\r三脚架 伟峰 WF-6663A      1\r绿叶 CPL  67mm     1\r绿叶 UV  67mm        1'),(19715,750237734001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','mk_hamer','mkkuzmenko@gmail.com','Mihail Kuz\'menko','30 let pobedy st.42 app.499<br>Cherkassy','Cherkassy','UA','UKRAINE','18029','+38 (067) 4706667','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 21:08:07',0,NULL,3,1,2,1,NULL,'mk_hamer\r绿叶 CPL  52mm    1\r橡胶遮光罩 52mm    1'),(19716,788789370002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','waynesjw','sjw2638@hotmail.com','Wayne Hsu','2102-4388 Buchanan St','Bunaby','BC','CANADA','V5C6R8','(778) 829-3685','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-09 22:02:04',0,NULL,3,1,2,1,NULL,'waynesjw'),(19717,750293580001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','hibottom','reiswig@clearwire.net','Alvin C Reiswig','1406 N E Talbot','Grants Pass','OR','UNITED STATES','97526','(541) 471-1597','NoPaymentFailure','CheckoutComplete','Other','2011-11-09 23:16:11',0,NULL,3,1,1,1,NULL,'hibottom'),(19718,810792739017,270806201214,'Photo Studio Table Light 40cm Cube Kit Box Tent Set',1,'AKT091',85,'photographyacc','vairinhos','vairinhos78@hotmail.com','Totalstor (Mr. Carlos Vairinhos)','Ed. Mirante, Estrada de Alfragide Lt 107','Amadora','','PORTUGAL','2610-008','+~351935610311','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 23:54:06',0,NULL,3,1,4,1,'YW867661923CN ','vairinhos\r欧标   \r▲'),(19719,753627784018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','kencode0','kencode@biolargo.com','Kenneth Code','26116A Highway 16<br>Unit 19','Spruce Grove','AB','CANADA','T7Y 1A1','(780) 418-3936','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-09 23:55:38',0,NULL,3,1,2,1,NULL,'kencode0'),(19720,753645289018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','theos_123','tsarlamis@gmail.com','Theo Sarlamis','49 Captain Cook Drive<br>Taren Point','Sydney','New South Wales','AUSTRALIA','2229','0295794966','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 00:55:18',0,NULL,3,1,2,1,NULL,'theos_123'),(19721,8881320888981584,111,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',11.8,'aliexpress','1005150698','trianon8@mail.ru','Krutev Aleksandr	','3 Privokzalniy 16-39','Achinsk','Krasnoyarskiy kray	','RUSSIAN FEDERATION	','662155','89233469990',NULL,NULL,NULL,'2011-11-10 01:36:21',0,NULL,3,1,3,1,'RA184572612CN ',''),(19722,753660263018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',2,'AD1122',31.6,'photographyacc','yefim_f','170161@gmail.com','Yefim Fefer','1 Gadera st, apt 24','Petah Tikva','center','ISRAEL','49724','+972 52 6132451','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 01:45:39',0,NULL,3,1,3,1,'RA184572440CN\r ','yefim_f'),(19723,8881320889555761,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',18.58,'aliexpress','1005152928','82000@walla.com','Netanel Haimov	','POB 9097','Ashqelon','Israel','ISRAEL','78190','+972 3 5463377',NULL,NULL,NULL,'2011-11-10 01:45:55',0,NULL,3,1,3,1,'RA184572643CN ',''),(19724,8881320890459657,111,'CANON LOGO的新款内胆包',1,'AD1162',0,'photographyacc','evgeny1958.137','e.scherbakov@mail.ru','Evgeny Scherbakov','Vosstania str., 42-12','Sankt Petersburg','Russia','RUSSIAN FEDERATION','191123','+7(911) 920-09-90',NULL,NULL,NULL,'2011-11-10 02:00:59',0,NULL,3,0,3,1,'RA184572348CN\r ',NULL),(19725,8881320890759652,111,'x2 45W 220V 5500K Studio Light Bulb Daylight with E27 Socket ',1,'AKT007',15.98,'aliexpress','1005167308','jandow@live.dk','Jan Dow','Fuglevaenget 72h','Grenaa','grenaa','DENMARK','8500','+45 5014 4092',NULL,NULL,NULL,'2011-11-10 02:05:59',0,NULL,3,1,3,1,'RA184572688CN ',''),(19726,753684411018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','singingphotomom','leah_belanger_photography@yahoo.ca','Leah Belanger','123 Trager Drive','The Pas','MB','CANADA','R9A 1K5','(204) 623-3303','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 03:20:44',0,NULL,3,0,2,1,NULL,'singingphotomom\r白色 '),(19727,810855068017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','annette3433','amazonlady6@hotmail.com','Annette Dunn','Po Box 5712  Torquay','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-10 03:26:40',0,NULL,3,1,4,1,'YW867661864CN ','annette3433\r新地址\rAnnette Dunn. \r34 Turrum Street \rScarness. 4655 \rHervey Bay.    ▲\rQueensland.\rAustralia. \r\r'),(19728,810866179017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','arnelcindy','arnelm2000@yahoo.com','Arnel Macababbad','16 St Vincent Way','Caroline Springs','Victoria','AUSTRALIA','3023','61447878288','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 04:25:01',0,NULL,3,1,2,1,NULL,'arnelcindy'),(19729,810875205017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',2,'AD1401',15.6,'photographyacc','edanhouse','ejpback@hotmail.com','Edward Backhouse','683A Mt Dandenong Rd','Kilsyth','Victoria','AUSTRALIA','3137','0397618021','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 04:45:20',0,NULL,3,1,2,1,NULL,'edanhouse'),(19730,750398743001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','icreates_meenu','gai3nk@gmail.com','ICREATES','1-6-11,FUJIMI<br>407-CONFORE KAWASAKI FUJIMI','KAWASAKI SHI,KAWASAKI KU','Kanagawa','JAPAN','210-0011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-10 06:39:30',0,NULL,3,1,6,1,'EE645619395CN ','icreates_meenu'),(19731,810908444017,270750677827,'New Camera shoulder bag D1 for Nikon D5000 D7000 D80',1,'AO0032',19.99,'photographyacc','snordsy','markrigsby@bigpond.com','Mark Rigsby','29 Gyton Avenue','Glen Waverley','Victoria','AUSTRALIA','3150','0400318228','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 07:40:27',0,NULL,3,1,3,1,' RA184572524CN\r','snordsy'),(19732,8881320911142651,111,'2.4x3m背景架里的4节横杆',1,'',0,'hermeshine','borisvideo','vladimir-video@mail.ru','Vladimir Paloha','Murinsona 35a,29','Chernigov','','UKRAINE','14017','093-750-30-22',NULL,NULL,NULL,'2011-11-10 07:45:42',0,NULL,3,0,3,1,' RA184572609CN\r',NULL),(19733,885953008015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','bernard8180','wayne.mctaggart@ntlworld.com','bernard mctaggart','12 pantycelyn rd townhill','swansea','Swansea','UNITED KINGDOM','sa1 6na','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-10 07:50:15',0,NULL,3,1,4,1,'YW867661945CN ','bernard8180\r+白布 \r▲'),(19734,793113319002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','cyclops45*62','teyoung1@hotmail.com','kerry lawrence','7307 Sandhurst Dr NW','Cedar Rapids','IA','UNITED STATES','52405-5329','(319) 270-6258','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-10 07:57:26',0,NULL,3,1,1,1,NULL,'cyclops45*62'),(19735,885963550015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','24***b','melisa_irem@yahoo.de','bahar gösker','franz-huber-str.4','kiefersfelden','','GERMANY','83088','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 08:29:06',0,NULL,3,1,4,1,'YW867660442CN ','24***b\r黑+白\r▲'),(19736,753792532018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','yefim_f','170161@gmail.com','Yefim Fefer','1 Gadera st, apt 24','Petah Tikva','center','ISRAEL','49724','+972 52 6132451','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 11:28:25',0,NULL,3,1,2,1,NULL,'yefim_f'),(19737,750465467001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','xyepic','alterfate@live.com','XIAO YI ZHANG','38  Delfin  Dr','MacGregor','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 11:30:49',0,NULL,3,1,2,1,NULL,'xyepic'),(19738,753793828018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','bboymd','mike@dancenrg.com.au','Mike Dorrington','1/2 Downey St','Bexley','New South Wales','AUSTRALIA','2207','0291505597','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-10 11:32:45',0,NULL,3,1,3,1,'RA184572569CN ','bboymd'),(19739,8881320926511956,111,'b座',1,'AB2301',0,'photographyacc','augywilangkara','augy_wilangkara@yahoo.com','Augy Wilangkara','29 Scribbly Gum Sq.<br>Willetton','Perth','Western Australia','AUSTRALIA','6155','0427487399',NULL,NULL,NULL,'2011-11-10 12:01:51',0,NULL,3,1,3,1,'RA184572572CN ',NULL),(19740,791707570002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','prankish','japan061@yahoo.com','prakash gurung','5/1 firth street<br>arncliffe','sydney','New South Wales','AUSTRALIA','2205','0280657857','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 13:09:23',0,NULL,3,1,2,1,NULL,'prankish'),(19741,811002892017,270750637170,'Neoprene Camera Cover Case for Nikon D3000 D5000 M',4,'AC2304',23.92,'photographyacc','pahanapp','alex_sachik@list.ru','Oleksandr Sachyk','P.O. Box 139','Kiev','','UKRAINE','03150','0990608090','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 13:19:18',0,NULL,3,1,2,1,NULL,'pahanapp'),(19742,753845950018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',52,'photographyacc','andre.s.58','andre.s.lortie@gmail.com','André Lortie','73 des lotus','Gatineau','QC','CANADA','J9J 2G4','(819) 682-9374','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 14:14:33',0,NULL,3,1,3,1,'RA184572657CN ','andre.s.58'),(19743,811038439017,270806201214,'Photo Studio Table Light 40cm Cube Kit Box Tent Set',1,'AKT091',85,'photographyacc','sonrisa_m','mirsini.1@gmail.com','Mirsini Bogdanou','M. Alexandrou 149','Athens - Keratsini','Greece','GREECE','18755','(+30) 6955474696','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 15:00:29',0,NULL,3,1,4,1,'YW867660464CN ','sonrisa_m\r申报$20  欧标\r▲'),(19744,867916088016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',2,'AB3329',61.98,'hutongstore','8andon8','ka_r_a@hotmail.com','Kalle Anteroinen','Hakapellonkatu 4 F 84','Turku','','FINLAND','20540','+358451126957','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 15:44:21',0,NULL,3,1,4,1,'YW867660475CN ','8andon8\r▲'),(19745,750563999001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','juliuslepetit','bluntride@hotmail.com','Julien Petitclerc','357 Dalbec','Saint-Paul','QC','CANADA','j0k3e0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 16:23:41',0,NULL,3,0,2,1,NULL,'juliuslepetit\r黑色 '),(19746,793272013002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','cb412357','c.brisebois@gmail.com','Charles Brisebois','265 Northwind St','Ottawa','ON','CANADA','K4A 5G5','(613) 697-8179','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 16:40:05',0,NULL,3,1,2,1,NULL,'cb412357'),(19747,753908978018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','wattslinda','linda.watts@bcu.ac.uk','linda watts','room b409 Baker Building BCU<br>City North Campus','Birmingham','West Midlands','UNITED KINGDOM','b42 2su','01213317762','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 16:57:43',0,NULL,3,1,2,1,NULL,'wattslinda'),(19748,886181775015,250666866568,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49,'hutongstore','esthera12','esthera_12@yahoo.com','Timotei Pecura','4608 N KILPATRICK AVE','CHICAGO','IL','UNITED STATES','60630-4026','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 17:29:56',0,NULL,3,1,4,1,'YW867660486CN ','esthera12\r灯泡换成110v的  \r▲'),(19749,793297171002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','66_shovelhead_guy','shovel1966@gmail.com','Chad Ritchie','1921 Millbrook Ct','Virginia Beach','VA','UNITED STATES','23453-5931','(757) 301-7265','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-10 17:40:33',0,NULL,3,1,1,1,NULL,'66_shovelhead_guy'),(19750,806293537017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','levymask0','levymask@gmail.com','Levy Alvares Melo','AV. C255 Quadra 588 Lote 4/8 N.270<br>Ed. Centro Empresarial Sebba. SALA 1112','Goiânia','Goiânia-GO','BRAZIL','74280010','62 84243671','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-10 18:16:21',0,NULL,3,0,3,1,'RA184572626CN ','levymask0\r xxl  已入库'),(19751,886252589015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','semihrayman','srayman@live.nl','semih rayman','Riemkamp 17','TERWOLDE','','NETHERLANDS','7396CE','0571270344','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-10 19:21:21',0,NULL,3,1,3,1,'RA184572586CN ','semihrayman'),(19752,886269219015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','apostoli2pavel','simo.peltola@kotikone.fi ','Simo Peltola','Rantapolku 1.','Orivesi','Oletus','FINLAND','35300','0505921175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-10 19:40:32',0,NULL,3,1,3,1,'RA184572590CN ','apostoli2pavel\r4个'),(19753,750693110001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','01slet','simenleth@yahoo.no','Simen Leth','Grunnavågsveien 6<br>Sagvåg','Stord','Sunnhordland','NORWAY','5410','48235017','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 20:32:14',0,NULL,3,1,3,1,'RA184578235CN ','01slet'),(19754,750700791001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','kevintahiti12','kevintahitimail@gmail.com','Kevin KWANG','BP: 3088 TAHITI','PAPEETE','DOM-TOM','FRENCH POLYNESIA','98714','+689293422','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 20:48:25',0,NULL,3,1,3,1,'RA184572674CN ','kevintahiti12'),(19755,886056485015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','mike95444','michaelunwin@ukf.net','Mike Unwin','Beechcomber<br>Station Road','Sharpthorne','West Sussex','UNITED KINGDOM','RH19 4NY','01342810626','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-10 20:48:26',0,NULL,3,1,3,1,'RA184572691CN ','mike95444'),(19756,750703463001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','sirius063','e.vatolin@mail.ru','Evgeniy Vatolin','Sportivnaya 8-122','Togliatti','Samarskaya obl','RUSSIAN FEDERATION','445057','8482363234','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-10 20:51:29',0,NULL,3,1,2,1,NULL,'sirius063'),(19757,793469752002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-10 23:34:15',0,NULL,3,1,3,1,'RA184572705CN ','mariomarques.com.br'),(19758,886435794015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','calumriddellphotography','c-r-p@hotmail.co.uk','Calum Riddell Photography','5 Holland Street','Aberdeen','Aberdeenshire','UNITED KINGDOM','AB25 3UJ','0122452908','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-11 00:43:30',0,NULL,3,1,4,1,'YW867661875CN ','calumriddellphotography\r英标\r▲'),(19759,8881320975327185,111,'150x200 5in1 反光板   ',15,'AD1182',925,'hermeshine','matti3650','masapirhonen@dnainternet.net','Matti Pirhonen','Tiirankatu 13','Lohja','','FINLAND','08150','+358445056886',NULL,NULL,NULL,'2011-11-11 01:35:27',0,NULL,3,0,12,1,'1107589921\r ','新地址：\rFoos\rTiirankatu 13\rLohja \r08150\rFinland \r 泡重   37.488   实重28.636'),(19760,793536036002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',3,'AKT014',110.85,'hermeshine','muva77','adolfo.vite@gmail.com','adolfo muñoz','grijalba no. 1089','guadalajara','ME','MEXICO','44430','013336503334','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 03:14:32',0,NULL,3,1,3,1,'RA184572745CN ','muva77\r分开发  \rRA184572759CN\rRA184572665CN'),(19761,811382559017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','spliftopnohgih','anton@artof2.com','Anton Rehrl','Level 13<br>50 Bridge St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-11 04:16:19',0,NULL,3,1,2,1,NULL,'spliftopnohgih'),(19762,747975021018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','newlamwargame25','nlwg25@y7mail.com','DALE BLACKWELL','14 CLARENCE ROAD','NEW LAMBTON','New South Wales','AUSTRALIA','2305','0468689629','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-11 04:17:04',0,NULL,3,1,3,1,' RA184572878CN','newlamwargame25'),(19763,754189401018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','arena808','robjess@internode.on.net','Robert Gjessing','29 Railway Ave','Stanmore','New South Wales','AUSTRALIA','2048','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-11 04:34:17',0,NULL,3,1,2,1,NULL,'arena808'),(19764,750852904001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','allanh3188','allanemail@yahoo.com','Duc Cuong Hong','9411-108A Avenue','Edmonton','AB','CANADA','T5H 1B9','(780) 425-3188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 05:10:02',0,NULL,3,1,2,1,NULL,'allanh3188'),(19765,793565663002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','afald','akfald@telus.net','andrea fald','site 449 b2 c4 rr2','drayton valley','AB','CANADA','t7a2a2','(780) 542-7279','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 05:47:08',0,NULL,3,1,3,1,' RA184572881CN','afald'),(19766,793577423002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','kyungsdesign77','pkjewelrydesign@gmail.com','Kyung Ae Park (P.K jewelry)','2 W 47th St<br>Ste 408','New York','NY','UNITED STATES','10036-3339','(646) 258-2038','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-11 07:00:27',0,NULL,3,1,1,1,NULL,'kyungsdesign77'),(19767,868337661016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','sim_pakost','sim_pakost24@hotmail.com','SIME JADRESIN','Rue du cimetiere 11','ARLON','','BELGIUM','6700','0496384993','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-11 08:08:16',0,NULL,3,1,2,1,NULL,'sim_pakost'),(19768,886568163015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','pepjp','pep_jp@hotmail.com','Josep Jorba Pons','Calle Sant Víctor nº 73','Sallent','Cataluña','SPAIN','08650','650643466','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 08:44:31',0,NULL,3,1,2,1,' ','pepjp'),(19769,754256990018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','whaler_au','sgrigoryev@gmail.com','Sergey Grigoryev','201-203 Bulwer Street','Perth','Western Australia','AUSTRALIA','6000','61418929281','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-11 09:57:28',0,NULL,3,1,17,0,NULL,'whaler_au'),(19770,754257278018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','whaler_au','sgrigoryev@gmail.com','Sergey Grigoryev','201-203 Bulwer Street','Perth','Western Australia','AUSTRALIA','6000','61418929281','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-11 09:58:13',0,NULL,3,1,4,1,'YW867661831CN ','whaler_au\r反光板支架      1\r斜臂      1\r▲'),(19771,868383407016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','gsmsecurity','myinkognito@gmail.com','Control Freq Ltd','Omnibus House<br>39 - 41 North Road','London','London','UNITED KINGDOM','N7 9DP','07796176341','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-11 10:37:58',0,NULL,3,1,4,1,'YW867661842CN ','gsmsecurity\r▲'),(19772,886613879015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','spellman89','twspellman1@sheffield.ac.uk','tom spellman','47 college road<br>harrow weald','harrow','London','UNITED KINGDOM','ha3 6ef','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 11:07:43',0,NULL,3,1,3,1,' RA184579068CN\r','spellman89'),(19773,754289511018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','kroost1105','erwin_roost@hotmail.com','Erwin Roost','Kelperveen 31','kelpen-oler','','NETHERLANDS','6037sg','06 15862434','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 11:52:36',0,NULL,3,1,2,1,NULL,'kroost1105'),(19774,886632709015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','kasia_milosz','milosz1905@gmail.com','Milosz Krawczyk','47 Mansfield Road','Bognor Regis','West Sussex','UNITED KINGDOM','PO22 9HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 11:54:09',0,NULL,3,1,3,1,' RA184579156CN\r','kasia_milosz'),(19775,793657889002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',25.99,'hermeshine','visitmyusa','matus@safetybis.com','Anastasiya Kostsina','29 1st Silnickogo Str','Vitebsk','BY','BELARUS','210013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 12:24:55',0,NULL,3,1,3,1,' RA184579142CN\r','visitmyusa'),(19776,886661267015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','villho','ville.honkamaki@gmail.com','Ville Honkamäki','Ramsaynkuja 8 D 19<br>-','Espoo','-','FINLAND','02780','(358)408018113','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-11 13:07:33',0,NULL,3,1,17,0,NULL,'villho'),(19777,886661268015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','villho','ville.honkamaki@gmail.com','Ville Honkamäki','Ramsaynkuja 8 D 19<br>-','Espoo','-','FINLAND','02780','(358)408018113','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-11 13:07:34',0,NULL,3,1,4,1,'YW867661816CN ','villho\r斜臂     1\r2B柔    1\r▲'),(19778,754318036018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','xpete1975x','petet1975@ntlworld.com','Peter Taylor','37 Flaxton Way<br>Top Valley','Nottingham','Nottinghamshire','UNITED KINGDOM','NG5 9AT','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 13:20:09',0,NULL,3,1,2,1,NULL,'xpete1975x'),(19779,868469939016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','paknip','mthanif@yahoo.co.uk','Hanif Mohamed Talha','Flat 31C, Bowsden Court<br>South Gosforth','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE3 1RR','01912859694','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-11 14:18:18',0,NULL,3,1,2,1,NULL,'paknip'),(19780,751041039001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','thecrankypanda','leahmcorey@gmail.com','Leah Corey','137 niagara trail','georgetown','ON','CANADA','l7g0a6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 16:27:58',0,NULL,3,0,2,1,NULL,'thecrankypanda\r黑色'),(19781,751072185001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','tedwill38','ted@tedf8.plus.com','Edward Williams','Flat 35 Worcester Court','Bootle','Merseyside','UNITED KINGDOM','L209AF','01515231677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-11 17:37:46',0,NULL,3,1,3,1,' RA184572935CN\r','tedwill38'),(19782,793787509002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','acostaochoa_123','acostaochoa@yahoo.com.mx','Guillermo Acosta','Instituto de Investigaciones Antropologicas UNAM<br>Circuito Exterior s/n Ciudad Universitaria','Del. Coyoacan','Mexico DF','MEXICO','04510','52 (55) 56229520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 17:51:00',0,NULL,3,1,3,1,' RA184579200CN\r','acostaochoa_123'),(19783,793786086002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','nikosfra','nikosfra@gmail.com','NIKOS FRAGKOULIS','2 STHNIDON STR','MEGARA','MEGARA','GREECE','19100','+302296021041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 17:51:18',0,NULL,3,1,2,1,NULL,'nikosfra\r欧标 '),(19784,793791703002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','bruno99999bici','travis9011@gmail.com','Alessandro Travi','via fontanella 15','gravedona','Como','ITALY','22015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 18:00:20',0,NULL,3,1,17,0,NULL,'bruno99999bici'),(19785,751083271001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','bruno99999bici','travis9011@gmail.com','Alessandro Travi','via fontanella 15','gravedona','Como','ITALY','22015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 18:00:21',0,NULL,3,1,2,1,NULL,'bruno99999bici\r方镜广角托架（ 一槽）    1\r77cm接口环    1\r普通托架     1'),(19786,793793054002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','raq_plaza','raq_plaza@hotmail.com','Raquel Plaza Nagore','Calle Globo 13 3º B','zaragoza','Aragón','SPAIN','50015','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 18:02:43',0,NULL,3,1,2,1,NULL,'raq_plaza'),(19787,751120919001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','sunflower.26.07','doreenoliver@btinternet.com','Doreen Oliver','12 Elvet Close<br>Wideopen','Newcastle upon Tyne','Tyne and Wear','UNITED KINGDOM','NE13 7HE','01912364630','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 19:11:43',0,NULL,3,1,2,1,NULL,'sunflower.26.07'),(19788,754571865018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.6,'photographyacc','roflz','wizzgti@gmail.com','Miha Andrejašič','Cesta španskih borcev 12','Ljubljana','Ljubljana','SLOVENIA','1000','041919866','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-11 22:23:41',0,NULL,3,1,2,1,NULL,'roflz'),(19789,886974082015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','annabelrr','robertsofingleby@btinternet.com','Annabel Roberts','49 St Davids Grove<br>Ingleby Barwick','Stockton on Tees','Cleveland','UNITED KINGDOM','ts17 5he','01642764124','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-11 22:25:00',0,NULL,3,1,4,1,'YW867661820CN ','annabelrr\r黑+白\r▲'),(19790,751229470001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','demonod','dick_an@hotmail.com','Sherley Nobin','Nicholson road le fou lane','vacoas','mauritius','MAURITIUS','230','2309371292','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 23:06:18',0,NULL,3,1,3,1,' RA184579235CN\r','demonod'),(19791,751234549001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','babygirl4realz','kriskay77@yahoo.com.au','Kris Kaye','80 Princes Hwy','Sylvania','New South Wales','AUSTRALIA','2224','0295228858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-11 23:28:37',0,NULL,3,1,2,1,NULL,'babygirl4realz'),(19792,887038715015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','miahishere','cherylmia@btinternet.com','cheryl mia','41 alma street','lowestoft','Suffolk','UNITED KINGDOM','nr32 2eb','07770488276','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-12 01:10:50',0,NULL,3,1,4,1,'YW867661794CN ','miahishere\r黑+白 \r▲'),(19793,793990288002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pambond','pamthepom@bigpond.com','Pamela Phillips','27 bauhinia road<br>forrestfield','perth','Western Australia','AUSTRALIA','6058','0894531612','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 02:19:15',0,NULL,3,1,3,1,' RA184579111CN\r','pambond'),(19794,751291894001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','migbara','migbara@gmail.com','MIGUEL JESUS BARAHONA JUAN','ALFONSO CEA 10 1 D','MADRID','Madrid','SPAIN','28011','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-12 03:07:12',0,NULL,3,1,4,1,'YW867661805CN ','migbara\r黑+白 \r▲'),(19795,754656718018,280717920072,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',28,'photographyacc','enwilkes','enwilkes@bigpond.net.au','Eric Wilkes','5 Challenger Court','Happy Valley','South Australia','AUSTRALIA','5159','0408745280','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 03:20:33',0,NULL,3,1,17,0,NULL,'enwilkes'),(19796,754656256018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',52,'photographyacc','enwilkes','enwilkes@bigpond.net.au','Eric Wilkes','5 Challenger Court','Happy Valley','South Australia','AUSTRALIA','5159','0408745280','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 03:18:50',0,NULL,3,1,3,1,'RA184578116CN ','enwilkes\r蜂窝     1\r70x100cm通用卡口柔光箱    1'),(19797,811898063017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','kingtread','mboily@videotron.ca','Mario Boily','1923 Des Hiboux<br>Unit # 105','Chicoutimi','QC','CANADA','G7H7S3','(418) 543-1215','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 04:48:33',0,NULL,3,1,2,1,NULL,'kingtread'),(19798,794061861002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','sunny.claudia','snnclaudia@gmail.com','verry jap','7537 Davies Street','burnaby','BC','CANADA','v3n3h2','(778) 788-6118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 08:28:40',0,NULL,3,0,3,1,' RA184579258CN\r','sunny.claudia\r1.6*3黑色  '),(19799,887158179015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',49,'hutongstore','telizak','tlam752556@btinternet.com','LISA LAMBERT','25 HAIG DRIVE WINDSOR MEADOWS','SLOUGH','Berkshire','UNITED KINGDOM','SL19HA','01753823910','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-12 09:03:56',0,NULL,3,1,4,1,'YW867661772CN ','telizak\r黑+白\r▲'),(19800,811955223017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',65,'photographyacc','kennypap','kdpapworth@gmail.com','ken papworth','10 grant street','goornong','Victoria','AUSTRALIA','3557','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-12 09:27:44',0,NULL,3,1,4,1,'YW867661783CN ','kennypap\r▲'),(19801,811959122017,270753944377,'New Lambency Flash Diffuser for Nikon SB600 SB800 P1',1,'AB3306',21.5,'photographyacc','georgesavu-2007','georgerobocop@yahoo.co.uk','Gheorghe Savu','6 Hillside Gardens','London','London','UNITED KINGDOM','ha3 9uw','07872610801','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 09:40:23',0,NULL,3,1,3,1,' RA184579244CN\r','georgesavu-2007'),(19802,751370477001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','bmd_02','obermufftee@punkrap.ch','Sascha Rossier','Neunbrunnenstrasse 157','Zürich','','SWITZERLAND','8050','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:48:03',0,NULL,3,1,4,1,'YW867661750CN ','bmd_02\r▲'),(19803,751371882001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','bollero4','vtuske@yahoo.com','Veronika Studer-Tüske','Jurablick 1','Safenwil','Aargau','SWITZERLAND','5745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:56:59',0,NULL,3,1,17,0,NULL,'bollero4'),(19804,751371619001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','bollero4','vtuske@yahoo.com','Veronika Studer-Tüske','Jurablick 1','Safenwil','Aargau','SWITZERLAND','5745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:57:00',0,NULL,3,1,17,0,NULL,'bollero4\r'),(19805,751187663001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',59.98,'hermeshine','bollero4','vtuske@yahoo.com','Veronika Studer-Tüske','Jurablick 1','Safenwil','Aargau','SWITZERLAND','5745','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 09:57:00',0,NULL,3,1,4,1,'YW867661761CN ','bollero4\r150-200cm 5in1 反光板     1\r反光板 110cm 5合1      1      \r反光板支架      2\r燕文一票两件   \r两个反光板支架一起  其余的一起 '),(19806,754739809018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',2,'AD1116',9,'photographyacc','ncoo2937','nicolecooperphotography@live.com.au','Nicole Cooper','39/30-34 Greenoaks Ave ','Cherrybrook','New South Wales','AUSTRALIA','2126','0299806172','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 10:05:10',0,NULL,3,1,2,1,NULL,'ncoo2937'),(19807,754739427018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','killigurl','oliversfam@gmail.com','kylie oliver','140 myall rd','cardiff','New South Wales','AUSTRALIA','2285','0249542653','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 10:06:18',0,NULL,3,0,2,1,NULL,'killigurl\r灰色'),(19808,751390408001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','sally_shepherd','gavinsally@internode.on.net','Sally Shepherd','4 Koolinda Street','Warana','Queensland','AUSTRALIA','4575','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 10:57:46',0,NULL,3,1,2,1,NULL,'sally_shepherd'),(19809,751432939001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','viong','jhenault@cgocable.ca','Jean-Pierre Henault','501 Turcotte','Drummondville','QC','CANADA','J2C 4C5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 13:12:34',0,NULL,3,1,2,1,NULL,'viong'),(19810,751445573001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','pepesz','pakula38@zonnet.nl','Lukasz  Pakula','Mekelweg 4, EWI/EI, HB13.130','Delft','','NETHERLANDS','2628CD','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 13:47:15',0,NULL,3,1,3,1,' RA184579139CN\r','pepesz'),(19811,754852729018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','wideye138','jhokm@yahoo.com','Jason Ho','Level 2, Prima 8<br>Jalan Teknokrat 6','Cyberjaya','Selangor','MALAYSIA','63000','0383215629','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 15:19:31',0,NULL,3,1,17,0,NULL,'wideye138'),(19812,752347036018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','mbarb64','m.barbuto@mattbarbuto.com','matt barbuto','1615 genesee st','utica','NY','UNITED STATES','13501-4745','(315) 292-3007','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 15:22:06',0,NULL,3,1,1,1,NULL,'mbarb64'),(19813,812088941017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'AKT081',28,'photographyacc','wideye138','jhokm@yahoo.com','Jason Ho','Level 2, Prima 8<br>Jalan Teknokrat 6','Cyberjaya','Selangor','MALAYSIA','63000','0383215629','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 15:26:30',0,NULL,3,1,3,1,'RA184578408CN ','wideye138\r除了c 里面的再发\r9个环+两种托架'),(19814,751490416001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',2,'AA2101',72,'hermeshine','hurtube','jacques@jacqueshurtubise.com','Jacques Hurtubise','5210 de la Fabrique','Laval','QC','CANADA','h7c1e6','(450) 661-7014','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-12 15:37:45',0,NULL,3,0,3,1,' RA184579187CN\r','hurtube\r3XL  已入库   两件 '),(19815,794214910002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','allmarvin22','msul1@um.edu.mt','Marvin Sultana','Faculty for the Built Environment Building<br>University of Malta','Msida','','MALTA','MSD 2080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 15:59:48',0,NULL,3,1,2,1,NULL,'allmarvin22'),(19816,812119629017,270781061513,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',158,'photographyacc','tonito2806','aantonii@telefonica.net','Antonio de la Peña','Comuneros de castilla 21 9ºA','Burgos','Burgos','SPAIN','09006','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 16:26:21',0,NULL,3,1,4,1,'YW867661735CN ','tonito2806\r▲'),(19817,794251344002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',29.98,'hermeshine','hadarberl','quater4@walla.co.il','Hadar Berl','Ha-Alonim 8/2','Kiryat Bialik','','ISRAEL','27212','0525705332','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-12 17:22:55',0,NULL,3,1,2,1,NULL,'hadarberl'),(19818,887468027015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','duffybear1988','duffybear@hotmail.co.uk','Adam Harris','12 Tudor Way','Bridgwater','Somerset','UNITED KINGDOM','TA6 6UE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-12 19:10:12',0,NULL,3,1,2,1,NULL,'duffybear1988'),(19819,887468983015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','8andon8','ka_r_a@hotmail.com','Kalle Anteroinen','Hakapellonkatu 4 F 84','Turku','','FINLAND','20540','+358451126957','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-12 19:11:56',0,NULL,3,1,4,1,'YW867661746CN ','8andon8\r蓝色布 欧标\r▲'),(19820,751631251001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','de1970','yukseluyan@hotmail.com','Yüksel UYAN','Güçlükaya Mah. Ezine Sok. 23/22','Keçiören-Ankara','','TURKEY','6310','9005424062991','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-12 19:53:59',0,NULL,3,1,5,1,'CP238126774CN ','de1970\r黑+白 '),(19821,794357075002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','accura31','accurakirk@ymail.com','Irnie Dave Obias','Sabal Hospital Room #120, Velez Street, Cagayan de Oro City 9000','Cagayan de Oro City','','PHILIPPINES','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-12 20:14:14',0,NULL,3,1,2,1,NULL,'accura31'),(19822,887527149015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','mosapuh954','yassems@gmail.com','Yass y Monica','C/ Maria Luisa 29 Atico C','Blanes','Girona / Catalunya','SPAIN','17300','619643056','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-12 20:40:23',0,NULL,3,1,3,1,' RA184579125CN\r','mosapuh954'),(19823,755061753018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','laserfreak0815','mystique2404@hotmail.de','Martin Aigner','Gartenstr. 11','Grasbrunn/Neukeferloh','','GERMANY','85630','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-12 21:44:34',0,NULL,3,1,3,1,' RA184572949CN\r','laserfreak0815'),(19824,812356664017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','shaunmailbox2008','shaunmailbox@gmail.com','shaun treble','601/38 college st','darlinghurst','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-12 23:54:17',0,NULL,3,1,2,1,NULL,'shaunmailbox2008'),(19825,755128919018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','jcmh','jcmh@aol.com','James Howat','4557 Linden Ave','Long Beach','CA','UNITED STATES','90807','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 00:39:35',0,NULL,3,1,1,1,NULL,'jcmh'),(19826,8881321147757272,111,'套装',1,'',164,'hutongstore','krupi2','krupi2@pobox.sk','Peter Krupas','Brett Supplies Ltd.<br>130-131 Ashbourne ','Industrial Estate','Ashbourne, Meath','IRELAND','130-131','',NULL,NULL,NULL,'2011-11-13 01:29:17',0,NULL,5,0,18,0,NULL,NULL),(19827,8881321147858476,111,'套装',1,'AKT063',164,'hutongstore','krupi2','krupi2@pobox.sk','Peter Krupas','Brett Supplies Ltd.<br>130-131 Ashbourne ','Industrial Estate','Ashbourne, Meath','IRELAND','','',NULL,NULL,NULL,'2011-11-13 01:30:58',0,NULL,3,1,4,1,'YW867661713CN ','包括两块背景布  白 + 黑 \r英标\r▲'),(19828,8881321148364497,111,'50cm棚的包',1,'',0,'hutongstore','chseychell','info@aate.biz','Charlo Seychell','Fralaw, Triq ic-Cawsli<br>130-131 Ashbourne ','Qormi','-','MALTA','QRM3900','(+356) 9945 0624',NULL,NULL,NULL,'2011-11-13 01:39:24',0,NULL,3,0,3,1,' RA184579160CN\r',NULL),(19829,751774530001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','4tuliptulip4','allan44@tpg.com.au','allan mclean','74 nannatee way','wanneroo','Western Australia','AUSTRALIA','6065','0894054886','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 02:05:30',0,NULL,3,1,2,1,NULL,'4tuliptulip4'),(19830,887684973015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2101',25,'hutongstore','ninaringo','maga_elfa@yahoo.com.br','Marina Val Rafael','Rua dos  Sabias no. 12, Cond. Porto Alegre, ap 701 - Renascenca II','Sao Luis','MA','BRAZIL','65075-360','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 02:16:43',0,NULL,3,0,3,1,' RA184572921CN\r','ninaringo\r3XL  已入库'),(19831,8881321151601818,111,'2m 灯架',1,'AE3401',0,'photographyacc','chto72223','christer@torget2.se','Christer Tornkvist','Torget 2','STROMSHOLM','Vastmanland','SWEDEN','SE73494','+4622041194',NULL,NULL,NULL,'2011-11-13 02:33:21',0,NULL,3,1,3,1,' RA184579037CN\r',NULL),(19832,755162901018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','littlebit_beth1975','littlebit_beth@yahoo.com','Beth Nemeth','454 Montrose Ave','Kalamazoo','MI','UNITED STATES','49001-4224','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 02:47:39',0,NULL,3,0,1,1,NULL,'littlebit_beth1975\rxxl  已入库'),(19833,812420940017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',21.5,'photographyacc','gusandjenroberts','justin@jrobertsphotography.com.au','Justin Roberts','19 Connemara Ave<br>Killarney Heights','Sydney','New South Wales','AUSTRALIA','2087','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-13 03:10:43',0,NULL,3,1,3,1,' RA184579010CN\r','gusandjenroberts'),(19834,755194661018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','ericknewart','contatoerickrochalocutor@gmail.com','Erick Rocha','rua: Minoro Sakassegawa,231<br>Conj. Nova Esperança','Nova Esperança','Paraná','BRAZIL','87600-000','(+55) 44 3252 7285','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 05:08:11',0,NULL,3,1,3,1,' RA184579195CN\r','ericknewart'),(19835,755226165018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','shasha-group','shaanchristy@hotmail.com','Sohail Zeeshan','601 Woodland Mills Dr','Seaford','DE','UNITED STATES','19973-1546','(302) 249-1045','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 07:55:52',0,NULL,5,1,18,0,NULL,'shasha-group'),(19836,749975760001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','mr.pastukhov2009','mr.pastukhov@gmail.com','Pavel O. Pastukhov','Novozhilova Street, 29-14','Vladivostok','Primorsky Territory, Russia','RUSSIAN FEDERATION','690011','+7(914)705-4541','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 08:22:29',0,NULL,3,1,5,1,'CP238126788CN ','mr.pastukhov2009'),(19837,812510536017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','jac111256','jacondello@netspace.net.au','Julie Condello','49 Temple Drive','Thomastown','Victoria','AUSTRALIA','3074','0392400434','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-13 09:30:05',0,NULL,3,1,4,1,'YW867661724CN ','jac111256\r澳标\r▲'),(19838,794602469002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','assojuancarlos','iptajc@coitiar.es','Juan Carlos Martinez Beleret','Cmno de las Torres 11','Zaragoza','Aragón','SPAIN','50008','609968798','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 09:43:55',0,NULL,3,1,2,1,NULL,'assojuancarlos'),(19839,751901241001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','gervento','solyger@gmail.com','Geroni Vento Marco','avg de l`horta nº23 pª21','alboraia','Comunidad Valenciana','SPAIN','46120','616955560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 10:36:17',0,NULL,3,1,2,1,NULL,'gervento'),(19840,751833664001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','frodeloe','frode.loe@ntebb.no','Frode Løe','Nedre Bakkevei 7','Steinkjer','','NORWAY','7713','91820830','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-13 10:41:11',0,NULL,3,1,3,1,' RA184579023CN\r','frodeloe'),(19841,869642000016,260768456440,'New 77mm Lenscap for Nikon Lens Snap-on 77  Front Cap',1,'AA1309',1.87,'hutongstore','jamesandjames11','peterjamesjames@yahoo.co.uk','Peter Sidebotham','212a<br>Haverstock Hill','London','London','UNITED KINGDOM','NW32AE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 11:31:08',0,NULL,3,1,2,1,NULL,'jamesandjames11'),(19842,755351783018,280666794780,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',19.99,'photographyacc','rerskine89','rachael_erskine89@hotmail.com','Rachael Erskine','1 Durham Street','Henley Beach','South Australia','AUSTRALIA','5022','0883536000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-13 12:56:22',0,NULL,3,1,3,1,' RA184579108CN\r','rerskine89'),(19843,887933365015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','sarahlou205','sarah205@live.co.uk','sarah lockyer','3 Writhlington Court, Frome Road<br>Writhlington, Radstock','Bath','Avon','UNITED KINGDOM','BA3 3PF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 13:05:57',0,NULL,3,1,3,1,' RA184579099CN\r','sarahlou205'),(19844,752002511001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','krisztian.takacs','krisztian.takacs.77@gmail.com','Krisztian Takacs','Nepfurdo u. 15/b V.em 25','Budapest','Budapest','HUNGARY','1138','+36302029410','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 14:08:18',0,NULL,3,1,2,1,NULL,'krisztian.takacs'),(19845,752011950001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','bluebluerock65','siehartley@yahoo.com','Simon Hartley (Private) c/o J Heebink UK','Unit 9 Westpoint Enterprise Park<br>Clarence Avenue, Trafford Park','Trafford Park','Greater Manchester','UNITED KINGDOM','M17 1QS','01618724971','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 14:25:50',0,NULL,3,0,2,1,NULL,'bluebluerock65\r黑  '),(19846,812681592017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','iflyhigher','iflyhigher@msn.com','Calvin B. Scholten','10184 Gillespie Oak Dr','Lakeland','TN','UNITED STATES','38002','(901) 277-2791','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 14:54:43',0,NULL,3,1,1,1,' ','iflyhigher'),(19847,755450213018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','kmoo3159','kmoore48831@gmail.com','KATHRYN MOORE','220 N 1ST ST','ELSIE','MI','UNITED STATES','48831','(989) 862-5377','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 15:46:17',0,NULL,5,0,18,1,' ','kmoo3159\rxxl    已入库'),(19848,794790495002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','js6571','js6571@yahoo.com','jamshed sani','3648 S SETON AVE','gilbert','AZ','UNITED STATES','85297','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-13 15:55:32',0,NULL,3,1,1,1,NULL,'js6571'),(19849,755461324018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','siammutz','eberhard_diana@yahoo.de','Diana Eberhard','Rietstrasse 1','Maseltrangen','','SWITZERLAND','8723','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 16:02:28',0,NULL,3,1,2,1,NULL,'siammutz'),(19850,794805036002,120482516915,'New YONGNUO LCD Timer Remote Control for Canon RS-60E3',1,'AA3221',45.9,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454010','8-951-488-9340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 16:27:34',0,NULL,3,1,3,1,' RA184579071CN\r','galaher57'),(19851,752168447001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','gloggnitz0','k.samitsch@aon.at','Karl Samitsch','Rosenhügelgasse 8','Gloggnitz','','AUSTRIA','2640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 17:54:58',0,NULL,3,1,2,1,NULL,'gloggnitz0'),(19852,888224061015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',22,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-13 18:32:17',0,NULL,3,1,17,0,NULL,'shayanshiraz'),(19853,869978960016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 18:32:18',0,NULL,3,1,17,0,NULL,'shayanshiraz'),(19854,794931689002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',5,'AKT051',57.5,'hermeshine','igrom78','igromv@gmail.com','Ilya Gromyko','10 Komsomolskaya Str. App. 74','Gostilicy','Leningradskaya obl','RUSSIAN FEDERATION','188520','+79062678380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 18:31:59',0,NULL,3,1,3,1,' RA184579085CN\r','igrom78\r10只'),(19855,869978149016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-13 18:32:18',0,NULL,3,1,5,0,'CP238126757CN ','shayanshiraz\r欧标    除了c 里面的再发\r115w 5500k 灯泡  220v    2\r反光板  80cm 5合1       1\r一转四 灯头     2'),(19856,888213691015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 18:32:19',0,NULL,3,1,17,0,NULL,'shayanshiraz'),(19857,888213182015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','shayanshiraz','shiraz.iqbal@live.no','shiraz iqbal','karl Andersensveien 137','oslo','','NORWAY','1086','95966405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-13 18:32:20',0,NULL,3,1,17,0,NULL,'shayanshiraz'),(19858,755609213018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','mountainbikeguy1','info@applesonpress.com','Kenneth Sands','25 Tacoma Ln','Syosset','NY','UNITED STATES','11791-6232','(516) 496-0004','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 18:38:32',0,NULL,3,1,1,1,NULL,'mountainbikeguy1'),(19859,812879745017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','stas-fomin','stanislav.fomin@gmail.com','Stanislav Fomin','PO Box  692, Glavpochtampt, Myasnitskaya 26','Moscow','','RUSSIAN FEDERATION','101000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-13 18:38:54',0,NULL,3,1,3,1,' RA184579173CN\r','stas-fomin\r欧标  '),(19860,794963967002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','pjwd54','pjdowney@ciaccess.com','Patrick Downey','box 252<br>14 galbraith Ave','Erieau','ON','CANADA','n0p 1n0','(519) 676-3745','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 18:57:24',0,NULL,3,1,2,1,NULL,'pjwd54'),(19861,870161051016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','redphreddy','phoenix10is@hotmail.co.uk','Phred Russell','21 Durham Road','Charfield','Gloucestershire','UNITED KINGDOM','GL12 8TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 20:38:29',0,NULL,3,1,3,1,'RA260122347CN\r\r','redphreddy\rRA184579045CN 换单重发 新单号RA260122347CN'),(19862,795094769002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',3,'AKT055',189,'hermeshine','bayekulabigboss','concert2011@hotmail.ca','BAYEKULA  KADIANGA','2861 BAYCREST DR. #1906','OTTAWA','ON','CANADA','K1V8X8','(613) 216-9625','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 21:08:25',0,NULL,3,1,5,1,'CP238126765CN ','bayekulabigboss\r灯泡是110v 的   放欧转美标'),(19863,888424886015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','brugaldominicano','brugaldominicano@yahoo.it','Felix Omar Ferrario','Piazza Salvador Allende n.3','Malnate','VA','ITALY','21046','3484927034','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-13 21:18:24',0,NULL,3,1,3,1,' RA184579054CN\r','brugaldominicano'),(19864,795147105002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nazar.y92','ha3ar@ua.fm','Nazar Yurystovskyy','Kulparkivska 162/30','Lviv','','UKRAINE','79021','+380938399528','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-13 22:26:29',0,NULL,3,1,2,1,NULL,'nazar.y92'),(19865,888536259015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','happy-knight','des.robinson@ntlworld.com','Mr. D. Robinson','12 Shepherd Close,<br>Thornaby,','Stockton on Tees,','Cleveland','UNITED KINGDOM','TS17 8QB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-13 23:41:27',0,NULL,3,1,2,1,NULL,'happy-knight'),(19866,755888063018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','amirul_rahimi_ahmad','amirul.rahimi@gmail.com','Amirul Rahimi Ahmad','3/205 Waterloo Road','Marsfield','New South Wales','AUSTRALIA','2122','61433004331','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-14 01:00:43',0,NULL,3,1,2,1,NULL,'amirul_rahimi_ahmad'),(19867,8881321235138332,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',26.99,'aliexpress','1005207322','-@-.com','Sergey Chernikov	','ul. Shumilova 15/4, str.1, kv.20','Moscow','Moscow','RUSSIAN FEDERATION	','109378','+7 926 3696193',NULL,NULL,NULL,'2011-11-14 01:45:38',0,NULL,3,1,3,1,' RA184572918CN\r',NULL),(19868,8881321235434957,111,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',5.99,'aliexpress','1005221553','dgool@mail.ru','Dmitry Gool	','pionerskaya 20','leninogorsk','tatarstan','RUSSIAN FEDERATION	','423254','+7 917 3996215',NULL,NULL,NULL,'2011-11-14 01:50:34',0,NULL,8,1,17,0,' ',NULL),(19869,8881321235768331,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m',1,'AE2501',25.99,'aliexpress','1005221673','dgool@mail.ru','Dmitry Gool	','pionerskaya 20','leninogorsk','tatarstan','RUSSIAN FEDERATION	','423254','+7 917 3996215',NULL,NULL,NULL,'2011-11-14 01:56:08',0,NULL,3,1,3,1,' RA184573003CN\r','反光板支架 * 1\r灯架包薄  * 1\r '),(19870,8881321236076885,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m',1,'AE2501',25.99,'aliexpress','1005232035','anton@kraska66.ru','Anton Batanin	','Rassvetnaya st. 13-320','Ekaterinburg','Sverdlovskaya oblast	','RUSSIAN FEDERATION	','620072','+7 343 2633182',NULL,NULL,NULL,'2011-11-14 02:01:16',0,NULL,3,1,3,1,'RA184572983CN\r ',' '),(19871,8881321237812545,111,'5灯头',1,'AD1191',0,'photographyacc','infrcs','morjanoff@yahoo.com.au','Paul Morjanoff','13 Elizabeth St Avalon','Sydney','New South Wales','AUSTRALIA','2107','0299188647',NULL,NULL,NULL,'2011-11-14 02:30:12',0,NULL,3,1,3,1,' RA184572952CN\r','只发灯头，不发棚\r另外，放5个115w灯泡上去测试一下 '),(19872,8881321238618589,111,'NG128 配件',1,'AB3304',0,'hermeshine','celtic_flowerchild','flowerchildgypsy@yahoo.com.au','Ian Campbell','3 Armstrong Ave','Parafield Gardens','South Australia','AUSTRALIA','5107','0421796655',NULL,NULL,NULL,'2011-11-14 02:43:38',0,NULL,3,1,3,1,'RA184579227CN ','我来 '),(19873,8881321239326108,111,'2m灯架底座',1,'',0,'hermeshine','skorpions2k','ev.safronov@gmail.com','Evgeniy Safronov','Batova, 9-17','Volgograd','RU','RUSSIAN FEDERATION','400015','',NULL,NULL,NULL,'2011-11-14 02:55:26',0,NULL,3,1,3,1,' RA184572997CN\r',NULL),(19874,795278741002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','doobooguy','doobooguy@yahoo.com','Seowoo Lee','3839 213th St<br>Apt 1','Bayside','NY','UNITED STATES','11361-2027','(917) 575-8003','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-14 03:56:16',0,NULL,3,1,1,1,NULL,'doobooguy'),(19875,755980065018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','alannamary92','elly_lou_1994@hotmail.com','Alanna Christeson','Lot 8 Old Coach Rd','Woodstock','Queensland','AUSTRALIA','4816','0747788524','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-14 06:22:49',0,NULL,3,1,4,1,'YW867661853CN ','alannamary92\r白布 ▲'),(19876,795331212002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',25.98,'hermeshine','chaotenjupp','mdahler@web.de','Michael Dahler','Andreas-Hofer-Str.27','Pirmasens','','GERMANY','66954','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-14 08:10:08',0,NULL,3,1,17,0,NULL,'chaotenjupp'),(19877,870487735016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','ston821123','tony.hickey1@googlemail.com','tony Hickey','4 Curtis Road','Ewell','Surrey','UNITED KINGDOM','KT19 0LG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 09:00:49',0,NULL,3,1,2,1,NULL,'ston821123'),(19878,795349714002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jerwinpuzon','jerwinpuzon@yahoo.com','Jeoffrey Erwin Puzon','44 Laurel St.','Baguio City','none','PHILIPPINES','2600','9156000086','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 09:27:30',0,NULL,3,1,2,1,NULL,'jerwinpuzon'),(19879,888742716015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','lisaw1338','lisa.wilkins2@fsmail.net','Lisa Wilkins','21 Waterloo Avenue','Basingstoke','Hampshire','UNITED KINGDOM','RG238DL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-14 09:29:37',0,NULL,3,1,4,1,'YW867660534CN ','lisaw1338 \r黑加白\r▲'),(19880,789575011002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-14 10:00:30',0,NULL,3,1,3,1,'RA184579805CN\r ','saud-p\r分开发\r贴made in china  \r申报实值lighting kit  $128\rRA184579712CN\rRA184579726CN\r'),(19884,752649085001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','2011borisov','paypal_ebay_by@yahoo.com','VIKTAR HAURYLIUK','ul. Parkovaya 4','Borisov','Minskaya oblast','BELARUS','222518','375 17 77 762651','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 11:12:44',0,NULL,3,1,3,1,'RA184579845CN\r ','2011borisov'),(19881,795364080002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','branimirfrankavita','branimir.kralj@zg.t-com.hr','Branimir Kralj','Dubrava 41','Zagreb','','CROATIA','10040','00385992525244','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 10:22:16',0,NULL,3,1,3,1,'RA184579765CN\r ','branimirfrankavita'),(19882,795365785002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','chaotenjupp','mdahler@web.de','Michael Dahler','Andreas-Hofer-Str.27','Pirmasens','','GERMANY','66954','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 10:25:10',0,NULL,3,1,3,1,'RA184579774CN\r ','chaotenjupp\r柔光伞110cm      2\r反光伞110cm      1'),(19883,8881321267475550,111,'45w  220v',1,'',0,'hermeshine','ya_maska09','ya_maska@hotmail.com','Oksana Iskusnova','st. B.Galushkina, 17-317','Moscow','','RUSSIAN FEDERATION','129301','8-916-353-35-42',NULL,NULL,NULL,'2011-11-14 10:44:35',0,NULL,3,0,3,1,'RA184579828CN\r ',NULL),(19885,752648977001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',59.98,'hermeshine','david20737','davidwhittet@xtra.co.nz','David Whittet','147 Settlement Road','Kurow','North Otago','NEW ZEALAND','9435','+6421344107','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 11:19:12',0,NULL,3,1,3,1,'RA184579791CN\r ','david20737\r10个'),(19886,812333290017,270833010437,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','ysoyipek','yusuf@soyipek.com','Omer Sarikaya','19. Mayis Bulvari<br>No 77 Kat 1','Ankara','Mamak','TURKEY','06270','(312) 372 - 1900','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 12:49:39',0,NULL,3,1,2,1,' ','ysoyipek'),(19887,752680480001,110417009256,'NIB TianYa 77mm ND8 filter New 77 Neutral Density Grey',1,'AA2314',7.4,'hermeshine','tweakmax2','cho99481@singnet.com.sg','Cho Jason','Blk 302D Punggol Place<br>#05-213','default','','SINGAPORE','824302','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 12:53:09',0,NULL,3,1,11,1,NULL,'tweakmax2'),(19888,752704695001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','joshmate','joshei_yeahyeah@yahoo.com.au','joshua woning','91 Richmond St, Gordon Park','brisbane','Queensland','AUSTRALIA','4031','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-14 14:02:42',0,NULL,3,1,2,1,NULL,'joshmate'),(19889,795442065002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pieme30','malletprospective@free.fr','Patrick MALLET','BP 21422, 4 rue Deyron','NIMES cédex 1','Gard','FRANCE','30017','0621150018','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-14 14:25:09',0,NULL,3,0,3,1,'RA184579831CN\r ','pieme30\rL  已入库'),(19890,888899960015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','dennisl37','dennis.g0fbr@btinternet.com','dennis lockwood','4 cairnfechel cottages<br>udny green','ellon','Aberdeenshire','UNITED KINGDOM','AB41 6ST','01651842799','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 15:52:35',0,NULL,3,1,2,1,NULL,'dennisl37'),(19891,870659712016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','yar.d.zull','trollsama@gmail.com','Yaroslav Marchenko','Izmailovsky proezd 22-1-15','Moscow','Moscow','RUSSIAN FEDERATION','105037','89629923237','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-14 16:06:36',0,NULL,3,1,5,1,'CP238126712CN ','yar.d.zull\r欧标'),(19892,813509485017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','bdaf6887','bdafonseca@otop-interactive.com','Bruno Da Fonseca','Otop Interactive<br>15 place Henri Neveu','Colombes','Île-de-France','FRANCE','92700','06.70.71.56.39','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 17:30:10',0,NULL,3,1,2,1,NULL,'bdaf6887'),(19893,752803530001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','levymask0','levymask@gmail.com','Levy Alvares Melo','AV. C255 Quadra 588 Lote 4/8 N.270<br>Ed. Centro Empresarial Sebba. SALA 1112','Goiânia','Goiânia-GO','BRAZIL','74280010','62 84243671','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 17:54:51',0,NULL,3,1,3,1,'RA184579859CN\r ','levymask0'),(19894,752814719001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','anya_ab','abramovy@mksat.net','serg abramov','31, Novoselskaya str.','Nikolaev','Nikolaev region','UKRAINE','54002','+380677902355','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 18:11:50',0,NULL,3,1,5,1,'CP238126726CN ','anya_ab'),(19895,752891175001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','mowtowmike','mike@laserbits.com','mike fruciano / LaserBits','24410 N 20th Dr','Phoenix','AZ','UNITED STATES','85085-1316','(623) 879-0005','NoPaymentFailure','CheckoutComplete','Other','2011-11-14 20:11:47',0,NULL,3,1,1,1,NULL,'mowtowmike'),(19896,752908415001,110462204958,'Continuous Lighting System：light stand/bulb holder/um',1,'AKT009',60,'hermeshine','gazkin1','gazkin@googlemail.com','Gary Kinnair','42 Sorley Street<br>Millfield','Sunderland','Tyne and Wear','UNITED KINGDOM','SR4 7UU','07931690863','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-14 20:40:15',0,NULL,3,1,4,1,'YW867660545CN\r ','gazkin1\r英标\r▲'),(19897,756319876018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','wleying','leying.wang@gmail.com','wang leying','via Pieragostini 62 C divertimento Fiumara','genova','GE','ITALY','16151','3393393878','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 20:40:52',0,NULL,3,1,3,1,'RA184579788CN\r ','wleying'),(19898,889129222015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','d_prokopas','prokopas@gmail.com','PROKOPIOS DROGARIS','Menelaou 54','Sparti','Lakonias','GREECE','23100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-14 21:10:20',0,NULL,3,1,2,1,NULL,'d_prokopas'),(19899,752927790001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','iinfinity88','summersurfer@msn.com','jules phillips','6/2 dudley st','Balgowlah','New South Wales','AUSTRALIA','2093','0416003007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-14 21:13:17',0,NULL,3,1,2,1,NULL,'iinfinity88'),(19900,813703985017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','avokitorod','marti3na@yahoo.co.uk','Martina Dorotikova','53 Seymout Court<br>Colney Hatch Lane','London','London','UNITED KINGDOM','N10 1ED','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-14 22:46:26',0,NULL,3,1,2,1,NULL,'avokitorod'),(19901,795709517002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','cft555','cft556@walla.co.il','RAFAEL K','shani 34/1','modi\'in','','ISRAEL','71726','97289759959','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-14 22:51:37',0,NULL,3,1,3,1,'RA117766726CN\r','cft555\rRA184579902CN\r之前漏发了沙袋 补发一个'),(19902,752985581001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','cklatt7','cklatt@xplornet.com','Crystal Klatt','Box 33 Site 201 RR#2','Stony Plain','AB','CANADA','T7Z 1X2','(780) 709-7677','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-14 23:21:15',0,NULL,3,1,5,1,'CP238126709CN ','cklatt7\r黑+白'),(19903,795737902002,120701787289,'GGS Glass LCD Screen Protector for Nikon D90 ',1,'AB2212',7.6,'hermeshine','woxter1962','franduranpe@gmail.com','FRANCISCO DURAN PELAEZ','AVDA. ROSA REGAS 7  1º B','GETAFE','Madrid','SPAIN','28907','914912045','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 00:08:55',0,NULL,3,1,2,1,NULL,'woxter1962'),(19904,813739631017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',3.88,'photographyacc','keeper1770','keeper@lighthaus.com.au','Lighthaus creative Pty Ltd','PO Box 1884<br>Toowong BC','Brisbane','Queensland','AUSTRALIA','4066','0738708200','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 00:21:32',0,NULL,3,1,2,1,NULL,'keeper1770'),(19905,870985567016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','elin_79','info@davidappelgren.se','David Appelgren','Nybohovsbacken 81','Stockholm','','SWEDEN','117 64','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 00:38:51',0,NULL,3,1,3,1,'RA184579814CN\r ','elin_79'),(19906,813766460017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',5.69,'photographyacc','mrberry10','mrberry10@exemail.com.au','Michael Berry','PO Box 90','Glenfield','New South Wales','AUSTRALIA','2167','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 01:43:06',0,NULL,3,1,2,1,NULL,'mrberry10'),(19907,8881321321582974,111,'Photo Studio Background Support Carrying Carry Bag',3,'AD1129',17.97,'aliexpress','1005251242','-@-.com','Johan Olsson	','Ingegatan 2L','Kungalv','Vastragotaland','SWEDEN','442 37','46769260700',NULL,NULL,NULL,'2011-11-15 01:46:22',0,NULL,3,1,3,1,'RA184578310CN ',NULL),(19908,756467452018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','bundyrvs','ben@bundyrvs.com.au','Ben Searle','23 Phoebe Crst','Bundaberg','Queensland','AUSTRALIA','4670','0741513000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 03:04:06',0,NULL,3,1,2,1,NULL,'bundyrvs'),(19909,756467434018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',102,'photographyacc','beachesjon107','horizon147@hotmail.com','Jon Vidler','2 Grandview Drive','Newport Beach','New South Wales','AUSTRALIA','2106','020416156172','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 03:04:09',0,NULL,3,1,4,1,'YW867660556CN ','beachesjon107\r▲'),(19910,795813982002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','whiskerkiss','omniroot@gmail.com','ruth Root','81 Walker St<br>Fl 3','NEW YORK','NY','UNITED STATES','10013-3566','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-15 04:28:02',0,NULL,3,1,1,1,NULL,'whiskerkiss'),(19911,753097358001,110462204958,'Continuous Lighting System：light stand/bulb holder/um',1,'AKT009',60,'hermeshine','magellan_organization','colclasureda@yahoo.com','Daniel Colclasure','Viset Road<br>22/11 Soi Naya, Moo 1','Rawai','Phuket','THAILAND','83130','(668) 004-1183 ext.: 9','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 06:46:56',0,NULL,3,1,6,1,'EE645619170CN ','magellan_organization'),(19912,887117847015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','rocifoto01','rocifoto@citromail.hu','Balogh Roland','Előre<br>utca 2','Dunapataj','Bács-Kiskun','HUNGARY','6328','+36703375385','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 06:51:29',0,NULL,3,1,3,1,'RA184578133CN ','rocifoto01'),(19913,889351001015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','joker818181','gideon616@hotmail.com','Peter Lennox','18 Eastburn Gardens','Gateshead','Tyne and Wear','UNITED KINGDOM','NE10 0RN','01914402718','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 06:52:09',0,NULL,3,1,3,1,'RA184578120CN ','joker818181'),(19914,795866117002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','mrsbml09','blivingstone@internode.on.net','Barbara Livingstone','42 Timbertop Drive','Rowville','Victoria','AUSTRALIA','3178','0397901925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 08:43:26',0,NULL,3,1,2,1,NULL,'mrsbml09'),(19915,756548966018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','dfit3763','daniel.fitzgerald@gvi.com.au','Daniel Fitzgerald','16 Swan St<br>North Hobart','Hobart','Tasmania','AUSTRALIA','7000','61418860988','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 09:17:51',0,NULL,3,1,4,1,'YW867661691CN ','dfit3763\r▲'),(19916,813884288017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','eezy2see','dontcallmesharon@yahoo.com','Sandra Greed','57 Coish Ave.','Benalla','Victoria','AUSTRALIA','3672','0411296087','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 09:32:33',0,NULL,3,1,17,0,NULL,'eezy2see'),(19917,813886611017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','eezy2see','dontcallmesharon@yahoo.com','Sandra Greed','57 Coish Ave.','Benalla','Victoria','AUSTRALIA','3672','0411296087','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 09:40:52',0,NULL,3,1,2,1,NULL,'eezy2see\r肩带 canon      2'),(19918,753150398001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','vanila_bellina','irsen2005@mail.ru','Pinaev Nikolaj Vladimirovich','Schepkina street 23/30','Rybinsk','Yaroslavl region','RUSSIAN FEDERATION','152919','+79159986666','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 10:29:02',0,NULL,3,1,3,1,'RA184578385CN ','vanila_bellina\r欧标'),(19919,753150883001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','agerbak.dk','john@agerbak.dk','John Agerbak','Solvænget 14','Sæby','Danmark','DENMARK','9300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 10:31:21',0,NULL,3,1,2,1,NULL,'agerbak.dk'),(19920,753155395001,110618891254,'Pro Photo Vest for Canon 450D 500D 550D 7D 60D  user',1,'AA2120',32,'hermeshine','psyco_ivan','psycoivan@gmail.com','Manuel Vilches Nieto','C/Paraiso 21','Granada','Andalucía Ceuta y Melilla','SPAIN','18008','670415234','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 10:49:10',0,NULL,3,0,3,1,'RA184578297CN ','psyco_ivan\r2XL已入库'),(19921,889429382015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','tortik_tanya','t.y.efremova@hotmail.com','Tatyana Efremova','ul. Kadikova, 30-352','Cheboksary','Chuvashia','RUSSIAN FEDERATION','428037','8-903-064-90-01','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 11:13:20',0,NULL,3,1,2,1,NULL,'tortik_tanya'),(19922,813914168017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',3,'AA1310',17.85,'photographyacc','glomp','ameb@icecubefire.com','Anderson Miller','PO Box 226','Northbridge','Western Australia','AUSTRALIA','6865','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 11:13:56',0,NULL,3,1,2,1,NULL,'glomp'),(19923,889441556015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','*gsd15*','guinniesiaron@yahoo.com','Mary Guinnie Dasco','147 Russell court fr. Russell road<br>Raheen','Limerick','Limerick','IRELAND','','061210887','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 11:38:24',0,NULL,3,1,4,1,'YW867661702CN ','*gsd15*\r黑+白\r▲'),(19924,753175372001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','chalkkos030','chalkkos@gmail.com','KOSTAS CHALKIADAKIS','6, STERGIOGIANNI st.','HERAKLION CRETE','','GREECE','71305','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 12:04:10',0,NULL,3,0,3,1,'RA184578323CN ','chalkkos030\r黑+白  '),(19925,753205292001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','julija_diomina','julija.diomina@gmail.com','Julija Diomina','Savanoriu str. 27-18','Vilnius','','LITHUANIA','LT-03128','(370) 604 04 954','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 13:30:37',0,NULL,3,1,2,1,NULL,'julija_diomina'),(19926,753210322001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','hectorjuan1960','hbiocca@yahoo.com','Hector      J Biocca','Catamarca   1930     8 D','Mar del Plata','Buenos Aires','ARGENTINA','7600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 13:45:26',0,NULL,3,1,2,1,NULL,'hectorjuan1960'),(19927,871130061016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','eneas_williams','eneaswilliams@gmail.com','Eneas Williams','Vladmir Lenine<br>565, 3o, flat 10','maputo','Maputo','MOZAMBIQUE','01004','+258825363806','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-15 15:24:54',0,NULL,3,1,6,1,'EE495359525CN ','eneas_williams'),(19928,814003918017,270819648126,'New Profession​al Tripod Ball Head Camera Ballhead KS-0  + Quick Release Plate',1,'AD1186',32,'photographyacc','alihigg64alison','ahiggins@netspace.net.au','alison Higgins','2A Enid Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892931503','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 16:04:14',0,NULL,3,1,17,0,NULL,'alihigg64alison'),(19929,756672471018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',4.19,'photographyacc','alihigg64alison','ahiggins@netspace.net.au','alison Higgins','2A Enid Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892931503','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 16:04:15',0,NULL,3,1,17,0,NULL,'alihigg64alison'),(19930,814007035017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','alihigg64alison','ahiggins@netspace.net.au','alison Higgins','2A Enid Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892931503','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 16:04:15',0,NULL,3,1,17,0,NULL,'alihigg64alison'),(19931,756673897018,280671625895,'New Green.L Premium Quality 55mm UV Filter Canon Nikon ',1,'AA3302',3.2,'photographyacc','alihigg64alison','ahiggins@netspace.net.au','alison Higgins','2A Enid Road','Kalamunda','Western Australia','AUSTRALIA','6076','0892931503','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 16:04:16',0,NULL,3,1,3,1,'RA184578345CN ','alihigg64alison\rks-0 II （绿盒）     1\r绿叶 UV  67mm     1\r绿叶 UV  58mm       1\r绿叶 UV  55mm         1'),(19932,814027270017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','sontran56','sontran56@optusnet.com.au','Anthony Tran','64 Burwood Highway Burwood East','Melbourne','Victoria','AUSTRALIA','3151','0398333887','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 16:14:44',0,NULL,3,1,2,1,NULL,'sontran56'),(19933,753285329001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','hw4m','dgibiuh@yahoo.com','H.A.A. van Deventer','111/9 Moo 9<br>Pimanchon Villages 4','Khon Kaen','Khon Kaen','THAILAND','40000','043322396','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 16:55:20',0,NULL,3,1,6,1,'EE645619183CN ','hw4m\r黑+白'),(19934,753284260001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','sevaseagull','seagull@ubas.ru','Всеволод Истраткин','Башиловская, 23 к 2, 185','Москва','','RUSSIAN FEDERATION','127287','+7(962) 9295089','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 16:57:53',0,NULL,3,1,3,1,'RA184578442CN ','sevaseagull'),(19935,889600289015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','flash74chrism','mullers_1974foto-genics@hotmail.co.uk','Christopher Mulvaney','68 Blenheim Road','Clacton-on-Sea','Essex','UNITED KINGDOM','CO15 1DN','07584721481','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-15 17:19:26',0,NULL,3,1,4,1,'YW867661676CN ','flash74chrism\r黑+白 \r▲'),(19936,871368811016,260838264614,'New Large High quality heavy duty sand bag Empty',6,'AD1168',53.94,'hutongstore','jth*','ukjimmy@rocketmail.com','JAIME TRAVEZAN','36B WILSON ROAD','LONDON','London','UNITED KINGDOM','SE5 8PE','02077011266','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 17:59:49',0,NULL,3,1,3,1,'RA184578368CN ','jth*'),(19937,753327179001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','ghponies','jeannefick@yahoo.com','Jeanne Fick','PO Box 242','ALBERTINIA','','SOUTH AFRICA','6695','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 18:18:11',0,NULL,3,1,2,1,NULL,'ghponies'),(19938,753330475001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',2,'AE1603',71.8,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','+598 099639597','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 18:25:59',0,NULL,3,1,17,0,NULL,'pddl2010'),(19939,753330487001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','+598 099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 18:26:05',0,NULL,3,0,17,0,NULL,'pddl2010'),(19940,796076935002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','+598 099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 18:26:04',0,NULL,3,0,17,0,NULL,'pddl2010\rXL  已入库'),(19941,753330488001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pddl2010','uy.pablo@gmail.com','Javier Larramendy','Calle Mozart  Manzana M Solar 28','Villa Foresti, Las Piedras','Canelones','URUGUAY','90200','+598 099639597','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 18:26:06',0,NULL,3,0,5,1,'CP240320533CN ','pddl2010\r独脚架  伟峰 WT-1005     2 \r摄影背心 Canon  老款  XL     1\r摄影背心 Nikon 老款    2XL    1\r摄影背心 Nikon 老款    XL    1\r已入库'),(19942,753336981001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','c_r_croker','rccroker@netscape.net','Clayton R Croker','75 Wentworth Avenue','Sydney','New South Wales','AUSTRALIA','2000','0292121005','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 18:38:33',0,NULL,3,1,3,1,'RA184578425CN ','c_r_croker'),(19943,889653190015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','chriward1','chris-ward0911@hotmail.com','chris ward','58 cambridge rd','dorchester','Dorset','UNITED KINGDOM','dt1 2ls','01305265596','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 18:56:59',0,NULL,3,1,3,1,'RA184578266CN ','chriward1'),(19944,796117853002,120509024249,'Continuous Lighting System light stand/bulb holder/umbr',2,'AKT009',190,'hermeshine','torikwww','tor1k@bk.ru','Anton Gorbushin','Sodrugestva 86, kv.4','Rostov-na-Donu','Rostovskaya','RUSSIAN FEDERATION','344103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 19:34:16',0,NULL,3,1,5,1,'CP240320520CN ','torikwww\r注意是两套  \r欧标'),(19945,796165266002,120654661056,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','omega2eba','carmilagi@hotmail.com','--SINDEL--carlos latorre gimenez','Pol. Ind. El Tollo<br>Avda. Los Arrieros Parcela 21','utiel','Comunidad Valenciana','SPAIN','46300','962173553','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-15 20:48:03',0,NULL,3,0,3,1,'RA184578283CN\r ','omega2eba\r2XL  已入库'),(19946,889759767015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','1004swiftypaul','1004swifty@googlemail.com','paul swift','10 all saints close<br>goxhill','barrow on humber','Lincolnshire','UNITED KINGDOM','dn19 7ll','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-15 20:57:15',0,NULL,3,0,2,1,NULL,'1004swiftypaul\r黑色 '),(19947,756856713018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','acumedi','jaekim64@hotmail.com','jae kim','430 S Western Ave<br>Ste 102-A','Los Angeles','CA','UNITED STATES','90020-4173','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-15 21:05:08',0,NULL,3,1,1,1,' ','acumedi'),(19948,796190316002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','milanrush','harvey101@eircom.net','mark english','19 glen ellan court','swords','Dublin','IRELAND','default','018402357','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 21:30:19',0,NULL,3,1,2,1,NULL,'milanrush'),(19949,796231388002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 22:53:31',0,NULL,3,1,3,1,'RA184578399CN ','mariomarques.com.br\r476g'),(19950,796239442002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'',55,'hermeshine','dtsirsh','slepoglaz@gmail.com','Dmitrijs Cirss','Kr. Valdemara 143/4 - 79','Riga','Riga','LATVIA','LV1013','29732715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-15 23:19:30',0,NULL,3,1,3,1,'RA184578779CN\r ','dtsirsh\r新式皮包  nikon '),(19951,756936962018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','clintgando2010','clintgando@optusnet.com.au','clint ganderton','12 peppercorn place<br>kirrawee','sydney','New South Wales','AUSTRALIA','2232','0295287588','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-15 23:52:54',0,NULL,3,0,3,1,'RA184578456CN ','clintgando2010\r粉+蓝+红'),(19952,753517940001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','smithg5702','gsmith5702@gmail.com','George W. Smith','5702 Windmill Dr','Indianapolis','IN','UNITED STATES','46254-2314','(317) 294-6575','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-16 00:34:34',0,NULL,3,1,3,1,'RA184578439CN ','smithg5702\r1.257kg'),(19953,795956488002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','nef87','nefryt87@gmail.com','Tomasz Niemiec','8518 W Rascher Ave<br>Unit 5','Chicago','IL','UNITED STATES','60656-1313','(773) 822-1550','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 01:17:11',0,NULL,3,1,4,1,'YW867661680CN ','nef87\r灯泡是110v 的   \r放欧转美标头\r▲'),(19954,8881321406629976,111,'HB-7',5,'AA1216',0,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500',NULL,NULL,NULL,'2011-11-16 01:23:49',0,NULL,3,1,3,1,'RA184578371CN ',NULL),(19955,753536958001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 01:35:13',0,NULL,3,1,17,0,NULL,'bipede38'),(19956,8881321408438924,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included ',1,'AC2402',19.99,'aliexpress','1005263578','pongtawee2529@gmail.com','pongtawee khotsena	','146/18 Sukhumvit71. Klong Toey.','Wattana','Bangkok','THAILAND','10110','+66 850 449150',NULL,NULL,NULL,'2011-11-16 01:53:58',0,NULL,3,1,3,1,'RA184578796CN\r ',NULL),(19957,753539332001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 01:54:33',0,NULL,3,1,3,1,'RA184578354CN ','bipede38\r牛津布大包       1\r反光板支架     1\r'),(19958,796295639002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','4226chris','chris.stewart@covidien.com','chris stewart','1797 Crowbridge Dr','frisco','TX','UNITED STATES','75034-1474','(972) 814-1469','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 01:54:42',0,NULL,5,1,18,0,NULL,'4226chris'),(19959,8881321409825246,111,'110CM 柔光伞',1,'AD1125',0,'photographyacc','colasli7','colasli@gmail.com','Nicolas Li','PO BOX 4566<br>Robina Town Centre','Robina','Queensland','AUSTRALIA','4230','0412713068',NULL,NULL,NULL,'2011-11-16 02:17:05',0,NULL,3,1,3,1,'RA184578337CN ','打开检查一下再发 '),(19960,796310560002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','conti512','conti534@yahoo.com.au','Marin Costica','3/268 Grand Promenade<br>Dianella','Perth','Western Australia','AUSTRALIA','6059','0404142880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 02:38:28',0,NULL,3,1,3,1,'RA184578270CN ','conti512\r1.215kg'),(19961,753556277001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','aleksey_efimov','fokus_studio@mail.ru','Aleksey Efimov','Dagestanskay 4 68','Yekaterinburg','Sverdlovskay obl','RUSSIAN FEDERATION','620010','+7-912-2849044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 02:36:08',0,NULL,3,1,2,1,NULL,'aleksey_efimov'),(19962,796321826002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','olympicwiz','alan.issers@yahoo.com.au','Alan Issers','C/- RBS Equities<br>Level 23, 88 Phillip St','Sydney CBD','New South Wales','AUSTRALIA','2000','0400800088','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 03:12:52',0,NULL,3,1,2,1,NULL,'olympicwiz'),(19963,753571210001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','wilbur1146','daclyn@optusnet.com.au','David Harris','St George Bank<br>39 Woodlark St','Lismore','New South Wales','AUSTRALIA','2480','0266242380','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 03:23:37',0,NULL,3,1,2,1,NULL,'wilbur1146'),(19964,796339676002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','fabby347','lainggladys@yahoo.com','fabian davis','880 E 93rd St','brooklyn','NY','UNITED STATES','11236-2002','(347) 424-1646','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-16 04:13:42',0,NULL,3,1,1,1,NULL,'fabby347'),(19965,757042593018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',24,'photographyacc','bladerr','johncat5@bigpond.com','John Catton','53 Ardblair Terrace<br>Narre Warren South','Melbourne','Victoria','AUSTRALIA','3805','0414276937','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 06:10:29',0,NULL,3,1,3,1,'RA184578589CN ','bladerr'),(19966,753608586001,110541871813,'New Benro A1691TB0 Monopod Tripod Kit Travel Angel Bag',1,'AD1131',202,'hermeshine','sempre_carvalho','semprecarvalho@gmail.com','Luiz Roberto Carvalho','rua são cristóvão, 1031, apto 105 A<br>bairro coqueiros','florianópolis','SC','BRAZIL','88080-320','(55)(48)99281173','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 06:18:59',0,NULL,3,1,5,1,'CP240320547CN ','sempre_carvalho\rtripod  $40'),(19967,753612961001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',2,'AA3309',11.9,'hermeshine','budda001','isaev.foto@gmail.com','Kutuzova Maria Alexandrovna','Stroitelei d.42 kv.34','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 06:47:55',0,NULL,3,1,17,0,NULL,'budda001'),(19968,796369880002,120792099042,'New Twin Flash Bracket for Nikon  D700  SB900 SB800 Canon 7D 5DII  580EX O-Shape',1,'AD1192',35,'hermeshine','budda001','isaev.foto@gmail.com','Kutuzova Maria Alexandrovna','Stroitelei d.42 kv.34','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187114','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 06:47:56',0,NULL,3,1,17,0,NULL,'budda001'),(19969,796369773002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',3,'AKT067',29.7,'hermeshine','budda001','isaev.foto@gmail.com','Kutuzova Maria Alexandrovna','Stroitelei d.42 kv.34','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 06:47:56',0,NULL,3,1,17,0,NULL,'budda001'),(19970,796369832002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',3,'AA1310',16.47,'hermeshine','budda001','isaev.foto@gmail.com','Kutuzova Maria Alexandrovna','Stroitelei d.42 kv.34','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 06:47:57',0,NULL,3,1,3,1,'RA184578575CN ','budda001\r绿叶 CPL  55mm    2\rO型闪光灯支架      1\rlenspen     6\r气吹 + 机皮       3'),(19971,757060544018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','abjet2005','abhijit.chattaraj@gmail.com','Abhijit Chattaraj','25 Rocklea Drive','Port Melbourne','Victoria','AUSTRALIA','3207','61413305242','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-11-16 07:40:20',0,NULL,3,1,4,1,'YW867660560CN ','abjet2005\r▲'),(19972,890017332015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','lapees','audrrrone@gmail.com','Audrone Joskaudiene','Naujakiemio 2-44','Klaipeda','','LITHUANIA','94187','0037068432420','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 07:46:27',0,NULL,3,1,2,1,NULL,'lapees'),(19973,796406109002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','enich14','enich18@gmail.com','Evgeny kondaurov','Kustanayskaya st. 8 - 1 - 95','Moscow','Moscow','RUSSIAN FEDERATION','115580','+7-926-597-85-66','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 09:20:40',0,NULL,3,1,5,1,'CP240320958CN ','enich14\r+白色背景布  '),(19974,753649342001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','nikosfra','nikosfra@gmail.com','NIKOS FRAGKOULIS','2 STHNIDON STR','MEGARA','MEGARA','GREECE','19100','+302296021041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 09:28:44',0,NULL,3,0,2,1,NULL,'nikosfra\r蓝色'),(19975,796413969002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','taz2801','pl.ameztoy@laposte.net','Paul-Louis AMEZTOY','14 AV. DES MARTYRS DE LA LIBERTE<br>BAT.A APPT.28 (digicode : 8919)','COMPIEGNE','Picardie','FRANCE','60200','03.44.42.13.57','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 09:51:05',0,NULL,3,1,2,1,NULL,'taz2801'),(19976,8881321438269312,111,'1600W 套装+ 5个115w',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-11-16 10:11:09',0,NULL,3,1,12,1,'1733274874\r ','灯泡都是110v的 \r实重7.47  泡重11.5'),(19977,796423630002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','selcankurt85','selcanaydinli@gmail.com','Selcan Kurt','sevgi mah. 663 sok. 18/101 gaziemir/ izmir (asil iş hanı- Aydınlı Eczanesi)','İZMİR','','TURKEY','35410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:25:14',0,NULL,3,1,17,0,NULL,'selcankurt85'),(19978,753665059001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',2,'AKT031',100,'hermeshine','selcankurt85','selcanaydinli@gmail.com','Selcan Kurt','sevgi mah. 663 sok. 18/101 gaziemir/ izmir (asil iş hanı- Aydınlı Eczanesi)','İZMİR','','TURKEY','35410','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 10:25:15',0,NULL,3,1,17,0,NULL,'selcankurt85'),(19979,796423631002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',6,'AD1169',41.28,'hermeshine','selcankurt85','selcanaydinli@gmail.com','Selcan Kurt','sevgi mah. 663 sok. 18/101 gaziemir/ izmir (asil iş hanı- Aydınlı Eczanesi)','İZMİR','','TURKEY','35410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:25:16',0,NULL,3,1,17,0,NULL,'selcankurt85'),(19980,753665060001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','selcankurt85','selcanaydinli@gmail.com','Selcan Kurt','sevgi mah. 663 sok. 18/101 gaziemir/ izmir (asil iş hanı- Aydınlı Eczanesi)','İZMİR','','TURKEY','35410','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:25:17',0,NULL,3,1,5,1,'CP240320961CN ','selcankurt85\r斜臂     1\r灯架  2m      4\r沙袋（普通）     6\r800w  220v 灯泡     5'),(19981,753666174001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','boyadjy','fred.boyadjian@gmail.com','frederic boyadjian','31 rue charles de gaulle<br>App G','alfortville','Ile-de-France','FRANCE','94140','+33 622632539','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 10:29:29',0,NULL,3,1,3,1,'RA184578782CN\r ','boyadjy'),(19982,870596426016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','manis404','quadslash@yahoo.com','Manishi Barosee','32 Rue Jean-Pierre Beicht','Luxembourg','Luxembourg','LUXEMBOURG','L-1226','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 10:41:10',0,NULL,3,1,3,1,'RA184578629CN\r ','manis404'),(19983,753674634001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','bournouv','lebayeur@free.fr','Jean-François DUPLAND','26 allée des bournouviers','HERBLAY','Île-de-France','FRANCE','95220','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 10:59:58',0,NULL,3,1,2,1,NULL,'bournouv'),(19984,753675163001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','s_loginoff','s.loginov@yahoo.com','Sergey Loginov','ul. Krasn. Sloboda. d. 10','YOSHKAR-OLA','rep MARI-EL','RUSSIAN FEDERATION','424000','+7 (927) 872-4858','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 11:02:18',0,NULL,3,1,3,1,'RA184578615CN\r ','s_loginoff'),(19985,757114062018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','thenewbornposingpod','newbornposingpod@gmail.com','Amy-Lee Hands','15 Torello Cres','Victoria Point','Queensland','AUSTRALIA','4165','0466663641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 11:04:50',0,NULL,3,1,4,1,'YW867661654CN ','thenewbornposingpod\r▲'),(19986,814481822017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','spansun','spanman21@hotmail.com','Mr  M, J.  THOMAS','EDRIN,<br>21,  High Street,','PORTHMADOG','Gwynedd,','UNITED KINGDOM','LL49 9LR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 11:19:36',0,NULL,3,1,2,1,NULL,'spansun'),(19987,757127637018,280722265640,'New 10 pcs Landscape Color Filters Kit for Cokin P',1,'AKT077',42,'photographyacc','sandie_99','sandie258@gmail.com','Sandie Braun','165 Gellies Road','Wildwood','Victoria','AUSTRALIA','3429','0397444821','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 11:49:16',0,NULL,3,1,3,1,'RA184578805CN\r ','sandie_99'),(19988,757130728018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','jonny_taise','j_knaap@hotmail.com','Jonathan van der Knaap','Unit 6, 157 Fullarton Road','Rose Park','South Australia','AUSTRALIA','5067','0406760733','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 11:54:57',0,NULL,3,1,3,1,'RA184578717CN\r ','jonny_taise'),(19989,753701053001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','cemcalistiran','cem@calistiran.com','Cem Calistiran','sanatcilar sitesi 39B blok no :6 tarabya','ISTANBUL','','TURKEY','34000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 12:30:46',0,NULL,3,1,5,1,'CP240320944CN ','cemcalistiran\r欧标  '),(19990,871870725016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','bepi811226','bepi8112@gmail.com','Istvan Bende','Batthyany u. 18/3','Békéscsaba','Bekes','HUNGARY','5600','+36703159299','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 13:18:55',0,NULL,3,1,2,1,NULL,'bepi811226'),(19991,753721523001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',1,'AA1304',2.6,'hermeshine','tofeu2feu','tofeu2feu@gmail.com','JUNG Christophe','21 rue de chapelle','METZ','Lorraine','FRANCE','57000','06.09.32.75.64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 13:33:50',0,NULL,3,1,17,0,NULL,'tofeu2feu'),(19992,753724194001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','tofeu2feu','tofeu2feu@gmail.com','JUNG Christophe','21 rue de chapelle','METZ','Lorraine','FRANCE','57000','06.09.32.75.64','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 13:41:10',0,NULL,3,1,3,1,'RA184578748CN\r ','tofeu2feu\rCANON 镜头盖  77mm     1\r魔术手臂11寸    1'),(19993,753753139001,110414160597,'55mm CPL Circular Polarizing Filter 55 CPL Green.L ',1,'AA3309',5.95,'hermeshine','mecataz8296262','mecataz8296@hotmail.com','Joel Sepúlveda','Urb. Villas Del Hato, A-1 Calle Robles','San Lorenzo','PR','UNITED STATES','00754','787 914 0124','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-16 15:01:25',0,NULL,3,1,1,1,NULL,'mecataz8296262'),(19994,753799112001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','foxj862011','neptune.d2d@gmail.com','Sufwan Abu-Salih','Sakhnin<br>Havradim','Sakhnin','Israel, Sakhnin Pobox: 43 Postal code 30810','ISRAEL','30810','+972526826821','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 16:52:51',0,NULL,3,1,3,1,'RA184578703CN\r ','foxj862011'),(19995,872000752016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','oadby13','theo.lambourne@btinternet.com','Theo Lambourne','20 Woodside Road','Leicester','Leicestershire','UNITED KINGDOM','LE24SE','01162713633','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 17:41:53',0,NULL,3,1,2,1,NULL,'oadby13'),(19996,890286392015,250847020386,'Green Slim 77mm Fader ND Filter adjustable ND2 to ND400',1,'AD1143',27.9,'hutongstore','soina06','mmeric@free.fr','MERIC MICHEL','MSD L\'Ariane \"Le Petit Palais\"<br>1 Square Chateauneuf de Constantin','NICE','Provence-Alpes-Côte d\'Azur','FRANCE','06300','0607437577','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-16 18:10:15',0,NULL,3,1,3,1,'RA184578734CN\r ','soina06'),(19997,796618736002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','vent4you','rusanow.denis@yandex.ru','Denis Rusanov (www.vent4you.ru)','Grizodubovoy 16, apartment 39','Zhukovsky','Russia','RUSSIAN FEDERATION','140182','+7 903 1861066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 18:46:13',0,NULL,3,1,17,0,NULL,'vent4you\r一共3个'),(19998,890320414015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','baby-travel','babytraveluk@gmail.com','Dan Smith','Baby Travel Unit 13 St Anne\'s Ind Est<br>St Anne\'s Rd','Willenhall','West Midlands','UNITED KINGDOM','WV131Dy','01902366333','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-16 19:17:35',0,NULL,3,1,2,1,NULL,'baby-travel'),(19999,757332895018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',5,'AC2301',29.5,'photographyacc','cotebupa','majobupa@gmail.com','Julio Fernàndez Y.','Santa Beatriz<br>269 Depto 302','Providencia','SANTIAGO','CHILE','7500496','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-16 19:26:53',0,NULL,3,1,3,1,'RA184578663CN\r ','cotebupa'),(20000,796662901002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','limey711','limey711@msn.com','Russell Swindlehurst','37 Marlborough<br>Ashurst','Skelmersdale','Lancashire','UNITED KINGDOM','WN8 6SD','0169551710','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 19:57:40',0,NULL,3,0,3,1,'RA184578685CN\r ','limey711\r3XL   已入库 '),(20001,796739438002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','missannyho','anny.ho@live.nl','Anny Ho','Wilgenlei 70A','ROTTERDAM','','NETHERLANDS','3052CG','0647226583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 22:15:29',0,NULL,3,1,2,1,NULL,'missannyho'),(20002,796740577002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','leopbrasil','padual@hotmail.com','Leonardo Rodrigues','R. Coronel Correia de Figueiredo 185<br>Bairro Museu','Conselheiro Lafaiete','Minas Gerais','BRAZIL','36400000','553137615992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 22:17:29',0,NULL,3,1,17,0,NULL,'leopbrasil'),(20003,753979112001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','leopbrasil','padual@hotmail.com','Leonardo Rodrigues','R. Coronel Correia de Figueiredo 185<br>Bairro Museu','Conselheiro Lafaiete','Minas Gerais','BRAZIL','36400000','553137615992','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-16 22:17:29',0,NULL,3,1,3,1,'RA184578694CN\r ','leopbrasil\r欧标   \r除了c 里面的再发  \r大力夹     1'),(20004,890485121015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','wpal3226','waynesworldoffashion@hotmail.co.uk','Wayne Palmer','58 Boundary Walk','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 0LZ','07974441772','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-16 22:54:28',0,NULL,3,1,4,1,'YW867661665CN ','wpal3226\r白+黑 \r▲'),(20005,793919067002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',16.9,'hermeshine','goronzz','goronz@libero.it','Luca Goroni','via di porta fabbrica , 15 int.b12','Roma','RM','ITALY','00165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 23:07:04',0,NULL,3,1,2,1,NULL,'goronzz'),(20006,752706711018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','croydoncamera','dean@croydoncamerahouse.com.au','Croydon Camera House','125 Main Street','Croydon','Victoria','AUSTRALIA','3136','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-16 23:22:40',0,NULL,3,0,3,1,'RA184578677CN\r ','croydoncamera\r3xl   已入库'),(20007,754011480001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',3,'AE3601',54,'hermeshine','loffman83','samloughland@hotmail.com','Sam loughland','3/260 St.Goerge\'s Rd','North Fitzroy','Victoria','AUSTRALIA','3068','0408408288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-16 23:47:23',0,NULL,3,1,3,1,'RA184578751CN\r ','loffman83\r3个'),(20008,754017269001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','caska69','caska@internode.on.net','Andrew Cascone','9 Donday Court','Pakenham','Victoria','AUSTRALIA','3810','0418342232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 00:06:55',0,NULL,3,1,3,1,'RA184578725CN\r ','caska69'),(20009,757479708018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',200,'photographyacc','smithrowe','studio@smithandrowe.com.au','William Rowe','Suite 3, 15-17 Pakington Street','St Kilda','Victoria','AUSTRALIA','3182','0395253933','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-17 00:31:29',0,NULL,3,1,4,1,'YW867661643CN ','smithrowe\r澳标\r▲'),(20010,796797241002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','tgapen','tom@tresgatos.net','Thomas Gapen','28018 Tupelo Ridge Dr','Valencia','CA','UNITED STATES','91354-1325','(661) 296-0682 ext.: 8187133712','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 01:03:06',0,NULL,3,1,1,1,NULL,'tgapen'),(20011,814959655017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',11.99,'photographyacc','paul_pearl600d','chumpong17@hotmail.com','chumpong chanaka','89 Baxter Road','Sydney','New South Wales','AUSTRALIA','2020','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 06:50:17',0,NULL,3,1,2,1,NULL,'paul_pearl600d'),(20012,757572450018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','michael.how','howwa@netspace.net.au','Matthew How','68 Channel Highway Kingston','Hobart','Tasmania','AUSTRALIA','7050','0362294079','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 07:00:38',0,NULL,3,1,3,1,'RA184575199CN\r ','michael.how'),(20013,8881321513612213,111,'牛津布包 x  1+ 580ex 肥皂盒 x  2',1,'',0,'hermeshine',' sithideth2011  ','panlao528818@yahoo.com','sithideth OUNKHAMVOLACHIT','Nongbone Road Naxay home 2<br>51 nuay 3 Naxay Village','Saysettha District Vientiane PO box 6465','','LAOS','','',NULL,NULL,NULL,'2011-11-17 07:06:52',0,NULL,3,1,3,1,' RA184575137CN\r',NULL),(20014,890644606015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','lemmylemur','lemmy@netatonce.net','Timmy Fagerlund','Kulturmejeriet<br>Stora Södergatan 64','LUND','','SWEDEN','222 23','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 07:21:10',0,NULL,3,1,17,0,NULL,'lemmylemur'),(20015,890643466015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','lemmylemur','lemmy@netatonce.net','Timmy Fagerlund','Kulturmejeriet<br>Stora Södergatan 64','LUND','','SWEDEN','222 23','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 07:15:29',0,NULL,3,1,2,1,NULL,'lemmylemur\r橡胶遮光罩 55mm     1\r橡胶遮光罩 52mm    1'),(20016,890654852015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','javyrus','jarmo.hir@gmail.com','Jarmo Hirvikoski','Kalskeentie 2-4 C 67','PORI','','FINLAND','28370','+358449997692','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 07:59:13',0,NULL,3,1,3,1,' RA184575110CN\r','javyrus'),(20017,796899497002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','ds14599','dstevenson@aventura1.com','Dale Stevenson','7270 201st Street','Langley','BC','CANADA','V2Y 3G3','(604) 533-2753','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 08:30:01',0,NULL,3,1,2,1,NULL,'ds14599'),(20018,754135270001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','alicemajbritt','alice@doek.dk','alice majbritt Jensen','bygränd 4','malmö','standard','SWEDEN','21236','004520727523','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 08:57:16',0,NULL,3,1,17,0,NULL,'alicemajbritt'),(20019,757599794018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','letterboxesdirect','letterboxesdirect@turbon.com.au','Turbon','39 Cavendish Rd','Coorparoo','Queensland','AUSTRALIA','4151','0738473166','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 09:02:29',0,NULL,3,1,4,1,'YW867661595CN ','letterboxesdirect\r▲'),(20020,8881321522452941,111,'2m灯架配件',1,'',0,'hermeshine','nmljoel','toledodesign@gmail.com','joel garcia','berget8<br>51 nuay 3 Naxay Village','4400','flekkefjord','NORWAY','4400','',NULL,NULL,NULL,'2011-11-17 09:34:12',0,NULL,3,0,3,1,' RA184575208CN\r','2m灯架最上面的那个夹子  1 '),(20021,890683768015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','sailingsam0','messages@surguy.com','Jason Surguy','23 Garden Road','Bingham','Nottinghamshire','UNITED KINGDOM','NG13 8GB','01949875310','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-17 09:36:32',0,NULL,3,1,4,1,'YW867661606CN ','sailingsam0\r黑加白\r▲'),(20022,8881321522593220,111,'灯架包好  ',1,'AD1128',0,'hermeshine','vlad_molodtsov','molodtsovv@yandex.ru','Vladimir Molodtsov','St. Chernyshevskogo 29<br>51 nuay 3 Naxay Village','Mineralnye Vody','Stavropol region','RUSSIAN FEDERATION','357209','+78792264285',NULL,NULL,NULL,'2011-11-17 09:36:33',0,NULL,3,1,3,1,' RA184575171CN\r',NULL),(20023,754138625001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','alicemajbritt','alice@doek.dk','alice majbritt Jensen','bygränd 4','malmö','standard','SWEDEN','21236','004520727523','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 09:05:38',0,NULL,3,0,4,1,'YW867661610CN ','alicemajbritt\r灯架  2m    2        ▲\r灯架包薄     1\r3m 横杆（通用4节）       1\r背景布 3x6 白色      1'),(20024,872415035016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','bostjan1971','bostjan.rudolf@mentek.si','Boštjan Rudolf','Kettejeva 14','Koper','','SLOVENIA','6000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 09:45:58',0,NULL,8,1,17,0,NULL,'bostjan1971'),(20025,890687234015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.48,'hutongstore','bostjan1971','bostjan.rudolf@mentek.si','Boštjan Rudolf','Kettejeva 14','Koper','','SLOVENIA','6000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 09:45:59',0,NULL,3,1,2,1,NULL,'bostjan1971\rNIKON 镜头盖 52mm   1\r大号灰卡      1'),(20026,754149841001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','rightrower_ericpng','rightrower@gmail.com','Eric Png','455 SEGAR ROAD<br>#10-113','default','','SINGAPORE','670455','93804339','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 09:48:04',0,NULL,3,1,11,1,NULL,'rightrower_ericpng'),(20027,757612886018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','mpopov77','mpopovic77@gmail.com','Mladen Popovic','S. Ferencaka 43','Dugo Selo','','CROATIA','10370','+38598380631','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 09:49:34',0,NULL,3,1,5,1,'CP238126730CN ','mpopov77'),(20028,757632032018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','brian500au','kblake@falview.com','Kelvin Blake','Po Box 543','Williamstown','Victoria','AUSTRALIA','3016','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 10:56:34',0,NULL,3,1,3,1,'RA184575145CN\r ','brian500au'),(20029,890714047015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','494jeremy','jezju@talktalk.net','Jeremy Sage','33 Centurion Walk,<br>Kingsnorth','Ashford','Kent','UNITED KINGDOM','TN23 3FQ','01233500145','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 11:05:38',0,NULL,3,1,2,1,NULL,'494jeremy\r英标  '),(20030,872462408016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','ffandy7293','becky.havery@googlemail.com','Andrew Havery','19 Southbourne Road','Lymington','Hampshire','UNITED KINGDOM','SO419JB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 12:04:54',0,NULL,3,1,2,1,NULL,'ffandy7293'),(20031,757673021018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','+79232892744','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 13:10:19',0,NULL,3,1,5,1,'CP238126743CN ','zenitar16'),(20032,754237567001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 14:41:31',0,NULL,3,1,3,1,'RA184575083CN\r ','paulolagoaseca2010'),(20033,751615301018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','mariobradaric','mariobradaric.photo@gmail.com','MARIO BRADARIĆ','CVJETNI TRG 9','NJIVICE','','CROATIA','51512','0917609384','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 14:19:02',0,NULL,3,1,2,1,NULL,'mariobradaric'),(20034,890814073015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','archileos','mail@studiolms.com','Leo Maria Scordo','Viale Mazzini 139','Vicenza','VI','ITALY','36100','0444021038','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 15:13:53',0,NULL,3,1,3,1,'RA184575070CN\r ','archileos\rboom arm    $15'),(20035,797020861002,120753012046,'Brand New Official Original Nikon Photo Vest for D300 D90 D700 D80 Size M ',1,'AD1159',42,'hermeshine','dynse','snlchan@rogers.com','Samuel Chan','119 Exeter Road<br>Unit H','London','ON','CANADA','N6L 1A4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 15:21:39',0,NULL,3,1,3,1,' RA184575097CN\r','dynse'),(20036,872543491016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','doomed_angel','kaylahackney@hotmail.co.uk','keeley fleckney','3 Bloomfield close','derby','Derbyshire','UNITED KINGDOM','DE1 2FY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-17 15:24:36',0,NULL,3,1,3,1,'RA184575123CN\r ','doomed_angel'),(20037,757725636018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','henry.tan','henfry83@hotmail.com','Henry Tan','55  Belmore  Bend','Aubin Grove','Western Australia','AUSTRALIA','6164','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 15:33:57',0,NULL,3,1,2,1,NULL,'henry.tan'),(20038,757732526018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','geoffrey7937','gward@iinet.net.au','geoffrey ward','15 corring way-parmelia','perth','Western Australia','AUSTRALIA','6167','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 15:52:24',0,NULL,3,1,2,1,NULL,'geoffrey7937'),(20039,797036690002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','daniv2011','danielvalero1970@hotmail.com','Daniel Valero Soler','Avenida del Valles nº 67','Cardedeu','Cataluña','SPAIN','08440','600936937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 16:02:38',0,NULL,3,1,3,1,'RA184575154CN\r ','daniv2011'),(20040,797047374002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',85.98,'hermeshine','johnnykcr2010','johnnykcr@hotmail.co.uk','Puttirit Kaewcharee','4810/91 Liverpool St','Sydney','New South Wales','AUSTRALIA','2000','0401655555','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 16:29:16',0,NULL,3,1,4,1,'YW867661621CN ','johnnykcr2010\r▲'),(20041,594561499004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',52,'hermeshine','vovadacenko1979','vovadacenko@ukr.net','Volodymyr Datsenko','Volkova 59. k62.','Cherkasy','Cherkasy','UKRAINE','18016','+380934706633','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 16:53:27',0,NULL,3,1,3,1,'RA184575066CN\r ','vovadacenko1979'),(20042,754392066001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.98,'hermeshine','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 8 A 22','Tampere','','FINLAND','33100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 20:11:59',0,NULL,3,1,3,1,' RA184575106CN\r','zuhmia\r欧标'),(20043,795520184002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','levymask0','levymask@gmail.com','Levy Alvares Melo','AV. C255 Quadra 588 Lote 4/8 N.270<br>Ed. Centro Empresarial Sebba. SALA 1112','Goiânia','Goiânia-GO','BRAZIL','74280010','62 84243671','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 20:25:29',0,NULL,3,1,5,1,'CP240320935CN ','levymask0'),(20044,754400827001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','lyzalizlec','lecliz_72@yahoo.com','Frederick L. Duldulao','FMC Law Duplicating Services<br>77 King Street West, Suite 400','Toronto','ON','CANADA','M5K 0A1','(416) 863-4528','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-17 20:27:52',0,NULL,3,1,2,1,NULL,'lyzalizlec'),(20045,754420659001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','1193838','muphyd@hotmail.com','mufeed abdul rahumaan','fiyari','LH.naifaru','','MALDIVES','9938911','9938911','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 21:05:23',0,NULL,3,1,2,1,NULL,'1193838\r黑色  '),(20046,797201132002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','romulolhp','romuloronie@hotmail.com','Thais Larissa Souza da Silva','qnc 13 casa 20','Taguatinga','Distrito Federal','BRAZIL','72115-630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 21:16:01',0,NULL,3,1,3,1,'RA184575049CN\r ','romulolhp\r\r\r\r'),(20047,757913849018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','ashilleong','thecrypt4@hotmail.com','Jasmine Adams','10/265<br>Dugan Street','Kalgoorlie','Western Australia','AUSTRALIA','6430','0890222269','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 21:30:07',0,NULL,3,1,2,1,NULL,'ashilleong'),(20048,757911625018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',40,'photographyacc','lukeluke01','lfrohling01@yahoo.com.au','Luke Frohling','11 Stadler Ct','Parkwood','Queensland','AUSTRALIA','4214','0403445793','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-17 21:30:47',0,NULL,3,1,3,1,'RA184575185CN\r ','lukeluke01'),(20049,754437306001,110488938513,'10 NEW Snap-on Front Lens Caps 52mm - 77mm Canon Nikon',1,'AKT029',24,'hermeshine','dennis87654','dknepper@optonline.net','Dennis Knepper','38 Maple Ave','Bellport','NY','UNITED STATES','11713','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-17 21:36:26',0,NULL,3,0,1,1,' ','dennis87654\r77mm       1\r72 mm       2\r67mm        7\r全是nikon\r已入库  \r'),(20050,891067696015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','pedrocampos85','pedroinfantecampos@hotmail.com','Pedro Campos','Rua da Paz nº13<br>Guifões','Matosinhos','','PORTUGAL','4460-081','918489161','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-17 21:53:01',0,NULL,3,1,3,1,' RA184575035CN\r','pedrocampos85\r欧标  '),(20051,815347237017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','maspac2','sergarang@yahoo.es','SILVIA FERRER ALEMANY','pla de la font 13<br>peluqueria','pego','Comunidad Valenciana','SPAIN','03780','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-17 22:28:21',0,NULL,3,0,3,1,' RA184575021CN\r','maspac2\r1.6*3白色  '),(20052,754474028001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','bagongbuhay2008','ellagampongan@gmail.com','Maria Ella Ampongan','3/49 Nungerner Street','Balwyn','Victoria','AUSTRALIA','3103','61433364995','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-17 23:05:00',0,NULL,3,1,2,1,NULL,'bagongbuhay2008'),(20053,754482709001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','xkmendl','mintchips@verizon.net','Jim Whobrey','4516 Narrot St','Torrance','CA','UNITED STATES','90503-1432','(310) 542-8116','NoPaymentFailure','CheckoutComplete','Other','2011-11-17 23:29:32',0,NULL,3,0,1,1,NULL,'xkmendl\rXL  已入库 '),(20054,815394743017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','patkua','pkua@yahoo.com','Patrick Kua','Eclipse Computing<br>Level 3, 499 St Kilda Road','Melbourne','Victoria','AUSTRALIA','3004','0432528526','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 00:42:01',0,NULL,3,1,2,1,' ','patkua'),(20055,797299857002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','marcostomasi','mctomasi00@yahoo.com.br','Marcos Cleber Tomasi','Rua José Rossini Nº 424<br>Bairro Santa Helena','Bento Goncalves','Rio Grande do Sul','BRAZIL','95700000','54 3454 1547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 01:52:51',0,NULL,3,1,5,1,'CP240320581CN ','marcostomasi\r欧标   本身就是欧标  '),(20056,815420471017,270855429801,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',28.9,'photographyacc','farmerdave','dww_ma@yahoo.com','David Ma','5200 Calderwood Crescent','Richmond','BC','CANADA','V7C 3G3','(604) 275-5415','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 02:08:19',0,NULL,3,1,3,1,' RA184575052CN\r','farmerdave'),(20057,754532767001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','tyler*anderson','tyland18@hotmail.com','Tyler Anderson','Suite 202 - 10012 97th Avenue','Fort St. John','BC','CANADA','V1J 5P3','(250) 793-9502','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 02:30:32',0,NULL,3,1,2,1,' ','tyler*anderson'),(20058,797337100002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','kauffmankt_47','kauffmankt@lycos.com','KEITH KAUFFMAN','411 N Kyrene Rd<br>Apt 277','CHANDLER','AZ','UNITED STATES','85226-2789','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 04:09:53',0,NULL,3,1,1,1,NULL,'kauffmankt_47'),(20059,758044304018,280714977904,'New Dual-Layer Soft Reflective Umbrella Studio 85cm 33\"',1,'AD1156',19.8,'photographyacc','mickmok','mickmok@gmail.com','Michael Curtin','2/32 Pyne Street<br>Caulfield South','Melbourne','Victoria','AUSTRALIA','3162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 04:22:17',0,NULL,8,1,17,0,' ','mickmok'),(20060,758045718018,280774575751,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9,'photographyacc','mickmok','mickmok@gmail.com','Michael Curtin','2/32 Pyne Street<br>Caulfield South','Melbourne','Victoria','AUSTRALIA','3162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 04:27:03',0,NULL,8,1,17,0,' ','mickmok\r'),(20061,758045238018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','mickmok','mickmok@gmail.com','Michael Curtin','2/32 Pyne Street<br>Caulfield South','Melbourne','Victoria','AUSTRALIA','3162','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 04:24:41',0,NULL,3,1,3,1,' RA184575168CN\r','mickmok\r85cm  两用伞 1\r闪光灯B座   1  \r灯架  2m      1'),(20062,754569999001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',2,'AD1195',58,'hermeshine','cyriopereira',' cyriopereira@gmail.com','Cyrio Marin Pereira','320 S Flamingo Rd<br># 226','Pembroke Pines','FL','UNITED STATES','33027-1770','(305) 597-8380','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-18 05:21:38',0,NULL,3,1,1,1,NULL,'cyriopereira'),(20063,797346623002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','robm1111','bomat3@gmail.com','Robert Maitland','Unit 2, 77 Teague Street','VICTORIA PARK','Western Australia','AUSTRALIA','6100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 04:57:39',0,NULL,3,1,2,1,NULL,'robm1111'),(20064,758061256018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',8.5,'photographyacc','rayseow','seowray@iinet.net.au','Raymond Seow c/o Yat Kee','12 Lakeside Drive','Burwood East','Victoria','AUSTRALIA','3151','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 05:49:50',0,NULL,3,1,2,1,NULL,'rayseow'),(20065,8881321597150971,111,'800w 220v',3,'AO0015',0,'hutongstore','maxmillion76','dwaynetyou@hotmail.com','Dwayne Timmons','PCD TRANSPORT LIMITED<br>GORTLUM BRITTAS CO DUBLIN D24','Dublin','Dublin','IRELAND','d24','0857283770',NULL,NULL,NULL,'2011-11-18 06:19:10',0,NULL,3,1,3,1,'RA184575432CN ','上次漏发了？ '),(20066,8881321597850619,111,'套装',1,'AKT037',0,'hermeshine','marikksk','sembaevm@gmail.com','Marat Sembayev','ulica Kustanaiskaya 79, kvartira 75','Semey','KZ','KAZAKHSTAN','071410','77222348163',NULL,NULL,NULL,'2011-11-18 06:30:50',0,NULL,3,1,8,1,'CP240320927CN ','套装里共两块3mx6m背景布  绿色 + 白色 '),(20067,754586395001,110414378946,'New ND8 Filter for Cokin P Series Neutral Density ND 8',1,'AA2325',7.2,'hermeshine','keith10w1977','keith10w1@gmail.com','Keith Low','Blk 421 Hougang Ave 10<br>#04-301','default','','SINGAPORE','530421','84887776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 06:57:13',0,NULL,3,1,11,1,NULL,'keith10w1977'),(20068,754598099001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','chalkkos030','chalkkos@gmail.com','KOSTAS CHALKIADAKIS','6, STERGIOGIANNI st.','HERAKLION CRETE','','GREECE','71305','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 08:03:21',0,NULL,3,1,3,1,'RA184575429CN ','chalkkos030'),(20069,8881321603486954,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m',2,'AE2501',51.98,'aliexpress','1005312382','sarl.grandi@hotmail.fr','Grandi Bruno	','rue de la rivoire','saint victor de morestel	','rhone alpes	','FRANCE	','38510','+033 6 62851301',NULL,NULL,NULL,'2011-11-18 08:04:46',0,NULL,3,1,3,1,' RA184575640CN\r','如果一票不能控制在2kg以内，\r就分成2票发'),(20070,872995471016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jcchavez07','geissgoh@gmail.com','Elsbeth Dutler','10 Seaforth Ave','Broadbeach Waters','Queensland','AUSTRALIA','4218','0432555108','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-18 08:54:26',0,NULL,3,1,4,1,' YW867661584CN ','jcchavez07\r澳标\r▲'),(20071,891136927015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','cardososan','cardoso@tvtel.pt','Paulo Cardoso','Rua Padre Himalaya nº 50 A','Porto','','PORTUGAL','4100 553','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 09:01:21',0,NULL,3,1,2,1,NULL,'cardososan'),(20072,815518208017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 09:07:07',0,NULL,3,1,17,0,NULL,'krisvisual'),(20073,815523096017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.9,'photographyacc','jesspoddy','jess_poddy@hotmail.com','jessica podporin','19 heatherlea grove','lakes entrance','Victoria','AUSTRALIA','3909','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 09:22:54',0,NULL,3,1,2,1,NULL,'jesspoddy'),(20074,758109357018,280667758168,'New Green.L 77mm Macro Close-up Filter +4',1,'AE3221',7.55,'photographyacc','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 09:38:18',0,NULL,3,1,2,1,NULL,'krisvisual\r一转四 灯头    1\r绿叶近摄镜 +4  77mm    1'),(20075,891299771015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','riztickets','rizzo31@hotmail.co.uk','Denise Richards','3 Redcar Rd','Wolverhampton','West Midlands','UNITED KINGDOM','wv10 6pp','07971975902','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 09:43:05',0,NULL,3,1,2,1,NULL,'riztickets'),(20076,797407232002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','ivanultrasonica','ultrasonica@hotmail.com','Ivan (Documentacion)','C/ Madalena, 21<br>Polígon Son Bugadelles (IB3)','Santa Ponça (Calvià)','Baleares','SPAIN','07180','607832564','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 09:56:10',0,NULL,3,1,2,1,NULL,'ivanultrasonica'),(20077,796907650002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','vent4you','rusanow.denis@yandex.ru','Denis Rusanov (www.vent4you.ru)','Grizodubovoy 16, apartment 39','Zhukovsky','Russia','RUSSIAN FEDERATION','140182','+7 903 1861066','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 09:28:33',0,NULL,3,1,3,1,' RA184575874CN\r','vent4you\r三个c型夹      '),(20078,758121510018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',87,'photographyacc','chriskarlosam','chris.cortvriendt@gmail.com','Chris Cortvriendt','Izegemstraat 152','Ingelmunster','','BELGIUM','8770','0478427635','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 10:22:03',0,NULL,3,1,4,1,'YW867660571CN\r ','chriskarlosam\r▲'),(20079,754633227001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','ghponies','jeannefick@yahoo.com','Jeanne Fick','PO Box 242','ALBERTINIA','','SOUTH AFRICA','6695','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 10:31:51',0,NULL,5,1,18,0,NULL,'ghponies\r看看可以发几个小包\r'),(20080,873031885016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','cmonlineltd','admin@cmessaging.com','Simon Mellamphy','573A London Road','Westcliff on sea','Essex','UNITED KINGDOM','SS0 9PQ','01702332239','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-18 10:48:45',0,NULL,3,1,4,1,'YW867660582CN\r ','cmonlineltd\r英标\r▲'),(20081,797433184002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','jewelv2','jewelv@mail.ru','Vitaliy Piven','Altufevskoe shosse, dom 34, korpus 2, kv 1<br>Алтуфьевское шоссе, дом 34, корпус 2, квартира 1','Moscow','','RUSSIAN FEDERATION','127562','+7(910)413-4557','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 11:29:29',0,NULL,3,1,2,1,NULL,'jewelv2\r布换成机皮  以后都是机皮'),(20082,754654153001,110541871813,'New Benro A1691TB0 Monopod Tripod Kit Travel Angel Bag',1,'AD1131',202,'hermeshine','flyfishing_norway','frode.raaen@hotmail.com','Frode Raaen Stakston','Durudveien 12A','Haslum','Baerum','NORWAY','1344','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 11:48:06',0,NULL,3,1,17,0,NULL,'flyfishing_norway\r'),(20083,754654152001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','flyfishing_norway','frode.raaen@hotmail.com','Frode Raaen Stakston','Durudveien 12A','Haslum','Baerum','NORWAY','1344','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 11:48:05',0,NULL,3,1,4,1,'YW867660593CN\r ','flyfishing_norway\r绿叶 渐变镜 52mm    1   ▲\r百诺三脚架A1691TB0   1'),(20084,891346536015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','catmayas','omaildamaya@gmail.com','Cristina Maya','Praça Infante D. Henrique, 6, 6º Dto','LOURES','LOURES','PORTUGAL','2670-390','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-18 11:57:58',0,NULL,3,1,3,1,' RA184575888CN\r','catmayas'),(20085,754667846001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','leksandra.stepanova','stepanova_aleksa@mail.ru','Aleksandra Stepanova','Dm. Donskogo','Moscow','Moscow','RUSSIAN FEDERATION','117216',' 89263459593','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 12:34:21',0,NULL,3,1,5,1,'CP240320357CN\r ','leksandra.stepanova'),(20086,891364116015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','allinisrl','allini.srl@alice.it','Francesco Allini','Viale Kennedy n.15','Aversa','CE','ITALY','81031','0815037752','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 12:41:40',0,NULL,3,1,2,1,NULL,'allinisrl'),(20087,891370696015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','maccauk','maccauk_007@hotmail.com','Ben Macdonald','11 Forester Way','kidderminster','Worcestershire','UNITED KINGDOM','DY10 1NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 12:58:19',0,NULL,3,1,3,1,' RA184575891CN\r','maccauk'),(20088,758163023018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','csabi83','csepi83@gmail.com','Csaba Fodemesi','Zalan utca 11<br>XVIII','Budapest','Budapest','HUNGARY','1183','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 12:40:20',0,NULL,3,1,5,1,'CP240320365CN\r ','csabi83'),(20089,8881321626670121,111,'欧标',1,'',0,'hermeshine','ben7154','freefeeling@gmail.com','Ben Baur','Kibbutz Ramat Hashofet<br>off','Kibbutz Ramat Hashofet','ISRAEL','ISRAEL','19238','97249898536',NULL,NULL,NULL,'2011-11-18 14:31:10',0,NULL,3,1,2,1,NULL,NULL),(20090,891411508015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','vitormpdias','vitormpdias@gmail.com','Vitor Dias','Rua Dr Afonso Cordeiro, 877 - sala 201','Matosinhos','Portugal','PORTUGAL','4450-007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 14:32:53',0,NULL,3,1,3,1,'RA184574635CN ','vitormpdias'),(20091,8881321627165011,111,'红头灯+800w灯泡',2,'AKT055',0,'hermeshine','ktriscrew','alzota@hotmail.com','emile gbaka','27 rue de marseille','EPINAY SUR SEINE','Ile-de-France','FRANCE','93800','0664352329',NULL,NULL,NULL,'2011-11-18 14:39:25',0,NULL,3,0,4,1,'YW867660604CN\r ','▲ '),(20092,797520156002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',65,'hermeshine','avaneendra','avaneendraa@gmail.com','Avaneendra Alugupalli','8024 Wade Green Pl','Cary','NC','UNITED STATES','27519-1515','(919) 386-8086','NoPaymentFailure','CheckoutComplete','Other','2011-11-18 15:43:55',0,NULL,3,1,17,0,NULL,'avaneendra'),(20093,797520157002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','avaneendra','avaneendraa@gmail.com','Avaneendra Alugupalli','8024 Wade Green Pl','Cary','NC','UNITED STATES','27519-1515','(919) 386-8086','NoPaymentFailure','CheckoutComplete','Other','2011-11-18 15:43:56',0,NULL,3,1,4,1,'YW867660615CN\r ','avaneendra\r115w 5500k 灯泡  110v     4\r4灯头 灯头 孔     2\r▲'),(20094,797508527002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'',55,'hermeshine','debosuepo','mt.taylor@live.ca','Debbie Taylor','120 Woodside Cir NW','Airdrie','AB','CANADA','T4B 2S6','(403) 980-7890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 15:16:21',0,NULL,3,1,3,1,'RA184574454CN\r ','debosuepo'),(20095,815665537017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','perezfreytes','miguel.ruiznazario@gmail.com','Miguel Ruiz','263 Calle M Perez Freytes','Arecibo','PR','UNITED STATES','00612-4647','(787) 878-1995','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 16:04:50',0,NULL,3,1,1,1,NULL,'perezfreytes'),(20096,891465612015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','ngwillym','neil@gwillym.plus.com','Neil Gwillym','The Haven<br>Twiggs Lane, Marchwood','Southampton','Hampshire','UNITED KINGDOM','SO40 4UN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-18 16:27:17',0,NULL,3,1,3,1,' RA184575905CN\r','ngwillym\r'),(20097,891473822015,250666873771,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',120,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-18 16:38:31',0,NULL,3,1,12,1,'5241761265\r ','sorimp\r欧标 \r申报$20\r实重6.85  泡重7.35\r最终计费 8kg'),(20098,754763717001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',3,'AA1202',7.44,'hermeshine','xyzchristianxyz86','xyzchristianxyz@vtxmail.ch','Christian Graf','Studenbühlstrasse 39','Wollerau','','SWITZERLAND','8832','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 16:53:07',0,NULL,3,1,2,1,NULL,'xyzchristianxyz86'),(20099,891495526015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','filipburman','filip.burman@gmail.com','Filip Burman','Skeppargatan 11B','Skellefteå','Västerbotten','SWEDEN','93130','+46702854702','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-18 17:17:43',0,NULL,3,1,4,1,'YW867660626CN\r ','filipburman\r欧标\r已签收\r'),(20100,797597063002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',2.18,'hermeshine','shells123blue','sarri80@gmail.com','Oliver Sarri','Abbekasgatan 12b','Malmo','Skane','SWEDEN','21440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 18:28:37',0,NULL,3,1,17,0,NULL,'shells123blue'),(20101,797597064002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','shells123blue','sarri80@gmail.com','Oliver Sarri','Abbekasgatan 12b','Malmo','Skane','SWEDEN','21440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 18:28:38',0,NULL,3,1,17,0,NULL,'shells123blue'),(20102,797597066002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',35,'hermeshine','shells123blue','sarri80@gmail.com','Oliver Sarri','Abbekasgatan 12b','Malmo','Skane','SWEDEN','21440','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-18 18:28:38',0,NULL,3,1,17,0,NULL,'shells123blue'),(20103,754808994001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','shells123blue','sarri80@gmail.com','Oliver Sarri','Abbekasgatan 12b','Malmo','Skane','SWEDEN','21440','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-18 18:28:39',0,NULL,3,1,4,1,'YW867660630CN\r ','shells123blue\r方形滤镜接口环 58mm   1\r方形滤镜接口环 77mm     1\r115w 5500k 灯泡  220v    2\r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）    1\r欧标\r\r▲\r\r\r\r'),(20104,758327715018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','gtb_daytona','bone_collector@bigmir.net','Ivan Magdjuk','Kaverin STR<br>house#1, APT#193','Dnipropetrovsk','Dnipropetrovsk','UKRAINE','49008','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 19:05:02',0,NULL,3,1,2,1,NULL,'gtb_daytona'),(20105,797639149002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','technophilerick','graphicartistrick@cox.net','RICARDO LEIJA','917 Saddle Horn Dr','Henderson','NV','UNITED STATES','89002','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-18 19:51:15',0,NULL,3,1,1,1,NULL,'technophilerick'),(20106,797628442002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','dfung2000','fungdanny_2000@yahoo.com','Daniel Fung','1 Cooperage Street','Brampton','ON','CANADA','L6Y5K1','(416) 456-0100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 19:32:48',0,NULL,3,1,2,1,NULL,'dfung2000'),(20107,754910263001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','katyakolya','naja0807@gmail.com','Ekaterina Kozyr','14/10/473, UI. Akademika Yangelya','Moscow','','RUSSIAN FEDERATION','117534','79031444007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 21:47:28',0,NULL,3,1,2,1,' ','katyakolya'),(20108,815856962017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',3.99,'photographyacc','ansie_gabe','gavincie@bigpond.com','Ansie Botha','409 Brookton Hwy','Roleystone','Western Australia','AUSTRALIA','6111','0893979886','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-18 21:57:45',0,NULL,3,1,2,1,' ','ansie_gabe'),(20109,754932104001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',2,'AD1180',27.8,'hermeshine','mordikkio83','redluk@infinito.it','Luca Greco','via Calimno 25','Roma','RM','ITALY','00141','3886942503','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 22:37:57',0,NULL,3,1,3,1,' RA184575715CN\r','mordikkio83'),(20110,797723213002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','dmiljak','dominik.miljak@yahoo.com','Dominik Miljak','Gruda 147','Gruda','Konavle','CROATIA','20215','020-791-307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 22:38:26',0,NULL,3,1,3,1,'RA184574057CN\r ','dmiljak'),(20111,797723215002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','dmiljak','dominik.miljak@yahoo.com','Dominik Miljak','Gruda 147','Gruda','Konavle','CROATIA','20215','020-791-307','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 22:38:26',0,NULL,3,1,5,1,'CP240320493CN\r ','dmiljak\r欧标  \r除了c  里的再发\r2mx1.5m 背景板（蓝，绿）   1\r看看好不好包  不好包背景板就单发 '),(20112,758451257018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','gadyrdal','gadyrdal@online.no','Geir Dyrdal','Karolinervn 1 A','Trondheim','Sør Trøndelag','NORWAY','N-7021','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-18 23:14:06',0,NULL,3,1,2,1,NULL,'gadyrdal'),(20113,754951540001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ravirep1','ravirep@hotmail.com','Per Ivar Olsen','Dalheimvegen 8b','Trondheim','sør-trønderlag','NORWAY','7059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-18 23:35:13',0,NULL,3,1,3,1,' RA184575812CN\r','ravirep1'),(20114,758467830018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','robm1111','bomat3@gmail.com','Robert Maitland','Unit 2, 77 Teague Street','VICTORIA PARK','Western Australia','AUSTRALIA','6100','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-19 00:06:01',0,NULL,3,1,2,1,NULL,'robm1111'),(20115,754965513001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','scottsop','stxssab@att.net','scott soper','1845 Michigan Ave','port isabel','TX','UNITED STATES','78578-4615','(956) 943-3968','NoPaymentFailure','CheckoutComplete','Other','2011-11-19 00:22:16',0,NULL,3,1,1,1,NULL,'scottsop'),(20116,758480317018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','mathewlett','thehewlett@bigpond.com','Mathew hewlett','20 schanck drive','metford','New South Wales','AUSTRALIA','2323','0249338959','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-19 00:50:08',0,NULL,3,1,3,1,'RA184575698CN\r\r','mathewlett'),(20117,754983226001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','inc1914','bob.papa@yahoo.com','Robert H Papa','2934 E 8th St','National City','CA','UNITED STATES','91950','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 01:31:54',0,NULL,3,1,1,1,NULL,'inc1914'),(20118,815959064017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','memo_pool','memo_pool_27@hotmail.com','Guillermo Pool Uc','53<br>196','Valladolid','Yucatán','MEXICO','97780','9858563712','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 03:09:32',0,NULL,3,1,2,1,' ','memo_pool\r'),(20119,797807106002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','alejandroriverosw','ariverosw@ufl.edu','Alejandro Riveros Walker','368 Maguire Vlg<br>Apt 5','Gainesville','FL','UNITED STATES','32603-2011','(352) 846-5390','NoPaymentFailure','CheckoutComplete','Other','2011-11-19 03:34:55',0,NULL,3,1,1,1,' ','alejandroriverosw\rL   已入库  '),(20120,815982283017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',2,'AA1202',5.8,'photographyacc','estate775523','timtcel@hotmail.com','Tri City Estate Liquidators','2028 Karl Rd','Bay City','MI','UNITED STATES','48706-9736','(989) 667-9635','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 04:46:48',0,NULL,3,1,1,1,NULL,'estate775523'),(20121,815986271017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',1,'AKT052',42.8,'photographyacc','weathertim','weathertim@bigriver.net','Timothy G Simpson','6236 Althorp Cv','Lakeland','TN','UNITED STATES','38002-7004','(901) 829-5800','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 05:06:55',0,NULL,3,1,3,1,' RA184575707CN\r','weathertim'),(20122,797851135002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',2,'AKT061',74.3,'hermeshine','chikon','chinanai@mail.ru','Chingis Gazeyev','Shevchenko dom 24, GMZ','Aktobe','','KAZAKHSTAN','030000','+771336 23504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 07:31:13',0,NULL,8,1,17,0,NULL,'chikon\r\r\r\r'),(20123,758582168018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','rangirangz','koiwhio@hotmail.com','Rangi Rangitukunoa','82 Fowlds avenue, Sandringham','Auckland','North Island','NEW ZEALAND','1025','09 846 3508','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 08:59:14',0,NULL,3,1,3,1,' RA184575741CN\r','rangirangz'),(20124,873581747016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','darrenanthonykerr','dakerr@ntlworld.com','D A KERR','32 kings grove<br>wardle road','rochdale','Lancashire','UNITED KINGDOM','ol12 9hr','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 09:02:01',0,NULL,3,1,3,1,' RA184575843CN\r','darrenanthonykerr'),(20125,891904544015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','pepete1383','pepete13@gmail.com','Rémi DOMANGE','5, rue jose d arbaud','Meyrargues','Provence-Alpes-Côte d\'Azur','FRANCE','13650','0627910610','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 10:15:31',0,NULL,3,1,2,1,NULL,'pepete1383'),(20126,873609100016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',2,'AA1301',3.74,'hutongstore','pheonix707','paul.halford.post@hotmail.com','paul halford','36 foxborough road<br>lucan','co. dublin','Dublin','IRELAND','default','016211866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 10:23:52',0,NULL,3,1,2,1,' ','pheonix707\r单独发  再重新打地址'),(20127,873624211016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','33region','kolpakov921@gmail.com','Dmitry Kolpakov','Sovetskaya 29A-24','Murom','Vladimirskaya oblast`','RUSSIAN FEDERATION','602267','+79209032440','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 11:01:56',0,NULL,3,1,5,1,'CP240320502CN\r ','33region'),(20128,891946460015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','ekathinka','ekathinka@gmail.com','Elise Cox','Vardatun Studentboliger 173','Haugesund','','NORWAY','5532','45082176','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 12:02:15',0,NULL,3,1,2,1,NULL,'ekathinka'),(20129,758643564018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','silvesterv','silvestervadsl2@dodo.com.au','Silvester Valiente','194 Junction Road','Ruse','New South Wales','AUSTRALIA','2560','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-19 12:10:00',0,NULL,3,1,3,1,' RA184575786CN\r','silvesterv'),(20130,891964598015,250600315208,'Flash Softbox Diffuser for external flash SB800 580EX ',1,'AB3302',8.8,'hutongstore','azaharaferrari','azahara_sp@hotmail.com','sandra pires','rua fernando farinha 28 - 7º dt<br>lisbon','lisbon','','PORTUGAL','1950-448','(00351)919036376','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 12:46:25',0,NULL,3,1,2,1,NULL,'azaharaferrari'),(20131,891993324015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','lassep58','kjell.vennberg@gmail.com','Kjell Vennberg','Bergsättravägen 37','SODERTALJE','SODERTALJE','SWEDEN','15249','+46 911271316','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 13:49:31',0,NULL,3,1,4,1,'YW867660641CN\r ','lassep58\r欧标\r▲'),(20132,758693590018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',6,'AD1169',38.4,'photographyacc','2592kim','boardwalk@kimmartin65.wanadoo.co.uk','Kim Martin','65 South Avenue Kidlington, Kidlington','Oxford','Oxfordshire','UNITED KINGDOM','OX5 1DQ','01865372792','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-19 14:23:07',0,NULL,3,1,3,1,' RA184575667CN\r','2592kim'),(20133,755202164001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','apgv10','vgor@i.ua','Victor Gorban','per. Ostrovskogo, 13','pgt. Pokrovske','obl Dnipropetrovska','UKRAINE','53600','5638-5-00-77','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-19 15:18:45',0,NULL,3,1,5,1,'CP240320476CN\r ','apgv10\r黑加白'),(20134,755229416001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','marieinger','marieinger@hotmail.com','Ole Papsø','Marie Curies Alle 68 1.5','Aalborg Øst','Jylland','DENMARK','9220','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-19 16:19:09',0,NULL,3,1,3,1,' RA184575724CN\r','marieinger'),(20135,798038571002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',85.98,'hermeshine','diegooior','diegooio@hotmail.com','Diego Oio .','Av. senador teotonio Vilela, 4029<br>bloco 20A apto 34','Sao Paulo','Sao paulo','BRAZIL','04833-901','55 11 59243679','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-19 16:34:31',0,NULL,3,1,5,1,'CP240320480CN\r ','diegooior'),(20136,755248415001,110717761104,'New 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',36.99,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 16:52:17',0,NULL,3,1,17,0,NULL,'franznawrath'),(20137,798048728002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 16:52:18',0,NULL,3,1,17,0,NULL,'franznawrath'),(20138,798036377002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','mbet5479','m.parma@yahoo.it','massimo bettinzoli','via puccini 6','parma','PR','ITALY','43123','0521-2403655','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 16:30:07',0,NULL,3,1,3,1,' RA184575857CN\r','mbet5479\rSoftbox   $15'),(20139,798048729002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','franznawrath','fnawrath@gmail.com','Franz Nawrath','Varas 854 - Dpto 304','Temuco','Araucania','CHILE','4791250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 16:52:19',0,NULL,3,1,3,1,'RA184574600CN\r ','franznawrath\r可调ND镜 77mm     1\r肩带 无字   1\r肥皂盒 柔光罩   580EX   1\r'),(20140,798061204002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','dinamitbreiin','dinamit@narod.ru','Pavel Kolikov','st. Zur-Uram 8-90','Kazan','Tatarstan','RUSSIAN FEDERATION','420088','+79093075579','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 17:15:59',0,NULL,3,1,2,1,NULL,'dinamitbreiin'),(20141,798062107002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','tomsjones14','tomsjones@hotmail.co.uk','Tom Jones','55 Oaklands Road<br>Chirk Bank','Clywd','Wrexham','UNITED KINGDOM','LL14 5DW','01691774572','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-19 17:16:59',0,NULL,3,1,4,1,'YW867660652CN\r ','tomsjones14\r+白布  \r▲'),(20142,755260675001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','geabeckjung','geabeckjung@yahoo.com','hoil byun','1700 Butler Pike<br>Apt 24B','conshohocken','PA','UNITED STATES','19428-1267','(267) 241-8539','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-19 17:17:18',0,NULL,3,1,3,1,' RA184575772CN\r','geabeckjung'),(20143,755278283001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','danros75','rosenthal46@gmail.com','dan rosenthal','nizana<br>13','givataim','tel aviv','ISRAEL','53364','03-7311960','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 17:47:22',0,NULL,3,1,2,1,' ','danros75'),(20144,755369113001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 20:27:48',0,NULL,3,1,17,0,NULL,'allapopova19'),(20145,755369644001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 20:27:47',0,NULL,3,1,3,1,' RA184575738CN\r','allapopova19\rc里面的接口环换成49cm的\r除了c里面的再发\r圆形柔光棚 40cm   1\rlenspen    2 \r已入库'),(20146,798170710002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 20:27:49',0,NULL,3,1,17,0,' ','allapopova19\r圆形柔光棚 40cm   1\r方镜普通托架（三槽）  1\r'),(20147,892280666015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','*jayrou*','yfourart@gmail.com','james roughley','1 Sligo Mews,Aquila Road,St Helier','Jersey','Channel Islands','UNITED KINGDOM','je2 3zx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-19 21:15:51',0,NULL,3,1,2,1,NULL,'*jayrou*'),(20148,798217830002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','tv9276118','vrchotat@comcast.net','ANTHONY VRCHOTA','3135 S Keeler Ave','CHICAGO','IL','UNITED STATES','60623-4825','(773) 523-8709','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-19 21:53:07',0,NULL,3,1,1,1,NULL,'tv9276118'),(20149,755434627001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jtt30-4','buddatay05@hotmail.com','Tasha Kildoo','2395 W Willow Breeze Dr','Chino Valley','AZ','UNITED STATES','86323-4127','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-19 22:38:53',0,NULL,3,1,1,1,NULL,'jtt30-4\r黑色 '),(20150,755433890001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','fabian612011','fabian61_60@hotmail.com','fabian maldonado loyola','calle 27 #219 jardines de santa clara','ecatepec','estado de mexico','MEXICO','55450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 22:42:54',0,NULL,3,1,2,1,NULL,'fabian612011'),(20151,874032239016,260894474713,'New Studio Light 800W Continuous Lighting Complete Kit with background support',1,'AKT087',102,'hutongstore','bloodgroup801','vegetablemarket@hotmail.com','Francis Symons','C/Mar Tirreno 52','Torre de la Horadada','Alicante','SPAIN','03191','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-19 22:44:49',0,NULL,3,1,4,1,'YW867660663CN\r ','bloodgroup801\r欧标\r▲'),(20152,798246957002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','akds18','akila_18@hotmail.com','Mr. A.Y De Silva','40/4B, Wattegedara road','Maharagama','Western','SRI LANKA','10280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 23:00:08',0,NULL,3,1,2,1,NULL,'akds18'),(20153,798252506002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',56.5,'hermeshine','jimterry5854','james7839@sbcglobal.net','James Terry','40 Norman St.','Waterford','CT','UNITED STATES','06385','(860) 443-8128','NoPaymentFailure','CheckoutComplete','Other','2011-11-19 23:14:44',0,NULL,3,1,1,1,NULL,'jimterry5854'),(20154,795720889002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','jeringoso91','jero_supra@hotmail.com','Jeronimo Mauregui','479 n°2613','La Plata','Buenos Aires','ARGENTINA','1896','+5402214801344','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-19 23:54:38',0,NULL,3,1,3,1,' RA184575769CN\r','jeringoso91\r1.6*3灰色背景布   '),(20155,759025799018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','ianop2011','ianpelly@ireland.com','Ian Pelly','THE BUNGALOW<br>HAcketstown','carlow','Carlow','IRELAND','','0868538504','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 02:30:51',0,NULL,3,1,17,0,NULL,'ianop2011'),(20156,759040131018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','rchalberg','rchalberg@cox.net','R. CHALBERG','6884 Alsacia St','SAN DIEGO','CA','UNITED STATES','92139-2502','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 03:16:32',0,NULL,3,1,1,1,NULL,'rchalberg \rXXXL     已入库 '),(20157,816521046017,270794124972,'Big Travel Bag for Photo Equipment w Padded Dividers',1,'AD1164',50,'photographyacc','ianop2011','ianpelly@ireland.com','Ian Pelly','THE BUNGALOW<br>HAcketstown','carlow','Carlow','IRELAND','','0868538504','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 03:39:16',0,NULL,3,1,4,1,'YW867660674CN\r ','ianop2011\r反光板支架  1\r灯架      1\r红边套装包   1\r▲\r'),(20158,798335230002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','watermar50','robin-bird@juno.com','robin Waterman','1500 Little Whaleneck Rd','merrick','NY','UNITED STATES','11566-1624','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-20 03:54:53',0,NULL,3,1,1,1,NULL,'watermar50'),(20159,798361688002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','chikon','chinanai@mail.ru','Chingis Gazeyev','Shevchenko dom 24, GMZ','Aktobe','','KAZAKHSTAN','030000','+771336 23504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 06:01:19',0,NULL,8,1,17,0,NULL,'chikon'),(20160,755551192001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','chikon','chinanai@mail.ru','Chingis Gazeyev','Shevchenko dom 24, GMZ','Aktobe','','KAZAKHSTAN','030000','+771336 23504','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 06:02:47',0,NULL,3,1,8,1,'CP244548391CN ','chikon\r6片装的滤镜袋 1 \r灯架包薄     1\r灯架  2m    2\r单灯头 欧标    2\r反光伞     2\r航空153运费   DHL443'),(20161,798378138002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'',55,'hermeshine','rossann78','rossannreeves@yahoo.com.au','rossann reeves','4 Boyle avenue','rockingham','Western Australia','AUSTRALIA','6168','0895276207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 07:27:36',0,NULL,3,1,3,1,'RA184574406CN\r ','rossann78\r▲'),(20182,755867251001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','tacgear-nl','wargod2@xs4all.nl','M. Peter','Paradijspoort 32','Delft','','NETHERLANDS','2611 MB','+31643434933','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 17:15:30',0,NULL,3,1,3,1,' RA184575928CN\r','tacgear-nl'),(20162,816446940017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','gal.a','gtribute@gmail.com','Antal Gal','Bajnok utca 15','Budapest','','HUNGARY','1063','+36209924796','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 08:39:54',0,NULL,3,1,17,0,NULL,'gal.a'),(20163,874222015016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',2,'AB3329',61.98,'hutongstore','artsagittum','sales@johnarrow.org','John Arrow','29 Billington Gardens, Hedge End','Southampton','Hampshire','UNITED KINGDOM','so30 2ax','01489790934','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 08:52:18',0,NULL,3,1,4,1,'YW867660685CN\r ','artsagittum\r▲'),(20164,892545645015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','mackerg4','bob@marketpro.co.uk','Mr Robert Kerr','Lea Line Cottage<br>Lea','Ross-on-Wye','Herefordshire','UNITED KINGDOM','HR9 7LQ','01989750279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 09:33:44',0,NULL,3,1,3,1,' RA184575755CN\r','mackerg4'),(20165,798418386002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','sottelkrauze','krauze2003@mail.ru','Viktor Krauze','Voroshilova 62-39','Ust-Kamenogorsk','VKO','KAZAKHSTAN','070002','+77052811111','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-20 09:42:08',0,NULL,3,1,8,1,'CP240320374CN\r ','sottelkrauze\r欧标 '),(20166,892572688015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','joaquin1153','joaquinfocus@hotmail.com','Hermanos Vargas S.C ( at. Joaquin Vargas Arenas)','Lechuza S/N','Paradas','Andalucía Ceuta y Melilla','SPAIN','41610','607738771','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-20 10:26:09',0,NULL,3,1,4,1,'YW867660696CN\r ','joaquin1153\r已签收\r▲'),(20167,798437228002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','luckydube777','david.brown.2007@hotmail.com','david brown','83 lake entrance rd oak flats','shellhabour','New South Wales','AUSTRALIA','2529','0242569543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 10:26:10',0,NULL,3,1,2,1,NULL,'luckydube777'),(20168,759103214018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','dirty-steing','cdott@bigpond.net.au','rocky rocky','71 fenton ave<br>christies beach','adelaide','South Australia','AUSTRALIA','5165','0881865199','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-20 10:54:43',0,NULL,3,0,2,1,NULL,'dirty-steing\r白色    '),(20169,816105405017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','anthony_nardelli','anthony_nardelli@hotmail.com','Anthony Nardelli','82 Giancola Crescent','Maple','ON','CANADA','L6A 2T5','(905) 417-9187','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 11:04:50',0,NULL,3,1,2,1,NULL,'anthony_nardelli'),(20170,816662924017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','traceyd8064','t-davis5@sky.com','Tracey Davies','50 Caemawr Gardens, Porth','Mid Glamorgan','Rhondda Cynon Taff','UNITED KINGDOM','CF39 9DB','07903437876','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 11:27:30',0,NULL,3,1,2,1,NULL,'traceyd8064'),(20171,755659225001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','johncat49','john.e.catalano@gmail.com','John Catalano','unit 26,block 9<br>Amicitia circuit','Northmead','New South Wales','AUSTRALIA','2152','0296316343','PayPalPaymentInProcess','CheckoutComplete','OtherInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,'johncat49'),(20172,759205071018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',35.9,'photographyacc','stuart5137','info@stuartvideoproductions.com','Stuart Dwyer','20 Prime Court','Berwick','Victoria','AUSTRALIA','3806','0414826723','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-20 12:19:43',0,NULL,3,1,3,1,' RA184575790CN\r','stuart5137'),(20173,798466102002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','strat66res','nigelsj@hotmail.co.uk','Nigel Jones','1 Loughborough Avenue, Tunstall','Sunderland','Tyne and Wear','UNITED KINGDOM','SR2 9AT','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 12:25:58',0,NULL,3,1,2,1,NULL,'strat66res'),(20174,755696542001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','2010defendertd5','ntplaster@gmail.com','P Butler','GPO Box 308','Darwin','Northern Territory','AUSTRALIA','0801','0488945420','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 12:58:52',0,NULL,3,1,4,1,'YW867660792CN\r ','2010defendertd5\r新地址：\rP Butler\r23/43 Duke Street\rStuart Park \rNT 0820, \rAustralia\r0488945420▲\r'),(20175,892663528015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','jacqui.burton','jacqui_burton@yahoo.co.uk','Jacqui Burton','7 Wilding Road<br>Ball Green','Stoke on Trent','Staffordshire','UNITED KINGDOM','ST6 8BA','07963289013','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-20 13:01:40',0,NULL,3,1,3,1,' RA184575809CN\r','jacqui.burton'),(20176,755737906001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','ivlichev65sergey','ivlichev65@mail.ru','Sergey Ivlichev','Gagarina d.32, kv. 42,','Zhitomir','Zhitomir','UKRAINE','10002','+380675030950','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-20 14:16:17',0,NULL,3,1,5,1,'CP240320459CN\r ','ivlichev65sergey'),(20177,892741352015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','pacomakis47','pacomakis@gmail.com','Francisco Menéndez López','C/Feria de Jerez nº 7-Esc 4-4-A<br>Fuengirola','Malaga','Andalucía Ceuta y Melilla','SPAIN','29640','605627776','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-20 14:58:23',0,NULL,3,1,2,1,NULL,'pacomakis47'),(20178,8881321801216040,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag',1,'AO0011',81.99,'aliexpress','1005314880','dj.aisberg@gmail.com','Artyom Kuptsov	','Yubilejnaya str 83-15','Berezniki','Ru','RUSSIAN FEDERATION	','618416','+7 904 3689745',NULL,NULL,NULL,'2011-11-20 15:00:16',0,NULL,3,1,5,1,'CP240320462CN\r ','1.6x2.1m * 1 (粉色)'),(20200,8881321838620395,111,'3mx6m 背景布 2块（ 白  + 黑）',2,'',0,'hutongstore','krupi2','krupi2@pobox.sk','Peter Krupas','Brett Supplies Ltd.<br>130-131 Ashbourne ','Industrial Estate','Ashbourne, Meath','IRELAND','','',NULL,NULL,NULL,'2011-11-21 01:23:40',0,NULL,3,0,4,1,'YW867660722CN\r ',' 加三个夹子\r▲'),(20179,8881321801900155,111,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',2,'AD1128',35.98,'aliexpress','1005316685  ','raphaelmilian@yahoo.com.br','Raphael Milian	','Av. Patricio Caldeira de Andrade, 627 bloco A ap 401','florianopolis','santa catarina	','BRAZIL','88085150','+55 48 33647894',NULL,NULL,NULL,'2011-11-20 15:11:40',0,NULL,3,1,3,1,' RA184575980CN\r','抓紧时间发货，万一缺货通知我一声 '),(20180,798585215002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','cmiq2301','miquelnolla@telefonica.net','Casimir Miquel Nolla','Pompeu Fabra, 4 B','Botarell (Tarragona)','Cataluña','SPAIN','43772','977833022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-20 15:15:22',0,NULL,3,0,3,1,' RA184575976CN\r','cmiq2301\rXXL '),(20181,755792836001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','hw4m','dgibiuh@yahoo.com','H.A.A. van Deventer','111/9 Moo 9<br>Pimanchon Villages 4','Khon Kaen','Khon Kaen','THAILAND','40000','043322396','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 15:45:33',0,NULL,3,1,3,1,' RA184575675CN\r','hw4m'),(20183,798703608002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','nickee87','nykacek@gmail.com','Nikola Schwarzová','Božkovská 32','Plzeň','Czech Republic','CZECH REPUBLIC','32600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 17:39:25',0,NULL,3,1,2,1,NULL,'nickee87'),(20184,759444152018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','indioteatro','indioapache70@hotmail.com','salvador mena','c/ constanilla corta nº114(urb.sta margarita)','la linea','Andalucía Ceuta y Melilla','SPAIN','11300','651914270','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 18:08:01',0,NULL,3,0,2,1,NULL,'indioteatro\r白色 '),(20185,798770358002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','kostantbrother','cigsos@yahoo.es','Christopher  Gomez Solana','paseo colon<br>22 5b','irun','País Vasco','SPAIN','20302','678525998','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 18:39:31',0,NULL,3,1,3,1,' RA184575931CN\r','kostantbrother'),(20186,798771288002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','laurts76','leesmaa@yahoo.com','Lauri Leesmaa','Põhja 8a/1-20','Keila','Harju','ESTONIA','76610','+3725256741','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 18:43:45',0,NULL,3,1,2,1,NULL,'laurts76\r欧标'),(20187,759517371018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','hollister6019','brande_murray@yahoo.com','brandy murray','3625 meadow creek ln','raleigh','NC','UNITED STATES','27616-8999','(910) 465-7097','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 19:02:56',0,NULL,3,1,1,1,NULL,'hollister6019'),(20188,798807365002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',60,'AA1310',329.4,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 19:11:11',0,NULL,3,1,3,1,' RA184575945CN\r','blinker-182\r不要原包装，只包笔就行'),(20189,759561220018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','gavbc','ghaworth@talktalk.net','Gavin Haworth','14 The Cliffs','Heysham','Lancashire','UNITED KINGDOM','LA31NY','01524859645','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 19:39:47',0,NULL,3,0,17,0,NULL,'gavbc'),(20190,756033267001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','swsbrg','myphases@hotmail.com','stephanie briggs','3831 e.147th','cleveland','OH','UNITED STATES','44128','(216) 921-0407','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-20 19:42:17',0,NULL,3,0,1,1,NULL,'swsbrg\r黑色'),(20191,759567689018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','gavbc','ghaworth@talktalk.net','Gavin Haworth','14 The Cliffs','Heysham','Lancashire','UNITED KINGDOM','LA31NY','01524859645','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 19:42:38',0,NULL,3,0,3,1,' RA184576000CN\r','gavbc\r1.6*2.1白+黑  '),(20192,759586649018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','gerryharry2010','gezherd@googlemail.com','Geraldine  Herd','56 Atlantic Park View<br>West End','Southampton','Hampshire','UNITED KINGDOM','SO18 3RQ','02380470280','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 20:04:40',0,NULL,3,1,3,1,' RA184575959CN\r','gerryharry2010'),(20193,756060207001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','zuhmia','suhmia@googlemail.com','Suvi Ahola','Tampellan Esplanadi 8 A 22','Tampere','','FINLAND','33100','+358456326520','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 20:08:16',0,NULL,3,1,3,1,' RA184575914CN\r','zuhmia'),(20194,798954170002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','johnny_bjorling','johnny.bjorling@gmail.com','Johnny Bjorling','Bergdalsvagen 5','Aby','','SWEDEN','61633','+461160535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 21:34:16',0,NULL,3,1,17,0,NULL,'johnny_bjorling'),(20195,798954171002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','johnny_bjorling','johnny.bjorling@gmail.com','Johnny Bjorling','Bergdalsvagen 5','Aby','','SWEDEN','61633','+461160535','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-20 21:34:17',0,NULL,3,1,3,1,' RA184575993CN\r','johnny_bjorling\r永诺 CTR-301P 触发器    1\r永诺 CTR-301P 接受器   2\r反光板 80cm 2合1       1'),(20196,817195492017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','gal.a','gal.antal69@gmail.com','Antal Gal','Bajnok utca 15','Budapest','','HUNGARY','1063','+36209924796','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-20 22:01:42',0,NULL,3,1,2,1,NULL,'gal.a\rcanon 反接环  52mm   1\r绿叶 UV  52mm    1'),(20197,799017328002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','emanuele.sforza','emanuele.sforza@gmail.com','Emanuele Sforza','Fornace, 30','Castel Guelfo','BO','ITALY','40023','+393357581910','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-20 23:25:40',0,NULL,3,0,3,1,' RA184575684CN\r','emanuele.sforza\r3XL  已入库'),(20198,874986293016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jabocangas','ebay@jaboweb.com','Jose Manuel Benavides Orge','Hio Limens Barreira, 35','Cangas de Morrazo','Galicia','SPAIN','36940','676319433','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-20 23:46:02',0,NULL,3,1,4,1,'YW867660711CN\r ','jabocangas\r欧标\r▲'),(20199,893310384015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','kooregani89','kooregani@gmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-21 00:38:21',0,NULL,3,1,3,1,' RA184575962CN\r','kooregani89'),(20201,8881321838832852,111,'1.6x2.1 背景布  2块（ 黑 + 灰）',2,'',0,'photographyacc','liokos_t','liokos_t@hotmail.com','Thomas Liokos','Orestou 2','Argos Orestiko, Kastoria','','GREECE','52200','',NULL,NULL,NULL,'2011-11-21 01:27:12',0,NULL,3,0,3,1,' RA184575865CN\r','让小冯给客户发个邮件确认一下我们从paypal里看到的地址对不对 \r\r'),(20202,759801633018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','cricketcricket2004','redgrovers@aapt.net.au','Sandra Redgrove','C/- LES RUSSELL & SON<br>75 FLEET ST','BRANXTON','New South Wales','AUSTRALIA','2335','0409582858','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 02:09:57',0,NULL,3,1,2,1,NULL,'cricketcricket2004'),(20203,759828302018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','renzl24','brenzi@metlife.com','Brian E Renzi','23 Covel Cir','Warwick','RI','UNITED STATES','02888-3203','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 03:18:50',0,NULL,3,1,1,1,NULL,'renzl24'),(20204,817363509017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','annette3433','amazonlady6@hotmail.com','Annette Dunn','34 Turrum Street<br>Scarness','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-21 04:22:21',0,NULL,3,1,4,1,'YW867660733CN\r ','annette3433\r▲'),(20205,759854457018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','ruske75','russkenn@internode.on.net','Russell Kennedy','c/o Wipro<br>Level 1, 19 Grenfell St','Adelaide','South Australia','AUSTRALIA','5000','0416030881','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 04:50:08',0,NULL,3,1,17,0,NULL,'ruske75'),(20206,759853659018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','ruske75','russkenn@internode.on.net','Russell Kennedy','c/o Wipro<br>Level 1, 19 Grenfell St','Adelaide','South Australia','AUSTRALIA','5000','0416030881','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 04:46:29',0,NULL,3,1,4,1,'YW867660744CN\r ','ruske75\r斜臂  1\r反光板支架    1\r▲'),(20207,799148979002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dan.lam','daneeeyo@hotmail.com','Daniel Lam','235 Milliken Meadows Dr','Markham','ON','CANADA','L3R0V9','(647) 832-2832','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 05:12:51',0,NULL,3,1,2,1,NULL,'dan.lam'),(20208,756322044001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','jihadaj1','jihadaj@yahoo.com','Jihad Aravassery','P O Box 98536<br>Saniya','Al Ain','Abu Dhabi','UNITED ARAB EMIRATES','98536','00971507124261','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 05:43:35',0,NULL,3,1,2,1,NULL,'jihadaj1'),(20209,799162739002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','541148657042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 06:19:55',0,NULL,3,1,3,1,' RA184575619CN\r','2010bousosheila\r申报$15'),(20210,799171336002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','artgnezdo','lucheya@ya.ru','Svetlana Garadja','Varshavskoe shosse dom 70 korpus 2 kvartira 57','Moskow','','RUSSIAN FEDERATION','117556','+79104341636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 07:04:31',0,NULL,3,1,2,1,NULL,'artgnezdo'),(20211,8881321861965259,111,'欧标头',2,'',0,'hermeshine','maesro110','maestro110@mail.ru','Roman Platok','60 Bilu str.','Rehovot','Shfela','ISRAEL','76442','972508493010',NULL,NULL,NULL,'2011-11-21 07:52:45',0,NULL,3,0,3,1,'RA184574383CN\r ',NULL),(20212,756346119001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','jmchtizen','jmdamez@free.fr','jean marc damez','4 allée A av de la rhônelle','Aulnoy les Valenciennes','Nord-Pas-de-Calais','FRANCE','59300','09.52.42.47.65','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-21 07:55:07',0,NULL,3,1,3,1,'RA184574370CN\r ','jmchtizen'),(20213,759895572018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',63,'photographyacc','remiandreheggen','remiandre80@hotmail.com','Remi Andre Heggen','Slattum Terrasse 29A<br>1480 Slattum','Slattum','Slattum','NORWAY','1480','004748482808','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 08:15:03',0,NULL,3,1,4,1,'YW867660755CN ','remiandreheggen\r黑色\r▲'),(20214,889436430015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',21.2,'hutongstore','robertasw','roberta_sw@yahoo.com.br','Lauro Roberto Borges','Rua Monsenhor Gercino, 73','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 08:57:27',0,NULL,3,1,3,1,'RA184574352CN\r ','robertasw'),(20215,893482357015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','lemmylemur','lemmy@netatonce.net','Timmy Fagerlund','Kulturmejeriet<br>Stora Södergatan 64','LUND','','SWEDEN','222 23','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 08:40:09',0,NULL,3,1,2,1,NULL,'lemmylemur'),(20216,799202944002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mpepe20','mpepe1982@gmail.com','Magne-Chem Kft.','Jókai u. 22. fsz 2.','Budapest','Budapest','HUNGARY','1195','307478629','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 09:28:40',0,NULL,3,1,3,1,'RA184574318CN\r ','mpepe20'),(20217,799205447002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','esotrance','trancedelica@gmail.com','Boris Kramarenko','Kovrov street, 4-1-188','Moscow','','RUSSIAN FEDERATION','109147','926-284-24-24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 09:39:07',0,NULL,3,1,3,1,'RA184574410CN\r ','esotrance'),(20218,756372203001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','charlysf2011','carlosbertalo@gmail.com','carlos bertalo lopez','c/ real alta nº2, 1º_La Graña_','ferrol','Galicia','SPAIN','15590','650074688','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-21 09:43:24',0,NULL,3,1,4,1,'YW867660766CN ','charlysf2011\r▲'),(20219,893506320015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','fabrizioferrante','valentinoferrante@virgilio.it','VALENTINO FERRANTE','via sabotino 56','GIULIANOVA','TE','ITALY','64022','0858004945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 09:54:21',0,NULL,3,1,3,1,'RA184574423CN\r ','fabrizioferrante'),(20220,875200396016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','rosielle0911','gian14_blue@yahoo.com','Ma Rosielle fernandez','86 pells street','reading','Berkshire','UNITED KINGDOM','RG1 2NR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 09:54:04',0,NULL,3,1,2,1,NULL,'rosielle0911'),(20221,797496758002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','naomah','khirael@msn.com','rinnely','rua moises ferreira 136','curitiba','parana','BRAZIL','81880320','041 33492098','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 10:45:06',0,NULL,3,1,3,1,'RA184574335CN\r ','naomah'),(20222,817458856017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',18,'photographyacc','yetbo2009','yetbomd@yahoo.ie','celso caliguia','111 bantry square<br>waterville','blanchardstown','Dublin','IRELAND','15','0871245029','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 10:56:10',0,NULL,3,1,3,1,'RA184574366CN\r','yetbo2009'),(20223,759948646018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','timay554v','sylvainguimond@gmail.com','Sylvain Guimond','2850, des Hirondelles','Bécancour','QC','CANADA','G9H 4M5','(819) 698-3005','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 11:27:45',0,NULL,3,1,3,1,'RA184574445CN\r ','timay554v'),(20224,893563014015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',126,'hutongstore','moh1t','moh1t@hotmail.com','mohit pattni','77 Clarkson Avenue<br>Tapping','Perth','Western Australia','AUSTRALIA','6065','0892061373','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 12:26:53',0,NULL,3,1,4,1,'YW867660770CN ','moh1t\r▲'),(20225,759981116018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','rafael.nunescruz','ncrafa@yahoo.com.br','Rafael Nunes Cruz','Av. Getúlio Vargas, 990<br>bloco 24 apartamento 14','Osasco','São Paulo','BRAZIL','06233020','55 11 36025138','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 13:09:38',0,NULL,3,1,3,1,'RA184578972CN\r ','rafael.nunescruz'),(20226,756431561001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','danielaires','daniel_aires@globo.com','Daniel Pereira','SQN 307 bloco D apt 207','Brasilia','Distrito Federal','BRAZIL','70746-040','+556191076948','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-21 13:11:22',0,NULL,3,1,2,1,NULL,'danielaires'),(20227,817502910017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','starleos','helensaunders1@hotmail.com','Jonathon Stebbing','1st Floor<br>308 Kororoit Creek Road','Williamstown','Victoria','AUSTRALIA','3016','0393999372','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 13:14:02',0,NULL,3,1,2,1,NULL,'starleos'),(20228,799273261002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','luckydube777','david.brown.2007@hotmail.com','david brown','83 lake entrance rd oak flats','shellhabour','New South Wales','AUSTRALIA','2529','0242569543','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 13:25:27',0,NULL,3,1,2,1,NULL,'luckydube777'),(20229,760009192018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','dazzi-b','dazzi_b@tiscali.co.uk','Darran Buckley','2 Cardinals Court<br>Cawood','Selby','North Yorkshire','UNITED KINGDOM','YO8 3TD','07773411991','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 14:27:36',0,NULL,3,1,3,1,'RA184578969CN\r ','dazzi-b'),(20230,893627109015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','nikoul','nkoul@freemail.gr','NIKOLAOS KOULOURIS','FRIDERIKOU SMITH 53','ATHENS','ATTIKI','GREECE','11745','6973627400','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 14:57:21',0,NULL,3,1,2,1,NULL,'nikoul'),(20231,799337034002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','bigdanielparrot','bigdr4497@aol.com','Daniel F. Robinson','7 Inland Rd','Marion','MA','UNITED STATES','02738','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 16:12:38',0,NULL,3,1,1,1,NULL,'bigdanielparrot'),(20232,817583326017,270748975009,'Hot Shoe Protector Cover Cap for Sony Alpha A550 A900',1,'AA1205',2.5,'photographyacc','zebulon08','alaindjoudi@aol.com','Alain Djoudi','7 rue des forges','Sedan','Champagne-Ardenne','FRANCE','08200','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 16:30:57',0,NULL,3,1,2,1,NULL,'zebulon08'),(20233,756513997001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','mjcole1982','mjcole82@gmail.com','Danielle Rideout','57 Bald Mountain Dr','Bangor','ME','UNITED STATES','04401-2349','(207) 852-9348','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-21 16:47:30',0,NULL,3,1,1,1,NULL,'mjcole1982'),(20234,893689469015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',2,'AKT015',98,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 16:59:03',0,NULL,3,1,5,1,'CP240302388CN ','leifs123\r欧标\r申报$20\r两块黑布 两块白布  '),(20235,893678199015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','abatarphoto','bjornmoller@telia.com','Bjorn Moller','Heljestrandsgatan 20 B','Eskilstuna','Sweden / Europe','SWEDEN','S63344','+46-16-136219','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-21 17:15:46',0,NULL,3,1,2,1,NULL,'abatarphoto\r欧标'),(20236,756537425001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',3,'AA1312',4.5,'hermeshine','krumeline72','lkaarboe@online.no','Linda Sandven Kaarbø','Gjethushaugen 7','Kolltveit','Kolltveit','NORWAY','5360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 17:35:38',0,NULL,3,1,17,0,NULL,'krumeline72'),(20237,893710836015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','thecatdozer','csmiff@screaming.net','COLIN SMITH','13Front Street','Fishburn','Cleveland','UNITED KINGDOM','TS214AN','01740622678','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-21 17:35:39',0,NULL,3,1,3,1,'RA184574397CN\r ','thecatdozer'),(20238,799384229002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','krumeline72','lkaarboe@online.no','Linda Sandven Kaarbø','Gjethushaugen 7','Kolltveit','Kolltveit','NORWAY','5360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 17:49:39',0,NULL,3,1,3,1,'RA184574349CN\r ','krumeline72\r麂皮    3\rCanon D8 单肩包     1'),(20239,756548647001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.15,'hermeshine','vickysmart1969','vsmart1@btinternet.com','vicky smart','44 sugden road','worthing','West Sussex','UNITED KINGDOM','bn11 2jl','01903200865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-21 17:58:02',0,NULL,3,1,2,1,NULL,'vickysmart1969'),(20240,760108382018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','curt-28','curtis_dafoe@hotmail.com','Curtis Dafoe','51 PRISCILLA\'S Place','Barrie','ON','CANADA','L4N5X6','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 18:08:16',0,NULL,3,1,2,1,NULL,'curt-28'),(20241,893774971015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','focus_diy','ryannmorris@btinternet.com','Ryan Morris','56 Bedlormie Drive<br>Blackridge','Bathgate','West Lothian','UNITED KINGDOM','EH48 3RT','01501753621','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-21 19:01:22',0,NULL,3,1,4,1,'YW867660781CN ','focus_diy\r白加黑\r▲'),(20242,760146393018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','dremod2899','tintype54@yahoo.com','tom davison','21W551 North Ave<br>Apt 112','lombard','IL','UNITED STATES','60148-1154','(630) 244-8802','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 19:12:02',0,NULL,3,1,1,1,NULL,'dremod2899'),(20243,760182251018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','zairizain','zairizain@yahoo.com','Ahmad Zairi Mohd Zain','32 Schilletter Village<br>Apartment  A','Ames','IA','UNITED STATES','50010','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 20:03:02',0,NULL,3,1,1,1,NULL,'zairizain'),(20244,817758877017,270745053720,'NEW WF-6662A FANCIER Pro Tripod with Ball head bag',1,'AE1601',62,'photographyacc','supermodels2000','info@supermodels.com.au','Paul Wilcox','33 Borambil Place','Oyster Bay','New South Wales','AUSTRALIA','2225','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-21 21:11:02',0,NULL,3,1,4,1,'YW867661573CN ','supermodels2000\r▲'),(20245,817754063017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','matthijs.v.g','matthijs.v.g@orange.nl','Matthijs Gooswilligen, van','Torenmolen 30','PAPENDRECHT','','NETHERLANDS','3352VG','078-6182866','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 21:14:54',0,NULL,3,1,2,1,NULL,'matthijs.v.g'),(20246,817803559017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','shur777','shurmur@gmail.com','Alexander  Muravich','Uziel st. 8 Apartment 16','Petah-Tikva','Israel','ISRAEL','49381','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 22:32:26',0,NULL,3,1,3,1,'RA184574511CN\r ','shur777\r白色    '),(20247,760277339018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',1,'',80,'photographyacc','michael.jenkin','michael.jenkin@usa.net','Michael Jenkin','Suite 49<br>239 Magill Road','Maylands','South Australia','AUSTRALIA','5069','0883666573','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-21 22:52:15',0,NULL,3,1,3,0,'RA184578986CN\r ','michael.jenkin'),(20248,756718195001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mindenwally2','mindenwally@juno.com','John Brooks','1611 Olua St','Minden','NV','UNITED STATES','89423-4423','(775) 782-9148','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-21 22:55:20',0,NULL,3,1,1,1,NULL,'mindenwally2'),(20249,760280015018,280774576148,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',37.99,'photographyacc','jevadamir','damirjevtic@gmail.com','Damir Jevtic','Save Jugo Bujkove 23','Rijeka','Primorsko-goranska zupanija','CROATIA','51000','00385915720398','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-21 22:59:19',0,NULL,3,1,3,1,'RA184574499CN\r ','jevadamir\r欧标'),(20250,756731717001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-22 00:00:15',0,NULL,3,1,3,1,'RA184574321CN\r ','garyshark024\r欧标'),(20251,8881321923367426,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m',1,'AE2501',25.99,'aliexpress','1005363622','photos1on1@hotmail.com','grant campbell	','4A ferretti grove Lower hutt','wellington','new zealand	','NEW ZEALAND	','5011','+064 03 9387626',NULL,NULL,NULL,'2011-11-22 00:56:07',0,NULL,3,1,3,1,'RA184574715CN\r ',NULL),(20303,8881322012381068,111,'x2 115W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT049',27.89,'aliexpress','1005377382','catricio.paris@gmail.com','Catricio BET	','12 Ter, Av. Emile Zola','Poissy','Poissy','FRANCE','78300','+33 659003727',NULL,NULL,NULL,'2011-11-23 01:39:41',0,NULL,7,0,18,0,NULL,NULL),(20252,799619001002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','rhou1631','rhough2@cogeco.ca','Robert Hough','5  Ohare Street','Belleville','ON','CANADA','K8P4R9','(613) 966-1495','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 01:47:45',0,NULL,3,1,3,1,'RA184574508CN\r ','rhou1631'),(20253,817874817017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','ew7733','cw_rf@yahoo.com','Chi Wang','22336 Lost Branch Cir','Ashburn','VA','UNITED STATES','20148-7501','(703) 858-0349','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 01:50:36',0,NULL,3,1,1,1,NULL,'ew7733'),(20254,760353362018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','supertodd64','jgamtodd@bigpond.net.au','John Todd','64 J. Hickey Ave.','Gladstone','Queensland','AUSTRALIA','4680','49787008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 02:54:03',0,NULL,3,1,3,1,'RA184574437CN\r ','supertodd64'),(20255,799034332002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','bartechiari10','bartechiari@hotmail.com','Philippe Chiari or Carnino Santos','129 SW 15th St','Deerfield Beach','FL','UNITED STATES','33441-6756','(754) 366-1716','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-22 02:50:02',0,NULL,3,1,1,1,NULL,'bartechiari10'),(20256,817941169017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','josearrunategui','sabaticonegro@hotmail.com','Jose arrunategui','Recavarren 1371 Dpto 403 Surquillo','Lima','','PERU','34','5114420057','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 06:07:27',0,NULL,3,1,17,0,NULL,'josearrunategui'),(20257,799687661002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','restefond','pfrance@numericable.fr','Franceschelli Patrick','29 av mendiguren','nice','06','FRANCE','06000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:13:55',0,NULL,3,1,17,0,NULL,'restefond'),(20258,799687878002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','josearrunategui','sabaticonegro@hotmail.com','Jose arrunategui','Recavarren 1371 Dpto 403 Surquillo','Lima','','PERU','34','5114420057','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:14:29',0,NULL,3,1,2,1,NULL,'josearrunategui\r柔光伞110cm    1\r大力夹   1'),(20259,756834682001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','restefond','pfrance@numericable.fr','Franceschelli Patrick','29 av mendiguren','nice','06','FRANCE','06000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:15:39',0,NULL,3,1,17,0,NULL,'restefond'),(20260,799688730002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','restefond','pfrance@numericable.fr','Franceschelli Patrick','29 av mendiguren','nice','06','FRANCE','06000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 06:19:29',0,NULL,3,1,3,1,'RA184574587CN\r ','restefond\r新款内胆包 L  Nikon    1\r带水平仪 热靴保护盖    1\r2螺丝井字扳手       1\r'),(20261,894126726015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','igor2656','go6ik@inbox.lv','Igors Gracovs','Druvienas iela 17-18','Riga','Latvia','LATVIA','lv1079','0037126563525','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-22 08:24:18',0,NULL,3,1,3,1,'RA184574701CN ','igor2656'),(20262,756870054001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','vanda_c_oliveira','vanda.c.oliveira@gmail.com','Vanda Oliveira Marques','Urbanização da Matinha, Edificio Verde<br>Rua 2, 3º Esq.º','Lisboa','Portugal','PORTUGAL','1950-073','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 09:11:20',0,NULL,3,1,2,1,NULL,'vanda_c_oliveira\r欧标 '),(20263,817987827017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.29,'photographyacc','daley82','adaley87@gmail.com','Adam Daley','82 Figtree Drive','Goonellabah','New South Wales','AUSTRALIA','2480','0402609480','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 09:29:51',0,NULL,3,1,2,1,NULL,'daley82'),(20264,799737409002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','6804jj','hpn737@telenet.be','J JCuelenaere','Waterstraat 4','St Laureins','','BELGIUM','9980','0498-295817','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 09:59:12',0,NULL,3,1,2,1,NULL,'6804jj'),(20265,760458267018,280685239907,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',49,'photographyacc','chrisa5697','chrisa567@gmail.com','Chris Arrandale','6 Parsonage Road, Flixton','Manchester','Greater Manchester','UNITED KINGDOM','M41 6PZ','01617553388','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 10:30:10',0,NULL,3,1,3,1,'RA184574746CN\r ','chrisa5697'),(20266,894195984015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','tommytimbo','tommyroberts252@hotmail.com','thomas roberts','50 glenbervie road','kirkcaldy','Fife','UNITED KINGDOM','ky2 6lq','01592642906','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-22 11:55:07',0,NULL,3,1,4,1,'YW867660814CN ','tommytimbo\r黑加白\r▲'),(20267,760492715018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',13,'photographyacc','pallecon','mmolog@hotmail.com','Mile` Stanisic','Suite 11, 6A Gray Street<br>Myshopping.com.au','Bondi Junction','New South Wales','AUSTRALIA','2022','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 12:23:58',0,NULL,3,1,2,1,NULL,'pallecon'),(20268,818041903017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','rtvstudioaleksandr','rtv-studio@ukr.net','Oleksandr Garin','Sadovaya ul, 27, kv.14','Berdichev','UA','UKRAINE','13300','+380682184541','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 12:24:13',0,NULL,3,0,3,1,'RA184574689CN\r ','rtvstudioaleksandr\rxxxl   已入库'),(20269,894219026015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','tryggtorkel','benno.productions@gmail.com','benjamin ahlman','glasförgyllaren 56','staffanstorp','skåne','SWEDEN','24535','046-258626','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-22 12:49:16',0,NULL,3,1,3,1,'RA184574803CN\r ','tryggtorkel'),(20270,756931249001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','manymany-many','pacific@electroz.org','Emmanuel Droz','Village 4','Corseaux','','SWITZERLAND','1802','41765141087','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 12:51:59',0,NULL,3,1,3,1,'RA184574777CN\r ','manymany-many'),(20271,818052054017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','jimaras_50','jjkoutlis@gmail.com','James Koutlis','65<br>Rowes Lane','Wallan','Victoria','AUSTRALIA','3756','0357833900','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 12:53:29',0,NULL,3,1,2,1,' ','jimaras_50'),(20272,818066669017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','tadman666','tonyharman@amnet.net.au','Anthony A Harman','13 Binburra Way','Mt Nasura','Western Australia','AUSTRALIA','6112','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 13:35:50',0,NULL,3,1,2,1,NULL,'tadman666'),(20273,756944957001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','kingra77','memento1@gmx.de','Martin König','Kreischaer Str. 7','dresden','','GERMANY','01219','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-22 13:36:06',0,NULL,3,1,3,1,'RA184574732CN\r ','kingra77'),(20274,875929455016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','kuntaob','mikkixl@yahoo.com','mikki o berko','13 plantagenet square<br>13 plantagenet square','northampton','Northamptonshire','UNITED KINGDOM','nn49rg','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-22 14:00:10',0,NULL,3,1,4,1,'YW867660825CN ','kuntaob\r英标  \r▲'),(20275,760556052018,280676579192,'New 58mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1208',4.85,'photographyacc','drewagil','stargazer292@bigpond.com','Andrew Liga','7 Orchid Pass','Thornlie - Perth','Western Australia','AUSTRALIA','6108','0424617996','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 15:22:33',0,NULL,3,1,2,1,NULL,'drewagil'),(20276,756982217001,110583613495,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',7.98,'hermeshine','pb770_00','pbewright@gmail.com','paul wright','9 MORGAN ST','SHENTON PARK','Western Australia','AUSTRALIA','6008','0893819981','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-22 15:23:46',0,NULL,3,1,2,1,NULL,'pb770_00'),(20277,875976267016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','adi_kmf','adrian.szczypinski@wp.pl','Adrian Szczypiński','Telewizja Kablowa<br>Żółkiewskiego 22','Racibórz','śląskie','POLAND','47-400','697 365972','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-22 15:46:53',0,NULL,3,1,5,1,'CP240320618CN ','adi_kmf\r220V \r欧标\r'),(20278,757021148001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-22 16:58:55',0,NULL,3,1,3,1,'RA184574785CN\r ','jordano-jordano2000'),(20279,894367783015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','196919671969','a_listratov@mail.ru','Natalia Lobachevskaya','ul. Pulkovskaya 6, korp. 4, ap. 219','St.Petersburg','','RUSSIAN FEDERATION','196158','+7-9112568185','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 17:49:37',0,NULL,3,1,5,1,'CP240320621CN ','196919671969\r欧标  \r\r'),(20280,757056889001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','sarawaneeparish','sarawaneeparish@yahoo.com','Sarawanee Parish','462 Scott St','Auburn','AL','UNITED STATES','36830-6010','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-22 18:14:06',0,NULL,3,1,1,1,NULL,'sarawaneeparish'),(20281,894392077015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.4,'hutongstore','veronicafuentes10','veronicafuentes@ono.com','Veronica Fuentes Izquierdo','Lòpez de Sena  La MIna','Laredo','Cantabria','SPAIN','39770','942611757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 18:31:45',0,NULL,3,1,17,0,NULL,'veronicafuentes10'),(20282,894391018015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',6.9,'hutongstore','veronicafuentes10','veronicafuentes@ono.com','Veronica Fuentes Izquierdo','Lòpez de Sena  La MIna','Laredo','Cantabria','SPAIN','39770','942611757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 18:31:45',0,NULL,3,1,2,1,NULL,'veronicafuentes10\r柔光伞   1\r单灯头   1 欧标'),(20283,754556300001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',68,'hermeshine','takechiyo','go.george2@gmail.com','George Go','1140-1185 West Georgia Street','Vancouver','BC','CANADA','V6E 4E6','(604) 688-7227 ext.: 5','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 18:32:28',0,NULL,3,1,3,1,'RA184574794CN\r ','takechiyo\r两个'),(20284,893612234015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','qazpl890','wardy77@hotmail.com','chris ward','26 Pioneer Avenue<br>Burton Latimer','Kettering','Northamptonshire','UNITED KINGDOM','NN15 5LH','07791455151','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-22 18:59:09',0,NULL,3,1,4,1,'YW867660836CN ','qazpl890\r黑加白\r申报$25\r▲'),(20285,818220211017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','v_kh','v_khomoutov@mtu-net.ru','Tatiana Khomutova','Michurinsky pr-t, Olimpiiskaya der.,<br>15-155','Moscow','Russia','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 19:04:17',0,NULL,3,1,17,0,NULL,'v_kh'),(20286,760662186018,280674125495,'New Neoprene Neck Shoulder Strap for  SLR camera',1,'AB1407',5.08,'photographyacc','v_kh','v_khomoutov@mtu-net.ru','Tatiana Khomutova','Michurinsky pr-t, Olimpiiskaya der.,<br>15-155','Moscow','Russia','RUSSIAN FEDERATION','119602','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 19:04:17',0,NULL,3,1,2,1,NULL,'v_kh\r肩带 无字    1\r镜头笔     1'),(20287,876097760016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','cyporkandris','andris.gauracs@rtu.lv','Andris Gauracs','Sesku 67-152','Riga','LATVIA','LATVIA','LV1082','003719186288','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-22 19:09:30',0,NULL,3,1,5,1,'CP240320635CN ','cyporkandris\r欧标\r申报gift  '),(20288,818233109017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',2,'AB3321',33.98,'photographyacc','rampho','rampho@juno.com','Ramfis Campiz','2880 Mandarin Meadows Dr N','Jacksonville','FL','UNITED STATES','32223-2633','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-22 19:25:36',0,NULL,3,1,1,1,NULL,'rampho'),(20289,894454481015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','passit92','aasen@live.no','Alexander Aasen Pedersen','Konsul Christian Salvesens gate 9','Mandal','Mandal','NORWAY','4514','99397996','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 19:49:58',0,NULL,3,1,4,1,'YW867660840CN ','passit92\r+白色背景布   ▲\r申报gift   $25'),(20290,799973139002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','thomasd2324','thomas.dislis@gmail.com','Thomas Dislis','Kolokotroni 23','Thessaloniki','Thessaloniki','GREECE','54641','+306978341601','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-22 19:57:53',0,NULL,3,1,17,0,NULL,'thomasd2324'),(20291,757115381001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',3.98,'hermeshine','thomasd2324','thomas.dislis@gmail.com','Thomas Dislis','Kolokotroni 23','Thessaloniki','Thessaloniki','GREECE','54641','+306978341601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 19:57:53',0,NULL,3,1,3,1,'RA184574613CN\r ','thomasd2324\r三脚架  伟峰 WF-6662A    1\r普通有线快门线C1   1\r'),(20292,894477623015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','johnnyreb0_2','johnmorris16@btinternet.com','John Morris','40 Worsley Road<br>Farnworth','Bolton','Lancashire','UNITED KINGDOM','BL4 9LT','01204793890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 20:18:15',0,NULL,3,1,3,1,'RA184574661CN\r\r ','johnnyreb0_2'),(20293,760714168018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',1,'',80,'photographyacc','atomic.blue','pete@blueturtle.com.au','Pete Hall','94 - 96 Fullarton Road','Norwood','South Australia','AUSTRALIA','5067','61883629764','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 20:26:07',0,NULL,3,1,4,1,'YW867660895CN ','atomic.blue'),(20294,894506485015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','dermitzos7589','dermitzos@hotmail.com','Ioannis Dermitzakis','V. Sofias 79','Marousi','Attiki','GREECE','15124','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 20:55:24',0,NULL,3,1,3,1,'RA184574675CN\r ','dermitzos7589'),(20295,894515404015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-22 21:07:59',0,NULL,3,1,5,1,'CP240320649CN ','leifs123\r欧标\r申报$20'),(20296,757164983001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','2005anthonyh','anthonyhorner@hotmail.com','Anthony Horner','7/3 Mahony Road Constitution Hill','Sydney','New South Wales','AUSTRALIA','2145','0296712838','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-22 21:20:32',0,NULL,3,1,2,1,' ','2005anthonyh'),(20297,876206073016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','agvrt','a.gevart@libertysurf.fr','GEVART ARTHUR','74 RUE DU PORT BOYER','NANTES','Pays de la Loire','FRANCE','44300','(33)  24049114','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-22 21:27:30',0,NULL,3,1,4,1,'YW867660851CN ','agvrt\r▲'),(20298,894530789015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','aberana3030','annalendrum@googlemail.com','Anna Lendrum','Pierro\'s Cottage, 5 Briars Court<br>Rouge Rue','St Peter Port','Channel Islands','UNITED KINGDOM','GY1 1ZA','07781456630','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-22 21:27:59',0,NULL,3,1,2,1,NULL,'aberana3030'),(20299,757212437001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','mikhail.b','mikhail.b@gmail.com','Mikhail Benkovich','Kuybysheva 260a 30','Donetsk','','UKRAINE','83122','+380979158658','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 23:07:18',0,NULL,3,1,3,1,'RA184574729CN\r ','mikhail.b'),(20300,800080010002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','danielaires','daniel_aires@globo.com','Daniel Pereira','SQN 307 Bloco D Apartamento 207','Brasília','Distrito Federal','BRAZIL','70746040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-22 23:11:36',0,NULL,3,1,2,1,NULL,'danielaires'),(20301,8881322010563886,111,'背景布塑料夹子',2,'',0,'hutongstore','vjannus','vjannus@gmail.com','Veres János','Kerepesi 132-134 III/38','Budapest','Budapest','HUNGARY','1144','',NULL,NULL,NULL,'2011-11-23 01:09:23',0,NULL,3,1,2,1,NULL,NULL),(20302,800121520002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','thaistorres','thaistorresreis@gmail.com','Thais Torres dos Reis','Rua São Mateus, 997. São Mateus','Juiz de Fora','Minas Gerais','BRAZIL','36025001','03232322811','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 01:26:04',0,NULL,3,1,2,1,NULL,'thaistorres'),(20304,8881322012381068,111,'x2 115W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT049',27.89,'aliexpress','1005377382','catricio.paris@gmail.com','Catricio BET	','12 Ter, Av. Emile Zola','Poissy','Poissy','FRANCE','78300','+33 659003727',NULL,NULL,NULL,'2011-11-23 01:39:41',0,NULL,3,1,3,1,'RA184577359CN\r ',NULL),(20305,8881322016083997,111,'配件',1,'',0,'hermeshine','mikesad2011','mikesad@mail.ru','Mikhail Sadomtsev','Likhachevskiy prospekt 70<br>1 bld, 181 apt','Dolgoprudniy','Moscow region','RUSSIAN FEDERATION','141707','9163958215',NULL,NULL,NULL,'2011-11-23 02:41:23',0,NULL,3,0,3,1,'RA184574750CN\r ',NULL),(20306,818448342017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',225,'photographyacc','timely41','tim-hardy@grapevine.com.au','Tim Hardy','15 Ennor Cr','Florey','Australian Capital Territory','AUSTRALIA','2615','0262587178','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-23 03:39:22',0,NULL,3,1,4,1,'YW867660862CN ','timely41\r▲'),(20307,760881742018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','nuckleheadz','suebiz333@gmail.com','Sue Taite','231 Esplanade','Seaford','South Australia','AUSTRALIA','5169','0883271156','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 03:42:48',0,NULL,3,0,2,1,' ','nuckleheadz\r黑色'),(20308,876358022016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','joyce_duah','joyceybaby27@gmail.com','Joyce Duah','48 Chatsworth Drive','Liverpool','Merseyside','UNITED KINGDOM','L76LG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 03:45:30',0,NULL,3,1,3,1,'RA184574763CN\r ','joyce_duah'),(20309,818464762017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','searchhero','cliffro@yahoo.com','LinkedIn Cliff Rosenberg','Level 11<br>130 Pitt Street','Sydney','New South Wales','AUSTRALIA','2000','0414345655','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 04:45:20',0,NULL,3,1,2,1,NULL,'searchhero'),(20310,760917752018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','ytshuva','kobi_psh@bezeqint.net','kobi tshuva','tiltan 12','yavne','israel','ISRAEL','81556','(972) 894-2648 ext.: 2','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 06:40:09',0,NULL,3,1,3,1,'RA184577067CN\r ','ytshuva'),(20311,800207381002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','doctordrelaud','drelaud@gmail.com','Jason Drelaud','42-52  Abbott Street<br>InterOil Level 3 Cairns Square','Cairns','Queensland','AUSTRALIA','4870','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 07:33:42',0,NULL,3,1,2,1,NULL,'doctordrelaud'),(20312,760934524018,280680264353,'New Camera Bag Cover for Canon EOS 60D 18-135 / 18-200 ',1,'AD1115',12.99,'photographyacc','aupyd1','yongdaepark@yahoo.co.kr','Yong Dae Park','18 Plymouth St.','Enfield','New South Wales','AUSTRALIA','2136','0297363539','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 07:57:35',0,NULL,3,1,2,1,NULL,'aupyd1'),(20313,760973198018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT082',51.5,'photographyacc','rapv02','helimad@blueyonder.co.uk','DAVID LEWIS','7 PARADE ROAD<br>WEST PARK','PLYMOUTH','Devon','UNITED KINGDOM','PL5 2NL','01752319236','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 10:24:13',0,NULL,3,1,3,1,'RA184577447CN\r ','rapv02'),(20314,894802289015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','phiou67','philippe.tardy@free.fr','Philippe TARDY','34a, rue du Chêne','HOENHEIM','Alsace','FRANCE','67800','0632509690','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-23 10:30:34',0,NULL,3,1,3,1,'RA184577305CN ','phiou67'),(20315,760982968018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','coopy110','adamcooper77@hotmail.com','Adam Cooper','9A Park Way','Mawson Lakes','South Australia','AUSTRALIA','5095','0423399858','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 10:58:00',0,NULL,3,1,3,1,'RA184577291CN ','coopy110'),(20316,800260739002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','joanguiu','joanguiu@yahoo.com','joan guiu reig','calle Miquel Mumany i Campderros , 11-19','rubi','Cataluña','SPAIN','08191','675628153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 11:06:02',0,NULL,3,1,2,1,NULL,'joanguiu\r欧标'),(20317,760984029018,280671626328,'New Green.L Premium Quality 62mm UV Filter Canon Nikon ',1,'AA3304',3.99,'photographyacc','sanjotsonalkar','sanjot@aol.in','Sanjot Sonalkar','14, Vinay (Chakala) CHS,<br>Chakala, 95/5, Andheri (E),','Mumbai','MH','INDIA','400099','9820347078','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 11:12:14',0,NULL,3,1,2,1,NULL,'sanjotsonalkar'),(20318,760996060018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','motorvation_feb_07','motorvation_d_a@hotmail.com','Richard Hall','28<br>Lucretia Street','Eaton','Western Australia','AUSTRALIA','6232','0897252620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 11:42:15',0,NULL,3,1,3,1,'RA184577288CN\r ','motorvation_feb_07'),(20319,8881322048767881,111,'lenspen +小号lenspen',1,'AA1310',0,'hutongstore','lillo2k1','monicarn@interfree.it','Saluzzi Domenico','Via Ausa 69','Coriano','Rimini','ITALY','47853','',NULL,NULL,NULL,'2011-11-23 11:46:07',0,NULL,3,1,2,1,' ','小号镜头笔问我 '),(20320,757410655001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','pattieanna','lindakay37@yahoo.com','Linda James','21459 Highway 167<br>Lot 30','Dry Prong','LA','UNITED STATES','71423-3512','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-23 12:28:57',0,NULL,3,1,1,1,NULL,'pattieanna\r白色'),(20321,894844246015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.45,'hutongstore','white.lion78','lehuytrung@yahoo.com','Trung Le Huy','Apt 318 Weekday Cross Building<br>Halifax Place','Nottingham','Nottinghamshire','UNITED KINGDOM','ng11ql','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 12:39:54',0,NULL,3,1,2,1,' ','white.lion78'),(20322,757420578001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','gya1971','masi@freemail.hu','Attila György','Gábor Áron köz 8.','Budapest','','HUNGARY','1026','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-23 12:59:34',0,NULL,3,1,17,0,NULL,'gya1971'),(20323,757420577001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','gya1971','masi@freemail.hu','Attila György','Gábor Áron köz 8.','Budapest','','HUNGARY','1026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 12:59:33',0,NULL,3,1,17,0,NULL,'gya1971'),(20324,800295522002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',16.4,'hermeshine','gya1971','masi@freemail.hu','Attila György','Gábor Áron köz 8.','Budapest','','HUNGARY','1026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 12:59:34',0,NULL,3,1,17,0,NULL,'gya1971'),(20325,800291910002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','gya1971','masi@freemail.hu','Attila György','Gábor Áron köz 8.','Budapest','','HUNGARY','1026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 12:59:35',0,NULL,3,1,17,0,NULL,'gya1971'),(20326,894861583015,250637927048,'New Hairlight photostudio boom arm 75-135cm',2,'AE3101',37.98,'hutongstore','whateverwhahever','raymond@blueislandtv.com','Raymond O\'Daly','26 The Paragon<br>43 Searles Road','London','London','UNITED KINGDOM','SE1 4YL','02077011831','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 13:05:05',0,NULL,3,1,3,1,'RA184577274CN ','whateverwhahever\r'),(20327,800234283002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',238,'hermeshine','moldostas','stanislav.rijcov@gmail.com','Stanislav Rijcov','Calea Iesilor str.<br>27 bloc \"D\", app.30','Balti','Balti','MOLDOVA, REPUBLIC OF','MD-3121','+373 69063615','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 13:25:03',0,NULL,3,1,5,1,'CP240320652CN ','moldostas\r除了c以外再加一个\rDC引闪器\r实重5.656  泡重7.35  \r我算了  还是sal 便宜'),(20328,757431315001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','gya1971','masi@freemail.hu','Attila György','Gábor Áron köz 8.','Budapest','','HUNGARY','1026','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 13:32:43',0,NULL,3,1,5,1,'CP240320666CN ','gya1971\r斜臂    1\r灯架  2m  2\r闪光灯B座    2\r大力夹    1\r牛津布大包    1\r\r\r\r'),(20329,894876099015,250895544246,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',56.99,'hutongstore','sufertashu','mihai.stanimir@gmail.com','Mihai Stanimir','Petre Ramneantu nr 15A ap 12','Timisoara','Timis','ROMANIA','300595','0040764177508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 13:38:55',0,NULL,8,1,17,0,NULL,'sufertashu'),(20330,894876100015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.4,'hutongstore','sufertashu','mihai.stanimir@gmail.com','Mihai Stanimir','Petre Ramneantu nr 15A ap 12','Timisoara','Timis','ROMANIA','300595','0040764177508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 13:38:55',0,NULL,3,1,2,1,NULL,'sufertashu\r85cm柔光伞   1'),(20331,757443136001,110718665736,'Official Original Nikon Photo Vest D300 D90 Size XL ',1,'AD1161',42,'hermeshine','netrunner-sweden','hans_hard@hotmail.com','Hans Hard af Segerstad','Kinnekullev. 4<br>16743 Bromma','Bromma / Stockholm','Stockholm','SWEDEN','16743','+46704220333','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-23 14:09:00',0,NULL,3,1,3,1,'RA184577455CN\r ','netrunner-sweden'),(20332,761080903018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','action-max69','action-max@hotmail.com','Malherbe Maxime','place de l\'hotel de ville, 26/3','Herve','','BELGIUM','4650','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 15:48:00',0,NULL,3,1,3,1,'RA184577265CN ','action-max69\rReflector holder  $15'),(20333,757484901001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','m.petrosyan','miqayelpetrosyan@gmail.com','Valya Gharibyan','Davitashen 2 district 37a-32','Yerevan','','ARMENIA','0054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 16:02:42',0,NULL,3,1,2,1,NULL,'m.petrosyan'),(20334,876608974016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',3,'AD1167',29.97,'hutongstore','gubaguba','gubavision@comcast.net','Paul Guba','85 Portland Rd','Highlands','NJ','UNITED STATES','07732-1955','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 16:27:19',0,NULL,3,1,1,1,NULL,'gubaguba'),(20335,818692177017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',73,'photographyacc','ckristie000','ckristie000@aol.com','Kristie Covington','66 Seminole Rd NE','Cartersville','GA','UNITED STATES','30121-5069','(678) 431-2997','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 17:01:04',0,NULL,3,1,4,1,'YW867660873CN ','ckristie000\r▲'),(20336,757521700001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','xxalex29xx','funcity@bellsouth.net','alex lopez','12246 SW 128th St','Miami','FL','UNITED STATES','33186-5419','(305) 275-2539','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-23 17:26:42',0,NULL,3,1,1,1,NULL,'xxalex29xx\r500g  挂号便宜 '),(20337,761144005018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','laserfreak0815','mystique2404@hotmail.de','Martin Aigner','Gartenstrasse 11','Grasbrunn','','GERMANY','85630','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-23 18:06:39',0,NULL,3,1,3,1,'RA184577331CN\r ','laserfreak0815\rXXL\r已入库'),(20338,895052165015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','rk01753','rkrakowski@btopenworld.com','Richard Krakowski','1 Salt Hill Avenue','Slough','Berkshire','UNITED KINGDOM','SL1 3XP','07946754428','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 19:00:13',0,NULL,3,1,3,1,'RA184577420CN ','rk01753'),(20339,800478494002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'',55,'hermeshine','nickiehoare1','nickiehoare@gmail.com','nicola hoare','70a Gipsy Hill','London','London','UNITED KINGDOM','SE19 1PD','447826020975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 19:43:00',0,NULL,3,1,3,1,'RA184577328CN\r ','nickiehoare1'),(20340,761210583018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','my_tackle','sales@mytackle.com.au','My Tackle','18 homestead cct','macquarie links','New South Wales','AUSTRALIA','2565','0413454117','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 19:52:45',0,NULL,3,0,2,1,' ','my_tackle\r白色'),(20341,895124010015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','groomie37','garygroom22@hotmail.com','gary groom','22 maryfield close','bexley','Kent','UNITED KINGDOM','DA52HY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 20:29:57',0,NULL,3,1,3,1,'RA184577226CN\r ','groomie37'),(20342,818819147017,270757832583,'Pro Heavy Video Camera Tripod EI-717 1.55m 5ft version',1,'AO0022',225,'photographyacc','junkyard_boy','mistamichal@dodo.com.au','Michael Tokarski','1 Jiloa Way','Don','Tasmania','AUSTRALIA','7310','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-11-23 20:31:17',0,NULL,3,1,4,1,'YW867660884CN ','junkyard_boy\r▲'),(20343,800513184002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','thelattarstore','shawna.lock@gmail.com','Shawna Lock','908 Centre Street South','Whitby','ON','CANADA','L1N4X3','(416) 710-0882','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-23 20:39:10',0,NULL,3,1,2,1,NULL,'thelattarstore'),(20344,895143405015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','zipo_tn','zipo.tn@gmail.com','Milan Buchel','15 Malin House, Waterville Rd<br>Blanchardstown','Dublin','Dublin','IRELAND','15','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 20:56:00',0,NULL,3,1,3,1,'RA184577433CN\r ','zipo_tn'),(20345,800531642002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','teffa70','teffa70@yahoo.com','tawfeeq albakry','almarwa dist.','makkah','','SAUDI ARABIA','21955','00966555014570','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-23 21:12:54',0,NULL,3,1,3,1,'RA184577230CN\r ','teffa70\rXL '),(20346,876841181016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','derwijko','derwisinski@o2.pl','Sebastian Derwisinski','175 Windmill Road','London','London','UNITED KINGDOM','W54DH','02085606015','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-23 21:48:33',0,NULL,3,1,12,1,'2770975152\r ','derwijko\r3个英标 \r3个欧标\r3个澳标\r实重7.18  泡重9.38'),(20347,895193233015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','southern_islander','caa1972@hotmail.com','Christopher Agius','18, Gori Mancini Street','Birkirkara','','MALTA','BKR 1220','(356) 7970 2193','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-23 22:11:51',0,NULL,3,1,5,1,'CP240320900CN ','southern_islander\r黑加白'),(20348,876867848016,260808990748,'Stainless Steel Spanner Wrenches for lens repair, clean',1,'AA2401',24.8,'hutongstore','matthew_gd','matthew@mdurnford.com','Matthew Durnford','40 Silver Street','Wiveliscombe','Somerset','UNITED KINGDOM','TA4 2PB','01984623541','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 22:39:47',0,NULL,3,1,3,1,'RA184577212CN\r ','matthew_gd'),(20349,895230245015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','latsanovsky','lavin32@mail.ru','SLAVA LATSANOVSKY','20 HARTLAND ROAD','MORDEN','Surrey','UNITED KINGDOM','SM46LZ','07951122144','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-23 23:23:00',0,NULL,3,1,2,1,NULL,'latsanovsky'),(20350,761329261018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','waffle-com','tenkyistar@yahoo.com.au','Reinard Irawan','719/118 Franklin Street','Melbourne','Victoria','AUSTRALIA','3000','610423625111','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-23 23:56:03',0,NULL,3,1,2,1,NULL,'waffle-com'),(20351,818943392017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','gt300bois','pepin.perron@cgocable.ca','BENOIT PEPIN','285 PLACE DE ROME','DRUMMONDVILLE','QC','CANADA','J2C8M3','(819) 474-7023','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 01:15:45',0,NULL,3,1,2,1,NULL,'gt300bois'),(20377,819047475017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','dagfrj1','frs_2222@yahoo.com','Juan Lavina','95 San Francisco St.,<br>Barrio Kapitolyo','Pasig City','Metro Manila','PHILIPPINES','1603','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 08:58:11',0,NULL,3,1,2,1,NULL,'dagfrj1\r电话\r(632)-921-472-8116'),(20352,895277549015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','vanbus','denu@melbpc.org.au','Dennis Edwards','5 Lombard Road','Vermont','Victoria','AUSTRALIA','3133','0398737520','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 01:45:14',0,NULL,3,1,2,1,' ','vanbus'),(20353,876939261016,260660051871,'New 3 pcs filters for Cokin System P Series',1,'AKT062',13.8,'hutongstore','tlit2272','tamanddee@westnet.com.au','Tamlin Little','51 Don cct','Durack','Northern Territory','AUSTRALIA','0830','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 01:45:36',0,NULL,3,1,2,1,' ','tlit2272\r两个店买的分开发   '),(20354,8881322099387080,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head',1,'AE1603',30.99,'aliexpress','1005393604','andrew328@pochta.ru','Andrey Popkov','Domashnikova 24-37','Ufa','Bashkortostan','RUSSIAN FEDERATION	','450015','+7 917 4044668',NULL,NULL,NULL,'2011-11-24 01:49:47',0,NULL,3,1,3,1,'RA184577566CN ',NULL),(20355,800633462002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','redcurley6','davedot@aapt.net.au','David R Smith','4 Hamilton Ave','Cannonvale','Queensland','AUSTRALIA','4802','0749461937','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 01:53:03',0,NULL,3,1,2,1,NULL,'redcurley6'),(20356,818953906017,270747042944,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',2.5,'photographyacc','jasonxzou','rebornzx@gmail.com','Xin Zou','100 Timber Hollow Ct<br>Apt 202','Chapel Hill','NC','UNITED STATES','27514-5433','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 01:57:21',0,NULL,3,1,1,1,NULL,'jasonxzou'),(20357,757749020001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','iliketoteach','dj_jimmyc12@hotmail.com','Jimmy Campos','3649 Louisiana St<br>Apt 109','San Diego','CA','UNITED STATES','92104-4080','(619) 876-7879','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 02:22:57',0,NULL,3,1,1,1,' ','iliketoteach'),(20358,818961163017,270748510307,'NIB TianYa Gradual grey Color Filter for Cokin P series',1,'AA2322',7.29,'photographyacc','tlit2272','tamanddee@westnet.com.au','Tamlin Little','51 Don cct','Durack','Northern Territory','AUSTRALIA','0830','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 02:23:39',0,NULL,3,1,17,0,NULL,'tlit2272'),(20359,761367382018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','tlit2272','tamanddee@westnet.com.au','Tamlin Little','51 Don cct','Durack','Northern Territory','AUSTRALIA','0830','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 02:27:26',0,NULL,3,1,2,1,NULL,'tlit2272\r天涯方形滤镜  渐变灰    1\r绿叶 CPL  67mm     1\r两个店买的分开发   '),(20360,8881322103423689,111,'150-200 5in1 反光板+ 3个袋子',1,'AD1182',0,'hermeshine','cfwegman','cfwegman@earthlink.net','Charlie Wegman','6396 Burnt Poplar Ct<br>C.E. Smith Company','Greensboro','NC','UNITED STATES','27409-9710','(336) 908-7130',NULL,NULL,NULL,'2011-11-24 02:57:03',0,NULL,3,1,4,1,'YW867660906CN ',' 150-200 5in1 反光板+ 额外的3个袋子\r▲'),(20361,800655278002,120498233006,'New Camera Tripod Fancier 6662A for Dslr with Bag',1,'AE1601',59,'hermeshine','pichunman','jc.pichunman@gmail.com','Juan Pichunman','San Cristobal 0710. Villa Santa Teresa','Temuco. Region de la Araucania','Chile','CHILE','4811057','+560963101132','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 03:35:31',0,NULL,3,1,17,0,NULL,'pichunman'),(20362,800658958002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','pichunman','jc.pichunman@gmail.com','Juan Pichunman','San Cristobal 0710. Villa Santa Teresa','Temuco. Region de la Araucania','Chile','CHILE','4811057','+560963101132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 03:37:18',0,NULL,3,1,17,0,NULL,'pichunman'),(20363,757762263001,110419742422,'Green.L 67mm Neutral Density ND8 Filter ND 8 67',1,'AE2312',6.7,'hermeshine','pichunman','jc.pichunman@gmail.com','Juan Pichunman','San Cristobal 0710. Villa Santa Teresa','Temuco. Region de la Araucania','Chile','CHILE','4811057','+560963101132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 03:37:19',0,NULL,3,1,17,0,NULL,'pichunman'),(20364,800655814002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','pichunman','jc.pichunman@gmail.com','Juan Pichunman','San Cristobal 0710. Villa Santa Teresa','Temuco. Region de la Araucania','Chile','CHILE','4811057','+560963101132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 03:37:20',0,NULL,3,1,17,0,NULL,'pichunman'),(20365,757761646001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','pichunman','jc.pichunman@gmail.com','Juan Pichunman','San Cristobal 0710. Villa Santa Teresa','Temuco. Region de la Araucania','Chile','CHILE','4811057','+560963101132','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 03:37:20',0,NULL,3,1,5,1,'CP240320895CN ','pichunman\r三脚架  伟峰 WF-6662A         1\r伟峰 6662A 快装板                1\r绿叶 ND8  67mm   1\r绿叶 CPL  67mm    1\r绿叶 UV  67mm     1\r\r'),(20366,895287403015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',34.15,'hutongstore','krixsuni','krixsun@gmail.com','Krisztian Toth','15.Lissadel Crescent Seabury<br>Malahide','Malahide','Dublin','IRELAND','default','0851313429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 03:42:49',0,NULL,3,1,12,1,'2770981091\r ','krixsuni\r3片装的滤镜袋   2\r67cm 遮光罩    1\r85cm 柔光伞     2\r独脚架  伟峰 WT-1003    1\r2m灯架   2\r双灯头 （英标+欧标）    2  \r反光伞    2\r45w 灯泡  2\r115w 220v   2\r包     1\r60cm 5in1  反光板    2\r已入库\r实重6.2  泡重7.7'),(20367,761407233018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','propertysnaps','ebay@propertysnaps.com.au','Vince DeStesano','50 Beeazly Road','Cardina','Victoria','AUSTRALIA','3978','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 05:41:16',0,NULL,3,1,2,1,NULL,'propertysnaps'),(20368,755659225001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','johncat49','john.e.catalano@gmail.com','John Catalano','unit 26,block 9<br>Amicitia circuit','Northmead','New South Wales','AUSTRALIA','2152','0296316343','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-24 06:09:10',0,NULL,3,1,2,1,NULL,'johncat49'),(20369,757695317001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','jzcorner','scripteros@gmail.com','Jose Joaquin Giron','Apartado Correos 11','Gorliz','País Vasco','SPAIN','48630','607430362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 06:22:42',0,NULL,3,1,2,1,NULL,'jzcorner'),(20370,819015476017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','rogo666','insideofrogo@yahoo.com','Rodrigo Solana','Francisco Palazuelos 32A Bajo Dcha','Santander','Cantabria','SPAIN','39006','606632561','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 06:28:53',0,NULL,3,0,3,1,'RA184577495CN\r ','rogo666\r白色 '),(20371,761423622018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','ohqj','ohqijie@hotmail.com','Baha\'i National Office - Attn: Qi Jie Oh','173 Mona Vale Road','Ingleside','New South Wales','AUSTRALIA','2101','0421567285','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 07:16:06',0,NULL,3,1,3,1,'RA184577504CN ','ohqj'),(20372,800706153002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','donrabina2002','donrabina2002@yahoo.com','FERDINAND RABINA','9902 DU PAGE AVE','WHITTIER','CA','UNITED STATES','90605-2720','(562) 457-7252','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-24 07:40:40',0,NULL,3,1,3,1,'RA184577521CN ','donrabina2002'),(20373,800708607002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 07:52:43',0,NULL,3,1,3,1,'RA184577518CN ','alainice06\r欧标 '),(20374,800715394002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',36,'hermeshine','leonendianalemans','l.lemans@chello.nl','Diana Lemans','Plataanstraat 8','Puttershoek','','NETHERLANDS','3297 XS','078-8443123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 08:23:27',0,NULL,8,1,17,0,NULL,'leonendianalemans'),(20375,757164220001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',125.88,'hermeshine','leonendianalemans','l.lemans@chello.nl','Diana Lemans','Plataanstraat 8','Puttershoek','','NETHERLANDS','3297 XS','078-8443123','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 08:23:28',0,NULL,3,1,5,1,'CP240335011CN ','leonendianalemans\r背景布 1.6*2.1  （白+ 黑） 2\r背景架2mx2m  + 3个夹子   1\r背景布1.6*2.1m （蓝，绿，红，灰, 黄， 橙， 棕， 粉）    8\r小号灰卡    1\r热靴保护盖  普通     1\r已入库\r实重5.673  泡重8.4\r'),(20376,877043467016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','gbresson','gmsprop@gmail.com','Gustavo de Mello e Souza','Calle Ibi, 1 - 6º - pta 11<br>Terramelar (Edif. Buenavista II)','Paterna','Comunidad Valenciana','SPAIN','46989','671628200','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-24 08:44:25',0,NULL,3,1,3,1,'RA184577708CN ','gbresson'),(20378,761462975018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',7.2,'photographyacc','vitorwood','vmcm@ci.uc.pt','Vítor M. C. Madeira','Centro de Neurociências, Univ. Coimbra<br>L. M. Pombal','Coimbra','','PORTUGAL','3004-517','+351239714759','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 10:02:32',0,NULL,3,1,2,1,NULL,'vitorwood'),(20379,761472928018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','gf987','frankie.geerinck@bt.com','Frankie Geerinck','Hammestraat 101','Moerzeke','','BELGIUM','9220','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 10:39:49',0,NULL,3,1,2,1,NULL,'gf987'),(20380,757697364001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','mishs2j','mishilily9@hotmail.com','Jason Li','27 Welby Street<br>Eastwood','Sydney','New South Wales','AUSTRALIA','2122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 10:41:09',0,NULL,3,1,2,1,NULL,'mishs2j'),(20381,757861192001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','bohras2','idris.adamjy@gmail.com','IDRIS ADAMJY','40 rue de la Commune de Paris','Aubervilliers','Ile-de-France','FRANCE','93300','0648229214','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 11:21:45',0,NULL,3,1,4,1,'YW867660910CN ','bohras2\r▲'),(20382,818396476017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',2,'AD1126',29,'photographyacc','singin_bayer','just-timmi@optusnet.com.au','Timothy Woolf','14 Dennis Street','Greystanes','New South Wales','AUSTRALIA','2145','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-24 11:44:48',0,NULL,3,1,2,1,NULL,'singin_bayer'),(20383,895456937015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','narsango','narsango@hotmail.com','NARCISO SANCHEZ GOODY','LUMELCO Avd. Matapiñonera,7','San Sebastian de los Reyes','Madrid','SPAIN','28700','647879490','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-24 12:21:23',0,NULL,3,1,3,1,'RA184577654CN ','narsango'),(20384,800812571002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','hemeroskopion','ewi@telefonica.net','Olaf Speier','Avenida 9 de Octubre, 9, 1º B<br>Residencial El Tossalet','Polop de la Marina','Comunidad Valenciana','SPAIN','03520','637101199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 14:21:17',0,NULL,3,1,2,1,NULL,'hemeroskopion'),(20385,757914238001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','geninio86','geninio@gmail.com','Claudia Sala','Gesellschaftsstrasse 30','Bern','','SWITZERLAND','3012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 14:21:41',0,NULL,3,1,2,1,NULL,'geninio86'),(20386,761575033018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'photographyacc','gosrnbman','chrizzy184@yahoo.com','chris jones','122 retford rd<br>harold hill','romford','Essex','UNITED KINGDOM','rm3 9nh','07828167536','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 15:53:28',0,NULL,3,1,3,1,'RA184577610CN ','gosrnbman'),(20387,800858350002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','robwrx04','robertbaek@gmail.com','Robert Baek','4 Minister Brook Dr','Weatogue','CT','UNITED STATES','06089-9716','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 16:21:48',0,NULL,3,1,1,1,NULL,'robwrx04'),(20388,757987517001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',35.99,'hermeshine','d1rentertainment','d1rentertainment@yahoo.com','Coty Martin','3130 CHRISTOPHERS BEND','ELLENWOOD','GA','UNITED STATES','30294','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-24 17:33:49',0,NULL,3,1,3,1,'RA184577623CN ','d1rentertainment\r两节   '),(20389,895602366015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','morty22582','morty22582@btinternet.com','Ian morton','10<br>bridge street','deeping st james','Lincolnshire','UNITED KINGDOM','pe6 8ha','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-24 17:41:59',0,NULL,3,1,2,1,NULL,'morty22582'),(20390,757996891001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','alegatrick','kralex08@mail.ru','Aliaksandr Kruchkou','Poplayskaya st, 3-31','Zhlobin','Gomelskaya oblast\'','BELARUS','247210','+375291029779','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 17:58:54',0,NULL,3,1,5,1,'CP240320670CN ','alegatrick\r欧标'),(20391,800903408002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','revdean','dean@potsuppress.com','Kenneth D Sines  Jr.','3049 Dogwood Dr','Atlanta','GA','UNITED STATES','30354-1169','(404) 545-4154','NoPaymentFailure','CheckoutComplete','Other','2011-11-24 18:02:01',0,NULL,3,0,1,1,NULL,'revdean\rXL 已入库'),(20392,895641664015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',18,'hutongstore','edugalvez2009','egf@edugalvez.com','Amanda Moon','Ronda Zamenhof, 119','Sabadell','Cataluña','SPAIN','08201','937122112','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-24 18:46:57',0,NULL,3,1,3,1,'RA184577637CN ','edugalvez2009\r欧标'),(20393,895652910015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','tparcius','marcio.santos@gmail.com','Márcio Alexandre Pires dos Santos','Casal dos Celeiros, n1<br>Tojal de Baixo','Porto de Mós','Leiria','PORTUGAL','2480-188','916444373','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-24 19:02:08',0,NULL,3,1,3,1,'RA184577570CN ','tparcius'),(20394,758042836001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-24 19:31:03',0,NULL,3,1,17,0,NULL,'garyshark024'),(20395,758042992001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-24 19:31:03',0,NULL,3,1,5,1,'CP240320683CN ','garyshark024\r4灯头 灯头 孔   2\r50cmx70cm 的柔光箱 (配4灯头）2\r欧标\r申报$25\r'),(20396,758063588001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',2,'AKT024',8.2,'hermeshine','77148207','e.matveev@mail.ru','Irina Khudzinskaya','Leninsky prospekt, 135-4, apt.41','St. Petersburg','','RUSSIAN FEDERATION','198216','(904)551-0039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 20:04:34',0,NULL,3,1,2,1,NULL,'77148207\r两套'),(20397,819341077017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',3.5,'photographyacc','kovall89','koval007@yandex.ru','Vitalij Kovalenko','Institutskij side street,<br>building 3, flat 32','Sumy','Sumy','UKRAINE','40022','(380) 66 245 1254','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-24 20:51:33',0,NULL,3,1,2,1,NULL,'kovall89'),(20398,758093386001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','il_nero','maxmobnet@gmail.com','Ferenc Fekete','Gyongyvirag u. 30.','Nagykovacsi','EU','HUNGARY','2094','+36203404974','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-24 20:59:51',0,NULL,3,1,3,1,'RA184577645CN ','il_nero'),(20399,895796673015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','lebiodiene','annaleb06@aol.com','ANA LEBIODIENE','22 KESTREL DRIVE','WESTON-SUPER-MARE','Avon','UNITED KINGDOM','BS22 8RG','01934527180','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-24 22:51:16',0,NULL,3,1,4,1,'YW867660921CN ','lebiodiene\r英标\r▲'),(20400,801053257002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','remyers1959','remyers59@comcast.net','Bob Myers','3145 Indian Summer Trl','friendswood','TX','UNITED STATES','77546','','NoPaymentFailure','CheckoutComplete','Other','2011-11-24 23:11:08',0,NULL,3,1,1,1,NULL,'remyers1959\r已入库'),(20401,761808942018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',3,'AE1203',16.5,'photographyacc','alex_lx4','lxa4@yandex.ru','Alexey Chernyshov','Pushkinskaya str. 68-83','Vladivostok','Primorskiy kr','RUSSIAN FEDERATION','690001','79147901077','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 00:23:40',0,NULL,3,1,2,1,NULL,'alex_lx4'),(20402,895293530015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',84.56,'hutongstore','krixsuni','krixsun@gmail.com','Krisztian Toth','15.Lissadel Crescent Seabury<br>Malahide','Malahide','Dublin','IRELAND','default','0851313429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 01:47:22',0,NULL,3,1,17,0,NULL,'krixsuni\r英标和欧标\r灯泡220V\r'),(20403,761829639018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','debbyvoysey_123','debbyvoysey@hotmail.com','Deborah voysey','28 McGrowdie Place','Gordon','Australian Capital Territory','AUSTRALIA','2906','0262943496','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-25 01:50:35',0,NULL,3,1,3,1,'RA184577583CN ','debbyvoysey_123'),(20404,8881322186621677,111,'3x6m 背景布 绿+ 黑',2,'',0,'photographyacc','r3sponsive','saulpowerseller@gmail.com','SAUL FERNANDEZ FUENTES','CALLE LA Torre Number 10. CP 24191 ','VILLABALTER - LEON','','SPAIN','24191','+34 675 72 05 01',NULL,NULL,NULL,'2011-11-25 02:03:41',0,NULL,3,0,4,1,'YW867660932CN ','3mx6m 背景布   2\r绿色 + 蓝色 \r▲'),(20405,895858325015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','god_dice','tjsilva@gmail.com','Tiago Silva','Rua Cabeco do Nuno n.11<br>Vale de Ilhavo','Ilhavo','Ilhavo','PORTUGAL','3830-155','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 02:08:21',0,NULL,3,1,3,1,'RA184577597CN ','god_dice'),(20406,877527837016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','1966maurice','maurmorwood@btinternet.com','Maurice Morwood','66 Oswald Road','Ayr','South Ayrshire','UNITED KINGDOM','KA8 8PD','01292284301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 02:52:36',0,NULL,3,1,2,1,' ','1966maurice'),(20407,758199445001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','cl23cl2005','cassandra@paddysbricks.com.au','Cassandra Le Marshall','7 Lincoln street','Yarraville','Victoria','AUSTRALIA','3013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 03:01:59',0,NULL,3,1,2,1,NULL,'cl23cl2005'),(20408,819483853017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.59,'photographyacc','danieljaems','daniel@ftape.com','Daniel James','12 benyon wharf<br>295 kingsland road','london','London','UNITED KINGDOM','e8 4dq','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 04:09:44',0,NULL,3,1,2,1,NULL,'danieljaems'),(20409,801129495002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','juanpedroverdier','juan.verdier@gmail.com','Juan Pedro Verdier Tarigo','Francisco Puelma 26 Torre 20 depto 307','Santiago','Santiago de chile','CHILE','11700','09 78573266','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-25 04:40:41',0,NULL,3,1,5,1,'CP240320697CN ','juanpedroverdier\r欧标'),(20410,8881322199722660,111,'2m灯架的底座',1,'',0,'hermeshine','photo_master.and','andrey.schnell@gmail.com','Andrey Schnell','Beregowaja 41','Aksu','Pawlodar','KAZAKHSTAN','140100','87183733084',NULL,NULL,NULL,'2011-11-25 05:42:02',0,NULL,3,1,3,1,'RA184577787CN ',NULL),(20411,801116303002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','tracykianwai','kianwai80@hotmail.com','Tracy Soo','Blk 208, Boon Lay Place<br>#14-195','default','','SINGAPORE','640208','63359330','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 07:20:19',0,NULL,3,1,11,1,NULL,'tracykianwai'),(20412,761897350018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','nazreex','mohd-nazree.mohdnor@zf-lenksysteme.com','MOHD NAZREE BIN MOHD NOR','20 LORONG 6,TAMAN SERI MURNI<br>SG.DUA','BUTTERWORTH','PENANG','MALAYSIA','13800','0124012437','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 07:38:49',0,NULL,3,1,3,1,'RA184577760CN ','nazreex\rXXXL 已入库'),(20413,8881322206749932,111,'1600W 套装 + 115w 110v x2',1,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-11-25 07:39:09',0,NULL,3,1,12,1,'2770981102\r ','灯泡都是110v \r实重 6.569  泡重9.807'),(20414,758253544001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','azzaufa','azat87.7@mail.ru','Азат Абдульманов','St.Zlobina, 6 -27','Ufa','Bashkortostan','RUSSIAN FEDERATION','450022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 08:04:55',0,NULL,3,1,2,1,NULL,'azzaufa'),(20415,761913951018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',203,'photographyacc','xx-wildchild-xx','bendover.ho@gmail.com','Niko Keček','Ljutomerska cesta 8','Ormož','','SLOVENIA','2270','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 08:40:26',0,NULL,3,1,5,1,'CP240320706CN ','xx-wildchild-xx\r欧标'),(20416,895504861015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','zito*euclides','zitodelgado@hotmail.com','euclides DELGADO','rua presidente arriaga n.13 1249-086 lisboa','alcantara- lisboa','portugal','PORTUGAL','1249-086','( +351)969790944','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-25 09:31:55',0,NULL,3,1,3,1,' RA184577901CN','zito*euclides'),(20417,758300376001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','gogs106','blitzin2007@hotmail.co.uk','gordon abbott','4 HAMILTON SQUARE','BO,NESS','West Lothian','UNITED KINGDOM','EH51 0NG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:07:37',0,NULL,3,1,2,1,NULL,'gogs106'),(20418,758309124001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','educa77','educa1972@yahoo.es','Eduardo CAMARGO','10/C<br>2 PARK ROAD (Mid-Levels)','default','','HONG KONG','default','6775636','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:39:01',0,NULL,3,1,2,1,NULL,'educa77'),(20419,758313528001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','hazelebach','laurenshazelebach@yahoo.com.au','Laurens Hazelebach','P.O. Box 213096<br>Al Wasl Post Office','Dubai','United Arab Emirates','UNITED ARAB EMIRATES','213096','(971) 050 9244013','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-25 11:56:49',0,NULL,3,1,8,1,'CP240320710CN\r','hazelebach\r除了C以外再发\r一转四 灯头   1\r单灯头    2  欧标\r反光板  80cm 5合1       1\r\r'),(20420,758313529001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','hazelebach','laurenshazelebach@yahoo.com.au','Laurens Hazelebach','P.O. Box 213096<br>Al Wasl Post Office','Dubai','United Arab Emirates','UNITED ARAB EMIRATES','213096','(971) 050 9244013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:56:50',0,NULL,3,1,17,0,NULL,'hazelebach'),(20421,801226962002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','hazelebach','laurenshazelebach@yahoo.com.au','Laurens Hazelebach','P.O. Box 213096<br>Al Wasl Post Office','Dubai','United Arab Emirates','UNITED ARAB EMIRATES','213096','(971) 050 9244013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:56:50',0,NULL,3,1,17,0,NULL,'hazelebach'),(20422,758313530001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',1,'AE3301',13.98,'hermeshine','hazelebach','laurenshazelebach@yahoo.com.au','Laurens Hazelebach','P.O. Box 213096<br>Al Wasl Post Office','Dubai','United Arab Emirates','UNITED ARAB EMIRATES','213096','(971) 050 9244013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 11:56:51',0,NULL,3,1,17,0,NULL,'hazelebach'),(20423,758331586001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','berendsenpeter','berendsenpb@hotmail.com','PETER berendsen','35 ranfordstreet','perth,kelmscott','Western Australia','AUSTRALIA','6111','0419190134','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 12:59:57',0,NULL,3,1,2,1,NULL,'berendsenpeter'),(20424,896043446015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','gfsbuilding','gfs.building@btinternet.com','George Smith','Calders Lea','Weisdale','Shetland','UNITED KINGDOM','ZE29LQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 13:02:13',0,NULL,3,1,2,1,NULL,'gfsbuilding'),(20425,896082155015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','macmadbrighton','liskeard2bed@gmail.com','chris riccio','28 Walton bank','Brighton','East Sussex','UNITED KINGDOM','bn1 9at','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 14:33:41',0,NULL,3,1,3,1,' RA184577977CN\r','macmadbrighton'),(20426,896084682015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','pedrosalet','pedrofcy@hotmail.com','Pedro Francisco Candela Yago','Esteban Diaz nº20 piso 1º','Yecla','Murcia','SPAIN','30510','680412199','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 14:39:24',0,NULL,3,1,3,1,' RA184577985CN','pedrosalet'),(20427,801280805002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','shreddays','moxep@mail.ru','Leonid Mokhirev','Zelenogradskaya dom 33 korpus 7 kv. 52','Moscow','','RUSSIAN FEDERATION','125475','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 14:42:33',0,NULL,3,1,5,1,'CP240320405CN\r','shreddays'),(20428,758344436001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','christoboul_75','christophe.paixao@free.fr','Christophe paixao','3 rue dangeau','Paris','Île-de-France','FRANCE','75016','0685553773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 14:55:46',0,NULL,3,1,3,1,' RA184577994CN\r','christoboul_75'),(20429,758380961001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','holly_langley','holly_langley565@hotmail.com','Holly Langley','66 Rainbow Park','Winnersh','Berkshire','UNITED KINGDOM','RG41 5SF','07771688622','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-25 15:23:29',0,NULL,3,1,4,1,'YW867660954CN\r','holly_langley\r黑加白\r▲'),(20430,762046374018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','liam-hd','andrey.k@i.ua','Korabelnikov Andrey','prospekt Mira, dom2, kv28','Dnepropetrovsk','UKRAINE','UKRAINE','49130','+380930953281','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 15:46:00',0,NULL,3,1,2,1,NULL,'liam-hd'),(20431,762087168018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','nunoborralho','nunoborralho@mac.com','Nuno Borralho','Edificio Grupo Impala<br>Rua da Impala, 33-A','S. Pedro de Penaferrim','Sintra','PORTUGAL','2710-070','+351219238028','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 17:13:43',0,NULL,3,1,2,1,NULL,'nunoborralho'),(20432,758450743001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','profess0rhastig','maltep@gmx.de','MLP Finanzdienstleistungen AG','Küterstraße 14-18<br>Kiel1 / Malte Preugschat','Kiel','','GERMANY','24103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 18:03:34',0,NULL,3,1,3,1,' RA184578005CN\r','profess0rhastig'),(20433,801394389002,120593061981,'New Pro Photo Vest for all DSLR fans  Size: L',1,'AA1103',30,'hermeshine','vm25','vickifoto@gmail.com','Vicki Maddy','16713 128th Ave SE','Renton','WA','UNITED STATES','98058-5531','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-25 18:55:01',0,NULL,3,1,1,1,NULL,'vm25\rL 已入库'),(20434,819785814017,270860550811,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX C-Shape',1,'AD1193',15.8,'photographyacc','mickmick26','mickael.chorier@yahoo.fr','Mickael CHORIER','8, lot les jardins de coinaud','saint rambert d\'albon','Rhône-Alpes','FRANCE','26140','06.09.53.86.96','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 19:19:33',0,NULL,3,1,3,1,' RA184576075CN\r','mickmick26'),(20435,896279803015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',2,'AD1126',15.2,'hutongstore','matiner2002','matiner2002@yahoo.es','José Monzó Soriano','Av.Gaspar Aguilar nº 22-14ª','Valencia','Comunidad Valenciana','SPAIN','46007','646900634','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 20:11:50',0,NULL,3,1,2,1,NULL,'matiner2002'),(20436,819848331017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','anick2027','mllepopcorn@videotron.ca','Anick Bélanger','172 Louis-Joseph-Rodrigue','Saint-Eustache','QC','CANADA','J7R 5Y5','(450) 735-4257','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-25 20:57:42',0,NULL,3,0,3,1,' RA184576089CN','anick2027\rXXXL 已入库'),(20437,896341242015,250607841646,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',18,'hutongstore','0nline*discounts','mizgsr@gmail.com','Zana Poposki','10 Clover Avenue','CASULA','New South Wales','AUSTRALIA','2170','0296818552','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-25 21:49:41',0,NULL,3,1,3,1,' RA184577915CN\r','0nline*discounts'),(20438,896346346015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','motke999','motke9@wp.pl','Tomasz Stasikowski, TGP Landscape Architects','7 The Square<br>95 Morrison Street','Glasgow','Glasgow (City of)','UNITED KINGDOM','G5 8LP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 21:56:50',0,NULL,3,1,2,1,NULL,'motke999'),(20439,877999440016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','fred262x','glenjgill@yahoo.co.uk','Glen Gill','14 Lincoln Street<br>New Rossington','Doncaster','South Yorkshire','UNITED KINGDOM','dn11 0tl','01302866645','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-25 21:58:50',0,NULL,3,1,2,1,NULL,'fred262x'),(20440,758569413001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','7397stepheni','mckindley_removals@bigpond.com','Stephen Ilott','16 Batten St','Bendigo','Victoria','AUSTRALIA','3550','0354463550','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'7397stepheni'),(20441,896354975015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','leelee-0145','lwarhurst@sky.com','lee warhurst','40 Gladstone street','Glossop','Derbyshire','UNITED KINGDOM','sk13 8ne','01457861894','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-25 22:11:19',0,NULL,3,1,4,1,'YW867660965CN\r','leelee-0145\r+白布  ▲'),(20442,878037366016,260883390517,'New Arrival Fancier Professional Tripod WT-6714 with Damped Pan Head w/ Case',1,'AD1196',40,'hutongstore','2011aatakker','aatakker@gmail.com','aat akker','wallsteijnpad 4','spijkenisse','','NETHERLANDS','3207zj','0031181671293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 23:12:37',0,NULL,3,1,17,0,NULL,'2011aatakker'),(20443,896386008015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',65,'hutongstore','2011aatakker','aatakker@gmail.com','aat akker','wallsteijnpad 4','spijkenisse','','NETHERLANDS','3207zj','0031181671293','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-25 23:12:38',0,NULL,3,1,4,1,'YW867660976CN\r','2011aatakker\r除了C以外再发\r伟峰6714 三脚架    1\r欧标\r▲'),(20444,758600615001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','sanderleik89','alex_diler@bk.ru','Alexander Bachinskiy','shishkina 52/2-71','Odessa','Odessa','UKRAINE','65088','380936395115','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-25 23:22:09',0,NULL,3,1,2,1,' ','sanderleik89'),(20445,801609503002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','klfamous','klfamous@yahoo.com','Kenneth Lo','15 Greenview Avenue<br>Townhouse 7','Toronto','ON','CANADA','M2M 4M7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 04:37:40',0,NULL,3,1,3,1,'RA117764597CN\r ','klfamous'),(20446,801621867002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 05:38:35',0,NULL,3,1,2,1,NULL,'dmitriyla'),(20447,820030073017,270744174175,'62mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT021',4.19,'photographyacc','kgurner70','trevor5057@hotmail.com','katreina gurner','38 nelson street','Nambucca Heads','New South Wales','AUSTRALIA','2448','0265685162','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 06:24:41',0,NULL,3,1,2,1,NULL,'kgurner70'),(20448,762410817018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','wsun3575','sundud1981@yahoo.com','Wei Sun','16 Clara St Macleod VIC 3085','Macleod','Victoria','AUSTRALIA','3085','0394328461','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 09:00:17',0,NULL,3,1,2,1,NULL,'wsun3575'),(20449,758758124001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','werner197531','wernercornelissen@vodamail.co.za','Werner Cornelissen','Hoofstraat 15','Keimoes','','SOUTH AFRICA','8860','+27828901183','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-26 10:21:17',0,NULL,3,1,3,1,' RA184577929CN\r\r','werner197531'),(20450,896590191015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','werner197531','wernercornelissen@vodamail.co.za','Werner Cornelissen','Hoofstraat 15','Keimoes','','SOUTH AFRICA','8860','+27828901183','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 10:24:52',0,NULL,3,1,3,1,' RA184577946CN\r','werner197531\r澳转欧标\r\r'),(20451,801688812002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','heyjojoh','jo9109@hotmail.com','Attaphong Naksupphamit','222 Soi Bangbon4 Soi4<br>Bangbon','Bangkok','','THAILAND','10150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 10:31:11',0,NULL,3,1,2,1,NULL,'heyjojoh'),(20452,878246346016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-0507254189','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 10:40:01',0,NULL,3,1,3,1,'RA117768316CN ','amnon064'),(20453,801689879002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','saratovfoto','titov_vit@mail.ru','Виталий Титов','2 Московский проезд, д.8, кв 32','Саратов','','RUSSIAN FEDERATION','410062','+79042406446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 10:42:14',0,NULL,3,1,17,0,NULL,'saratovfoto'),(20454,801690938002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','saratovfoto','titov_vit@mail.ru','Виталий Титов','2 Московский проезд, д.8, кв 32','Саратов','','RUSSIAN FEDERATION','410062','+79042406446','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 10:42:15',0,NULL,3,1,3,1,' RA184577932CN','saratovfoto\r伞式柔光箱 80cm 8角     2\r伞式柔光箱 60×90cm    1'),(20455,896647971015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-26 12:44:23',0,NULL,3,1,5,1,'CP240320414CN\r','leifs123\r欧标\r申报$20\r灯泡220V'),(20456,896671793015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','swax5','swax1980@aol.co.uk','darius spis','20 may gardens','hamilton','South Lanarkshire','UNITED KINGDOM','ml3 0ss','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-26 13:35:05',0,NULL,3,1,4,1,'YW867660980CN\r','swax5\r+白布 ▲'),(20457,758831114001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','ariefinn','ariefin+ebay@gmail.com','Arie Fineshtein','Cochavit 1<br>apartment 18','nazareth illit','IL','ISRAEL','17097','(972) 52-2823705','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-26 13:58:21',0,NULL,3,1,2,1,NULL,'ariefinn'),(20458,896682703015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','andrepferreira','andrepintoferreira@gmail.com','Andre Ferreira','Rua 19 nº1434 1ºEsq','Espinho','','PORTUGAL','4500-251','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 14:41:04',0,NULL,3,1,3,1,' RA184577950CN\r','andrepferreira\r欧标'),(20459,758878416001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','piromassster','beaumontmartin@hotmail.com','Martin Beaumont','1084 Ste-Thérèse','Sherbrooke','QC','CANADA','J1K 2V2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 15:49:30',0,NULL,3,1,3,1,' RA184577875CN\r','piromassster'),(20460,762563595018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','dominic09-09','sawdominic@yahoo.com.au','dominic tin','18 brown cres<br>seville grove','perth','Western Australia','AUSTRALIA','6112','0893997245','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-26 15:55:00',0,NULL,3,1,3,1,' RA184576150CN\r','dominic09-09');
INSERT INTO `hmsh_ebay_transaction` VALUES (20461,801843749002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','2004little_miss_sunshine87','nickseah87@gmail.com','Nick Seah','No.20, JLN 2/154a, Taman Delima,<br>Cheras, 56000, KL','Kuala Lumpur','Malaysia, WP, KL, Cheras','MALAYSIA','56000','0169963608','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 16:59:17',0,NULL,3,1,6,1,'EE636828815CN\r ','2004little_miss_sunshine87'),(20462,820331292017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','26thstreetboutique','kenrodulfo@gmail.com','Kennneth Rodulfo','350 E 19th St<br>Apt 2B','New York','NY','UNITED STATES','10003-2892','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 18:55:39',0,NULL,3,1,1,1,NULL,'26thstreetboutique'),(20463,878510712016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','dmitri4411','aleksey@vimpo.ru','Алексей Ожогин','3 п/о д.5 кв.64','Люберцы','','RUSSIAN FEDERATION','140003','915-439-439-7','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-11-26 19:12:24',0,NULL,3,1,5,1,'CP240320428CN\r','dmitri4411\r欧标'),(20464,801933181002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','lenapapa34','lenapapa2@hotmail.com','ELENA PAPADOPOULOU','AMMOXOSTOU 52','ATHENS','AXARNAI','GREECE','13671','(0030) 6981828037','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 19:30:55',0,NULL,3,1,2,1,NULL,'lenapapa34'),(20465,759041536001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','chrjem','jemtland@gmail.com','Christian Magnus Jemtland','Rosenlundveien 12','Sandefjord','','NORWAY','3225','0047 46418919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 20:40:38',0,NULL,3,1,2,1,NULL,'chrjem'),(20466,896955593015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','1673nicolas','nicolas@extraterrestres.net','EgoBook SARL','62, voie romaine','craponne','Rhône-Alpes','FRANCE','69290','0678597804','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 20:49:11',0,NULL,3,1,17,0,NULL,'1673nicolas'),(20467,896955307015,250933223732,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT075',188,'hutongstore','1673nicolas','nicolas@extraterrestres.net','EgoBook SARL','62, voie romaine','craponne','Rhône-Alpes','FRANCE','69290','0678597804','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 20:49:11',0,NULL,3,1,4,1,'YW867660991CN\r','1673nicolas\r除了C里面的以外再发\r麦克风   1\r欧标'),(20468,759053397001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','vincetoro','viciotoro@gmail.com','Vincenzo Santoro','Via Paladini 280','Caltanissetta','CL','ITALY','93100','336271837','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-26 21:02:03',0,NULL,3,1,2,1,NULL,'vincetoro'),(20469,896977620015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','buyer0011','matias@eertola.fi','Matias Eertola','Gesterbyntie 355 a','Kirkkonummi','','FINLAND','02400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 21:20:38',0,NULL,3,1,4,1,'YW867661002CN\r','buyer0011\r除了C以外再发\r白反光伞110cm     2  ▲\r欧标'),(20470,896986570015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',2,'AD1126',15.2,'hutongstore','buyer0011','matias@eertola.fi','Matias Eertola','Gesterbyntie 355 a','Kirkkonummi','','FINLAND','02400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-26 21:38:50',0,NULL,3,1,17,0,NULL,'buyer0011'),(20471,897014881015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','lorr9','lorraine955@btinternet.com','Lorraine Creaney','9 Grange Avenue','Castlewellan','Down','UNITED KINGDOM','BT31 9UH','02843778066','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 22:20:15',0,NULL,3,1,17,0,NULL,'lorr9'),(20472,878658938016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','lorr9','lorraine955@btinternet.com','Lorraine Creaney','9 Grange Avenue','Castlewellan','Down','UNITED KINGDOM','BT31 9UH','02843778066','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 22:20:15',0,NULL,3,1,17,0,NULL,'lorr9'),(20473,897014882015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','lorr9','lorraine955@btinternet.com','Lorraine Creaney','9 Grange Avenue','Castlewellan','Down','UNITED KINGDOM','BT31 9UH','02843778066','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 22:20:16',0,NULL,3,1,17,0,NULL,'lorr9'),(20474,878658939016,260894474713,'New Studio Light 800W Continuous Lighting Complete Kit with background support',1,'AKT087',102,'hutongstore','lorr9','lorraine955@btinternet.com','Lorraine Creaney','9 Grange Avenue','Castlewellan','Down','UNITED KINGDOM','BT31 9UH','02843778066','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-26 22:20:16',0,NULL,3,1,12,1,'2770950512\r ','lorr9\r英标\r除了C以外再发\r背景布 1.6  黑色 1\r灯架  2m  1\r反光板支架   1\r反光板 80cm 2合1       1\r实重9.515 泡重10.512\r\r'),(20475,897016809015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','alexxfin','tsp_20@hotmail.com','aleksi pihlström','urpukuja<br>4','salo','varsinais-suomi','FINLAND','24240','+358415507755','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-26 22:24:05',0,NULL,3,1,3,1,' RA184576058CN','alexxfin'),(20476,820470339017,270751577658,'New Soft Camera Bag Cover for Canon EOS 5D ii / 24-105',1,'AD1115',12.99,'photographyacc','einaar','f_evensen@yahoo.no','Frank Evensen','Monradsgate 13c','Oslo','','NORWAY','0564','+4793067155','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-26 22:47:20',0,NULL,3,1,2,1,NULL,'einaar'),(20477,759135412001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','relwofretep','robbpet@virginbroadband.com.au','Peter Fowler','PO Box 770','Tamworth','New South Wales','AUSTRALIA','2340','0267618915','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 00:15:16',0,NULL,3,1,2,1,NULL,'relwofretep'),(20478,759145765001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','jpeuvion79','jpeuvion@msn.com','Jean-Patrick Peuvion','105 Principale','Ste-Cécile-de-Lévrard','QC','CANADA','G0X 2M0','(819) 263-2552','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 00:46:10',0,NULL,3,1,2,1,NULL,'jpeuvion79'),(20479,756743945001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','jclaudio73a','claudio@millevini.com.br','Jose Claudio Silva','R. Visconde de Pirajá, 82 - Slj.201<br>Ipanema','Rio de Janeiro','Rio de Janeiro','BRAZIL','22410003','2122478835','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 01:01:03',0,NULL,3,1,2,1,NULL,'jclaudio73a'),(20480,802088727002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rinat2baly','tnati77@gmail.com','rinat2baly tubaly','netz hahalav  8','modi\'in','','ISRAEL','71708','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 01:09:20',0,NULL,3,1,2,1,NULL,'rinat2baly'),(20481,897105877015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','brucepanther','nathanroberts84@gmail.com','nathan roberts','21 bornemouth road','folkestone','Kent','UNITED KINGDOM','ct19 5ba','07776276503','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 01:40:29',0,NULL,3,1,3,1,' RA184576044CN\r','brucepanther'),(20482,897126285015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','stanabadzhiev','ts_abadzhiev@yahoo.com','JOVATECHIT, Tsanko Abadzhiev','Unit 3, 55 Parer rd<br>Airport west','Melbourne','Victoria','AUSTRALIA','3042','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 02:36:55',0,NULL,3,1,2,1,NULL,'stanabadzhiev'),(20483,759194820001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','c683920sam','c683920@gmail.com','Sam Ibrahim','73 Inverness ave<br>Penshurst','Sydney','New South Wales','AUSTRALIA','2222','0417028050','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-27 03:42:36',0,NULL,3,1,2,1,NULL,'c683920sam'),(20484,8881322367317504,111,'双灯头',1,'AE1301',0,'hermeshine','sstruik','simonstruik@msn.com','Simon Struik','Via Airolo 33','MILANO','Milano','ITALY','20159','',NULL,NULL,NULL,'2011-11-27 04:15:17',0,NULL,3,1,3,1,' RA184577813CN\r',NULL),(20485,762796978018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','fairy-jenni','jenniboo@optusnet.com.au','Jenni Davies','4 Britt Place','McDowall','Queensland','AUSTRALIA','4053','0414322896','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 06:03:34',0,NULL,3,1,3,1,' RA184576035CN\r','fairy-jenni'),(20486,802189225002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',2,'AA1206',7.98,'hermeshine','dennisco2010','littlephil63@yahoo.com.au','Philip Collins','4 / 23 Storey Road<br>Reservoir','Melbourne','Victoria','AUSTRALIA','3073','0394781999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 07:47:33',0,NULL,3,1,2,1,NULL,'dennisco2010'),(20487,819418254017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',15.36,'photographyacc','vheve','sab@southcom.com.au','Simon Bugg','P O Box 321','Wynyard','Tasmania','AUSTRALIA','7325','0364424040','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 09:29:13',0,NULL,3,1,2,1,' ','vheve\r58橡胶遮光罩   1\rcanon 反接环  52mm    1\rcanon 反接环  58mm    1\r已入库'),(20488,759296912001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','a.molina.ibanez','amolina2003@hotmail.com','Antonio Miguel Molina Ibáñez','Andrés de Urdaneta<br>6 D 1 A','Madrid','Madrid','SPAIN','28045','665901560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 10:24:09',0,NULL,3,1,17,0,NULL,'a.molina.ibanez'),(20489,802244066002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','a.molina.ibanez','amolina2003@hotmail.com','Antonio Miguel Molina Ibáñez','Andrés de Urdaneta<br>6 D 1 A','Madrid','Madrid','SPAIN','28045','665901560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 10:27:51',0,NULL,3,1,2,1,' ','a.molina.ibanez\r普通有线快门线C1  1\r爵影红外 canon   1'),(20490,802245648002,120460990450,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',16.2,'hermeshine','ljubo2360','ljubopavlic@gmail.com','Ljubo Pavlic','Obrtniska 7','Radlje ob Dravi','','SLOVENIA','2360','0038641752480','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 10:30:18',0,NULL,3,1,2,1,NULL,'ljubo2360'),(20491,763024561018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','50ebon50','eionmailbox@googlemail.com','Eion Johnston','2 Wardie Grove','Edinburgh','Midlothian','UNITED KINGDOM','EH5 1AQ','01315521768','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 11:11:00',0,NULL,3,1,2,1,NULL,'50ebon50'),(20492,897310782015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',1.88,'hutongstore','domenicon81','84billy@aliceposta.it','David Guerrini','Via carpine 32','Montefiascone','VT','ITALY','01027','3939793793','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 11:20:50',0,NULL,3,1,2,1,NULL,'domenicon81'),(20493,897316045015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','keiran1992','keiranhumphries@hotmail.co.uk','keiran humphries','6 westbury road yarnbrook','trowbridge','Wiltshire','UNITED KINGDOM','ba14 6aa','01225768072','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-27 11:44:54',0,NULL,3,1,4,1,'YW867661013CN\r','keiran1992\r黑加白\r▲'),(20494,759385973001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','klimov0512','mr.bnk@yandex.ru','Andrey Babikov','ulica Tbilisskaya, 25-89','Perm','Permskiy kray','RUSSIAN FEDERATION','614090','89058625436','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-27 13:37:53',0,NULL,3,1,17,0,NULL,'klimov0512'),(20495,802345443002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','avil5170','villalbaandy@gmail.com','Andres villalba','98 S Common St<br>apt 6','lynn','MA','UNITED STATES','01902-4549','(781) 479-9166','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 13:59:41',0,NULL,3,1,1,1,NULL,'avil5170'),(20496,897410940015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','odeemi','otto.liulia@gmail.com','Otto Liulia','Kuninkaankaarre 2 C 2','Koskenkylän saha','','FINLAND','07700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 14:03:20',0,NULL,3,1,3,1,' RA184576027CN','odeemi'),(20497,802381322002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','klimov0512','mr.bnk@yandex.ru','Andrey Babikov','ulica Tbilisskaya, 25-89','Perm','Permskiy kray','RUSSIAN FEDERATION','614090','89058625436','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 15:02:07',0,NULL,3,1,5,1,'CP240320431CN\r','klimov0512\r三脚架 伟峰 WF-6663A    1\rEW-73B   1\r'),(20498,897493427015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','phillip1684','phill71@talktalk.net','Mr Phillip Knipe','26 Allenby Rd, Cadishead','Manchester','Greater Manchester','UNITED KINGDOM','M44 5EA','01617762492','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 15:53:54',0,NULL,3,1,3,1,' RA184576013CN\r','phillip1684'),(20499,897531248015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','ritcc','ricares@euskalnet.net','RICARDO ARES','SANTIAGO BROUARD 5 2 F','BILBAO','VIZCAYA','SPAIN','48012','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-27 16:35:54',0,NULL,3,1,3,1,' RA184576101CN','ritcc'),(20500,897587664015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','davidled76','daviduco76@gmail.com','David Agudo Garcia','Piedra redonda nº 14 3ºC','Adeje','Canarias','SPAIN','38670','922710647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-27 17:29:27',0,NULL,3,1,2,1,NULL,'davidled76'),(20501,802558325002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','ukb1ll','bill@radiobangkok.net','William Hammerton','99/12 Soi Watcharathit Ahtit Soi 3<br>Soi 101/1 Bang Jak Prakanong','Bangkok','BA','THAILAND','10260','+66 (0) 83 923 7779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 18:30:29',0,NULL,3,1,17,0,NULL,'ukb1ll'),(20502,759607497001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','ukb1ll','bill@radiobangkok.net','William Hammerton','99/12 Soi Watcharathit Ahtit Soi 3<br>Soi 101/1 Bang Jak Prakanong','Bangkok','BA','THAILAND','10260','+66 (0) 83 923 7779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 18:30:31',0,NULL,3,1,2,1,NULL,'ukb1ll\r反光伞110cm    1\r沙袋（大）   1'),(20503,897681028015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',1.87,'hutongstore','kevinandmarvin','suzi@figment-media.com','Andrew Huffer','39 Oak Street<br>Belle Vue','Shrewsbury','Shropshire','UNITED KINGDOM','sy3 7rq','07801538536','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 18:39:26',0,NULL,3,1,2,1,NULL,'kevinandmarvin'),(20504,802615796002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',103,'hermeshine','darthpilot','drgates55@comcast.net','Donald Gates','652 White Oak Ln','Bartlett','IL','UNITED STATES','60103','(630) 837-4060','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-27 19:15:48',0,NULL,3,1,4,1,'YW867661024CN\r','darthpilot\r▲'),(20505,897771907015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','jasonturnergraphics','contact@jason-turner.com','Jason Turner','Disturb Media<br>5 Cowcross Street','London','London','UNITED KINGDOM','EC1M 6DW','07905303984','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-11-27 19:42:45',0,NULL,3,1,4,1,'YW867661035CN\r','jasonturnergraphics\r英标\r▲'),(20506,763447396018,280680882557,'Dslr Remote Shutter Release Cord RS-N1 Nikon D300s D700',1,'AA3207',3.99,'photographyacc','53andrzej','happy103@tiscali.co.uk','andrzej mackiewicz','103 balliol rod<br>kempston','bedford','Bedfordshire','UNITED KINGDOM','mk42 7et','01234851789','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-27 20:10:58',0,NULL,3,1,2,1,NULL,'53andrzej'),(20507,897849938015,250599989246,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200mm',1,'AC1204',4.38,'hutongstore','andosunrise','sales@pannyhire.co.uk','Stewart Addison','134 Sutton Park Road','Kidderminster','Worcestershire','UNITED KINGDOM','DY11 6JQ','07541636265','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-27 20:41:31',0,NULL,3,1,2,1,NULL,'andosunrise'),(20508,802724450002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',27,'hermeshine','netrunner-sweden','hans_hard@hotmail.com','Hans Hard af Segerstad','Kinnekullev. 4<br>16743 Bromma','Bromma / Stockholm','Stockholm','SWEDEN','16743','+46704220333','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 20:57:44',0,NULL,3,1,3,1,' RA184576061CN\r','netrunner-sweden'),(20509,759818960001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','beardmiller','grmiller@dal.ca','Gary Miller','16 Walker Street','Dartmouth','NS','CANADA','B2X 1B1','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-27 22:03:56',0,NULL,3,1,5,1,'CP240320445CN\r','beardmiller\r'),(20510,759820068001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','wahan09','wahan1@telia.com','Wahan Harutun','Mossvägen 4','Vansbro','Dalarna','SWEDEN','78050','+4628171925','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 22:10:48',0,NULL,3,1,3,1,'RA184576092CN\r','wahan09'),(20511,759829624001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','professorc_123','professor_frog@hotmail.com','(In care of DIANE PERREAULT) Thomas Campbell','4207 38th Ave E','Bradenton','FL','UNITED STATES','34208','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-27 22:26:02',0,NULL,3,1,1,1,' ','professorc_123'),(20512,763573082018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',2,'AA1304',5,'photographyacc','rosie3040','sueniven@hotmail.com','sue niven','304 Hemmant-Tingalpa Rd, Hemmant','Brisbane','Queensland','AUSTRALIA','4174','0417633493','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 22:57:49',0,NULL,3,1,17,0,NULL,'rosie3040'),(20513,763572396018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',2,'AA1315',5.98,'photographyacc','rosie3040','sueniven@hotmail.com','sue niven','304 Hemmant-Tingalpa Rd, Hemmant','Brisbane','Queensland','AUSTRALIA','4174','0417633493','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 22:57:50',0,NULL,3,1,2,1,NULL,'rosie3040\rCANON 镜头盖  77mm   2\r机身盖/镜头后盖  Canon    2'),(20514,821288344017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','cyborgfetusx','jenkins.d@internode.on.net','Daniel Jenkins','5/5-9 Greenwich Rd','Greenwich','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-27 22:58:48',0,NULL,3,1,2,1,NULL,'cyborgfetusx'),(20515,802804295002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','maxikes_777','maxikes777@gmail.com','Maxim Obolenskiу','Staropregol\'skaja naberezhnaja, 6-19','Kaliningrad','','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 22:59:47',0,NULL,3,1,2,1,NULL,'maxikes_777\r布都换成麂皮了'),(20516,759864132001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','7psyxos','gtolios@hotmail.com','George Tolios','Papagou 11','Marousi','Attiki','GREECE','15126','00306955062036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-27 23:35:43',0,NULL,3,1,2,1,NULL,'7psyxos'),(20517,821104699017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','jvivas67','jimmyv@baptisthealth.net','jimmy vivas','13178 SW 10th Ln','miami','FL','UNITED STATES','33184-2030','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 00:28:21',0,NULL,3,1,1,1,NULL,'jvivas67'),(20518,879655343016,260676062965,'New Neoprene Protector Camera Cover for Canon Nikon',1,'AC1305',4.8,'hutongstore','lemjosh','lynsey.mein@ntlworld.com','Lynsey Mein','91 Coolgardie Avenue','highams park','London','UNITED KINGDOM','E4 9HU','07931855203','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 00:35:11',0,NULL,3,1,2,1,NULL,'lemjosh'),(20519,759908032001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','anthonybeltoise','anthonybeltoise@hotmail.com','gregory julien','2133a sainte catherine est','montreal','QC','CANADA','h2k2h9','(514) 445-7268','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 01:32:46',0,NULL,3,1,3,1,'RA117764019CN ','anthonybeltoise'),(20520,802874614002,120457058846,'New Camera Tripod for Canon 450D 400D 500D 1000D 40D',1,'AE1601',59.99,'hermeshine','dolsy18','dolzy@hotmail.com','Andrew Dols','45 Kennedy St','Maylands','Western Australia','AUSTRALIA','6051','0431254430','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 01:39:21',0,NULL,3,1,4,1,'YW867661046CN\r','dolsy18\r▲'),(20521,762547203018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','michaelanthonylloyd','michaelanthonylloyd@yahoo.com','Michael Lloyd PTY2379','2789 NW 82nd Ave','DORAL','FL','UNITED STATES','33122-1074','(305) 592-8700','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 02:17:23',0,NULL,3,1,1,1,' ','michaelanthonylloyd'),(20522,8881322447907171,111,'x2 45W 110V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AD1133',16.98,'aliexpress','1005448495','bregalo@yahoo.com.br','Adiel Nunes Ferreira','Sao Caetano do Sul	','Sao Caetano do Sul	','Sao Paulo	','BRAZIL','09520-310','+55 11 35655030',NULL,NULL,NULL,'2011-11-28 02:38:27',0,NULL,3,1,3,1,'RA117764107CN\r ','45w 5500k 灯泡 110v * 2 '),(20523,8881322448157438,111,'77mm canon 镜头盖',1,'AA1304',0,'hutongstore','xulanas','ricardoisaa@gmail.com','ricardo isaá','rua maria fernanda toscano rico, nº 30','portel','portel','PORTUGAL','7220','',NULL,NULL,NULL,'2011-11-28 02:42:37',0,NULL,3,1,3,1,' RA184577889CN\r',NULL),(20524,898100763015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','raikkonenf60','g_tsompanopoulos@yahoo.com','george tsompanopoulos','kononos 69-71 pagrati','athens','Attiki','GREECE','11633','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 03:30:11',0,NULL,3,1,2,1,' ','raikkonenf60'),(20525,763691327018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','spliftopnohgih','anton@artof2.com','Anton Rehrl','Level 13<br>50 Bridge St','Sydney','New South Wales','AUSTRALIA','2000','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 03:52:59',0,NULL,3,1,4,1,'YW867661562CN\r','spliftopnohgih\r▲'),(20526,802930677002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','susan2208','spapazian@dodo.com.au','Susan  Papazian','18 Uralba Place','Sydney','New South Wales','AUSTRALIA','2076','61294897773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 03:58:42',0,NULL,3,1,17,0,NULL,'susan2208\r'),(20527,759966064001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','susan2208','spapazian@dodo.com.au','Susan  Papazian','18 Uralba Place','Sydney','New South Wales','AUSTRALIA','2076','61294897773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 04:09:37',0,NULL,3,1,3,1,'RA117764098CN ','susan2208\r反光伞   1\r灯架  2m  1\r闪光灯B座   1\r柔光伞   1\r\r'),(20528,821420396017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','tas-man10','byrnel@utas.edu.au','Liam Byrne','C/O PTAC<br>PO Box 1014','Kalgoorlie','Western Australia','AUSTRALIA','6430','0890371181','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 04:17:35',0,NULL,3,1,2,1,NULL,'tas-man10'),(20529,759973771001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','wwwarn','w_warn@hotmail.com','Patiparn Pomtongkom','Hillside Condo3 Room831 Nimmanhemin Rd.<br>t.suthep A.Muang','Chiang Mai','Chiang Mai','THAILAND','50200','0817243112','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 04:42:42',0,NULL,3,1,17,0,' ','wwwarn\r'),(20530,802946141002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','wwwarn','w_warn@hotmail.com','Patiparn Pomtongkom','Hillside Condo3 Room831 Nimmanhemin Rd.<br>t.suthep A.Muang','Chiang Mai','Chiang Mai','THAILAND','50200','0817243112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 04:50:54',0,NULL,3,1,17,0,NULL,'wwwarn'),(20531,802946669002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','wwwarn','w_warn@hotmail.com','Patiparn Pomtongkom','Hillside Condo3 Room831 Nimmanhemin Rd.<br>t.suthep A.Muang','Chiang Mai','Chiang Mai','THAILAND','50200','0817243112','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 04:53:11',0,NULL,3,1,17,0,' ','wwwarn'),(20532,802947354002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',75,'hermeshine','wwwarn','w_warn@hotmail.com','Patiparn Pomtongkom','Hillside Condo3 Room831 Nimmanhemin Rd.<br>t.suthep A.Muang','Chiang Mai','Chiang Mai','THAILAND','50200','0817243112','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 04:55:19',0,NULL,5,1,6,1,'EE636828824CN\r ','wwwarn\r除了C里面的以外再发\r背景架2mx2m  + 3个夹子    1\r背景布 1.6*2.1 黑加白\r1.6*2.1  绿色   1\r4灯头 灯头 孔  2\r5灯头+60-90棚    2\r澳标转美标\r已经发货  点不了  \r'),(20533,759978369001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','wwwarn','w_warn@hotmail.com','Patiparn Pomtongkom','Hillside Condo3 Room831 Nimmanhemin Rd.<br>t.suthep A.Muang','Chiang Mai','Chiang Mai','THAILAND','50200','0817243112','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 04:58:45',0,NULL,3,1,17,0,NULL,'wwwarn'),(20534,763713901018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','8gifts8','jewellery4u@live.com.au','Mei Siu','PO 520','Malvern','Victoria','AUSTRALIA','3144','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 05:18:08',0,NULL,3,1,2,1,NULL,'8gifts8'),(20535,898158801015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','nagi603','bugger@freemail.hu','Balazs Andras Nagy','Tulok utca 55','Budapest','-','HUNGARY','1194','+36204304737','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 06:50:19',0,NULL,3,1,2,1,NULL,'nagi603'),(20536,8881322463571239,111,'HB-7',5,'AA1216',0,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500',NULL,NULL,NULL,'2011-11-28 06:59:31',0,NULL,3,1,3,1,' RA184576146CN',NULL),(20537,760011879001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','alex_black_1','alexz7@mail.ru','Alexander Zinchenko','Yablochkova 15-75','Moscow','','RUSSIAN FEDERATION','127 322','+79266382731','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 07:48:12',0,NULL,3,1,2,1,NULL,'alex_black_1'),(20538,760013303001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','jmercado1202','j_mercado1202@yahoo.com','Jerome Mercado','c/o CARLA MERCADO<br>MBC 72, PO Box 3354','King Faisal Specialist Hospital & Research Center','Riyadh','SAUDI ARABIA','11211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 07:53:11',0,NULL,3,1,3,1,' RA184577892CN','jmercado1202'),(20539,760018527001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:16:08',0,NULL,3,1,17,0,NULL,'jig_jigsaw'),(20540,802990608002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:16:09',0,NULL,3,1,17,0,NULL,'jig_jigsaw'),(20541,802990607002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:16:09',0,NULL,3,1,17,0,NULL,'jig_jigsaw'),(20542,802990610002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:16:10',0,NULL,3,1,17,0,NULL,'jig_jigsaw'),(20543,760018528001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 08:16:10',0,NULL,3,1,3,1,'RA117764022CN\r ','jig_jigsaw\r普通有线快门线C1   1\r绿叶 渐变镜 72mm   1\r绿叶 UV  72mm      1\r绿叶 CPL 72mm    1\rEW-78D    1\rLenspen+气吹+麂皮 1\r'),(20544,802990606002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','jig_jigsaw','benxu@canada.com','Xiaoming Xu','4984 Edgepark DR NW','Calgary','AB','CANADA','T3A4H3','(403) 451-1945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 08:16:08',0,NULL,3,0,17,0,NULL,'jig_jigsaw'),(20545,763769912018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','dbull79','dflbullock88@hotmail.com','Joseph Stanley Selvaraj','401 Trinity Lane','Moose Jaw','SK','CANADA','S6H0E3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 09:25:46',0,NULL,3,0,2,1,NULL,'dbull79\r默认白色'),(20546,879842756016,260894475033,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k 312AS for 5D2 7D 60D',1,'AD1149',139,'hutongstore','4eba_2008','cheba__@mail.ru','IGOR VOLKOV','VOENNIY GORODOK \'\'KURSI VISTREL\'\' 5/65','SOLNECHNOGORSK','MOSCOW REGION','RUSSIAN FEDERATION','141501','8 905 5362078','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 09:40:01',0,NULL,3,1,6,1,'EE636828926CN ','4eba_2008\r申报  led   $50'),(20547,898234449015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','rufillo','rufillo@telefonica.net','Jose Vazquez Lopez','ACE Europe - C/ Francisco Gervas 13','Madrid','Madrid','SPAIN','28020','659347399','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-28 10:48:17',0,NULL,3,1,3,1,'RA117764036CN ','rufillo'),(20548,763796265018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',18,'photographyacc','write2nessnow','write2nessnow@hotmail.com','Vanessa Norris','30 Berberis Crescent<br>Frankston','Melbourne','Victoria','AUSTRALIA','3199','0397505307','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 10:51:58',0,NULL,3,1,3,1,'RA117764040CN\r ','write2nessnow'),(20549,803025103002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 11:01:44',0,NULL,3,1,3,1,'RA117764053CN\r ','mariomarques.com.br\r申报39.88'),(20550,821522058017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.9,'photographyacc','liesh72','eviles72@hotmail.com','Elysia Viles','C/o: Plaztech<br>PO Box 1','Coniston','New South Wales','AUSTRALIA','2500','0414869240','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 12:25:57',0,NULL,3,1,2,1,NULL,'liesh72'),(20551,879914597016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','dearjym','rossintx@yahoo.com','Emirates Airlines Service Delivery','POBox # 36050 - Archana Nambiar Parakat<br>MailBox #413 (ph.04-441-3695)','Dubai','Dubai','UNITED ARAB EMIRATES','Stf#250331','00971-4-441-3695','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 12:46:45',0,NULL,3,1,2,1,NULL,'dearjym'),(20552,898294270015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','radiomops','siegfried.schoettle@gmx.de','Siegfried E. Schoettle','Johann-Peter-Hebel-Weg 3','Grafenau/Württ.','','GERMANY','71120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 13:13:50',0,NULL,3,1,2,1,' ','radiomops'),(20553,763851528018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',2,'AB3329',97.98,'photographyacc','thomasscobie','tomscobie@hotmail.com','Thomas Scobie','112 Crampton Drive','Carleton Place','ON','CANADA','K7C 4P8','(613) 889-3828','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 13:33:54',0,NULL,3,1,5,1,'CP240320873CN ','thomasscobie'),(20554,879931815016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','m_mavrikios','m_mavrikios@yahoo.com','MICHAEL A MAVRIKIOS','3 EGLIS STREET<br>UNIT 201','LIMASSOL','','CYPRUS','3090','+35797734431','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-28 13:38:43',0,NULL,5,0,18,0,NULL,'m_mavrikios'),(20555,760133898001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','sk8suffer','sufferskateboards@yahoo.com','Craig Jefferson','9114 Marlove Oaks Ln','owings mills','MD','UNITED STATES','21117-6709','(443) 825-6462','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-28 14:29:34',0,NULL,3,0,1,1,' ','sk8suffer'),(20556,758581790001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','tirilhjelm','tiril.hjelmeland@gmail.com','Tiril Hjelmeland','Kalfarveien 58','Bergen','Bergen','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 16:01:02',0,NULL,3,1,17,0,NULL,'tirilhjelm'),(20557,803148800002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','tirilhjelm','tiril.hjelmeland@gmail.com','Tiril Hjelmeland','Kalfarveien 58','Bergen','Bergen','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 16:01:03',0,NULL,3,1,2,1,NULL,'tirilhjelm\r反光伞  1\r大力夹   1'),(20558,803157127002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','josepinheiroesales','pinheirojose@gmail.com','José Pinheiro','Rua José Monteiro de Castro Portugal 667 Ent B 1º DT','Vila Nova de Gaia','','PORTUGAL','4405-568','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 16:19:08',0,NULL,3,1,4,1,'YW867738492CN ','josepinheiroesales\r1.6*2.1 白布\r▲'),(20559,763963967018,280717920072,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',28,'photographyacc','tagov','tagov@telefonica.net','SANTIAGO VITORES TOLEDO','PLAZA DOCTOR LAGUNA, 9, 8ºB','MADRID','Madrid','SPAIN','28009','630097749','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 17:36:42',0,NULL,3,1,3,1,'RA184576968CN\r ','tagov'),(20560,760221347001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','lozt099','lucieotremblay@videotron.ca','lucie Tremblay','111 michel du gue','Varennes','QC','CANADA','J3X 1H5','(450) 652-5458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 17:41:11',0,NULL,3,1,2,1,NULL,'lozt099'),(20561,760240927001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','hliobressanvendas','bressanvendas@gmail.com','Hélio Bressan','Rua Dr Candido Espinheira 396<br>perdizes','São Paulo','São Paulo','BRAZIL','05004-000','1196973610','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 18:11:48',0,NULL,3,1,5,1,'CP240320887CN ','hliobressanvendas'),(20562,760318596001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','cannelllechristine','cannellle@msn.com','christine boulay','78 De La Loire','repentigny','QC','CANADA','j6a5b3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:06:54',0,NULL,3,0,2,1,NULL,'cannelllechristine\r1.6*2.1 蓝色'),(20563,898564305015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','jameschampionphoto','james.championphoto@googlemail.com','James Champion','24 New Street','Ringwood','Hampshire','UNITED KINGDOM','bh24 3ad','07872442699','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-28 20:08:18',0,NULL,3,1,4,1,'YW867738503CN ','jameschampionphoto\r黑加白\r▲'),(20564,803305487002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','viktorzinin2000','zinin2000@rambler.ru','Viktor Zinin','ul.Lizukova d.43 kv.113','Voronezh','RU','RUSSIAN FEDERATION','394053','+79081350163','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:14:36',0,NULL,3,1,2,1,' ','viktorzinin2000'),(20565,764077332018,280696885182,'New Pro Photo Vest for all DSLR fans Size Canon Nikon',1,'AA1103',28,'photographyacc','closner281','closnerdavid@hotmail.com','David Closner','10523 Prospect Hill Dr','Houston','TX','UNITED STATES','77064-5419','(281) 935-2696','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 20:22:09',0,NULL,3,0,1,1,NULL,'closner281\rxl 已入库'),(20566,803311859002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','basem_aar','basem.abdalraziq@gmail.com','Basem Abd Alraziq','Hagefen 56 apt. 19','Haifa','Israel','ISRAEL','35053','(972) 54 7259191','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 20:43:26',0,NULL,3,1,3,1,'RA117764084CN ','basem_aar\r电话054-7259191\r地址打清楚一点\r分开发\rRA117764075CN'),(20567,821848982017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',4.19,'photographyacc','peyotepal','agleonard@btinternet.com','ANTHONY G. LEONARD','GLENCOE, STATION ROAD<br>LOSTOCK GRALAM','NORTHWICH','Cheshire','UNITED KINGDOM','CW97PN','0160645496','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 20:57:57',0,NULL,3,1,2,1,' ','peyotepal'),(20568,803349576002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','schmikko','rmhoesli@optusnet.com.au','Michael Hoesli','5 Mindoro Place','Lethbridge Park','New South Wales','AUSTRALIA','2770','0298356583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-28 21:18:10',0,NULL,3,1,3,1,'RA184576971CN\r ','schmikko'),(20569,898641768015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.52,'hutongstore','gs.business','globalstyle.business@gmail.com','Yury Kharchenko','30 Oak Vale, Bailis Downs, Athlumney','Navan','Meath','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-28 21:35:22',0,NULL,3,1,2,1,NULL,'gs.business'),(20570,898654816015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','if-ripper','mick.bland2469@ntlworld.com','Joanne Dow','10 Pennycross Sq<br>Pennywell','Sunderland','Tyne & wear','UNITED KINGDOM','SR4 0HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 21:53:24',0,NULL,3,1,3,1,'RA184576985CN\r ','if-ripper'),(20571,760406427001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','36tara','star_light124@hotmail.com','Tara Schafer','15 Pioneer Crt','St.Catharines','ON','CANADA','L2N 7B6','(905) 321-7040','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-28 22:26:03',0,NULL,3,1,2,1,NULL,'36tara'),(20572,880321202016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','vanessaglenreid','vanessa.69@live.com','C BENNETT','61 HARROWGATE ROAD<br>HACKNEY','LONDON','London','UNITED KINGDOM','E9 5EB','07832129238','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-28 22:54:16',0,NULL,3,0,17,0,NULL,'vanessaglenreid'),(20573,898681283015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','vanessaglenreid','vanessa.69@live.com','C BENNETT','61 HARROWGATE ROAD<br>HACKNEY','LONDON','London','UNITED KINGDOM','E9 5EB','07832129238','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-28 22:54:17',0,NULL,3,1,12,1,'2770977495\r ','vanessaglenreid\rc以外再加：\r1.6m x 3m 背景布   1   白色\r\r英标'),(20574,821927238017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','moneen32','colinthlang@hotmail.com','Colin Thlang','25 Laughlin Street<br>Kingston','Brisbane','Queensland','AUSTRALIA','4114','0434390478','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 23:05:04',0,NULL,3,1,2,1,NULL,'moneen32'),(20575,764189027018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',1,'AA1304',2.5,'photographyacc','druce8022','drucehorton@ledanet.com.au','Druce Horton','285 Oak Forest Road','Kuranda','Queensland','AUSTRALIA','4881','0740938208','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 23:34:24',0,NULL,3,1,17,0,NULL,'druce8022'),(20576,821936313017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','druce8022','drucehorton@ledanet.com.au','Druce Horton','285 Oak Forest Road','Kuranda','Queensland','AUSTRALIA','4881','0740938208','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 23:34:25',0,NULL,3,1,17,0,NULL,'druce8022'),(20577,764185933018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','druce8022','drucehorton@ledanet.com.au','Druce Horton','285 Oak Forest Road','Kuranda','Queensland','AUSTRALIA','4881','0740938208','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-28 23:34:25',0,NULL,3,1,17,0,NULL,'druce8022'),(20578,764185080018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','druce8022','drucehorton@ledanet.com.au','Druce Horton','285 Oak Forest Road','Kuranda','Queensland','AUSTRALIA','4881','0740938208','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-11-28 23:34:26',0,NULL,3,1,4,1,'YW867738514CN ','druce8022\r除了C里面的再发            ▲\rCANON 镜头盖  77mm   1\rCANON 镜头盖  58mm     1\r反光板支架的夹子（双轮）   1'),(20579,764199710018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','shoppbrx','vendascomph@yahoo.com.br','wagner andrade','Dr. muricy 839  ap 154','curitiba','parana','BRAZIL','80020040','4185024177','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-28 23:57:39',0,NULL,3,1,17,0,NULL,'shoppbrx'),(20580,760445765001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','shoppbrx','vendascomph@yahoo.com.br','wagner andrade','Dr. muricy 839  ap 154','curitiba','parana','BRAZIL','80020040','4185024177','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 00:00:53',0,NULL,3,1,3,1,'RA184576999CN\r ','shoppbrx\r圆形柔光棚 40cm  2'),(20581,8881322531090181,111,'115w 220v   1',1,'AE3601',0,'hutongstore','fst1979gib','francistrenado@yahoo.co.uk','Francis Stephen Trenado','9 Evening Primrose House<br>Waterport Terraces','Gibraltar','Gibraltar','GIBRALTAR','n/a','0035058008860',NULL,NULL,NULL,'2011-11-29 01:44:50',0,NULL,3,1,3,1,'RA184577005CN\r ',NULL),(20582,8881322531509160,111,'麦克风',2,'AA1215',0,'photographyacc','hiranrathnayake','hiranstudio@yahoo.com','Hiran Mahendra','PERERA RD,Old town,Madampe','Chilaw, NORTH WESTERN ','','SRI LANKA','61230','',NULL,NULL,NULL,'2011-11-29 01:51:49',0,NULL,3,1,3,1,'RA184576923CN\r ',' 试着包在一个包装里，\r申报 Microphone $48 '),(20583,8881322532124746,111,'新的6662a上的球台',1,'',0,'hermeshine','sybnios','synbios1982@yahoo.com','Chris Makridis','Andromaxis 192','Athens','Kallithea','GREECE','17674','',NULL,NULL,NULL,'2011-11-29 02:02:04',0,NULL,3,0,3,1,'RA184576910CN\r ','检查一下一定要是新的好的 '),(20584,8881322532155223,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag',1,'AD1183',73.79,'aliexpress','1005487255','viruzvip@gmail.com','Mikhail Ivanov	','Yablochkova st. 1\"g\" kv.10','Astrakhan','RUSSIA','RUSSIAN FEDERATION	','414041','+7 927 2819072',NULL,NULL,NULL,'2011-11-29 02:02:35',0,NULL,3,1,5,1,'CP240320856CN ','+白色背景布   '),(20585,898788065015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','vanguardfilmuk','vanguardfilm@hotmail.co.uk','Simon Whybourne','19 Dennis Avenue','St Helens','Merseyside','UNITED KINGDOM','WA10 3QD','01512920307','PayPalPaymentInProcess','CheckoutComplete','UK_ExpeditedShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ','vanguardfilmuk'),(20586,760530795001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','hobie123cat','danwcasey@hotmail.com','Daniel Casey','71 Tranquille Street','Dieppe','NB','CANADA','E1A 7R4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 04:01:40',0,NULL,3,1,2,1,NULL,NULL),(20587,760546319001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','proteus30','cedricdrolet@gmail.com','Cedric Drolet','1285 rue Madelin','Quebec','QC','CANADA','G3J1N2','(418) 843-6199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 05:03:28',0,NULL,3,0,2,1,' ',' '),(20588,803533174002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','jcamilop','jcamilop960@hotmail.com','Juan Camilo Pimienta','Carrera 27 # 7 B - 50<br>Montes Claros B - Casa 161','Medellin','Antioquia','COLOMBIA','000','0574-3119783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 05:05:09',0,NULL,3,1,2,1,NULL,NULL),(20589,760554174001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','nobuhouse','solisaline@hotmail.com','aline solis','910 woodbridge ct','safety harbor','FL','UNITED STATES','34695-2951','(727) 599-6880','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-29 05:43:24',0,NULL,3,0,1,1,' ','1.6m x 2.1m 背景布   1\r黑色\r另外再放白色， 蓝色， 灰色 ，棕4种颜色的一小块做样品'),(20590,803555947002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','corpsekeeper','manuelsteel@hotmail.com','Juan Manuel Sanchez Rascon','Lote 5 Manzana 4 Colonia Los Rios<br>Calle Rio Magdalena','Guaymas','Sonora','MEXICO','85440','016221051097','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 06:00:12',0,NULL,3,1,3,1,'RA117764654CN ',NULL),(20591,8881322548470796,111,'Pro Photo Vest for 450D 500D 40D 30D 50D 5D2 user',1,'AD1134',26.99,'aliexpress','1005497089','jemmy@mbg.ocn.ne.jp','Ginary SAORI KODA	','3-25-18 GrandfortYoga702 Yoga','Setagaya-ku	','TOKYO	','JAPAN','1580097','+81 90 10457515',NULL,NULL,NULL,'2011-11-29 06:34:30',0,NULL,3,1,3,1,'RA117778653CN ',NULL),(20592,764357078018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','noodles367','bertmarie@iinet.net.au','Marie Lennerts','29 Pentland Street','CANNING VALE','Western Australia','AUSTRALIA','6155','0861428283','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 08:46:41',0,NULL,3,1,4,1,'YW867739730CN ','▲ '),(20593,803601317002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','12fred12','platon52@free.fr','fred martin','78 av de la republique','saint-dizier','Champagne-Ardenne','FRANCE','52100','0325062716','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 09:17:07',0,NULL,3,1,4,1,'YW867739741CN ','▲ '),(20594,803611601002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 09:54:03',0,NULL,3,1,3,1,'RA117764481CN\r ',' 申报gift $29.99'),(20595,760614666001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','asidored','liquidmetal@013.net','Asaf Yacobovitch','17 Perlock st.','Tel - Aviv','','ISRAEL','69367','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 10:05:33',0,NULL,3,1,2,1,NULL,NULL),(20596,764379985018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',52,'photographyacc','shell*33','goughos@bigpond.com','Shelley Gough','9 Darley Road<br>Bluewater','Townsville','Queensland','AUSTRALIA','4818','0419242475','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 10:10:33',0,NULL,3,0,3,1,'RA117764566CN\r ','XL 黑色 已入库 '),(20597,803617127002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','albotalbot86','albinre@bredband.net','Albin Rönnblad Ericsson','Hannebergsgatan 22','Solna','Solna','SWEDEN','17168','+46735403665','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 10:13:31',0,NULL,3,1,4,1,'YW867739752CN ','▲ '),(20598,898964905015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','edilson37','ducati78@hotmail.com','Edilson Santos','10 MEDLAR HOUSE<br>HEMLOCK CLOSE','London','London','UNITED KINGDOM','SW16 5PS','07968809411','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 10:52:39',0,NULL,3,1,2,1,NULL,NULL),(20599,760628211001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','electrofanaticss','okanuygun@gmail.com','ZEHRA UYGUN','YALI MH.YONCA SK. NO:1<br>KARTAL','ISTANBUL','','TURKEY','34873','00905554851454','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 10:57:06',0,NULL,3,0,2,1,NULL,' 1.6*2.1白色'),(20600,763915644018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','ojaeyna','oja_6152@yahoo.com','NOR SA\'ID HARUN','NO 6, QUARTERS GURU<br>SMK SULTAN ABDULLAH','CHENDERONG BALAI','PERAK','MALAYSIA','36600','019-4156876','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 10:59:46',0,NULL,3,0,3,1,'RA117764570CN\r ',' XXXL 已入库'),(20601,760630828001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','sruthi36','sruthi.36@gmail.com','Sruthi Pillai','5, Bridgeview Circuit','Bella Vista','New South Wales','AUSTRALIA','2153','0296296360','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 11:04:27',0,NULL,3,1,2,1,NULL,NULL),(20602,898989164015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','iorox10','io_tz@yahoo.gr','Roxani Konstantinidou','Aristotelous 28A','Thessaloniki','Macedonia','GREECE','55133','(2310) 448586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 11:59:38',0,NULL,3,1,3,1,'RA117764549CN\r ',NULL),(20603,764413414018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','filmoz1954','film_oz@bigpond.com','David  Walpole','47 Templetonia Retreat','Canningvale','Western Australia','AUSTRALIA','6155','61862542670','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 11:59:48',0,NULL,3,1,3,1,'RA117764552CN\r ',NULL),(20604,760645887001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','oksana.pesternikova','pesternikovao@yahoo.com','Оксана Пестерникова','ул. Профсоюзная 77 кв.82','Москва','','RUSSIAN FEDERATION','117342','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 12:05:00',0,NULL,3,1,2,1,NULL,' 1.6*2.1黑色布'),(20605,899001221015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',5,'AA1314',11,'hutongstore','thepacecentre','simon.ekless@thepacecentre.org','Simon Ekless','The PACE Centre, Riverside House<br>44 Wedgewood Street','Aylesbury','Buckinghamshire','UNITED KINGDOM','HP19 7HL','07931929685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 12:30:44',0,NULL,3,1,3,1,'RA117764464CN\r ','5个 '),(20606,760663830001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','luisfacampos1','luisfacampos@gmail.com','Luis Campos','Rua Carlos Ramos, N 14, 1D','Coimbra','Coimbra','PORTUGAL','3030-777','00351965247620','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 12:57:35',0,NULL,3,1,3,1,'RA117764583CN\r ',NULL),(20607,760700227001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',59.98,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 14:40:04',0,NULL,3,1,17,0,NULL,NULL),(20608,760700228001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 14:40:05',0,NULL,3,1,5,1,'CP240320860CN ',' 反光板支架  2\r牛津布大包    1\r'),(20609,764472221018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','tomburke7','tom_burke@dodo.com.au','Tom Burke','7 Farrer Crt','Warranwood','Victoria','AUSTRALIA','3134','0398763047','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 14:44:07',0,NULL,3,1,2,1,' ',''),(20610,803713989002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','rav4eg','roadmaster@mail.ru','Vasiliy Vavilov','22a<br>Angarskaya','Perm\'','Permskiy Kray','RUSSIAN FEDERATION','614018','+79091003444','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 15:02:22',0,NULL,3,1,5,1,'CP240320839CN ',NULL),(20611,803735599002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',43,'hermeshine','ebhenderson2008','ebrunson@scsu.edu','Elaine  Henderson','1285 Oaklane Dr','Orangeburg','SC','UNITED STATES','29115-8116','(803) 539-1846','NoPaymentFailure','CheckoutComplete','Other','2011-11-29 15:55:37',0,NULL,3,0,1,1,NULL,' XXXL 已入库'),(20612,898925091015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','jonatanjc','jon83stc@hotmail.com','jonatan justicia carrasco','calle duquesa de la victoria 20 3 2','terrassa','Cataluña','SPAIN','08223','637117107','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 16:14:37',0,NULL,3,1,4,1,'YW867739763CN ','▲ '),(20613,803746018002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','flyingspits','flyingspit@yahoo.co.uk','longmire ian','1 briarhill gdns','hartlepool','Cleveland','UNITED KINGDOM','TS26 0JW','01429861929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 16:16:51',0,NULL,3,1,2,1,NULL,NULL),(20614,803788834002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',3,'AD1198',98.97,'hermeshine','chomba8','extreme_gc@hotmail.com','francisco gomez','miguel cruchaga<br>1351A','rancagua','rancagua','CHILE','2820704','5690895207','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 17:43:01',0,NULL,3,1,3,1,'RA117764637CN ',NULL),(20615,760787463001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mrobertvr6','mrobertvr6@hotmail.com','Martin Robert','606 philippes kennes','Granby','QC','CANADA','j2h0c8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-29 17:56:40',0,NULL,3,1,2,1,' ',NULL),(20616,803784008002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','saratovfoto','titov_vit@mail.ru','Виталий Титов','2 Московский проезд, д.8, кв 32','Саратов','','RUSSIAN FEDERATION','410062','+79042406446','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-29 18:08:55',0,NULL,3,1,3,1,'RA117764478CN\r ',NULL),(20617,880796838016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',32,'hutongstore','1205osiris','lumiere1205@hotmail.com','Ben Yap','Blk 530 Bukit Batok St 51#02-34','default','','SINGAPORE','650530','92293913','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 18:14:24',0,NULL,5,1,3,1,'RA117769753CN\r ',' 接口 环换成77mm的\r已发货  点不了 '),(20618,803821655002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','lamel29m','marina_krasik@ukrpost.net','Marina Krasik','Shakhtostroiteley bl.,h.26, f. 48','Donetsk','UA','UKRAINE','83052','38-050-158-50-81','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 18:40:20',0,NULL,3,1,3,1,'RA117764535CN\r ',NULL),(20619,880845950016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','ivanov1985','m-star@list.ru','Алексей Иванов','serafima-deryabina 19/2 105','Ekaterinburg','Sverdlovskaya oblast','RUSSIAN FEDERATION','620102','007 9126568638','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-29 19:18:15',0,NULL,3,1,5,1,'CP240320842CN ',NULL),(20620,803864396002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','lilluvely','ahudgins@gmail.com','Charles','10306 Fox Chase Cir','New Market','MD','UNITED STATES','21774','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-29 19:45:23',0,NULL,3,1,1,1,NULL,NULL),(20621,803864163002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','luthwitz','luther.padial@gmail.com','Luther Victor Santos Padial','Rua Luigi Giuseppe Ercolin 20<br>Assunção','Sao Bernardo Do Campo','São Paulo','BRAZIL','09850-120','+55 11 23560888','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-29 19:46:05',0,NULL,3,1,3,1,'RA117764521CN\r ',NULL),(20622,899260391015,250692237866,'New 3 filters & Ring holder for Cokin System P Series',1,'AKT071',16,'hutongstore','tundike78','tunde.kugler@freemail.hu','Tunde Kugler','29 Snell Wood Court ','Little Chalfont','Buckinghamshire','UNITED KINGDOM','HP79QT','07724692282','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 19:58:27',0,NULL,3,1,3,1,'RA117778389CN ',' 接口环62mm  1\r58mm接口环换成77mm的，\r其他不变'),(20623,760888879001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','20110661','thierry.mabic@gmail.com','Thierry MABIC','72 chemin de Lapujade<br>Batiment 4','TOULOUSE','Midi-Pyrénées','FRANCE','31200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 20:40:11',0,NULL,3,1,17,0,NULL,NULL),(20624,760889753001,110540946330,'QR Quick Release Plate Tripod Head For Fancier FT-6663A',1,'AB1203',8,'hermeshine','20110661','thierry.mabic@gmail.com','Thierry MABIC','72 chemin de Lapujade<br>Batiment 4','TOULOUSE','Midi-Pyrénées','FRANCE','31200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 20:40:10',0,NULL,3,1,4,1,'YW867739774CN ',' 三脚架 伟峰 WF-6663A    1\r伟峰 6663A 快装板    1\r▲'),(20625,803967650002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kestas_bar','kestutis.barauskas@gmail.com','Kestutis','233 Castleforbes Sq<br>Block E , Castleforbes Road Dublin D1','Dublin','Dublin','IRELAND','D1','353865865','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-29 22:38:51',0,NULL,3,1,3,1,'RA117764518CN\r ',NULL),(20626,899387533015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','peediesanday1','leonatulloch@hotmail.com','Leona Allan','Fynchaley, Holm Road,','Kirkwall','Orkney','UNITED KINGDOM','KW151PY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-29 22:53:40',0,NULL,3,1,4,1,'YW867739785CN ',NULL),(20627,822171653017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','xevildeazx','evildeaz@gmail.com','David Fernandez Artiñano','c/travesia del cristo mº 12 bajo A','arrigorriaga','País Vasco','SPAIN','48480','686590889','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-29 23:43:26',0,NULL,3,1,2,1,NULL,NULL),(20628,764767050018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','bintanggg23','bintanggg@yahoo.com','graeme bint','23 Law St','Cairns North','Queensland','AUSTRALIA','4870','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-29 23:59:13',0,NULL,3,1,3,1,'RA117764606CN\r ',NULL),(20629,881033594016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',2,'AD1177',35.8,'hutongstore','jamer1967','jamer2021@gmail.com','javier merchan ramirez','conde de cedillo 27','cedillo del condado','Castilla-La Mancha','SPAIN','45214','636581980','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-29 23:59:51',0,NULL,3,1,3,1,'RA117764645CN\r ',NULL),(20630,8881322617334601,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',23.39,'aliexpress','1005511626 ','akylov-oleg-n@mail.ru','JULIA PORFIREVA	','Highway of Enthusiasts dom54kv56','Balashikha','M.O	','RUSSIAN FEDERATION	','143900','+926 022 8578',NULL,NULL,NULL,'2011-11-30 01:42:14',0,NULL,3,1,3,1,'RA117778675CN ',NULL),(20631,8881322619898016,111,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2401',16.73,'aliexpress','1005512275','finik@voila.fr','ledjiri nataliya','149 rue de l echasse','saint quentin fallavier	','france','FRANCE','38070','+336 610 77953',NULL,NULL,NULL,'2011-11-30 02:24:58',0,NULL,3,1,3,1,'RA117778667CN ',NULL),(20632,881108029016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','dlel7893','scottanddonna1@bigpond.com','donna lellmann','26 lockheed circuit','st clair','New South Wales','AUSTRALIA','2759','0404802852','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 03:11:02',0,NULL,3,1,2,1,NULL,NULL),(20633,764841626018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',3,'AE1201',13.2,'photographyacc','windowsolutions','scottwindowsolutions@bigpond.com','scott b buttigieg','PO box 274','Maroubra','New South Wales','AUSTRALIA','2035','0293141777','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 04:00:05',0,NULL,3,1,2,1,NULL,NULL),(20634,761066837001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','wait2870','wait2870@comcast.net','Mark Waite c/o Thomas J Paul, Inc.','1061 Rydal Rd','Rydal','PA','UNITED STATES','19046-1713','(215) 886-3220 ext.: 104','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 04:52:47',0,NULL,3,1,3,1,'RA117764835CN ',NULL),(20635,761079653001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',3,'AE3601',54,'hermeshine','loffman83','samloughland@hotmail.com','Sam loughland','3/260 St.Goerge\'s Rd','North Fitzroy','Victoria','AUSTRALIA','3068','0408408288','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 05:53:46',0,NULL,3,1,3,1,'RA117764858CN ',NULL),(20636,761079797001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',2,'AD1401',18,'hermeshine','exemxm','exem_xm@hotmail.com','Mohamed Ahmed (7979079)','Ma. Inguruge','Male\'','','MALDIVES','20165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 05:55:45',0,NULL,3,1,12,1,'2770968583\r',' 灯架  2m  2\r力飞 影视闪光灯 lf200w   2  欧标\r柔光伞  2\r反光伞 2\r牛津布包   1\r已入库\r催小王把拿回来\r实重5.496   泡重6.37'),(20637,804113409002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',2,'AKT051',23,'hermeshine','junque2jewels','esales@junque2jewels.com','R Burke','4364 HENDERSON CIR','Jackson','MS','UNITED STATES','39206-5925','(601) 665-3033','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-11-30 06:38:14',0,NULL,3,1,17,0,NULL,NULL),(20638,761086040001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',36.99,'hermeshine','junque2jewels','esales@junque2jewels.com','R Burke','4364 HENDERSON CIR','Jackson','MS','UNITED STATES','39206-5925','(601) 665-3033','NoPaymentFailure','CheckoutComplete','Other','2011-11-30 06:38:14',0,NULL,3,1,1,1,NULL,' lenspen   2\r4螺丝井字扳手   2'),(20639,8881322635603866,111,'闪光灯套装',1,'AKT079',0,'hermeshine','junque2jewels','esales@junque2jewels.com','R Burke','4364 HENDERSON CIR','Jackson','MS','UNITED STATES','39206-5925','(601) 665-3033',NULL,NULL,NULL,'2011-11-30 06:46:43',0,NULL,5,1,18,0,NULL,NULL),(20640,761097348001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','lysabassan','yann.ontsa.ontsa@gmail.com','ONTSA-ONTSA Yann','4 rue du Versant Ouest','Poitiers','Poitou-Charentes','FRANCE','86000','06.71.09.16.16','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 07:29:18',0,NULL,3,1,3,1,'RA117764844CN ',NULL),(20641,899573028015,250599919356,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',1.6,'hutongstore','tundike78','tunde.kugler@freemail.hu','Tunde Kugler','29 Snell Wood Court ','Little Chalfont','Buckinghamshire','UNITED KINGDOM','HP79QT','07724692282','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 07:46:33',0,NULL,8,1,17,0,NULL,NULL),(20642,880504413016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','larsleer','lars.leer@webspeed.dk','Lars Leer','Tinggaarden 27','Herfoelge','','DENMARK','4681','61261862','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 08:47:02',0,NULL,3,1,2,1,NULL,NULL),(20643,899611018015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','alfij','post@alf-inge.com','Alf-Inge Johnsen','Kongensgate 59','Bodø','','NORWAY','8006','004793242605','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 09:42:38',0,NULL,3,1,3,1,'RA117778755CN ',NULL),(20644,764923502018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','peyotepal','agleonard@btinternet.com','ANTHONY G. LEONARD','GLENCOE, STATION ROAD<br>LOSTOCK GRALAM','NORTHWICH','Cheshire','UNITED KINGDOM','CW97PN','0160645496','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-11-30 09:49:38',0,NULL,3,1,2,1,NULL,NULL),(20645,761135257001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','akrfraser','akr.fraser@gmail.com','Angus Fraser','32 James Pde','Traralgon','Victoria','AUSTRALIA','3844','0488591188','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 10:00:11',0,NULL,3,1,4,1,'YW867661212CN ','▲ '),(20646,764946775018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','janakae','janaka.e@gfk.com','Janaka Ediriwickrema','Level 8<br>107 Mount Street','North Sydney','New South Wales','AUSTRALIA','2060','0421027663','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 11:07:06',0,NULL,3,1,2,1,NULL,NULL),(20647,880365153016,260854010827,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',11.9,'hutongstore','musse63stefan','a10z24@hotmail.com','stefan wallström','silverstigen 6','södertälje','södertälje','SWEDEN','15148','4608-55035019','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 12:07:01',0,NULL,3,1,2,1,NULL,NULL),(20648,761178881001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',33.98,'hermeshine','antiques_private_collection','halkalis@msn.com','MILTIADIS CHALKALIS','M.KARAOLI 23','KOMOTINI','RODOPI','GREECE','69100','+306944852975','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 12:28:47',0,NULL,3,1,3,1,'RA117778738CN ',NULL),(20649,764984264018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','jonny_taise','j_knaap@hotmail.com','Jonathan van der Knaap','Unit 6, 157 Fullarton Road','Rose Park','South Australia','AUSTRALIA','5067','0406760733','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 13:01:46',0,NULL,3,1,2,1,NULL,NULL),(20650,761197240001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','eeffamous','teenage_tragedy@live.nl','Evelien van den Berg','Columbusstraat 223','Den Haag','','NETHERLANDS','2561AJ','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 13:24:08',0,NULL,3,1,3,1,'RA117778619CN ',NULL),(20651,881318855016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','katstanley93','kat-stanley@hotmail.co.uk','Miss Kat Stanley','24a Grosvenor Road<br>Langley Vale','Epsom','Surrey','UNITED KINGDOM','KT186JH','07837386709','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 13:49:20',0,NULL,3,1,2,1,NULL,NULL),(20652,881322499016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','catmere4','colinfarrow@tiscali.co.uk','Colin Farrow','4 Catmere Herne<br>Mulbarton','Norwich','Norfolk','UNITED KINGDOM','NR14 8NU','01508570522','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-30 13:55:36',0,NULL,3,1,4,1,'YW867661223CN ','▲ '),(20653,822825262017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.9,'photographyacc','deman08','robs@live.com.au','Robert Pasnin','9 Gallery court<br>Kawungan','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 14:22:59',0,NULL,3,1,17,0,NULL,NULL),(20654,822826483017,270833010437,'Bounce Flash Diffuser for Speedlight Flash Canon 430EX',1,'AB3331',2.9,'photographyacc','deman08','robs@live.com.au','Robert Pasnin','9 Gallery court<br>Kawungan','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-11-30 14:25:43',0,NULL,3,1,2,1,NULL,' EW-73B   1\r肥皂盒 柔光罩  430EX     1'),(20655,761223316001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','cafemg','carlosmerino149@hotmail.com','Carlos Merino','Jirón Mantaro 102 - El Tambo','Huancayo','Junín','PERU','064','242676','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-11-30 14:38:03',0,NULL,3,1,3,1,'RA117778698CN ',NULL),(20656,899734972015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','koubekson','jakub.hlavaty@gmail.com','Jakub Hlavatý','Brojova 16','Plzeň','','CZECH REPUBLIC','32600','(00420) 776 299 455','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-11-30 14:41:32',0,NULL,3,1,5,1,'CP240320723CN ',NULL),(20657,899748325015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','marcoaoa','marco.oa@hotmail.com','Marco Olmo Alba','c/ Medico Antonio Arroyo, 2 fase 1 escalera 6 6º A<br>Telephone +34 607239809','Alicante','Comunidad Valenciana','SPAIN','03005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 15:16:18',0,NULL,3,1,2,1,NULL,NULL),(20658,761333542001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','mullin-17','mbassot@gmail.com','Marcel Bassot','Brunnenweg 2b','Würenlos','','SWITZERLAND','5436','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 18:33:41',0,NULL,3,1,3,1,'RA117778707CN ',NULL),(20659,761343185001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'',68.99,'hermeshine','lexdetva','alexander.filo@post.sk','Alexander Filo','Obrancov mieru 6','Detva','','SLOVAK REPUBLIC','962 12','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 18:47:30',0,NULL,3,1,3,1,'RA117778715CN ',' 2m灯架    1\r云台      1\r伞式柔光箱 80cm 8角      1'),(20660,761357064001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',2,'AD1195',58,'hermeshine','ost-video','a.ostryanin@gmail.com','Artemij Ostryanin','ul.Kalinina d.79b, kv.111','Tula','Tulskaya','RUSSIAN FEDERATION','300040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 19:07:12',0,NULL,3,1,3,1,'RA117778640CN ',NULL),(20661,881516585016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','matthewsdj','slackmat74@hotmail.co.uk','Darren Matthews','66 Ashfield Drive','Halifax','West Yorkshire','UNITED KINGDOM','HX3 5PG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 19:16:58',0,NULL,3,1,17,0,NULL,NULL),(20662,899912090015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','matthewsdj','slackmat74@hotmail.co.uk','Darren Matthews','66 Ashfield Drive','Halifax','West Yorkshire','UNITED KINGDOM','HX3 5PG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-11-30 19:16:59',0,NULL,3,1,4,1,'YW867661190CN ',' 灯架包厚   1\r灯架  2m   2\r闪光灯B座    2\r柔光伞     2                    ▲\r泡重4.6  实重  3.2\r'),(20663,899911913015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','foglaursen','pfl@hr-laursen.dk','Peter Laursen','Praestemarksvej 30','Copenhagen S','','DENMARK','DK-2300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-11-30 19:17:59',0,NULL,3,1,4,1,'YW867661201CN ',' 黑加白\r▲'),(20664,804420482002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 19:47:15',0,NULL,3,1,3,1,'RA117778622CN ',' 申报gift$29.99'),(20665,899942292015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','mellydavies','melanie@meldavies.com','Melanie Davies','294 Coed-Y-Gores','Cardiff','Cardiff','UNITED KINGDOM','CF23 9NP','07502233929','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-30 20:07:00',0,NULL,3,1,4,1,'YW867661175CN ','英标 \r▲'),(20666,804457978002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','slm1805','maistacey@yahoo.com','Stacey Mai','1805 Neighborhood Walk','McDonough','GA','UNITED STATES','30252-8648','(678) 521-0423','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-11-30 20:39:07',0,NULL,3,1,1,1,' ',NULL),(20667,804450600002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','altego999','rlashley@pacbell.net','Robert Lashley','5931 Amapola Dr','San Jose','CA','UNITED STATES','95129-3058','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-11-30 20:27:35',0,NULL,3,1,3,1,'RA117778724CN ',NULL),(20668,761462503001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','abalswaid2011','abalswaid@yahoo.com','abdulrahman alswaid','aljabal alaswad<br>alsahafah area','riyadh','riyadh','SAUDI ARABIA','22490','966505254337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 21:54:47',0,NULL,3,1,3,1,'RA117778809CN ',NULL),(20669,804518666002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','jacqui6183','jacquilkelly@optusnet.com.au','Jacqui Kelly','23 Camira St<br>Maroubra','Sydney','New South Wales','AUSTRALIA','2035','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 22:20:51',0,NULL,3,1,2,1,NULL,NULL),(20670,881666869016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','lrhibbert','laura4some1sexy@hotmail.com','Laura Hibbert','15 Hunters Way','Sheffield','South Yorkshire','UNITED KINGDOM','S25 2TH','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-11-30 22:34:38',0,NULL,3,1,4,1,'YW867661186CN ','▲ '),(20671,761482233001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','dberkovic','danijel.berkovic@gmail.com','Danijel Berkovic','Sokolgradska 53','Zagreb','','CROATIA','10000','+385 91 6500945','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 22:35:18',0,NULL,3,1,2,1,NULL,NULL),(20672,804541209002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','kappate','melli_23@hotmail.com','Matias Cappato','SCALABRINI ORTIZ  3020 6° C','BUENOS AIRES','CAPITAL FEDERAL - BARRIO PALERMO','ARGENTINA','1425','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 23:28:19',0,NULL,3,1,17,0,' ',NULL),(20673,804552755002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kappate','melli_23@hotmail.com','Matias Cappato','SCALABRINI ORTIZ  3020 6° C','BUENOS AIRES','CAPITAL FEDERAL - BARRIO PALERMO','ARGENTINA','1425','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-11-30 23:39:39',0,NULL,3,1,3,1,'RA117778790CN ',' EW-73B     2\rlenspen     1\r'),(20674,804563177002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','enfermera1971','pep.sanso@gmail.com','JOSEP SANSO MARTI','C/GENIL,13','PALMA DE MALLORCA','Baleares','SPAIN','07009','971249999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 00:07:19',0,NULL,3,1,17,0,NULL,NULL),(20675,804563178002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','enfermera1971','pep.sanso@gmail.com','JOSEP SANSO MARTI','C/GENIL,13','PALMA DE MALLORCA','Baleares','SPAIN','07009','971249999','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 00:07:20',0,NULL,3,1,2,1,NULL,' 气吹 + 布     1\rlenspen     1\rEW-73B   1\r\r'),(20676,758569413001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','7397stepheni','mckindley_removals@bigpond.com','Stephen Ilott','16 Batten St','Bendigo','Victoria','AUSTRALIA','3550','0354463550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 00:42:02',0,NULL,3,1,2,1,NULL,NULL),(20677,760458521001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','nicehotbath','garyanicholson@gmail.com','Gary A.Nicholson ~ Garrison Brands','12 Lanyon Place. Admiralty Cove<br>Whitby','Wellington','Admiralty Cove','NEW ZEALAND','5024','11/11/11','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 00:47:01',0,NULL,3,1,2,1,NULL,NULL),(20678,804583209002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','danijel.polanc','polancd@yahoo.com','Danijel Polanc','Tina Ujevica 19<br>Kod Zatezalo','Rijeka','','CROATIA','51000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 01:09:34',0,NULL,3,1,2,1,NULL,NULL),(20679,765355609018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','black929929','nof@live.com.au','nick o\'ferrall','50 merlin tce kenmore','brisbane','Queensland','AUSTRALIA','4069','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 01:29:54',0,NULL,3,1,3,1,'RA117778684CN ',NULL),(20680,804600421002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','kinguiorasta','netolauro@yahoo.com.br','Dirlene Gomes','Rua 7 de setembro, 55.<br>Bairro: Tabuleiro dos Martins.','Maceió','Alagoas','BRAZIL','57061-140','55-82-33241676','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 02:01:22',0,NULL,3,1,3,1,'RA117778636CN ',NULL),(20681,804601401002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','susansusieshopper','suemoran@shaw.ca','Susan Moran','685 Greene Road','Kelowna','BC','CANADA','V1W1B7','(250) 764-2412','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 02:10:25',0,NULL,3,1,2,1,NULL,NULL),(20682,8881322705590610,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head',1,'AE1603',27.89,'aliexpress','1005535716 ','mehmetdenk@hotmail.com','mehmet denk	','IL EMNIYET MUDURLUGU FOTO FILM BURO AMIRLIGI','OSMANIYE','','TURKEY','80100','+90 505 5405885',NULL,NULL,NULL,'2011-12-01 02:13:10',0,NULL,3,1,3,1,'RA117769563CN\r ',NULL),(20683,804606436002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','autotek95','matson@centurytel.net','BRENT A. MATSON','301 1st St W','POLSON','MT','UNITED STATES','59860-2606','(406) 883-1886','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-01 02:19:37',0,NULL,3,1,4,1,'YW867661551CN',' 灯泡是110v的  \r已入库  \r▲'),(20684,761577475001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',2,'AA2205',7,'hermeshine','walterjan2005','wltrjn_pascua@yahoo.com','Walter Jan Pascua','7411 Somerton Way','Sacramento','CA','UNITED STATES','95828','(916) 662-3239','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-01 03:27:24',0,NULL,3,1,1,1,NULL,NULL),(20685,8881322710039269,111,'Nikon 肩带 黄色 logo',1,'AB1403',0,'hutongstore','djtomosullivan','djtomos07@yahoo.co.uk','Thomas O Sullivan','9 Huyton Hey Road, Huyton','Liverpool','Merseyside','UNITED KINGDOM','L36 5SF','',NULL,NULL,NULL,'2011-12-01 03:27:05',0,NULL,3,1,3,1,'RA117769033CN\r ',NULL),(20686,804643514002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','kmaxfiel','maxsoft@ix.netcom.com','Kevin Maxfield','1820 E 3900 S','Holladay','UT','UNITED STATES','84124-1613','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-01 04:20:25',0,NULL,3,1,3,1,'RA117769020CN\r ',NULL),(20687,765407693018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','peter2005reus','pedrofelipe@telefonica.net','Pedro Felipe Gay Sorrius','C/ Metalurgia Num 8, Poligono Industrial La Drecera<br>Automocion Pere SL','La Selva del Camp','Cataluña','SPAIN','43470','977760585','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-01 04:30:19',0,NULL,3,1,2,1,NULL,NULL),(20688,763702483018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',4,'AD1169',25.6,'photographyacc','david_lyf','ebay@ad.mu','David C. K. Li Yuen Fong','36 Uganda Street','Burwood','Victoria','AUSTRALIA','3125','0398333759','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 04:38:16',0,NULL,3,1,2,1,NULL,NULL),(20689,8881322715036574,111,'三脚架 伟峰 EI-717 配件',1,'',0,'hermeshine','sixties-and-seventies','adnan_pamukcu@hotmail.com','Adnan Pamukçu','Caferaga Mah. Yaver Bey Sok. No. 2/2<br>Moda-Kadiköy','Istanbul','-','TURKEY','34710','902164186956',NULL,NULL,NULL,'2011-12-01 04:50:36',0,NULL,7,0,18,0,NULL,NULL),(20690,8881322715127772,111,'三脚架 伟峰 EI-717 配件',1,'',0,'hermeshine','sixties-and-seventies','adnan_pamukcu@hotmail.com','Adnan Pamukçu','Caferaga Mah. Yaver Bey Sok. No. 2/2 Moda-Kadiköy','Istanbul','-','TURKEY','34710','902164186956',NULL,NULL,NULL,'2011-12-01 04:52:07',0,NULL,3,1,3,1,'RA117769740CN\r',NULL),(20691,804653362002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','rrrivera2110','rachelrivera2108@yahoo.co.nz','RACHEL RIVERA','281 C FITZGERALD AVENUE<br>CHRISTCHURCH CENTRAL','CHRISTCHURCH','Canterbury','NEW ZEALAND','8013','+64225723276','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-01 05:05:40',0,NULL,3,1,6,1,'EE495359640CN ','绿色背景布 '),(20692,761614043001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','stas-keld','stas.keld@gmail.com','Stanislav Borisov','Avrora, 183-6','Samara','Samara Region','RUSSIAN FEDERATION','443045','7 (846) 223-51-63','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 06:07:26',0,NULL,3,1,3,1,'RA117769104CN\r ',NULL),(20693,8881322724551524,111,'3个夹子',1,'',0,'hutongstore','jabocangas','ebay@jaboweb.com','Jose Manuel Benavides Orge','Hio Limens Barreira, 35','Cangas de Morrazo','Galicia','SPAIN','36940','676319433',NULL,NULL,NULL,'2011-12-01 07:29:11',0,NULL,3,1,3,1,'RA117769016CN\r ',NULL),(20694,804693543002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','andythien','andylove_18@hotmail.com','Thien Martin Nguyen Duc','Smedjegatan 1','Malmö','Skåne','SWEDEN','21421','+46702301997','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-01 08:11:41',0,NULL,3,1,4,1,'YW867661514CN ','▲ '),(20695,761643125001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','the-gpvideo','thegpvideo@gmail.com','Pavel Gulyga','pos. Saharnyj zavod, d.25, kv.1','Timashevsk','Krasnodarskij kraj','RUSSIAN FEDERATION','352701','79180175737','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-01 08:31:39',0,NULL,3,1,3,1,'RA117769078CN\r ',NULL),(20696,761656591001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','greavsie123','sampsoncollins@gmail.com','Benjamin Ramsey','17 Breadalbane Court<br>Sydenham','Melbourne','Victoria','AUSTRALIA','3037','0425791285','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 09:28:57',0,NULL,3,1,3,1,'RA117769166CN ',NULL),(20697,8881322732834632,111,'Photo Studio Background Support Carrying Carry Bag',1,'',5.39,'aliexpress','1005547574 ','serg8899@gmail.com','sergey ﻿kalabun﻿','Bryanceva 22 kv 28','Saint Petersburg','Russia','RUSSIAN FEDERATION','195297','+7 911 1902923',NULL,NULL,NULL,'2011-12-01 09:47:14',0,NULL,3,1,3,1,'RA117769665CN ','AD1129 \r灯架包薄 * 1'),(20698,765391379018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','840lauren','laurenc79@optusnet.com.au','Lauren Mugford','10 Ronald Rd<br>Redwood Park','Adelaide','South Australia','AUSTRALIA','5097','0882645603','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 10:38:56',0,NULL,3,1,4,1,'YW867661525CN ',NULL),(20699,765493042018,280678921424,'Neoprene Protector Camera Cover 4 Canon 7D 40D 5D ii L ',1,'AC1304',6.98,'photographyacc','vlato','vladimirtodorov@abv.bg','Vladimir Todorov','Zvanika #11<br>app. 7','Sofia','','BULGARIA','1680','+359878825082','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-01 10:41:15',0,NULL,3,1,2,1,NULL,NULL),(20700,900320668015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','yeast-london','ranaporosa@gmail.com','Riccardo Corsini','91 Kenworthy Road','London','London','UNITED KINGDOM','e9 5rb','07565417021','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 10:49:57',0,NULL,3,1,3,1,'RA117769696CN\r ',NULL),(20701,761679572001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','photosyntheseth','sethg@tpg.com.au','seth gibbard','2/3 scott street<br>pyrmont','sydney','New South Wales','AUSTRALIA','2009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 10:53:56',0,NULL,3,1,3,1,'RA117769170CN ',NULL),(20702,900337467015,250599945807,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',4,'AA1202',7.4,'hutongstore','j0hnnybb','johnnyb@marcallabs.co.uk','John Baldanza','The Lodge<br>Manor Farm','Sturt Green','Berkshire','UNITED KINGDOM','SL6 2JF','07973839339','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 11:35:39',0,NULL,3,1,2,1,NULL,NULL),(20703,761710966001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',2,'AD1184',67.98,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 13:03:08',0,NULL,3,1,17,0,NULL,NULL),(20704,761710335001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 13:03:07',0,NULL,3,1,17,0,' ',NULL),(20705,804767740002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-01 13:03:09',0,NULL,3,1,12,1,'2770968594\r ',' 3m 横杆（通用4节）      2\r背景架2mx 2m        1\r背景布 1.6 白色          1 \r灯架  2m                     6\r柔光箱 50-70cm 单灯头   6  欧标\r115w 5500k 灯泡  220v     6\r灯架包       3\r贴made in china  \r申报实值lighting kit  $509\r包好算一下   看发DHL可以吗  \r实重16.9  泡重 21到23\r\r'),(20706,881977510016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','bouffon2010charles','alineyve@hotmail.com','Charles Beaulieu','7340 IMPASSE ST-ZOTIQUE<br>APT 104','MONTREAL (ANJOU)','QC','CANADA','H1M3V4','(514) 351-8550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 13:39:14',0,NULL,3,1,2,1,NULL,NULL),(20707,765549427018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','samurai19817','jep_paulo@yahoo.com','Jefferson Paulo','6 Olive Road','Lynbrook','Victoria','AUSTRALIA','3975','61397029672','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-01 13:41:16',0,NULL,3,1,3,1,'RA117769308CN ',NULL),(20708,804790409002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','txorrota','txesar@gmail.com','zesar cebrian mayayo','ezkaba 2 1c','berriozar','Navarra','SPAIN','31013','635 64 61 48','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 13:50:43',0,NULL,3,1,2,1,NULL,NULL),(20709,761744998001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','dmitriy70','mr.trusov@gmail.com','Trusov Dmitriy','Volfson<br>19/5','Afula','Ameq Israel','ISRAEL','18268','0507576335','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 14:22:25',0,NULL,3,1,3,1,'RA117769197CN ',NULL),(20710,900436824015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','peternikon','peepboon@hotmail.com','Peter Hong','049.4 Severn Point<br>13 Llys Y Gored Ddu','Cardiff','Cardiff','UNITED KINGDOM','cf10 3ex','07429050167','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 15:25:23',0,NULL,3,1,3,1,'RA117769183CN ',NULL),(20711,804846208002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','5436meimem','eddiemat15@hotmail.co.uk','Eddie Martin','15 Park Road ','Broxburn','West Lothian','UNITED KINGDOM','EH52 5RF','01506852457','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 16:12:12',0,NULL,3,1,2,1,NULL,NULL),(20712,895628743015,250599969315,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',77.99,'hutongstore','sivanovai','sivanovai@abv.bg','Ivan Ivanov','Graf Ignatiev Str.36,Entr.0, Apt.5','Stara Zagora','','BULGARIA','6000','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-01 16:45:36',0,NULL,3,1,5,1,'CP240335095CN ','115w 5500k 灯泡  220v   1\r45w 220v 灯泡      4\r灯架  2m    2\r双灯头    欧标    2\r反光伞    2\r灯架包     1\r已入库   '),(20713,804871444002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','aleksicvalja','valya-z@mail.ru','Aleksic Andrija','Veljka Vlahovica 4/4 stan br.2','Budva','Montenegro','MONTENEGRO','85310','(382)67-314-054','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 17:06:56',0,NULL,3,1,2,1,' ','\r'),(20714,761826002001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','josiasfreitasjr','freitasfotos@gmail.com','josias Freitas junior','SRES Quadra 5 Bloco B Casa 51<br>Cruzeiro Velho','Brasília','Distrito Federal - DF','BRAZIL','70.640-027','55 61 9925-3766','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 17:35:26',0,NULL,3,1,3,1,'RA117769118CN ',NULL),(20715,761819722001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','callatya','abbey@liveingeorge.com','Abbey Wilkins','116 Farnham Road','Quakers Hill','New South Wales','AUSTRALIA','2763','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 17:27:05',0,NULL,3,1,2,1,NULL,NULL),(20716,900450332015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',18,'hutongstore','monaghanproductions','admin@monaghan-productions.com','James Monaghan','15 Barnfield rd east<br>Davenport','Stockport','Greater Manchester','UNITED KINGDOM','SK3 8TT','01612922156','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 17:50:43',0,NULL,3,1,3,1,'RA117769121CN ','英标 '),(20717,761868427001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','cdr2006','krspos@gmail.com','Luigi Crespo','3606 Hope Commons Ct','Frederick','MD','UNITED STATES','21704-7819','(202) 904-1325','NoPaymentFailure','CheckoutComplete','Other','2011-12-01 18:56:49',0,NULL,3,0,1,1,NULL,'3XL 已入库 '),(20718,900592951015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','roxeth_hilton','kevin_a_mills@hotmail.com','Kevin Mills','Moldavia<br>76 Amersham Rd','Little Chalfont','Buckinghamshire','UNITED KINGDOM','HP6 6SL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-01 19:49:18',0,NULL,3,1,4,1,'YW867661492CN ',' 黑加白\r▲'),(20719,761926480001,110414475072,'16chan Wireless Remote Control Set for OLYMPUS RM-UC1',1,'AA3206',18.5,'hermeshine','1492galeon','galeonesperdidos@orange.es','Jose Luis Brea Herrera','C/. Bariloche, 5. 3º C','Madrid','Madrid','SPAIN','28042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 20:36:59',0,NULL,3,1,2,1,NULL,'  电话\r00 34 617 077 657'),(20720,882228993016,260660051230,'Hot Shoe Cap Cover for SONY a900 a700 a350 FA-SHC1AM /B',1,'AA1205',1.5,'hutongstore','32190dariusd','loreta.gargzdai@gmail.com','loreta damuliene','dariaus gireno<br>33-26','gargzdai','klaipedos rajonas','LITHUANIA','96127','861616196','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 20:37:26',0,NULL,3,1,2,1,NULL,NULL),(20721,805002436002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',70,'hermeshine','kalfiskal','basurrea@gmail.com','Sacha Finsterbusch','Regina Pacis 750 depto 506<br>Ñuñoa','Santiago','Metropolitana','CHILE','7770066','(562)4757537','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-01 20:52:10',0,NULL,3,1,3,1,'RA117769152CN ',' 4个'),(20722,900657584015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','jan.henry.hansen','jan.henry.hansen@skien.online.no','Jan Henry Hansen','Follauglia 8','Skien','Telemark','NORWAY','3746','+47 95837323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-01 20:59:30',0,NULL,3,1,2,1,NULL,NULL),(20723,805011172002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','gacho_lv','gatis.strazdins@inbox.lv','Gatis Strazdiņš','Mālpils iela 2A - 33','Rīga','','LATVIA','1013','37129401732','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 21:08:48',0,NULL,3,1,3,1,'RA117769149CN ',NULL),(20724,761948829001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','hurukuru','mike@minpost.nu','Mike Toivonen','Kälvestavägen 43','Vällingby','','SWEDEN','16272','+46 70 5550105','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 21:10:58',0,NULL,3,1,3,1,'RA117769210CN ',' 4节'),(20725,900669646015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','sjlawrence123','sjl123@talktalk.net','Sarah Lawrence','Sycamore House<br>off Forge Ind. Est., North Roskear','Camborne','Cornwall','UNITED KINGDOM','TR14 0AP','01209719007','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 21:13:53',0,NULL,3,1,3,1,'RA117769237CN ',NULL),(20726,805049380002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','alex83ch','alex83-ch@mail.ru','Alexey Chernyukh','Botanicheskaya Str. 19A, ap. 79','Moscow','Moscow region','RUSSIAN FEDERATION','127427','+79262149184','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 22:18:17',0,NULL,3,1,3,1,'RA117769223CN ',NULL),(20727,761985320001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',84.96,'hermeshine','talgr','tal.grabiner@intel.com','Tal  Grabiner','27 Miryam Hahashmonait st.','Modiin','Israel','ISRAEL','71724','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 22:21:34',0,NULL,5,0,18,0,NULL,NULL),(20728,761988742001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','yyug','yyug@hotmail.com','Hugues Nabais Goncalves','12 rue de Locarno','Massy','Île-de-France','FRANCE','91300','0662202616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 22:29:52',0,NULL,3,1,2,1,NULL,NULL),(20729,761993759001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','petrick67','dipetri@bk.ru','Dmitry Petrichenko','Lat Strelkov d29, k20','Kazan','Tatarstan','RUSSIAN FEDERATION','420087','(+7)-917-2260997','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 22:38:47',0,NULL,3,1,2,1,NULL,NULL),(20730,762008088001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',2,'AE2201',75.96,'hermeshine','jcwanderico2011','jcwanderico@terra.com.br','joao carlos wanderico','fernando camargo, 895 cj 92','Americana','São Paulo','BRAZIL','13465020','19 34074936','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-01 23:17:18',0,NULL,3,1,5,1,'CP240335100CN ',' 欧标'),(20731,900715145015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','ninovendoecompro','antoninogiacobbo@gmail.com','antonino giacobbo','60, Bayston Road - Stoke Newington','London','London','UNITED KINGDOM','n167lt','078 18602254','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-01 23:49:44',0,NULL,3,1,3,1,'RA117769135CN ',' 4个'),(20732,900778572015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','rapp5398','ratchett@live.co.uk','Solaglas- Ray Appleyard','12 Rotterdam Road<br>Sutton Fields Ind. Est.','HULL','East Riding Of Yorkshire','UNITED KINGDOM','HU7 0XD','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-02 00:38:11',0,NULL,3,1,4,1,'YW867661503CN ',' 黑加白'),(20733,805116195002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-02 01:24:43',0,NULL,3,1,3,1,'RA117769245CN ','申报 gift    $39'),(20734,765872864018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',29.99,'photographyacc','duncandojroberts','duncan@northandsouth.com.au','Duncan Roberts','7/16 Leichardt Street<br>Glebe','Sydney','New South Wales','AUSTRALIA','2037','02 95184000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-02 00:57:47',0,NULL,3,1,3,1,'RA117769254CN ',NULL),(20735,8881322794758603,111,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',5.39,'aliexpress','1005547574','serg8899@gmail.com','sergey kalabun','Bryanceva 22 kv 28','Saint Petersburg	','Russia','RUSSIAN FEDERATION','195297','+7 911 1902923',NULL,NULL,NULL,'2011-12-02 02:59:18',0,NULL,7,0,18,0,NULL,' '),(20736,8881322798091307,111,'闪光灯套装',1,'',0,'hermeshine','fylhtq1984','borusenfinam@ya.ru','Андрей Пасюгин','ул. Гагарина д.4 кв.12','Магадан, Магаданская обл. ','','RUSSIA','685000','',NULL,NULL,NULL,'2011-12-02 03:54:51',0,NULL,3,0,6,1,'EX006379017SG\r ','2m 灯架   3\r力飞200w 闪光灯    3  转欧标\r50-70 通用卡口柔光箱  塑料    2\r反光伞   1\r柔光伞   1\r蜂窝       1\r红边包     1\r已入库\rАндрей Пасюгин\rул. Гагарина д.4 кв.12\rМагадан, Магаданская обл. 685000\rRUSSIA \r8 (4132)626007, 8 (4132)607521, +79512937023'),(20737,762090881001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','sptopher','christoph.spragg@gmail.com','Christoph Spragg','3 The Barbette','Castlecrag','New South Wales','AUSTRALIA','2068','6104316911','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-02 04:05:14',0,NULL,3,1,2,1,NULL,NULL),(20738,882448469016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','aron4410','him128@hotmail.com','Sami Koskimaa','Riihitie 10 A 8','Helsinki','','FINLAND','00330','+358408179205','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 04:40:23',0,NULL,3,1,4,1,'YW867661256CN ',' 欧标\r▲'),(20739,762103282001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','brianr8336','bdr9999@hotmail.com','Brian Ringuette','26749 Pawnee Ct','Flat Rock','MI','UNITED STATES','48134-2805','(734) 789-7509','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-02 04:57:10',0,NULL,3,1,1,1,NULL,NULL),(20740,765945126018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','court_10_nee','court_10_nee@hotmail.com','Courteney Brant','31 Neumann Rod','Capalaba','Queensland','AUSTRALIA','4157','0739064262','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-02 05:13:56',0,NULL,3,1,4,1,'YW867661234CN ','▲ '),(20741,882462072016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','tomislavprtenjaca10','tomislavprtenjaca@yahoo.com.au','tomislav','24 beechtree way','CRANBOURNE NORTH','Victoria','AUSTRALIA','3977','0359958735','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 05:32:34',0,NULL,3,1,4,1,'YW867661245CN ','▲ '),(20742,805188789002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','at0m-zlo','vmeste-s-vami@mail.ru','Artem Chepikov','Amurskiy bulvar<br>18-67','Khabarovsk','Khabarovskiy kray','RUSSIAN FEDERATION','680000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 05:42:35',0,NULL,3,1,5,1,'CP240320825CN ',' 欧标'),(20743,765959729018,280774575807,'Light Stand 80cm / 32\" for back light studio',2,'AE3501',46,'photographyacc','mcrokkor','gw4@bigpond.com','George  Sutton','16 Lower View Road','Montrose','Victoria','AUSTRALIA','3765','0439300312','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-02 06:23:58',0,NULL,3,1,3,1,'RA117769648CN\r ',NULL),(20744,805218426002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','wsun3575','sundud1981@yahoo.com','Wei Sun','16 Clara St Macleod VIC 3085','Macleod','Victoria','AUSTRALIA','3085','0394328461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 08:14:10',0,NULL,3,1,3,1,'RA117769651CN\r ',NULL),(20745,900922811015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','7578getcracking','porridge@tiscali.it','ALBERTO ODORIFERO','VIA CAMPAGNOLA N.30','BERGAMO','BG','ITALY','24126','3491304356','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 08:21:31',0,NULL,3,1,2,1,NULL,NULL),(20746,805237266002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','maoriboy.nz','rgcampbell.nz@gmail.com','Ross Campbell','Smales Farm, Telstraclear Building, Taharoto and Northcote Rd<br>Takapuna','Auckland','','NEW ZEALAND','0622','64299125740','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 09:31:42',0,NULL,3,1,3,1,'RA184556257CN\r ',NULL),(20747,805241041002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','ok7890','olga.kambas@student.uts.edu.au','Olga Kambas','23 Weston Rd','Hurstville','New South Wales','AUSTRALIA','2220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 09:45:33',0,NULL,3,1,2,1,NULL,' '),(20748,805235314002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',405,'hermeshine','souzanka4875','souzanka@hotmail.com','Souzan Mazloum','Chemin du Chalet de Pra Roman 6','LAUSANNE 26','','SWITZERLAND','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 10:31:57',0,NULL,3,1,6,1,'EA061773905HK\r\rEA061773905HK','C以外再一起发： \r灯架  2m   1\r5灯头+60-90棚     1   欧标\r45w 5500k 灯泡 220v    10\r申报 $125\r实重11.1 泡重16.79\r走递四方香港ems '),(20749,882552252016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','tilterje','tilterje@online.no','Terje Rensvold','severin kjers vei 2b','tonsberg','tonsberg','NORWAY','3117','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-02 10:47:44',0,NULL,3,1,5,1,'CP240320737CN ',' 欧标'),(20750,762182520001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',39.8,'hermeshine','eizojet','eizojet@yahoo.co.jp','Eizo Nakashima','naka1-41-30<br>hakataku','fukuoka city','Fukuoka','JAPAN','812-0893','+81-92-472-7909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 10:56:36',0,NULL,8,1,17,0,NULL,NULL),(20751,805261844002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','eizojet','eizojet@yahoo.co.jp','Eizo Nakashima','naka1-41-30<br>hakataku','fukuoka city','Fukuoka','JAPAN','812-0893','+81-92-472-7909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 10:56:37',0,NULL,8,1,17,0,NULL,NULL),(20752,805261847002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','eizojet','eizojet@yahoo.co.jp','Eizo Nakashima','naka1-41-30<br>hakataku','fukuoka city','Fukuoka','JAPAN','812-0893','+81-92-472-7909','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 10:56:38',0,NULL,3,1,6,1,'EE495359517CN ',' 牛津布大包    2\r伞式柔光箱 80cm 8角    2\r伞式柔光箱 60×90cm    2\r2.818'),(20753,805263882002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','ravivstein','mike1111114@walla.com','Raviv Stein','Haalon<br>mailbox 121','Ramat-Yishay','Emek-Izrael','ISRAEL','30095','(972) 523822235','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 11:04:14',0,NULL,3,1,3,1,'RA117767681CN ',NULL),(20754,805264841002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','corydoras74','a.niari@libero.it','Claudia Di Vilio','Tago 16 f','Fiumicino','RM','ITALY','00054','3479272980','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 11:07:54',0,NULL,3,1,2,1,NULL,NULL),(20755,900996708015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','kaspersa85','kaspersa@gmail.com','Kasper Andersen','Thomas B Thrigesgade 89<br>2. th','Odense C','','DENMARK','5000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 11:51:12',0,NULL,3,1,3,1,'RA184556169CN\r ',NULL),(20756,766055143018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','irenevithoulkas','irene_vithoulkas95@hotmail.com','irene Vithoulkas','defontenay road <br>barmera','barmera','South Australia','AUSTRALIA','5345','0439954585','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-12-02 12:27:48',0,NULL,3,1,4,1,'YW867661326CN ','新地址:\r\rIrene Vithoulkas\rStreet number 1 Lake Avenue Barmera \rSouth Australia  5345\rAustralia\r0439954585 \r\r'),(20757,762220771001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','lxxjxxx','lucybluzcafe@digisurf.com.au','Jian Liu','113 Crown St','Flemington','Victoria','AUSTRALIA','3031','0393768041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 13:03:00',0,NULL,3,1,2,1,NULL,NULL),(20758,762224409001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','courtesylioness','fionacyeo@gmail.com','Fiona Chia','940, Hougang Street 92, #02-19. Singapore 530940.','default','','SINGAPORE','530940','(+65) 96545604','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 13:15:27',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20759,901041412015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','starozi','info@d-gnet.com','GEORGIADIS DIMITRIOS P.','RODOPOLI SERRON','RODOPOLI SERRON','RODOPOLI SERRON','GREECE','62053','+302327023301','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 13:35:52',0,NULL,3,1,3,1,'RA184556172CN ',NULL),(20760,901044172015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','apostoli2pavel','simo.peltola@kotikone.fi ','Simo Peltola','Rantapolku 1.','Orivesi','Finland','FINLAND','35300','0505921175','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 13:40:54',0,NULL,3,1,3,1,'RA184556212CN\r',''),(20761,882659290016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','titano84','sqall84@alice.it','Angelo Cosentino','Piazza Vittorio Veneto, 3','Giustenice','SV','ITALY','17020','3287312103','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 14:55:40',0,NULL,3,1,2,1,NULL,NULL),(20762,805373244002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','jineiry','rmyim246@hotmail.com','Rebecca Muñiz','CALLE MUNOZ RIVERA<br>NUM 933','Penuelas','PR','PUERTO RICO','00624','787-215-6595','NoPaymentFailure','CheckoutComplete','Other','2011-12-02 16:02:19',0,NULL,3,1,3,1,'RA184556226CN\r ',NULL),(20763,805388849002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tut095806','nehal_bd@hotmail.com','Ifte Hasan','Tsurumi east river 502<br>4-43-10 Tsurumi chuo, Tsurumi ku','Yokohama','Kanagawa','JAPAN','230-0051','+8190-3565-1477','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 16:34:44',0,NULL,3,1,2,1,NULL,NULL),(20764,762346180001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','bnbsellingtime','mountaingoatz@hotmail.com','Robert Sizemore','114 Richmond St','Excelsior Springs','MO','UNITED STATES','64024-2576','(816) 984-3134','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-02 18:02:37',0,NULL,3,1,1,1,NULL,NULL),(20765,901189826015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',49.98,'hutongstore','jakkep81','0407457673@netti.fi','jarkko patana','kanavantie 4 b 13','viiala','','FINLAND','37830','+358407457673','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-02 18:04:13',0,NULL,3,1,4,1,'YW867661444CN','▲'),(20766,805436200002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','danielhash','daniel.hash@gmail.com','Daniel Hashai','Antverpen<br>22','Netanya','Israel','ISRAEL','42221','098613405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 18:08:16',0,NULL,3,1,17,0,NULL,NULL),(20767,824103042017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','ceckand','snipers810@gmail.com','Andrea Cecchini','Via Spinelli 2','Morciano di Romagna','RN','ITALY','47833','+393387664236','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 18:16:52',0,NULL,3,1,2,1,NULL,NULL),(20768,766222764018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','isa79n','neroni@cspaysbleuets.qc.ca','isabelle néron','1279 LW Leclerc','St-Félicien','QC','CANADA','G8K 2N4','(418) 275-4585 ext.: 2442','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 18:43:31',0,NULL,3,0,3,1,'RA184556230CN\r ','灰色和棕色'),(20769,762376469001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','alderique','alderique@hotmail.com','Gilles Fillion','20 rue du boise','St Ferreol les Neiges','QC','CANADA','G0A3R0','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-02 19:00:09',0,NULL,3,0,3,1,'RA184556243CN\r ','XL 已入库'),(20770,762408379001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','dima_kovalevskiy','dkov@mail.ru','Dmitriy Kovalevskiy','Istomina 29-1a','Sevastopol','Krymea','UKRAINE','99012','(068)468-1444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 20:01:21',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20771,805511293002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','420yeyo','4_e_bay@hotmail.ca','Muizz Jamil','20 sewells road, apt-103','toronto','ON','CANADA','M1B3G5','(416) 722-5337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 20:22:29',0,NULL,3,1,3,1,'RA184556288CN\r ',NULL),(20772,901301070015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',65,'hutongstore','cafurnlauren','lauren_eeyore@hotmail.co.uk','lauren mullan','42 earhart park','derry','Londonderry','UNITED KINGDOM','BT48 8FN','02871356164','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-02 20:44:00',0,NULL,3,1,4,1,'YW867661470CN ','英标\r▲'),(20773,805563788002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','stekkerfreak','ccvanduren@gmail.com','C.J.A. van Duren','Achterweg 21','Haarlem','','NETHERLANDS','2023 VE','0235262255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 21:52:15',0,NULL,3,1,17,0,NULL,NULL),(20774,805563790002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','stekkerfreak','ccvanduren@gmail.com','C.J.A. van Duren','Achterweg 21','Haarlem','','NETHERLANDS','2023 VE','0235262255','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 21:52:15',0,NULL,3,1,17,0,NULL,NULL),(20775,762469659001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','stekkerfreak','ccvanduren@gmail.com','C.J.A. van Duren','Achterweg 21','Haarlem','','NETHERLANDS','2023 VE','0235262255','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-02 21:52:16',0,NULL,3,1,3,1,'RA184556138CN ',' 柔光伞     1\r闪光灯B座    1\r伟峰 717 快装板    1'),(20776,805574787002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','wsun3575','sundud1981@yahoo.com','Wei Sun','16 Clara St Macleod VIC 3085','Macleod','Victoria','AUSTRALIA','3085','0394328461','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 22:15:17',0,NULL,3,1,3,1,'RA184556141CN',NULL),(20777,805592384002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ataylor05','apriltaylor79@yahoo.com','April Taylor','10605 73AVE','Grande Prairie','AB','CANADA','T8W 2S4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-02 23:05:02',0,NULL,3,1,2,1,NULL,NULL),(20778,805602462002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','3boysinthhouse','onlygirlinhouse@cableone.net','Geri Kinsley','1816 Fox Rd<br>null','Chino Valley','AZ','UNITED STATES','86323-7073','','NoPaymentFailure','CheckoutComplete','Other','2011-12-02 23:40:44',0,NULL,3,0,1,1,NULL,'L   (已入库)'),(20779,762518899001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','krabikabi','henry@ilusilm.ee','Henry Timusk','Oa 11a-5','Tartu','','ESTONIA','51008','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-02 23:54:52',0,NULL,3,1,3,1,'RA184556107CN',NULL),(20780,766385463018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','ciberkiyo-bis','quillo3000@gmail.com','jose manuel dominguez fernandez','C/ Cupreso, 43 - Edif. Selene PB7','Santa Ursula','Canarias','SPAIN','38390','649413643','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-02 23:59:41',0,NULL,3,1,2,1,NULL,NULL),(20781,805621464002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','duilingur','duidreki@hotmail.com','Eirikur Bryjnolfsson','Lagaras 20','Egilsstadir','None','ICELAND','700','47113876905475','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 00:13:36',0,NULL,3,1,5,1,'CP240320745CN ',NULL),(20782,805622442002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','sgag2538','stephanj.gagnon@sympatico.ca','Stéphan Gagnon','1630 rue des Ancolies','Québec','QC','CANADA','G1M 3X6','(418) 682-8715','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 00:16:28',0,NULL,3,1,2,1,NULL,NULL),(20783,762076783001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jillscsw','jillscsw@optonline.net','Jill Schieber','48 Birch Dr','Plainview','NY','UNITED STATES','11803','(516) 935-1561','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 01:25:15',0,NULL,3,0,1,1,NULL,NULL),(20784,805661486002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','poohbearkat77','k_panchuk@hotmail.com','Kathleen Caughey','349 Cranbrooke Avenue','Toronto','ON','CANADA','M5M1N2','(647) 341-5940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 02:25:13',0,NULL,3,1,2,1,NULL,NULL),(20785,762563688001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','kikikritter','the_kspot@hotmail.com','Alicia Cameron','Apt 5A<br>832 Armour Rd','Peterborough','ON','CANADA','K9H 2A2','(170) 553-1274 ext.: 8','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 02:34:40',0,NULL,3,1,5,1,'CP240320754CN',' 黑加白'),(20786,805666012002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',4.8,'hermeshine','shaun7794','saf57@iinet.net.au','Shaun Finch','P.O. Box 180','Bridgetown','Western Australia','AUSTRALIA','6255','0897614352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 02:40:10',0,NULL,3,1,2,1,NULL,NULL),(20787,762565666001,110750767778,'New Camera Case Shoulder Bag PU Leather for Canon 5D ii 7D 60D 40D Strong',1,'AD1201',55,'hermeshine','paperdaydream','allysongarcia@rocketmail.com','Allyson Garcia','641 Flora Dr','Oceanside','CA','UNITED STATES','92057-3629','(760) 433-9099','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 02:41:09',0,NULL,3,1,3,1,'RA184556155CN ',NULL),(20788,8881322880777300,111,'P4 碗罩',1,'AB3312',0,'photographyacc','gusandjenroberts','justin@jrobertsphotography.com.au','Justin Roberts','19 Connemara Ave<br>Killarney Heights','Sydney','New South Wales','AUSTRALIA','2087','',NULL,NULL,NULL,'2011-12-03 02:52:57',0,NULL,3,1,3,1,'RA184556067CN ','仔细确认是P4 '),(20789,8881322881274763,111,'斜臂上面的夹子',1,'',0,'photographyacc','ruske75','russkenn@internode.on.net','Russell Kennedy','c/o Wipro<br>Level 1, 19 Grenfell St','Adelaide','South Australia','AUSTRALIA','5000','0416030881',NULL,NULL,NULL,'2011-12-03 03:01:14',0,NULL,3,0,3,1,'RA184556305CN\r ',NULL),(20790,805706332002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','rogerparrain09','dgelab59@gmail.com','gerald labonte','189 st david','east angus','QC','CANADA','j0b1r0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 05:18:20',0,NULL,3,1,2,1,NULL,NULL),(20791,824390192017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','mmcm2009','mareece@spectrarealty.com.au','mareece mcmahon','92 Banks St','Alderley','Queensland','AUSTRALIA','4051','0437026980','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-03 05:29:44',0,NULL,3,1,4,1,'YW867661481CN ',' 澳标  \r▲'),(20792,883102729016,260880900498,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2106',25,'hutongstore','tevi51','terryvhowlett@hotmail.com','terry howlett','87 bass street warrane','hobart','Tasmania','AUSTRALIA','7018','0362441621','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 05:51:20',0,NULL,3,0,3,1,'RA184556075CN ','XL\rCanon 背心,标题错了,注意\r已入库\r\r'),(20793,805734979002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','gustavo_tas','gustavo_tasquer@yahoo.com.ar','Gustavo Tasquer','Av San Felipe #687 1104B,  Jesus Maria','Lima','Lima','PERU','Lima11','01-4618040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 07:44:07',0,NULL,3,1,17,0,NULL,NULL),(20794,762629218001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','gustavo_tas','gustavo_tasquer@yahoo.com.ar','Gustavo Tasquer','Av San Felipe #687 1104B,  Jesus Maria','Lima','Lima','PERU','Lima11','01-4618040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 07:44:08',0,NULL,3,1,17,0,NULL,NULL),(20795,805734980002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',2,'AA1315',5.98,'hermeshine','gustavo_tas','gustavo_tasquer@yahoo.com.ar','Gustavo Tasquer','Av San Felipe #687 1104B,  Jesus Maria','Lima','Lima','PERU','Lima11','01-4618040','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 07:44:08',0,NULL,3,1,3,1,'RA184556098CN ',' 伞式柔光箱 60×90cm    1\r反光板支架的夹子（双轮）   1\r机身盖/镜头后盖  Canon   2'),(20796,805724001002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','hro3510','hmrollo@optusnet.com.au','Heather Rollo','6 Trentino road, Turramurra','Sydney','New South Wales','AUSTRALIA','2074','0294025444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 07:45:23',0,NULL,3,1,3,1,'RA184556084CN',NULL),(20797,762656070001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','steverekun','ttplanet@gmail.com','Steve Rekun','Arlozorov 53/3','Petah Tikva','','ISRAEL','49453','0545894363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 09:20:23',0,NULL,3,1,3,1,'RA184587002CN\r',NULL),(20798,766526147018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39,'photographyacc','123ngari','ngariph@bigpond.net.au','ngari phillips','6 flinders terrace','mount gambier','South Australia','AUSTRALIA','5290','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 09:22:12',0,NULL,3,1,3,1,'RA184586917CN',NULL),(20799,762689647001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','edsaez73','edsaez@gmail.com','Edmundo Sáez Peña','C/Bailarina Anna Pavlova, 6 Esc. 3, 4º A','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 11:11:42',0,NULL,3,1,4,1,'YW867661455CN','▲ '),(20800,766557968018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','jasonseng1','jseng85@live.com.au','Jason  Seng','15 Bradman Street ','Moranbah','Queensland','AUSTRALIA','4744','0409186499','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 10:52:14',0,NULL,3,1,2,1,NULL,NULL),(20801,824496352017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','drclpatel2001','drclpatel@yahoo.com','Chandrakant Patel','3 Beagle Place','Carey Park','Western Australia','AUSTRALIA','6230','08466969076','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 11:44:29',0,NULL,3,1,17,0,NULL,NULL),(20802,824497102017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',130,'photographyacc','drclpatel2001','drclpatel@yahoo.com','Chandrakant Patel','3 Beagle Place','Carey Park','Western Australia','AUSTRALIA','6230','08466969076','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-03 11:45:56',0,NULL,3,1,4,1,'YW867661466CN ',' 白色背景布 1.6m  *3m 1\r手动升降背景架    1'),(20803,805810373002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','dirtfarming77','jj28th@gmail.com','Paul Clark','2751 E Beltline Ave SE','Grand Rapids','MI','UNITED STATES','49546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 11:56:13',0,NULL,3,1,17,0,NULL,NULL),(20804,805811324002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','dirtfarming77','jj28th@gmail.com','Paul Clark','2751 E Beltline Ave SE','Grand Rapids','MI','UNITED STATES','49546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-03 11:58:30',0,NULL,3,1,3,1,'RA117767704CN ',' 伞式柔光箱 60×90cm     2'),(20805,805819230002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','d_smit','danielsmith4213@gmail.com','Daniel Smith','26c Constellation Cres','Mudgeeraba','Queensland','AUSTRALIA','4213','0755227783','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 12:20:22',0,NULL,3,1,2,1,NULL,NULL),(20806,901676322015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','atmodrummer','atmodrummer@hotmail.com','Luis Soares','Estrada de Palmela nº231','Setúbal','Setúbal','PORTUGAL','2900-537','(00351) 913730607','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 12:42:59',0,NULL,3,1,3,1,'RA184556186CN ',NULL),(20807,805830361002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','sherp1a','tmoffatt@xplornet.com','Thomas F Moffatt','799 St. David Ridge Road','St. David Ridge','NB','CANADA','E3L 4S5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 12:52:39',0,NULL,3,1,2,1,NULL,NULL),(20808,805833158002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','danielhash','daniel.hash@gmail.com','Daniel Hashai','Antverpen<br>22','Netanya','Israel','ISRAEL','42221','098613405','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 12:59:00',0,NULL,3,1,3,1,'RA117767616CN ',' 伞式柔光箱 60×90cm    2'),(20809,762729022001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','2010jth','jay.t.hol@gmail.com','Jan Thore Hol','Baldersgate 1A','Horten','Vestfold','NORWAY','3182','(0047) 91913826','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 13:02:36',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20810,762791263001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','ennalotay2011','ennalotay@yahoo.com','anne flores','Blk 974, Jurong West St. 93<br>#03-421 Singapore','default','','SINGAPORE','640974','+65 83705632','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 15:30:23',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20811,805897201002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','stcharls','donal_hurley@eircom.net','Donal Hurley','4 Vartry Close<br>Raheen','Limerick','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 15:25:53',0,NULL,3,1,3,1,'RA184556190CN ',NULL),(20812,901814859015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',2,'AC1201',4.36,'hutongstore','hendycapel','peter@colbeck.eu','Peter M Colbeck','31 Chapel Street','Porthmadog','Gwynedd','UNITED KINGDOM','LL49 9DS','01766514657','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 16:45:12',0,NULL,3,1,2,1,NULL,NULL),(20813,901817802015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','angiemoonbeam','angie196112@hotmail.co.uk','Angie Cook','65 Oaklands','Bideford','Devon','UNITED KINGDOM','EX39 3HW','01237421322','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-03 16:49:56',0,NULL,3,1,4,1,'YW867661411CN','白加黑 \r▲'),(20814,901823504015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','1328_123','jaden@euroweb.net.mt','jesmond borg','block1,flat19,scheme3,paola hill','paola','','MALTA','1716','0035621806851','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-03 16:57:38',0,NULL,3,1,5,1,'CP240320768CN',NULL),(20815,901871322015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','7-larsson','zokscotland@gmail.com','CHRIS SIMPSON','3 BRIDGE PLACE,','BUCKIE','Aberdeenshire','UNITED KINGDOM','AB56 1XL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-03 18:02:47',0,NULL,3,1,4,1,'YW867661422CN ','白加黑 \r▲'),(20816,762883767001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','kimmoo123','k.oikarinen@kajaani.net','Kimmo Oikarinen','Kauppakatu 27 B16','Kajaani','','FINLAND','87100','+358400581071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 18:17:16',0,NULL,3,1,17,0,NULL,NULL),(20817,805996785002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','kimmoo123','k.oikarinen@kajaani.net','Kimmo Oikarinen','Kauppakatu 27 B16','Kajaani','','FINLAND','87100','+358400581071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 18:17:16',0,NULL,3,1,17,0,NULL,NULL),(20818,762883768001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','kimmoo123','k.oikarinen@kajaani.net','Kimmo Oikarinen','Kauppakatu 27 B16','Kajaani','','FINLAND','87100','+358400581071','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 18:17:17',0,NULL,3,1,3,1,'RA184556209CN ',' 反光板支架的夹子（双轮）    1\r斜臂    1\r1.6*2.1  黑色   1'),(20819,806035709002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 19:23:57',0,NULL,3,1,3,1,' RA184556115CN','申报 gift    $39'),(20820,883534025016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-03 19:59:21',0,NULL,3,1,3,1,'RA117767718CN ','申报 gift 低值'),(20821,902022889015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','lenbellemore','lbellemore@gmail.com','Len Bellemore','ControlCircle<br>Hertsmere House, 2 Hertsmere Road','London','London','UNITED KINGDOM','E14 4AB','7814036657','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-03 21:21:49',0,NULL,3,1,4,1,'YW867661282CN ','英标 \r▲'),(20822,762918068001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','tazzen86','trondstegarud@hotmail.com','Trond Stegarud','Villaveien 29b','RJUKAN','TELEMARK','NORWAY','3660','45222362','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 21:50:58',0,NULL,3,1,3,1,'RA184556124CN ',NULL),(20823,806130233002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','sagistious','leibmans@gmail.com','Sagi Leibman','Hanagid 4','Ramat Gan','','ISRAEL','52473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 22:03:13',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20824,806127352002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 22:04:07',0,NULL,3,1,17,0,NULL,' 欧标\r合并到下面'),(20825,766909225018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','gaspar1975','gasparmatheus@hotmail.com','MATHEUS GASPAR','AV. LUIZ TEIXEIRA MENDES, 1168, AP. 302, ZONA 04','MARINGÁ','PARANÁ','BRAZIL','87015000','(44) 99740039','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-03 22:07:20',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20826,766926282018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','maher7490','michaelmaherats@hotmail.com','michael maher','23 quinn street','emerald','Queensland','AUSTRALIA','4720','0749874929','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-03 22:41:21',0,NULL,3,1,2,1,NULL,NULL),(20827,902077850015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','ras190398','rassimpson@afc7.wanadoo.co.uk','Rodney Simpson','12 Bramblewood Park<br>Portadown','Co. Armagh','Northern Ireland','UNITED KINGDOM','BT623JG','02838351346','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-03 22:49:35',0,NULL,3,1,3,1,'RA184586925CN ',NULL),(20828,806153282002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',56.5,'hermeshine','wiizzzz','wizzzonline@hotmail.com','Faucon François','13 rue du Dr Lombard','ORCHAMPS','Franche-Comté','FRANCE','39700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-03 22:50:34',0,NULL,3,1,3,1,'RA184586934CN ',NULL),(20829,763045841001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','yannce6721','yannbazatte@yahoo.fr','Yann BAZATTE','3 rue olympe de gouges<br>Rés VIVALDI 2 Apt 106','TOULOUSE','Midi-Pyrénées','FRANCE','31200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-03 23:19:16',0,NULL,3,1,3,1,'RA184586948CN ',NULL),(20830,806174128002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','skyfor7','skyfor7@gmail.com','Shinsil Oh','6548 Montgomery Rd','Elkridge','MD','UNITED STATES','21075-5920','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-03 23:40:02',0,NULL,3,1,1,1,NULL,NULL),(20831,763063828001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 00:06:14',0,NULL,3,1,17,0,'、 ',NULL),(20832,763063829001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-04 00:06:14',0,NULL,3,1,3,1,'RA184586877CN',' 单灯头   1\r肩架   1\r欧标  '),(20833,8881322959410460,111,'58mm 接口环',1,'',0,'hutongstore','ffandy7293','becky.havery@googlemail.com','Andrew Havery','19 Southbourne Road','Lymington','Hampshire','UNITED KINGDOM','SO419JB','',NULL,NULL,NULL,'2011-12-04 00:43:30',0,NULL,3,1,2,1,NULL,NULL),(20834,8881322960520343,111,'摄影背心（河北，厚）canon XXL',1,'',0,'photographyacc','laserfreak0815','mystique2404@hotmail.de','Martin Aigner','Gartenstrasse 11','Grasbrunn','','GERMANY','85630','',NULL,NULL,NULL,'2011-12-04 01:02:00',0,NULL,3,0,3,1,'RA184586982CN                                                                                                                                                                                        ','一定确认是XXL\r上次发错了xl给客户 '),(20835,8881322960792362,111,'HB-7',1,'AA1216',0,'hermeshine','onurkaan32','gungor928@hotmail.com','GÖKHAN GÜNGÖR','Club Magic Life Belek İmperial Hotel<br>(Doctor Office) İlerıbası mevkıı  Belek-SERIK','ANTALYA','','TURKEY','07500','00905307879736',NULL,NULL,NULL,'2011-12-04 01:06:32',0,NULL,3,1,3,1,'RA184556359CN\r ',' GÖKHAN GÜNGÖR\rOrta mah. Serik cad. Nurlu apt. No:116/8 \rSerik-Antalya TURKEY  07500\r00905307879736'),(20836,883719011016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','esell-mall','amihoods@gmail.com','Amihood Segal','P.O.  Box  2146<br>(shamay   branch)','Jerusalem','','ISRAEL','91021','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-04 01:16:51',0,NULL,3,1,3,1,'RA184586979CN\r','申报  reflector   $30 '),(20837,763091296001,110502554980,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',2.6,'hermeshine','pierrer8081','dutytravelegs@hotmail.com','Pierre R. Legault','226 Waterford Rd','Ten Mile','TN','UNITED STATES','37880-2035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 01:33:12',0,NULL,3,1,1,1,NULL,NULL),(20838,763125523001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','hansensch','sch@stevenhansen.name','Steven Hansen','12 Greenmoor DR','Eagle Point','OR','UNITED STATES','97524','(541) 830-8606','NoPaymentFailure','CheckoutComplete','Other','2011-12-04 03:28:38',0,NULL,3,1,1,1,NULL,'M 已入库 '),(20839,806273155002,120448751908,'Remote Shutter Release Cord for Nikon D70s D80 = MC-DC1',2,'AA3208',7.96,'hermeshine','mygenweb','au3238@gmail.com','Tanawut Chomputsa','55 MOO 8<br>Tambon Rangkayai','Phimai','Nakhon Ratchasima','THAILAND','30110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 04:40:55',0,NULL,3,1,2,1,NULL,NULL),(20840,883803603016,260894474713,'New Studio Light 800W Continuous Lighting Complete Kit with background support',1,'AKT087',102,'hutongstore','kbzon59','nhage@mailcity.com','Nelson R. Hage','Salinas Leal y Reforma 1490<br>Colonia Guerrero','La Paz','BCS','MEXICO','23040','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 05:21:57',0,NULL,5,1,18,0,NULL,NULL),(20841,763178936001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','nathaninkingston','nathanaprince@gmail.com','Nathan Prince','752 Mona Dr','Kingston','ON','CANADA','k7m5c2','(613) 888-6444','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 07:32:27',0,NULL,3,1,2,1,NULL,NULL),(20842,763198563001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',59.98,'hermeshine','lemans1969-70','lemans-1969@hotmail.com','Graham Lawler','c/- Foxtel Cable TV<br>1-21 Dean Street, Moonee Ponds','Melbourne','Victoria','AUSTRALIA','3039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:46:49',0,NULL,8,1,17,0,NULL,NULL),(20843,763200515001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','samantha_g89','boo_900@hotmail.com','Rebecca Coady','48/59a Castle Street','Castle Hill Sydney','New South Wales','AUSTRALIA','2154','0288504518','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 08:52:39',0,NULL,3,1,2,1,NULL,NULL),(20844,902348283015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',75.78,'hutongstore','horserising','jrebenok@gmail.com','Sergey Ivanov','Zelenograd, korp.1209, kv.115','Moscow','Moscow, Zelenograd','RUSSIAN FEDERATION','124460','8(926)417-77-77','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 10:41:02',0,NULL,3,1,5,1,'CP240320771CN ',' 澳转欧标'),(20845,763276336001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','lemans1969-70','lemans-1969@hotmail.com','Graham Lawler','167 Holmes Road','Moonee Ponds','Victoria','AUSTRALIA','3039','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-04 11:48:58',0,NULL,3,1,4,1,'YW867661396CN','2m 灯架    2\r3m 横杆 （4节）  1\r灯架包   1\r夹子   3                  ▲\r反光板支架   2 '),(20846,767196511018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','gwmalan','gmalan@gmconsult.com.au','Gerhard Malan','PO Box 820','Newport Beach','New South Wales','AUSTRALIA','2106','0299860438','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-04 12:09:02',0,NULL,3,1,2,1,NULL,NULL),(20847,763315925001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','betnev','ilbetnev@mail.ru','Ilya Betnev','Chervonnaya 19-216','Yekaterinburg','','RUSSIAN FEDERATION','620134','+7(912)628-0028','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 13:00:27',0,NULL,3,1,3,1,'RA184586996CN ',NULL),(20848,902451979015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','wellfit88','muvage@gmx.de','Andre Irbach','Eibenweg 12a','Neufinsing','','GERMANY','85464','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 13:32:52',0,NULL,3,1,17,0,NULL,NULL),(20849,902451628015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',40,'hutongstore','wellfit88','muvage@gmx.de','Andre Irbach','Eibenweg 12a','Neufinsing','','GERMANY','85464','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 13:34:27',0,NULL,3,1,4,1,'YW867661400CN ','伞式柔光箱 60×90cm     2\r伞式柔光箱 80cm 8角      2\r▲\r '),(20850,899393287015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','lilieth2450','liliethbrown@hotmail.co.uk','Mr Brown','29 Alabama Street','Plumstead','London','UNITED KINGDOM','SE18 2SH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 15:00:20',0,NULL,3,1,2,1,NULL,NULL),(20851,806537829002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','sowah01234','sowah21@gmail.com','SOWAH SACKEY','242 alexander ST','newark','NJ','UNITED STATES','07106-2620','(973) 286-9865','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 15:26:11',0,NULL,3,1,3,1,'RA184556053CN ',NULL),(20852,884124196016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','roasttoe','roasttoe@hotmail.com','Paul Green','Drennan (International) Ltd.<br>Bocardo Court, Temple Road,','Cowley, Oxford','Oxfordshire','UNITED KINGDOM','OX4 2EX','07979218520','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-04 15:35:02',0,NULL,3,1,4,1,'YW867661293CN ','▲ '),(20853,806556602002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','kadett1079','kadettk@msn.com','José Antonio Sousa Neto','Rua Urbano Eulalio Filho, 1079','Picos','Piauí','BRAZIL','64.600-000','55 89 9921 6519','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 15:54:42',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20854,806558745002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','galtamirgal','tamirgal@gmail.com','Tamir Gal','37 Zafririm st.','Nofit','','ISRAEL','36001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 15:55:45',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20855,763435740001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',2,'AD1184',67.98,'hermeshine','jimwalms','jimwalms@arkansas.net','James Walmsley','PO Box 393<br>204 Biffle Rd','Newbern','TN','UNITED STATES','38059','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-04 16:10:53',0,NULL,3,1,3,1,'RA184586965CN ',' 两个 '),(20856,763440837001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','deb180875','deb180875@hotmail.com','Debadatta Tripathi','39 Buckland St<br>Apt 8123','Manchester','CT','UNITED STATES','06042-7714','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-04 16:17:16',0,NULL,3,1,1,1,NULL,NULL),(20857,763451660001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','shinee1978','mel902@gmx.de','Tanja Moarefi','Josef-Rutz-Str. 1','Mannheim','','GERMANY','68307','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 16:30:55',0,NULL,3,1,2,1,NULL,NULL),(20858,902612965015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','scrunchie_2000','rachel_forster_uk@yahoo.co.uk','Rachel Forster','52 Lexton Drive<br>Churchtown','Southport','Merseyside','UNITED KINGDOM','PR9  8QW','07971117025','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 16:35:00',0,NULL,3,1,3,1,'RA184556022CN ',NULL),(20859,767376886018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','jrosales1984','jcrch84@hotmail.com','Julio Rosales','Calle Estrada Casa#307<br>De la casa de Sor Maria 75 mts al este','Granada','Granada','NICARAGUA','505','+50586047201','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-04 16:41:55',0,NULL,3,1,3,1,'RA184556019CN ',NULL),(20860,902632878015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','wakeford93','danni.elle.x@hotmail.co.uk','Danielle Wakeford','15 Clover Way<br>Hunters Chase','Paddock Wood','Kent','UNITED KINGDOM','TN12 6BQ','01892832998','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-04 16:51:27',0,NULL,3,1,4,1,'YW867661304CN ','黑加白 \r▲'),(20861,806730072002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','solerpower','solercop@yahoo.com','james soler','267 windham rd','brooklyn','CT','UNITED STATES','06234','(860) 933-0133','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-04 18:47:06',0,NULL,3,1,1,1,NULL,NULL),(20862,902884317015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','lynniek0','lynnkowbas@yahoo.co.uk','phil kowbas','8 jones close','march','Cambridgeshire','UNITED KINGDOM','PE159RZ','01354651976','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-04 19:51:01',0,NULL,3,1,4,1,'YW867661374CN ','黑加白 \r▲'),(20863,763675917001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','mike211282','michael_scraseuk@yahoo.co.uk','Mr Michael Scrase','20 April Close','Horsham','West Sussex','UNITED KINGDOM','rh122ln','07875733160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 19:55:48',0,NULL,3,1,2,1,NULL,NULL),(20864,763712898001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','eldarkra','eldarkra@gmail.com','Eldar Kravetsky','Ha-Rakefet<br>15A / 5','Bney Aish','','ISRAEL','60860','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 20:28:22',0,NULL,3,1,11,1,' ','不挂号  \r▲'),(20865,884504620016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:42',0,NULL,8,1,17,0,NULL,NULL),(20866,902940861015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:41',0,NULL,8,1,17,0,NULL,NULL),(20867,902937805015,250692237054,'Green.L 77mm 77 Neutral Density ND4 Filter ND 4 New',1,'AE2307',4.55,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:44',0,NULL,8,1,17,0,NULL,NULL),(20868,884505479016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:42',0,NULL,8,1,17,0,NULL,NULL),(20869,884470429016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:41',0,NULL,8,1,17,0,NULL,NULL),(20870,902938531015,250845608545,'TianYa 77mm ND8 filter New 77 Neutral Density Grey NIB',1,'AA2314',5.28,'hutongstore','antonyfurneaux','my.ebay@haytor.net','Antony Furneaux','21 Oleander Drive<br>Totton','Southampton','Hampshire','UNITED KINGDOM','SO40 8XX','07701410649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 20:31:43',0,NULL,3,1,4,1,'YW867738525CN ','机身盖/镜头后盖  Canon    1\r圆形柔光棚 50cm   1\r绿叶 ND4  77mm     1\rCANON 镜头盖  77mm   1\r2mx1.5m 背景板（黑，白）     1\r天涯 ND8 77mm   换成绿叶的    1\r▲\r\r '),(20871,902987528015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','g_micra','moddedmicra@hotmail.com','Graeme Evans','12 Timothy Hackworth Drive','Darlington','Durham','UNITED KINGDOM','DL22GN','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-04 21:10:42',0,NULL,3,1,4,1,'YW867661385CN ','黑加白 \r▲'),(20872,902987428015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','iwens.123','wiegerwijnia@xs4all.nl','Wieger wijnia','staartmees<br>12','emmen','','NETHERLANDS','7827ce','06-30610114','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 21:12:08',0,NULL,3,1,3,1,'RA184586863CN ',NULL),(20873,806905215002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','chang0603','changsusong@yahoo.com','chang song','26952 calle esperanza','san juan capistrano','CA','UNITED STATES','92675-4916','(949) 496-6468','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-04 21:22:29',0,NULL,3,1,1,1,NULL,NULL),(20874,767731637018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','lucagio1980','luca@lg.id.au','Luca Giovannetti','PO BOX 4','Ringwood','Victoria','AUSTRALIA','3134','0417411622','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-04 22:11:26',0,NULL,3,1,2,1,NULL,NULL),(20875,903042316015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','bagaak44','maikenstaak@gmail.com','Maiken Staak','Kungla 20-7','Tallinn','default9','ESTONIA','10411','0055652475','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-04 22:11:51',0,NULL,3,1,11,1,' ','不挂号 \r▲'),(20876,763819654001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','jmarterogijon','jmartero@mailcity.com','Maria José Artero Fernández','c/Costa del Azahar, 4<br>Urbanización La Alcayna','Molina de Segura','Murcia','SPAIN','30507','968819035','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-04 22:45:07',0,NULL,3,1,3,1,'RA184586951CN ','4节 '),(20877,903105130015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','swordio777','swordio777-ebay@yahoo.co.uk','I Sword','67 Skibo Court','Dunfermline','Fife','UNITED KINGDOM','KY12 7EW','07737086302','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-04 23:31:19',0,NULL,3,1,3,1,'RA184556040CN ',NULL),(20878,763858032001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','blackpool_97202','pizzithompson@comcast.net','Philip Thompson','1605 SE Lexington St','Portland','OR','UNITED STATES','97202-6106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 00:05:50',0,NULL,3,1,1,1,NULL,NULL),(20879,807013140002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','akapparel22','katie.andrews94@gmail.com','Aaron Reichlin','501 Craig Ln','Villanova','PA','UNITED STATES','19085-1902','(610) 733-0040','NoPaymentFailure','CheckoutComplete','Other','2011-12-05 00:15:31',0,NULL,3,1,3,1,'RA184556036CN ','澳转美标 '),(20880,807016771002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','peter1977piotr','peter.fishing@hotmail.com','Piotr Wawrzyniuk','Ekvägen 2','Kyrkhult','','SWEDEN','290 60','0046 707766228','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 00:23:42',0,NULL,3,1,3,1,'RA184556291CN\r ','1.6*3m 灰色布 '),(20881,763871489001,110454864267,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',7.89,'hermeshine','pakalolo0001','alakai96@me.com','Dominic Cunningham','1420 Kupau Pl','Kailua','HI','UNITED STATES','96734-3666','(808) 630-8208','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-05 00:37:24',0,NULL,3,1,1,1,NULL,' '),(20882,8881323049287973,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',3,'AE3401',67.47,'aliexpress','1005580616 ','-@-.com','Johan Olsson	','﻿﻿﻿﻿Ingegatan ﻿﻿﻿﻿2L','Kungalv','Vastragotaland','﻿SWEDEN﻿	','442 37','+46 76926070',NULL,NULL,NULL,'2011-12-05 01:41:27',0,NULL,3,1,5,1,'CP240320785CN ',NULL),(20883,805267339002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','cz75sp01marcus','shootpang@yahoo.com','Woon Hao Xuan','52, Jalan Ikan Merah','default','','SINGAPORE','578080','92311838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 01:59:02',0,NULL,3,1,11,0,NULL,'■ '),(20884,8881323053542714,111,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',3,'AE2201',111.27,'aliexpress','1005599479 ','bizon500@rambler.ru','YRII ﻿ZALIVIN﻿	','SHKOLNAIA ﻿60\"G\"','BUDENNOVSK','STAVROPOL.REG','RUSSIAN FEDERATION','356800','+7 928 8100077',NULL,NULL,NULL,'2011-12-05 02:52:22',0,NULL,3,1,5,1,'CP240320799CN ','欧标 '),(20885,8881323053940425,111,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',22.09,'aliexpress','1005601926 ','andreyvedernikov74@yandex.ru','ANDREY VEDERNIKOV','ul. Lenina, d. 7, kv. 33','g. Magnitogorsk','Chelyabinskaya obl.','RUSSIAN FEDERATION','455001','+8 909 0923250',NULL,NULL,NULL,'2011-12-05 02:59:00',0,NULL,3,1,3,1,'RA184556265CN\r ',''),(20944,826580033017,270855429736,'New Studio Light 2300W Continuous Lighting Kit with background backdrop support',1,'AKT041',178,'photographyacc','polkovnik58','bordo58@gmail.com','Sergey Borisov','Nogradskiy pereulok<br>8-3','Mariinsk','Kemerovskaya oblast\'','RUSSIAN FEDERATION','652153','+7 38443 5-10-50','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 07:51:10',0,NULL,3,1,5,1,'CP240335025CN ','欧标 \r'),(20886,8881323054672753,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included ',1,'AC2402',19.99,'aliexpress','1005611627 ','marcelocvaz@gmail.com','Marcelo de Castro Vaz','Rua Riachuelo 925 / 301','Porto Alegre','Porto Alegre','BRAZIL','90010-270','+55 51 32124628',NULL,NULL,NULL,'2011-12-05 03:11:12',0,NULL,3,1,17,0,NULL,NULL),(20887,8881323054986152,111,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',15.99,'aliexpress','1005611626','marcelocvaz@gmail.com','Marcelo de Castro Vaz','Rua Riachuelo 925 / 301','Porto Alegre','RS﻿','BRAZIL','90010-270','+55 51 32124628',NULL,NULL,NULL,'2011-12-05 03:16:26',0,NULL,3,1,3,1,'RA117764813CN ','圆形柔光棚 50cm * 1 \r倒影板（白黑）* 1'),(20888,8881323055846132,111,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.89,'aliexpress','1005613064','sudogda-33@rambler.ru','Khokhlov Artur','Kommunisticheskaya 10-57','﻿Sudogda﻿','Vladimir','RUSSIAN FEDERATION','601351','89101702216',NULL,NULL,NULL,'2011-12-05 03:30:46',0,NULL,3,1,3,1,'RA117768090CN\r ',NULL),(20889,825878965017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','vi**th','vino83th@gmail.com','Vinoth Jayaratnam','07 Linlee St','Girraween','New South Wales','AUSTRALIA','2145','61430439810','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-05 03:40:10',0,NULL,3,1,2,1,NULL,NULL),(20890,807127784002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','vikebi7474','viktoreberle@gmail.com','Viktor Eberle','Siegfriedstr. 30','Bielefeld','','GERMANY','33615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 04:36:13',0,NULL,3,1,2,1,NULL,NULL),(20891,807138818002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','premierairfilters','sales@premierairfilters.com','Jeremy Pilchman','30 Calle De Los Ninos','Rancho Santa Margarita','CA','UNITED STATES','92688-2816','(949) 521-4376','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-05 05:16:40',0,NULL,3,1,1,1,NULL,NULL),(20892,763697409001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','ehf72','henry.feldt@telia.com','Henry Feldt','Stastorp 3014','Trelleborg','SD','SWEDEN','231 93','+46 733641160','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 05:34:46',0,NULL,3,1,4,1,'YW867661315CN ','欧标 \r绿色 布\r220v\r▲'),(20893,767935978018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',5,'AB1202',34.9,'photographyacc','redhatsales2004','dnancarrow@gmail.com','Darren Nancarrow','c/o Lightstorm International<br>Suite 4, 7 Gympie Way','WILLETTON','Western Australia','AUSTRALIA','6155','0432025276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-05 06:49:31',0,NULL,3,1,3,1,'RA184556274CN\r ',NULL),(20894,807161899002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','charitos50','petursa@terra.es','Rosario Pérez Carrillo','Lozano Sidro, 18 1º','Priego de Córdoba','Andalucía Ceuta y Melilla','SPAIN','14800','622217472','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-05 07:04:00',0,NULL,3,1,12,1,'2770968605\r ','欧标  \r实重 4.336  泡重6.1'),(20895,8881323068999690,111,'三脚架 伟峰 EI-717  配件',1,'',0,'photographyacc','junkyard_boy','mistamichal@dodo.com.au','Michael Tokarski','1 Jiloa Way','Don','Tasmania','AUSTRALIA','7310','',NULL,NULL,NULL,'2011-12-05 07:09:59',0,NULL,3,1,3,1,'RA184556345CN ',' 717手柄 上的配件   1'),(20896,764008447001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','agp567','anthonypilon@bigpond.com','Anthony Gary Pilon','PO Box 152','DUBBO','New South Wales','AUSTRALIA','2830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 07:49:13',0,NULL,3,1,2,1,NULL,NULL),(20897,595026805003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','2010fotoroy','rbjolsen@online.no','Roy Bjerke Olsen','SOLLIVEIEN 32','ASKER','Akershus','NORWAY','1384','97740694','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 08:02:51',0,NULL,3,1,5,1,'CP240320808CN\r',NULL),(20898,884878411016,260894475364,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',9.8,'hutongstore','malkimberley19','malkimberley@btinternet.com','Malcolm Shaw','Little House<br>Laurel Gardens','Yatton','Bristol','UNITED KINGDOM','BS49 4AE','01934833216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 08:06:34',0,NULL,3,1,2,1,NULL,NULL),(20899,884885988016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','3sfe','revvvvv@hotmail.com','Sean Bates','10 Caswell St<br>East brisbane','Brisbane','Queensland','AUSTRALIA','4169','0733912553','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 08:31:17',0,NULL,3,1,2,1,NULL,NULL),(20900,764020792001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','humshkin','hbande6@gmail.com','Humphrey Bande','His People Church<br>Cnr Solly Smidt and Joe Hattingh','N1 City','Western Cape','SOUTH AFRICA','7463','+27723267299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 08:43:42',0,NULL,3,1,3,1,'RA117767633CN ',NULL),(20901,807200602002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','ostfrallan','david@davidlundberg.se','David Lundberg','Bergsunds Strand 21','Stockholm','','SWEDEN','117 38','+460739566118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 09:38:15',0,NULL,8,1,17,0,NULL,NULL),(20902,807200603002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',65,'hermeshine','ostfrallan','david@davidlundberg.se','David Lundberg','Bergsunds Strand 21','Stockholm','','SWEDEN','117 38','+460739566118','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-05 09:38:16',0,NULL,3,1,4,1,'YW867738595CN ','4灯头 灯头 孔    1 欧标\r115w 5500k 灯泡  220v   4\r超重了  \r▲'),(20903,903387271015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',24.2,'hutongstore','1bestonly1','gigi@studiocafaro.com','World Trading SRL','Via Dei Mille 16','Adelfia','BA','ITALY','70010','0804597983','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 11:09:51',0,NULL,3,1,3,1,'RA117767620CN ',NULL),(20904,826035997017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','volfyn','volk15411541@ya.ru','Kirill Morozov','Russia, Moskovskaya oblast, Klinsky rayon, selo Spas-Zaulok, Tsentralnaya street, 10 dom. kv.5','Klin','Moskovskaya oblast','RUSSIAN FEDERATION','141667','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 12:30:53',0,NULL,3,1,11,1,NULL,'不挂号 '),(20905,903426460015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','aileenhughes','aileenhughes1@yahoo.co.uk','Aileen Hughes','Hughes Centra, 1A Main Street,<br>Carrickmore,','Omagh,','Tyrone','UNITED KINGDOM','BT79 9AY','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-05 12:41:13',0,NULL,3,1,4,1,'YW867738551CN ','白加黑 \r▲'),(20906,898788065015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','vanguardfilmuk','vanguardfilm@hotmail.co.uk','Simon Whybourne','19 Dennis Avenue','St Helens','Merseyside','UNITED KINGDOM','WA10 3QD','01512920307','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-05 12:54:28',0,NULL,3,1,12,1,'2771118136\r ','英标 \r实重4.288  泡重5.9'),(20907,764094450001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','yaronharel','yaron@technion.ac.il','Yaron Harel','p.o.box 574','Ramat Yishai','','ISRAEL','30095','972 52 8977929','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 13:00:19',0,NULL,3,1,3,1,'RA117767664CN ',NULL),(20908,826051300017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','5xwcwchampion','philipliuvancouver@yahoo.ca','Philip Liu','5338 Argyle Street<br>(basement, right side)','Vancouver','BC','CANADA','V5P 3J3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-05 13:10:28',0,NULL,3,1,2,1,NULL,'申报gift \r把这句话打出来贴在货上  \rPostmaster: Tenant lives on right side basement, NOT AT FRONT DOOR.\" '),(20909,903443502015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',2,'AKT003',88,'hutongstore','mario110400_1','marioillo@hotmail.com','Mario Gómez Calleja','Avda Del Stadium nº2  8ºB','Santander','Cantabria','SPAIN','39005','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 13:17:45',0,NULL,3,1,12,1,'2771108885\r','欧标 \r实重5.42 泡重6'),(20910,807292143002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',43,'hermeshine','aine-086','aine.brooks@gmail.com','AINE CASEY','MOYRIESK','QUIN','Clare','IRELAND','1','0868212371','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-05 14:08:39',0,NULL,3,0,3,1,'RA117767647CN ','XXL 已入库 '),(20911,764148581001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','zambuga','pfccasanova@hotmail.com','A.R.Casanova','Rua adolfo de medeiros 32<br>32','Ribeira Grande','Azores','PORTUGAL','9600 -500','351296472193','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 15:12:42',0,NULL,3,1,4,1,'YW867738536CN ','欧标 \r▲'),(20912,903544667015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','kpna33','kapona91@yahoo.es','Marta Capón Pérez','C/Rafael Salazar Alonso nº3  7ºiz','Madrid','Madrid','SPAIN','28007','680297273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 16:30:12',0,NULL,3,1,3,1,'RA117767721CN ','4节 '),(20913,764182539001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','auryla','a.bobrovas@gmail.com','Aurimas Bobrovas','14 College Bounds','Fraserburgh','Aberdeenshire','UNITED KINGDOM','AB43 9QP','07999603118','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 16:33:06',0,NULL,3,1,2,1,NULL,NULL),(20914,764184080001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','van1_123','pvdmuk@hotmail.com','Peter van der Merwe','Kilburn House','Ton Kenfig','Bridgend','UNITED KINGDOM','CF33 4PT','01656743312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 16:37:59',0,NULL,3,1,2,1,NULL,'英标'),(20915,807367215002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','heintzs1985','heintzs0@hotmail.com','Sarah Heintz','#3 37575 Hwy 2','Red Deer County','AB','CANADA','T4E 1A9','(403) 598-5398','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 16:52:31',0,NULL,3,1,3,1,'RA117767749CN ',NULL),(20916,885174562016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','christopher8186','tf1967@hotmail.com','christopher longstaff','77 keir hardy av,','stanley   co.durham','Durham','UNITED KINGDOM','dh96ju','01207234890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-05 18:24:14',0,NULL,3,1,2,1,NULL,NULL),(20917,807446296002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','dfung2000','fungdanny_2000@yahoo.com','Daniel Fung','1 Cooperage Street','Brampton','ON','CANADA','L6Y5K1','(416) 456-0100','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 19:00:32',0,NULL,3,1,2,1,NULL,NULL),(20918,807460475002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','maoz234','maoz.vay@gmail.com','Maoz Vaystooch','Ha\'Dekel st.<br>36/5','Tirat Carmel','Israel','ISRAEL','39020','+972544351537','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 19:20:15',0,NULL,3,1,3,1,'RA117767678CN ',NULL),(20919,903762174015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','fl0-0','bp.direktion1138@gmx.at','Zechner F','Obere Zweiggasse.5','St.Ulrich','','AUSTRIA','9524','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 20:56:39',0,NULL,3,1,11,1,NULL,'不挂号 '),(20920,763414211001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',1,'AKT059',29.99,'hermeshine','biker1011985','biker@email.ua','Eugen Stadnik','164a Chapaeva Street, Apt.29','Alchevsk','Luganskaya oblast','UKRAINE','94207','380668266887','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 21:02:42',0,NULL,3,1,3,1,'RA117767655CN ','5个 '),(20921,901635617015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','anestakos-delpi','anestakoss@hotmail.com','Anestis Georgiadis','Stamkidi Stefanou 17','Kozani','Mayrodendri - Kozanis','GREECE','50100','6932308608','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-05 22:01:19',0,NULL,3,1,3,1,'RA117767735CN ',NULL),(20922,807576254002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','a_strokins','andrejs.strokins@gmail.com','Andrejs Strokins','Bruninieku 20-43','Riga','','LATVIA','LV-1001','+371 26408773','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 22:17:56',0,NULL,3,1,11,1,NULL,'不挂号 '),(20923,764428267001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','gravitybits','gravity_biz@optusnet.com.au','Karl Weinert','27/ Twenty-Second Avenue','Brighton','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-05 23:36:43',0,NULL,3,1,2,1,' ',NULL),(20924,903834145015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','2terminator','franca.ferretti@alice.it','Daniele Silvestri','Via Enzo Tortora (7)','S.M degli Angeli','PG','ITALY','06088','3333692223','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-05 23:51:37',0,NULL,3,1,4,1,'YW867738540CN ','欧标 \r▲'),(20925,768411226018,280680102981,'YongNuo Flash Battery Pack for Nikon SB900 SD-9  /8AA',1,'AB3311',52,'photographyacc','jainashprakash','jainash.prakash@gmail.com','Jainash Prakash','6 Snow Gum Rd','Doncaster East','Victoria','AUSTRALIA','3109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 00:25:35',0,NULL,3,1,3,1,'RA117767695CN ',NULL),(20926,764442964001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',3,'AA1307',7.8,'hermeshine','joewickert','joe@summerhill.com.au','Joe  Wickert','PO Box 3255','Marrickville Metro','New South Wales','AUSTRALIA','2204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 00:27:04',0,NULL,3,1,2,1,NULL,NULL),(20927,807639691002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','sakkater09','sak_kater@yahoo.gr','Pagonas Athanasios','137 A/K MMP','Litohoro Pierias','','GREECE','60200','6944905449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 00:47:05',0,NULL,3,1,17,0,NULL,NULL),(20928,807642021002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','sakkater09','sak_kater@yahoo.gr','Pagonas Athanasios','137 A/K MMP','Litohoro Pierias','','GREECE','60200','6944905449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 00:49:08',0,NULL,3,1,17,0,NULL,NULL),(20929,764455219001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','sakkater09','sak_kater@yahoo.gr','Pagonas Athanasios','137 A/K MMP','Litohoro Pierias','','GREECE','60200','6944905449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 00:56:15',0,NULL,3,1,3,1,'RA117767752CN ','单灯头    1  欧标\r沙袋（普通）   1 \r伞式柔光箱 60×90cm    1'),(20930,764461582001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','andm1071','andrewdmah@aol.com','Andrew Mah','31 Milkwood','Rancho Santa Margarita','CA','UNITED STATES','92688-1111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 01:14:59',0,NULL,3,1,1,1,NULL,NULL),(20931,826461516017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','2011rachael86','rachael_mcgowan@hotmail.com','Rachael McGowan','32 Redbank Rise','Clarkson','Western Australia','AUSTRALIA','6030','0423632041','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(20932,8881323138253794,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft',1,'AO0005',16.99,'aliexpress','1005631666 ','apreciouspearl@yahoo.com','Anilla Asghar','12 Merton Road, Moseley','﻿birmingham﻿','West Midlands','UNITED KINGDOM','b13 9bx','+44 777 5445142',NULL,NULL,NULL,'2011-12-06 02:24:13',0,NULL,3,0,3,1,'RA117768205CN ','1.6x3.0m 背景布 * 1 （黑色） '),(20933,8881323138718796,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included ',1,'AC2402',19.99,'aliexpress','1005631771 ','reza@laidak.com','VENTILOGAINE SA Reza Daniel','Route des Jeunes 91','Geneva Carouge','Geneva﻿','SWITZERLAND','1227','+41 78 6009171',NULL,NULL,NULL,'2011-12-06 02:31:58',0,NULL,3,1,3,1,'RA117768191CN',NULL),(20934,8881323138936925,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head',1,'AE1603',30.99,'aliexpress','1005633666','stanley@analysys.com.sg','Stanley Leow','448 Tagore Industrial Avenue','﻿Singapore﻿','','﻿SINGAPORE﻿','787819','+65 64843202',NULL,NULL,NULL,'2011-12-06 02:35:36',0,NULL,3,1,3,1,'RA117768262CN ',NULL),(20935,826496992017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','monkiesmommy','susiequebe@aol.com','Susie Larson','4431 Brookpine Dr','San Luis Obispo','CA','UNITED STATES','93401-7802','(805) 545-9455','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 02:46:45',0,NULL,3,1,1,1,NULL,NULL),(20936,764495886001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','russellusbuyer','russellebay1@yahoo.com','Ruslan Trocin','5425 Garfield Ave<br>Apt 109','Sacramento','CA','UNITED STATES','95841-2849','(916) 524-7234','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-06 02:54:10',0,NULL,3,1,4,1,'YW867738573CN ','▲ '),(20937,768470018018,280687946370,'Pro Heavy Video Camera Tripod EI-717 1.80m 6ft version',1,'AO0023',260,'photographyacc','clment8784','clement.jolivet@laposte.net','Clément Jolivet','25 rue d\'Angoulême','Cognac','Poitou-Charentes','FRANCE','16100','0676220169','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 03:11:12',0,NULL,3,1,4,1,'YW867738584CN ','▲'),(20938,807710046002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','scottmadore13','scott@scottmadore.com','Scott Madore','5 Aurora Heights Dr.','Aurora','ON','CANADA','L4G2W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 03:50:35',0,NULL,3,1,3,1,'RA117768055CN\r\r ','美标 '),(20949,764615969001,110469599873,'Photo Video Light Stands Studio Photo Stand 7ft 200cm',1,'AE3401',28,'hermeshine','zarkoantonio','zarquit_o@hotmail.com','JOSE FELIPE VEGA PEREZ','C/ AMSTERDAM 6 ESC IZDA 6º A','OVIEDO','Asturias','SPAIN','33011','985114125','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 10:58:17',0,NULL,3,1,3,1,'RA117768333CN ',NULL),(20939,807741517002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','bisaido','bisaido@gmail.com','Huy Nguyen','8246 Mountain Ash Way','Gaithersburg','MD','UNITED STATES','20879-1549','(301) 938-4168','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 05:49:33',0,NULL,3,1,3,1,'RA117768038CN\r ',NULL),(20940,807748881002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','dendome60','dkpez@platinum.ca','Denise Pezderic','Box 1114','Claresholm','AB','CANADA','T0L 0T0','(403) 687-2149','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 06:27:08',0,NULL,3,1,2,1,NULL,NULL),(20941,807751794002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','esudibjo72','esudibjo@yahoo.com','Eko sudibjo','Perum Beverly<br>Beverly Park i1/29','Batam','Indonesia','INDONESIA','29464','+628129280494','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 06:39:40',0,NULL,3,1,2,1,NULL,NULL),(20942,8881323154977433,111,'4灯头 灯头 孔 ',1,'',0,'hermeshine','leopbrasil','padual@hotmail.com','Leonardo Rodrigues','R. Coronel Correia de Figueiredo 185<br>Bairro Museu','Conselheiro Lafaiete','Minas Gerais','BRAZIL','36400000','553137615992',NULL,NULL,NULL,'2011-12-06 07:02:57',0,NULL,3,1,3,1,'RA117768015CN\r ','欧标 '),(20943,768529340018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',6,'AD1169',38.4,'photographyacc','admodesi','email@keithyoung.com.au','Keith Young','1/292 Malton Rd','North Epping','New South Wales','AUSTRALIA','2121','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 07:08:49',0,NULL,3,1,3,1,'RA117768109CN\r ',NULL),(20945,807765857002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','mokongzz','eric_javier@hotmail.com','Eric Javier','PMB 1157 P.O. Box 10003','SAIPAN','MP','UNITED STATES','96950-8903','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 08:12:54',0,NULL,3,1,3,1,'RA117768024CN\r ',NULL),(20946,807787624002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','jiunshenghuang','pb220705@hotmail.com','JiunSheng Huang','888 Ofarrell St<br>Apt 314','San Francisco','CA','UNITED STATES','94109-7094','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 09:18:09',0,NULL,3,1,3,1,'RA117768355CN ',NULL),(20947,807780476002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','p0pc0rnp!4y4h','adih81@gmail.com','Adam Huszka','7 The Avenue, Windsor<br>Unit 7','Melbourne','Victoria','AUSTRALIA','3181','0421403638','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 08:48:04',0,NULL,3,1,3,1,'RA117768347CN ',NULL),(20948,764599331001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','wybranieck','konik19@poczta.onet.pl','Krzysztof Wybraniec','9 Belmont Square<br>Raheny, Dublin 5','Raheny','Dublin','IRELAND','5','0877637965','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 10:01:38',0,NULL,3,1,11,1,' 、','英标 \r不挂号'),(20950,826640927017,270751512053,'YongNuo 3m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AB3320',28.99,'photographyacc','marlabe','helmutk@westnet.com.au','H & G  KUMMER','PO BOX 49','MARLO','Victoria','AUSTRALIA','3888','','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2011-12-06 11:13:13',0,NULL,3,1,3,1,'RA117768320CN ',NULL),(20951,885674452016,260894475136,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',19.99,'hutongstore','1otusfan','ianformstone@dsl.pipex.com','Ian Formstone','15 Beech Avenue<br>Gresford','Wrexham','Wrexham County Borough','UNITED KINGDOM','LL12 8EL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 12:06:41',0,NULL,3,1,3,1,'RA117768188CN ',NULL),(20952,807839045002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','asd1978_blue','scottdeighton@telstra.com','Scott Deighton','Po Box 208','Miami','Queensland','AUSTRALIA','4220','0412521722','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 12:07:43',0,NULL,3,1,2,1,NULL,NULL),(20953,807874002002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','montex124','iroc@adam.com.au','ROBERT MONTELEONE','12 HEATHER ROAD','ALDGATE','South Australia','AUSTRALIA','5154','61883708120','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 13:54:46',0,NULL,3,1,3,1,'RA117768174CN ',NULL),(20954,885724253016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','benjiboy70','benjis@maltanet.net','Benjamin Sant','11 Vanilja Street','Mgarr','Malta','MALTA','MGR2250','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 14:01:37',0,NULL,3,1,3,1,'RA117768259CN ',NULL),(20955,904196536015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','mycronapoli','zammartino.m@gmail.com','Mirko Zammartino','Antica giardini 23','Giugliano in Campania','NA','ITALY','80014','0818957786','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 14:26:45',0,NULL,3,1,2,1,NULL,NULL),(20956,768671538018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','artbusines','artcuadrado@gmail.com','Jorge  Hernández Domínguez','Castillejos 350 2º','Barcelona','Cataluña','SPAIN','08025','655336293','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 14:42:17',0,NULL,3,1,2,1,NULL,NULL),(20957,807909838002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mpoco','mqf@columbus.rr.com','Maury Q Falkoff','1008 Blue Sail Dr','Westerville','OH','UNITED STATES','43081-2756','(614) 895-7639','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 15:13:00',0,NULL,3,1,3,1,'RA117768112CN ',NULL),(20958,764708731001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',2,'AA2114',64,'hermeshine','leandroeiki2011','leandroiwaki@gmail.com','Leandro Eiki Iwaki','av. João Dias 1331','São Paulo','São Paulo','BRAZIL','04723-001','551196888928','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-06 15:20:26',0,NULL,3,0,3,1,'RA117768214CN ','XXL 已入库   2件 '),(20959,826740854017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.59,'photographyacc','sanjotsonalkar','sanjot@aol.in','Sanjot Sonalkar','14, Vinay (Chakala) CHS,<br>Chakala, 95/5, Andheri (E),','Mumbai','MH','INDIA','400099','9820347078','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 15:22:40',0,NULL,3,1,2,1,NULL,NULL),(20960,807919184002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','feiz7','thengfei_loong@hotmail.com','Theng Loong','928 Swanston Street','Carlton','Victoria','AUSTRALIA','3053','0433378892','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 15:36:09',0,NULL,3,1,2,1,NULL,NULL),(20961,768696587018,280696359665,'New Camera Tripod Fancier with 3-way head Bag WF-6663A',1,'AE1502',80,'photographyacc','canlens','fbougee@gmail.com','Vladimir Podyukov','Uralskaya ul. 23,<br>korpus 4, kvartira 619','Moscow','','RUSSIAN FEDERATION','107065','8 (926) 0611605','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 15:41:25',0,NULL,3,1,5,1,'CP240335039CN ',NULL),(20962,904254290015,250599919356,'New 62mm Ring adapter for Cokin P Series Filter Holder',1,'AA2211',1.6,'hutongstore','max4feet','neil.armstrong@talktalk.net','c armstrong','92 ashley drive','Bangor','Down','UNITED KINGDOM','BT20 5RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 16:12:06',0,NULL,3,1,2,1,NULL,NULL),(20963,807963888002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','leviar','jakilevi@zahav.net.il','Aharon Levi','Mordey hagetaot 22-6','Rehovot','Rehovot','ISRAEL','76464','+972 89450577','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:06:39',0,NULL,3,1,11,1,NULL,'不挂号 '),(20964,903536516015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',23.28,'hutongstore','sivanovai','sivanovai@abv.bg','Ivan Ivanov','Graf Ignatiev Str.36,Entr.0, Apt.5','Stara Zagora','','BULGARIA','6000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 17:16:50',0,NULL,3,1,3,1,'RA117768165CN ','圆形柔光棚 50cm    1\r镜头笔      1\r52—52双阳环    1\r85cm柔光伞      1\r已入库'),(20965,807975010002,120642516712,'Tungsten bulb 800W for redhead light  X 1 3200K 110V',1,'AO0014',7.9,'hermeshine','freshido','bingo2003@hotmail.com','Frederic Perez','5765 Cote St Luc Road #211','Montreal','QC','CANADA','H3X 2E9','(514) 485-9821','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 17:26:51',0,NULL,3,1,2,1,NULL,NULL),(20966,807982256002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','usctrojanearl','earl.milligan@gmail.com','Multitek Digital Communications','1510 Baker Ave<br>Unit C','Evansville','IN','UNITED STATES','47710-2547','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 17:46:45',0,NULL,3,1,4,1,'YW867739715CN ','▲ '),(20967,807988118002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'AD1200',55,'hermeshine','jack9577','janine.d.acker@gmail.com','Janine Acker','3616 Danbury Terrace','North Port','FL','UNITED STATES','34286','(941) 779-3433','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-06 17:49:42',0,NULL,3,1,3,1,'RA117768228CN ',NULL),(20968,807994039002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-06 18:09:05',0,NULL,3,1,3,1,'RA117768302CN ','申报低值 '),(20969,826877259017,270753695711,'Flash Diffuser Softbox for Speedlight Flash SB800 SB900',1,'AB3314',6.69,'photographyacc','siammutz','eberhard_diana@yahoo.de','Diana Eberhard','Rietstrasse 1','Maseltrangen','','SWITZERLAND','8723','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 19:13:19',0,NULL,3,1,11,1,'、 ','不挂号 '),(20970,764877232001,110534333509,'3ft 1m  i-TTL(II) Off-Camera Flash Cord for Nikon',1,'AB3321',17.99,'hermeshine','enduro-al','alan-scott@talktalk.net','Alan Scott','10 Lansdowne Gardens','Stakeford, Choppington','Northumberland','UNITED KINGDOM','NE62 5LF','01670521982','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 20:23:00',0,NULL,3,0,2,1,NULL,'c里面的不对  应该是\r永诺nikon ttl 线  1m    1'),(20971,904454255015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','geoff5887','geoff@rounce.me.uk','Geoff Rounce','32 Chichester Close<br>Witley','Godalming','Surrey','UNITED KINGDOM','GU8 5PA','01428681374','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-06 20:37:10',0,NULL,3,1,2,1,NULL,NULL),(20972,808112139002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','1818edu','luoete@yahoo.es','Eduardo Penelo Sanchez','Avd coruña 58 bajo<br>Avd coruña 58 bajo','Lugo','Galicia','SPAIN','27003','696609506','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-06 21:00:13',0,NULL,3,1,3,1,'RA117768276CN ',NULL),(20973,808123795002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tirilhjelm','tiril.hjelmeland@gmail.com','Tiril Hjelmeland','Kalfarveien 58','Bergen','Bergen','NORWAY','5018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-06 21:18:02',0,NULL,3,1,3,1,'RA117768280CN ',NULL),(20974,904511624015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',21.2,'hutongstore','bitphoenix','ebay@bitphoenix.com','Frode Løvbukten','Tofsrudveien 116','Fetsund','','NORWAY','1900','93861878','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-06 21:47:40',0,NULL,3,1,3,1,'RA117768231CN ',NULL),(20975,768895748018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',5.9,'photographyacc','aquaseller2004','s.haile@toucansurf.com','Simon Haile','54 Warren Road<br>Hillmorton','Rugby','Warwickshire','UNITED KINGDOM','CV22 5LG','01788537027','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-06 21:13:55',0,NULL,3,1,2,1,NULL,NULL),(20976,827002319017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','sylvia5993','sylviar@mpeservices.com.au','Raphael Sylvia','PO Box 4057','Mt Eliza','Victoria','AUSTRALIA','3930','0413443066','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 22:11:40',0,NULL,3,1,17,0,NULL,NULL),(20977,827004138017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','sylvia5993','sylviar@mpeservices.com.au','Raphael Sylvia','PO Box 4057','Mt Eliza','Victoria','AUSTRALIA','3930','0413443066','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-06 22:13:16',0,NULL,3,1,2,1,NULL,'沙袋（大）   2 '),(20978,808212009002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','kaytee_1','kristy_145@hotmail.com','Kristy Taylor','826  Whitehorse  Rd<br>Level 2','Box Hill','Victoria','AUSTRALIA','3128','0400252215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 00:20:40',0,NULL,3,1,2,1,NULL,NULL),(20979,821937245017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',1,'AA1302',2.5,'photographyacc','druce8022','drucehorton@ledanet.com.au','Druce Horton','285 Oak Forest Road','Kuranda','Queensland','AUSTRALIA','4881','0740938208','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 00:56:16',0,NULL,3,1,2,1,NULL,NULL),(20980,765014673001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','robynjanderson','robynjanderson@hotmail.com','Robyn Anderson','45 Enterprize Drive','Sunbury','Victoria','AUSTRALIA','3429','0397443622','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 01:11:46',0,NULL,3,1,3,1,'RA117768293CN ',NULL),(20981,808233169002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',2,'AC3201',79.76,'hermeshine','andrealatterell','alatterell@lipstudios.com','Andrea Latterell','2545 SW Kristin Dr','Lees Summit','MO','UNITED STATES','64082-4125','','NoPaymentFailure','CheckoutComplete','Other','2011-12-07 01:15:08',0,NULL,3,1,4,1,'YW867739726CN ','▲ '),(20982,808246522002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','cclayborn1','cclayborn@gmail.com','Carmen Clayborn','3105 Autumn Run','Bargersville','IN','UNITED STATES','46106-8370','(317) 946-1639','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-07 01:51:03',0,NULL,3,1,4,1,'YW867738606CN ','灯泡都是110v的 \r▲'),(20983,765002011001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',51.99,'hermeshine','sqais','genmo@sympatico.ca','Guennadi Momot','45 Carlton Street, #710','Toronto','ON','CANADA','M5B 2H9','','NoPaymentFailure','CheckoutComplete','ExpeditedInternational','2011-12-07 01:51:40',0,NULL,3,1,6,1,'EE636828841CN ',NULL),(20984,8881323225515426,111,'40cm 和60cm闪光灯柔光箱     ',2,'',0,'hermeshine','serj161189','serj1989@mail.ru','Gerashchenko Sergey Mihaylovich','Ulica. Stadionnaya, dom 7/1, kv.54','UFA','Bashkortostan','RUSSIAN FEDERATION','450069','+79876237676',NULL,NULL,NULL,'2011-12-07 02:38:35',0,NULL,3,0,5,1,'CP240335042CN ','各两个 \r已入库'),(20985,765086440001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','hariendemel','buwas@omnibis.com','Harien de Mel','44 Guildford Crescent','Colombo 07','','SRI LANKA','00700','0094777683449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 04:56:11',0,NULL,3,1,3,1,'RA117768381CN ',NULL),(20986,764874474001,110502914189,'New 52mm ring adapter replacement for cokin P series',2,'AA2208',58.53,'hermeshine','waterwks','johelle1@bigpond.com','wayne lawson','110 Embreys Road','Tallegalla','Queensland','AUSTRALIA','4340','0754644900','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:00:02',0,NULL,3,1,3,1,'RA117768404CN ','方形滤镜接口环 52mm  2 \r方形滤镜接口环 82mm   1\r方形滤镜接口环 58cm      1\r无牌十片+盒子\r普通托架     1\r广角托架   1\r'),(20987,765097846001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',2,'AA2115',64,'hermeshine','skypics69','peter@skypics.com.au','Peter Barker','282 Waverley Road','Malvern East','Victoria','AUSTRALIA','3145','0359755499','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 05:40:11',0,NULL,3,0,3,1,'RA117768395CN ','摄影背心 黑色薄 canon   3XL 2件\r已入库 '),(20988,808320927002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','hauzi2003','martin.hauzenberger@gmail.com','Martin Hauzenberger','Landwiedstraße 184','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:44:49',0,NULL,3,0,17,0,NULL,' '),(20989,808321629002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','hauzi2003','martin.hauzenberger@gmail.com','Martin Hauzenberger','Landwiedstraße 184','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 05:46:49',0,NULL,3,0,3,1,'RA117768965CN ','背景布 1.6m * 3m    2块 \r白色和黑色'),(20990,765116642001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','scottklein_1025','scottklein@iwon.com','Scott Klein','200 SE 105th Ave<br>Apt 107','Portland','OR','UNITED STATES','97216-2954','(503) 828-1778','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 07:13:45',0,NULL,3,1,17,0,NULL,NULL),(20991,808339982002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','scottklein_1025','scottklein@iwon.com','Scott Klein','200 SE 105th Ave<br>Apt 107','Portland','OR','UNITED STATES','97216-2954','(503) 828-1778','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 07:13:46',0,NULL,3,1,3,1,'RA117768466CN ','铝合金灯座（N）   1\r伞式柔光箱 80cm 8角     1\r '),(20992,808348524002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','lisska.tigra','lisska@bk.ru','Elizaveta Stepanova','Yaroslavskoe shosse, dom. 22.<br>korpus 1. kv. 28','Moscow','','RUSSIAN FEDERATION','129337','+79265729559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:54:14',0,NULL,3,1,17,0,NULL,NULL),(20993,808348526002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','lisska.tigra','lisska@bk.ru','Elizaveta Stepanova','Yaroslavskoe shosse, dom. 22.<br>korpus 1. kv. 28','Moscow','','RUSSIAN FEDERATION','129337','+79265729559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:54:18',0,NULL,3,1,17,0,NULL,NULL),(20994,808348527002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','lisska.tigra','lisska@bk.ru','Elizaveta Stepanova','Yaroslavskoe shosse, dom. 22.<br>korpus 1. kv. 28','Moscow','','RUSSIAN FEDERATION','129337','+79265729559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:54:18',0,NULL,3,1,17,0,NULL,NULL),(20995,808348528002,120758268927,'Camera protector case bag f Nikon D200 D300s D700 XL',1,'AD1174',12.99,'hermeshine','lisska.tigra','lisska@bk.ru','Elizaveta Stepanova','Yaroslavskoe shosse, dom. 22.<br>korpus 1. kv. 28','Moscow','','RUSSIAN FEDERATION','129337','+79265729559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:54:19',0,NULL,3,1,17,0,NULL,NULL),(20996,765124836001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','lisska.tigra','lisska@bk.ru','Elizaveta Stepanova','Yaroslavskoe shosse, dom. 22.<br>korpus 1. kv. 28','Moscow','','RUSSIAN FEDERATION','129337','+79265729559','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 07:54:20',0,NULL,3,1,3,1,'RA117768758CN ','lenspen   1\r镜头筒 小，中，大，XL号各一个\r橡胶遮光罩 67mm   1\r新款内胆包 XL  Nikon     1\r橡胶遮光罩 52mm  1\r\r '),(20997,808184510002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','bap1664','brunopozzani@ntlworld.com','Bruno Pozzani','11 Kings Way<br>Groby','Leicester','Leicestershire','UNITED KINGDOM','LE60YJ','01162312286','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 07:57:48',0,NULL,3,0,3,1,'RA117768744CN ','XL 已入库 '),(20998,765106335001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','jelkodesign','reg@jelko.com','Jelena Tshebotar','J. Koorti 19-15','Tallinn','','ESTONIA','13623','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 08:29:36',0,NULL,3,1,11,1,NULL,'欧标\r不挂号 '),(20999,808386478002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','pro0','pro_sae@yahoo.com','SAEID HARAN ALSHAMMARI','200 vila<br>King Khalid Military City','PO. Box 10913 King Khalid Military City','HAFAR AL BATIN','SAUDI ARABIA','31991','+966505150815','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 10:20:47',0,NULL,3,1,3,1,'RA117766139CN ',NULL),(21000,886345743016,260838264614,'New Large High quality heavy duty sand bag Empty',3,'AD1168',26.97,'hutongstore','luisnok','freitas1974@gmail.com','Luis Freitas','Lugar da Pedreira, Lote 9','Guimarães','Azurém - Guimarães','PORTUGAL','4810-057','+351915590019','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-07 10:37:17',0,NULL,3,1,17,0,NULL,NULL),(21001,904819375015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',7,'AKT014',160.93,'hutongstore','selle_2006','wilmas@seznam.cz','Jiri Krouzek','Na Zizkove 1245','Ledec nad Sazavou','Vysocina','CZECH REPUBLIC','58401','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-07 10:37:37',0,NULL,3,1,5,1,'CP211275735CN ',NULL),(21002,904828777015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','luisnok','freitas1974@gmail.com','Luis Freitas','Lugar da Pedreira, Lote 9','Guimarães','Azurém - Guimarães','PORTUGAL','4810-057','+351915590019','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 10:51:03',0,NULL,3,1,3,1,'RA117766195CN ','\r沙袋（大）   3 \r带水平仪 热靴保护盖   1'),(21003,8881323257011073,111,'2m *1.5m 白色背景板',1,'AD1206',0,'hutongstore','oren_keller','oren_k@inter.net.il','Oren Keller','86 Mohaliver st.','Yahud','','ISRAEL','56209','972-50-8800307',NULL,NULL,NULL,'2011-12-07 11:23:31',0,NULL,3,1,3,1,'RA117766156CN\r ',NULL),(21004,904843165015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','charliebrowns*','mcgoverns@gmx.com','John Mcgovern','Dance2 Sound<br>9 Woodbridge Road','Guildford','Surrey','UNITED KINGDOM','GU14PU','07795547649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 11:26:19',0,NULL,3,1,11,1,NULL,'不挂号 '),(21005,886376038016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','export61','simongilbertphotography@yahoo.co.uk','simon gilbert','3 mill cottages<br>kenn','exeter','devon','UNITED KINGDOM','ex6 7ur','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 11:52:57',0,NULL,3,1,17,0,NULL,NULL),(21006,765194155001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','valnabi','valentinas.nabijevas@gmail.com','Valentinas Nabijevas','Zemaiciu g 88-3','Kaunas','','LITHUANIA','44182','+37061420015','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 12:00:35',0,NULL,3,1,3,1,'RA117766200CN ',NULL),(21007,904854554015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','export61','simongilbertphotography@yahoo.co.uk','simon gilbert','3 mill cottages<br>kenn','exeter','devon','UNITED KINGDOM','ex6 7ur','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-07 11:52:57',0,NULL,3,1,3,1,'RA117768917CN\r ','背景布 1.6*3  灰色布  1 \r伞式柔光箱 80cm 8角    1'),(21008,886394443016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','tofdragon62','ptitdragongsxr@hotmail.fr','colpin christophe','6 rue des chartreux','tatinghem','Nord-Pas-de-Calais','FRANCE','62500','0645804895','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 12:39:39',0,NULL,3,1,3,1,'RA117768934CN ','XL '),(21009,769202735018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','leighdu','leigh_dunne@hotmail.com','Leigh Dunne','32 Brookton highway','Kelmscott','Western Australia','AUSTRALIA','6111','93905928','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-12-07 12:41:22',0,NULL,3,1,4,1,'YW867739671CN ','▲ '),(21010,904891952015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-07 13:20:20',0,NULL,3,1,5,1,'CP211275386CN ','欧标\r申报$20 '),(21011,808472886002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 14:30:38',0,NULL,3,1,3,1,'RA117768948CN ','申报低值 '),(21012,765249767001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','limadanilo','email.danilo@gmail.com','DANILO LIMA','RUA ANA ORTEGA TRABALLI, 30 - CASA 22','SAO JOSE DOS CAMPOS','SAO PAULO','BRAZIL','12213-215','+55 12 91317964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 14:34:42',0,NULL,3,1,17,0,NULL,NULL),(21013,765249768001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','limadanilo','email.danilo@gmail.com','DANILO LIMA','RUA ANA ORTEGA TRABALLI, 30 - CASA 22','SAO JOSE DOS CAMPOS','SAO PAULO','BRAZIL','12213-215','+55 12 91317964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 14:34:43',0,NULL,3,1,17,0,NULL,NULL),(21014,808474975002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','limadanilo','email.danilo@gmail.com','DANILO LIMA','RUA ANA ORTEGA TRABALLI, 30 - CASA 22','SAO JOSE DOS CAMPOS','SAO PAULO','BRAZIL','12213-215','+55 12 91317964','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 14:34:45',0,NULL,3,1,5,1,'CP211275372CN ','大力夹云台   2 \r3m 横杆（通用4节）    1\r斜臂   1'),(21015,808476221002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','luisotadas','mluisabp@gmail.com','Mª Luisa Benítez Pecino','Urb. D.ª Casilda Bloque 10, p.2º, 5º derecha','Algeciras (Cádiz)','ANDALUCÍA CEUTA Y MELILLA','SPAIN','11204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 14:38:39',0,NULL,3,1,11,1,NULL,'不挂号  '),(21016,765199033001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 15:03:55',0,NULL,3,1,3,1,'RA117768951CN ',' 分开发\rRA117766142CN'),(21017,808516743002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:11:13',0,NULL,3,1,17,0,NULL,NULL),(21018,765288467001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:11:14',0,NULL,3,1,17,0,NULL,NULL),(21019,808516036002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:11:13',0,NULL,3,1,17,0,NULL,NULL),(21020,765288687001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:11:15',0,NULL,3,1,17,0,NULL,NULL),(21021,808515795002,120566694399,'Brand New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','allapopova19','lala1909@yandex.ru','Alla Popova, E.','street Korneichuka<br>House 33A, Apartment 133','Moscow','','RUSSIAN FEDERATION','127543','8-903-7651077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:11:15',0,NULL,3,1,3,1,'RA117768863CN ','lenspen   1\r52-58mm 双阳环  1\r方镜普通托架（三槽）   1\r方形滤镜接口环 52mm    1\r52-52mm 双阳环   1\r天涯方形滤镜系列  星光镜  star6  1\r\r '),(21022,765290780001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','medicmontana','lmontana64@bellsouth.net','LESLIE MONTANA','64286 Pearl St','Pearl River','LA','UNITED STATES','70452-3635','(504) 325-2817','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 16:18:41',0,NULL,3,1,3,1,'RA117768982CN ',NULL),(21023,765304271001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:24',0,NULL,3,1,17,0,NULL,NULL),(21024,765304272001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:25',0,NULL,3,1,17,0,NULL,NULL),(21025,808531355002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',1,'AA2203',3.5,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:25',0,NULL,3,1,17,0,NULL,NULL),(21026,765304275001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:26',0,NULL,3,1,17,0,NULL,NULL),(21027,808531357002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:26',0,NULL,3,1,17,0,NULL,NULL),(21028,765304276001,110583278393,'TianYa 58mm ND8 filter New 58 Neutral Density Grey NIB',1,'AA2303',6.7,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:27',0,NULL,3,1,17,0,NULL,' '),(21029,808531359002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','vladi_stock','vladi.stock@gmail.com','Natalya Loginova','142 Gogolya St., Apt. 39','Almaty','Almaty','KAZAKHSTAN','050000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:38:28',0,NULL,3,1,3,1,'RA117768877CN ','52-52mm 双阳环   1 \rnikon 反接环  52mm  1\r爵影红外 sony   1\rcanon 反接环  52mm  1\r绿叶 渐变镜 58mm  1\r天涯 ND858mm  1\r天涯 ND8 52mm  1\r'),(21030,765306955001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',2,'AA1204',3.98,'hermeshine','thomasd2324','thomas.dislis@gmail.com','Thomas Dislis','Kolokotroni 23','Thessaloniki','Thessaloniki','GREECE','54641','+306978341601','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 16:47:36',0,NULL,3,1,17,0,NULL,NULL),(21031,765316553001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','thomasd2324','thomas.dislis@gmail.com','Thomas Dislis','Kolokotroni 23','Thessaloniki','Thessaloniki','GREECE','54641','+306978341601','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 17:03:07',0,NULL,3,1,3,1,'RA117766111CN ',' 热靴保护盖  普通   2\r独脚架  伟峰 WT-1005   1'),(21032,765317860001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jamusino31','narotea@gmail.com','Jose M. A. Fonterosa','RUA MARISTAS  1  -   1º','TUI','Galicia','SPAIN','36700','607444020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:05:09',0,NULL,8,1,17,0,NULL,NULL),(21033,765317861001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','jamusino31','narotea@gmail.com','Jose M. A. Fonterosa','RUA MARISTAS  1  -   1º','TUI','Galicia','SPAIN','36700','607444020','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 17:05:10',0,NULL,3,0,17,0,NULL,NULL),(21034,808545358002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',2,'AKT067',19.8,'hermeshine','jamusino31','narotea@gmail.com','Jose M. A. Fonterosa','RUA MARISTAS  1  -   1º','TUI','Galicia','SPAIN','36700','607444020','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:05:10',0,NULL,3,1,4,1,'YW867661330CN ','橡胶遮光罩 58mm    1 \r三脚架 伟峰 wf-6662A+ 6160H 球台   1\r气吹 + 布  2\rlenspen   2  ▲\r'),(21035,808547455002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','spuality','matthewlevek@gmail.com','Matthew Levek','360 Hillview Dr','Wood River','IL','UNITED STATES','62095-1309','(618) 259-7518','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 17:09:25',0,NULL,3,1,3,1,'RA117766125CN\r ',NULL),(21036,808547133002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',27,'hermeshine','ukb1ll','bill@radiobangkok.net','William Hammerton','99/12 Soi Watcharathit Ahtit Soi 3<br>Soi 101/1 Bang Jak Prakanong','Bangkok','BA','THAILAND','10260','+66 (0) 83 923 7779','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:09:37',0,NULL,3,1,3,1,'RA117768996CN ',NULL),(21037,808547689002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',59.98,'hermeshine','only_stuff','leila.sabitsana@nsn-tech.com','Leila Sabitsana','1817 San Leanna Dr','Allen','TX','UNITED STATES','75013-4741','(214) 383-9778','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-07 17:10:37',0,NULL,3,1,4,1,'YW867739682CN ','▲ '),(21038,808550091002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','2010bousosheila','bousosheila@gmail.com','Carlos Alberto Bouso','Ecuador 318 1 Piso Departamento A','Capital Federal','Buenos Aires','ARGENTINA','C1214ACD','541148657042','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:13:53',0,NULL,3,1,3,1,'RA117766173CN ','申报$10 '),(21039,808556699002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','belleli6792','harley87@sfr.fr','manuel BELLELI','15 route du rabaud<br>Senon','SAINT GENCE','Limousin','FRANCE','87510','05.55.75.87.44','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:26:48',0,NULL,3,1,11,1,NULL,'不挂号  '),(21040,804771947002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','djsensor2011','djsensor@mail.ru','Andrey Botov','Yujniy bulvar<br>9 - 67','Chelyabinsk','','RUSSIAN FEDERATION','454010','79222322196','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 17:28:27',0,NULL,3,1,11,1,NULL,'不挂号  '),(21041,886630372016,260838264614,'New Large High quality heavy duty sand bag Empty',1,'AD1168',8.99,'hutongstore','emotion1070','office@julianlaidig.com','Julian Laidig','Genslerstraße 13a<br>Studio 203','Berlin','','GERMANY','13055','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-07 19:30:06',0,NULL,3,1,11,1,NULL,' 不挂号 '),(21042,765413438001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','sl3975','piepieloy@hotmail.com','S Loy','5440 Lomax Way','Woodbridge','VA','UNITED STATES','22193-3559','(703) 878-7830','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2011-12-07 19:49:30',0,NULL,3,1,3,1,'RA117768885CN ',' '),(21043,808652713002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',1,'AD1125',14.99,'hermeshine','vila-fetel','jomonco@hotmail.com','jordi monfort','Pere Gil nº13, 1º-B','vila-real','Comunidad Valenciana','SPAIN','12540','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-07 20:02:32',0,NULL,3,1,11,1,NULL,'不挂号  '),(21044,769438266018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','gopant','juanjogom@gmail.com','Juan Jose Gomez Pantion','C/Primavera, 10','Palomares del Rio (Sevilla)','Andalucía Ceuta y Melilla','SPAIN','41928','600932205','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-07 20:10:48',0,NULL,3,1,11,1,' ','不挂号  '),(21045,808706598002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','aleksandra1239','buyalex@mail.ru','Oleksandra Mursalimova','Hvoynyy side-st.12/39','Odessa','Odessa','UKRAINE','65059','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 21:27:36',0,NULL,3,1,11,1,NULL,'不挂号  '),(21046,765487239001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','tomtefoto','bruno.johannesson@gmail.com','Bruno Johannesson','Overvagen 10','Mantorp','','SWEDEN','59019','0046 14221677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-07 21:42:25',0,NULL,3,1,3,1,'RA117768979CN ',NULL),(21047,905238852015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','thedanedk','sinklov@dbmail.dk','Uffe Sinklov','Traedrejerporten 45','Hvidovre','Denmark','DENMARK','DK-2650','45-36494953','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 21:52:25',0,NULL,3,1,11,1,NULL,'不挂号  '),(21048,765504927001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','blasterfilms2011','blasterfilms@hotmail.com','Virgilio (2-30491) Rodríguez','8400 NW 25th St<br>Ste 110','Doral','FL','UNITED STATES','33122-1530','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-07 22:13:55',0,NULL,3,1,1,1,NULL,NULL),(21049,905255478015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','naniyoforsyth','blackmegrim@hotmail.com','Heikki Mitikka','Hattelmalantie 5-7c 72','Helsinki','Other','FINLAND','00710','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-07 22:14:44',0,NULL,3,1,3,1,'RA117769002CN\r ',NULL),(21050,827651571017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','wong0786','kendorado@hotmail.com','wong ken','40,jalan lembing 3, taman puteri wangsa','johor bahru','johor','MALAYSIA','81800','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-07 22:53:44',0,NULL,3,1,11,1,NULL,'不挂号  '),(21051,769539374018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','lsjhgj','hojo@hunterlink.net.au','Howard Johnson','10 Lillypilly Drive','Maryland','New South Wales','AUSTRALIA','2287','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 22:59:31',0,NULL,3,1,11,1,NULL,'不挂号  '),(21052,808772302002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','wasabrindo','smith.david.t@gmail.com','David Smith','975 35th St','Richmond','CA','UNITED STATES','94805-1314','(510) 778-4278','NoPaymentFailure','CheckoutComplete','Other','2011-12-07 23:34:42',0,NULL,3,1,3,1,'RA117766187CN ','美标  '),(21053,769553623018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.8,'photographyacc','ashilleong','thecrypt4@hotmail.com','Jasmine Adams','10/265<br>Dugan Street','Kalgoorlie','Western Australia','AUSTRALIA','6430','0890222269','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-07 23:34:52',0,NULL,3,1,11,1,NULL,'不挂号  '),(21054,765559213001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','ckes04','chriskirsty@gmail.com','Chris Farrelly','13 Dunloe Ave','Mont Albert North','Victoria','AUSTRALIA','3129','0398490260','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 00:36:12',0,NULL,3,1,11,1,NULL,'不挂号  '),(21055,765565841001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','vince_pkr','vincentl_37@hotmail.com','Vincent Lainé','251-B ave St-Michel','Québec','QC','CANADA','g1c 1g4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 00:58:23',0,NULL,3,1,11,1,' ','不挂号 '),(21056,765591822001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','minghuyu','minghuyu@yahoo.com','michael yu','6 Edgeridge Gate, N.W.','Calgary','AB','CANADA','T3A 6H7','(403) 471-6718','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 02:27:41',0,NULL,3,1,11,1,NULL,'不挂号 '),(21057,769568835018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',12,'AKT007',240,'photographyacc','ddre9415','ardentmill@bigpond.com','D Drew','Ardent Mill  po box 62<br>720 Elliott Way','Tumbarumba','New South Wales','AUSTRALIA','2653','0448667883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-08 03:12:39',0,NULL,3,1,4,1,'YW867661341CN ','24个 \rD Drew\r720 Elliott Way \rTumbarumba NSW   ▲\rAustralia 2653\rAUSTRALIA\r0448667883'),(21058,808864823002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','odet63','meir9544@gmail.com','meir swisa','kibutz ortal d.n ramat hagolan','kibutz ortal','RAMAT HAGOLAN','ISRAEL','12430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 04:18:57',0,NULL,3,1,11,1,NULL,'不挂号 '),(21059,769655295018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','jaimeleenben','beach_bumm_17@hotmail.com','jaime lee stribley','126 southern river road<br>Gosnells','perth','Western Australia','AUSTRALIA','6110','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-08 05:07:18',0,NULL,3,0,11,1,NULL,'白色\r不挂号 '),(21060,808887392002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','joaoamericobrazil','joaoamericofotografia@gmail.com','João Américo M. Filippi','SQS 314 Bl. E Apto. 103','Brasília','DF','BRAZIL','70383-050','+55 61 8122-1111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 06:00:59',0,NULL,3,1,11,1,NULL,'不挂号 '),(21061,808893736002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','wajc','jim@chaffer.id.au','James Chaffer','34 Stock Road','Attadale','Western Australia','AUSTRALIA','6156','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 06:34:25',0,NULL,3,1,11,1,NULL,'不挂号 '),(21062,769696054018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','broadley210763','steve@scjhtbroadley.fsnet.co.uk','Steve Broadley','35 Green Hill Road','Grantham','Lincolnshire','UNITED KINGDOM','NG31 8AG','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 08:19:42',0,NULL,3,1,17,0,NULL,NULL),(21063,769697144018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','broadley210763','steve@scjhtbroadley.fsnet.co.uk','Steve Broadley','35 Green Hill Road','Grantham','Lincolnshire','UNITED KINGDOM','NG31 8AG','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 08:24:09',0,NULL,3,1,3,1,'RA117766522CN\r ','斜臂的夹子（单轮）   1\r斜臂     1\r'),(21064,905509184015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',44,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-08 09:45:13',0,NULL,3,1,3,1,'RA117766615CN ','4个\r申报$20 '),(21065,905524710015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','mrkiou','mrkiou+ebay@gmail.com','Quentin PYANET','557, Ch du Paradis','Villeneuve sous Pymont','Franche-Comté','FRANCE','39570','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 10:32:12',0,NULL,3,1,11,1,' ','不挂号  '),(21066,808952234002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','vensenn71','detka_741@mail.ru','Yuliya Martyshkova','7-37-55','Stepnogorsk','Akmola','KAZAKHSTAN','021500','87016433485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 10:37:28',0,NULL,3,1,8,1,'CP211275721CN ',NULL),(21067,887023324016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','jacek1702','fotojacek@gmail.com','Marian Pieciak','11 Laurelmount Avenue<br>Rock Road','Carrigaline','Cork','IRELAND','000','0214919720','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 10:39:21',0,NULL,3,1,3,1,'RA117766624CN ',NULL),(21068,765714135001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','zosakmatus85','zosak.matus@gmail.com','Roman Nemec (Zosak)','Halenarska 37','Trnava','Slovakia','SLOVAK REPUBLIC','91701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 10:52:42',0,NULL,3,1,3,1,'RA117766902CN ','4节 '),(21069,765717982001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 11:05:18',0,NULL,8,1,17,0,NULL,NULL),(21070,765717981001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 11:05:17',0,NULL,3,1,5,1,'CP240335056CN ',' 分开发\r发两票SAL'),(21071,808960479002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pavlo7032','pasha@graphiteconcept.com','Pavlo Kasprevych','79 Ak.Koroleva str. apt. 23','Odessa','Odessa','UKRAINE','65122','+380503164586','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 11:05:18',0,NULL,3,1,5,1,'CP240335060CN ','150-200cm 5in1 反光板    1\r反光板 100*150 40*60 5合1    1\r分开发\r发两票SAL\r'),(21072,905552275015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','bitphoenix','ebay@bitphoenix.com','Frode Løvbukten','Tofsrudveien 116','Fetsund','','NORWAY','1900','93861878','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 11:37:45',0,NULL,3,1,3,1,'RA117766638CN ','欧标 '),(21073,808970612002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','rhiannonelise83','rhiannon_elise@hotmail.com','Rhiannon Jordan','313 Coburns Rd, Melton West','Melbourne','Victoria','AUSTRALIA','3888','0403265358','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 11:38:12',0,NULL,3,1,4,1,'YW867738632CN ','▲ '),(21074,808927565002,120757472199,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT074',310,'hermeshine','mazaec','mazayec@yandex.ru','Igor Emelyanenko','Morisa-Toresa 33-32','Samara','Samarskaya obl','RUSSIAN FEDERATION','443093','+79276996022','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 11:41:43',0,NULL,3,1,5,1,'CP240335073CN ','欧标\r除了C里面的以外再发\r5灯头+60-90棚 放澳转欧标   1\r\r'),(21075,808927643002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','mazaec','mazayec@yandex.ru','Igor Emelyanenko','Morisa-Toresa 33-32','Samara','Samarskaya obl','RUSSIAN FEDERATION','443093','+79276996022','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 11:41:44',0,NULL,3,1,17,0,NULL,NULL),(21076,765755367001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','leofaquir','leonardobandeirademelloazevedo@gmail.com','Leonardo Azevedo','Estrada do Encanamento, 350 303b<br>Parnamirim','Recife','Pernambuco','BRAZIL','52060210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 13:08:48',0,NULL,3,1,3,1,'RA117766655CN\r ',NULL),(21077,827915830017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','martyparty8','marty_gregor@yahoo.com.au','Martin Gregor','2 Sydenham<br>Wellington Rd','Cork City','','IRELAND','default','0879402676','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 13:10:35',0,NULL,3,1,11,1,NULL,'不挂号  '),(21078,769773313018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','pikkabbu','pikkabbu@yahoo.es','Michel Henric Coll','NETWORK<br>Plaza Colegio Patriarca, 4 ptº 1','VALENCIA','Comunidad Valenciana','SPAIN','46004','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 12:42:27',0,NULL,3,1,3,1,'RA117766641CN ',NULL),(21079,905597746015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','buyer0011','matias@eertola.fi','Matias Eertola','Gesterbyntie 355 a','Kirkkonummi','','FINLAND','02400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 13:24:58',0,NULL,3,1,4,1,'YW867738643CN ','白加黑 \r▲'),(21080,809011942002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','itay357','itayhiba@gmail.com','Itay Hiba','Hanapach<br>16','Holon Industrial Zone','center','ISRAEL','58818','972-54-4388674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 13:40:38',0,NULL,3,1,3,1,'RA184556504CN\rRA184556495CN\r ',' 分开发  两票  '),(21081,905610553015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','nicholasseymour','nickseymour@gmail.com','Nick Seymour','127 Boundary Road','Newbury','Berkshire','UNITED KINGDOM','RG14 7NT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 13:55:27',0,NULL,3,1,4,1,'YW867738654CN ','白色背景布\r英标 \r▲'),(21082,905624556015,250939650586,'Mini IR Wireless Remote Control for Pentax 200D 10D 20D',1,'AD1118',2.18,'hutongstore','big-beavis','d.bateman@tiscali.co.uk','John Bateman','35. Fitz Road','Cockermouth','Cumbria','UNITED KINGDOM','CA130AN','01900822459','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 14:23:04',0,NULL,3,1,11,1,' ','不挂号  '),(21083,765787672001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','armin1angel','zsuzskaangel@freemail.hu','Zsuzsanna Rámháp','Gesztenye sor 4<br>Fertőszentmiklós','Győr Moson Soprin','','HUNGARY','H-9444','0036304497560','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-08 14:37:19',0,NULL,8,1,17,0,NULL,NULL),(21084,809037256002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','armin1angel','zsuzskaangel@freemail.hu','Zsuzsanna Rámháp','Gesztenye sor 4<br>Fertőszentmiklós','Győr Moson Soprin','','HUNGARY','H-9444','0036304497560','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 14:47:56',0,NULL,3,1,5,1,'CP240335087CN ','背景架2mx2m  + 3个夹子   1\r背景布 1.6  *3m 黑色  1\r1.6*2.1m  黑加白\r '),(21085,827977674017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','radonja78','jomatkov@inet.hr','josko matkovic','Sv. Lovre 45','Stobrec','croatia','CROATIA','21311','0038521326405','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-08 15:34:08',0,NULL,3,0,3,1,'RA117766575CN ','3XL 已入库 '),(21086,765813932001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','suku5785','sukumar5785@gmail.com','Sukumar Ramachandran','3030 Pembina Hwy<br>Apt 210','Winnipeg','MB','CANADA','R3T4K4','(204) 894-5943','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 15:39:52',0,NULL,3,1,11,1,NULL,'不挂号  '),(21087,809081644002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jorniboy1989','jorniboy89@gmail.com','jørn edvardsen','Balsfjordvinden 20','tromsø','tromsø','NORWAY','9006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 16:29:04',0,NULL,3,1,3,1,'RA117766757CN ','申报$30 '),(21088,809065383002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','fjpiqueras','superkco@hotmail.com','Fco Javier Piqueras','C/ Neptuno 63, 4ºC','Valdemoro','Madrid','SPAIN','28341','607723932','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 15:54:01',0,NULL,3,1,3,1,'RA117766669CN ',NULL),(21089,905761402015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','chriward1','chris-ward0911@hotmail.com','chris ward','58 cambridge rd','dorchester','Dorset','UNITED KINGDOM','dt1 2ls','01305265596','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-08 18:17:30',0,NULL,3,1,3,1,'RA117766672CN ',NULL),(21090,765923666001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','chekhova2011','chekhova84@mail.ru','Galina Chekhova','Dorojnikov home17 apartment 2','Karasu ','Kostanay','KAZAKHSTAN','111000','87145221816','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 19:14:11',0,NULL,3,1,11,1,'、 ','不挂号  '),(21091,765951592001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','bigtimevolunteer','rutens@comcast.net','dee ann rutens','321 Brawood Dr','mobile','AL','UNITED STATES','36608-1535','(261) 342-5753','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-08 19:58:02',0,NULL,3,1,1,1,NULL,NULL),(21092,765953388001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','thedyman','rdye@dymanvisions.com','Richard F Dye','4509 N O Connor Rd<br>Apt 1130','Irving','TX','UNITED STATES','75062-3706','(214) 417-6007','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-08 20:01:07',0,NULL,3,1,1,1,NULL,NULL),(21093,809206169002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','draco2999','fboccabella3@gmail.com','Francis Boccabella III','200 Elmwood Dr','Clifton','NJ','UNITED STATES','07013-1130','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-08 20:16:09',0,NULL,3,1,1,1,NULL,NULL),(21094,765998370001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','acayoung01','acayoung@iinet.net.au','Alex Young','63 Dickson Pl','Warriewood','New South Wales','AUSTRALIA','2102','0299966674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 21:17:21',0,NULL,3,1,17,0,NULL,NULL),(21095,765997929001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'',68.99,'hermeshine','acayoung01','acayoung@iinet.net.au','Alex Young','63 Dickson Pl','Warriewood','New South Wales','AUSTRALIA','2102','0299966674','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 21:17:22',0,NULL,3,0,3,1,'RA117766730CN ','肥皂盒 柔光罩  430EX   1 \r2m灯架     1\r云台    1\r80cm 伞式柔光箱8角     1'),(21096,766001040001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','tmcf4091','tmcfarland@strongtie.com','Trisha McFarland','4613 Rustic Ridge Drive','McKinney','TX','UNITED STATES','75071','(214) 738-2520','NoPaymentFailure','CheckoutComplete','Other','2011-12-08 21:19:04',0,NULL,3,0,1,1,' ','L  已入库 '),(21097,809263700002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','lillt11','lill.t.tesdal@gmail.com','Lill Tesdal','vadmyra 36','bergen','','NORWAY','5172','91700907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-08 21:43:06',0,NULL,3,1,11,1,'、 ','不挂号 '),(21098,905964460015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.9,'hutongstore','spiceyone62','isleoffspice4@btinternet.com','geoff williams-thomas','32 Birchs Close<br>Hockliffe','Leighton Buzzard','Bedfordshire','UNITED KINGDOM','lu7 9lu','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-08 22:49:48',0,NULL,3,1,3,1,'RA117766686CN\r ',NULL),(21099,905988313015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','sunepopp','sp@sunepopp.dk','Sune Popp','Frederiksgårds Alle 8b, 2. th','Vanløse','','DENMARK','2720','60931216','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-08 23:37:52',0,NULL,3,1,3,1,'RA117766690CN ',NULL),(21100,826461516017,270759687007,'New soft box photography studio continue lighting Set ',1,'AKT016',95,'photographyacc','2011rachael86','rachael_mcgowan@hotmail.com','Rachael McGowan','32 Redbank Rise','Clarkson','Western Australia','AUSTRALIA','6030','0423632041','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-09 00:11:21',0,NULL,3,1,4,1,'YW867738665CN ','澳标\r▲'),(21101,906011354015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','hedge69er','hedge69@sky.com','Mr Stephen Whatley','16 Winchester Street','Overton','Hampshire','UNITED KINGDOM','RG25 3HS','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-09 00:33:47',0,NULL,3,1,4,1,'YW867738676CN ','黑加白 \r▲'),(21102,906022223015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','hellboy95','sergedealmeida95@gmail.com','serge de almeida','6 avenue du parc','Saint leu la foret','Ile-de-France','FRANCE','95320','0663666822','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 01:00:02',0,NULL,3,1,3,1,'RA117766567CN ',NULL),(21103,906024490015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','bugsbunny74','craigandsuz@gmail.com','Craig Davidson','80 The Hollies<br>Quakers Yard','Treharris','Mid Glamorgan','UNITED KINGDOM','CF46 5PP','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-09 01:05:58',0,NULL,3,1,4,1,'YW867738680CN ','英标 \r▲'),(21104,809378121002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','tim14536666','autract@yahoo.fr','BULDUK MUSTAPHA ;TBM electro sprl','rue verbist n3<br>tva BE 0474.838.061','bruxelles','','BELGIUM','1210','02-2190108','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 02:47:19',0,NULL,3,1,3,1,'RA117766743CN ',NULL),(21105,765025941001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',5.49,'hermeshine','christoper','chris@chrisabuchanan.com','christopher Buchanan','9312 Macswain Pl','Springfield','VA','UNITED STATES','22153-3901','(510) 703-0798','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-09 02:53:44',0,NULL,3,1,1,1,'\\ ',NULL),(21108,809396740002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','killerbee.kst','kornpae@hotmail.com','Warakorn Sae-Tang','487/13 Soi. Jomsomboon, Rama 4 Road','default','BA','THAILAND','10500','+66819249281','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 03:53:00',0,NULL,3,1,11,1,NULL,'不挂号 '),(21106,827873463017,270747070620,'New Neoprene Neck Shoulder Strap for Nikon SLR camera',1,'AB1403',5.08,'photographyacc','pqbay10','pqbay10@gmail.com','Quy  Nguyen','22 macauley Ave','Bankstown','New South Wales','AUSTRALIA','2200','0414275164','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-09 03:04:31',0,NULL,3,1,11,1,NULL,'不挂号 '),(21107,828335466017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','lachsy555','lachsy2@hotmail.com','deb lachs','29 Smith Lane','Yackandandah','Victoria','AUSTRALIA','3749','0260271978','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-12-09 03:18:13',0,NULL,3,1,4,1,'YW867738621CN ','▲ '),(21109,766177716001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','iamlado','vorobyevvladimir@mail.ru','Vladimir Vorobyev','Mira 34/1 kv.11<br>tel +7 (701) 747-69-20','Astana','Aqmola obl','KAZAKHSTAN','010000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 06:41:28',0,NULL,3,1,3,1,'RA117766805CN ','4节 '),(21110,8881323414006477,111,'2m 灯架最上面那个配件',1,'',0,'hutongstore','go2he11','shutnik.08@mail.ru','Utegenov Sagadat','Bekhozhina 15-164','Pavlodar','','KAZAKHSTAN','140000','',NULL,NULL,NULL,'2011-12-09 07:00:06',0,NULL,3,1,8,1,'CP211275474CN ','再加一块3mx6m 绿色背景布\r2m 灯架最上面那个配件\r'),(21111,766197431001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','55991999','emienuff4u@aol.com','jonathan frassetti','133 heulitt rd','colts neck','NJ','UNITED STATES','07722-1487','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 08:18:53',0,NULL,3,1,3,1,'RA117765062CN\r ',NULL),(21112,809462142002,120451748471,'YN462 YN-462 Flash Speedlite for Canon 450D 400D 350D ',3,'AB3305',95.4,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 08:47:33',0,NULL,8,1,17,0,NULL,NULL),(21113,809463604002,120770714159,'New 400w Photo Studio Mini Flash Kit with Flash Trigger',3,'AKT083',690,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 08:53:07',0,NULL,3,1,12,1,'3435990666\r ','除了C 3套外\r闪光的柔光箱   50cm  2 \r永诺闪光灯  YN462     3\r绿叶 UV  58mm    5\r绿叶 UV   52mm    5\r绿叶 UV  77mm   3\r独脚架  伟峰 WT-1003     1\r帽子 canon      2\rCANON 镜头盖  72mm   2\r4个大小的镜头筒   2套\r1.6m x 3m 背景布   6    （蓝色, 绿色,灰色 \r各2块)\rCANON 镜头盖  77mm     3\rCANON 镜头盖  67mm    2\rCANON 镜头盖  58mm     6\r橡胶遮光罩 58mm    4\r摄影背心 黑色厚 无字  XXL   2(已入库）\r摄影背心 黑色厚 无字 XL      2\r实重28.9  泡重32\r计费重量：33\r'),(21114,766206775001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',2,'AB3328',91.98,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 09:00:31',0,NULL,8,1,17,0,NULL,' '),(21115,828113256017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',127.9,'photographyacc','klim_buyer','mailto@i.ua','Klim Ivantsov','ul. Teatralnaya, dom 5, kv. 35','Dnepropetrovsk','Dnepropetrovskaya oblast','UKRAINE','49047','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-09 09:00:48',0,NULL,3,1,5,1,'CP211275718CN ','灯架  2m   2 \r柔光箱 50-70cm 单灯头   2    欧标\r115w 5500k 灯泡  220v   2\r灯架包     1\r眼罩 450D/500D   1\r已入库'),(21116,8881323421879650,111,'配4灯头的50-70柔光箱',2,'',0,'hutongstore','andreassoufis','andreassikkis@gmail.com;','Andreas Sikkis','Georgiou pop 9','Athens','Attica ','GREECE','11525','',NULL,NULL,NULL,'2011-12-09 09:11:19',0,NULL,3,1,3,1,'RA117765133CN\r ',NULL),(21117,906196705015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','asiernineu','asierizquierdo@hotmail.com','ASIER IZQUIERDO AGUILERA','TXORIERRI 35 1º DRCHA','LEIOA','País Vasco','SPAIN','48940','625700356','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 09:58:49',0,NULL,3,1,4,1,'YW867738691CN','黑加白 \r▲\r'),(21118,809497466002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','snowparking','snowpark@land.ru','Ivan Shilov','Gazovicov 2-9','Polazna','Perm','RUSSIAN FEDERATION','618703','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-09 10:55:50',0,NULL,3,1,5,1,'CP211275695CN ',NULL),(21119,766240387001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',2,'AA2114',64,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 11:04:04',0,NULL,8,0,17,0,NULL,' '),(21120,766241756001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',2,'AA2114',64,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 11:06:40',0,NULL,8,1,17,0,NULL,NULL),(21121,766243839001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',4,'AB1303',13.36,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:15:44',0,NULL,8,1,17,0,NULL,NULL),(21122,809502292002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',6,'AA1301',15.6,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:19:40',0,NULL,8,1,17,0,NULL,NULL),(21123,809502396002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',2,'AA1302',5.2,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:19:41',0,NULL,8,1,17,0,NULL,NULL),(21124,766243231001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',3,'AA1304',7.8,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:19:41',0,NULL,8,1,17,0,NULL,NULL),(21125,809506488002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',6,'AO0005',108,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:27:18',0,NULL,8,0,17,0,NULL,NULL),(21126,809507835002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',2,'AKT086',29.98,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:30:53',0,NULL,8,1,17,0,NULL,NULL),(21127,809508691002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','sunny.claudia','snnclaudia@gmail.com','verry jap','7537 Davies Street','burnaby','BC','CANADA','v3n3h2','(778) 788-6118','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:34:07',0,NULL,3,0,3,1,'RA184556416CN\r ','1.6x3m 白色 '),(21128,809502378002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5.2,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:19:40',0,NULL,8,1,17,0,NULL,NULL),(21129,766249557001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:37:18',0,NULL,8,1,17,0,NULL,NULL),(21130,766250619001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:38:36',0,NULL,8,1,17,0,NULL,NULL),(21131,766251101001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 11:41:23',0,NULL,8,1,17,0,NULL,NULL),(21132,766253315001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',3,'AA3307',14.7,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:47:58',0,NULL,8,1,17,0,NULL,NULL),(21133,809512448002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3301',16.25,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:47:58',0,NULL,8,1,17,0,NULL,NULL),(21134,766253297001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',5,'AA3303',17.75,'hermeshine','ahmedphotobh','ahmedphoto@live.com','sayed ahmed almosawi','4239','alduraz','alduraz','BAHRAIN','973','0097339747573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:47:59',0,NULL,8,1,17,0,' ',NULL),(21135,809514316002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','rvk1988','belnezer@gmail.com','Rivka Ariel','Harav Nerya 120','Dolev','Dolev','ISRAEL','71935','029975977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 11:51:07',0,NULL,3,1,3,1,'RA184556420CN\r ',NULL),(21136,766263885001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','ifinderlaposte','ifinder@laposte.net','GALERIE ESTAMPE MODERNE ET SPORT','P-A JULLIEN - 16 rue CHORON<br>16 rue CHORON','PARIS','ILE-DE-FRANCE','FRANCE','75009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 12:19:13',0,NULL,3,1,3,1,'RA184556433CN\r ',NULL),(21137,906260230015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',5,'AE3401',79.95,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 12:42:36',0,NULL,3,1,4,1,'YW867738702CN ','▲ '),(21138,906265722015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','davy793','david.garmont@tiscali.co.uk','DAVID GARMONT','60 STATION ROAD<br>CHISELDON','SWINDON','Wiltshire','UNITED KINGDOM','SN4 0PW','07808386867','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-09 12:53:06',0,NULL,3,1,3,1,'RA184556447CN\r ',NULL),(21139,809538496002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'AD1200',55,'hermeshine','sergbodr1969','sergbodr@gmail.com','Sergey Bodryagin','4 distr. 21 h. 59 ap.','Aktau','Mangistau','KAZAKHSTAN','130000','+77012099595','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:01:41',0,NULL,3,1,3,1,'RA184556668CN\r ',NULL),(21140,766278052001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','netjas','jan@janschmidt.dk','Jan Schmidt','Kærskiftevej 215','Valby','','DENMARK','2500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:01:59',0,NULL,3,1,3,1,'RA184556362CN\r ',NULL),(21141,766281616001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','blayk69','novura@mail.ru','Yuriy Novikov','67 Neplanovaya','Zherdevka','Tambovskaya region Zherdevskiy district','RUSSIAN FEDERATION','393670','+79108589437','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:13:33',0,NULL,3,1,11,1,NULL,NULL),(21142,809543734002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','berendsenpeter','berendsenpb@hotmail.com','PETER berendsen','35 ranfordstreet','perth,kelmscott','Western Australia','AUSTRALIA','6111','0419190134','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 13:17:16',0,NULL,3,0,3,1,'RA184556742CN\r ','XL   （已入库） '),(21143,906129428015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','randotomson','rando57@hotmail.com','rando tomson','Uusmaa tee 1/3-15<br>Peetri küla','Rae vald','Harju maa','ESTONIA','75312','+3725090297','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 13:34:01',0,NULL,3,1,5,1,'CP211275704CN ',NULL),(21144,809552358002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','arcangel084','glamdirel@hotmail.com','Juan Miguel Saval catalan','C/ Secretario Juan Antonio Baldovi n15  1º A','Benidorm','Comunidad Valenciana','SPAIN','03502','658389777','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 13:40:04',0,NULL,3,1,3,1,'RA184556708CN\r ','申报 tripod  $20 '),(21145,766293695001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','audiofile50','sonjaandfred@iinet.net.au','Fred Wettermann','48 Gardon Rise','Gwelup','Western Australia','AUSTRALIA','6018','0894451458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:48:06',0,NULL,3,1,17,0,NULL,NULL),(21146,906300212015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ze.bicho','jose.carlos.bicho@gmail.com','José Neto','Rua dos Bombeiros voluntários, Lote 37 1º Ft.','Vendas Novas','Vendas Novas','PORTUGAL','7080','962706869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 14:09:09',0,NULL,3,1,3,1,'RA184556610CN\r ',NULL),(21147,809551265002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ermaher','eru.ermahe@gmail.com','Maher Fernandez','c Emiliano Barral n.4-A, 3º-A','MADRID','Madrid','SPAIN','28043','636920710','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 13:36:18',0,NULL,3,1,3,1,'RA184556623CN\r ',NULL),(21148,809565860002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','audiofile50','sonjaandfred@iinet.net.au','Fred Wettermann','48 Gardon Rise','Gwelup','Western Australia','AUSTRALIA','6018','0894451458','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 14:21:53',0,NULL,3,1,11,1,NULL,' 肩带 nikon    1\r圆形柔光棚 50cm      1\r'),(21149,766313547001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','gloggnitz0','k.samitsch@aon.at','Karl Samitsch','Rosenhügelgasse 8','Gloggnitz','','AUSTRIA','2640','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 14:38:41',0,NULL,3,1,11,1,NULL,NULL),(21150,809600450002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','fuzzbutt99','kellyhicks@gmail.com','Kelly Hicks','121 englewood rd','Cammack Village','AR','UNITED STATES','72207-1801','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 15:36:40',0,NULL,3,1,3,1,'RA184556637CN\r ',NULL),(21151,766398925001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','mcdebugger','mc_debugger@mail.ru','Maxim Kachur','Volodarskogo ul; d. 34-A; kv. 76','Ivanovo','Ivanovskaya obl','RUSSIAN FEDERATION','153022','+79023150144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 17:44:49',0,NULL,3,1,3,1,'RA184556645CN\r ','8个   看会不会超重 \r1.642'),(21152,766403887001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','lucaarpaia','luca@isinet.it','Montecucco Enrica','via dell\'ardenza, 57','Livorno','LI','ITALY','57128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 18:22:44',0,NULL,3,1,11,1,NULL,NULL),(21153,809684557002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','chalkkos030','chalkkos@gmail.com','KOSTAS CHALKIADAKIS','6, STERGIOGIANNI st.','HERAKLION CRETE','','GREECE','71305','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 18:26:47',0,NULL,3,1,4,1,'YW867738713CN ','▲'),(21154,809706133002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','wihanto','wyomingkellys@yahoo.com','kevin kelly','26626 Glen Oak Dr','Wyoming','MN','UNITED STATES','55092-8338','','NoPaymentFailure','CheckoutComplete','Other','2011-12-09 19:04:02',0,NULL,3,0,1,1,NULL,'XL  (已入库） '),(21155,809718276002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',11.99,'hermeshine','burtonrider52','burtonchikk42@yahoo.com','Bob LaBarge','16 Phillips St','Massena','NY','UNITED STATES','13662-2076','(315) 769-9935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 19:22:36',0,NULL,3,1,1,1,NULL,NULL),(21156,766468676001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','fotozoom60','andrvil60@mail.ru','DMITRIY VYALOV','Kovalihinskaya street, 77-91','N. NOVGOROD','NIGEGORODSKAYA OBLAST','RUSSIAN FEDERATION','603155','(960)1962733','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 20:00:46',0,NULL,3,1,17,0,NULL,NULL),(21157,766476202001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','fotozoom60','andrvil60@mail.ru','DMITRIY VYALOV','Kovalihinskaya street, 77-91','N. NOVGOROD','NIGEGORODSKAYA OBLAST','RUSSIAN FEDERATION','603155','(960)1962733','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-09 20:04:52',0,NULL,3,1,3,1,'RA184556654CN\r ','ks-0 III (白盒）  1 \r肩架    1'),(21158,906527443015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','sweetev','eva.kirst@webmail.de','Tanja Hoefliger','Bruckwiesenweg 26','Fellbach','','GERMANY','70734','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 20:07:41',0,NULL,3,1,4,1,'YW867738724CN ','白+黑 \r▲'),(21159,906532506015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','sampsaj','sampsa@patagonia.fi','Sampsa Jyrkynen','Niittaajankatu 6 B 16','HELSINKI','','FINLAND','00810','358445768976','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 20:15:01',0,NULL,3,1,11,1,NULL,NULL),(21160,809789662002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','thiago_miller','thiago_miller@hotmail.com','Thiago Miller','Rua Maria Borba, N°67, AP 86','São Paulo','SP','BRAZIL','01221040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 21:30:15',0,NULL,3,1,11,1,NULL,NULL),(21161,906610009015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','thedanedk','sinklov@dbmail.dk','Uffe Sinklov','Traedrejerporten 45','Hvidovre','Denmark','DENMARK','DK-2650','45-36494953','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 22:11:13',0,NULL,3,1,11,1,NULL,NULL),(21162,888072231016,260901272165,'New Mini IR Wireless Remote Control for Olympus E520E E420',1,'AD1119',2.18,'hutongstore','ludopyt','ludopyt@hotmail.com','Ludovic Pytkowski','24 rue des maraichers','STAINS','Ile-de-France','FRANCE','93240','0664355202','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-09 22:18:27',0,NULL,3,1,11,1,NULL,NULL),(21163,766547472001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','camvanae','amoss28@yahoo.com','Andy Moss','11049 Brandywine Lake Way','Boynton Beach','FL','UNITED STATES','33473','(561) 302-7576','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-09 22:22:47',0,NULL,3,1,1,1,NULL,NULL),(21164,888119140016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','pr9865','fm70714@hotmail.com','Fernando  Mandry','Ciudad Universitaria<br>R-4 Calle 20','Trujillo Alto','PR','UNITED STATES','00976-3143','787 593 1002','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-09 23:58:01',0,NULL,3,1,3,1,'RA184556566CN\r ',NULL),(21165,766578973001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-09 23:45:03',0,NULL,3,1,17,0,NULL,NULL),(21166,809856282002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 00:09:05',0,NULL,3,1,17,0,NULL,NULL),(21167,809863912002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 00:28:06',0,NULL,3,1,3,1,'RA184556570CN\r ','单灯头   1  欧标\r沙袋（普通）       1\r50-70柔光棚 通用塑料卡口    1\r\r'),(21168,770679876018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','jenci','gene.nemeth@verizon.net','Gene Nemeth','415 Thornden St','South Orange','NJ','UNITED STATES','07079-1423','(973) 762-8620','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-10 01:28:24',0,NULL,3,0,17,0,NULL,NULL),(21169,770680709018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','jenci','gene.nemeth@verizon.net','Gene Nemeth','415 Thornden St','South Orange','NJ','UNITED STATES','07079-1423','(973) 762-8620','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-10 01:31:34',0,NULL,3,1,1,1,NULL,'摄影背心（河北，厚）nikon XXL   1   已入库\r6片装的滤镜袋     1'),(21170,809889216002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','daid2711','floyd2711@hotmail.com','Denis Daigle','1684 D\'Aquitaine','Terrebonne','QC','CANADA','J6W 5Z2','(450) 326-1553','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 01:50:27',0,NULL,3,1,11,1,NULL,NULL),(21171,809912942002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','zdog91','chrisrathburn@sbcglobal.net','Chris Rathburn','259 Fairground Rd','Bradford','VT','UNITED STATES','05033-9041','(817) 277-7436','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-10 03:10:46',0,NULL,3,1,1,1,NULL,NULL),(21172,828913321017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','liliannx3','lilyy_92@live.com','Lily Beeley','46 Hutton Road','Aspley','Queensland','AUSTRALIA','4034','0422461947','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-10 03:53:26',0,NULL,3,1,11,1,' ','澳标 '),(21173,906782801015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','icieling','icie.eici@gmail.com','Isaac M Leung','3 Foxwood Way','Cherrybrook','New South Wales','AUSTRALIA','2126','0419043563','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 06:05:54',0,NULL,3,1,3,1,'RA184556597CN\r ',NULL),(21174,766683196001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','mikegerch','m-s-g@live.com','Michael Gerchikov','120 Shelborne ave<br>Apt# 1012','Toronto','ON','CANADA','M6B 2M7','(647) 346-1127','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 06:46:45',0,NULL,3,1,11,1,NULL,NULL),(21175,761986759001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','oluwafemiainajohnson','omolaraainajohnson@hotmail.co.uk','OMOLARA AINA-JOHNSON','47,  ASHBROOK','ORANMORE','GALWAY','IRELAND','','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 09:18:17',0,NULL,3,1,11,1,NULL,NULL),(21176,906861958015,250599407365,'Green.L 72mm 72 Neutral Density ND4 Filter ND 4 New',1,'AE2306',4.3,'hutongstore','carcasg','carcasg@terra.es','JOSE CARLOS CASTRO GARCIA','C/ABANDOLA, 2, 1ºB','VELEZ-MALAGA','Andalucía Ceuta y Melilla','SPAIN','29700','652837198','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 10:25:42',0,NULL,3,1,17,0,NULL,NULL),(21177,906869348015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','carcasg','carcasg@terra.es','JOSE CARLOS CASTRO GARCIA','C/ABANDOLA, 2, 1ºB','VELEZ-MALAGA','Andalucía Ceuta y Melilla','SPAIN','29700','652837198','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-10 10:43:27',0,NULL,3,1,3,1,'RA184556583CN\r ','绿叶 ND4  72mm  1 \r伞式柔光箱 60×90cm    1'),(21178,810062720002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','theabbd2','leventeleevi@gmail.com','Evgeny Yurov','pr-t. Stroiteley 18-136','Engels','Saratovskaya obl','RUSSIAN FEDERATION','413111','89518832522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 12:37:28',0,NULL,3,1,5,1,'CP211275681CN ',' '),(21179,810067077002,120826071684,'New designed Professional 50cm 20\" Softbox soft box for Speedlite SB900 580EX',1,'AD1212',52,'hermeshine','gsfproduction','gsfproduction@gmail.com','shay sheleg','arlozorov 11','netania','israel','ISRAEL','42362','0507346138','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 12:51:46',0,NULL,3,1,3,1,'RA184556725CN\r ','记一下最终的重量 \r887g\r'),(21180,770869604018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','dragonmaster51','rwillett29@hotmail.com','Robert Willett','5/10 Canton St<br>Canterbury','Sydney','New South Wales','AUSTRALIA','2193','61417402053','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-10 12:54:46',0,NULL,3,1,11,1,NULL,NULL),(21181,906928564015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','relisys1476','orawski@poczta.onet.pl','sebastian orawski','86A North Bridge Street','Bathgate','West Lothian','UNITED KINGDOM','EH48 4PN','01506638036','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 12:54:54',0,NULL,3,1,11,1,NULL,NULL),(21182,766789436001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','dragonmaster51','rwillett29@hotmail.com','Robert Willett','5/10 Canton St<br>Canterbury','Sydney','New South Wales','AUSTRALIA','2193','61417402053','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 12:58:21',0,NULL,3,1,3,1,'RA184556521CN\r ',NULL),(21183,770872209018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','rg.wild','rg_rgb@iinet.net.au','Linda Wild','5 Burra Court','Clarkson','Western Australia','AUSTRALIA','6030','0417020558','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-10 13:05:00',0,NULL,3,1,4,1,'YW867738735CN ','白加黑 \r▲'),(21184,829106299017,270777043723,'Video 2400w Red Head Continuous Lighting Kit 800w x 3',1,'AKT072',299,'photographyacc','brucewayne1989','randallica1989@hotmail.com','Randall Evans','11 Bradman Street','Greystanes','New South Wales','AUSTRALIA','2145','0404322044','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-10 14:19:49',0,NULL,3,1,4,1,'YW867738746CN ','澳标 \r▲'),(21185,907013002015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','frankiebaby2008','catherinebalavage@googlemail.com','Catherine Hall','2 Wharncliffe Drive,','Hanwell','London','UNITED KINGDOM','UB1 3EP','01698732066','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-10 15:28:45',0,NULL,3,1,12,1,'3435990681\r ','英标 \r11.2\r泡重12.96\r计费重量：12.5\r'),(21186,766880944001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','studioplusrajeshwar','rajeshnabab@yahoo.com','Rajeshwar Nabab','First Road','Fond Du Sac','Pamplemouses','MAURITIUS','0001','2307540527','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-10 16:17:33',0,NULL,3,1,3,1,'RA184556535CN\r ',NULL),(21187,810183563002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',11.99,'hermeshine','bryceschroeder','bryce.schroeder@gmail.com','Bryce Schroeder','3200 Stones Throw Ln<br>Apt 4','Durham','NC','UNITED STATES','27713-2240','(530) 763-3064','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-10 16:54:49',0,NULL,3,1,1,1,NULL,NULL),(21188,907061311015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','sjaychauhan','sjaychauhan@hotmail.com','Sanjay Chauhan','9 Crantock Close','Leicester','Leicestershire','UNITED KINGDOM','LE5 6XG','01162206033','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 16:42:53',0,NULL,3,1,11,1,NULL,NULL),(21189,907124253015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',1.6,'hutongstore','sam-thomas','samthomsa@gmail.com','Sam Thomas','4 The Waltons<br>Great Ayton','Middlesbrough','Cleveland','UNITED KINGDOM','TS9 6HX','01642724444','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 18:08:38',0,NULL,3,1,11,1,NULL,NULL),(21190,829246511017,270755378942,'4 Bulb Stocks with 24x24\"/60x60cm Folding Easy Soft box',1,'AE2201',38,'photographyacc','godonya','hag@satlink.com.au','Haydn Godony','PO Box 705','Mornington','Victoria','AUSTRALIA','3931','0359751676','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-10 18:18:25',0,NULL,8,1,17,0,NULL,NULL),(21191,771040444018,280774575807,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',23,'photographyacc','godonya','hag@satlink.com.au','Haydn Godony','PO Box 705','Mornington','Victoria','AUSTRALIA','3931','0359751676','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-10 18:20:09',0,NULL,3,1,3,1,'RA184556739CN\r ','4灯头 灯头 孔  澳标   1 \r60cmx60cm 的柔光箱（配4灯头）    1\r灯架 84cm    1\r'),(21192,771098962018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.99,'photographyacc','rampho','rampho@juno.com','Ramfis Campiz','2880 Mandarin Meadows Dr N','Jacksonville','FL','UNITED STATES','32223-2633','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-10 20:02:58',0,NULL,3,1,1,1,NULL,NULL),(21193,810318598002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','kostas11100','olnov_11@list.ru','Konstantyn Olnov','Azovskaya 9k2 kv.15','Moscow','','RUSSIAN FEDERATION','117149','(985) 217-2948','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-10 20:34:21',0,NULL,3,1,3,1,'RA184556549CN\r ',NULL),(21194,888692618016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','stuartimoriarty','stuartimoriarti@talktalk.net','Stuart R Senior','13 Aintree Close,Kippax','Leeds','Yorkshire','UNITED KINGDOM','LS25 7HY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 20:53:28',0,NULL,3,1,11,1,NULL,NULL),(21195,0,120826219248,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','kalderaro','liorkk@gmail.com','Lior Kalderaro','Nurok Rabi 3/36','Ashkelon','Ashkelon','ISRAEL','888888','972-52-6095317','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-10 21:23:33',0,NULL,3,1,3,1,'RA184556552CN\r ',' '),(21196,888770787016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','tilli121','d-woods@virginmedia.com','diane woods','2 ashleigh avenue','wakefield','West Yorkshire','UNITED KINGDOM','WF29DA','01924366024','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-10 22:58:36',0,NULL,3,1,3,1,'RA184556464CN\r ',NULL),(21197,907346158015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',44,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-10 23:23:17',0,NULL,3,1,3,1,'RA184556478CN\r ','4个 \r\r申报  GBP 20.00 '),(21198,769797203018,280761998164,'Studio Continuous lighting kit 5 output light 45w bulbs x 10 equals 2000W output',1,'AKT090',350,'photographyacc','aleksi747','mirzo3@teaser.fr','Dr. Alexandre Serain Shuvaloff','CMPI 61 Bd Carnot','Le Vésinet','Ile-de-France','FRANCE','78110','33672573683','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 00:16:04',0,NULL,3,1,6,1,'10423111121200004\r ','整个订单:\r1- 5 x 2m 灯架\r2- 2 x 5灯头+60-90棚   欧标\r3- 3 x 斜壁\r4- 2 x 115w 220v\r5- 10x 45w 220v\r6- 灯架包  1\r已入库\r泡重16.3  实重13.15\r香港EMS\r'),(21199,810424653002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','phototech21','nexia777@yahoo.com','Zafar Khamdamov','21130 134th Ave N','Rogers','MN','UNITED STATES','55374-9598','(612) 703-7730','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 00:17:14',0,NULL,3,1,3,1,'RA184556376CN\r ',NULL),(21200,810424341002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','rzanini','zureta@gmail.com','Romulo Zanini de Gouveia Pinto','Rua Quintino Bocaiuva 131 ap. 61','Curitiba','PR','BRAZIL','80035090','+55 41 96119041','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 00:19:07',0,NULL,3,1,11,1,NULL,NULL),(21201,771262012018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',3,'AD1169',19.2,'photographyacc','rebelde_21','rivasosunadani@yahoo.es','daniel rivas osuna','paseo 22 julio 331 2º 2ª','terrassa','Cataluña','SPAIN','08225','665844612','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 01:29:12',0,NULL,3,1,11,1,NULL,NULL),(21202,767171834001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','rhoadog35','kevin@rhoadeskill.com','kevin rhoades','55 Poplar St<br>Apt 2A','brooklyn','NY','UNITED STATES','11201-6931','(917) 816-5445','NoPaymentFailure','CheckoutComplete','Other','2011-12-11 01:53:50',0,NULL,3,1,1,1,NULL,NULL),(21203,810496677002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',43,'hermeshine','topher4233','cguthrie001@columbus.rr.com','Chris Guthrie','22344 State Route 751','West Lafayette','OH','UNITED STATES','43845-9681','(740) 502-8221','NoPaymentFailure','CheckoutComplete','Other','2011-12-11 04:08:43',0,NULL,3,1,1,1,'','XXXL   (已入库) '),(21204,810504886002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','debju37p','juliemorton@clear.net.nz','Julie Morton','20 Hargest Crescent<br>St Clair','Dunedin','','NEW ZEALAND','9012','0276008573','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 04:40:12',0,NULL,3,1,11,1,NULL,' '),(21205,767218102001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','trinhv714','ttrinhv@att.net','vi trinh','749 N East St<br>Apt 180','anaheim','CA','UNITED STATES','92805','(714) 284-0819','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-11 04:42:46',0,NULL,3,1,1,1,' ','GGS 550D   1 \rEW-78D   1'),(21206,771320114018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','nettsy99','anocha_pa@hotmail.com','Anocha Patomnera','8/76 Rayongcondopex Tower F Moo 6<br>Sukumvit Rd.','Neon-Phra, Muang','Rayong','THAILAND','21150','66891739833','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-11 04:58:20',0,NULL,3,1,11,1,NULL,NULL),(21207,767232574001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','iron410','rfortin@wideopenwest.com','ROBERT FORTIN','5109 STONECROFT CT','HILLIARD','OH','UNITED STATES','43026-8670','(614) 582-4316','NoPaymentFailure','CheckoutComplete','Other','2011-12-11 05:45:57',0,NULL,3,1,1,1,NULL,'m\r '),(21208,771335734018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','5985rob','soul_man7@hotmail.com','Rob Randle','P.O.Box 3158','North Nowra','New South Wales','AUSTRALIA','2541','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 06:07:56',0,NULL,3,1,3,1,'RA184556518CN\r ',NULL),(21209,767242951001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','nhlane','nlane1@zoomtown.com','nathan lane','4336 marival way','mason','OH','UNITED STATES','45040-2864','(513) 309-3972','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-11 06:38:34',0,NULL,3,1,17,0,NULL,NULL),(21210,810530541002,120701787289,'GGS Glass LCD Screen Protector for Nikon D90 ',1,'AB2212',7.6,'hermeshine','nhlane','nlane1@zoomtown.com','nathan lane','4336 marival way','mason','OH','UNITED STATES','45040-2864','(513) 309-3972','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-12-11 06:38:35',0,NULL,3,1,17,0,NULL,NULL),(21211,810530543002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','nhlane','nlane1@zoomtown.com','nathan lane','4336 marival way','mason','OH','UNITED STATES','45040-2864','(513) 309-3972','NoPaymentFailure','CheckoutComplete','Other','2011-12-11 06:38:35',0,NULL,3,1,3,1,'RA184556787CN\r ','橡胶遮光罩 52mm    1\rGGS D90      1\r4灯头 灯头 孔      1\r\r '),(21212,771336416018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','kaneo33','kanenaaraat@yahoo.com','kane','14 Gawler st','Seaview Downs','South Australia','AUSTRALIA','5049','0419035412','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 06:11:16',0,NULL,3,1,3,1,'RA184556606CN\r ',NULL),(21213,765662008001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','earthsvirgo','desertrain31@hotmail.com','angela','PO Box 451','Moapa','NV','UNITED STATES','89025-0451','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-11 08:06:52',0,NULL,3,1,1,1,NULL,' 110v灯泡   '),(21214,771365904018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','annie_840_2','shultz28@hotmail.com','Rhiannon Atkinson','32 Woolmore Cross','Atwell','Western Australia','AUSTRALIA','6164','08949857774','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 08:26:14',0,NULL,3,0,11,1,NULL,'白色 \r新地址:\rRhiannon Atkinson\r9 Tanzanite Road\rAustralind WA 6233\rAUSTRALIA\r08949857774\r'),(21215,829597242017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',9,'photographyacc','gmc8172','opalservices@optusnet.com.au','Grant McDonald','7 Kennedy Place','Bacchus Marsh','Victoria','AUSTRALIA','3340','0353673600','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 08:39:04',0,NULL,3,1,11,1,NULL,NULL),(21216,810033614002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','claudio010367','claudio0103@gmail.com','Claudio Bassi','Motta 1a<br>Sant.Alberto','Ravenna','RA','ITALY','48123','3408560904','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 09:04:51',0,NULL,3,1,11,1,NULL,NULL),(21217,809260693002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','ranmo73','moranpl@012.net.il','ran moskovich','Hgaon 2/a','Pardes Hanna','israel','ISRAEL','37054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 09:08:47',0,NULL,3,1,3,1,'RA184556773CN\r ',NULL),(21218,810610838002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','brettyman13','bacooper@activ8.net.au','brett cooper','41 baileys rd ','parattah','Tasmania','AUSTRALIA','7120','0362541070','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 10:41:17',0,NULL,3,1,11,1,NULL,NULL),(21219,889047968016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','jokerk36','jokerk36@gmx.de','Denis Hoppe','Armyshop Lübeck<br>Warendorpstrasse 19c','Lübeck','','GERMANY','23554','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-11 11:10:23',0,NULL,3,1,4,1,'YW867738750CN ','欧标 \r▲'),(21220,907650157015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','jockspop','jsb@beechesdesign.co.uk','John Bellis','10 Six Acres<br>Radbrook Green,','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 6AF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 12:00:41',0,NULL,3,1,3,1,'RA184556699CN\r ',NULL),(21221,767372048001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','willysmile','fabienrabillard@ebuyclub.com','Fabien Rabillard','8 rue Nicolas  Boileau','CHOLET','Pays de la Loire','FRANCE','49300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 12:17:27',0,NULL,3,1,17,0,NULL,NULL),(21222,767369365001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','willysmile','fabienrabillard@ebuyclub.com','Fabien Rabillard','8 rue Nicolas  Boileau','CHOLET','Pays de la Loire','FRANCE','49300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-11 12:17:27',0,NULL,3,1,17,0,NULL,NULL),(21223,829716351017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',2,'AD1168',30,'photographyacc','sankacci','martin.cankov@gmail.com','Martin Cankov','760  Anzac  Pde<br>1','Maroubra','New South Wales','AUSTRALIA','2035','0401844972','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 12:36:41',0,NULL,3,1,3,1,'RA184556685CN\r ',NULL),(21224,810670299002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','v_lutsky','vitaly.lutsky@gmail.com','Vitaly Lutsky','st\' Ramat Motsa 27<br>apartment 3','Jerusalem','ISRAEL','ISRAEL','96771','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 12:37:34',0,NULL,3,1,11,1,NULL,NULL),(21225,810670986002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','franio-2007','franpnrua@gmail.com','Francisco Prada Nuñez','C/Campo Grande Nº86','La Rua De Valdeorras','Galicia','SPAIN','32350','988311224','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-11 12:37:40',0,NULL,3,1,3,1,'RA184556795CN\r ',NULL),(21226,767369887001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','willysmile','fabienrabillard@ebuyclub.com','Fabien Rabillard','8 rue Nicolas  Boileau','CHOLET','Pays de la Loire','FRANCE','49300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 12:17:28',0,NULL,3,1,3,1,'RA184556800CN\r ','爵影红外 5 in 1     1\r4螺丝井字扳手      1\r麂皮                         1\r\r '),(21227,767380365001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','pobaoill','obaoill@fsmail.net','PETER BOYLE','87 ARMAGH ROAD','NEWRY','Down','UNITED KINGDOM','BT356PW','02830257775','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-11 12:35:02',0,NULL,3,0,3,1,'RA184556711CN\r ','XXXL ( 已入库) '),(21228,889144303016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','licangelo','likangelo@yahoo.it','Hopeland di Bartolomeo Giuliano PI 03696360613','Via Vivaldi n°10','Marcianise','CE','ITALY','81025','3283829042','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-12-11 13:38:17',0,NULL,3,1,12,1,'3435990670\r ','欧标 \r实重  7.1   泡重8.9\r计费重量：8.5\r\r'),(21229,906245559015,250599945149,'New EyeCup for Nikon Af D80 D90 D200',1,'AA1203',1.85,'hutongstore','mrsgarybarlow','suehooke@hotmail.co.uk','sue hooke','30 avenue south<br>earl shilton','leicester','Leicestershire','UNITED KINGDOM','le9 7ab','01455841150','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 13:41:33',0,NULL,3,1,11,1,NULL,NULL),(21230,771528605018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',3,'AKT014',117,'photographyacc','seashaw34','shimtaw@gmail.com','Tim Shaw','5 Velda Close','Wishart','Queensland','AUSTRALIA','4122','0733496692','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 14:03:17',0,NULL,3,1,17,0,NULL,NULL),(21231,767439898001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',84.96,'hermeshine','c3md3r','cemilbelder@msn.com','cemal özbek','konarı köyü<br>aygaz otogaz istasyonu','safranbolu','karabük','TURKEY','78600','05444350631','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 14:23:52',0,NULL,3,1,5,1,'CP211275390CN ',NULL),(21232,907753041015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','croftcs','croftcs@gmail.com','John Murray','37 Pauls Croft,, Cricklade','Swindon','Wiltshire','UNITED KINGDOM','SN6 6AJ','01793750685','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 14:24:08',0,NULL,3,1,11,1,NULL,NULL),(21233,829763096017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',2,'AC3301',29.7,'photographyacc','seashaw34','shimtaw@gmail.com','Tim Shaw','5 Velda Close','Wishart','Queensland','AUSTRALIA','4122','0733496692','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 14:03:18',0,NULL,3,1,4,1,'YW867738761CN ','2B柔    3\r反光板  80cm 5合1     2\r▲\r '),(21234,767495449001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','fire252johan','fire9500@gmail.com','Johan Vercleyen','Voldersstraat 87','Geraardsbergen','','BELGIUM','9500','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-11 15:40:01',0,NULL,3,1,11,1,NULL,NULL),(21235,907872800015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','finkor01','flisty@hotmail.co.uk','Phyllis Braham','13 Town Fields','Sandbach','Cheshire','UNITED KINGDOM','CW11 4PH','01270765570','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 16:36:27',0,NULL,3,1,3,1,'RA184556380CN\r ',NULL),(21236,767567856001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','katarinca','primozic.k@gmail.com','Katarina Primozic','Nova pot 127d','Brezovica','Slovenia','SLOVENIA','1351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 17:08:40',0,NULL,3,1,5,1,'CP211275409CN ','欧标 '),(21237,810886361002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','181190sb','polipak_sb@mail.ru','Сергей Белоцерковский','Ю.Фучика, 4, 63','Орск','Оренбургская область','RUSSIAN FEDERATION','462403','89123574854','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 17:43:28',0,NULL,3,1,3,1,'RA184556671CN\r ','欧标 '),(21238,767718989001,110484388890,'New Camera Tripod Fancier FT-6662A with Ball head Bag ',1,'AE1601',60.99,'hermeshine','gonxvii','gonzalog_85@hotmail.com','Gonzalo Gómez','Avenida de America 4 6ºA','Madrid','Madrid','SPAIN','28028','917268477','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-11 19:19:59',0,NULL,3,1,3,1,'RA184556455CN\r ',NULL),(21239,908172658015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',58,'hutongstore','giggletots87','giggletots@hotmail.co.uk','Nicola Dolphin','215 Pilling Lane','preesall','Lancashire','UNITED KINGDOM','FY6 0HG','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-11 20:07:58',0,NULL,3,1,4,1,'YW867739660CN ','英标 \r▲'),(21240,811082519002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','mrstanleycup','mistered1204@rogers.com','Edward Lee','Suite #  14<br>435 Leinster Street','Woodstock','ON','CANADA','N4S 7G4','(226) 228-1204','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 20:11:14',0,NULL,3,1,11,1,NULL,NULL),(21241,830162638017,270862492371,'New Studio Lighting Kit Stands Large Carry Carrying Bag Material Oxford cloth',1,'AD1181',20,'photographyacc','angelajeanpurple','downings@bigpond.net.au','Angela Downing','133 Pebble Beach Boulevard<br>Meadow Springs','Perth','Western Australia','AUSTRALIA','6210','0895834400','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-11 20:22:15',0,NULL,3,1,11,1,NULL,'481g\r '),(21242,889593648016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','suklaamedia','kristian@suklaa.org','Kristian Tapaninaho','43 Manwood Road','London','London','UNITED KINGDOM','SE4 1AA','07867784083','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 20:13:55',0,NULL,3,1,3,1,'RA184556481CN\r ',NULL),(21243,908221738015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','ajavaim','vskabuki@gmail.com','Valerijs Sidoriks','21 Vermont Grove','Peterborough','Cambridgeshire','UNITED KINGDOM','PE3 6BN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-11 20:46:11',0,NULL,3,1,3,1,'RA184556827CN\r ','英标 '),(21244,908212341015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','vabui','vanbui@me.com','vinh van bui','skt joergensgade 30','odense c','fyn','DENMARK','5000','004526159950','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 20:39:53',0,NULL,3,1,3,1,'RA184556393CN\r ',NULL),(21245,811140569002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','and3311','jflasa@gmail.com','Jesus Lasa','Iraburu 2-2º izda','Bergara','País Vasco','SPAIN','20570','685722322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 21:25:28',0,NULL,3,1,3,1,'RA184556756CN\r',NULL),(21246,767895042001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.25,'hermeshine','maxysexy','maxanne@iprimus.com.au','MAX SABBIONE','4/191 FRANKLIN ST','MELBOURNE','Victoria','AUSTRALIA','3000','0396001616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 22:20:19',0,NULL,3,1,17,0,NULL,NULL),(21247,767898078001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.9,'hermeshine','maxysexy','maxanne@iprimus.com.au','MAX SABBIONE','4/191 FRANKLIN ST','MELBOURNE','Victoria','AUSTRALIA','3000','0396001616','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-11 22:25:28',0,NULL,3,1,11,1,NULL,'绿叶 UV  55mm   1 \r绿叶 UV  77mm    1'),(21248,908370700015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','pacovideo','fr-video@hotmail.com','FRANCISCO RIVERA BUSTAMANTE','ERROTALDE 5','GAZETA - ALAVA','País Vasco','SPAIN','01192','651707070','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-11 23:50:43',0,NULL,3,1,3,1,'RA184556314CN\r ',NULL),(21249,908375554015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','ipozzi','juri.pozzi@gmail.com','Juri Pozzi','Via Allende 30','Scandicci','FI','ITALY','50018','3206960925','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 00:01:57',0,NULL,3,1,3,1,'RA184556402CN\r ',NULL),(21250,889790821016,260901880795,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',2.18,'hutongstore','oldofficebird','julia.willis@tis-gb.co.uk','katie goff','barrow hill farm<br>top brand road','osgathorpe','leicestershire','UNITED KINGDOM','LE129TB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 00:16:14',0,NULL,3,1,17,0,NULL,NULL),(21251,772060523018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','xlkoop01','mrcali.tai@gmail.com','Tai Nguyen','Lvl 2<br>29 Nyrang St','Lidcombe','New South Wales','AUSTRALIA','2141','020411352888','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-12 00:26:53',0,NULL,3,1,3,1,'RA184556328CN\r ',NULL),(21252,810756592002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','janklaassen001','jrodenberg001@gmail.com','Jeroen Rodenberg','Stalbergweg 17','Venlo','','NETHERLANDS','5913 BH','0773982610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 00:28:08',0,NULL,3,1,11,1,NULL,NULL),(21253,889790822016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','oldofficebird','julia.willis@tis-gb.co.uk','katie goff','barrow hill farm<br>top brand road','osgathorpe','leicestershire','UNITED KINGDOM','LE129TB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 00:16:15',0,NULL,3,1,11,1,NULL,'Mini 红外  canon       1\r牛津布大包                 1'),(21254,8881323653824505,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',3,'AA1310',20.97,'aliexpress','1005707605','kbratli@gmail.com','kenneth ﻿bratli﻿	','askimveien 408','Slitu','Eidsberg','NORWAY','1859','004790573301',NULL,NULL,NULL,'2011-12-12 01:37:04',0,NULL,3,1,3,1,'RA184541575CN\r ',NULL),(21255,889844457016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','t6camera','t6mails@gmail.com','Teh Thean Seng','29A, Chai Chee Ave #10-80','default','','SINGAPORE','461029','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 02:05:25',0,NULL,3,1,3,1,'RA184556835CN\r ',NULL),(21256,889837355016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','kasautii','naziamalik12@hotmail.com','nasha malik','42 natal road','ilford','Essex','UNITED KINGDOM','IG12HA','02084786673','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 01:47:26',0,NULL,3,0,11,1,NULL,NULL),(21257,768006748001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','snow_pitchayapa','phisit.supa@gmail.com','Phisit Suphasawat','325/38 Suksawat 32  Bangpakok<br>Ratburana','default','Bangkok','THAILAND','10140','(6681)934-8856','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 02:28:20',0,NULL,3,1,3,1,'RA184556844CN\r ',NULL),(21258,768018283001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','trinhv714','ttrinhv@att.net','vi trinh','749 N East St<br>Apt 180','anaheim','CA','UNITED STATES','92805','(714) 284-0819','NoPaymentFailure','CheckoutComplete','ShippingMethodExpress','2011-12-12 03:12:55',0,NULL,3,0,17,0,NULL,' '),(21259,768036425001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','ozjohnbayid','texon@rogers.com','Oz John Tekson','2706 - 27 Sudbury Street','Toronto','ON','CANADA','M6J 3W6','(416) 837-3451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 03:38:55',0,NULL,3,1,3,1,'RA184556858CN\r ',NULL),(21260,768047976001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','kikerodrigo','equique@gmail.com','Enrique Rodrigo Alonso','Vilaverde 25','Cortegada','Orense','SPAIN','32211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 04:14:38',0,NULL,3,1,4,1,'YW867739656CN ','▲ '),(21261,889918661016,260660053110,'New IR Remote Control for Pentax K10D K20D K200D',1,'AA2205',2.75,'hutongstore','tuttiilibri','inmaguirado@mixmail.com','Juan GUIRADO','Pedrera, 30','Tarazona de la Mancha. Albacete','Castilla-La Mancha','SPAIN','02100','967480939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 04:46:48',0,NULL,3,1,11,1,NULL,NULL),(21262,811396225002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','aser1410','asv1410@gmail.com','Aleksandr Sergeev','Gagarina 30 kv 29','Ulan-Ude','Buryatia','RUSSIAN FEDERATION','670010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:04:19',0,NULL,8,1,17,0,NULL,NULL),(21263,811396224002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',103,'hermeshine','aser1410','asv1410@gmail.com','Aleksandr Sergeev','Gagarina 30 kv 29','Ulan-Ude','Buryatia','RUSSIAN FEDERATION','670010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-12 07:04:18',0,NULL,3,1,3,1,'RA184556813CN','橡胶遮光罩 77mm   1 \r球台 伟峰 WF-717AH    1'),(21264,767645695001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',3,'AE2201',143.94,'hermeshine','cinemasyon','pekin@cinemasyon.com','pekin azer','Ulus Mah. Öztopuz Caddesi Noterler sit. A4 blok D2 beşiktaş','istanbul','','TURKEY','34340','0090212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:30:04',0,NULL,3,1,6,1,'EE636828869CN ',NULL),(21265,811400468002,120598267827,'Camera shoulder bag with raincover for Canon 550D 40D',1,'AO0021',28.99,'hermeshine','iargie','ivanflesler@hotmail.com','Ivan Flesler','Level 8<br>11 Talavera Road','Macquarie Park','New South Wales','AUSTRALIA','2113','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-12 07:45:50',0,NULL,3,1,17,0,NULL,NULL),(21266,811402013002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','iargie','ivanflesler@hotmail.com','Ivan Flesler','Level 8<br>11 Talavera Road','Macquarie Park','New South Wales','AUSTRALIA','2113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 07:45:50',0,NULL,3,1,3,1,'RA184556901CN ','反光板 60cm 2合1     1\rCanon M2 单肩包    1'),(21273,908636288015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','ajcalixto','ajcalixtosantos@gmail.com','António José Calixto Santos','Rua Lauro Gonçalves<br>Bloco A, 1A','Santa Comba Dão','Santa Comba Dão','PORTUGAL','3440-385','+351965052773','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 11:05:56',0,NULL,3,1,11,1,NULL,NULL),(21267,768106187001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','alltorndown90','markryan1990@hotmail.com','Mark Ryan','9 stevensons road','melbourne','Victoria','AUSTRALIA','3977','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 08:31:22',0,NULL,3,1,11,1,NULL,NULL),(21268,768122171001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','90anfield','anfield_90@hotmail.com','Stephen Lambe','29A Derrycrow Road<br>Derrytrasna','Craigavon','Armagh','UNITED KINGDOM','BT66 6PT','02838340155','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 09:34:07',0,NULL,3,1,3,1,'RA184541028CN\r ',NULL),(21269,908602029015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','es2ws','estows@gmail.com','Kristian Dimitrov','Nadezhda 2, bl 238, ap 44','Sofia','Sofia','BULGARIA','1220','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 09:41:35',0,NULL,3,1,5,1,'CP211275412CN ','确认一下是不够2kg吗 \r超2了\r'),(21270,811448318002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','krisvisual','aronchik.vladimir@gmail.com','Vladimir Aronchik','Eli Cohen 1/3','Jerusalem','Jerusalem','ISRAEL','92347','972-527729951','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 10:22:09',0,NULL,3,1,11,1,NULL,NULL),(21271,830532583017,270753945148,'Lambency Flash Diffuser for SB26/27/28 F56AM EF500 P3 ',1,'AB3310',18,'photographyacc','childofthevortex','canexed@gmail.com','Mark Cairncross','4 Skye cres','Forster','New South Wales','AUSTRALIA','2428','0412655200','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-12 10:31:24',0,NULL,3,1,3,1,'RA184541031CN\r ',NULL),(21272,767380816001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','grsts','i62559886@yandex.ru','Gennadiy Petrukhin','Soyuznaya str.<br>19-39','Kursk','Kurskaya','RUSSIAN FEDERATION','305044','(960) 698-3019','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 10:40:40',0,NULL,3,1,3,1,'RA184541045CN\r ',NULL),(21274,811468434002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','alhusam2010','alhusam7@hotmail.com','mohammed alkhirat','king abdulaziz rood alkhaldih p.o.box11439<br>00966541231723','abha','asir','SAUDI ARABIA','61321','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 11:23:44',0,NULL,3,1,3,1,'RA117765629CN\r ',NULL),(21275,811480014002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',2,'AB3309',99.98,'hermeshine','jedding300','ebay@gonell.de','Dreigang Kommunikationsdesign Gonell.Brandhorst GbR','Eleonorenstrasse 20','Hannover','','GERMANY','30449','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-12 12:00:57',0,NULL,3,1,3,1,'RA184540328CN\r ',NULL),(21276,908677770015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','linnotte','pierrephotoart@onvol.net','Pierre Sammut','Linnet 8 ,<br>Triq il-Hbit mill-ajru','Mosta','Malta','MALTA','MST3840','00356 21410122','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-12 12:45:14',0,NULL,3,1,3,1,'RA117765632CN\r ','分开发 \rRA184556985CN\r'),(21277,811495356002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','p1valente','pedrovvalente@gmail.com','Pedro Valente','Rua dos Lirios, 56','Carregado','Carregado','PORTUGAL','2580-509','(+351) 926227200','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 12:48:11',0,NULL,3,1,11,1,NULL,NULL),(21278,908662982015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','b19-dvv','dv.17@live.com','daniel virr','9 forber grove<br>tyersal','bradford','West Yorkshire','UNITED KINGDOM','bd48nd','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 12:08:47',0,NULL,3,1,3,1,'RA184541059CN\r ',NULL),(21279,811508283002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','andriyphotobuyer','andriymarsiuk@yahoo.com','Andriy Marsiuk','6 Gonchara Str. App. 32','Kiev','UA','UKRAINE','01034','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 13:19:00',0,NULL,3,1,3,1,'RA117765615CN\r ',NULL),(21280,768216024001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','andreyaney','andrey@aney.ru','Andrey Moskalev','Moskovskiy bulvar<br>dom 3, kv. 197','Balashikha','MO','RUSSIAN FEDERATION','143909','007-917-5496993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:09:13',0,NULL,8,1,17,0,NULL,NULL),(21281,811527823002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','andreyaney','andrey@aney.ru','Andrey Moskalev','Moskovskiy bulvar<br>dom 3, kv. 197','Balashikha','MO','RUSSIAN FEDERATION','143909','007-917-5496993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:09:13',0,NULL,3,1,17,0,NULL,NULL),(21282,768216025001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','andreyaney','andrey@aney.ru','Andrey Moskalev','Moskovskiy bulvar<br>dom 3, kv. 197','Balashikha','MO','RUSSIAN FEDERATION','143909','007-917-5496993','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 14:09:14',0,NULL,3,1,5,1,'CP211275426CN ','反光伞    1\r柔光伞     1\r150-200cm 5in1 反光板     1'),(21283,810270366002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','jamienewton1966','tnewton@couryprop.com','Jamie Newton','5717 S Louisville Ave','Tulsa','OK','UNITED STATES','74135-4167','(918) 607-4087','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-12 15:15:54',0,NULL,3,1,4,1,'YW867661050CN ','▲ '),(21284,811562102002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',3,'AD1169',20.64,'hermeshine','dlkott','kdkott@comcast.net','Daniel L Kott','5534 Eastern Ave SE','Grand Rapids','MI','UNITED STATES','49508-6022','(616) 451-0614','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 15:30:14',0,NULL,3,1,1,1,NULL,NULL),(21285,811563942002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','museo29','freez_222000@yahoo.com.au','D. Millane','PO BOX 8049','Sumner','Victoria','AUSTRALIA','3057','0419369013','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 15:34:20',0,NULL,3,1,3,1,'RA184556994CN\r ',NULL),(21286,811572222002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','whit6485','spcwhitewolf@msn.com','Carol Lee White','332 Chestnut St','Bainbridge','PA','UNITED STATES','17502','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-12 15:52:45',0,NULL,3,1,3,1,'RA184556977CN\r ',NULL),(21287,772390303018,280666852926,'Photo Studio Light Stand Heavy Duty Clamp Copper head  ',2,'AE3102',20,'photographyacc','soyvalen','soyvalen@yahoo.es','Valentín Nieto García','C/ Las Damas, 38','MEDINA DEL CAMPO - Valladolid','Castilla y León','SPAIN','47400','983811919','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 16:16:32',0,NULL,3,0,17,0,NULL,NULL),(21288,908802872015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','tonyynotanthony','tonyynottony@talktalk.net','anthony blower','10 mallard avenue<br>stockingford','nuneaton','Warwickshire','UNITED KINGDOM','cv10 9lw','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 16:35:04',0,NULL,3,1,11,1,NULL,NULL),(21289,772403165018,280666794780,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',19.99,'photographyacc','ivan150997','ivan.larosi@larosi.net','Stilsign Limited srl','Mandrie 7','VILLA DEL CONTE','PD','ITALY','35010','049-5744738','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 16:37:14',0,NULL,3,1,3,1,'RA117765646CN\r ',NULL),(21290,772404384018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','soyvalen','soyvalen@yahoo.es','Valentín Nieto García','C/ Las Damas, 38','MEDINA DEL CAMPO - Valladolid','Castilla y León','SPAIN','47400','983811919','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-12 16:39:55',0,NULL,3,0,4,1,'YW867661061CN ','大力夹    2 \r2m 灯架   1\r反光板支架     1   ▲\r看看是否超过2kg\r超重了'),(21291,811612332002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','bernardolago','bernardolago@gmail.com','Bernardo Lago','SQSW 504 - Bloco J - Ap 111<br>Setor Sudoeste','Brasilia','DF','BRAZIL','70673-510','(61) 3963-6287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 17:10:11',0,NULL,3,1,3,1,'RA117765650CN\r ',NULL),(21292,908833326015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'AKT038',130,'hutongstore','deabreu9299','bigpete1981@hotmail.co.uk','Peter DEABREU','62 cherry road','Enfield','Middlesex','UNITED KINGDOM','EN35SF','07584908477','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-12 17:19:49',0,NULL,3,1,4,1,'YW867661072CN ','英标 \r▲'),(21293,768305662001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','erayhasim','array_a@yahoo.co.uk','Eray Haşim Arslan','Klassis Golf hotel Altintepe mevkii Seymen köyü<br>Silivri','silivri','istanbul','TURKEY','34570','905427769587','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 17:30:27',0,NULL,3,1,11,1,NULL,NULL),(21294,768329719001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','catalinudrea','catalinudrea@hotmail.com','Catalin Udrea','Str. Voila, Nr.3, Bl.59, Sc.4, Et.4, Ap.58, Sector 4','Bucharest','Romania','ROMANIA','041941','+40723149977','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 18:03:45',0,NULL,3,1,11,1,NULL,NULL),(21295,908871586015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','hart1mart','hart1mart@yahoo.co.uk','martin hartwell','71 lakes road erdington bham','birmingham','West Midlands','UNITED KINGDOM','b237ul','01213563880','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 18:09:24',0,NULL,3,1,11,1,NULL,NULL),(21296,768358989001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','ttt3black','tmononen@paju.oulu.fi','Tomi Mononen','Puistokatu 6B119','Oulu','','FINLAND','90120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 19:00:11',0,NULL,3,1,3,1,'RA117765703CN\r ',NULL),(21297,768391910001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',2,'AD1182',156,'hermeshine','otisserie','tom@thomasfahey.com','Thomas Fahey','1343 Middlesex Ave NE','Atlanta','GA','UNITED STATES','30306','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-12 19:35:06',0,NULL,3,1,4,1,'YW867661083CN ','2个 \r▲'),(21298,768404108001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','frodeloe','frode.loe@ntebb.no','Frode Løe','Nedre Bakkevei 7','Steinkjer','','NORWAY','7713','91820830','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:00:31',0,NULL,3,1,11,1,NULL,NULL),(21299,810477099002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','rebel1999','1gordie@cogeco.ca','E.G. Wagner Jr.','Main PO Box 203','Niagara Falls','NY','UNITED STATES','14302-0203','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-12 20:10:09',0,NULL,3,1,1,1,NULL,NULL),(21300,768428979001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','omerl10','hlv119@gmail.com','Lavy Hafakot-Tova Lavy','hatavor 119','shoham','ISRAEL','ISRAEL','60850','972-3-9793325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:24:02',0,NULL,3,1,17,0,NULL,NULL),(21301,811746174002,120752153194,'Photo Studio Background Support Carrying Carry Bag',3,'AD1129',29.7,'hermeshine','omerl10','hlv119@gmail.com','Lavy Hafakot-Tova Lavy','hatavor 119','shoham','ISRAEL','ISRAEL','60850','972-3-9793325','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 20:24:03',0,NULL,3,1,3,1,'RA117765561CN\r ','3m 横杆（通用4节）     1 \r灯架包薄    3\r给他能装下横杆的包'),(21302,909014195015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','spambot10','connor.hughes@hotmail.co.uk','Connor Hughes','209 Worlds End Lane','Orpington','Kent','UNITED KINGDOM','BR6 6AT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 20:46:50',0,NULL,3,1,11,1,NULL,NULL),(21303,909015879015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','hugomineiro','hugo.mineiro.r@gmail.com','Bianca Moura','Rua Tomás da Anunciação 52<br>2-Esq','Lisboa','','PORTUGAL','1350-328','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-12 20:49:47',0,NULL,3,1,11,1,NULL,NULL),(21304,766980865001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','dagandnorb','robertlaval@yahoo.com','Robert LaVallee','836 14th St SE','Mason City','IA','UNITED STATES','50401','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-12 22:03:37',0,NULL,3,1,1,1,NULL,NULL),(21305,811836295002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',1,'AD1125',14.99,'hermeshine','dralianblack','admin@parkour.lv','Kirils Dogadajevs','Kalnciema 116-9','Riga','','LATVIA','LV-1046','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-12 22:51:30',0,NULL,3,1,11,1,NULL,NULL),(21306,768523378001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','duncemedia','coffeelover1973@hotmail.com','Jason Rossi','87 Fort Sullivan Cir','Dalzell','SC','UNITED STATES','29040-9216','(803) 468-4717','NoPaymentFailure','CheckoutComplete','Other','2011-12-12 23:08:46',0,NULL,3,1,1,1,NULL,'XL   (已入库） '),(21307,768527076001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','yirmi-2009','amerida@walla.co.il','yirmi reich','uziel 49','ramat gan','israel','ISRAEL','52382','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-12 23:19:13',0,NULL,3,1,3,1,'RA184556963CN\r ',NULL),(21308,909128447015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',2,'AC3303',10.9,'hutongstore','clapson_tom','tomclapson2@hotmail.co.uk','Tom Clapson','74<br>Shaddongate','Carlisle','Cumbria','UNITED KINGDOM','CA25UG','07818506635','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-12 23:33:56',0,NULL,3,1,11,1,NULL,NULL),(21309,8881323741546388,111,'2m灯架下面那个夹子',1,'',0,'photographyacc','gunners456','callumbroom@gmail.com','Callum Broom','166/538 Little Lonsdale Street','Melbourne','Victoria','AUSTRALIA','3000','',NULL,NULL,NULL,'2011-12-13 01:59:06',0,NULL,3,1,3,1,'RA184541270CN ','是上面两个螺丝下面那个 '),(21310,8881323742732581,111,'lenspen   x    2',1,'',0,'hermeshine','junque2jewels','esales@junque2jewels.com','R Burke','4364 HENDERSON CIR','Jackson','MS','UNITED STATES','39206-5925','(601) 665-3033',NULL,NULL,NULL,'2011-12-13 02:18:52',0,NULL,3,0,1,1,NULL,' 改一个\rLK068319455CN '),(21311,768598621001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 02:41:39',0,NULL,3,1,17,0,NULL,NULL),(21312,811924838002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',85.98,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 02:41:40',0,NULL,3,1,17,0,NULL,NULL),(21313,768598623001,110606921919,'New Portable 50cm 20\"x20\" Soft Box Softbox for Flash ',1,'AB3328',45.99,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 02:41:41',0,NULL,3,1,17,0,NULL,NULL),(21314,768598622001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 02:41:41',0,NULL,3,1,4,1,'YW867661094CN ','反光板支架    1 \r闪光的柔光箱   50cm    1\r牛津布大包      1\r2m 灯架    2     ▲\r闪光灯云台    2\r柔光伞   1\r反光伞   1\r'),(21315,772739746018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',17.98,'photographyacc','nickvango','nickv7@optusnet.com.au','Nick Vangopoulos','25 Grange Rd Lower Mitcham','Adelaide','South Australia','AUSTRALIA','5062','0412217739','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 02:57:03',0,NULL,3,1,11,1,NULL,NULL),(21316,768607110001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','fusion.markus','fusion.markus@gmail.com','Markus Deutsch','Unit 1, 12 Selhurst Street<br>Coopers Plains','Brisbane','Queensland','AUSTRALIA','4108','61733446599','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 03:07:09',0,NULL,3,1,4,1,'YW867661105CN ','▲ '),(21317,811937709002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','thuanle19','thuanle19@hotmail.com','Thuan Le','736 Bay St.<br>Suite 1513','Toronto','ON','CANADA','M5G 2M4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 03:19:52',0,NULL,3,1,11,1,NULL,NULL),(21318,831061506017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','swanland123','swanland@optusnet.com.au','John Swanland','2610 E Section St<br>Unit 52','Mount Vernon','WA','UNITED STATES','98274-6105','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 03:32:19',0,NULL,3,1,1,1,NULL,NULL),(21319,909267995015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',135,'hutongstore','erez_123','leflerer@zahav.net.il','Erez Leffler','23/4 Ygal ST.','Jerusalem','Israel','ISRAEL','97241','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 05:14:44',0,NULL,3,1,12,1,' 3436063400','欧标 \r泡重12.1   实重9.3'),(21320,768638771001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','kal-99','karl101@gmail.com','Karl Claude','43 Nilphas-Richer<br>Apt.# 4','Gatineau','QC','CANADA','J8T 2W6','(613) 255-2441','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 06:01:36',0,NULL,3,1,3,1,'RA184541266CN ','\r'),(21321,909318875015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','nikosfra','nikosfra@gmail.com','NIKOS FRAGKOULIS','2 STHNIDON STR','MEGARA','MEGARA','GREECE','19100','+302296021041','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 08:20:15',0,NULL,3,1,11,1,NULL,'欧标'),(21322,812031801002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','ranmo73','moranpl@012.net.il','ran moskovich','Hgaon 2/a','Pardes Hanna','israel','ISRAEL','37054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 09:41:30',0,NULL,3,1,3,1,'RA184541589CN\r ',NULL),(21323,909352976015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','aquamoda','losbeni@yahoo.es','juan francisco benitez moros','C/CIRERRER N2 BAJOS','palma de mallorca','Baleares','SPAIN','07009','971409079','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-13 10:00:31',0,NULL,3,1,3,1,'RA184541592CN\r ',NULL),(21324,812037979002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','fun4sax69','fun4sax@yahoo.com','April Saxinger','197 Yaupon Cove Dr','Onalaska','TX','UNITED STATES','77360-5032','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-13 10:02:12',0,NULL,3,1,1,1,NULL,NULL),(21325,909354398015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','markatfellow','rav@fellowproductions.com','Mark Ratcliff','Fellow Productions<br>Unit 11 Iron Bridge House, 3 Bridge Approach,','London','London','UNITED KINGDOM','NW1 8BD','02074492379','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-13 10:06:18',0,NULL,3,1,4,1,'YW867661116CN ',' 英标 \r▲'),(21326,812047545002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','j00be','joope.erkkila@gmail.com','Waltteri Erkkilä','Varikonkatu 18 C','Sastamala','','FINLAND','38210','+358505714824','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 10:35:06',0,NULL,3,1,3,1,'RA184541601CN\r ',NULL),(21327,772872267018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','amanito_photo','amanitok15@gmail.com','Vase Petrovski','Bul. AVNOJ 68/25','Skopje','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','+38970342667','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-13 11:16:34',0,NULL,3,1,3,1,'RA184541513CN\r ','分开发 \rRA184541632CN\r'),(21328,812071233002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','xymopnoi72','xymopnoi@gmail.com','Vladimir Hutornoy','Gurievskaya street, 29 - 35','Novosibirsk','Новосибирская','RUSSIAN FEDERATION','630102','(923) 2290908','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 11:54:31',0,NULL,3,1,11,1,' ',NULL),(21329,831206287017,270751511455,'YongNuo 3m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3325',28.99,'photographyacc','tcrburleigh','timmybeban@hotmail.com','Timothy  Beban','22 Plantation Road','Burleigh Heads','Queensland','AUSTRALIA','4220','0412750726','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-13 12:02:49',0,NULL,3,1,11,1,NULL,NULL),(21330,812087618002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',75,'hermeshine','matoc4','mato.c4@pobox.sk','Martin Šinko','Legionarska 10','Žilina','','SLOVAK REPUBLIC','01001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 12:41:36',0,NULL,3,1,5,1,'CP211275430CN ','欧标 '),(21331,812094377002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','dchepko','chepko@yandex.ru','Danil Chepko','Marata, 67/2<br>l','Novosibirsk','','RUSSIAN FEDERATION','630046','+7-913-792-61-22','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 13:03:41',0,NULL,3,1,3,1,'RA184541527CN\r ',NULL),(21332,812096134002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','4705michele','michele.mcgivern@gmail.com','Michele McGivern','25 Belfry Gardens<br>St Alphonsus Road','Dundalk','Co Louth','IRELAND','default','0429336109','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 13:08:52',0,NULL,3,0,3,1,'RA184541535CN\r ','L (已入库) '),(21333,768765391001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','bhpjon','jonathan.mread@talktalk.net','jonathan read','43 burnbank avenue, south wellfield','whitley bay','Tyne and Wear','UNITED KINGDOM','NE259HG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 13:13:56',0,NULL,3,1,17,0,NULL,NULL),(21334,768765550001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','bhpjon','jonathan.mread@talktalk.net','jonathan read','43 burnbank avenue, south wellfield','whitley bay','Tyne and Wear','UNITED KINGDOM','NE259HG','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 13:13:56',0,NULL,3,1,3,1,'RA184541544CN\r ','反光板支架   2 '),(21335,812115298002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','grizz.ru','kurbatovpp@gmail.com','Aleksey Kurbatov','Tehnicheskiy pereulok 48-5','Vologda','Vologodskaya oblast','RUSSIAN FEDERATION','160032','89062928550','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 14:00:31',0,NULL,3,1,5,1,'CP211275443CN ',NULL),(21336,0,140658707225,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',9,'hermeshine','kaspo2010','a_kaspo@yahoo.com','ayad kaspo','skiftesvagen 12,2tr','Sodertalje','stockholms lan','SWEDEN','151 54','0046704973212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 15:15:53',0,NULL,3,0,11,1,NULL,'1.6 x 2.1m 绿色   1 '),(21337,812190318002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','elenakitty1980','elenaesteban8@hotmail.com','Elena Muñoz','C/ Del Tinte, 9 2ºA','Colmenar Viejo','Madrid','SPAIN','28770','699891838','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 16:59:05',0,NULL,3,1,3,1,'RA184541411CN\r ',NULL),(21338,768892933001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','antonikon','antonioluiscerezo@gmail.com','Antonio Luis Cerezo Parfenof','Calle Ruiz de Alda Nº4-4ºA','Santander','Cantabria','SPAIN','39009','616211263','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 18:06:58',0,NULL,3,1,4,1,'YW867661120CN ','欧标 \r▲'),(21339,805924096002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','natalygalan','nataly.galan@gmail.com','Nataly Sokolsky','Struma 27/3','Nahariya','Acco','ISRAEL','22242','+972522415330','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 18:56:54',0,NULL,3,0,3,1,'RA184541558CN\r ','摄影背心 Canon  老款    XL  已入库 '),(21340,605336254004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',52,'hermeshine','anaguzik','anaguzik@fibertel.com.ar','Ana Guzik','Corrientes 4006 2º 18','ciudad autonoma de buenos aires','ciudad autonoma de buenos aires','ARGENTINA','c1194aat','541148566903','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-13 19:30:00',0,NULL,3,1,3,1,'RA184541460CN\r ',NULL),(21341,909725083015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dan779866','williams.dd@gmail.com','Dan Williams','Crown Cottage<br>Market Place','Faringdon','Oxfordshire','UNITED KINGDOM','SN7 7HU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 20:48:04',0,NULL,3,1,3,1,'RA184541473CN\r ',NULL),(21342,768997109001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','fabo-sk','90spam10@gmail.com','Tomas Fabian','Luky 1136 70','Vráble','Slovakia','SLOVAK REPUBLIC','95201',' 0944114506','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 20:51:30',0,NULL,3,1,5,1,'CP211275457CN ','欧标 '),(21343,812340806002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','newguyri','kaonije@gmail.com','Mario Greblicki','Lovranska 4','Rijeka','','CROATIA','51000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-13 21:09:04',0,NULL,3,1,3,1,'RA184541629CN\r ','1.6x3m 黑色    1 \r申报$18, + 发票一张'),(21344,909764233015,250939650586,'Mini IR Wireless Remote Control for Pentax 200D 10D 20D',1,'AD1118',2.18,'hutongstore','drm567','marsden29@gmail.com','David Marsden','67 Fourth Avenue, Garston','Watford','Hertfordshire','UNITED KINGDOM','WD25 9QH','01923679567','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 21:37:05',0,NULL,3,1,11,1,NULL,NULL),(21345,909813820015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','andrewdolphin','andrew.dolphin@hiscox.com','Andrew Dolphin','24 Septimus Drive<br>Highwoods','Colchester','Essex','UNITED KINGDOM','CO4 9ET','07920199388','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 22:55:53',0,NULL,3,1,3,1,'RA184541487CN\r ',NULL),(21346,909823526015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',1.6,'hutongstore','davidleslie9331','davidlesliesmith@me.com','David Leslie Smith','48 Raymond ave , Northshore','Blackpool','Lancashire','UNITED KINGDOM','FY2 0UB','01253593882','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-13 23:13:21',0,NULL,3,1,11,1,NULL,NULL),(21347,909846380015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','nick_designs','nreynolds2007@googlemail.com','Nicholas Reynolds','38 Rowney Road','Dagenham','Essex','UNITED KINGDOM','RM9 4PP','02085176962','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 00:01:41',0,NULL,3,1,11,1,NULL,NULL),(21348,767011558001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',4,'AA1306',10.4,'hermeshine','mrsetcjr','mrsetcjr@verizon.net','michele cook','7711 Gromwell Ct','springfield','VA','UNITED STATES','22152-3128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-14 00:28:22',0,NULL,3,0,1,1,NULL,'4个 '),(21349,769100507001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','coorykoray','korayturkay@gmail.com','Koray Turkay','kurucesme mah. sakarya cad no:46<br>Osmangazi','bursa','bursa','TURKEY','16050','+902242236064','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 00:41:57',0,NULL,3,1,3,1,'RA184541495CN\r ','欧标 '),(21350,773268107018,280680267419,'New Neoprene Camera Cover for Nikon D80 D5000 +18-55mm',1,'AC1305',7.6,'photographyacc','evan_p','evan_pratama@yahoo.com','Evan Pratama','Redflex Traffic System<br>31 Market Street','South Melbourne','Victoria','AUSTRALIA','3205','61401724585','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 00:58:12',0,NULL,3,1,11,1,NULL,NULL),(21351,8881323826910204,111,'2.4x3m 背景架+1.6x4m 白色背景布',1,'AD1183',0,'photographyacc','eandy2010','t467838@yahoo.com','Андрей Колчанов','ул. Красных Партизан 5-12','Н. Тагил, Свердловская область','','RUSSIA','622042','',NULL,NULL,NULL,'2011-12-14 01:41:50',0,NULL,3,1,5,1,'CP211275465CN ',NULL),(21352,8881323827277639,111,'canon 1m ttl',1,'AB3321',0,'photographyacc','wsun3575','sundud1981@yahoo.com','Wei Sun','16 Clara St Macleod VIC 3085','Macleod','Victoria','AUSTRALIA','3085','0394328461',NULL,NULL,NULL,'2011-12-14 01:47:57',0,NULL,5,0,18,0,NULL,' '),(21353,8881323827339797,111,'NIkon TTL 1m',1,'AD1113',0,'photographyacc','wsun3575','sundud1981@yahoo.com','Wei Sun','16 Clara St Macleod VIC 3085','Macleod','Victoria','AUSTRALIA','3085','0394328461',NULL,NULL,NULL,'2011-12-14 01:48:59',0,NULL,3,1,3,1,'RA184541500CN\r ','确保是nikon的,上次发错货了 '),(21354,8881323827954300,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop',1,'AD1183',81.99,'aliexpress','1005769046','-@-.com','Artem Litvinov','Ul. Belyaeva, d. 3a, kv. 19','Shelkovo-4','﻿Moscow﻿','RUSSIAN FEDERATION','141104','+7 909 1692199',NULL,NULL,NULL,'2011-12-14 01:59:14',0,NULL,3,1,5,1,'CP211275678CN ',NULL),(21355,8881323828814148,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',25.99,'aliexpress','1005780099 ','annatalk@mail.ru','Anna Klueva','Dunaiskiy pr. 7/3-524','Saint-Petersburg','Russia﻿','RUSSIAN FEDERATION','196158','+7 965 0000189',NULL,NULL,NULL,'2011-12-14 02:13:34',0,NULL,3,1,3,1,'RA184540155CN ',NULL),(21356,8881323829015851,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',2,'AA1310',13.98,'aliexpress','1005783656','aasgrios@uol.com.br','Andre Grios','Avenida Paulista, 2444, Conj.141','Sao Paulo','SP/Brazil	','BRAZIL','01310300','+055 11 70270451',NULL,NULL,NULL,'2011-12-14 02:16:55',0,NULL,3,1,3,1,'RA184540067CN\r ',NULL),(21357,891264329016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','ayunite','sharleenh@gmail.com','Sharleen Hsu','606 Boundary Rd','Archerfield','Queensland','AUSTRALIA','4108','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 02:20:38',0,NULL,3,1,11,1,NULL,NULL),(21358,769132557001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','tiku97','tiku97@indosat.net.id','Kusnadi Sugiarto','Jl. Babatan Pantai Barat V/27','Surabaya','East Java','INDONESIA','60113','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 02:20:49',0,NULL,3,1,3,1,'RA184541561CN\r ',NULL),(21359,773296904018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',29.99,'photographyacc','gutte2007','gutte.peter@etsa.com.au','PETER GUTTE','79 TOLLEY RD<br>ST AGNES','ADELAIDE','South Australia','AUSTRALIA','5097','0883965398','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 02:22:58',0,NULL,3,1,3,1,'RA184541646CN\r ',NULL),(21360,8881323834213875,111,'115w 220v    1',1,'',0,'hermeshine','picturelizard','ebay@picturelizard.co.uk','Peter Townsend Picturelizaerd','Unit 2<br>Cobhan Centre','Swindon','Wiltshire','UNITED KINGDOM','SN5 7UJ','08454747842',NULL,NULL,NULL,'2011-12-14 03:43:33',0,NULL,3,1,3,1,'RA184541650CN\r ',NULL),(21361,812512848002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',48,'hermeshine','rena_isis','rena_isis@hotmail.com','Serena Docking','PO Box 2560','Port Lincoln','South Australia','AUSTRALIA','5606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 04:18:09',0,NULL,3,1,3,1,'RA184541615CN ',' 接口环换成52的 \r除了c里面的再发\r帽子 nikon      1\r已入库'),(21362,812512987002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','rena_isis','rena_isis@hotmail.com','Serena Docking','PO Box 2560','Port Lincoln','South Australia','AUSTRALIA','5606','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 04:18:10',0,NULL,3,1,17,0,NULL,NULL),(21363,812520776002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','avzaid','avzaid@gmail.com','Awni Hafedh','P.O. Box 55417','Abu Dhabi','','UNITED ARAB EMIRATES','55417','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 04:41:31',0,NULL,3,1,3,1,'RA184541703CN ',NULL),(21364,831706586017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','fixit7757','ecseed@yahoo.ca','ROBERT GADATE','83 DOUGLAS RD.','BLACKTOWN','New South Wales','AUSTRALIA','2148','(614) 393-7424 ext.: 6','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-14 05:28:02',0,NULL,3,1,11,1,NULL,NULL),(21365,773352511018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','kovacsit','kovacsi@freestart.hu','Mr. Tamas Kovacsi / Porsche Bank','Fay u. 27','Budapest','Hungary','HUNGARY','1139','+36306931043','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 05:32:57',0,NULL,3,1,3,1,'RA184541694CN ',NULL),(21366,812539901002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','adjl83andres','adjl83@gmail.com','Andres Jaramillo','Madrid y Toledo 844, Edf. Munich Dep. 8','Quito','Pichincha','ECUADOR','EC170109','593-02-2500-541','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 06:04:31',0,NULL,3,1,3,1,'RA184541685CN ',NULL),(21367,812545259002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','vafinalbert','blackfoot@ya.ru','Albert Vafin','Novo-Sadovaya street 42-266','Samara','Samarskaya oblast`','RUSSIAN FEDERATION','443110','+79608160501','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 06:32:29',0,NULL,3,1,11,1,NULL,NULL),(21368,768962211001,110625489113,'Green-L 67mm Graduated Neutral Density ND Grey Filter',1,'AA3319',7.41,'hermeshine','freestyler_2018','freestyler2018@gmail.com','Ivan Nikitin','Valchenko 57-18','Rybnitsa','','MOLDOVA, REPUBLIC OF','5500','37355542851','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 08:02:43',0,NULL,3,1,11,1,NULL,NULL),(21369,8881323851553204,111,'New 4 Sockets with 20\"X28\" Softbox Photo Video Light',1,'AD1176',0,'hermeshine','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','',NULL,NULL,NULL,'2011-12-14 08:32:33',0,NULL,3,1,3,1,'RA184541915CN\r ','欧标 '),(21370,769235489001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','jeffrey1031jeffrey0907','stressdissector@hawaii.rr.com','Jeffrey  Thomas','4 Meleana Pl','Kahului','HI','UNITED STATES','96732-3209','(808) 276-9354','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-14 09:22:03',0,NULL,3,1,1,1,NULL,NULL),(21371,812596081002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','carl76','carl1770@gmail.com','Carl O\'Loughlin','PO BOX 121','AGNES WATER','Queensland','AUSTRALIA','4677','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 10:05:36',0,NULL,3,1,3,1,'RA184540075CN ','m '),(21372,910058802015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','nhilan_emyeu','vnthaison@gmail.com','Michael thaison','fish shop 4/57-59 Brown road<br>Bonnyrigg','Sydney','New South Wales','AUSTRALIA','2177','0422889029','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 10:20:12',0,NULL,3,1,11,1,NULL,NULL),(21373,769258205001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','robertosakaguti','robertomsbr@hotmail.com','ROBERTO SAKAGUTI','RUA PERNAMBUCO, 1373 - AP. 804<br>BAIRRO MONTE CASTELO','CAMPO GRANDE','MS','BRAZIL','79010-040','+55 67 3042-0456','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 10:41:49',0,NULL,3,1,3,1,'RA184540084CN ',NULL),(21374,812621150002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','jlcubas64','jlcubas@terra.es','Jesus Lopez Cubas','Lazarillo de Tormes,44<br>San Antonio','Telde','','SPAIN','35200','928695285','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 11:51:53',0,NULL,3,0,3,1,'RA184540098CN ','XXL ( 已入库) '),(21375,891498059016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','parnoja2008','parnojak@yahoo.co.uk','Kristina Parnoja','Family Portrait Studio Unit 11 ground floor,<br>Omni Park Shopping center,Santry D9','Dublin','Dublin','IRELAND','9','0851486881','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-14 13:58:20',0,NULL,3,1,3,1,'RA184540107CN ',NULL),(21376,773495045018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','wedispau','aldaril@gmail.com','Sergey Simonov','Serathimovicha str., 19, fl. 139','Kiev','','UKRAINE','02152','+380503443154','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 13:59:13',0,NULL,3,1,11,1,NULL,NULL),(21377,605616471004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','kikerodrigo','equique@gmail.com','Enrique Rodrigo Alonso','Vilaverde 25','Cortegada','Orense','SPAIN','32211','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 14:16:36',0,NULL,3,1,11,1,NULL,NULL),(21378,812704559002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','berkbo1','salimguzeyer@ttmail.com','SALIM GUZEYER  - Saya  Ayakkabi','Fener Mahallesi, Tekelioglu Cad.Astur Sitesi,D Blok No: 82/B','Antalya','','TURKEY','07230','(0242) 324-2672','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 15:22:10',0,NULL,3,1,3,1,'RA184540019CN ',NULL),(21379,812714094002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','rail44','brucebadass@gmail.com','bruce brown','p.o. box 766','Jasper','AB','CANADA','t0e1e0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 15:45:13',0,NULL,3,1,11,1,NULL,NULL),(21380,769424747001,110426239104,'Brand New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','robertprins1967','robert-prins@hotmail.com','robert prins','Bachplein 494','SCHIEDAM','','NETHERLANDS','3122KR','0655347775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 17:49:42',0,NULL,3,1,11,1,NULL,NULL),(21381,769449592001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','zygenes','marcelthelover@hotmail.com','Mariette Lamoureux','201, Ch. des Gaies-Bleus','St-Didace','QC','CANADA','J0K 2G0','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(21382,832044849017,270855429760,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX C-Shape',1,'AD1193',18.9,'photographyacc','smohanraj2567','mohanraj_1978@yahoo.com','MOHANRAJ S','Plot No.158,10th Cross Street,CLRI Nagar<br>Neelangarai','Chennai','TN','INDIA','600041','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-14 19:29:20',0,NULL,3,1,3,1,'RA184540036CN ',NULL),(21383,811365442002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','mapski_cat','mapski2@gmail.com','Katie Webb','MACCS, Macquarie University<br>Building C5C, Room 417','Macquarie University, Sydney','New South Wales','AUSTRALIA','2109','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 20:59:29',0,NULL,3,1,11,1,NULL,NULL),(21384,812906947002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','crokogen2008','crokogen@gmail.com','Gennadiy Kondratyev','O. Pchilki Str., #3A, apt. 118<br>+38 (067) 503-11-03','Kiev','','UKRAINE','02068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 21:14:11',0,NULL,3,1,17,0,NULL,NULL),(21385,812906948002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','crokogen2008','crokogen@gmail.com','Gennadiy Kondratyev','O. Pchilki Str., #3A, apt. 118<br>+38 (067) 503-11-03','Kiev','','UKRAINE','02068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 21:14:12',0,NULL,3,1,17,0,NULL,NULL),(21386,812906949002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','crokogen2008','crokogen@gmail.com','Gennadiy Kondratyev','O. Pchilki Str., #3A, apt. 118<br>+38 (067) 503-11-03','Kiev','','UKRAINE','02068','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 21:14:13',0,NULL,3,1,3,1,'RA184540141CN ','灯架包薄    1 \r伞式柔光箱 80cm 8角     1\r伞式柔光箱 60×90cm     2'),(21387,910459712015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','123louieb','louiebcollins@yahoo.no','Louie Blystad-Collins','24 Withey Close East<br>Stoke Bishop','BRISTOL','Avon','UNITED KINGDOM','BS9 3SZ','01179685022','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 21:35:07',0,NULL,3,1,3,1,'RA184541972CN ','英标 '),(21388,910464229015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','hasiukas','hasiukas@gmail.com','Rasa Polikse','29 Fir Lodge<br>3 Gipsy Lane','Barnes','London','UNITED KINGDOM','SW15 5SA','07575856736','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-14 21:41:27',0,NULL,3,1,11,1,NULL,NULL),(21389,812950160002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','karmi_a','karmi.avi@gmail.com','Avi Karmi','Hagefen st. 28','Haifa','','ISRAEL','35053','+972-54-7430175','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-14 22:35:39',0,NULL,3,1,3,1,'RA184541986CN ',NULL),(21390,812952363002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','sacredrearth','dionysus@y7mail.com','Kieran Dionysus','51 Railway Place','Coburg','Victoria','AUSTRALIA','3058','0393867551','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 22:46:14',0,NULL,3,1,4,1,'YW867739623CN ','澳标 \r▲'),(21391,812954826002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','kaytee_1','kristy_145@hotmail.com','Kristy Taylor','2/7 Arthur Street<br>Wantirna South','Melbourne','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 22:46:41',0,NULL,3,0,17,0,NULL,NULL),(21392,769598646001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','kaytee_1','kristy_145@hotmail.com','Kristy Taylor','2/7 Arthur Street<br>Wantirna South','Melbourne','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 22:46:41',0,NULL,3,0,17,0,NULL,NULL),(21393,769598292001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','kaytee_1','kristy_145@hotmail.com','Kristy Taylor','2/7 Arthur Street<br>Wantirna South','Melbourne','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 22:46:42',0,NULL,3,1,3,1,'RA184541969CN ','绿叶 渐变镜 58mm    1\r倒影板（白黑）     1\r6片装的滤镜袋      1\r '),(21394,812963287002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','oscarmarques','oscarmarques@sapo.pt','Oscar Marques','Rua Casa da Guarda, lote 2','Lapa do Lobo','Beira-Alta','PORTUGAL','3525-611','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 23:09:21',0,NULL,3,1,11,1,NULL,NULL),(21395,769623703001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','juanjoselopezgarza2011','juanjoselopezgarza@yahoo.com.mx','JUAN JOSE LOPEZ GARZA','CERRO SAN MIGUEL 2809 COL. MIRADOR RESIDENCIAL','MONTERREY','NUEVO LEON','MEXICO','64920',' 8183490264','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-14 23:50:47',0,NULL,3,1,11,1,NULL,NULL),(21396,832217301017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','steggzz','gturnell@gmail.com','Greg Turnell','PO Box 43','Boronia','Victoria','AUSTRALIA','3155','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-15 00:39:31',0,NULL,3,1,11,1,NULL,NULL),(21397,773825751018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','artumb','rbn198@gmail.com','Rubén Crespo Martínez','c/ La Pau, 1','Mollet del Valles (Barcelona)','Cataluña','SPAIN','08100','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 00:41:32',0,NULL,3,1,3,1,'RA184541990CN\r ',NULL),(21398,813005991002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-15 01:07:53',0,NULL,3,1,3,1,'RA184542006CN ',NULL),(21399,8881323914037121,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',53.98,'aliexpress','1005795080','tonymtsai@gmail.com','Tony Tsai	','2 Clearview Ln Mt Pleasant','Christchurch','New Zealand	','NEW ZEALAND	','8081','64212699286',NULL,NULL,NULL,'2011-12-15 01:53:57',0,NULL,3,1,3,1,'RA184540495CN \rRA184540535CN','拆开发'),(21400,8881323914615554,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag',1,'AD1183',92.99,'aliexpress','1005798510','gunovgen@mail.ru','Gennadij Novikov	','Prospekt Pobedy street 37, 48','Stupino	','Moskovskaja oblast','RUSSIAN FEDERATION	','142800','+7 926 5776322',NULL,NULL,NULL,'2011-12-15 02:02:39',0,NULL,3,1,5,1,'CP211275655CN ','1.6x2.1m 背景布 * 1 （灰色） '),(21401,813043098002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','flydart2011','info@celebritysketch.com','Haidong Chen','25906 Pembroke Ave','Great Neck','NY','UNITED STATES','11020-1042','(917) 816-1760','NoPaymentFailure','CheckoutComplete','Other','2011-12-15 03:02:32',0,NULL,3,1,1,1,NULL,NULL),(21402,769691664001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','kilshaugen','roger@kilshaugen.no','Roger Mikalsen','Kil','Naustbukta','','NORWAY','7990','+4799113938','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 03:38:19',0,NULL,3,1,3,1,'RA184540053CN\r ',' 1.26'),(21403,8881323926917332,111,'一堆东西',1,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-12-15 05:28:37',0,NULL,3,0,12,1,'3436036855 ','2m灯架   x 5\r4灯头+50-70棚    2\r50-70棚的柔光布   2\r45w 110v   2\r115w 110v    1\r泡重10.36  实重7.8\r '),(21404,891998249016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',19.98,'hutongstore','smort04','threetanks@gmail.com','clement ireland','19 walmer crescent','wentworth falls','New South Wales','AUSTRALIA','2782','0448539560','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 06:16:36',0,NULL,3,1,11,1,NULL,NULL),(21405,892004281016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',4.5,'hutongstore','buddha_chan','searay@y7mail.com','Raymond Hare','PO Box 2038','Tarrawanna','New South Wales','AUSTRALIA','2518','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-15 06:43:17',0,NULL,3,1,11,1,NULL,NULL),(21406,769736601001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','borgesvillalba','conejeroman@hotmail.com','Carlos Javier Borges Villalba','C/Pescante nº 27 1º D','Playa Honda','Canarias','SPAIN','35509','636874700','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 07:14:06',0,NULL,3,1,5,1,'CP211275514CN','欧标 \r实重7.1   泡重8.9'),(21407,769749660001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','bekreler253','bendroz@gmail.com','Ben Droz','917 Columbia Rd NW','Washington','DC','UNITED STATES','20008-1518','(412) 805-0087','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-15 08:16:20',0,NULL,3,1,1,1,NULL,NULL),(21408,832360674017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','jesspoddy','jess_poddy@hotmail.com','jessica podporin','19 heatherlea grove','lakes entrance','Victoria','AUSTRALIA','3909','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-15 09:19:24',0,NULL,3,1,11,1,' ',NULL),(21409,813142048002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','shawsky99','th.dk@bigpond.com.au','Darren Shaw','23<br>Mc Conville street','Whyalla','South Australia','AUSTRALIA','5600','0886440451','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 10:11:32',0,NULL,3,1,11,1,NULL,NULL),(21410,8881323944249354,111,'4灯头+50-70棚',1,'AD1176',0,'photographyacc','jevadamir','damirjevtic@gmail.com','Damir Jevtic','Save Jugo Bujkove 23','Rijeka','Primorsko-goranska zupanija','CROATIA','51000','00385915720398',NULL,NULL,NULL,'2011-12-15 10:17:29',0,NULL,3,1,3,1,'RA184540858CN ','欧标\r里面都 '),(21411,769781842001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','jaffer363','jj99962@hotmail.com','Jaffer Hussain','villa 4723 - road 1226<br>block 812','Isa Town','BH','BAHRAIN','xxxx','97333141212','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-15 10:32:56',0,NULL,3,1,3,1,'RA184540504CN \rRA184540521CN\rRA184540645CN',' 看分几个小包  \r1.6*2.1白+黑\r1.6*3灰色和蓝色'),(21412,813149130002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',36,'hermeshine','jaffer363','jj99962@hotmail.com','Jaffer Hussain','villa 4723 - road 1226<br>block 812','Isa Town','BH','BAHRAIN','xxxx','97333141212','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 10:39:41',0,NULL,3,0,17,0,' ','1.6*3灰色和蓝色'),(21413,910751298015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','sfre3507','frenchfam830@btinternet.com','Stephen French','Kite Furlong<br>North Stoke','Bath','Avon','UNITED KINGDOM','BA1 9AS','01179328750','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 10:57:19',0,NULL,3,1,3,1,'RA184540552CN ',NULL),(21414,813166281002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-15 11:39:52',0,NULL,3,1,3,1,'RA184540464CN ',NULL),(21415,605961115004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',52,'hermeshine','myfotografer','newlando@gmail.com','Александр Солдатов','8-Марта<br>д. 27-а кв. 133','Пенза','Пензенская область','RUSSIAN FEDERATION','440011','962-398-3945','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-15 11:56:39',0,NULL,3,1,3,1,'RA184540478CN ',''),(21416,774000058018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',32.97,'photographyacc','thenolimitste','philoudoss@yahoo.fr','dossmann philippe','35 rue principale','gertwiller','Alsace','FRANCE','67140','0388085267','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 12:01:35',0,NULL,3,0,3,1,'RA184540549CN ','1.6x2.1    3   蓝  绿  红 '),(21417,910556768015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','mishs2j','mishilily9@hotmail.com','Jason Li','27 Welby Street<br>Eastwood','Sydney','New South Wales','AUSTRALIA','2122','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 12:36:26',0,NULL,3,1,11,1,NULL,NULL),(21418,910798388015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',20.9,'hutongstore','pmirosevic','gazdapavo@gmail.com','Pavao Mirosevic','Jaruscica 11<br>S623','Zagreb','','CROATIA','10000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 13:02:40',0,NULL,3,1,3,1,'RA184540481CN ',NULL),(21419,769858128001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','lensjocky','jromeo@bellatlantic.net','John Romeo','30 Charles St<br>Apt 43','New York','NY','UNITED STATES','10014','(212) 727-1161','NoPaymentFailure','CheckoutComplete','Other','2011-12-15 14:41:21',0,NULL,3,1,1,1,NULL,NULL),(21420,832471249017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.9,'photographyacc','esteban-banane','alain_danielle@globetrotter.net','Danielle Plante','754, 169e rue','Saint-Georges','QC','CANADA','G5Z 1H8','(418) 228-6009','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 14:50:52',0,NULL,3,1,11,1,NULL,NULL),(21421,767244452001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','bazhenov.73','fotograf777@gmail.com','Andrey Bazhenov','Russian Federation<br>Udmurtia','Izhevsk','Izhevsk/Udmurtia','RUSSIAN FEDERATION','426063','+79225209190','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 15:10:24',0,NULL,3,1,5,1,'CP211275664CN ',NULL),(21422,910854765015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','afghan-agent','afghanwing@gmx.de','Jassin Kadiri Visuals','Rebengarten 10','Bornheim','','GERMANY','53332','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 15:10:56',0,NULL,3,1,3,1,'RA184540654CN ',NULL),(21423,910864647015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','sarrak2011','silver@arrak.ee','Silver Arrak','Tule 3-52','Saue','Harjumaa','ESTONIA','76505',' 55562676','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-15 15:36:58',0,NULL,3,1,3,1,'RA184540606CN ',NULL),(21424,769880670001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','k_dynamo','k.gazuani@dynamo-eindhoven.nl','Kareem gazuani','Catharinaplein 21','EINDHOVEN','','NETHERLANDS','5611DE','31402393110','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 15:41:54',0,NULL,3,1,4,1,'YW867661142CN\r ','欧标  \r▲'),(21425,910886107015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','propellerheadhead','simon@invisiblecity.co.uk','simon moorhouse','Studio 3A, Gloucester House<br>45 Gloucester Street','Brighton','East Sussex','UNITED KINGDOM','BN14EW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 16:14:42',0,NULL,3,1,3,1,'RA184540518CN ',NULL),(21426,910887314015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','molotok.ru','digishop@mail.ru','Aleksey Bylinskiy','ul.Kamchatskaya, d.8, korp.1,kv. 92','Moscow','','RUSSIAN FEDERATION','107065','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-15 16:22:04',0,NULL,3,1,5,1,'CP211275488CN ',NULL),(21427,892213967016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','mahoutie2004','mahoutie@gmail.com','Mark Heaton','6, Truro Road','Ramsgate','Kent','UNITED KINGDOM','CT11 8DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 16:26:21',0,NULL,3,1,11,1,NULL,NULL),(21428,774122342018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','oldyankee1956','oldyankee1956@hotmail.com','RANDY MILLER','3660 County Road 12','BELLEFONTAINE','OH','UNITED STATES','43311','(937) 465-9500','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 17:44:31',0,NULL,3,1,4,1,'YW867661153CN ','换弹簧灯架给他 \r▲'),(21429,813353509002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','fotografinternational10','fotograf.international@yahoo.com','Hubert Mueller','Sandholzerstrasse 16 a','Altach','','AUSTRIA','A-6844','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 19:17:54',0,NULL,3,1,11,1,NULL,NULL),(21430,813384951002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','hemeroskopion','ewi@telefonica.net','Olaf Speier','Avenida 9 de Octubre, 9, 1º B<br>Residencial El Tossalet','Polop de la Marina','Comunidad Valenciana','SPAIN','03520','637101199','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 20:11:41',0,NULL,3,1,11,1,NULL,NULL),(21431,774298942018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','tkelly363','tim___kelly@hotmail.com','Tim Kelly','factory 2, 155 Abbotts Road,','South Dandenong','Victoria','AUSTRALIA','3175','0397027066','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-15 22:31:55',0,NULL,3,1,11,1,NULL,NULL),(21432,911150399015,250692242296,'77mm CPL Circular Polarizing Filter 77 CPL Green.L New',1,'AA3314',4.5,'hutongstore','50ebon50','eionmailbox@googlemail.com','Eion Johnston','2 Wardie Grove','Edinburgh','Midlothian','UNITED KINGDOM','EH5 1AQ','01315521768','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 22:42:16',0,NULL,3,1,11,1,' ',NULL),(21433,911169565015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',2,'AE2401',36,'hutongstore','bathmg','davidmspeak@hotmail.com','David Speak','42 Penn lea Road','Bath','Somerset','UNITED KINGDOM','BA13RB','01225314865','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-15 23:21:38',0,NULL,3,1,3,1,'RA184540597CN ',' 两个 英标 '),(21434,770120478001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',2,'AE3403',75.9,'hermeshine','mr_irresi8ble','hungtrinh@live.com.au','Hung Trinh','7/166-168 Meadows Road','Mount Pritchard','New South Wales','AUSTRALIA','2170','0423060919','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-15 23:49:34',0,NULL,3,1,4,1,'YW867739612CN ','▲ '),(21435,774335396018,280727838751,'Soft Camera Cover protector S for Nikon D3100 18-55mm',1,'AD1171',7.99,'photographyacc','lourdes2009edwin','joshuatv10@yahoo.com','Edwin Thillet','1722 Calle Augusta<br>San Gerardo','San Juan','Puerto Rico','PUERTO RICO','00926-3467','(787) 466-8828','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-15 23:57:49',0,NULL,3,1,11,1,NULL,NULL),(21436,774345395018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',30,'photographyacc','blondishbird','janoo77@hotmail.com','Jan Wise','93 Black Pinch Road','Pomona','Queensland','AUSTRALIA','4568','0754850677','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 00:27:19',0,NULL,3,1,3,1,'RA184540583CN ',NULL),(21437,774378903018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','tarlie144','paris.jager@hotmail.com','Paris Jager','65 Venice Street','Burleigh Waters','Queensland','AUSTRALIA','4220','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-16 02:17:02',0,NULL,5,0,18,0,NULL,'白+黑 '),(21438,8881324001928791,111,'EW-78D',1,'AA3405',0,'hermeshine','sptopher','christoph.spragg@gmail.com','Christoph Spragg','3 The Barbette','Castlecrag','New South Wales','AUSTRALIA','2068','6104316911',NULL,NULL,NULL,'2011-12-16 02:18:48',0,NULL,3,1,3,1,'RA184540566CN ','上次发了EW-73B,一定别再错了 '),(21439,8881324005025950,111,'HB-7',5,'AA1216',0,'hermeshine','happyjaya','theoriginaldj@yahoo.com','Danang Jaya','Jl.Perdagangan, No:14A<br>Bintaro','Jakarta Selatan','JKT','INDONESIA','12330','+628388381500',NULL,NULL,NULL,'2011-12-16 03:10:25',0,NULL,3,1,3,1,'RA184540570CN ',NULL),(21440,774404058018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','murray_at_savi','endreconsulting@gmail.com','murray irwin','unit 23 48 Harrison Street','Brunswick East','Victoria','AUSTRALIA','3057','0412113059','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 04:06:08',0,NULL,3,1,17,0,NULL,NULL),(21441,774403202018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','murray_at_savi','endreconsulting@gmail.com','murray irwin','unit 23 48 Harrison Street','Brunswick East','Victoria','AUSTRALIA','3057','0412113059','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 04:06:08',0,NULL,3,1,17,0,NULL,NULL),(21442,832836199017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','murray_at_savi','endreconsulting@gmail.com','murray irwin','unit 23 48 Harrison Street','Brunswick East','Victoria','AUSTRALIA','3057','0412113059','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 04:06:09',0,NULL,3,1,17,0,NULL,NULL),(21443,774403436018,280666852926,'Photo Studio Light Stand Heavy Duty Clamp Copper head  ',2,'AE3102',20,'photographyacc','murray_at_savi','endreconsulting@gmail.com','murray irwin','unit 23 48 Harrison Street','Brunswick East','Victoria','AUSTRALIA','3057','0412113059','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 04:06:09',0,NULL,3,1,17,0,NULL,' '),(21444,774403642018,280676697206,'New Multi Purpose Heavy Spring Clamp with Ball head',1,'AE3103',13,'photographyacc','murray_at_savi','endreconsulting@gmail.com','murray irwin','unit 23 48 Harrison Street','Brunswick East','Victoria','AUSTRALIA','3057','0412113059','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 04:06:10',0,NULL,3,1,4,1,'YW867738772CN ','反光板支架    1\r 斜臂     1                     ▲\r反光板  80cm 5合1   1\r大力夹云台     1\r大力夹    2'),(21445,770194942001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','marcostomasi','mctomasi00@yahoo.com.br','Marcos Cleber Tomasi','Rua José Rossini Nº 424<br>Bairro Santa Helena','Bento Goncalves','Rio Grande do Sul','BRAZIL','95700000','54 3454 1547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 04:09:56',0,NULL,3,1,3,1,'RA184540835CN ',NULL),(21446,832856944017,270855429801,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',28.9,'photographyacc','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100<br>Tel 8(912)939-43-61','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','(912)936-07-29','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 05:01:23',0,NULL,3,1,3,1,'RA184540844CN ',NULL),(21447,813583624002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','03181991','oldcop1@hotmail.com','Robert P. Schoen','14 Jeanne Dr','Tunkhannock','PA','UNITED STATES','18657-9592','(570) 836-3004','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-16 05:15:22',0,NULL,3,1,1,1,NULL,'新地址\rRobert Schoen\r2523 S memorial drive\rGreenville, NC 27834\rUNITED STATES\r '),(21448,774433542018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','ecochampions','ecochamps@gmail.com','Bing Da Xu','6 Shaun Court','Springvale','Victoria','AUSTRALIA','3171','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-16 05:53:41',0,NULL,3,0,11,1,NULL,'白色 '),(21449,770217564001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','nib_floyd','nib_floyd@hotmail.com','Samantha Kornoski','805 Keller St','Plano','IL','UNITED STATES','60545-1489','(630) 862-5799','NoPaymentFailure','CheckoutComplete','Other','2011-12-16 05:58:54',0,NULL,3,1,1,1,NULL,' 已入库'),(21450,8881324024583326,111,'72mm 橡胶罩',1,'AB1306',0,'hermeshine','dcalbrecht','dave@dcdadvancedtech.com','Dave Albrecht','14 Hudson Dr','New Windsor','NY','UNITED STATES','12553-7427','(914) 455-4243',NULL,NULL,NULL,'2011-12-16 08:36:23',0,NULL,3,1,1,1,'LK124842666CN ',NULL),(21451,770258298001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','magicla32','llremola@msn.com','Lluís Remolà Pagès','C/ Església, nº3  2º','Sant Feliu de Llobregat','Barcelona','SPAIN','08980','600488883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:24:29',0,NULL,3,1,17,0,NULL,NULL),(21452,770253879001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','magicla32','llremola@msn.com','Lluís Remolà Pagès','C/ Església, nº3  2º','Sant Feliu de Llobregat','Barcelona','SPAIN','08980','600488883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:24:30',0,NULL,3,1,17,0,NULL,NULL),(21453,769823919001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','magicla32','llremola@msn.com','Lluís Remolà Pagès','C/ Església, nº3  2º','Sant Feliu de Llobregat','Barcelona','SPAIN','08980','600488883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:24:31',0,NULL,3,1,17,0,NULL,NULL),(21454,813634054002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','magicla32','llremola@msn.com','Lluís Remolà Pagès','C/ Església, nº3  2º','Sant Feliu de Llobregat','Barcelona','SPAIN','08980','600488883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:24:32',0,NULL,3,1,17,0,NULL,NULL),(21455,813629221002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','magicla32','llremola@msn.com','Lluís Remolà Pagès','C/ Església, nº3  2º','Sant Feliu de Llobregat','Barcelona','SPAIN','08980','600488883','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:24:30',0,NULL,3,1,4,1,'YW867739590CN ','115w 5500k 灯泡  220v   1 \r眼罩 450D/500D    1\r新款内胆包 中号 canon logo    1\r2m 灯架  1                 ▲\r单灯头  欧标    1\r反光伞    1\rew-73b    1'),(21456,813641885002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','arkadiykr','krasnoyarovi@gmail.com','Arkadiy Krasnoyarov','Mangeldina 44- 70','Shymkent','UKO','KAZAKHSTAN','160005','+77057003142','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 09:52:02',0,NULL,3,1,3,1,'RA184545033CN ',''),(21457,774496282018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',3.4,'photographyacc','jcars64','jcars@sapo.pt','Jose Carlos  F. Silva','Rua  do  Pinheiro  Nº1','Leiria','Maceira lis','PORTUGAL','2405-008','351964318215','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 10:27:35',0,NULL,3,1,11,1,NULL,'不挂号  '),(21458,892693220016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','thee-ou','pascal.wibaut@gmail.com','Pascal Wibaut','rue du Ham 139','Bruxelles','','BELGIUM','1180','0477-398308','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-16 11:06:34',0,NULL,3,1,17,0,NULL,NULL),(21459,892692305016,260838264614,'New Large High quality heavy duty sand bag Empty',4,'AD1168',35.96,'hutongstore','thee-ou','pascal.wibaut@gmail.com','Pascal Wibaut','rue du Ham 139','Bruxelles','','BELGIUM','1180','0477-398308','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-16 11:06:35',0,NULL,3,1,17,0,NULL,NULL),(21460,911393331015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','thee-ou','pascal.wibaut@gmail.com','Pascal Wibaut','rue du Ham 139','Bruxelles','','BELGIUM','1180','0477-398308','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 11:06:35',0,NULL,3,1,17,0,NULL,' '),(21461,892693031016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','thee-ou','pascal.wibaut@gmail.com','Pascal Wibaut','rue du Ham 139','Bruxelles','','BELGIUM','1180','0477-398308','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 11:06:36',0,NULL,3,1,4,1,'YW868053120CN\r','2mx1.5m 背景板（黑，白）     1\r沙袋（大）          4\r透明10片装盒     1              ▲\r天涯方形滤镜  渐变灰    1\r方形滤镜接口环 58mm   1\r方镜普通托架（三槽）     1\r\r\r\r\r'),(21462,774512224018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','rebelhaft','rebel_haft@mail.ru','Pavel Barsukov','Adoratskogo 66, 92','Kazan','Tatarstan','RUSSIAN FEDERATION','420137','+79600433308','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 11:23:23',0,NULL,3,1,3,1,'RA184545149CN ',NULL),(21463,813660018002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','rubydazle','kitty24@live.co.uk','D etherington','12 princess way','wellingborough','Northamptonshire','UNITED KINGDOM','nn8 2hj','01933381644','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 11:30:08',0,NULL,3,1,11,1,NULL,'不挂号  '),(21464,911417196015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','mrmtudor','mrmtudor@yahoo.co.uk','Mike Tudor','6 Peverel Drive','Whittington','Shropshire','UNITED KINGDOM','Sy114pn','07540735944','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 12:15:05',0,NULL,3,1,11,1,NULL,'不挂号  '),(21465,892746803016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','arturbaikov','baikovartur@yandex.ru','Artur Baikov','Kyivskaya 25-29','Zhytomyr','','UKRAINE','10014','380412471753','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 13:28:31',0,NULL,3,1,11,1,NULL,'不挂号  '),(21466,911450953015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','erfpusher','blackpowderman@smartemail.co.uk','geoffrey may','12 elm rd','bishops waltham','Hampshire','UNITED KINGDOM','so321jr','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 13:30:17',0,NULL,3,1,11,1,NULL,'不挂号  '),(21467,770331900001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','tontoncedric94','cjappont@hotmail.com','cedric jappont','6 résidence des closeaux','RUNGIS','Île-de-France','FRANCE','94150','0662799677','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 13:42:17',0,NULL,3,1,11,1,' ','不挂号  '),(21468,911485029015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','samgy1','sami.laine@hotmail.com','Sami Laine','orapihlajanpolku 1 b 32','vantaa','Finland','FINLAND','01360','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 14:49:43',0,NULL,3,1,3,1,'RA184545016CN ',NULL),(21469,813766466002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','mapagkakatiwalaan*','karol_tan@yahoo.com','karol lyn sangil','villa no. 3, Garden City<br>khalidiya','Abu Dhabi','Abu Dhabi','UNITED ARAB EMIRATES','42311','0552362279','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-16 16:07:51',0,NULL,3,1,3,1,'RA184545020CN ','新地址:\rkarol lyn sangil\rvilla no. 3, Garden City\rkhalidiya\rAbu Dhabi Abu Dhabi POBOX: 42311\rUNITED ARAB EMIRATES\r0552362279 '),(21470,911565385015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','harlequin-tusk','petevals3@optonline.net','PETER C VARLEY','24 Ronald Ln','SYOSSET','NY','UNITED STATES','11791-3517','(516) 802-2578','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-16 17:16:09',0,NULL,3,1,1,1,NULL,NULL),(21471,770449000001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','apox201','blairsmith201@gmail.com','Blair Smith','17 Wellington','Appin','ON','CANADA','N0L1A0','(519) 955-1766','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-16 18:28:53',0,NULL,3,0,3,1,'RA184545237CN ','L (  '),(21472,813833213002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','africazzr','thierry.brunetzzr@laposte.net','thierry brunet','3 bis rue des Blaisis','charge','Centre','FRANCE','37530','0247575044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:31:49',0,NULL,8,1,17,0,NULL,NULL),(21473,774691581018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',21.98,'photographyacc','alejonimo','monfry90@hotmail.com','alejandro nieto monfrino','ministerio de la vivienda b/7-9d','malaga','malaga','SPAIN','29010','667541654','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 18:41:14',0,NULL,3,1,3,1,'RA184545095CN ','白 + 黑 '),(21474,606437626004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','africazzr','thierry.brunetzzr@laposte.net','thierry brunet','3 bis rue des Blaisis','charge','Centre','FRANCE','37530','0247575044','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 18:31:49',0,NULL,3,1,11,1,NULL,'EW-73B   1 \rMini 红外  canon     1\r不挂号 '),(21475,813848261002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','tonyecs','tonycoutinho@terra.com.br','Tony Coutinho','Conj. Ilha de Sao Joao, BL-12D, Ap 302','Salvador','BA','BRAZIL','40800-095','32165522','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 19:01:24',0,NULL,3,1,11,1,' ','不挂号  '),(21476,770469633001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','opahujo','hmkann@mchsi.com','Hugo M. Kann','2320 Kings Ct','Marion','IA','UNITED STATES','52302-1445','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-16 19:04:37',0,NULL,3,1,1,1,NULL,NULL),(21477,770505586001,110566021188,'New TianYa Graduated Gray Filter & Ring & Holder',1,'AKT028',10.99,'hermeshine','perroviejo69','surferrider1@hotmail.com','maximiliano galinelli','carretera gral nº4 edificio prat de la solana bloque 1,piso 3º4º','erts ( la massana)','andorra la vella','ANDORRA','AD400','00376622594','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 20:13:11',0,NULL,3,1,11,1,NULL,'不挂号  '),(21478,910375726015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','michaldnb','michal@breakbeat.sk','Michal Cvik','6<br>Hyperion Walk','Horley','Surrey','UNITED KINGDOM','RH6 7DA','07747194873','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 20:53:59',0,NULL,3,1,11,1,' ','不挂号  '),(21479,911718746015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','pooh_monster','poohmonster@btinternet.com','IAN ONEILL','BRYN SERCHOG','GELLILYDAN','Gwynedd','UNITED KINGDOM','LL41 4EG','07761099472','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-16 21:13:36',0,NULL,3,1,3,1,'RA184545152CN ',NULL),(21480,770553051001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','marcostomasi','mctomasi00@yahoo.com.br','Marcos Cleber Tomasi','Rua José Rossini Nº 424<br>Bairro Santa Helena','Bento Goncalves','Rio Grande do Sul','BRAZIL','95700000','54 3454 1547','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 21:53:42',0,NULL,3,1,3,1,'RA184545104CN ',NULL),(21481,812900969002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','arch1972','arch72@aol.com','ACHILEAS F','PO Box 73','NEW PORT RICHEY','FL','UNITED STATES','34656-0073','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-16 22:18:38',0,NULL,3,1,3,1,'RA184545121CN ',NULL),(21482,770564030001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','machino94','jplm94@hotmail.fr','jean-pascal le mevel','16 E rue de chennevieres','VILLIERS SUR MARNE','Île-de-France','FRANCE','94350','06 20 36 44 12','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-16 22:19:23',0,NULL,3,1,11,1,NULL,'不挂号  '),(21483,833263329017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','stedeutscher','stefan_deutscher@yahoo.com','Stefan Neamtu','sat Valeni-Podgoria, nr.339','Calinesti','Arges','ROMANIA','117207','+40733422822','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-16 22:26:04',0,NULL,3,1,11,1,NULL,'不挂号  '),(21484,813985965002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',50,'hermeshine','bardurbardur','bardurthomassen@hotmail.com','Bardur Thomassen','Rasmusargøta 10','Midvagur','Faroe Island','DENMARK','0370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 00:07:38',0,NULL,3,1,3,1,'RA184545254CN ','环换成 77mm的   已入库'),(21485,8881324085010920,111,'麂皮',1,'',0,'hermeshine','sk8suffer','sufferskateboards@yahoo.com','Craig Jefferson','9114 Marlove Oaks Ln','owings mills','MD','UNITED STATES','21117-6709','(443) 825-6462',NULL,NULL,NULL,'2011-12-17 01:23:30',0,NULL,3,0,1,1,'LK108653964CN ','需要仔细检查,我来 '),(21486,774867863018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','yuyox11','yuyox11@hotmail.com','Julio Rivera','951 Brickell ave<br>Apt 2011','Miami','FL','UNITED STATES','33131-3937','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 01:47:53',0,NULL,3,1,1,1,NULL,NULL),(21487,814019868002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','oscardeluca','oscrin@hotmail.com','oscar Christiansen','langgata 23c','Porsgrunn','Telemark','NORWAY','3920','047 99227221','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 02:11:33',0,NULL,3,1,11,1,NULL,'不挂号  '),(21488,770634706001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','laplantafer','laplantafer@hotmail.com','Fernando Uribe','4601 Garden Point Trl','Wellington','FL','UNITED STATES','33414-7423','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-17 02:17:58',0,NULL,3,1,1,1,NULL,NULL),(21489,833347985017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',1,'AA1203',2.9,'photographyacc','missis_pink','pink_3_faith@yahoo.com','Pamela Reid','RR2','Crossfield','AB','CANADA','T0M 0S0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 02:51:39',0,NULL,3,1,11,1,NULL,'不挂号  '),(21490,774896861018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','davewill64','mrdavidwillie@gmail.com','Dave Willie','7 Brighton Retreat','Berwick','Victoria','AUSTRALIA','3806','0403235621','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 03:43:56',0,NULL,3,1,11,1,NULL,'不挂号  '),(21491,774902505018,280683074803,'New Camera Body and Rear Lens Cap for CANON EOS EF',1,'AA1315',2.99,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/49 DOLPHIN AVE','MERMAID BEACH','Queensland','AUSTRALIA','4218','0435010514','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 04:08:55',0,NULL,3,1,17,0,NULL,NULL),(21492,833369479017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',3,'AA1310',17.85,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/107 sunshine blvd','MERMAID waters','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 04:17:10',0,NULL,3,1,17,0,NULL,NULL),(21493,774926764018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/107 sunshine blvd','MERMAID waters','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 06:16:14',0,NULL,3,1,17,0,NULL,NULL),(21494,774931230018,280674079821,'New 77mm Snap-on Front Lens Cap for Canon 77 mm lenscap',2,'AA1304',5,'photographyacc','jobapro','jobaprophoto@y7mail.com','BRETT CUNLIFFE','1/107 sunshine blvd','MERMAID waters','Queensland','AUSTRALIA','4218','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-17 06:42:47',0,NULL,3,1,3,1,'RA184545166CN ','机身盖/镜头后盖  Canon   1\rlenspen    3\ryongnuo无线 YN159-C3    1\rCANON 镜头盖  77mm     2\r肥皂盒 580EX   3\r\r\r\r '),(21495,814077251002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','tyu81','tyu626@charter.net','timohty yu','9137 ralph st','rosemead','CA','UNITED STATES','91770-1941','(626) 675-1823','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-17 06:45:49',0,NULL,3,1,1,1,NULL,NULL),(21496,770720933001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','mrdavium','david.dm@live.it','David Di Maria','Via Melone 209','Santa Maria a Monte','PI','ITALY','56020','05877114420','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 09:40:02',0,NULL,3,0,4,1,'YW867739601CN ','白+黑 \r▲'),(21497,911971701015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','telepuza2010','falko2003@ukr.net','Sergey Gaevsky','Lenina 7 ap 43','Tiraspol','MD Moldova','MOLDOVA, REPUBLIC OF','3300','+37353351276','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 10:14:29',0,NULL,3,1,3,1,'RA184545183CN ',NULL),(21498,814169341002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','duminda70','mewan70@gmail.com','Duminda Epasinghe','Nestle Lanka PLC.,<br>440, T. B. Jayaha Mawatha','Colombo 10','Western Province','SRI LANKA','01000','+94777418036','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 12:50:56',0,NULL,3,1,3,1,'RA184545118CN ',NULL),(21499,770794079001,110750767778,'New Camera Case Shoulder Bag PU Leather for Canon 5D ii 7D 60D 40D Strong',1,'AD1201',55,'hermeshine','aviv01','shalyasayag@gmail.com','sigal  asayag','10130 NW 13th St','plantation','FL','UNITED STATES','33322-6528','(954) 667-8793','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 13:38:49',0,NULL,3,1,3,1,'RA184545170CN ',NULL),(21500,912075951015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','azholbek','azholbek@hotmail.com','Anna Holbek','15 MANOR DRIVE<br>DUNNINGTON','YORK','North Yorkshire','UNITED KINGDOM','YO19 5QR','07921151215','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 14:25:36',0,NULL,3,1,11,1,' ','不挂号  '),(21501,814215675002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','ffuffe','ffuffe@hotmail.com','jose  gonzalez moreno','padura 3, 3º D','elorrio','País Vasco','SPAIN','48230','666 81 29 22','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 14:52:09',0,NULL,3,1,3,1,'RA184545055CN ',NULL),(21502,814218809002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','runmaximus2oo9','ms330005@ohio.edu','Max Stier','2227 W County Road 250 S','Connersville','IN','UNITED STATES','47331-8762','(513) 378-4658','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-17 15:00:38',0,NULL,3,1,3,1,'RA184545047CN ',NULL),(21503,770836685001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','cortescorcuera55','cortescorcuera@gmail.com','Laura Corcuera','C/ Francisco Cantera Nº 4- 6d','Miranda De Ebro','BURGOS','SPAIN','09200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 15:28:58',0,NULL,3,1,11,1,NULL,'不挂号  '),(21504,833587904017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',6,'AA1301',15,'photographyacc','bentsfoto','hollohan1985@hotmail.com','Quinn Hollohan','99 Wyndham St. North','Guelph','ON','CANADA','N1H4E9','(519) 823-5610','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-17 16:14:00',0,NULL,3,1,3,1,'RA184545245CN ',NULL),(21505,912140475015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','ebay2sho','ebay@sigls.net','Bernd Sigl','Am Auwald 17','Ismaning','','GERMANY','85737','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-17 16:30:45',0,NULL,3,1,3,1,'RA184545081CN ',NULL),(21506,770873539001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','lhchd','lhchd@aol.com','H Keith Erickson','1810 Hillside Dr NW','Cedar Rapids','IA','UNITED STATES','52405','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-17 16:48:43',0,NULL,3,1,1,1,NULL,NULL),(21507,912224164015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','m0rdc','robertcooke1964@tiscali.co.uk','robert d cooke','1 fiona walk','liverpool','Merseyside','UNITED KINGDOM','L10 4YW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-17 18:35:08',0,NULL,3,1,3,1,'RA184540994CN ',NULL),(21508,770932569001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','carmelolarra','carmelolarra@yahoo.es','Carmelo Larrabide Barquin','Los caserios nº8.Portal1 4ºA','Castro Urdiales','Cantabria','SPAIN','39700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 18:38:13',0,NULL,3,1,3,1,'RA184540977CN ',NULL),(21509,814338297002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','redjeepgirl1','redjeepgirl1@yahoo.com','Michelle Appleton','39 6100 Old Vernon Rd','Kelowna','BC','CANADA','v1x 7t8','(250) 765-7262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 19:01:16',0,NULL,3,1,3,1,'RA184545078CN ','1.6x3m  背景布   黑色    1 '),(21510,814337223002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','redjeepgirl1','redjeepgirl1@yahoo.com','Michelle Appleton','39 6100 Old Vernon Rd','Kelowna','BC','CANADA','v1x 7t8','(250) 765-7262','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 19:01:17',0,NULL,3,1,3,1,'RA184545064CN ','\r800w红头灯        1\r800w  110v 灯泡   1\r '),(21511,770948455001,110664971893,'GGS Glass LCD Screen Protector for Canon 550D',1,'AB2210',7.6,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 19:07:24',0,NULL,3,1,17,0,NULL,NULL),(21512,770948456001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 19:07:25',0,NULL,3,0,17,0,NULL,NULL),(21513,770948457001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 19:07:25',0,NULL,3,0,17,0,NULL,NULL),(21514,770948458001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 19:07:26',0,NULL,3,1,17,0,NULL,NULL),(21515,770951367001,110569964443,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',66,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-17 19:10:29',0,NULL,3,0,17,0,NULL,NULL),(21516,770951369001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 19:10:29',0,NULL,3,1,17,0,' ',' '),(21517,770951370001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-17 19:10:30',0,NULL,3,1,5,1,'CP211275647CN ','GGS 550D     1\r灯架  2m    4\r3m 横杆(通用4节)    2\r灯架包薄    2\r背景布 3x6 绿色   2\r4灯头 灯头 孔     4\r50cmx70cm 的柔光箱 (配4灯头）4\r\r\r\r '),(21518,8881324167390622,111,'110cm 反光伞',1,'AD1126',0,'hermeshine','deliusbrazil-10','deliotech@gmail.com','Mario Barboza','Rua Alexandre Herculano, 63 ap.12 Boqueirao','Santos','Sao Paulo','BRAZIL','11050-030','55 13 32233564',NULL,NULL,NULL,'2011-12-18 00:16:30',0,NULL,3,1,3,1,'RA184545135CN ',NULL),(21519,814485821002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','zosomilby','tollyman50@aol.com','Ian Milby','24695 Deer Ridge Ln','athens','AL','UNITED STATES','35613-5380','(256) 216-8300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 00:33:18',0,NULL,3,1,4,1,'YW867739575CN ','▲ '),(21520,8881324168931565,111,'52mm 渐变灰',1,'AA3315',0,'hermeshine','tyler*anderson','tyland18@hotmail.com','Tyler Anderson','Suite 202 - 10012 97th Avenue','Fort St. John','BC','CANADA','V1J 5P3','(250) 793-9502',NULL,NULL,NULL,'2011-12-18 00:42:11',0,NULL,3,1,3,1,NULL,'需要仔细检查镜面,我来吧 '),(21521,775356207018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','emidigital','emidigital@gmail.com','Emilio Suarez Rodriguez','Pedrouzo nº2 <br>Bertola','Pontevedra','Galicia','SPAIN','36140','630052758','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-18 00:43:35',0,NULL,3,0,11,1,NULL,'白色 \r不挂号 '),(21522,771091898001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','jillo2510','jill@peregrineadventures.com','Gillian Blunsom','15  Charlotte  Pl<br>1','St Kilda','Victoria','AUSTRALIA','3182','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 00:45:15',0,NULL,3,1,11,1,NULL,'不挂号  '),(21523,912442555015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','javialippi','marumaru109@hotmail.com','carlos javier alippi','calle rio duero nº 63 4º B','Leganes','Madrid','SPAIN','28913','676547591','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 01:02:02',0,NULL,3,1,11,1,NULL,'不挂号  '),(21524,814497022002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','creativejuan','ema8720@gmail.com','Juan Correa','1908 Bahamas Dr<br>Apt 1','Edinburg','TX','UNITED STATES','78541-3940','(956) 207-4632','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 01:09:38',0,NULL,3,1,3,1,'RA184545197CN ',NULL),(21525,893718320016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','ciarandciaran','gociaran_go@live.ie','ciaran devine','drummucklagh','raphoe','Donegal','IRELAND','','0749144883','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 01:23:18',0,NULL,3,1,11,1,' ','不挂号  '),(21526,771114614001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','cure4commoncold','drewswisher@gmail.com','Andrew Swisher','43 Hartford St','Westover','WV','UNITED STATES','26501-4311','(304) 282-1223','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-18 02:09:16',0,NULL,3,1,3,1,'RA184540963CN ',NULL),(21527,893735165016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','huatao1975','huatao86@hotmail.com','Hua Tao','386 Bell St','Preston','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-18 02:15:36',0,NULL,3,1,17,0,NULL,NULL),(21528,912483347015,250599424828,'77mm Snap-on Front Cap for Nikon 77mm Filters Lens New',1,'AA1309',1.88,'hutongstore','mrl-2k7','penege@gmail.com','Miguel Rodriguez Lago','Bulevar Jose Prat 9B, 5A','MADRID','Madrid','SPAIN','28032','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 03:06:22',0,NULL,3,1,11,1,' ','不挂号 '),(21529,893762316016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','huatao1975','huatao86@hotmail.com','Hua Tao','386 Bell St','Preston','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 03:45:36',0,NULL,3,1,4,1,'YW867739586CN ','2mx1.5m 背景板（黑，白）    1 \r150-200cm 5in1 反光板    1\r▲'),(21530,770883624001,110467740275,'New Camera Tripod Fancier FT-6662A with 6160H Ball head',1,'AE1503',79.99,'hermeshine','toshka-lnk','telecom-lnk@mail.ru','Anton Novikov','pr.Tekstilshikov, dom 4/1, kv 33','Leninsk-Kuzneckii','Kemerovskaya obl','RUSSIAN FEDERATION','652523','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-18 03:51:06',0,NULL,3,1,5,1,'CP211275491CN ',NULL),(21531,814540934002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','manamer','casilladecorreo@fibertel.com.ar','Hernan Ferreiro','Mercedes 1564','Buenos Aires','CAPITAL FEDERAL','ARGENTINA','1407','54-011-4639-5287','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-18 03:52:12',0,NULL,3,1,3,1,'RA184545223CN ','L 号 已入库 '),(21532,814633639002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','heidionfirepix','heidionfire@yahoo.com','Heidi Pultar','227<br>North West Arm Road','GRAYS POINT','New South Wales','AUSTRALIA','2232','0419187152','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 10:22:15',0,NULL,3,1,3,1,'RA184545206CN ',NULL),(21533,814694557002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',4,'AA1310',21.96,'hermeshine','jerashka','manzanka22@gmail.com','Yury Pogudaev','Leningradskiy prospekt, 13, 69','Moscow','Moscow','RUSSIAN FEDERATION','125040','(926) 1882023','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:06:35',0,NULL,3,1,11,1,' ','不挂号  '),(21534,775573667018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',25.99,'photographyacc','neononacyvane','neononac@gmail.com','Angel Francisco Perez Castello','Juan Ramon Jimenez 84  2-E','Castellon','Comunidad Valenciana','SPAIN','12006','964069697','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-18 13:09:21',0,NULL,3,1,17,0,NULL,NULL),(21535,775573353018,280774576148,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',37.99,'photographyacc','neononacyvane','neononac@gmail.com','Angel Francisco Perez Castello','Juan Ramon Jimenez 84  2-E','Castellon','Comunidad Valenciana','SPAIN','12006','964069697','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-18 13:09:22',0,NULL,3,1,4,1,'YW867739553CN ','灯架  2m   1 \r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）   1\r欧标\r▲\r'),(21536,771308191001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100<br>Tel 8(912)939-43-61','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','(912)936-07-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 13:26:20',0,NULL,3,1,3,1,'RA184541005CN ',NULL),(21537,775598254018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','kirra03','dkirra03@yahoo.com.au','Tanya Daley:/Compass Building Inspections','Unit 10 / 1015 Nudgee Road,','Banyo','Queensland','AUSTRALIA','4014','0412411210','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-18 13:57:45',0,NULL,3,1,4,1,'YW867739564CN ','没有查询记录，已经重发了 '),(21538,814758268002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','fisker10','olore@sfjbb.net','Oyvind Lorentzen','Guttorm Jarlsvei 28','Sandefjord','','NORWAY','3221','+4790726210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 14:50:09',0,NULL,3,1,11,1,NULL,'不挂号  '),(21539,834134155017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',1,'AD1126',14.5,'photographyacc','grasan8','shiny8@optusnet.com.au','sandra scholte','77 Osborne Ave','umina beach','New South Wales','AUSTRALIA','2257','0243425283','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-18 14:51:11',0,NULL,3,1,11,1,' ','不挂号  '),(21540,814762738002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','kievgreatdeals','glizz@ukr.net','Gryn Dmytro','Lomonosova st, 55, apt #811','Kiev','UA','UKRAINE','03022','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 14:58:23',0,NULL,3,1,11,1,NULL,' 不挂号 '),(21541,814767064002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','2010inli','inge_lie@mac.com','Inge Lie','Hoelveien 8','Ski','','NORWAY','1400','0047 90528230','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 15:05:42',0,NULL,3,1,11,1,' ','2个 \r不挂号 '),(21542,775691534018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','tigger9431','x_pert@bigpond.com','Cherie Flanagan','7/9 Tristania Street<br>\"Windsor-on-Streeton\"','Rivett','Australian Capital Territory','AUSTRALIA','2611','0262877251','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-18 16:33:48',0,NULL,3,1,4,1,'YW867738783CN ','▲ '),(21543,814854542002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dzedushka','tdvplus@gmail.com','Dmitry Tiunchik','pereulok Adahovskiy dom 8','Baranovichi, Brestskaya oblast','','BELARUS','225417','+375295251210','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 17:14:13',0,NULL,3,1,11,1,NULL,'不挂号 '),(21544,814862460002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dzedushka','tdvplus@gmail.com','Yuriy Titov','ul. Kommunisticheskaya dom 15 kvartira 44','Baranovichi','Brestskaya oblast','BELARUS','225415','+375-29-6414508','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 17:23:55',0,NULL,3,1,11,1,NULL,'不挂号 \r'),(21545,775798629018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','matthew_carr','me@matthewcarr.us','Matthew Carr','20 Alyssa Dr','Lowell','MA','UNITED STATES','01851-2342','(978) 257-3729','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-18 18:36:09',0,NULL,3,1,1,1,NULL,NULL),(21546,913015985015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','nattefreak','jonst309@gmail.com','Jonathan Stoltz','Bodekullsgatan 29b','Malmö','Malmö','SWEDEN','21440','0735-440345','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 19:06:35',0,NULL,3,1,11,1,' ','不挂号  '),(21547,894365743016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',1.6,'hutongstore','damon_666','bellevue.de.sylva@gmail.com','damon de sylva','7 Hambleton Close, Longton','Preston','Lancs','UNITED KINGDOM','PR4 5DQ','01772617518','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 20:19:45',0,NULL,3,1,11,1,NULL,'不挂号  '),(21548,913175648015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','s_h_e_r_i_f_f_o','grzegorz.szarkiewicz@googlemail.com','Gregory Szarkiewicz','Watt\'s Close 4c','Musselburgh','Midlothian','UNITED KINGDOM','EH21 6AW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 21:32:10',0,NULL,3,1,3,1,'RA184540915CN ',NULL),(21549,913193931015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','la-malle-aux-tresors0609','la-malle-aux-tresors@hotmail.fr','kétline Schmitt','144 Rue des cordeliers','Moyenneville','Picardie','FRANCE','60190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 21:57:06',0,NULL,3,1,3,1,'RA184540929CN ',NULL),(21550,913196721015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','trelvis001','trevorwilliams@bigfoot.com','Trevor P Williams','606 New Chester road','Bromborough','Wirral','UNITED KINGDOM','CH62 2AZ','0151343101','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-18 21:59:21',0,NULL,3,1,3,1,'RA184540985CN ',NULL),(21551,815117212002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 22:12:50',0,NULL,3,1,3,1,'RA184540932CN ',NULL),(21552,912636290015,250692240063,'Remote Control Cord 4 Sony a700 a350 a300 a900 RM-S1AM',1,'AA3212',2.52,'hutongstore','zedthedragon','zedthedragon@voila.fr','CYRIL COUTURE','50 AVENUE DE ROBINSON','LE PLESSIS ROBINSON','Île-de-France','FRANCE','92350','0616306199','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 23:16:34',0,NULL,3,1,11,1,NULL,'不挂号  '),(21553,894512160016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','geleeuw','g.leeuwenburg@xs4all.nl','Gerard Leeuwenburg','de Does 4','PIJNACKER','','NETHERLANDS','2642KT','0624119483','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-18 23:48:45',0,NULL,3,1,11,1,' ','不挂号 '),(21554,771743871001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','plorenzo29','plorenzog@gmail.com','Paul Eduardo Lorenzo Gallardo','Jr. Tiahuanaco nº 889 Urb. Zarate','Lima','Lima','PERU','Lima 36','(511)489-0497','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-18 23:58:31',0,NULL,3,1,5,1,'CP211275505CN ','1.6*2.1 白色背景布 \r美标'),(21555,8881324260255291,111,'配4灯头的50x70棚',1,'',0,'hermeshine','ihti','ihti@ureach.com','Ehtisham ul Haq','7655 Terrasse Saint Roch # 5','Montreal','QC','CANADA','H3N 1Z6','(514) 270-1276',NULL,NULL,NULL,'2011-12-19 02:04:15',0,NULL,3,0,3,1,'RA184545308CN ',NULL),(21556,815239301002,120824638021,'Brand New Lens Repair Tool Stainless Steel Spanner Wrench with swap-able tips',1,'AD1207',40,'hermeshine','start_collecting','o8i8o@msn.com','Thitinant Thanyavimol','513/65 Charansanitwong 37 rd.<br>Bangkhunsri','Bankoknoi','Bangkok','THAILAND','10700','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 03:37:04',0,NULL,3,1,3,1,'RA184545299CN ',NULL),(21557,771820221001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','smithscottyyy','scottyysmith88@gmail.com','scott smith','6n570 fairway ln','itasca','IL','UNITED STATES','60143-1931','(708) 646-6779','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-19 03:43:53',0,NULL,3,1,1,1,NULL,NULL),(21558,776137509018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',2,'AD1120',36,'photographyacc','chosenindustries','mattdarleybentley@hotmail.com','Chosen Industries','32  Brougham  ST','East Gosford','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 05:26:39',0,NULL,3,1,11,1,NULL,NULL),(21559,8881324279683267,111,'欧标',1,'',0,'hermeshine','ben7154','freefeeling@gmail.com','Ben Baur','Kibbutz Ramat Hashofet<br>off','Kibbutz Ramat Hashofet','ISRAEL','ISRAEL','19238','97249898536',NULL,NULL,NULL,'2011-12-19 07:28:03',0,NULL,3,1,3,1,'RA184543205CN',NULL),(21560,913414807015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',22,'hutongstore','petr0nyx','petronyx@gmail.com','Dmitry Petrovsky','Kinnereth 6325','Ashdod','','ISRAEL','77700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 07:37:27',0,NULL,3,1,3,1,'RA184543117CN ',NULL),(21561,8881324280384514,111,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',187.99,'aliexpress','1005852642','michelle.chuah@gmail.com','Michelle Chuah	','No. 2, Jalan USJ 2/5K UEP Subang Jaya','Petaling Jaya	','Selangor','MALAYSIA','47610','+6 016 2801990',NULL,NULL,NULL,'2011-12-19 07:39:44',0,NULL,3,1,6,1,'EE636829422CN ','地址联系人改为”Supermodels Secrets“\rC里的东西加 “背景布 3x6 白色 * 1\"\r英标\r'),(21562,8881324280459512,111,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft',1,'AO0018',78.99,'aliexpress','1005852726','michelle.chuah@gmail.com','Michelle Chuah	','No. 2, Jalan USJ 2/5K UEP Subang Jaya','Petaling Jaya	','Selangor','MALAYSIA','47610','+6 016 2801990',NULL,NULL,NULL,'2011-12-19 07:40:59',0,NULL,3,1,17,0,NULL,''),(21563,894668463016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','naaman_1708','glenn_stargate@hotmail.com','Glenn Nor','Løkkevegen 5b','Løvenstad','raelingen','NORWAY','2006','04792089952','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-19 07:55:26',0,NULL,3,1,5,1,'CP211275616CN ','欧标 '),(21564,913419393015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','petersellers64','lkoukissa@gmail.com','leopold koukissa','208 rue saint maur','paris','Île-de-France','FRANCE','75010','01 42 03 01 41','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 07:55:32',0,NULL,3,1,3,1,'RA184543125CN ',NULL),(21565,815293753002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','hkman66','hhlo@ucdavis.edu','Damian Lo','40165 Leslie St','Fremont','CA','UNITED STATES','94538-2912','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 07:58:42',0,NULL,3,1,3,1,' RA184543134CN',NULL),(21566,771878647001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',178,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-19 08:48:24',0,NULL,3,1,5,1,'CP211275620CN\r ','除了C里面以外再发\rlenspen   1 \r1.6*2.1  蓝色背景布    1\rC里面背景布 白色\r欧标\rc里面伞换成柔光伞'),(21567,771878926001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 08:57:11',0,NULL,3,0,17,0,NULL,NULL),(21568,815303518002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 08:57:12',0,NULL,3,1,17,0,NULL,NULL),(21569,815312554002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',2,'AB3312',36,'hermeshine','2pinguelos','jvalgon@telefonica.net','Juan pedro valdes gonzález','Calle Achaman, 63','Santa Cruz de Tenerife','Canarias','SPAIN','38111','922686464','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 09:27:20',0,NULL,3,1,3,1,'RA184543695CN\r ',NULL),(21570,913463874015,250932215120,'7\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1194',18.9,'hutongstore','scottishboz','scott.bond@live.com','Scott Wooding','127 Crowborough Lane<br>Kents Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK7 6JN','01908238070','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 10:32:10',0,NULL,8,1,17,0,NULL,NULL),(21571,913463875015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','scottishboz','scott.bond@live.com','Scott Wooding','127 Crowborough Lane<br>Kents Hill','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK7 6JN','01908238070','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 10:32:10',0,NULL,3,1,3,1,'RA184543430CN ','魔术手臂7寸    1\r45w 5500k 灯泡 220v    2\r '),(21572,834746537017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',3,'AE3301',44.4,'photographyacc','jimmi_42','jimmi_42@msn.com','Mr David Hendriks','26 Bradley Street','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:43:41',0,NULL,3,1,17,0,NULL,NULL),(21573,776201230018,280683088995,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',3.4,'photographyacc','jimmi_42','jimmi_42@msn.com','Mr David Hendriks','26 Bradley Street','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:43:41',0,NULL,3,1,17,0,NULL,NULL),(21574,834733357017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',2,'AD1125',25,'photographyacc','jimmi_42','jimmi_42@msn.com','Mr David Hendriks','26 Bradley Street','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:43:42',0,NULL,3,1,17,0,NULL,NULL),(21575,776133323018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','jimmi_42','jimmi_42@msn.com','Mr David Hendriks','26 Bradley Street','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:43:42',0,NULL,3,1,17,0,NULL,NULL),(21576,776202388018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',2,'AKT069',120,'photographyacc','jimmi_42','jimmi_42@msn.com','Mr David Hendriks','26 Bradley Street','Springwood','Queensland','AUSTRALIA','4127','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:43:43',0,NULL,3,1,4,1,'YW868052490CN ','一转四 灯头   3 \rMini 红外  canon   1\r柔光伞110cm   2   ▲\r反光板支架   1\r115w 5500k 灯泡  220v   8'),(21577,776203634018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','violinsandsilk','answers@violinsandsilk.com','Peter and Kim Colbourne','5 South Arm Rd','Rokeby','Tasmania','AUSTRALIA','7019','0427751975','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 10:45:29',0,NULL,3,1,3,1,'RA184543443CN ',NULL),(21578,771913470001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','allsaz25','allsaz@mail.ru','Alexander Sazonov','Kirova street 93a - 110','Vladivostok','Primorsky','RUSSIAN FEDERATION','690068','89025217574','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 11:14:57',0,NULL,3,1,5,1,'CP211275593CN ',NULL),(21579,776213482018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','bensonbrowndog','annagray04@hotmail.com','T & A Gray','8 Konara Drive','LOGANHOLME','Queensland','AUSTRALIA','4129','0416243095','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 11:25:55',0,NULL,3,0,11,1,NULL,'1.6*2.1   白色'),(21580,771919948001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 11:40:37',0,NULL,3,1,11,1,NULL,NULL),(21581,913491415015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','smixiebobby','smixiebobby91@hotmail.co.uk','vicky  squire ','15 clinton street','worksop','Nottinghamshire','UNITED KINGDOM','s802ry','07530833255','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-19 12:03:32',0,NULL,3,1,3,1,'RA184543620CN ','4节 '),(21582,771929296001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','sergey.khomyakov','shomykov@mail.ru','Sergey Khomyakov','7, Garazhnaya ','Stupino','Moscow region','RUSSIAN FEDERATION','142800','+79154794302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 12:16:59',0,NULL,3,1,3,1,'RA184543616CN ',NULL),(21583,815367417002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','bonchoo','morekrit@hotmail.com','CHOONIAH LAO','59/72 NAKANIWAS48, Moo4,<br>NAKANIWAS STREET,','LADPROW','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 13:03:37',0,NULL,3,0,3,1,'RA184543465CN ','1.6*3 黑色 '),(21584,913525721015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','dammy201010','lararoyal@live.ie','Molara Shomoye','36 CHIEFTAINS DRIVE','Ballbriggan','Dublin','IRELAND','01','0861943179','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 13:35:13',0,NULL,8,1,17,0,NULL,NULL),(21585,913524492015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','dammy201010','lararoyal@live.ie','Molara Shomoye','36 CHIEFTAINS DRIVE','Ballbriggan','Dublin','IRELAND','01','0861943179','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 13:35:14',0,NULL,8,1,17,0,NULL,NULL),(21586,834805300017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','fast_fashion_delivered','famousfarley@yahoo.com.au','Farley Ward','PO BOX 1071','Maleny','Queensland','AUSTRALIA','4552','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-19 13:56:19',0,NULL,3,0,3,1,'RA184543559CN ','1.6*3  绿色 '),(21587,894780379016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','dammy201010','lararoyal@live.ie','Molara Shomoye','36 CHIEFTAINS DRIVE','Ballbriggan','Dublin','IRELAND','01','0861943179','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-19 14:03:27',0,NULL,3,1,4,1,'YW868053116CN ','除了C以外再发\r45w 5500k 灯泡 220v   4 \r3m 横杆（通用4节）    1\r英标     ▲\r实重 10.66  泡重14.9'),(21588,815391677002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','konz666','sebastian.konopka@web.de','Sebastian Konopka','Hermann-Löns-Straße 10','Gelsenkirchen','','GERMANY','45894','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 14:23:24',0,NULL,3,0,3,1,'RA184543704CN ','XL 已入库 '),(21589,815397511002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','kmahnet','kruno.mahnet@gmail.com','Kruno Mahnet','Kozincev 1. odvojak 3','Zagreb','Croatia','CROATIA','10 090','00385915007337','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 14:40:16',0,NULL,3,1,11,1,' ',NULL),(21590,771994960001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','jnorman76','jonathan.norman@gmail.com','Jonathan Norman','8134 Stickney Ave','Wauwatosa','WI','UNITED STATES','53213-1636','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-19 15:54:52',0,NULL,3,1,1,1,NULL,NULL),(21591,772011538001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',2,'AKT031',100,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 16:56:28',0,NULL,3,1,5,1,'CP211275602CN ',NULL),(21592,913619714015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','prometeusz2004','konradszalinski@yahoo.com','Konrad Szalinski','1 Grove Court<br>Grove Road','Surbiton','Surrey','UNITED KINGDOM','KT6 4DD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 17:05:29',0,NULL,3,1,3,1,'RA184543457CN ',NULL),(21593,815475078002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','narik84','khnorchik@gmail.com','Hovhannes Boranyan','Norki 1 Zangvats, Nansen str 5/2, apt 18<br>apt.18','Yerevan','','ARMENIA','0056','+374 95 555610','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 17:56:48',0,NULL,3,1,11,1,NULL,NULL),(21594,913648546015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','kerrykennelly','kerry@kerryseye.com','Kerry Kennelly','22 Ashe Street','Tralee','Kerry','IRELAND','default','0872547593','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 17:56:59',0,NULL,3,1,3,1,'RA184543488CN ',NULL),(21595,815298132002,120765360792,'New 400w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT080',218,'hermeshine','77info','mrheorhi@tut.by','Dmitriy Shishkov','Leschinskogo 43-61','Minsk','Belarus','BELARUS','220140','+375(29)3551683','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 18:08:37',0,NULL,3,1,5,1,'CP243056492CN ',NULL),(21596,776367210018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','frankedbyedisson','alexander.puziy@inbox.lv','Александр Пузий','Balta 24-70','Riga','','LATVIA','LV 1055','+37122020805','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-19 18:28:02',0,NULL,3,1,3,1,'RA184543491CN ','申报$12 '),(21597,772068412001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 18:49:45',0,NULL,3,1,3,1,'RA184543412CN ',NULL),(21598,772084966001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','reinaldocaj','rcaj27@msn.com','Reinaldo Coutinho de Azevedo Junior','AV. SANTA CATARINA, 1274<br>Balneário','Florianopolis','Santa Catarina','BRAZIL','88075-500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 19:13:56',0,NULL,3,1,11,1,NULL,NULL),(21599,772110414001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','urbanwear_ch','urbanwear_ch@hotmail.com','Luis Llerena','Rue de la Borde 22bis','Lausanne','','SWITZERLAND','1018','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 19:59:54',0,NULL,3,1,17,0,NULL,'\r\r'),(21600,913737188015,250939650416,'New in box 52mm 52 Haze UV Filter For Canon SONY Pentax Nikon Protect lens',1,'AA3301',2.18,'hutongstore','vipereddy','eddyviper@gmail.com','Darius Lasinis','Dainu g. 44-18','Siauliai','Siauliai','LITHUANIA','78285','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 20:10:59',0,NULL,3,1,11,1,NULL,NULL),(21601,772128448001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','spw1967','sami@jomena.fi','Sami Wilenius','Tilkankatu 29 A 19<br>00300','Helsinki','','FINLAND','00300','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-19 20:41:59',0,NULL,3,1,3,1,'RA184543505CN ',NULL),(21602,772172785001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','tattoos_fr','alexandre.charles@alcatel.fr','Alexandre Charles Labrousse','Domaine de la seigneurie<br>37 avenue Jean Jaurés','Crosne','Ile-de-France','FRANCE','91560','06.86.45.31.24','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-19 22:15:42',0,NULL,3,1,3,1,'RA184543426CN ','4个 '),(21603,772183944001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','richardwho','richard@richardwho.com','Richard K. Briggs','13712 Kerrydale Rd','Dale City','VA','UNITED STATES','22193-4711','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-19 22:43:52',0,NULL,3,0,1,1,NULL,'52mm     4\r55mm      1\r58mm       1\r62mm        1\r67mm         1\r72mm       1\r77mm      1    已入库\r'),(21604,913834558015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','laurisan','lauri.hynninen@iki.fi','Lauri Hynninen','Vuorimiehenkatu 18 B 17','Helsinki','','FINLAND','00140','(358)405752932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-19 23:00:43',0,NULL,3,1,11,1,NULL,NULL),(21605,913856063015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',3,'AD1176',70.5,'hutongstore','lorraine3862','designskii@googlemail.com','lorraine patterson','86b stormont road','battersea','London','UNITED KINGDOM','sw11 5el','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 23:55:58',0,NULL,3,1,4,1,'YW868052501CN ','英标 '),(21606,913850707015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','phongvt89','vuthanhphong.edu@gmail.com','Phong Thanh Vu','85, Addington Road','Reading','Berkshire','UNITED KINGDOM','RG15PZ','07402993958','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-19 23:41:58',0,NULL,3,1,11,1,NULL,NULL),(21607,815657789002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','severinoasumu12','severinoasumu@gmail.com','Juan Asumu','16432 89 ave','Edmonton','AB','CANADA','T5R 4R9','(780) 249-5270','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 01:00:45',0,NULL,3,0,3,1,'RA184543474CN ','1.6*3  白色 '),(21608,913879386015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0005',23.97,'hutongstore','ukmorante','ukmorante@fsmail.net','Lee Morante','39 Wensley Drive','Accrington','Lancashire','UNITED KINGDOM','BB56SB','07856420227','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 01:02:03',0,NULL,3,0,3,1,'RA184543545CN ','1.6*2.1   黑，白，灰 '),(21609,8881324345423566,111,'Photo Studio Background Support Carrying Carry Bag ',1,'AD1129',5.99,'aliexpress','1005882285','jungis38@gmail.com','Mats Jungmyren	','Krakrisvagen 5A 2tr','Motala','Sweden','SWEDEN','59154','+0046 70 5158982',NULL,NULL,NULL,'2011-12-20 01:43:43',0,NULL,3,1,3,1,'RA184542156CN ',NULL),(21610,8881324345929670,111,'Studio Background Support 7x7 ft + 2 (White and Black) Backdrops + Free Carry bag',1,'AKT015',74.99,'aliexpress','1005879197','mwlim@pacific.net.sg','Lim Ming Wei','UWCSEA (Tampines Campus) - IT Dept 1 Tampines Street 73','Singapore','Singapore','SINGAPORE','529508','+065 96824887',NULL,NULL,NULL,'2011-12-20 01:52:09',0,NULL,3,1,6,1,'EE636829382CN ','白+黑  '),(21611,776596376018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-12-20 04:50:18',0,NULL,3,1,4,1,'YW868052512CN ','▲ '),(21612,772111237001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',142.97,'hermeshine','urbanwear_ch','urbanwear_ch@hotmail.com','Luis Llerena','Rue de la Borde 22bis','Lausanne','','SWITZERLAND','1018','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-20 07:41:17',0,NULL,3,1,4,1,'YW868052523CN ','铝合金灯座（N）   1 \r灯架  2m    1\r斜臂      1         ▲\r永诺 CTR-301P 1托3      1\r伞式柔光箱 60×90cm      1\r已入库'),(21613,914018644015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','dacorumphil','phil@melenstudios.com','Phil Richardson','MelenStudios<br>Gaddesden Row','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP2 6HG','01582840172','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 09:57:36',0,NULL,3,1,17,0,NULL,NULL),(21614,895247115016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','dacorumphil','phil@melenstudios.com','Phil Richardson','MelenStudios<br>Gaddesden Row','Hemel Hempstead','Hertfordshire','UNITED KINGDOM','HP2 6HG','01582840172','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 09:57:37',0,NULL,3,1,4,1,'YW868053083CN ','2mx1.5m 背景板（蓝，绿）  1 \r2mx1.5m 背景板（黑，白）   1\r▲'),(21615,776661727018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','beardy2765','beardy1993@hotmail.com','James Beard','9 George Street','Riverstone','New South Wales','AUSTRALIA','2765','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-20 10:45:45',0,NULL,3,1,11,1,'、 ',NULL),(21616,914032381015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','totalpears','pbartlett2@sky.com','PAUL BARTLETT','210,BUTTS ROAD<br>SHOLING','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO19 1BQ','02380431642','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-20 10:48:05',0,NULL,3,1,3,1,'RA184542085CN ',NULL),(21617,835259215017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','hhdjz','hhdjz2004@gmail.com','QUAN JIANG','247 Selwyn Rd','Richmond Hill','ON','CANADA','L4E0R4','(416) 264-7318','PayPalPaymentInProcess','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184542099CN ',NULL),(21618,772356356001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','shlomokazan','shlomomusin@gmail.com','shlomo and rachel musin','L.Lipsky<br>38-10','Jerusalem','','ISRAEL','97459','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 12:09:30',0,NULL,3,1,11,1,NULL,NULL),(21619,772358983001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','dumax750','dumax95@mail.ru','Maxim Dudov','Zaiceva st, 22/13-7','Saint Petersburg','','RUSSIAN FEDERATION','198188','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-20 12:20:57',0,NULL,3,1,3,1,'RA184542108CN ',NULL),(21620,913246677015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','trishamt06','ronc@maltanet.net','RONALD COCKS','21,St Mary Street','Balzan','','MALTA','BZN1213','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 12:36:00',0,NULL,3,1,5,1,'CP243056475CN ','欧标 '),(21621,815805265002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','vitali1995','vitalivictor@yahoo.co.uk','Vital iGerasimovitch','Culvert court<br>105 culvert road','london','London','UNITED KINGDOM','sw11 5au','07921551877','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 12:58:40',0,NULL,3,1,11,1,NULL,NULL),(21622,815813877002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','jovisur','jovisur@eresmas.com','José Vives Montero','Apart. de Correos Nº 593 (P.Box)','Granada','Andalucía Ceuta y Melilla','SPAIN','18.080','627976414','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 13:24:11',0,NULL,3,0,3,1,'RA184542139CN ','1.6*3  白色 '),(21623,895343911016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','sipe2010','edvideoproducoes@hotmail.com','Edison Eron','Av. Senador Salgado Filho, 4390 SB 21<br>Uberaba','Curitiba','Paraná / Curitiba/ Guabirotuba','BRAZIL','81570001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 15:20:31',0,NULL,3,1,3,1,'RA184542142CN ','申报$49 '),(21624,895387478016,260894474713,'New Studio Light 800W Continuous Lighting Complete Kit with background support',1,'AKT087',102,'hutongstore','keshavsujeeun','kesh2503@yahoo.com','keshav sujeeun','astoria road, goodlands','port-louis','','MAURITIUS','230','+230 9185083','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-20 17:08:11',0,NULL,5,1,18,1,'CP243056489CN ','英标 '),(21625,772443263001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','lucio.bittencourt','luciobittencourt@hotmail.com','Lucio Bittencourt','SQN 104 - Bl. G - Aptº 408','Brasília','Distrito Federal','BRAZIL','70733-070','55-61-33265224','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 17:21:47',0,NULL,3,1,11,1,NULL,NULL),(21626,815991246002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','smillie2011','gertsmilde@gmail.com','gert Smilde','Polberg <br>47','Hardenberg','','NETHERLANDS','7772EW','0523268018','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-20 21:29:56',0,NULL,3,1,11,1,'、 ',NULL),(21627,816033313002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','a7709836','al_v_7709836@yahoo.com','alex vega','7396 n sandario rd','tucson','AZ','UNITED STATES','85743-7285','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-20 23:51:50',0,NULL,3,1,1,1,NULL,''),(21628,895584070016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','grammofontel','haetta@gmail.com','Kenneth Hætta','Hegdehaugsveien 25','Oslo','','NORWAY','0352','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-21 00:06:49',0,NULL,3,0,3,1,'RA184542023CN ','改成2mx1.5m 白色背景板   \r'),(21629,816048221002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',245,'hermeshine','andrzejcorkbeg','corkbeg@yahoo.ie','Andrew Dzijak','Unit22 Nordic Enterprise Park','Midleton','CORK','IRELAND','default','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 00:50:36',0,NULL,3,1,17,0,NULL,NULL),(21630,772602187001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','andrzejcorkbeg','corkbeg@yahoo.ie','Andrew Dzijak','Unit22 Nordic Enterprise Park','Midleton','CORK','IRELAND','default','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-21 00:50:37',0,NULL,3,1,4,1,'YW868053094CN ','灯架  2m  3\r5灯头+60-90棚    2\r115w 5500k 灯泡 220v     11\r柔光箱 50-70cm 单灯头    1  \r灯架包     2           ▲\r斜臂          1 \r英标  泡重18.8  实重11.6\r'),(21631,772604643001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',8,'AC2301',49.68,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 00:55:49',0,NULL,3,1,3,1,'RA184542010CN ','申报低值 '),(21632,774378903018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','tarlie144','paris.jager@hotmail.com','Paris Jager','65 Venice Street','Burleigh Waters','Queensland','AUSTRALIA','4220','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-21 01:21:03',0,NULL,3,1,4,1,'YW868053105CN ','白+黑  \r▲'),(21633,816063867002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','shamailachaudhry','shamas.chaudhry@gmail.com','Shamas Chaudhry','118 Arran Cres.<br>Basement','Vaughan','ON','CANADA','L4L 1G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 01:40:16',0,NULL,3,1,3,1,'RA184542068CN\r ','伞式柔光箱 80cm 8角     1 \r伞式柔光箱 60×90cm      2'),(21634,8881324435170827,111,'天涯方形滤镜  ND2',1,'',0,'hermeshine','andythien','andylove_18@hotmail.com','Thien Martin Nguyen Duc','Smedjegatan 1','Malmö','Skåne','SWEDEN','21421','+46702301997',NULL,NULL,NULL,'2011-12-21 02:39:30',0,NULL,3,0,3,1,'RA184542071CN ','已入库 '),(21635,895634804016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',2,'AD1182',92,'hutongstore','zemskiis','eric.macdonald@gmail.com','Eric Macdonald','33 Queens Rd ','Asquith','New South Wales','AUSTRALIA','2077','0424177159','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 03:03:00',0,NULL,3,1,4,1,'YW868052556CN ','▲ '),(21636,816085353002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','shamailachaudhry','shamas.chaudhry@gmail.com','Shamas Chaudhry','118 Arran Cres.<br>Basement','Vaughan','ON','CANADA','L4L 1G6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 03:09:09',0,NULL,3,1,17,0,NULL,NULL),(21679,777353022018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','5985rob','soul_man7@hotmail.com','Rob Randle','P.O.Box 3158','North Nowra','New South Wales','AUSTRALIA','2541','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 03:29:53',0,NULL,3,1,17,0,' ',NULL),(21637,772657351001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','bankexcite','hamster_bank@hotmail.com','Wittawat Lertcharoenamnuay','125/12 M.Promphat Kanjanapisak Rd. Sapansoong','Sapansoong','Bangkok','THAILAND','10250','(668) 313-73704','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 05:14:03',0,NULL,3,1,11,1,NULL,NULL),(21638,772670115001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','fenix_art','euglink@gmail.com','Eugene  Linkov','10/74 Wardell Rd<br>Earlwood','Sydney','New South Wales','AUSTRALIA','2206','0295594602','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 06:43:15',0,NULL,3,1,11,1,NULL,NULL),(21639,816136301002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','canon-rockrider','photographed426@gmail.com','Richárd Tóth','Esze Tamás utca 7, földszint 8','Koppánymonostor','','HUNGARY','2903','+36706040799','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 08:03:19',0,NULL,3,1,3,1,'RA184544126CN\r ',NULL),(21640,835641576017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','em9','em-carter@hotmail.com','Emma  Carter','53 Bridges street','Peterborough','South Australia','AUSTRALIA','5422','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-21 09:12:27',0,NULL,3,1,11,1,NULL,NULL),(21641,816135045002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','eladtsa','etsadka@gmail.com','Elad Tsadka','Mailbox 111','Beit-Yitzhak','Israel','ISRAEL','42920','972 524473828','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 09:30:10',0,NULL,3,0,11,1,NULL,NULL),(21642,772703694001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ikupi','ivan@inode.nl','Ivan Kupi','2e octaviolaan 36','Capelle aan den IJssel','','NETHERLANDS','2909 RC','+31645748509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 10:14:00',0,NULL,3,0,17,0,NULL,''),(21643,914511980015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','konkolyt','tkonkoly@gmail.com','Konkoly Tibor','Népfürdő u. 24-26<br>Erste Befektetési Zrt.','Budapest','','HUNGARY','1138','+36305068964','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 10:29:43',0,NULL,3,1,5,1,'CP243056546CN ','+1.6*2.1  白色布 '),(21644,835660156017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','5xwcwchampion','philipliuvancouver@yahoo.ca','Philip Liu','5338 Argyle Street<br>(basement, right side)','Vancouver','BC','CANADA','V5P 3J3','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-21 10:41:22',0,NULL,3,1,11,1,NULL,'申报gift \r把这句话打出来贴在货上  \rPostmaster: Tenant lives on right side basement, NOT AT FRONT DOOR.\"  '),(21645,816165406002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','ikupi','ivan@inode.nl','Ivan Kupi','2e octaviolaan 36','Capelle aan den IJssel','','NETHERLANDS','2909 RC','+31645748509','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 10:47:07',0,NULL,3,1,3,1,'RA184544404CN ','1.6*2.1  灰色   1\r1.6*3      灰色    1 '),(21646,895736135016,260661685518,'New AF Confirm Chip for Canon EOS EF Lens adapter',1,'AA1214',4.98,'hutongstore','z8shjrt','jjutta@gmx.de','Jutta Engelmann','Turmstr. 5','Aichwald','','GERMANY','73773','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 11:06:55',0,NULL,5,0,18,0,NULL,'没发货，客户问起来就退钱给他，说估计路上丢了 '),(21647,816170081002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','van1_123','pvdmuk@hotmail.com','Peter van der Merwe','Kilburn House','Ton Kenfig','Bridgend','UNITED KINGDOM','CF33 4PT','01656743312','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 11:12:48',0,NULL,3,1,11,1,NULL,'英标 '),(21648,816171090002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sergey.khomyakov','shomykov@mail.ru','Sergey Khomyakov','7, Garazhnaya ','Stupino','Moscow region','RUSSIAN FEDERATION','142800','+79154794302','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 11:16:22',0,NULL,3,1,3,1,'RA184544262CN ',NULL),(21649,835668917017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',65,'photographyacc','dtasker','dtasker@netspace.net.au','D Tasker','342 Marriot Street<br>PO Box 155','Westbury','Tasmania','AUSTRALIA','7303','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-21 11:20:38',0,NULL,3,1,4,1,'YW868053061CN ','地址 \rD Tasker\r342 Marriot Street\rWestbury Tasmania 7303\rAUSTRALIA'),(21650,772716878001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','aldiyar1','affiliate.aldiyar@gmail.com','Aldiyar Kuandykov','20 Liniya 48-49','Almaty','Almatinskaya obl','KAZAKHSTAN','050046','+77012110080','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 11:21:25',0,NULL,3,1,8,1,'CP243056501CN ','欧标 '),(21651,895762544016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','chusgr','jgr_85_bcn@hotmail.com','Jesús Gómez Rodríguez','C/ Ntra. Sra. de Lourdes nº 18 2º  1ª','Molins de Rei','Cataluña','SPAIN','08750','625726498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 12:43:17',0,NULL,3,1,11,1,NULL,NULL),(21652,914563252015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','phw_dk','per@wolfsdorf.dk','Per Wolfsdorf','Tybjergparken 107 1.tv','Brøndby Strand','Danmark','DENMARK','2660','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 13:30:41',0,NULL,3,1,11,1,NULL,NULL),(21653,914586239015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','dalv086','grigore_v@yahoo.com','Vlad Grigore','189 Hampton Square<br>Navan Road','Dublin','Dublin','IRELAND','7','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 14:43:52',0,NULL,3,1,11,1,' ',NULL),(21654,772773884001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','explorer1969','frode.edvindsen@yahoo.no','Frode Edvindsen','Odvar Solbergs Vei 216','Oslo','Oslo','NORWAY','0973','004792807077','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 15:31:47',0,NULL,3,1,3,1,'RA184544228CN ',NULL),(21655,772802469001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','dezent777','mikstel@telelanas.lt','Jevgenij Mikulin','Vaidaugu 3-91','Klaipeda','','LITHUANIA','LT-95221','+37060166626','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 17:06:00',0,NULL,3,1,11,1,NULL,NULL),(21656,772808814001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','nominal99','main@vcm.ru','Dmitry Denisov','ul. 70 Let Oktyabrya dom 46 kv 2','Togliatti','','RUSSIAN FEDERATION','445031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 17:26:48',0,NULL,3,1,3,1,'RA184544214CN ','4节 '),(21657,816268649002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','vladpv','petrushevskiy@gmail.com','Vladislav Petrushevskiy','19 Tolstogo str.<br>fl. 65','Novorossiysk','Krasnodarskiy region','RUSSIAN FEDERATION','353905','9298448144','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 17:29:54',0,NULL,3,1,11,1,NULL,NULL),(21658,816283219002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','marcmtl61','marcmtl61@hotmail.com','Marc Pageau','1151 Beaudry #3','Montreal','QC','CANADA','H2L 3E3','(514) 526-1748','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 18:10:18',0,NULL,3,1,11,1,NULL,NULL),(21659,816284013002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','slipaisaldis','aldissene@inbox.lv','Aldis Sene','Cīruļi<br>Burtnieki','Burtnieku novads','','LATVIA','LV-4206','+37129148890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 18:14:41',0,NULL,3,1,3,1,'RA184544302CN ',NULL),(21660,895886743016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','justy_west','west_boy_46@hotmail.com','Justin Caruana','Our Lady of Ta\' Pinu<br>Frenc tal-Gharb Str.','Gharb','Gozo','MALTA','GRB 1202','(356) 7928 4601','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-21 18:36:27',0,NULL,3,1,11,1,NULL,NULL),(21661,816308564002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','chompi18','itsik.madjar@gmail.com','itsik madjar','hanarkisim 18','kiriat bialik','israel','ISRAEL','27214','052-8337707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 19:14:03',0,NULL,3,1,17,0,NULL,NULL),(21662,772848557001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','chompi18','itsik.madjar@gmail.com','itsik madjar','hanarkisim 18','kiriat bialik','israel','ISRAEL','27214','052-8337707','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 19:14:04',0,NULL,3,1,17,0,NULL,NULL),(21663,816308566002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',1,'AD1125',14.99,'hermeshine','chompi18','itsik.madjar@gmail.com','itsik madjar','hanarkisim 18','kiriat bialik','israel','ISRAEL','27214','052-8337707','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-21 19:14:04',0,NULL,3,1,3,1,'RA184544293CN ','伞式柔光箱 60×90cm    1 \r铝合金灯座（N）    1\r柔光伞110cm     1'),(21664,771954201001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','hansbuys','ebay@hansdejong.net','J.R. de Jong','Watermaalpad 27','Amsterdam','','NETHERLANDS','1066WX','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 19:59:19',0,NULL,3,1,11,1,NULL,NULL),(21665,914763566015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','olidan63','madasawasp1@aol.com','Mark Adamson','12, Vale Close','Appley Bridge','Wigan','UNITED KINGDOM','WN6 9LB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 21:23:06',0,NULL,3,1,11,1,NULL,NULL),(21666,914776962015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','k9sams','pd012g7313@blueyonder.co.uk','Phil Davies','271 Longbridge Lane, West Heath','Birmingham','West Midlands','UNITED KINGDOM','B314RE','01214753814','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-21 21:53:07',0,NULL,3,1,3,1,'RA184544276CN ',NULL),(21667,772931147001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','filip444','fkardun@gmail.com','Filip Kardun','gračanski mihaljevac 7d','Zagreb','','CROATIA','10000','+38598820880','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 23:23:54',0,NULL,3,1,11,1,NULL,NULL),(21668,816397708002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','woofy_wrecker','olle.jorsved@gmail.com','Olle Jörsved','smörbollsgatan 2c<br>41718','Göteborg','N/A','SWEDEN','417 18','+46704773079','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-21 23:33:06',0,NULL,3,1,3,1,'RA184544280CN ',NULL),(21669,772940995001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','1775.bert','grevingb@hotmail.com','E.I. Greving','Napo 404','Utrecht','','NETHERLANDS','3509 VS','+31645501775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 00:08:48',0,NULL,3,1,11,1,NULL,NULL),(21670,602817667003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','japeto22','nachocanarias@gmail.com','Ignacio Suarez Hernandez','c/ pascal nº2 calero Bajo','Telde','Las Palmas de Gran Canaria','SPAIN','35.200','629579382','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 00:15:25',0,NULL,3,1,4,1,'YW868052560CN ',NULL),(21671,777319743018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',2,'AA1204',5,'photographyacc','parkinb411','brianparkin@iprimus.com.au','Brian Parkin','12 Glasshouse Crescent','Forest Lake','Queensland','AUSTRALIA','4078','0732799979','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 00:53:46',0,NULL,3,1,11,1,NULL,NULL),(21672,896041559016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 01:30:38',0,NULL,3,0,3,1,'RA184544316CN ','1.6*3   黑色 '),(21673,8881324520069305,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1005913105','cheeb2005@gmail.com','Natalya Kuznetsova	','Krylatsksya str. 31/1-158','Moscow','Russia','RUSSIAN FEDERATION	','121614','+7 910 4594061',NULL,NULL,NULL,'2011-12-22 02:14:29',0,NULL,3,1,3,1,'RA184544333CN\r ',NULL),(21675,772968738001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','tob046','tonyobrie@hotmail.co.uk','tony  o\'brien','5 woodside close','rainham','Essex','UNITED KINGDOM','RM139PB','07780662336','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 02:29:14',0,NULL,3,1,3,1,'RA184544355CN\r ',NULL),(21674,8881324520205502,111,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',5.99,'aliexpress','1005913224','nominal99@yandex.ru','Dmitry Denisov	','ul. 70 Let Oktyabrya, dom 46 kv. 2','Togliatti','Samarskaya oblast	','RUSSIAN FEDERATION	','445031','+7 902 3763385',NULL,NULL,NULL,'2011-12-22 02:16:45',0,NULL,3,1,3,1,'RA184544347CN\r ',NULL),(21676,8881324521975798,111,'1600w 套装',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-12-22 02:46:15',0,NULL,3,1,12,1,'3436120273 ','110V\r 实重5.7 泡重7.2'),(21677,815789976002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','skyeminx19','skye75@live.com.au','skye quartermaine','1  Cowra  Dr<br>Unit 27','Newman','Western Australia','AUSTRALIA','6753','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 02:55:40',0,NULL,3,1,11,1,NULL,NULL),(21678,8881324523053174,111,'3个铝合金灯座配件',1,'',0,'hutongstore','gubaguba','gubavision@comcast.net','Paul Guba','85 Portland Rd','Highlands','NJ','UNITED STATES','07732-1955','',NULL,NULL,NULL,'2011-12-22 03:04:13',0,NULL,3,0,1,1,'LK130007067CN','波哥过去拿 '),(21680,777352871018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','5985rob','soul_man7@hotmail.com','Rob Randle','P.O.Box 3158','North Nowra','New South Wales','AUSTRALIA','2541','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 03:29:53',0,NULL,3,1,11,1,NULL,'沙袋（普通）  2'),(21681,772831199001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','soulforsoup','justintmk@hotmail.com','Justin Tan','Blk 330 Clementi Ave 2 #08-182<br>Singapore','default','','SINGAPORE','120330','81899967','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 04:30:13',0,NULL,3,1,3,1,'RA184544320CN\r ',NULL),(21682,816465369002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','artpl23','arturw23@hotmail.com','Artur Wojcik','133 Cherry St','Clifton','NJ','UNITED STATES','07014-1301','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-22 04:45:09',0,NULL,3,1,1,1,NULL,NULL),(21683,816474156002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','reg24krksp','uzbekksp@mail.ru','Aleksandr Ribalchenko','Kutuzova, 77a-194','Krasnoyarsk','Krasnoyarsk region','RUSSIAN FEDERATION','660094','+79504142435','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 05:42:29',0,NULL,3,1,11,1,NULL,NULL),(21684,914905067015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','streetball_is_my_job','hoopsstarz@yahoo.com','Krisztian Kindler','Haszkovo Utca 14/C','Veszprem','Veszprem','HUNGARY','8200','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 05:52:38',0,NULL,3,0,11,1,NULL,'1.6*2.1  灰色 '),(21685,816497724002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','shamroc77','77patrick@gmail.com','Patrick Carter','1509 Meridian Ave<br>Apt 4','Miami Beach','FL','UNITED STATES','33139-3433','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-22 08:33:23',0,NULL,3,1,3,1,'RA184544673CN\r ',NULL),(21686,914946503015,250666859818,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45.8,'hutongstore','kalabaher','yes@apochemu.net','Igor Dulenko','70 let Oktyabrya, 8-272','Krasnodar','Krasnodrskiy Kray','RUSSIAN FEDERATION','350089','(918) 683-4693','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 09:42:55',0,NULL,3,1,5,1,'CP243056532CN ','欧标 '),(21687,816275808002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','jerome_jam','jerome.espenida@yahoo.com','jeronimo espenida','area 3 hornbill st., sitio veterans<br>brgy. bagong silangan','quezon city','','PHILIPPINES','1119','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 10:14:19',0,NULL,3,1,3,1,'RA184544775CN ',NULL),(21688,816536270002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','auction--trader','auctiontrader@bigpond.com','Paul Holland and Rochelle Cook','PO Box 6103<br>GCMC','Bundall','Queensland','AUSTRALIA','9726','61411516155','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-22 12:27:37',0,NULL,3,1,3,1,'RA184544789CN ',NULL),(21689,914984645015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','luzdeflash','david.pelaz@gmail.com','David Pelaz Rodriguez','C/ Barón Pierre Cubertain 28, 1º 3ª<br>La Albada','Tarragona','Cataluña','SPAIN','43006','977083040','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 12:34:56',0,NULL,3,1,3,1,'RA184544792CN ','欧标 '),(21690,816555289002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','123onasteek','trade@gnui.net','Johan Alteir Tuvesson','Stralsundsvägen 35','LUND','-','SWEDEN','224 79','0703-128000','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 13:59:44',0,NULL,3,1,11,1,'\\ ',NULL),(21691,816563231002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',5,'AE1302',47.5,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 14:35:37',0,NULL,3,1,3,1,'RA184544801CN ','欧标 '),(21692,769449592001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','zygenes','marcelthelover@hotmail.com','Mariette Lamoureux','201, Ch. des Gaies-Bleus','St-Didace','QC','CANADA','J0K 2G0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 14:36:20',0,NULL,3,1,11,1,NULL,NULL),(21693,915080519015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','godfather_11','mr_henyo_11@yahoo.com','marvin velando','3 daresbury close<br>bridgehall','stockport','Greater Manchester','UNITED KINGDOM','sk3 8ly','01614775584','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 17:40:19',0,NULL,3,1,3,1,'RA184544713CN ',NULL),(21694,915098868015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','mikelgl','mikel.goni@gmail.com','Mikel Goñi','Gatzaga kalea, 7 atzealdea.<br>3. locala','Pasaia-Trintxerpe','País Vasco','SPAIN','20110','695759770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-22 18:28:03',0,NULL,3,1,11,1,NULL,NULL),(21695,915121391015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','andreascamper','sieling@iom.com','Steve Sieling','The Sycamores, Leodest Road','Andreas','Isle of Man','UNITED KINGDOM','IM74HA','01624880935','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 19:20:18',0,NULL,3,1,11,1,NULL,NULL),(21696,0,120826219990,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','lip90s','lip90@yandex.ru','Ivan Lipuzhin','Marshala Rokossovskogo 6 - 74','Nizhny Novgorod','','RUSSIAN FEDERATION','603136','8-903-042-56-76','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 19:23:20',0,NULL,3,1,11,1,NULL,NULL),(21697,816662482002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','buyer_direct','richardattard@optusnet.com.au','Richard Attard','7 Tuabilli St','Pemulwuy','New South Wales','AUSTRALIA','2145','0411186888','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-22 20:02:29',0,NULL,3,1,11,1,NULL,NULL),(21698,915144347015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','legrisventre','alan@farrell.net','Alan Farrell','Braidwood, 18 Mont Pelle<br>Tower Road, St Helier','Jersey','Channel Islands','UNITED KINGDOM','JE2 3LW','01534505004','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 20:11:29',0,NULL,3,1,11,1,NULL,NULL),(21699,775433641018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','kayb7904','baiya@bigpond.com','Margaret K Burley','87 Bucketts Way','TWELVE MILE CREEK','New South Wales','AUSTRALIA','2324','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 21:20:03',0,NULL,3,0,11,1,'、\r ','1.6*2.1  黑色 '),(21700,915202809015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','redsweetie33','pinoy2uk@yahoo.co.uk','Rick Agra','103 A Balgores Lane, Gidea Park','romford','Essex','UNITED KINGDOM','RM26BT','01708471393','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 22:39:03',0,NULL,3,1,11,1,NULL,NULL),(21701,773246082001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','csimpson1971uk','csimpson1971@talktalk.net','Christopher Simpson','9 Glenalla Road','Llanelli','Carmarthenshire','UNITED KINGDOM','SA15 1EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-22 23:27:27',0,NULL,3,1,11,1,'\\ ',NULL),(21702,836276363017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','sin123bluedog','sin.sid@rocketmail.com','sindhunata sindhunata','19 Tipperary Bend','Canning Vale','Western Australia','AUSTRALIA','6155','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-22 23:40:25',0,NULL,3,1,11,1,NULL,NULL),(21703,816723717002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','dudewheresmytutu','aeb7311@gmail.com','Amy Lanchester','36 Maple Street','Kingston','Queensland','AUSTRALIA','4114','0404041043','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 00:07:01',0,NULL,3,1,3,1,'RA184544727CN ',NULL),(21704,773261385001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','pierrer8081','dutytravelegs@hotmail.com','Pierre R. Legault','226 Waterford Rd','Ten Mile','TN','UNITED STATES','37880-2035','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 00:43:26',0,NULL,3,1,1,1,NULL,NULL),(21705,777651387018,280666869553,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop White/Black',1,'AA1218',62,'photographyacc','stedeutscher','stefan_deutscher@yahoo.com','Stefan Neamtu','sat Valeni-Podgoria, nr.339','Calinesti','Arges','ROMANIA','117207','+40733422822','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-23 00:55:52',0,NULL,3,1,3,1,'RA184544735CN ',NULL),(21706,915237089015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','larisza58','leif-nilsson@sjobo.nu','Larisza Szeverin','Beritslundsg .6','Sjöbo','Skane','SWEDEN','27595','0046 41541114','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 01:01:44',0,NULL,3,1,11,1,'、 ',NULL),(21707,777657020018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','kari.5802','lee.hauser@hotmail.com','Kari Habib','20 Young street','lara','Victoria','AUSTRALIA','3212','0352825802','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-23 01:24:23',0,NULL,3,1,4,1,'YW868053024CN ','▲ '),(21708,816754274002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','barm9762','barry.armstead@grapevine.com.au','Barry Armstead','2 Cope Place','Wanniassa','Australian Capital Territory','AUSTRALIA','2903','610401052548','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-23 01:46:26',0,NULL,3,1,3,1,'RA184544744CN ',NULL),(21709,915257020015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','boostifer','crshuston@googlemail.com','Chris Huston','Apt 68<br>17 Queens Square','Belfast','Antrim','UNITED KINGDOM','BT13FF','02890244699','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 02:02:10',0,NULL,3,1,3,1,'RA184544758CN ',NULL),(21710,816767870002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','philliply','philliply@gmail.com','Phillip So','1495 N. 8th','Fresno','CA','UNITED STATES','93703','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 02:53:14',0,NULL,3,1,3,1,'RA184544761CN\r ',NULL),(21711,608521884004,140651224761,'New Mini IR Wireless Remote Control for Nikon D90 D3000 D80 D7000 D5100',1,'AD1116',3.3,'hermeshine','spacylittlecowgirl','fyrelyzard@yahoo.com','Florence Chan','16 Dallimore Circle<br>Unit #201','North York','ON','CANADA','M3C 4C4','(416) 919-1761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 02:55:41',0,NULL,3,1,17,0,NULL,NULL),(21712,816766658002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',2,'AA1309',5.2,'hermeshine','spacylittlecowgirl','fyrelyzard@yahoo.com','Florence Chan','16 Dallimore Circle<br>Unit #201','North York','ON','CANADA','M3C 4C4','(416) 919-1761','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 02:55:41',0,NULL,3,1,11,1,NULL,'Mini 红外  nikon     1 \rNIKON 镜头盖 77mm    2'),(21713,8881324611251710,111,'800w 110v 灯泡 ',1,'',0,'hermeshine','freshido','bingo2003@hotmail.com','Frederic Perez','5765 Cote St Luc Road #211','Montreal','QC','CANADA','H3X 2E9','(514) 485-9821',NULL,NULL,NULL,'2011-12-23 03:34:11',0,NULL,3,1,3,1,'RA184544850CN\r ','仔细检查一下灯丝有没有坏 '),(21714,836339923017,270767170462,'100% Cotton Photo Vest for Sony a200 a300 a700 a900user',1,'AA2113',29.99,'photographyacc','nwknwk','nwkirkness@yahoo.com','Neil Kirkness','Box 2041','MARMION','Western Australia','AUSTRALIA','6020','0862620893','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-23 04:37:20',0,NULL,3,1,3,1,'RA184544846CN\r ','XL  已入库 '),(21715,773306977001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.9,'hermeshine','reapenrewards','hans63@bigpond.com','Hans Bork','8 Heydon crs<br>Evatt','Canberra','Australian Capital Territory','AUSTRALIA','2617','0406742804','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 05:06:39',0,NULL,3,1,11,1,NULL,NULL),(21716,816790895002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','nicoman1112','nmonsod@yahoo.com','Nelson','6150 Canterbury Dr<br>Apt 113','Culver City','CA','UNITED STATES','90230-7190','(310) 477-7131','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-23 05:03:47',0,NULL,3,1,1,1,NULL,NULL),(21717,816794202002,120592918906,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',189,'hermeshine','kairgali','kairgalib@yandex.ru','KAIYRGALI BEKKALI','28 mikrorayon, 27 dom, 7 kvartira','Aktau','Mangistau','KAZAKHSTAN','130000','+7-7292-400216','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-23 05:38:45',0,NULL,3,1,8,1,'CP243056529CN ','1.6*2.1  白色布\r欧标 '),(21718,777707391018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','troublehoney2004','trouble_honey2004@yahoo.co.nz','Honey Landreth','Unit E105<br>6 Mandible Street','Sydney, NSW','New South Wales','AUSTRALIA','2015','0414809058','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2011-12-23 06:17:15',0,NULL,3,1,4,1,'YW868053002CN ','1.6*2.1  白色布 \r▲'),(21719,915312774015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','spindulelisgt','karolismankauskas@yahoo.com','Karolis Mankauskas','Klaipėdos 94a - 12','Panevėžys','','LITHUANIA','37359','(370) 6342 1155','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-23 06:48:42',0,NULL,3,1,3,1,'RA184544829CN\r ',NULL),(21720,773321216001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','aksionov','aaksionov@dodo.com.au','Anthony Aksionov','130 High Street','Cobram','Victoria','AUSTRALIA','3644','0417100147','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-23 07:02:21',0,NULL,3,1,3,1,'RA184544815CN\r ','3XL 已入库 '),(21721,608551637004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','minghuyu','minghuyu@yahoo.com','michael yu','6 Edgeridge Gate, N.W.','Calgary','AB','CANADA','T3A 6H7','(403) 471-6718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 07:34:52',0,NULL,3,1,17,0,NULL,NULL),(21722,773325841001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',1,'AB3331',2.6,'hermeshine','minghuyu','minghuyu@yahoo.com','michael yu','6 Edgeridge Gate, N.W.','Calgary','AB','CANADA','T3A 6H7','(403) 471-6718','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 07:34:51',0,NULL,3,1,11,1,NULL,'Mini 红外  canon    1 \r肥皂盒 柔光罩  430EX    1'),(21723,773340126001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','anhquile','anhquile@yahoo.com','Anh Qui Le','122 Kingsgrove Road. Kingsgrove','Sydney','New South Wales','AUSTRALIA','2208','020421847287','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 09:24:33',0,NULL,3,1,11,1,NULL,' '),(21724,777738615018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÚMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-23 09:54:10',0,NULL,3,1,3,1,'RA184542575CN ',NULL),(21725,816831525002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','jozef.peniak','peniakfoto@gmail.com','Jozef Peniak','Svetlá 1504/1','Nitra','','SLOVAK REPUBLIC','949 01','00421907423907','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:01:02',0,NULL,3,1,3,1,'RA184542641CN ',NULL),(21726,915346922015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','caver_ssv','mescal@yandex.ru','Sergiy Sheremet','Gelvakovskogo st. 6a./14','Dnepropetrovsk','','UKRAINE','49081','+380675628417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 10:05:48',0,NULL,3,1,3,1,'RA184542377CN ',NULL),(21727,773347948001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','xolodilnik.pokypaet','ice.xolodilnik@mail.ru','Евгений Жилин','Гоголя 93 4','Вологда','','RUSSIAN FEDERATION','160014','89535136153','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:19:49',0,NULL,3,1,5,1,'CP243055996CN ',NULL),(21728,816837548002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','yossiburmad1','yossiburmad@gmail.com','yossi BURMAD','Shmuel Rozovsky 4/9','ASHDOD','ISRAEL','ISRAEL','77376','0544737692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:37:50',0,NULL,3,1,17,0,NULL,''),(21729,816837549002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','yossiburmad1','yossiburmad@gmail.com','yossi BURMAD','Shmuel Rozovsky 4/9','ASHDOD','ISRAEL','ISRAEL','77376','0544737692','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 10:37:51',0,NULL,3,0,11,1,NULL,'肥皂盒 柔光罩   580EX     1 \rC型大力夹      1 '),(21730,915363550015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','suntales','minaevlex@gmail.com','Alexey Minaev','Rusanovaskaya naberejnaya 12, kv. 131','Kiev','','UKRAINE','02147','(066) 087 8294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 11:22:45',0,NULL,3,1,5,1,'CP243055979CN ','欧标 '),(21731,915367078015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','lasernostalgi','editman@hotmail.com','Peter Lundström','Fredrik Jahns gränd 14','Nacka','Nacka','SWEDEN','13136','0707993255','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-23 11:39:06',0,NULL,3,1,3,1,'RA184542363CN\r ','申报$15 '),(21732,773363102001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','bishmaru','rucanof@ya.ru','Nikita Rusanov','Street Litkina 14, 504','Tomsk','RU','RUSSIAN FEDERATION','634045','+7 923 4444282','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-23 11:50:41',0,NULL,3,1,11,1,NULL,NULL),(21733,816856608002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','matthew_carr','me@matthewcarr.us','Matthew Carr','20 Alyssa Dr','Lowell','MA','UNITED STATES','01851-2342','(978) 257-3729','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 12:33:51',0,NULL,3,1,3,1,'RA184542451CN ',NULL),(21734,773376245001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','drwjono','dwalujono@gmail.com','Daniel Walujono','7 Helga Place','Hassall Grove','New South Wales','AUSTRALIA','2761','0296280562','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 13:06:21',0,NULL,3,1,11,1,NULL,NULL),(21735,896581052016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','hoskins6384','hoskins.colin@btinternet.com','Colin Hoskins','34 Orchard Way','Knebworth','Hertfordshire','UNITED KINGDOM','SG3 6BU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 13:38:11',0,NULL,3,1,11,1,NULL,NULL),(21736,915397654015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','montblueglass','montblueglassware@gmail.com','Dmitriy Ablaev','Rostislavova 17, Prague 4, Nusle','Prague','Bohemia','CZECH REPUBLIC','14000','+420 608639331','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 13:46:10',0,NULL,3,1,17,0,NULL,NULL),(21737,915397655015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','montblueglass','montblueglassware@gmail.com','Dmitriy Ablaev','Rostislavova 17, Prague 4, Nusle','Prague','Bohemia','CZECH REPUBLIC','14000','+420 608639331','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 13:46:11',0,NULL,3,1,11,1,NULL,'圆形柔光棚 40cm   1 \r倒影板（白黑）    1'),(21738,896586852016,260854010827,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',11.9,'hutongstore','frank3604','fe.glue@ntlworld.com','FRANK GLUE','8 BROOKHEAD DRIVE','CHEADLE','Cheshire','UNITED KINGDOM','SK82HZ','01612823448','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-23 13:57:14',0,NULL,3,1,11,1,NULL,NULL),(21739,773402578001,110767047921,'New Arrival Fancier Professional Tripod & Monopod Kit WT-6614A  w/ Case for DSLR',1,'AD1197',168,'hermeshine','brianbracken1949','brianbracken@yahoo.ca','Brian Bracken','376 Samuel Edey','Gatineau','QC','CANADA','J9J 2J5','(613) 222-7728','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 15:18:22',0,NULL,3,1,5,1,'CP243055951CN ',NULL),(21740,816892571002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','edaliza','edaliza_balingit@yahoo.com','Balingit Edaliza','670 Jalan Damai<br>#14-47','default','','SINGAPORE','410670','+6590670607','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 15:25:09',0,NULL,3,1,11,1,NULL,NULL),(21741,915427237015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','malbb','ebay@loyer.name','Martin Loyer','33 rue de condé','LYON','Rhône-Alpes','FRANCE','69002','0762554019','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-23 15:31:17',0,NULL,3,1,17,0,NULL,NULL),(21742,915427942015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.5,'hutongstore','malbb','ebay@loyer.name','Martin Loyer','33 rue de condé','LYON','Rhône-Alpes','FRANCE','69002','0762554019','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 15:32:46',0,NULL,3,1,4,1,'YW868052980CN ','2B柔    两套\r柔光伞   1\r ▲'),(21743,915438786015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',1,'AD1125',7.9,'hutongstore','victorcap','droit@atlas.cz','Viktor Cap','U Kovarny 24','Olomouc','','CZECH REPUBLIC','77900','+420605577858','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-23 16:09:43',0,NULL,3,1,11,1,NULL,NULL),(21744,773437617001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','tonyphotographer','manutony123456789@hotmail.com','TONY JEFFREY','36 LANGTON WAY','EGHAM','Surrey','UNITED KINGDOM','TW208DP','01784460171','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-23 17:26:55',0,NULL,3,1,3,1,'RA184542385CN\r ',NULL),(21745,816947243002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','aborve','atleborve@gmail.com','Atle Børve','Rieber Mohnsvei 10','Paradis','','NORWAY','5231','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 18:43:47',0,NULL,3,1,11,1,'\\ ',NULL),(21746,773460609001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','dkolega','danijel.kolega1@zd.t-com.hr','Danijel Kolega','Bana Josipa Jelacica 1c','Zadar','','CROATIA','23000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 18:59:54',0,NULL,3,1,5,1,'CP243055965CN ','欧标 '),(21747,816956532002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','tuttle5pi','turtle5pi@yahoo.com','Kevin Kelly','313 Delaware Ave','Absecon','NJ','UNITED STATES','08201','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-23 19:13:12',0,NULL,3,1,1,1,NULL,NULL),(21748,773487384001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','vmjcouch','v.mark.j.couch@citi.com','Mark Couch','176 Broadway<br>Apt 15A','New York','NY','UNITED STATES','10038-2518','(212) 276-5828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-23 20:22:32',0,NULL,3,1,1,1,NULL,NULL),(21749,768728471001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.55,'hermeshine','memmalee01','emmalee.macmaster@gmail.com','Emma-Lee MacMaster','2/17a Collaroy Rd','New Lambton','New South Wales','AUSTRALIA','2305','0418472300','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 20:52:59',0,NULL,3,1,11,1,NULL,NULL),(21750,816990552002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','bayfairdental','269obr@gmail.com','Chris Anderson','DentalPlus<br>41 Girven Road','Mount Maunganui','NZ','NEW ZEALAND','3116','64 7 575 5808','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-23 21:12:11',0,NULL,3,1,3,1,'RA184542448CN ',NULL),(21751,896743271016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','christopher8186','tf1967@hotmail.com','christopher longstaff','77 keir hardy av,','stanley   co.durham','Durham','UNITED KINGDOM','dh96ju','01207234890','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-23 21:57:16',0,NULL,3,1,11,1,NULL,NULL),(21752,836591892017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','jlcortell','pepelu_1990@hotmail.com','Jose Luis Cortell Añó','C/Almeria 10- 7, Catarroja','Valencia','Comunidad Valenciana','SPAIN','46470','675013932','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-23 22:48:26',0,NULL,3,0,3,1,'RA184542709CN ','1.6*3  白色 '),(21753,817033981002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','yobinfo','gblok@yohb.com','Gavin Blok Practice','PO Box 67971','Bryanston','Gauteng','SOUTH AFRICA','2021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 00:29:00',0,NULL,3,1,3,1,'RA184542434CN ','分开发    '),(21754,773558732001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','andykg0935','andykg09@interchange.ubc.ca','Andy Grellmann','4366 Gander Place','Richmond','BC','CANADA','v7e5r1','(604) 512-5961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 02:10:30',0,NULL,3,1,3,1,'RA184542425CN ',NULL),(21755,817083566002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 05:47:35',0,NULL,3,1,17,0,NULL,NULL),(21756,773590097001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','bald_white_buy','bald_white_guy@yahoo.com','Andrew Mercer','Unit 66, 540 Queen Street','Brisbane','Queensland','AUSTRALIA','4000','0457041640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 05:56:44',0,NULL,3,1,3,1,'RA184542417CN ','斜臂    1 \r大力夹云台   1'),(21757,817095807002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 07:39:21',0,NULL,3,1,17,0,NULL,NULL),(21758,773600349001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','jujusito','emiliomserrano@hotmail.com','Emilio Minguez Serrano','C/ Conde de Casas Rojas, nº7 - 4ºA','Alicante','Comunidad Valenciana','SPAIN','03006','658070512','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 07:40:14',0,NULL,3,1,11,1,NULL,'肥皂盒 柔光罩   580EX   1 \r方形滤镜接口环 82mm    1'),(21759,817117341002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',50,'hermeshine','kostelin','kostelin69@yahoo.es','Oier Elorriaga Intxausti','Bº Mendieta  nº67, 1º izda','Ajangiz','País Vasco','SPAIN','48320','699611322','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 10:26:03',0,NULL,3,1,3,1,'RA184542638CN ','Oier Elorriaga Intxausti\rMendieta 67, 1 izda\r48320 Ajangiz\rSpain\r\r\r '),(21760,817150661002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-24 13:43:20',0,NULL,3,1,3,1,'RA184542505CN\r ','申报gift低值 '),(21761,817159483002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','westfotoru','kezzz@mail.ru','Denis Alekseevich Tokarev','Dobrolubova street, dom1 kv 136','Kamensk-Uralsky','(RUS) Sverdlovskaya oblast','RUSSIAN FEDERATION','623428','+7(902)4477166','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 14:25:41',0,NULL,3,1,11,1,NULL,NULL),(21762,773668163001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','2011akam','akamspog@yahoo.com','dr. Akam SpOG, RS Krakatau Medika','Jl. Semang Raya','Cilegon','Banten','INDONESIA','42434','+62254386660','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-24 14:54:38',0,NULL,3,1,11,1,NULL,NULL),(21763,915793307015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',1.88,'hutongstore','kazdaglis','kazdaglis@hotmail.com','Michael Kazdaglis','Agiou Dimitriou 13 - Flat 401<br>Pallouriotissa','Nicosia','Nicosia','CYPRUS','1035','0035799680619','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-24 16:38:56',0,NULL,3,1,11,1,NULL,NULL),(21764,896982689016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','jaakko2232','jaakko.salonen@gmail.com','Jaakko Salonen','Servinkuja 2 D 33','Espoo','Finland','FINLAND','02150','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-24 17:29:45',0,NULL,3,1,24,1,NULL,NULL),(21765,817204630002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','sakkater09','sak_kater@yahoo.gr','Pagonas Athanasios','137 A/K MMP','Litohoro Pierias','','GREECE','60200','6944905449','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-24 17:46:16',0,NULL,3,1,3,1,'RA184542496CN\r ','2个 '),(21766,817206352002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 17:54:45',0,NULL,3,1,3,1,'RA184542482CN\r ',NULL),(21767,773722625001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'',68.99,'hermeshine','spinechocycle','spinecho@hotmail.com','ADAM ELDIEB, C/O BAY RADIOLOGY','71 TENTH AVE<br>PROMED HOUSE, SUITE 4','TAURANGA','','NEW ZEALAND','3110','0210465589','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 19:09:17',0,NULL,3,0,3,1,'RA184542479CN ','2m灯架     1\r闪光灯云台 （配合灯架）   1\r80cm 伞式柔光箱8角     1 \r已入库'),(21768,817224514002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jymbol','ymbolj@yahoo.com','Jesus Ymbol','8726 Deer Creek Cir','Stockton','CA','UNITED STATES','95210-4453','(209) 676-7660','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-24 19:17:04',0,NULL,3,1,3,1,'RA184542465CN ',NULL),(21769,915850277015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','milajaka','dyflooringltd@sky.com','david macanaspie','28 north street<br>bletchley','milton keynes','Buckinghamshire','UNITED KINGDOM','mk22py','01908368099','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-24 20:09:49',0,NULL,3,0,11,1,NULL,'1.6*2.1   黑色'),(21770,915862916015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','lisnotbold','lisnotbold@hotmail.com','Atish Mistry','12 Norbury Avenue','Leicester','Leicestershire','UNITED KINGDOM','LE4 6NW','01162242301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-24 20:57:29',0,NULL,3,1,3,1,'RA184542553CN ',NULL),(21771,915862648015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','kristirim','kristirim@gmail.com','Kristina Noreikiene','Korallveien 4a','Oslo','','NORWAY','0198','37062253785','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-24 20:58:01',0,NULL,3,1,5,1,'CP243055982CN ',NULL),(21772,773764403001,110518902223,'8AA YONGNUO Flash Battery Pack SF-18 Nikon SB900 ',1,'AB3311',49.99,'hermeshine','theralen','info@photomedia.se','Jens C Hilner','Annebergsgatan 8 b','Malmö','Skåne','SWEDEN','214 66','+46 762142730','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-24 22:42:21',0,NULL,3,1,3,1,'RA184542540CN\r ',NULL),(21773,817269672002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','w2willi','wmbeebe2@yahoo.com','william beebe','7021 Bridgewater Dr','smyrna','TN','UNITED STATES','37167-4468','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-24 22:56:36',0,NULL,3,1,1,1,NULL,NULL),(21774,897067415016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','gr8stuff247','angelerediauwa@yahoo.com','angel iguehide erediauwa','FLAT 15, TRAFALGAR COURT<br>Marine Drive','Barking','Essex','UNITED KINGDOM','IG11 0GN','07572075677','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-24 23:08:09',0,NULL,3,1,4,1,'YW868052976CN ','英标 \r▲'),(21775,817273224002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','raoninicolai','raonipn@yahoo.com.br','Raoni Nicolai','Rua Almirante Noronha<br>529','São Paulo','São Paulo','BRAZIL','02043-060','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-24 23:16:47',0,NULL,3,1,11,1,NULL,NULL),(21776,773781891001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','yobinfo','gblok@yohb.com','Gavin Blok Practice','PO Box 67971','Bryanston','Gauteng','SOUTH AFRICA','2021','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 00:33:50',0,NULL,3,1,3,1,'RA184542536CN\r ','分开发\r'),(21777,778225852018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.5,'photographyacc','chklare','chklare@yahoo.com.au','Muhammad N Anwer','50 Isabella Way<br>Tarneit','Melbourne','Victoria','AUSTRALIA','3029','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-25 02:32:49',0,NULL,3,1,11,1,NULL,NULL),(21778,817318778002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','drl1drl','myebay@pathology.uchc.edu','richard lindquist','1047 Main St','South Windsor','CT','UNITED STATES','06074','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 04:50:44',0,NULL,3,1,1,1,NULL,NULL),(21779,817323115002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','neil_le','nle1@tpg.com.au','Nhuong Le','1/11 Kathleen Street','Wiley Park','New South Wales','AUSTRALIA','2195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 05:31:23',0,NULL,3,1,11,1,NULL,NULL),(21780,817324828002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','hariendemel','buwas@omnibis.com','Harien de Mel','44 Guildford Crescent','Colombo 07','','SRI LANKA','00700','0094777683449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 06:10:51',0,NULL,3,1,3,1,'RA184542522CN ',NULL),(21781,817342531002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','samuriah071480','samuriah@gmail.com','Samuel Robinson','30649 Blue Lagoon Cir','Menifee','CA','UNITED STATES','92584-8989','(909) 800-2097','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-25 08:37:11',0,NULL,3,1,1,1,NULL,'L 已入库 '),(21782,773850690001,110560100430,'Heavy Duty Professional Camera Video Tripod Dolly WT600',1,'AO0027',82,'hermeshine','tariqmorning','tariq@morninglight.se','Tariq Hassan','Bandstolsvägen 2','Uppsala','','SWEDEN','75648','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 10:18:35',0,NULL,3,1,4,1,'YW868052582CN ','▲ '),(21783,897174391016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','tariqmorning','tariq@morninglight.se','Tariq Hassan','Bandstolsvägen 2','Uppsala','','SWEDEN','75648','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-12-25 10:38:23',0,NULL,3,1,4,1,'YW868052965CN ','欧标 \r▲\r'),(21784,916014069015,250933223732,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT075',188,'hutongstore','j.hallen88','j.hallen@hotmail.com','Johan Hallén','Räntmästargatan 52','Örebro','Närke','SWEDEN','70225','+731522559','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 11:10:55',0,NULL,3,1,4,1,'YW868052954CN ','欧标 \r▲'),(21785,817375107002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','pabloaronna2009','pabloaronna@hotmail.com','Pablo Aronna','Galicia 49 - Puerta 6','Ibiza','Baleares','SPAIN','07800','971306245','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 11:50:00',0,NULL,3,1,17,0,NULL,NULL),(21786,773867043001,110408007449,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',7.3,'hermeshine','pabloaronna2009','pabloaronna@hotmail.com','Pablo Aronna','Galicia 49 - Puerta 6','Ibiza','Baleares','SPAIN','07800','971306245','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 11:53:20',0,NULL,3,1,11,1,NULL,'EW-73B    1\rET-65B      1\r'),(21787,773875039001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.55,'hermeshine','kopek2009','kopek2008@freemail.hu','Kovacs Magda','Ioan Gallu,12','Satu Mare','Romania','ROMANIA','440084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 12:38:32',0,NULL,3,1,17,0,NULL,NULL),(21788,773866768001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','kopek2009','kopek2008@freemail.hu','Kovacs Magda','Ioan Gallu,12','Satu Mare','Romania','ROMANIA','440084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 12:38:31',0,NULL,3,1,17,0,NULL,NULL),(21789,773889628001,110541874625,'10 NEW 3-stage Rubber Lens Hood 52mm - 77mm Canon Nikon',1,'AKT035',33,'hermeshine','spstack','spstack@gmail.com','Sean P. Stack','5189 S Farmhouse Pl','Boise','ID','UNITED STATES','83716','(208) 841-3267','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-25 13:53:55',0,NULL,3,0,1,1,' ','橡胶遮光罩 58mm   3\r52mm              2\r62 mm           1\r67 mm            2\r72 mm            1\r77 mm          1                   已入库'),(21790,916091777015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2101',25,'hutongstore','hazze58','hazzeeklof@yahoo.se','Hazze Eklöf','sylvasväg 1, 57635, 57635<br>57635','Sävsjö','Sävsjö','SWEDEN','57635','070-6209256','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 16:05:22',0,NULL,3,0,3,1,'RA184546484CN\r ','XL  已入库 '),(21791,817432349002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','unonesimo','unonesimo@hotmail.com','Orlando Díaz Martinez','C/ los planos nº 6 2º b','Arnedo','La Rioja','SPAIN','26580','675076045','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-25 16:24:05',0,NULL,3,1,3,1,'RA184542584CN ',NULL),(21792,773933080001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','kopek2009','kopek2008@freemail.hu','Kovacs Magda','Ioan Gallu,12','Satu Mare','Romania','ROMANIA','440084','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-25 17:12:27',0,NULL,3,1,11,1,' ','绿叶 UV  58mm   1 \r52-58mm 双阳环   1\r52-52mm 双阳环   1\r\r'),(21793,916202952015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',22,'hutongstore','jonde9k','jonde33@hotmail.com','Joonas Tertsunen','Johtokiventie 6','Helsinki','Uusimaa','FINLAND','00710','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-25 20:40:06',0,NULL,3,1,3,1,'RA184542519CN ',' 2个'),(21794,916206691015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','thedanedk','sinklov@dbmail.dk','Uffe Sinklov','Traedrejerporten 45','Hvidovre','Denmark','DENMARK','DK-2650','45-36494953','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-25 20:47:18',0,NULL,3,1,11,1,NULL,NULL),(21795,778451038018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','melaniemick','melanielbusby@hotmail.com','melanie  busby','1447 islay plains rd','alpha','Queensland','AUSTRALIA','4724','0749853551','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-25 20:54:06',0,NULL,3,0,11,1,NULL,'1.6*2.1  白色 '),(21796,837161040017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',22.5,'photographyacc','kaymsea2706','kmc2706@gmail.com','Kylie Cox','64 Avocado Street','Elanora','Queensland','AUSTRALIA','4221','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-25 21:20:05',0,NULL,3,1,11,1,' ',NULL),(21797,837181076017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.5,'photographyacc','leosuzie88','arnie888@iprimus.com.au','arnold in','6 kestrel ave<br>hinchinbrook','sydney','New South Wales','AUSTRALIA','2168','0296072641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-25 22:31:19',0,NULL,3,1,11,1,NULL,NULL),(21798,778489585018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','wojo_5','wojo5@wp.pl','Wojtek Szymanski','27 Woodford Villas','Clondalkin','Dublin','IRELAND','22','353862399','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-25 23:35:59',0,NULL,3,0,11,1,NULL,'1.6*2.1  白色 '),(21799,916266217015,250615150268,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',57.8,'hutongstore','juliano-c','proceram@mundo-r.com','JULIAN CALVO CORDERO','RIESTRA Nº 19-3ºA','PONTEVEDRA','Galicia','SPAIN','36001','986862431','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 00:03:51',0,NULL,3,1,4,1,'YW868052932CN ','▲ '),(21800,8881324861931883,111,'LENSPEN',1,'AA1310',0,'hutongstore','bepi811226','bepi8112@gmail.com','Istvan Bende','Batthyany u. 18/3','Békéscsaba','Bekes','HUNGARY','5600','+36703159299',NULL,NULL,NULL,'2011-12-26 01:12:11',0,NULL,3,1,3,1,'RA184542607CN\r ',' '),(21803,817585884002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mjwhip2','whipple.mike@gmail.com','Mike Whipple','2896 W 2100 N','Clinton','UT','UNITED STATES','84015-7692','(801) 791-5686','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-26 01:40:49',0,NULL,3,1,1,1,NULL,NULL),(21801,8881324863314921,111,'New Photo Studio Light Stand Umbrella Flash B-Mount set',1,'AKT014',42.99,'aliexpress','1005947011','photohappy@mail.ru','Mutiev Hasan','Sheremet evskaya ul 31-2-53','Moscow','Moscow','RUSSIAN FEDERATION','127521','+10 903 7523276',NULL,NULL,NULL,'2011-12-26 01:34:38',0,NULL,3,1,3,1,'RA184542655CN ',NULL),(21802,778515925018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',1,'',80,'photographyacc','demonstrawberry','demon_fairy_666@hotmail.com','Terri Kruithof','60 McMillan Street','Briagolong','Victoria','AUSTRALIA','3860','0351455687','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 01:40:05',0,NULL,3,1,4,1,'YW868052943CN ','▲ '),(21804,774071198001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','limrebali','daunpinus@gmail.com','Ketut Ermilyawan','KARYATANGAN INDAH PT-IT<br>JL BANJAR BATURNING NO 1 MAMBAL ABIANSEMAL','DENPASAR','BALI','INDONESIA','80239','+6281337958059','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-26 01:49:06',0,NULL,3,1,3,1,'RA184542598CN\r ',NULL),(21805,817590482002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','dfaulkne','faulkner@hiwaay.net','James Faulkner','105 Dovewood Pl','Florence','AL','UNITED STATES','35633-1588','(256) 335-8990','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 02:05:31',0,NULL,3,1,1,1,NULL,NULL),(21806,8881324867930509,111,'Holder arm grip',1,'',0,'photographyacc','brunos_92','bru.rou@me.com','ROUBLIQUE','4, sentier des Grimonts','Saint Fiacre','Ile-de-France','FRANCE','77470','0676589971',NULL,NULL,NULL,'2011-12-26 02:52:10',0,NULL,3,0,4,1,'YW868052571CN ','斜臂单轮+沙袋钩子+沙袋 X 4\r 反光板支架杆X 4\r800W  220v  灯泡  X 10\r称一下重量\r检查一下\r4.1'),(21807,817601400002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',4,'AD1169',27.52,'hermeshine','egonzoiii','egonzo3@frontier.com','Edmundo Gonzalez','302 Jenny Lind Dr','Normal','IL','UNITED STATES','61761-4822','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 03:01:11',0,NULL,3,1,1,1,NULL,NULL),(21808,8881324869899836,111,'新款内胆包 canon logo 大号',1,'',0,'hutongstore','sjaychauhan','sjaychauhan@hotmail.com','Sanjay Chauhan','9 Crantock Close','Leicester','Leicestershire','UNITED KINGDOM','LE5 6XG','01162206033',NULL,NULL,NULL,'2011-12-26 03:24:59',0,NULL,3,0,3,1,'RA184542567CN\r ',NULL),(21809,8881324870115617,111,'nikon 镜头盖 62mm',4,'',0,'hermeshine','mrsetcjr','mrsetcjr@verizon.net','michele cook','7711 Gromwell Ct','springfield','VA','UNITED STATES','22152-3128','',NULL,NULL,NULL,'2011-12-26 03:28:35',0,NULL,3,0,1,1,'LK106191796CN  ',''),(21810,817626608002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fotosell','billiardbock@optonline.net','fred bock','po box 618','putnam valley','NY','UNITED STATES','10579-0618','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 05:42:35',0,NULL,3,1,1,1,NULL,NULL),(21811,817630418002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','79233486117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 06:15:04',0,NULL,3,1,3,1,'RA184542624CN ',NULL),(21812,774117734001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','dsn222','dn222@hotmail.com','Daniel Nemes','8/36-38 Park Street, Narrabeen','Sydney','New South Wales','AUSTRALIA','2101','0406785838','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 07:17:01',0,NULL,3,1,3,1,'RA184542615CN ',NULL),(21813,897508721016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','lasernostalgi','editman@hotmail.com','Peter Lundström','Fredrik Jahns gränd 14','Nacka','Nacka','SWEDEN','13136','0707993255','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-26 07:38:42',0,NULL,3,1,3,1,'RA184546440CN\r ','申报$20 '),(21814,897510274016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','bitz007','bitz007@hotmail.com','tobias webb','po box 7212<br>newtown','wellington','new zealand','NEW ZEALAND','6242','021783778','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 07:50:37',0,NULL,3,1,11,1,NULL,NULL),(21815,774126553001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','ilinnikfoto','ilin5574@mail.ru','Андрей Ильин','Калининградская обл. Гурьевский р-он Пос. Большое Исаково ул. Садовая дом 26','Калининград','','RUSSIAN FEDERATION','238311','8-952-795-1771','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 08:30:25',0,NULL,3,1,11,1,NULL,NULL),(21816,778577783018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','jake_the_hake','jake.rusznyak@gmail.com','Jake Rusznyak','BMF Advertising<br>Lvl 2, 63 Miller St Pyrmont','Sydney','New South Wales','AUSTRALIA','2009','0417691452','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 08:37:56',0,NULL,3,1,11,1,NULL,NULL),(21817,817658067002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',3,'AD1125',44.97,'hermeshine','2.1mian','d2mian@hotmail.fr','Demian WICKY','6 Rue de l\'école','Riedisheim','Alsace','FRANCE','68400','0604148192','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-26 09:45:06',0,NULL,3,1,3,1,'RA184546475CN\r ',NULL),(21818,778597090018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','murrami_jagman','jagmanis@hotmail.com','John Barton','44 Judges Gardens','Leda','Western Australia','AUSTRALIA','6170','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2011-12-26 10:24:26',0,NULL,3,1,4,1,'YW868052921CN ','除了C以外再发\r镜头筒 小，中，大，XL大号'),(21819,837312013017,270822547911,'4 pcs Lens Pouch s:70mm x 100mm m:85mm x 150mm l:90mm x 180mm xl:95mm x 230mm',1,'AKT086',18.5,'photographyacc','murrami_jagman','jagmanis@hotmail.com','John Barton','44 Judges Gardens','Leda','Western Australia','AUSTRALIA','6170','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 10:27:34',0,NULL,3,1,17,0,NULL,NULL),(21820,817666726002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 10:28:57',0,NULL,3,1,3,1,'RA184546555CN\r ',NULL),(21821,817669265002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','presseridan','idanpresser@gmail.com','Idan Presser','Shlomoh Hamelech 65 ST','Be\'er Sheva','South','ISRAEL','84548','972545225554','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 10:41:45',0,NULL,3,1,3,1,'RA184546538CN ',NULL),(21822,817683639002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','fotosell','billiardbock@optonline.net','fred bock','po box 618','putnam valley','NY','UNITED STATES','10579-0618','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-26 11:51:08',0,NULL,3,1,1,1,NULL,NULL),(21823,817690126002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',103,'hermeshine','ouharry123','darktirak@indiana-jones-fanclub.com','inconstant jordan','35 rue thiers<br>BP 2109','reims cedex','Champagne-Ardenne','FRANCE','51074','0615580220','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-26 12:23:48',0,NULL,3,1,4,1,'YW868052910CN ','▲ '),(21824,778623614018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.98,'photographyacc','coyote_au','amwcoyte@optusnet.com.au','Adrian Coyte','32 McCartney Cressent','St Clair','New South Wales','AUSTRALIA','2759','0298346834','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 12:27:52',0,NULL,3,1,11,1,NULL,NULL),(21825,774172378001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',8,'AC1301',49.92,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 12:36:07',0,NULL,3,1,3,1,'RA184546586CN\r ','申报gift低值  '),(21826,916418992015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','sufertashu','mihai.stanimir@gmail.com','Mihai Stanimir','Petre Ramneantu nr 15A ap 12','Timisoara','Timis','ROMANIA','300595','0040764177508','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 12:20:45',0,NULL,3,1,3,1,'RA184546515CN ',NULL),(21827,774194514001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','rich15862','rw@bruford.org.uk','RICHARD BRUFORD','NEATHWOOD<br>CHRISTOW','EXETER','DEVON','UNITED KINGDOM','EX6 7PJ','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-26 14:15:35',0,NULL,3,1,3,1,'RA184546419CN\r ',NULL),(21828,817733688002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','erifnonam09','vonrimsskela@hotmail.com','Aleksander Smirnov','2616 Whitehall Ter<br>Apt 102','Louisville','KY','UNITED STATES','40220-6033','(502) 759-4488','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-26 15:30:51',0,NULL,3,1,1,1,NULL,NULL),(21829,897617594016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','north9464','dave@beaver36.freeserve.co.uk','DAVID NORTH','1 HALIFAX CLOSE, BREADSALL','DERBY','Derbyshire','UNITED KINGDOM','DE214GT','01332831608','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 15:32:07',0,NULL,3,1,17,0,NULL,NULL),(21830,916478318015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',2,'AD1402',11,'hutongstore','north9464','dave@beaver36.freeserve.co.uk','DAVID NORTH','1 HALIFAX CLOSE, BREADSALL','DERBY','Derbyshire','UNITED KINGDOM','DE214GT','01332831608','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 15:39:49',0,NULL,3,1,3,1,'RA184546541CN\r ','2mx1.5m 背景板（黑，白）    1 \r柔光伞   2'),(21831,817739107002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','arcane2962','ralphru@gmail.com','Ralph Ruivivar','Commission on Population<br>Cabatangan','Zamboanga City','Zamboanga del Sur','PHILIPPINES','7000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 15:51:09',0,NULL,3,1,3,1,'RA184546422CN\r ',NULL),(21832,916484439015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','filatelijaivic','martinas@net.hr','Ivan Martinas','Primorska 1A','Rijeka','','CROATIA','51000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 15:55:11',0,NULL,3,1,11,1,NULL,NULL),(21833,774219640001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','ashaker11','ahmed.shaker@inbox.com','Ahmed Shaker','P.O. Box 87925 Riyadh 11652 Saudi Arabia<br>4th Floor Dar Al-Hamd Building, Olaya Road, North','Riyadh','','SAUDI ARABIA','11652','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-26 15:55:59',0,NULL,3,1,3,1,'RA184546569CN ','蓝加黑 \r分开发   \rRA184546572CN'),(21834,771161431001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','imperial11101','planetshirley@gmail.com','Shirley Cohen','2523 Voorhees Ave<br>Apt B','Redondo Beach','CA','UNITED STATES','90278-2567','(253) 709-8077','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-26 16:11:45',0,NULL,3,1,1,1,NULL,NULL),(21835,774246659001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454010','8-951-488-9340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 17:21:45',0,NULL,3,1,17,0,NULL,NULL),(21836,774246658001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454010','8-951-488-9340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 17:21:44',0,NULL,3,1,17,0,NULL,NULL),(21837,774246660001,110581528856,'Video Tripod Fluid Pan Head EI717 717 1.55m 5ft version',1,'AO0022',244,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454010','8-951-488-9340','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 17:21:45',0,NULL,3,1,5,1,'CP243056515CN ','DSLR-Rig    1 \rks-0 III (白盒）  1\r三脚架 伟峰 EI-717  155   1'),(21838,916519995015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','french_aristo','frederic_ebay@mac.com','Frederic Feret-Fillon','3 Merlin Way<br>Jennett\'s Park','Bracknell','Berkshire','UNITED KINGDOM','RG12 8BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 17:24:10',0,NULL,3,1,3,1,'RA184546467CN\r ',NULL),(21839,817777461002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','bzul2117','wxyzreviews@hotmail.com','Brent Zuliani','311 11th ave','Lively','ON','CANADA','p3y 1m8','(705) 692-1043','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 17:44:48',0,NULL,3,1,3,1,'RA184546609CN\r ',NULL),(21840,916564378015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','gregwild1954','snorkas@gmail.com','Graham  Adams','30 Sydenham Court','Kelso','Borders','UNITED KINGDOM','TD5 7NR','01573229413','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 18:57:40',0,NULL,3,1,11,1,NULL,NULL),(21841,897724616016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','emakariene11','makarasm@hotmail.com','Martynas Makaras','Uogynu 3','Vijoliai, Siauliai','Siauliu r','LITHUANIA','76225','+370 6 3505073','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 19:31:19',0,NULL,3,1,11,1,NULL,NULL),(21842,897730296016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','djm49000','duncan.macgregor@talktalk.net','Duncan J MacGregor','17 Phillips Close','Bridgwater','Somerset','UNITED KINGDOM','TA6 7AR','01278453412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 19:43:57',0,NULL,3,1,11,1,NULL,NULL),(21843,897771983016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','lamia10','kelly.e.boyce@btinternet.com','Philip Boyce','30 Dereham Rd','Shipdham','Norfolk','UNITED KINGDOM','IP25 7NA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-26 21:18:04',0,NULL,3,1,11,1,NULL,NULL),(21844,778806529018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',43,'photographyacc','tomandkay1956','toml2008@live.co.uk','Thomas Lavender','50 Walton Avenue','Blyth','Northumberland','UNITED KINGDOM','NE24 5HB','01670368650','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-26 21:54:01',0,NULL,3,1,3,1,'RA184546590CN\r ',NULL),(21845,897793830016,260894475399,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',9.5,'hutongstore','hacker_toni','amms_6210@hotmail.com','António Manuel Martins dos Santos - JOSE RAPOSO','Rua Conde D. Henrique Lote 1 - 3Drt','Satão','Satão/Viseu/Portugal','PORTUGAL','3560-183','00351932885018','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-26 22:14:02',0,NULL,3,1,11,1,NULL,NULL),(21846,778831307018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','jesimclaren','jesimclaren@hotmail.com','Jessica Mclaren','1/50 Duffys Road','Terrigal','New South Wales','AUSTRALIA','2260','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-26 23:16:23',0,NULL,3,1,11,1,NULL,NULL),(21847,817897789002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','rochediag38','frederic.jacquey@free.fr','frédéric JACQUEY','53 chemin des Brunets<br>Bat B Les Coteaux de Lumbin','LUMBIN','Rhône-Alpes','FRANCE','38660','04.76.76.30.90','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 23:38:25',0,NULL,3,1,17,0,NULL,NULL),(21848,774370685001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','rochediag38','frederic.jacquey@free.fr','frédéric JACQUEY','53 chemin des Brunets<br>Bat B Les Coteaux de Lumbin','LUMBIN','Rhône-Alpes','FRANCE','38660','04.76.76.30.90','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-26 23:38:25',0,NULL,3,1,3,1,'RA184546507CN\r ','大力夹   1 \r魔术手臂11寸    1'),(21849,817915053002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','jaymesdickerson','jdanda@gmail.com','Jaymes Dickerson','2353 Preston Park Ct','Decatur','GA','UNITED STATES','30032-5200','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-27 00:42:37',0,NULL,3,1,3,1,'RA184546498CN\r ',NULL),(21850,769833505001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','mikipico','miguelina77@hotmail.com','Miguelina Pico','Joaquín V. Gonzalez  719<br>entre calle Thames y Wilde','Buenos Aires','Boulogne','ARGENTINA','1609','','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-27 00:43:50',0,NULL,3,1,3,1,'RA184546524CN\r ',NULL),(21851,817937193002,120761201279,'10pcs color filters ring holder box for cokin p series',1,'AKT082',48,'hermeshine','finnigan001','finnigan001@iprimus.com.au','Tim leonard','3 Galian Way','Spearwood','Western Australia','AUSTRALIA','6163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 02:15:16',0,NULL,3,1,3,1,'RA184546657CN\r ',' '),(21852,8881324956168597,111,'1600W 套装',1,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2011-12-27 03:22:48',0,NULL,3,1,12,1,'3436178955 ','灯架  2m   2\r45w 5500k 灯泡 110v   8\r4灯头+50-70棚    2\r灯架包    3\r 实重5.92  泡重7.2'),(21853,8881324957484172,111,'2m 灯架上面2个配件',1,'',0,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273',NULL,NULL,NULL,'2011-12-27 03:44:44',0,NULL,3,0,3,1,'RA184546643CN\r ',NULL),(21854,778895766018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',4.5,'photographyacc','deviltrucho','devil_trucho@hotmail.com','César Lopez','10470 Avenue Papineau','Montréal','QC','CANADA','H2B 2A4','(514) 680-4068','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-27 03:46:50',0,NULL,3,1,11,1,'BJ01670219\r ',NULL),(21855,8881324959659595,111,'欧标',1,'',0,'hermeshine','souzanka4875','souzanka@hotmail.com','Souzan Mazloum','Chemin du Chalet de Pra Roman 6','LAUSANNE 26','','SWITZERLAND','1000','',NULL,NULL,NULL,'2011-12-27 04:20:59',0,NULL,3,1,3,1,'RA184546626CN\r ','大的那个转欧标转换器\r澳标转欧标 '),(21856,774432936001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','autosmile1','g-navigator@km.ru','Vladislav Volynka','Dumenko 4-26','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350089','(928) 2100152','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-27 04:27:30',0,NULL,3,1,3,1,'RA184546630CN\r ',NULL),(21857,774450972001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','oren1975','oren@cigarmag.co.il','Oren Kfir','4th Hasahlav','Raanana','Israel','ISRAEL','43394','972-50-6006007','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 06:35:37',0,NULL,3,1,3,1,'RA184549049CN\r ','4个 '),(21858,916787278015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','oceanoccc','oceano_ce@hotmail.com','César Cortinas Cano','Paseo Florencio Marcos, 13-19, esc 1, 2º E','Salamanca','Salamanca','SPAIN','37008','629557066','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 06:45:56',0,NULL,3,1,11,1,'BJ01601323\r ',NULL),(21859,774159714001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','sottelkrauze','krauze2003@mail.ru','Viktor Krauze','Voroshilova 62-39','Ust-Kamenogorsk','VKO','KAZAKHSTAN','070002','+77052811111','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:10:12',0,NULL,3,1,8,1,'CP211275531CN ','欧标 '),(21860,817966264002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.5,'hermeshine','frondoza','gtrak@hotmail.com','IOANNIS  TRAKADAS','AGIOS DIMITRIOS<br>PAPAGOY 18','ATHENS','ATTICA','GREECE','173 43','+306943482953','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:13:27',0,NULL,3,1,11,1,'BJ01601322\r ',NULL),(21861,817963359002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','chevtchenko72','clin_cardio@yahoo.com','Alexey Shevchenko','Osennij blvd 10-1-463','Moscow','','RUSSIAN FEDERATION','121609','(985) 7238599','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 07:53:40',0,NULL,3,1,5,1,'CP243056002CN ','欧标 '),(21862,916822353015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','gabrielaxox','gabriela_porcaru@hotmail.co.uk','Gabriela Porcaru','53 Sirinham Point','London','London','UNITED KINGDOM','SW8 1QE','07889684210','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-27 09:56:12',0,NULL,3,1,4,1,'YW868052615CN ','+  1.6*2.1  白色布\r▲'),(21863,778949620018,280676579733,'New 52mm Macro Reverse Adapter Ring for Nikon AF Mount',1,'AA1210',4.85,'photographyacc','sdcbmac','sdcb@iinet.net.au','Sean McKibbin','2 Price St St','Moss Vale','New South Wales','AUSTRALIA','2577','0422000044','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-27 09:34:38',0,NULL,3,1,11,1,'BJ01601321\r ',NULL),(21864,897966255016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','pppyuma','signorgasmo@hotmail.it','Saul Paloschi','via Caprera 68','Cremona','CR','ITALY','26100','3497810611','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-27 10:44:23',0,NULL,3,1,4,1,'YW868052626CN ','欧标 \r▲'),(21865,818037472002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tmutila','timo.mutila@kolumbus.fi','Timo Mutila','Kirkkotie 686','Nurmijarvi','','FINLAND','01900','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 11:57:44',0,NULL,3,1,3,1,'RA184546918CN\r ',NULL),(21866,774521895001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',2,'AD1182',156,'hermeshine','joakim.k','joakim_k@yahoo.com','Joakim Karlsson','Nobelvagen 11a','Malmo','','SWEDEN','214 29','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 13:30:00',0,NULL,3,1,4,1,'YW868052630CN ',NULL),(21867,815350253002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',4,'AB2301',32.8,'hermeshine','elizeucine','agenciamol@gmail.com','elizeu mol','Rua Sempre Viva 155/304<br>Privavera','Timoteo','Minas Gerais','BRAZIL','35182-446','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 13:58:09',0,NULL,3,1,3,1,'RA184547003CN\r ',NULL),(21868,818064904002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',2,'AA1205',4.4,'hermeshine','dwoolfie_sick_sad_world','dwoolfie@netspace.net.au','David Woolfield','214 Old North Rd','Wamuran','Queensland','AUSTRALIA','4512','0754966781','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:15:20',0,NULL,3,1,11,1,'BJ01601326\r ',NULL),(21869,818067509002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','madbrother','juergen.frick@a1.net','Jürgen Frick','Dr. Isa Großschädelweg 7b','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:42:32',0,NULL,3,1,17,0,'RA184546997CN\r ',NULL),(21870,818066348002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',7.5,'hermeshine','madbrother','juergen.frick@a1.net','Jürgen Frick','Dr. Isa Großschädelweg 7b','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:42:33',0,NULL,3,1,17,0,'RA184546997CN\r ',NULL),(21871,774531451001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','madbrother','juergen.frick@a1.net','Jürgen Frick','Dr. Isa Großschädelweg 7b','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:42:33',0,NULL,3,1,17,0,'RA184546997CN\r ',NULL),(21872,818066701002,120500442483,'Large size Neoprene Lens Pouch / Case 90mm x 220mm',1,'AC1203',5.6,'hermeshine','madbrother','juergen.frick@a1.net','Jürgen Frick','Dr. Isa Großschädelweg 7b','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:42:34',0,NULL,3,1,17,0,'RA184546997CN\r ',' '),(21873,818067102002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','madbrother','juergen.frick@a1.net','Jürgen Frick','Dr. Isa Großschädelweg 7b','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 14:42:35',0,NULL,3,1,3,1,'RA184546997CN\r ','lenspen    1\r气吹 + 布   1\r大号内胆包canon   1\r镜头筒 小号    1\r镜头筒 大号     1\r4片装的滤镜袋    1\r'),(21874,916904401015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','katre60','andreaspranklen@talktalk.net','Brian Spranklen','59 Shaw Lane','Glossop','Derbyshire','UNITED KINGDOM','SK13 6EF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 14:50:01',0,NULL,3,1,3,1,'RA184546983CN\r ',NULL),(21875,818095536002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','dudi275','dudi.y@hotmail.com','Dudi Yecheskel','41 Yossef st.','Modiin','','ISRAEL','71700','0549454063','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 15:54:16',0,NULL,3,1,11,1,'BJ01601325\r ',NULL),(21876,818097248002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','paulpacifico','polo33700@gmail.com','Paul Pacifico','11 rue Emile zola','Merignac','Aquitaine','FRANCE','33700','33683706025','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 16:01:07',0,NULL,3,1,11,1,'BJ01601331\r ',NULL),(21877,818100374002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','sam34290','samirquarcia81@msn.com','samir quarcia','les 4 vents chemins des serres','montblanc','Languedoc-Rousillon','FRANCE','34290','0467390291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 16:10:14',0,NULL,3,1,11,1,'BJ01601320\r ',NULL),(21878,818120123002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sgotwr','zen223820@zen.co.uk','Alwyn Jones','27 The Square','Blaenau Ffestiniog','Gwynedd','UNITED KINGDOM','LL413UL','01766830291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 17:06:00',0,NULL,3,1,3,1,'RA184546970CN\r ',NULL),(21879,774584335001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',2,'AKT056',120,'hermeshine','murtgot','martin@gotblad.com','Martin Gotblad','Hornsgatan 79','STOCKHOLM','SE','SWEDEN','11849','46 706472500','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-27 17:11:30',0,NULL,3,1,4,1,'YW868052641CN ','2套 '),(21880,774585253001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','1965ayb','arnoyb@terra.com.br','Arno Yukio Borges','Rua José Tomasi # 142 ; Casa 9','Curitiba','Paraná','BRAZIL','82.015-630','55(41)3015-4395','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 17:14:14',0,NULL,3,1,11,1,'BJ01601324\r ',NULL),(21881,916589658015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','twiggy5959','alexandre.lescieux@gmail.com','Chantal DEMORTIER','1, Rue Descartes','DUNKERQUE','Nord-Pas-de-Calais','FRANCE','59140','0328590716','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 17:29:57',0,NULL,3,1,3,1,'RA184546949CN\r ',NULL),(21882,774596333001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','tlrurka','tlrurka@yahoo.ca','Twila Rurka','3104 67a ST','Edmonton','AB','CANADA','T6K 1S1','(780) 468-3485','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 17:47:51',0,NULL,3,1,11,1,'BJ01601329\r ',NULL),(21883,916985422015,250600488479,'New Hairlight  photostudio boom arm and Light stand ',1,'AKT030',32.8,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 18:10:56',0,NULL,3,1,17,0,NULL,NULL),(21884,898117127016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 18:10:55',0,NULL,3,1,4,1,'YW868052652CN ','除了C以外再发\r2.4x3m背景架+ 白布    1 \r灯架  2m   1 \r斜臂      1\r欧标\r▲'),(21885,916985732015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 18:10:56',0,NULL,3,1,17,0,NULL,'\r '),(21886,774603937001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 18:13:14',0,NULL,3,1,3,1,'RA184546935CN\r ',NULL),(21887,898154475016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ryanmalta','farrugiaryan@hotmail.com','Ryan Farrugia','Block B , Flat 3 , G/H/E<br>Triq San Frangisk Saverju','Birzebbuga','Birzebbuga','MALTA','bbg2206','21651686','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 19:22:57',0,NULL,3,1,3,1,'RA184546881CN\r ',NULL),(21888,917033915015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','ryanmalta','farrugiaryan@hotmail.com','Ryan Farrugia','Block B , Flat 3 , G/H/E<br>Triq San Frangisk Saverju','Birzebbuga','Birzebbuga','MALTA','bbg2206','21651686','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 19:38:40',0,NULL,3,1,17,0,'RA184546952CN\r ',NULL),(21889,917035613015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',5.5,'hutongstore','ryanmalta','farrugiaryan@hotmail.com','Ryan Farrugia','Block B , Flat 3 , G/H/E<br>Triq San Frangisk Saverju','Birzebbuga','Birzebbuga','MALTA','bbg2206','21651686','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 19:41:47',0,NULL,3,1,3,1,'RA184546952CN\r ','灯架  2m  1\r反光伞   1\r\r'),(21890,917066025015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','jacket_potato','vaughan5@hotmail.co.uk','Vaughan Matthews','48 Collinwood Road<br>Headington','Oxford','Oxfordshire','UNITED KINGDOM','OX3 8HL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 20:41:01',0,NULL,3,1,11,1,'BJ01601319\r ',NULL),(21891,917082031015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','alert24','j_navaratnam@hotmail.com','Jay Navaratnam','12 Farmstead Road','Harrow','Middlesex','UNITED KINGDOM','HA3 5HQ','07904092234','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-27 21:12:07',0,NULL,3,1,3,1,'RA184546878CN\r ',NULL),(21892,818231514002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','petruchioo10','petruchioo@gmail.com','Petar Cholakov','Hristo Maksimov 16<br>floor 1','Sofia','Sofia','BULGARIA','1111','+35928717506','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-27 21:49:11',0,NULL,3,1,11,1,'BJ01601318\r ',NULL),(21893,917104118015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','duiveltje21','zenga13@hotmail.com','Chantal Sintmaartensdijk','Beiaard 379','Etten-Leur','NB','NETHERLANDS','4876 CK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 22:02:14',0,NULL,3,1,17,0,'RA184549035CN\r ',NULL),(21894,917103810015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','duiveltje21','zenga13@hotmail.com','Chantal Sintmaartensdijk','Beiaard 379','Etten-Leur','NB','NETHERLANDS','4876 CK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 22:02:15',0,NULL,3,1,3,1,'RA184549035CN\r ','圆形柔光棚 50cm   1 \r倒影板（白黑）   1'),(21895,917098993015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','taralolo','ebuyclub91@ebuyclub.com','blanc sandra','78 rue danton','draveil','Île-de-France','FRANCE','91210','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-27 22:02:41',0,NULL,3,1,11,1,'BJ01601316\r ',NULL),(21896,774714603001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','oshead087','oshead@gmail.com','David O\'Shea','27 Lanesborough Crescent<br>Finglas','Dublin','Dublin','IRELAND','D11','852722474','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-27 23:07:08',0,NULL,3,1,3,1,'RA184546864CN\r ',NULL),(21897,818275183002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','glueparkenigma','gpking@angelking.net','Graeme King','71 Waratah Drive','Altona Meadows','Victoria','AUSTRALIA','3028','0417472363','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 00:12:58',0,NULL,3,1,11,1,'BJ01601315\r ',NULL),(21898,898281024016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','videoshopping','estetica80@gmail.com','FABRIZIO PESCE WAGNER','MONTE SIRENTE 27','FRANCAVILLA AL MARE','CH','ITALY','66023','3292514624','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 00:18:00',0,NULL,3,1,4,1,'YW868052663CN ','欧标 \r▲'),(21899,818298528002,120448645643,'TianYa Gradual Orange Filter for Cokin P Series Sunset',1,'AA2317',7.2,'hermeshine','davethay','xenovolcano@yahoo.com','David Thayer','Im Gstein 110','Embrach','','SWITZERLAND','8424','(044) 576-1135','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 01:43:12',0,NULL,3,1,11,1,'BJ01601317\r ',NULL),(21900,8881325036595492,111,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',15.99,'aliexpress','1005999396','trots.m@gmail.com','Margarita Trots','Delegatskaya str. 16/1/ apts 135 ','Moscow','Moscow','RUSSIAN FEDERATION','127473','+7 926 5206253',NULL,NULL,NULL,'2011-12-28 01:43:15',0,NULL,3,1,17,0,NULL,NULL),(21901,8881325036788027,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',25.99,'aliexpress','1005999395','trots.m@gmail.com','Margarita Trots','Delegatskaya str. 16/1/ apts 135 ','Moscow','Moscow','RUSSIAN FEDERATION','127473','+7 926 5206253',NULL,NULL,NULL,'2011-12-28 01:46:28',0,NULL,3,1,17,0,NULL,NULL),(21902,838024674017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','xsf-1','ecca22@gmail.com','Vanguard Nagal','12 Tania Street','North Sunshine','Victoria','AUSTRALIA','3020','030405051976','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-28 02:29:25',0,NULL,3,1,11,1,'BJ01601332\r ',' '),(21903,8881325039589507,111,'800W 220V 灯泡',1,'',0,'hermeshine','selcankurt85','selcanaydinli@gmail.com','Selcan Kurt','sevgi mah. 663 sok. 18/101 gaziemir/ izmir (asil iş hanı- Aydınlı Eczanesi)','İZMİR','','TURKEY','35410','',NULL,NULL,NULL,'2011-12-28 02:33:09',0,NULL,3,0,3,1,'RA184546966CN\r ','仔细检查一下灯丝有没有坏 \r\r多包些保护好'),(21904,774765357001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','defranki79h6','defranki@aol.com','Unforgettable Images','1007 54th st','Oakland','CA','UNITED STATES','94608-3131','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-28 02:40:05',0,NULL,3,1,1,1,NULL,NULL),(21905,8881325040330476,111,'New Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.99,'aliexpress','1006009728','trots.m@gmail.com','Margarita Trots','Delegatskaya str. 16/1/ apts 135 ','Moscow','Moscow','RUSSIAN FEDERATION','127473','+7 926 5206253',NULL,NULL,NULL,'2011-12-28 01:46:28',0,NULL,3,1,3,1,'RA184549707CN\r ','倒影板（白黑） * 1 \r圆形柔光棚 60cm * 1\r绿叶 渐变镜 62mm * 1'),(21906,818316072002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',75,'hermeshine','likemlo','medwards@dzinex.us','Melvin Edwards','4009 Gaster Ave','North Las Vegas','NV','UNITED STATES','89081-6696','(702) 280-0300','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-28 02:51:41',0,NULL,3,1,4,1,'YW868052674CN ','换弹簧灯架给他 \r▲'),(21907,917208485015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','hazel_757','h.photography@live.co.uk','Hazel McDowall','St Julian\'s farm<br>ShoscombeBath','Bath','Avon','UNITED KINGDOM','BA2 8NE','07730266285','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2011-12-28 03:21:01',0,NULL,3,1,4,1,'YW868052685CN ','1.6*2.1黑加白 \r▲'),(21908,774776923001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','iphoto84','ghostboy1@gmail.com','Ivan Martinez','1531 Apache Dr<br>Unit E','Chula Vista','CA','UNITED STATES','91910-7154','(619) 482-8743','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-28 03:34:29',0,NULL,3,1,1,1,NULL,NULL),(21909,917214174015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','trinityracinguk','trinityracinguk@hotmail.com','william mcgregor','Flat 0/2 25 Kilmuir cresent<br>Thornliebank','Glasgow','East renfrewshire','UNITED KINGDOM','G46 8DL','01416203382','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 03:43:28',0,NULL,3,1,3,1,'RA184549052CN\r ',NULL),(21910,609603657004,140651224761,'New Mini IR Wireless Remote Control for Nikon D90 D3000 D80 D7000 D5100',1,'AD1116',3.3,'hermeshine','ashleeclark','ashleeclark@hotmail.com','Ashlee Carroll','124 Preston Trl','Meadowlakes','TX','UNITED STATES','78654-6434','(512) 660-4833','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-28 04:26:51',0,NULL,3,1,1,1,NULL,NULL),(21911,818340488002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','6843_orangutan','kazzwilloughby@yahoo.com.au','Karen Nielsen','12 Grace Court','Heritage Park','Queensland','AUSTRALIA','4118','0423436843','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 04:44:12',0,NULL,3,1,11,1,'BJ01601328\r ',NULL),(21912,609610352004,140651224761,'New Mini IR Wireless Remote Control for Nikon D90 D3000 D80 D7000 D5100',1,'AD1116',3.3,'hermeshine','nettybooper','nettybooper@charter.net','annette c siebert','92 Valley View Dr','pismo beach','ca','UNITED STATES','93449-2867','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-28 05:26:23',0,NULL,3,1,1,1,'\\ ',NULL),(21913,838073514017,270747042771,'New 67mm Snap-on Front Lens Cap for Canon 67mm lenscap',4,'AA1302',10,'photographyacc','ronl1909','arlager@bigpond.net.au','Ron Lagergren','C/- BP Service Station<br>94 Main Street','Foster','Victoria','AUSTRALIA','3960','0356822008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-28 06:26:55',0,NULL,3,1,17,0,NULL,NULL),(21914,779310288018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.6,'photographyacc','ronl1909','arlager@bigpond.net.au','Ron Lagergren','C/- BP Service Station<br>94 Main Street','Foster','Victoria','AUSTRALIA','3960','0356822008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-28 06:26:54',0,NULL,3,1,17,0,NULL,NULL),(21915,838074772017,270745064346,'New Green.L Premium Quality 58mm UV Filter Canon Nikon ',1,'AA3303',3.49,'photographyacc','ronl1909','arlager@bigpond.net.au','Ron Lagergren','C/- BP Service Station<br>94 Main Street','Foster','Victoria','AUSTRALIA','3960','0356822008','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-28 06:26:55',0,NULL,3,1,3,1,'RA184549755CN\r ','CANON 镜头盖  67mm   4 \r绿叶 CPL  67mm   1\r绿叶 UV  58mm   1'),(21916,818357704002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','pete082005','peterandgarnet@bigpond.com','Peter Siccama','7 Mal St','Camira','Queensland','AUSTRALIA','4300','0733890640','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 06:33:55',0,NULL,3,1,11,1,NULL,NULL),(21917,774735856001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','gedrasas','gstugas@gmail.com','Giedrius Stugas','Ežero 3 - 41','Šiauliai','','LITHUANIA','77142','37061283598','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 09:29:43',0,NULL,3,1,3,1,'RA184549724CN\r ',NULL),(21918,818385095002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','chevymuscle572','bhallgts@gmail.com','Ben Hall','c/o Animal Control Technologies<br>46-50 Freight Drive','Somerton','Victoria','AUSTRALIA','3062','0419841989','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 09:36:08',0,NULL,3,1,11,1,NULL,NULL),(21919,898409998016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','bluewiccan1','eric130152@hotmail.com','Eric McFadyen','Unit 7<br>47 Malcolm St','West Perth','Western Australia','AUSTRALIA','6005','0893241757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 10:02:07',0,NULL,3,0,3,1,'RA184549888CN\r ','1.6*3  黑色 '),(21920,818393041002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','serg140457','sergltd@list.ru','Sergey Gorban','Starokorsunskaya<br>85','Krasnodar','Krasnodarskii krai','RUSSIAN FEDERATION','350912','(861) 227-8429','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:17:07',0,NULL,3,1,3,1,'RA184549812CN ',NULL),(21921,774846526001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','spzphoto','info@spzphoto.gr','Spiros Zacharakis','Digeni Akrita 3','Chania','Crete','GREECE','73100','00306937633526','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-28 10:43:59',0,NULL,3,1,17,0,NULL,NULL),(21922,818398610002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','spzphoto','info@spzphoto.gr','Spiros Zacharakis','Digeni Akrita 3','Chania','Crete','GREECE','73100','00306937633526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:43:59',0,NULL,3,1,17,0,NULL,NULL),(21923,818398611002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','spzphoto','info@spzphoto.gr','Spiros Zacharakis','Digeni Akrita 3','Chania','Crete','GREECE','73100','00306937633526','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 10:44:00',0,NULL,3,1,3,1,'RA184549826CN\r ','4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）  1\rlenspen   1\r伞式柔光箱 60×90cm    1\r欧标\r包好后称一下重量看挂号超重吗\r '),(21924,917314692015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','eperjesi.tomas','tomas.eperjesi@gmail.com','Tomas Eperjesi','Tulska 31','Zvolen','','SLOVAK REPUBLIC','96001','0903017073','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 11:39:22',0,NULL,3,1,11,1,NULL,NULL),(21925,917329062015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','steveepsilon','steveandjaneo@btinternet.com','stephen lowe','Golf Links Farm,Bradnor<br>Kington','Hereford','Herefordshire','UNITED KINGDOM','HR53RE','01544239091','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 12:27:53',0,NULL,3,1,3,1,'RA184549830CN\r ',NULL),(21926,917334043015,250692239254,'New Neoprene Reversible Cover for Canon 5D II 7D L',1,'AC1304',5.5,'hutongstore','sunbeam278','hellohaze@aol.com','Hazel Morgan','27 Rigby Road','Liverpool','Merseyside','UNITED KINGDOM','L318AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 12:44:35',0,NULL,3,1,11,1,NULL,NULL),(21927,917339289015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','tathagataone','tathagata@rocketmail.com','Tristan McDonald','154 Richmond Road','Bristol','Bristol','UNITED KINGDOM','BS6 5ES','07578110436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 13:02:34',0,NULL,3,1,3,1,'RA184549843CN\r ',NULL),(21928,818435262002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','hrcornejo_zamora','hrcornejo@gmail.com','Héctor Rodríguez Cornejo','Avd. Alfonso Peña 1, 4º B','Zamora','Castilla y León','SPAIN','49010','699236232','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 13:33:00',0,NULL,3,1,11,1,NULL,NULL),(21929,917379333015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','therealbruce1','rob.walker@versko.com','Rob Walker','36 Rowallan Gardens','Glasgow','Glasgow (City of)','UNITED KINGDOM','G117LJ','01415766195','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 15:07:44',0,NULL,3,1,11,1,NULL,NULL),(21930,916695908015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','balazsve','balazs.vizhanyo@gmail.com','Balazs Vizhanyo','Interior Art kft<br>Stefánia 6','Szeged','Csongrád','HUNGARY','6720','0036205753933','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 15:34:39',0,NULL,3,1,3,1,'RA184549857CN\r ',NULL),(21931,774934708001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','hlaz212','hlaz212@yahoo.com','Hassan Lazrag','1 allée Jacques Offenbach','Suresnes','Ile de France','FRANCE','92150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 16:35:43',0,NULL,3,1,3,1,'RA184549684CN\r ',NULL),(21932,917447538015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','mria*creativ','hormann_maria@freemail.hu','Mária Kassainé Hörmann','1214 Budapest<br>Rákóczi Ferenc út 322','Budapest','alapértelmezés','HUNGARY','1214','3614251681','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 17:42:17',0,NULL,3,1,11,1,' ',NULL),(21933,818521666002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sam34290','samirquarcia81@msn.com','samir quarcia','les 4 vents chemins des serres','montblanc','Languedoc-Rousillon','FRANCE','34290','0467390291','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 18:01:01',0,NULL,3,1,3,1,'RA184549715CN\r ',NULL),(21934,818541604002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-28 18:54:42',0,NULL,3,1,3,1,'RA184549738CN\r ','M  已入库 \r2件'),(21935,917494556015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','safianauman','i.y.nauman@gmail.com','nauman israr','flat 1a<br>20 westbourne street','stockton on tees','Cleveland','UNITED KINGDOM','ts18 3eh','01642730721','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 19:14:41',0,NULL,3,1,3,1,'RA184549786CN\r ','共2个 '),(21936,917495552015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','loupdrawolbo','jm.roux3@gmail.com','JEAN MICHEL ROUX','4 RUE DU NEOULOUS','TRESSERRE','Languedoc-Roussillon','FRANCE','66300','06.85.64.94.49','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 19:16:31',0,NULL,3,1,3,1,'RA184549769CN\r ',NULL),(21937,917504001015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',2,'AD1176',47,'hutongstore','mariacf71','cebrian.maria@gmail.com','maria cebrian fernandez','huertas de mataespesa 29','alpedrete','Madrid','SPAIN','28430','677431853','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 19:32:42',0,NULL,3,1,4,1,'YW868052906CN ','欧标 \r2套\r▲'),(21938,775005374001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','jenbeaul','jen@kreativetouch.ca','Jen Duffin','170 Murray St.','Brantford','ON','CANADA','N3S5R2','(519) 720-0897','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-28 19:33:57',0,NULL,3,1,3,1,'RA184549891CN\r ','共4个 \r110V '),(21939,917522405015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','behemot288','dublin_couple@o2.pl','Dominik Urbanowicz','22 La Vallee','Bray','Wicklow','IRELAND','01','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 20:05:16',0,NULL,3,1,3,1,'RA184549790CN\r ',NULL),(21940,818583489002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','primoycete','primoy@ya.com','Antonio Otero Primoy','C/ Breogán nº 13, piso 1º','Ferrol','Galicia','SPAIN','15401','679946603','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-28 20:28:44',0,NULL,3,1,3,1,'RA184549741CN\r ',NULL),(21941,818590937002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','tshirtcrib','sunnymathur@gmail.com','Sunny Mathur','7587 Lindberg Dr','Alexandria','VA','UNITED STATES','22306','(732) 991-8822','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-28 20:45:29',0,NULL,3,1,3,1,'RA184549809CN\r ',NULL),(21942,818593075002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','luberon01','jaimeleluberon@hotmail.fr','Philippe chaupin','9 bis rue voltaire','L Isle sur la sorgue','Provence-Alpes-Côte d\'Azur','FRANCE','84800','0682294034','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-28 20:54:23',0,NULL,3,1,3,1,'RA184549772CN\r ','共 2个\r又重发了一次。\r单号RA184504365CN\r'),(21943,917575658015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','safeasfcuk2008','danny_linton@yahoo.com','danny linton','28 brandy cove road','swansea','Swansea','UNITED KINGDOM','sa33hb','01792233314','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 21:54:30',0,NULL,3,1,3,1,'RA184549905CN\r ',NULL),(21944,917577507015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','94mitchell','vmtch@hotmail.co.uk','Victoria Mitchell','115 Canesworde Road','Dunstable','Bedfordshire','UNITED KINGDOM','LU6 3PZ','01582752297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-28 21:57:46',0,NULL,3,1,3,1,'RA184549667CN\r ',NULL),(21945,917608422015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',2,'AD1176',47,'hutongstore','pekinensraimonds','pekinens@inbox.lv','RAIMONDS GLAUDA','VALDLAUCI 8-28','RIGA','','LATVIA','LV 1076','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-28 23:16:05',0,NULL,3,1,5,1,'CP211275528CN ','欧标\r2套 '),(21946,818676324002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','74anki','majusk@hotmail.com','anki karlsson','bangårdsgatan 31','torsby','none','SWEDEN','68533','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 01:25:14',0,NULL,3,1,3,1,'RA184549675CN\r ',NULL),(21947,8881325122706909,111,'Pro FANCIER WFC-592T Carbon Fiber Tripod +Ball Head kit',1,'AO0020',144.99,'aliexpress','1006029158','jonas@jonta.se','Jonas Eriksson','Borgnasgatan 18','Malmo','SWE','SWEDEN','212 36','+46 070 5955441',NULL,NULL,NULL,'2011-12-29 01:38:26',0,NULL,3,1,4,1,'YW868052711CN ',' '),(21948,818696045002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','rbsantanna','rbsantanna@yahoo.com.br','Roberto Bertolini Sant Anna','Rua Tutoia, 811<br>Caixa Postal - 27036','Sao Paulo','Sao Paulo','BRAZIL','04007970','551198349955','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 02:47:38',0,NULL,3,1,11,1,NULL,NULL),(21949,775133985001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',35.99,'hermeshine','amtozzi1','ambertozzi9600@comcast.net','Amber Trementozzi','9600 Treemont Ln','Spotsylvania','VA','UNITED STATES','22553-1934','(540) 507-8295','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-29 02:49:57',0,NULL,3,1,3,1,'RA184549698CN\r ','2节 '),(21950,775153958001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','79233486117','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 04:32:26',0,NULL,3,1,3,1,'RA184547198CN ',NULL),(21951,779691584018,280670190865,'Green.L Premium Quality 72mm CPL Circular Polarizer New',1,'AA3313',7.2,'photographyacc','streblo69','streblo@live.ca','Jonathan  Millions','11 Red Willow cr','winnipeg','MB','CANADA','r2j 4g4','(204) 254-7126','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-29 05:07:02',0,NULL,3,1,11,1,NULL,NULL),(21952,779699992018,280667740626,'New IR Wireless Remote Control for Sony a230 a330 a550',1,'AA2203',3.5,'photographyacc','julie0480','roganj44@yahoo.com.au','Julie Hudson','P.O. Box 131','Bourke','New South Wales','AUSTRALIA','2840','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-29 06:01:25',0,NULL,3,1,11,1,NULL,NULL),(21953,779707271018,280666852926,'Photo Studio Light Stand Heavy Duty Clamp Copper head  ',1,'AE3102',10,'photographyacc','matthew.cen','su_rmt78@yahoo.com','rahmat rahmat','1/50 Flinders Street<br>Darlinghurst','Sydney','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-29 06:51:14',0,NULL,8,1,17,0,NULL,' '),(21954,779707759018,280774575751,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',9,'photographyacc','matthew.cen','su_rmt78@yahoo.com','rahmat rahmat','1/50 Flinders Street<br>Darlinghurst','Sydney','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-29 06:54:14',0,NULL,3,1,11,1,NULL,'大力夹   1\r闪光灯B座   1'),(21955,818743519002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','chossoun','bahaanadem@yahoo.com','bahaa nadem','38768 fairfield dr','sterling heights','MI','UNITED STATES','48310-3146','(586) 822-5693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 07:12:29',0,NULL,3,1,1,1,NULL,'L '),(21963,775197706001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','axoyloys1976','fotiadis21@hotmail.gr','iordanis fotiadis','abadon 28','axarnes','προεπιλογή','GREECE','13672','6986834539','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 09:36:37',0,NULL,3,1,11,1,NULL,NULL),(21956,609889488004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','steeleo07','steele_89@hotmail.com','Steele Luscombe','34 Portumna Street<br>Bracken Ridge','Brisbane','Queensland','AUSTRALIA','4017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 08:24:41',0,NULL,3,1,11,1,'BJ01670200\r ',NULL),(21957,775187186001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','xforced','xforsaged@gmail.com','Сергей Борисов','б-р Гая 16/101','Тольятти','Самарская обл','RUSSIAN FEDERATION','445039','+79084013388','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-29 08:27:52',0,NULL,3,1,5,1,'CP211275545CN ','黑加白 '),(21958,818751214002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','drorartzi','drorartzi@gmail.com','Dror Artzi','default','Kibbutz Kfar Hanassi','','ISRAEL','12305','972528088775','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 08:34:15',0,NULL,8,1,17,0,NULL,NULL),(21959,818750654002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','drorartzi','drorartzi@gmail.com','Dror Artzi','default','Kibbutz Kfar Hanassi','','ISRAEL','12305','972528088775','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-29 08:34:16',0,NULL,3,1,3,1,'RA184547272CN\r ','2云柔  1\r肥皂盒 柔光罩   580EX  1 '),(21960,775188637001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','pugl2000','pnfirth@hotmail.com','Peter Firth','23 Yarra Bank Court','Abbotsford','Victoria','AUSTRALIA','3067','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 08:39:33',0,NULL,3,1,11,1,NULL,NULL),(21961,898857036016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','h_strand','heidistrand@hotmail.com','Heidi Strand','Mølledalen 11','Sandnes','','NORWAY','4319','+4793228807','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-12-29 08:42:57',0,NULL,3,1,12,1,'3436156721  ','欧标\r220V \r实重7.1 泡重9.1'),(21962,775196198001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','raj695','rajnesh.devasahayam@sydney.edu.au','Raj Devasahayam','14 Barrett Street','Guildford','New South Wales','AUSTRALIA','2161','0401601940','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 09:22:11',0,NULL,3,1,11,1,NULL,NULL),(21964,838536185017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',9,'photographyacc','aoa_vic','abel.abella@hotmail.com','Abel Abella','73 Pacific Drive','Aspendale Gardens','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-29 10:09:46',0,NULL,3,1,11,1,'BJ01670058\r ',NULL),(21965,917776345015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','pootes','info@sarahdunn.com','sarah dunn','73 Macleod Road','London','London','UNITED KINGDOM','N21 1SW','02083640906','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 10:50:20',0,NULL,3,1,11,1,NULL,NULL),(21966,917487437015,250599949620,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',16,'hutongstore','lingstar22','theraddish@hotmail.co.uk','Chris Lingham','325 esparto way<br>south darenth','dartford','Kent','UNITED KINGDOM','da49lq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 10:51:29',0,NULL,3,1,3,1,'RA184547343CN\r ',NULL),(21967,818795000002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','eutas70','eusokol@yahoo.com','Evgeniy Sokolov','ul. Mironshoh, 84','Tashkent','Uzb','UZBEKISTAN','100015','+99897 470-10-36','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 12:03:57',0,NULL,3,1,3,1,'RA184547391CN\r ',NULL),(21968,775244685001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','nat4gk','sector1903@gmail.com','Mike Keller','Brunngasse 4','Winterthur','','SWITZERLAND','8400','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 13:13:56',0,NULL,3,1,11,1,NULL,NULL),(21969,779789550018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','gregokoi','ian_grego@yahoo.co.uk','IAN GREGORY','4 HAYFIELD CLOSE, BELPER','derby','Derbyshire','UNITED KINGDOM','DE561FA','01773825030','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-29 13:36:50',0,NULL,3,1,11,1,NULL,NULL),(21970,898938164016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','luchs60','p.lux@gmx.ch','Peter Luchs','Talstrasse 23','Brienz','','SWITZERLAND','3855','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 13:44:54',0,NULL,3,1,3,1,'RA184547312CN\r ',NULL),(21971,917843743015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','victico_7','victico7@hotmail.com','Victor Triana Gil','C/Industria, 20, bajo','El Astillero','Cantabria','SPAIN','39610','687841404','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-29 14:32:25',0,NULL,3,1,4,1,'YW868052696CN ','▲ '),(21972,818849719002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','vsaaa','vesaaa@gmail.com','Vesa Antikainen','Pohjankulma 4 A 5','Tampere','Tampere','FINLAND','33500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 15:27:06',0,NULL,3,1,3,1,'RA184547365CN\r ',NULL),(21973,818851266002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','idan998','idanhuri@gmail.com','idan huri','ha-vered 27','reshon le-zion','','ISRAEL','75441','9720523694762','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 15:34:10',0,NULL,3,1,3,1,'RA184547326CN\r ',NULL),(21974,917901864015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','1975rocket','rocket75@hotmail.co.uk','Majid Hussain','6 Leyton Park Road','Leyton','London','UNITED KINGDOM','E10 5RJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 16:52:57',0,NULL,3,1,3,1,'RA184547405CN\r ',NULL),(21975,917902964015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',2,'AKT069',84,'hutongstore','mariacf71','cebrian.maria@gmail.com','maria cebrian fernandez','huertas de mataespesa 29','alpedrete','Madrid','SPAIN','28430','677431853','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-29 16:54:45',0,NULL,3,1,17,0,NULL,NULL),(21976,775313006001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1307',5.2,'hermeshine','joshmartin82073','joshtn@gmail.com','Josh Martin','179 Bellingham Ln<br>Apt 203','Cordova','TN','UNITED STATES','38018-4894','(901) 692-1420','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 17:03:41',0,NULL,3,1,1,1,NULL,NULL),(21977,899013501016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','kellbrooke','montysmama@hotmail.co.uk','amanda womack','10 matlock crescent<br>south oxhey','watford','Hertfordshire','UNITED KINGDOM','wd197gb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-29 17:03:45',0,NULL,3,1,3,1,'RA184547428CN\r ',NULL),(21978,775319387001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','michaelpicas','randomizer2000@hotmail.com','Michael Picas','Artemidos 9 Aglantzia','Nicosia','','CYPRUS','2101','0035799806449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 17:22:53',0,NULL,3,1,11,1,NULL,NULL),(21979,917902966015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',2,'AD1126',15.2,'hutongstore','mariacf71','cebrian.maria@gmail.com','maria cebrian fernandez','huertas de mataespesa 29','alpedrete','Madrid','SPAIN','28430','677431853','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 16:54:46',0,NULL,3,1,4,1,'YW868052700CN ','115w 5500k 灯泡  220v    8个 \r白反光伞110cm     2\r▲'),(21980,775341372001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',2,'AO0015',15.8,'hermeshine','dvdguychatter2','doggyman15@gmail.com','Jasmin Gluhić','Jamska cesta 4','Postojna','Notranjsko kraška regija','SLOVENIA','6230','+38657262215','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 18:22:17',0,NULL,3,1,11,1,NULL,NULL),(21981,818902004002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','manwilk','feliciobrandao@gmail.com','Felicio Domingos Brandao','R J 3 Q 11 LT 01 SETOR JAO','Goiania','Go','BRAZIL','74673-150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 19:30:42',0,NULL,3,1,17,0,NULL,NULL),(21982,818899456002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','manwilk','feliciobrandao@gmail.com','Felicio Domingos Brandao','R J 3 Q 11 LT 01 SETOR JAO','Goiania','Go','BRAZIL','74673-150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 19:30:42',0,NULL,3,1,3,1,'RA184547414CN\r ','大号内胆包 无字  1 \r摄影背心 夏  L     1'),(21983,775389063001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','drummerstefen','stefen.palam@gmail.com','stefen palam','433 Martingrove Road','Toronto','ON','CANADA','M9B 4M3','(416) 620-1930','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 20:20:49',0,NULL,3,1,3,1,'RA184547459CN\r ',NULL),(21984,899126516016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','josephl2011','josephloudon@hotmail.com','Joseph Loudon','103 Abercromby Avenue','HIGH WYCOMBE','Buckinghamshire','UNITED KINGDOM','HP12 3BN','01494556971','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2011-12-29 20:50:43',0,NULL,3,1,11,1,NULL,NULL),(21985,775395421001,110777196885,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k for 5D2  7D',1,'AD1149',230,'hermeshine','mark_alot','mark_alot85@hotmail.com','mark valines','703 calle rio de janeiro','san juan','puerto rico','PUERTO RICO','00915-4617','(787)220-0792','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-29 20:58:30',0,NULL,3,1,4,1,'YW868052722CN ','▲ '),(21986,899148379016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','byfer39','fernando2@burna.e.telefonica.net','Fernando Ocaña Fernandez','C/lerida, 92 Local Bajo - Burna -','Madrid','Madrid','SPAIN','28020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-29 21:37:43',0,NULL,3,1,3,1,'RA184547330CN\r ',NULL),(21987,779980540018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',5.9,'photographyacc','a1pharam','sean.baverstock@gmail.com','Sean Baverstock','24 Chessington Crescent<br>Trentham','Stoke on Trent','Staffordshire','UNITED KINGDOM','ST4 8ER','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-29 22:09:08',0,NULL,3,1,11,1,NULL,NULL),(21988,819014487002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','achangsta','chang.andy@gmail.com','Andy Chang','3920 Mystic Valley Pkwy<br>Apt 314','Medford','MA','UNITED STATES','02155-6905','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-29 22:55:01',0,NULL,3,1,3,1,'RA184547374CN\r ',NULL),(21989,819029497002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','santigris','santigris@hotmail.com','Santiago Sanchez moreno','C/ Gran Vía, 17, 1-D (santiago y Mª Jose)','Cehegín','Murcia','SPAIN','30430','686143675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 23:42:17',0,NULL,3,1,17,0,NULL,NULL),(21990,775457179001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','santigris','santigris@hotmail.com','Santiago Sanchez moreno','C/ Gran Vía, 17, 1-D (santiago y Mª Jose)','Cehegín','Murcia','SPAIN','30430','686143675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 23:42:18',0,NULL,3,1,17,0,NULL,NULL),(21991,819028949002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','santigris','santigris@hotmail.com','Santiago Sanchez moreno','C/ Gran Vía, 17, 1-D (santiago y Mª Jose)','Cehegín','Murcia','SPAIN','30430','686143675','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-29 23:42:18',0,NULL,3,1,12,1,'3436156732 ','除了C里面以外再发\rlenspen   1 \r1.6*2.1  灰色\r欧标\r实重6.2  泡重7.3'),(21992,819038617002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','marcos.fialho','marcos_fialho@yahoo.com.br','Marcos Fialho','LEONCIO JOSE RODRIGUES 69<br>CS','Belo Horizonte','MINAS GERAIS','BRAZIL','31742179','553195042708','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 00:21:40',0,NULL,3,1,3,1,'RA184547388CN\r ',NULL),(21993,918100384015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','anton_du_toit','antondutoit@live.co.uk','Anton du Toit','26 Worple Road<br>2nd Floor','Wimbledon','London','UNITED KINGDOM','SW194EE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 00:01:18',0,NULL,3,1,11,1,NULL,NULL),(21994,819044589002,120581410694,'NIB TianYa 72mm ND8 filter New 72 Neutral Density Grey',1,'AA2313',7.4,'hermeshine','harrymharing1953','harrymharing@hotmail.com','Harry Haring','PO Box 803','Lyndoch','South Australia','AUSTRALIA','5351','0423464439','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 00:35:59',0,NULL,3,1,11,1,NULL,NULL),(21995,775462437001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','alannareeves','lanny-lou@hotmail.com','Alanna Reeves','45 Birubi Road','Lavington','New South Wales','AUSTRALIA','2641','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 01:17:19',0,NULL,3,1,11,1,NULL,NULL),(21996,819062617002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 01:48:57',0,NULL,3,1,3,1,'RA184547431CN\r ',NULL),(21997,819069103002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jorniboy1989','jorniboy89@gmail.com','jørn edvardsen','Balsfjordvinden 20','tromsø','tromsø','NORWAY','9006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 02:15:13',0,NULL,3,1,3,1,'RA184547445CN\r ','申报$30  '),(21998,775502536001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','tombricke','bricke.thomas@att.net','Mary Bricke','2042 Ridgeline Ave','Vista','CA','UNITED STATES','92081','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 02:51:21',0,NULL,3,1,1,1,NULL,''),(21999,775515681001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','kl7hlf','donlinnen@juno.com','Donald L Linnen','3349 S 2000 W','Syracuse','UT','UNITED STATES','84075-8906','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-30 03:51:22',0,NULL,3,1,1,1,NULL,NULL),(22000,775525107001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','abx1982','robert_bonilla@hotmail.com','Robert Bonilla','A7 Urb Santa Marta','San German','PR','UNITED STATES','00683-4402','(787) 717-3269','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-30 04:37:25',0,NULL,3,1,1,1,NULL,NULL),(22001,780084033018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','gathcity69','gathcity@yahoo.ca','Tom Gath','553 Devine St.','Sarnia','ON','CANADA','N7T 1W7','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 04:56:33',0,NULL,3,1,11,1,NULL,NULL),(22002,819106050002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',29.99,'hermeshine','jarrod.basl','jarrodsumpter@gmail.com','Just Basl Productions','14021 15th Ave NE<br>Apt 304N','Seattle','WA','UNITED STATES','98125-3186','(503) 580-4665','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 05:04:49',0,NULL,3,1,1,1,NULL,NULL),(22003,819107373002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','dollars*11','dollars_princess07@yahoo.com','dollars Bun','6A Burne Ave','Clayton South','Victoria','AUSTRALIA','3169','0433721299','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 05:11:48',0,NULL,3,1,11,1,NULL,NULL),(22004,819089310002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','phyy00','paul@paulyeung.org','Irene Wong','1542 Nanton Avenue','Vancouver','BC','CANADA','V6J 2X2','(604) 788-1668','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 06:26:00',0,NULL,3,1,12,1,'3436161875 ','110V  \r美标\r实重11.2  泡重12.9'),(22005,819126270002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','sammy3503','jack_411@yahoo.com','Jack Boungnaseng','14815 Flint Bridge Ct','Sugar Land','TX','UNITED STATES','77498-7065','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-30 07:19:36',0,NULL,3,1,1,1,NULL,NULL),(22006,838945649017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','punkthesystem','butleris@gmail.com','Jeremy','Suite 4 / 30-38 Victoria St','Paddington','New South Wales','AUSTRALIA','2021','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2011-12-30 08:35:56',0,NULL,3,1,11,1,'\\   ',NULL),(22007,819153996002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','jurepez','jure.pezdirc@gmail.com','Jure Pezdirc','Trnjava 60','Lukovica','Lukovica','SLOVENIA','1225','+38640845635','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 10:08:11',0,NULL,3,1,23,1,'BP04081201030006 ',NULL),(22008,775586055001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','737607','torunov@gmail.com','Валерий Торунов','Безбокова 1а-33','Иркутск','Иркутская область','RUSSIAN FEDERATION','664056','(914)895-8121','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-30 11:01:13',0,NULL,3,1,5,1,'CP243056458CN\r ','黑加白 '),(22009,819166038002,120539705975,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',9.6,'hermeshine','shaun7794','saf57@iinet.net.au','Shaun Finch','P.O. Box 180','Bridgetown','Western Australia','AUSTRALIA','6255','0897614352','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 11:06:02',0,NULL,3,1,11,1,NULL,NULL),(22010,899357361016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','zak-zak-zak','m0522670797@gmail.com','zecharia liberman','nahal ein gedi 33/2','beit shemesh','beit shemesh','ISRAEL','99098','508288088','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2011-12-30 11:07:24',0,NULL,3,1,12,1,'2100834595 ','欧标 \r申报sample $49\r在不影响体积的情况下\r能多放个灯泡就多放1个\r实重6.2  泡重8.1'),(22011,819174624002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 11:48:17',0,NULL,3,1,11,1,NULL,NULL),(22012,819185870002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','sova353','eastudio_fotki@mail.ru','Olga Porter','Level 2, LeasePlan House<br>Central Park, Leopardstown','Dublin','','IRELAND','D18','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 12:37:08',0,NULL,3,1,24,1,NULL,NULL),(22013,775616776001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','val5736','val195736@gmail.com','VALERY OTIN','yl.Galyhina,19-176','Arhangelsk','RU','RUSSIAN FEDERATION','163065','79062850449','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 13:22:40',0,NULL,3,0,11,1,' ','1.6*2.1  黑色 '),(22014,780184588018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','zenitar16','taimen1@mail.ru','Aleksej Aksenov','Medicinskiy 20-532','Krasnoyarsk','Krasnoyarsk','RUSSIAN FEDERATION','660042','+79232892744','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 13:42:06',0,NULL,3,1,5,1,'CP243056461CN\r ',NULL),(22015,775628343001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-30 14:05:26',0,NULL,3,1,25,1,'RT123689475HK\r ',NULL),(22016,819210775002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','cody-ru','codymail@mail.ru','Stanislav Burenkov','ul Makarenko 22 kv 128','Novosibirsk','','RUSSIAN FEDERATION','630027','+79137006583','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 14:17:22',0,NULL,3,1,5,1,'CP243056435CN\r ','欧标 '),(22017,918313284015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','lolhangman','lmaitrehut@gmail.com','loic maitrehut','1300 route des cretes<br>wallstreet systems','Valbonne','Provence-Alpes-Côte d\'Azur','FRANCE','06560','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2011-12-30 13:52:04',0,NULL,3,1,4,1,'YW868052733CN\r ','欧标 \r1.6*2.1  白色布\r补发的夹子单号\rRA184530793CN'),(22018,835259215017,270787913068,'Strong Camera shoulder bag D8 for Nikon D90 D7000 D5000',1,'AD1163',29.99,'photographyacc','hhdjz','hhdjz2004@gmail.com','QUAN JIANG','247 Selwyn Rd','Richmond Hill','ON','CANADA','L4E0R4','(416) 264-7318','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 14:27:53',0,NULL,3,1,3,1,'RA184539126CN\r ',NULL),(22019,918326048015,250666866568,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49,'hutongstore','siljen69','silviofarrugia@onvol.net','Silvio Farrugia','Jensil, Triq Santa Marija','Marsascala','MALTA','MALTA','MSK1080','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 14:29:16',0,NULL,3,1,5,1,'CP243056444CN\r ','欧标 '),(22020,899421124016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','dgaga64','k.gaga@gmx.net','Dragica Krekovic','Promenade 8','Davos Platz','','SWITZERLAND','7270','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 14:31:04',0,NULL,3,1,24,1,NULL,NULL),(22021,918329756015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','cesarmurdok','cesarmurdok@hotmail.com','César Casco Oviedo','Calle San Prudencio<br>15, 3º Izda','Espera','Cadiz','SPAIN','11648','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 14:38:14',0,NULL,3,1,21,1,'RA184539069CN\r ',NULL),(22022,918331632015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','pattypatritsia','patty.p9@gmail.com','Patritsia Panayi','Georgiou Sfrantzi 5/101<br>Strovolos','Nicosia','','CYPRUS','2047','00357-99565946','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 14:46:00',0,NULL,3,1,5,1,'CP243056413CN\r ','棕色布 '),(22023,819229054002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','anochecer4321','amanecer_4321@hotmail.com','Ramiro Villar Ruiz','C/ Los Álamos, 286, urb. La Arboleda<br>Pioz','Guadalajara','Castilla-La Mancha','SPAIN','19162','680992478','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 15:20:09',0,NULL,3,1,2,1,NULL,NULL),(22024,918350051015,250692240567,'TianYa Gradual color Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 15:31:44',0,NULL,3,0,17,0,NULL,NULL),(22025,918350053015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 15:31:44',0,NULL,3,1,17,0,NULL,''),(22026,819262347002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','kazaparia','post-indep-production@hotmail.fr','Raoul Dattola','3 rue Mancel','Lorient','Bretagne','FRANCE','56100','0679080918','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','0000-00-00 00:00:00',0,NULL,7,0,18,0,NULL,NULL),(22027,918403769015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','alphablue_0','mail@andrewh52.plus.com','andrew huszar','63 dale st','rochdale','Lancashire','UNITED KINGDOM','OL163NJ','07973735570','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 17:35:31',0,NULL,3,1,11,1,NULL,NULL),(22028,918418791015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','mw007.2008','marcio_wagner@hotmail.com','Marcio Wagner','Flat7<br>4 Stead\'s Place - Leith','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','eh6 5ad','07977816520','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 18:08:51',0,NULL,3,1,11,1,NULL,NULL),(22029,918452760015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','2565dennis','denfos@sky.com','Dennis Foster','12 Staincross Avenue, Crosland Moor','Huddersfield','West Yorkshire','UNITED KINGDOM','HD4 5HZ','01484651142','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-30 19:18:15',0,NULL,3,1,3,1,'RA184537638CN\r ',NULL),(22030,775737857001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'',68.99,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 19:34:24',0,NULL,3,1,21,1,'RA184548128CN\r\r ',' 灯架+伞式柔光箱 80cm 8角 +云台 '),(22031,819329461002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','bronco1158','enemyno1@seznam.cz','Rostislav Mikulka','Tresnova 1158','Straznice','Jihomoravsky','CZECH REPUBLIC','69662','+420 721 502 890','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-30 19:58:54',0,NULL,3,1,3,1,'RA184539130CN\r ',NULL),(22032,899577411016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','macfor','enricmacia2011@yahoo.es','Enric Macià','Vic, 10 (tienda)','SANT HILARI SACALM','Cataluña','SPAIN','17403','629415391','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-30 20:35:57',0,NULL,3,1,2,1,NULL,NULL),(22033,775782819001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','bob_nic','rpbaill@optonline.net','Robert Baillie','51 Leewater Ave','Massapequa','NY','UNITED STATES','11758-8314','(516) 541-3575','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-30 21:38:21',0,NULL,3,1,1,1,NULL,NULL),(22034,839206066017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',78,'photographyacc','liamneeson','curtis-m@live.ie','Curtis Morris','32s Pearse House<br>Pearse Street','Dublin 2','','IRELAND','','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-30 21:49:10',0,NULL,3,1,21,1,'RA184539090CN\r ',NULL),(22035,775826905001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','malclakin','malclakin@yahoo.co.uk','malcolm lakin','45 coleridge rd<br>lipson','plymouth','Devon','UNITED KINGDOM','pl4 7pa','01752558425','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 00:22:14',0,NULL,3,1,11,1,NULL,'渐变灰   1 '),(22036,899415885016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',24,'hutongstore','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 01:05:54',0,NULL,3,0,3,1,'RA184539191CN\r ','1.6x3m  绿色   2 '),(22037,819426066002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','thrift_store_mommy','lisa@coastalpetrescue.org','Lisa Scarbrough c/o Paula Deen Enterprises','2391 Downing Ave','Savannah','GA','UNITED STATES','31404-3925','(912) 856-2710','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2011-12-31 01:19:56',0,NULL,3,1,1,1,'LK168759914CN\r ',NULL),(22038,819429846002,120767298141,'16chan Wireless Remote Control Cord for Nikon D90 D7000',1,'AD1178',18.5,'hermeshine','ernist5','ernist1@gmail.com','Ernestas Stanulis','359 55th St<br>Apt 201W','Clarendon Hills','IL','UNITED STATES','60514-1781','(630) 570-1425','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 01:37:52',0,NULL,3,1,1,1,'LK165016991CN\r ',NULL),(22039,819443848002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','kazulow','kazuoppac@gmail.com','Marcelo Haraguchi','Av. Bosque da Saude, 546 - apt.212    Saude','Sao Paulo','SP','BRAZIL','04142081',' 551188503776','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 02:43:46',0,NULL,3,1,5,1,'CP243056395CN\r ',NULL),(22040,835002212017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',220,'photographyacc','lilitasatryan','ylarmenia@yahoo.com','LIlit Asatryan','Sisakyan<br>8-24','Yerevan','Ajapnyak','ARMENIA','0099','055423348','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-31 06:41:50',0,NULL,3,1,5,1,'CP243056400CN\r ','欧标 '),(22041,775904465001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','rcal2566','ruel_sc@yahoo.com','ruel calungsod','16611 woodruff avenue apt 37','bellflower','CA','UNITED STATES','90706','(562) 726-9385','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 07:53:49',0,NULL,3,1,1,1,' ',NULL),(22042,819506271002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-31 09:23:43',0,NULL,3,1,17,0,NULL,NULL),(22043,819506272002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-31 09:23:44',0,NULL,3,1,5,1,'CP243056373CN\r ','115w 5500k 灯泡  220v   4 \r5灯头+60-90棚     1  转欧标\r普通有线快门线C1     1'),(22044,918694873015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','budmal17545','mlettin@blueyonder.co.uk','Malcolm lettin','111 Arundell Drive<br>Lundwood','Barnsley','South Yorkshire','UNITED KINGDOM','S71 5LF','01226711428','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 09:29:51',0,NULL,3,1,3,1,'RA184539231CN\r ','M号'),(22045,899776479016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','m0rdc','robertcooke1964@tiscali.co.uk','Mr Robert Cooke','24 Meadfoot Road<br>Moreton','Wirral','Merseyside','UNITED KINGDOM','CH46 7UW','07801993334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 09:37:12',0,NULL,3,1,3,1,' RA184539112CN\r',' '),(22046,918698937015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','wmw-wmw','wmw777wmw@yahoo.com','Ilya Anshin','Elijas 5-9','Riga','','LATVIA','1050','37125555271','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2011-12-31 09:50:11',0,NULL,3,1,24,1,'30110727242\r ',NULL),(22047,819485536002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','kazaparia','post-indep-production@hotmail.fr','Raoul Dattola','3 rue Mancel','Lorient','Bretagne','FRANCE','56100','0679080918','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2011-12-31 10:18:36',0,NULL,3,1,4,1,'YW868052744CN\r ',NULL),(22048,775927613001,110790903696,'New Neoprene Soft Camera Cover Canon EOS 450D with kit lenses 18-55mm 50mm',1,'AD1213',7.99,'hermeshine','thiago_miller','thiago_miller@hotmail.com','Thiago Miller','Rua Maria Borba, N°67, AP 86','São Paulo','SP','BRAZIL','01221040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 10:29:50',0,NULL,3,1,24,1,'30111186626\r ','包好后称一下重量 86G'),(22049,775938189001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',2.18,'hermeshine','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 11:21:35',0,NULL,3,1,11,1,NULL,'天涯方形滤镜  渐变橙  1 \r3片装的滤镜袋   1\r方形滤镜接口环 55mm    1\r已入库 '),(22050,775945669001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','saether.t','saether.thomas@gmail.com','Thomas Sæther','Gamleveien 2F leil 303','Ås','Akershus','NORWAY','1430','91163952','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 11:58:24',0,NULL,3,1,21,1,'RA184539109CN\r ',NULL),(22051,819476022002,120616934286,'Video Tripod Fluid Pan Head EI717 717 1.80m 6ft version',1,'AO0023',275,'hermeshine','mr.rauld','raul_duenas@hotmail.com','Raul Dueñas Sedano','82 N Terrace Ave<br>PMB 176','Nogales','AZ','UNITED STATES','85621-3215','(520) 762-7310','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2011-12-31 12:00:50',0,NULL,3,1,4,1,'YW868052755CN\r ','▲ '),(22052,918741976015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','m1xzg','rmckenzi@rpmdp.com','Robert McKenzie','19 Goldfinch Drive<br>Cottenham','Cambridge','Cambridgeshire','UNITED KINGDOM','CB24 8XY','07733322998','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 12:44:41',0,NULL,3,1,11,1,NULL,NULL),(22053,8881325336230237,111,'灯架配件',1,'',0,'photographyacc','klim_buyer','mailto@i.ua','Klim Ivantsov','ul. Teatralnaya, dom 5, kv. 35','Dnepropetrovsk','Dnepropetrovskaya oblast','UKRAINE','49047','',NULL,NULL,NULL,'2011-12-31 12:57:10',0,NULL,3,0,21,1,'RA184539143CN\r ','2m灯架下面的支架 + 最上面的塑料件 '),(22054,819534943002,120503730834,'New Fancier Carbon Fiber WFC-592T + WF-570H Ball head',1,'AO0020',179,'hermeshine','upltradingsro','roman.jurik@upltrading.eu','Roman Jurik','bystre 1323<br>Bystre 1323','frenstat pod radhostem','Moravskoslezsky','CZECH REPUBLIC','74401','00420731104104','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 13:14:51',0,NULL,3,1,5,1,'CP243056387CN\r ',NULL),(22055,918756667015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','malkimberley19','malkimberley@btinternet.com','Malcolm Shaw','Little House<br>Laurel Gardens','Yatton','Bristol','UNITED KINGDOM','BS49 4AE','01934833216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 13:25:13',0,NULL,3,1,3,1,'RA184539205CN\r ',NULL),(22056,819584154002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gpr1958','grahamrobins.net@googlemail.com','GRAHAM ROBINS','125 Hinkler Road<br>Thornhill','Southampton','Hampshire','UNITED KINGDOM','SO19 6FW','02380477860','NoPaymentFailure','CheckoutComplete','OtherInternational','2011-12-31 15:06:40',0,NULL,3,0,3,1,'RA184539228CN\r ','XXXL  (已入库） '),(22057,899885064016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',24,'hutongstore','napnigel','welshents@aol.com','nigel popp','39 heol rhos las<br>swansea road','merthyr tydfil','Merthyr Tydfil','UNITED KINGDOM','cf48 1hf','01685350171','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 15:45:05',0,NULL,3,0,3,1,'RA184537615CN\r ','1.6*3    黑色 1\r1.6*3  白色   1'),(22058,819639613002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','andykg0935','andykg09@interchange.ubc.ca','Andy Grellmann','4366 Gander Place','Richmond','BC','CANADA','v7e5r1','(604) 512-5961','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 17:56:30',0,NULL,3,1,3,1,'RA184539245CN\r ',NULL),(22059,819654343002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','alexenot','ebayman@ua.fm','Alexei Slusarenko','92/100 Moskovskaya st., app. 35','Azov','Rostov-on-Don region','RUSSIAN FEDERATION','346787','79185089992','NoPaymentFailure','CheckoutComplete','StandardInternational','2011-12-31 18:49:26',0,NULL,3,1,3,1,'RA184539259CN\r ',NULL),(22060,918885857015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','artlekoi','artlekoi@tiscali.co.uk','Derek Liddle','7 Ferry terrace','Pembrokedock','Pembrokeshire','UNITED KINGDOM','SA726TY','01646685804','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2011-12-31 19:06:44',0,NULL,3,1,11,1,'BJ01670167\r ',NULL),(22061,819669234002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','ecor3403','emeliacc@hotmail.com','Emelia Coral','94 Madison Street','Dover','NJ','UNITED STATES','07801','(973) 366-5469','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 19:43:18',0,NULL,3,1,1,1,'LK173577035CN\r ',NULL),(22062,819704159002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','oudicola2012','oudicola@gmail.com','Oudi Cola','3410 Galt Ocean Dr','Fort Lauderdale','FL','UNITED STATES','33308-7044','(954) 918-0402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2011-12-31 22:13:00',0,NULL,3,1,21,1,'RA184537575CN\r ',NULL),(22063,776115338001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','greybandit1','mitchclarke@bigpond.com','mitchell clarke','19 cowan pl','lloyd','New South Wales','AUSTRALIA','2650','0269315778','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(22064,8881325378981135,111,'2m 背景架+白',1,'AO0010',0,'photographyacc','kirra03','dkirra03@yahoo.com.au','Tanya Daley:/Compass Building Inspections','Unit 10 / 1015 Nudgee Road,','Banyo','Queensland','AUSTRALIA','4014','0412411210',NULL,NULL,NULL,'2012-01-01 00:49:41',0,NULL,3,1,4,1,'YW868052766CN\r ',NULL),(22065,919001419015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','dethklok_123','rygal@hotmail.co.uk','Ryan Galeozzi','3 Station Terrace<br>Station Road','Gilwern','Monmouthshire','UNITED KINGDOM','NP7 0HN','01873831979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 02:26:52',0,NULL,3,1,11,1,'\\ ',NULL),(22066,780760429018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','erik50000','erik.life@hotmail.com','erik homan','2/1273 the horsley drive','wetherill park','New South Wales','AUSTRALIA','2164','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-01 03:03:39',0,NULL,3,1,11,1,'BJ01670166\r ',NULL),(22067,780777311018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','waterwks','johelle1@bigpond.com','wayne lawson','110 Embreys Road','Tallegalla','Queensland','AUSTRALIA','4340','0754644900','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-01 05:07:00',0,NULL,8,1,17,0,NULL,NULL),(22068,780777159018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','waterwks','johelle1@bigpond.com','wayne lawson','110 Embreys Road','Tallegalla','Queensland','AUSTRALIA','4340','0754644900','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-01 05:07:00',0,NULL,3,1,3,1,'RA184548131CN\r ','3片装的滤镜袋     2\r6片装的滤镜袋      2  '),(22069,776179861001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',1,'AA3210',3.98,'hermeshine','dmitriyla','info@da-group.ru','Dmitriy Lagunov','Uinskaya 1b-26','Perm','Permski krai','RUSSIAN FEDERATION','614051','83422712669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 05:54:18',0,NULL,3,1,17,0,NULL,NULL),(22070,900127649016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','lenaki27','epgiane@yahoo.gr','Elena Papadopoulou','24, Erenes Street<br>2460 Pano Deftera','Nicosia','','CYPRUS','2460','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 08:37:54',0,NULL,3,1,24,1,NULL,NULL),(22071,780475651018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',2,'AKT014',78,'photographyacc','robbieinaus','robbiedrew2000@yahoo.com.au','robert drew','5 novar court','robina','Queensland','AUSTRALIA','4226','0404558231','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-01 11:32:22',0,NULL,3,1,4,1,'YW868052770CN\r ',NULL),(22072,780841210018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',87,'photographyacc','pachequinman','carol-cubas@hotmail.es','Lauren Pacheco Aguado','c/ Los madroños 43 2','Cubas de la sagra','Madrid','SPAIN','28978','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-01 12:28:23',0,NULL,3,1,4,1,'YW868052781CN\r ','■ '),(22073,776232273001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','zabousik','zabous@zabous.cz','Gabriela  Homolova','Rabstejnska 49','Plzen','Czech Republic','CZECH REPUBLIC','32300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 12:16:50',0,NULL,3,1,3,1,'RA184539174CN\r ',NULL),(22074,919116558015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','gdg-1984','gg-1984@hotmail.co.uk','Gareth Grindle','12 Welbeck Road','Wigan','Lancashire','UNITED KINGDOM','WN3 6RS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 12:52:13',0,NULL,3,1,11,1,NULL,NULL),(22075,780873745018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',4,'AD1169',25.6,'photographyacc','caius_doktus','kaywai@web.de','Kay Waidelich','Gutweinstraße 3','Regensburg','','GERMANY','93059','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-01 14:35:06',0,NULL,3,1,23,1,'BP04081201030005 ',NULL),(22076,819881904002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','theblackorchid','mavis.hooi@gmail.com','Mavis Hooi','Smedjegatan 5G','Linköping','','SWEDEN','58235','+460703702375','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 15:20:44',0,NULL,3,1,21,1,'RA184539072CN\r ',NULL),(22077,919194961015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','lambacka','riku.lambacka@gmail.com','Riku Lambacka','Tulipiipuntie 21','OULU','','FINLAND','90420','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 16:19:35',0,NULL,3,1,21,1,'RA184537584CN\r ',NULL),(22078,900269044016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','trundeli','trundeli@aol.com','Ian Trundell','25 Ringwood Crescent<br>Sothall','Sheffield','South Yorkshire','UNITED KINGDOM','s20 2dt','01142473761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-01 16:33:21',0,NULL,3,1,3,1,'RA184539188CN\r ',NULL),(22079,819913238002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tuningfreaky66','sutterboris@gmx.net','Sutter Boris','Otmarseggstr.6','Andwil','','SWITZERLAND','9204','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 16:51:06',0,NULL,3,1,22,1,NULL,NULL),(22080,776173977001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','kal-99','karl101@gmail.com','Karl Claude','43 Nilphas-Richer<br>Suite #4','Gatineau','QC','CANADA','J8T 2W6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 19:10:14',0,NULL,3,1,3,1,'RA184539165CN\r ',NULL),(22081,900364722016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','at_bedroom','info@samarasolives.gr','Triantafyllos Samaras','Anaxagora 25','Tavros','Athens','GREECE','17778',' 6973305186','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 19:21:28',0,NULL,3,1,22,1,NULL,NULL),(22082,819994582002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',29.98,'hermeshine','vera_73','joselitovera@yahoo.es','Jose Antonio  Vera Gonzalez','Avd Agustin Balsamo 3 Edf Torreuropa Portal A 3 C','Algeciras','Andalucía Ceuta y Melilla','SPAIN','11203','856 12 75 05','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-01 19:30:46',0,NULL,3,1,23,1,'BP04081201030004 ',NULL),(22083,776391632001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','fateful_83','miika.salmi@gmail.com','Miika Salmi','Ekmaninkatu 6 c 103','Turku','','FINLAND','20320','+358405097748','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 19:41:22',0,NULL,3,1,17,0,NULL,NULL),(22084,776391753001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',2,'AA3310',12,'hermeshine','fateful_83','miika.salmi@gmail.com','Miika Salmi','Ekmaninkatu 6 c 103','Turku','','FINLAND','20320','+358405097748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 19:42:34',0,NULL,3,1,17,0,NULL,NULL),(22085,776391674001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3303',7.1,'hermeshine','fateful_83','miika.salmi@gmail.com','Miika Salmi','Ekmaninkatu 6 c 103','Turku','','FINLAND','20320','+358405097748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 19:42:35',0,NULL,3,1,21,1,'RA184539038CN\r ','独脚架  伟峰 WT-1003     1 \r绿叶 CPL  58mm      2\r绿叶 UV  58mm        2'),(22086,919326095015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','bizamar','marcela.biznarova@yahoo.de','Branislav Polacek','Bystricka 22','Pezinok','','SLOVAK REPUBLIC','90201','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 20:08:28',0,NULL,3,1,5,1,'CP243056356CN\r ',NULL),(22087,919330324015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','blackermoon','blackermoon@gmail.com','Marco Solleveld','Blauwe reiger 3','Rozenburg','','NETHERLANDS','3181KA','0618049505','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-01 20:09:38',0,NULL,3,1,21,1,'RA184539157CN\r ',NULL),(22088,776422057001,110609166815,'New Camera shoulder bag D1 for Nikon D90 D3100 D5000',1,'AO0032',20.99,'hermeshine','fobwodat','wkbc62446@aol.com','Kevin B. Cronin','po box 388<br>15 lower broadford rd.','bellevue','ID','UNITED STATES','83313-0388','(208) 578-3547','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-01 20:50:06',0,NULL,3,1,3,1,'RA184539041CN\r ',NULL),(22089,776436289001,110790903696,'New Neoprene Soft Camera Cover Canon EOS 450D with kit lenses 18-55mm 50mm',1,'AD1213',7.99,'hermeshine','mel.walker230','melissa.walker@utoronto.ca','Melissa Walker','111 Elizabeth St<br>Suite 623B','Toronto','ON','CANADA','M5G 1P7','(416) 884-2597','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 21:23:43',0,NULL,3,1,11,1,NULL,NULL),(22090,781057671018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','just_jedi','osmondcourt@bigpond.com','Justin Deklerk','10 Osmond Crt','Pacific Pines','Queensland','AUSTRALIA','4211','0433796582','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-01-01 21:36:55',0,NULL,3,1,4,1,'YW868052792CN\r ',NULL),(22091,820056058002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','piotrpj','piotr.jaruga@gmail.com','Piotr Jaruga','Lędzian 100','Lublin','lubelskie','POLAND','20828','501 386497','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-01 21:54:08',0,NULL,3,1,23,1,'BP04081201030003 ',NULL),(22092,776454150001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','guela31','javimatoses@gmail.com','javier matoses perez','avda. del puerto 40-bajo -CATALANA OCCIDENTE-','valencia','Comunidad Valenciana','SPAIN','46023','963390201','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-01 22:14:01',0,NULL,3,1,4,1,'YW868052803CN\r ','▲ '),(22093,820067888002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','olibenny33','olibenny@hotmail.com','Olivier Beine','rue Soldat F. Charles 1','AUTRE-EGLISE','','BELGIUM','1367','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-01 22:25:56',0,NULL,3,1,24,1,NULL,NULL),(22094,820094988002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pamarbut','pamarbut@msn.com','Phillip Marbut','4130 Vincent Ave N','Minneapolis','MN','UNITED STATES','55412-1526','(612) 588-4481','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-01 23:55:04',0,NULL,3,1,21,1,'RA184537567CN\r ',NULL),(22095,776495697001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','yoda3108','kyskei@yahoo.com','roy kei','21323 Andalucia Ln','Huntington Beach','CA','UNITED STATES','92648-5745','(714) 960-3642','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-02 00:38:44',0,NULL,3,1,1,1,NULL,NULL),(22096,776508054001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','rockycat69travel','wendymichl@gmail.com','wendy michl','2149 Circlewood Dr','Melbourne','FL','UNITED STATES','32935-5540','(321) 960-2421','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-02 01:27:33',0,NULL,3,1,1,1,NULL,NULL),(22097,820142933002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','carmelocte','camaro350@ono.com','Carmelo Torro Enguix','Avenida Almansa, 29','Onteniente','Comunidad Valenciana','SPAIN','46870','962385334','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 02:51:44',0,NULL,3,1,4,1,'YW868052814CN\r ','2m 弹簧灯架     1\r2mx1.5m 背景板（黑，白）    1\r▲'),(22098,781155267018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',26.8,'photographyacc','dragonmaster51','rwillett29@hotmail.com','Robert Willett','5/10 Canton St<br>Canterbury','Sydney','New South Wales','AUSTRALIA','2193','61417402053','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-02 03:00:13',0,NULL,3,1,3,1,'RA184548145CN\r ',NULL),(22099,820120257002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','base.jump','para44@free.fr','Malinge','31 rue des chevaliers','Rezé','Pays de la Loire','FRANCE','44400','+33682142519','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 03:04:42',0,NULL,3,1,3,1,'RA184548074CN\r ',NULL),(22100,820158310002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','joaovictorinacio','joao.victor.inacio@gmail.com','Joao Pereira','31A Kaihuia Street, Northland','Wellington','','NEW ZEALAND','6012','+64 022 312 8774','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 03:50:55',0,NULL,3,1,2,1,NULL,NULL),(22101,820170628002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','rex1256','idav@adam.com.au','Ian Davis','Po Box 103','Uraidla','South Australia','AUSTRALIA','5142','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 04:49:31',0,NULL,3,1,11,1,NULL,NULL),(22102,820174605002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','coisaslegais','contato@mondocao.com','Paulo Verdu Junior','Rua Carlos da Silva, 29','São Bernardo do Campo','São Paulo','BRAZIL','09632-090','(551) 123-5659 ext.: 37','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 05:10:30',0,NULL,3,1,5,1,'CP243056360CN\r ','欧标 '),(22103,610901789004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',52,'hermeshine','rleslievideo','rleslievideo@yahoo.com','Rob Leslie','213 - 8738 French St','Vancouver','BC','CANADA','V6P 4W7','(604) 617-6051','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-02 05:40:44',0,NULL,3,1,3,1,'RA184548088CN\r ',NULL),(22104,776587543001,110414476355,'Remote Shutter Release for Canon Rebel XT XTi = RS-60E3',1,'AA3210',4.45,'hermeshine','crazyjoseph30','troyhayes03@yahoo.com','Troy Hayes','407 Amanda Ct','Whitehouse','TX','UNITED STATES','75791-3861','(903) 504-6625','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-02 08:24:17',0,NULL,3,1,1,1,NULL,NULL),(22105,776594709001,110790903696,'New Neoprene Soft Camera Cover Canon EOS 450D with kit lenses 18-55mm 50mm',1,'AD1213',7.99,'hermeshine','alykat_creative','alysonpearson500@hotmail.com','Alyson Pearson','117 Edgevale Road','Kew','Victoria','AUSTRALIA','3101','0416419956','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 09:09:13',0,NULL,3,1,11,1,NULL,NULL),(22106,840156011017,270758485093,'Photo Studio 85cm 33“ Reflective Black/Silver Umbrella',1,'AD1401',7.8,'photographyacc','zcbv','antonio335@hotmail.com','ANTONIO  RODRIGUEZ INFANTES','C/ LA FUENTE Nº 13','ALGAR','CADIZ','SPAIN','11639','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-02 10:51:00',0,NULL,3,1,2,1,NULL,NULL),(22107,776634491001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','antonio9666','antonio2freeski@yahoo.com','Antonio Le','3309 Claridge Ct','Silver Spring','MD','UNITED STATES','20902-2201','(202) 701-8994','NoPaymentFailure','CheckoutComplete','Other','2012-01-02 12:12:38',0,NULL,3,1,1,1,NULL,'M   '),(22108,820276895002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','cloister1965','riggg@tpg.com.au','Gianni Riggi','18/9 Anselm Street','Strathfield South','New South Wales','AUSTRALIA','2136','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 13:45:04',0,NULL,3,1,11,1,NULL,NULL),(22109,776663046001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','spartanof84','matthew_alderdice@yahoo.com.au','Matthew Alderdice','46 Middle St Kingsford','Sydney','New South Wales','AUSTRALIA','2032','0407627369','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 14:02:08',0,NULL,3,1,3,1,'RA184548091CN\r ',NULL),(22110,919667164015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','dougal1264','kaymcclelland@hotmail.com','Dougal McClelland','107 Laleham Road','Staines','Middlesex','UNITED KINGDOM','TW18 2EB','01784454432','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-02 14:16:40',0,NULL,3,1,12,1,' 2100834610','英标 \r实重4.3  泡重5.2'),(22111,900721828016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','dicouit','dicouit@ebuyclub.com','GOUYET ROBIN','23 CHEMIN DU MERAUD','STE BLANDINE','Rhône-Alpes','FRANCE','38110','0608160699','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 14:22:30',0,NULL,3,1,3,1,'RA184548065CN\r ',NULL),(22112,776521795001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','carmelocte','camaro350@ono.com','Carmelo Torro Enguix','Avenida Almansa, 29','Onteniente','Comunidad Valenciana','SPAIN','46870','962385334','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 14:59:00',0,NULL,3,1,17,0,NULL,NULL),(22113,840240542017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','bond007lesen','jarekb007@arcor.de','Jaroslaw Panasewicz','Moritz Str.3','Duisburg','','GERMANY','47053','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-02 15:26:50',0,NULL,3,1,21,1,'RA184539024CN\r ',NULL),(22114,919690421015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','pabl0o0o','pablo_mad_@hotmail.com','pablo quetglas escarate','c/islas cies 22','pozuelo de alarcon','Madrid','SPAIN','28223','656616882','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 15:14:29',0,NULL,3,1,23,1,'BP04081201030002 ',NULL),(22115,900766688016,260901272169,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',36,'hutongstore','quenoteam','secrealmachar@infonegocio.com','Javier Rupérez Bermejo','Calle Eugenia Ríos nº 2, bajo','Almáchar','Malaga','SPAIN','29718','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 16:08:54',0,NULL,3,1,23,1,'BP04081201030001 ',NULL),(22116,919707827015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','robbatesphotography5','robbatesphotography@gmail.com','robert bates','28 rectory road','upton upon severn','Worcestershire','UNITED KINGDOM','wr8 0lx','01684591341','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-02 15:52:55',0,NULL,3,1,4,1,'YW868052825CN\r ','英标 '),(22117,900778296016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',25.98,'hutongstore','leetech49','leetech49@yahoo.com','lee harris','47 springfield road<br>THORNTON HEATH','croydon','Surrey','UNITED KINGDOM','cr7 8dz','07930396698','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 16:32:57',0,NULL,3,1,3,1,'RA184525422CN\r ','货被退回来，发信问重发或退款 \r重新发一次'),(22118,919369433015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-02 17:01:50',0,NULL,3,1,17,0,NULL,''),(22119,900432311016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:01:51',0,NULL,3,1,17,0,NULL,NULL),(22120,900432310016,260894475632,'43\" Dual double layer reflective and translucent soft  umbrella 110cm',1,'AD1157',18,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:01:52',0,NULL,3,1,17,0,NULL,NULL),(22121,900432309016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-02 17:01:53',0,NULL,3,1,4,1,'YW868052836CN ','除了C里面的以外再发\r4灯头 灯头 孔      1    英标\r150-200cm 5in1 反光板    1\r反光板支架         1\r115w 5500k 灯泡  220v     4\r110cm 两用伞    1 \r灯架  2m                3\r800w红头灯         3\r800w  220v 灯泡   6\r红边套装包     1\r红头灯5m电源延长线     3\r实重24.9   泡重39.8\r燕文一票两件\r'),(22122,919369431015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:01:54',0,NULL,3,1,17,0,NULL,NULL),(22123,900432308016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:01:53',0,NULL,3,1,17,0,NULL,NULL),(22124,900793252016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','purple67-holly','tracey.maeer@btinternet.com','Tracey Maeer','Holly House<br>Chapel Street','Hillam, Leeds','North Yorkshire','UNITED KINGDOM','LS25 5HP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-02 17:03:18',0,NULL,3,1,11,1,NULL,NULL),(22125,900432312016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','leemiddleton','ebay@toppledgod.me.uk','Lee Middleton','10/1 Ferry Gait Crescent','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH4 4GR','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-02 17:01:50',0,NULL,3,1,17,0,NULL,NULL),(22126,776789800001,110718715286,'Soft Camera Bag Case Cover Canon EOS 5D ii + 24-105mm',1,'AD1214',12.99,'hermeshine','marisc2009','maris_c@inbox.lv','Maris Cirulis','Jaunlepiki','Launkalnes pag.','Smiltenes nov','LATVIA','LV4729','37129184900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 19:19:22',0,NULL,3,1,24,1,NULL,NULL),(22127,919861759015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','ersc1902','erling.schulz@gmail.com','Erling Schulz','Billundvej 24','Kolding','Jylland','DENMARK','6000','004520274277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 20:11:19',0,NULL,3,1,22,1,' ',NULL),(22128,776855099001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','linitalinis','ahhpei@hotmail.com','Lina Yu','4035 Eton Street','Burnaby','BC','CANADA','V5C 1J8','(604) 771-5462','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-02 21:35:04',0,NULL,3,1,11,1,NULL,NULL),(22129,781513730018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','theduk3nuk3m','thedukenukem@gmail.com','DIEGO GARIN MARTIN','C/ VALDES PUMARINO, 21 BAJO (ESTANCO)','CANDÁS','Asturias','SPAIN','33430','610741892','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-02 22:07:07',0,NULL,3,1,2,1,NULL,NULL),(22130,919935865015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','david.sant','david.sant@gmail.com','David Sant','36,<br>Dun Karm Psaila Str','Haz Zebbug','','MALTA','ZBG3525','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 22:20:43',0,NULL,3,1,5,1,'CP243056342CN\r ','英标 '),(22131,776882609001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','fgui7480','artgraph.fr@gmail.com','guilhem fouques','3 avenue Antoine Pinay<br>GOTO GAMES FRANCE','Hem','Nord-Pas-de-Calais','FRANCE','59510','0626957568','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-02 22:47:06',0,NULL,3,1,3,1,'RA184548012CN\r ',NULL),(22132,900989732016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','yushanyu','yushannet1@aol.com','Shan   Yu','45 Robinson St','Somerville','MA','UNITED STATES','02145-3610','(617) 629-0985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-02 23:04:59',0,NULL,3,1,1,1,'LK168408056CN\r ','XL  '),(22133,820543573002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','mthistlethwaite','thistles1@hotmail.com','michelle thistlethwaite','19 howarth st','wyong','New South Wales','AUSTRALIA','2259','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 00:33:03',0,NULL,3,1,11,1,NULL,NULL),(22134,776914038001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','graham.wigmore','graham.wigmore@flinders.edu.au','Graham Wigmore','School of Biological Sciences, Flinders University<br>GPO Box 2100','Adelaide','South Australia','AUSTRALIA','5001','0882012050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 00:33:27',0,NULL,3,1,11,1,'BJ01670124\r ',NULL),(22135,820545502002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pny_enterprises','pnyenterprises@gmail.com','Ronald Quinonez','40 Rosella Avenue','Werribee','Victoria','AUSTRALIA','3030','0430487103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 00:39:10',0,NULL,3,1,3,1,'RA184537641CN\r ',NULL),(22136,920000626015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','miky31694','mike31694@hotmail.com','Michael CRESSON','30 rue Antonin Bacou','Saint Alban','Midi-Pyrénées','FRANCE','31140','0619642070','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 00:59:51',0,NULL,3,1,4,1,'YW868052895CN\r ','+1.6*2.1  白色布 '),(22137,8881325553585331,111,'NIkon 的帽子',1,'AD1190',0,'photographyacc','vi**th','vino83th@gmail.com','Vinoth Jayaratnam','07 Linlee St','Girraween','New South Wales','AUSTRALIA','2145','61430439810',NULL,NULL,NULL,'2012-01-03 01:19:45',0,NULL,3,1,3,1,'RA184548159CN\r ',NULL),(22138,8881325553867131,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1006077586','helleboa@hotmail.com','Helle Andersen	','nagboelvej 38','lunderskov','lunderskov','DENMARK','6640 dk','+45 40536304',NULL,NULL,NULL,'2012-01-03 01:24:27',0,NULL,3,1,21,1,'RA184539055CN\r ',NULL),(22139,8881325554168913,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1006078871 ','hs-63@hotmail.com','henrik soerensen	','Byagervej 176 sttv','8330 Beder	','Denmark','DENMARK','dk-8330','+45 00 60115090',NULL,NULL,NULL,'2012-01-03 01:29:28',0,NULL,3,1,21,1,'RA184539086CN\r ',NULL),(22140,8881325554573833,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',25.99,'aliexpress','1006087705 ','uraganchik@gmail.com','Ivan Chistyakov	','ul. Litovskiy bulvar, d.13/12, kv.465','Moscow','Moscow','RUSSIAN FEDERATION	','117593','+7 903 7227854',NULL,NULL,NULL,'2012-01-03 01:36:13',0,NULL,3,1,3,1,'RA184548043CN\r ',NULL),(22141,8881325554820266,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1006096158 ','jungis38@gmail.com','Mats Jungmyren	','Krakrisvagen 5A 2tr','Motala	','Sweden	','SWEDEN	','59154','+0046 70 5158982',NULL,NULL,NULL,'2012-01-03 01:36:13',0,NULL,3,1,21,1,'RA184539015CN\r ',NULL),(22142,8881325555030417,111,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006096437','gozumercan@hotmail.com','Ceren SUMER	','Carsi Mahallesi Uzun Sokak Konak Pasaji No. 68 Sumer Spor','Trabzon','Trabzon','TURKEY','61040','+0090 538 6981248',NULL,NULL,NULL,'2012-01-03 01:43:50',0,NULL,3,1,3,1,'RA184548030CN\r ',NULL),(22143,8881325555068794,111,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006096456','gozumercan@hotmail.com','Ceren SUMER	','Carsi Mahallesi Uzun Sokak Konak Pasaji No. 68 Sumer Spor','Trabzon','Trabzon','TURKEY','61040','+0090 538 6981248',NULL,NULL,NULL,'2012-01-03 01:43:50',0,NULL,7,0,18,0,NULL,NULL),(22144,8881325555563777,111,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006096456','gozumercan@hotmail.com','alpaslan salgut	','kolejtepe mah.hosgor cad.derya apt.kat:2 no:3/7 sahinbey','Gaziantep','Gaziantep','TURKEY','27010','+0090 532 7449296',NULL,NULL,NULL,'2012-01-03 01:43:50',0,NULL,3,1,3,1,'RA184548026CN\r ',NULL),(22145,8881325555790801,111,'New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',25.99,'aliexpress','1006096563','gozumercan@hotmail.com','Kagan KESKIN	','Esentepe Mahallesi Adnan Menderes BulvariTurkuaz Sitesi A Blok Daire 30','Afyon','Afyon','TURKEY','03000','+0090 507 2246036',NULL,NULL,NULL,'2012-01-03 01:56:30',0,NULL,3,1,3,1,'RA184537377CN\r\r ',NULL),(22146,776959232001,110414476544,'Remote Cord Shutter Release for Canon 450D 500D 1000D',2,'AA3210',7.96,'hermeshine','junation89','junation@hotmail.com','Jun Cheng ng','12A, Jalan TK4/8D<br>Taman Kinrara Seksyen 4','Puchong','Selangor','MALAYSIA','47190','0123928719','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 03:33:53',0,NULL,3,1,2,1,NULL,NULL),(22147,820621046002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','fullmeat','ksuzuki@gmail.com','Ken Suzuki','3720 32nd Ave W','Seattle','WA','UNITED STATES','98199','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-03 05:39:14',0,NULL,3,1,1,1,'LK173976032CN\r ',NULL),(22148,820634456002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','morris-engraving','keith@morris-engraving.co.uk','keith morris','1 cross lane close<br>lakenheath','brandon','Suffolk','UNITED KINGDOM','IP279HZ','01842860736','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 07:06:26',0,NULL,3,1,11,1,NULL,NULL),(22149,8881325574469222,111,'1600W 套装',1,'',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-01-03 07:07:49',0,NULL,3,1,12,1,' 2100828704\r','灯架  2m   2 \r柔光箱 60-60cm  四灯头    2\r45w 5500k 灯泡 110v     11\r灯架包     3\r实重6.6  泡重10.4\r'),(22150,820636621002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',2.18,'hermeshine','bazoz','aus99a@yahoo.com.au','BILL FARMAKIDIS','2 LYMINGTON ST','BEXLEY','New South Wales','AUSTRALIA','2207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 07:23:29',0,NULL,3,1,11,1,NULL,' '),(22151,777003630001,110750769809,'New Strong Camera Case Shoulder Bag  for Nikon D700 D90  24-70mm  80-200mm ',1,'',45,'hermeshine','athlon89','athlon.89@mail.ru','Alexandr Detinkin','ul.Molodjozhnaja, d.4a, kv.31','g.Noginsk','Moskovskaja obl','RUSSIAN FEDERATION','142411','+79687498654','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 07:46:31',0,NULL,3,1,3,1,'RA184548114CN ','747g '),(22152,920117804015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','chippie12309','dazcofilms@yahoo.com','Darren O\'Brien','27 Eversley Place<br>Heaton','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE6 5AL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 08:38:56',0,NULL,3,1,3,1,'RA184537332CN\r ',NULL),(22153,901158145016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','citrusko','radoslav.brokes@gmail.com','Radoslav Brokes','Pod Hajom 1089/56','Dubnica nad Vahom','','SLOVAK REPUBLIC','01841','0907164334','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 09:34:07',0,NULL,3,1,24,1,'30110894166\r ',NULL),(22154,901174759016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.4,'hutongstore','dgaga64','k.gaga@gmx.net','Dragica Krekovic','Promenade 8','Davos Platz','','SWITZERLAND','7270','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 10:15:33',0,NULL,3,1,24,1,'30110903605\r ',NULL),(22155,920148448015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','tegi-begi','ktegez@gmail.com','Ferenc Koroknai-Tegez','Kálvin tér 8.','Budapest','','HUNGARY','1091','0036302479494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 10:44:20',0,NULL,3,1,24,1,'30110905731\r ',NULL),(22156,777035931001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','leofotografias','leo.fotografias@hotmail.com','Leonardo Pimentel Magalhães','Rua: Manoel Samora, nº 108<br>Bairro: Bromélias','Timóteo','Minas Gerais','BRAZIL','35180-510','(31) 8625-5202','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 10:48:36',0,NULL,3,1,25,1,'RT123702472HK\r ',NULL),(22157,920159749015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','mjd0070','mduerden@hotmail.com','michael Duerden','\'Coolgreany\'<br>Droum,','Leap, Nr Skibbereen','Co  Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 11:20:22',0,NULL,3,1,17,0,NULL,NULL),(22158,901192712016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','mjd0070','mduerden@hotmail.com','michael Duerden','\'Coolgreany\'<br>Droum,','Leap, Nr Skibbereen','Co  Cork','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 11:20:23',0,NULL,3,1,24,1,'30110902522\r ','圆形柔光棚 40cm  1 \rlenspen    1'),(22159,781710394018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'photographyacc','igun9435','ayamgoreng74@yahoo.com.au','Ika Gunawan Saputera','Unit 204/4 Broughton Road','Artarmon','New South Wales','AUSTRALIA','2064','0413298990','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-03 11:41:17',0,NULL,3,1,3,1,'RA184537346CN\r ',NULL),(22160,8881325591257478,111,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',0,'hermeshine','barneyhk','sbarnes@unlocking-outlook.com','Stephen Barnes','8 Camden WayMeadow Springs','Western Australia','','AUSTRALIA','','',NULL,NULL,NULL,'2012-01-03 11:47:37',0,NULL,3,1,4,1,'YW868052840CN ','除了C里面的以外再发\r灯架  2m   2\r双灯头    2\r反光伞   2    澳标\r灯架包    1\r3m *6m 黑色和白色布\r '),(22161,820688411002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lecturesean','sean.kenny@dkit.ie','Sean Kenny','25 Belfry Gardens,<br>St. Alphonsus Road','Dundalk','Louth','IRELAND','1','0879040733','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 11:48:09',0,NULL,3,0,21,1,'RA184537315CN\r ','2XL 已入库  '),(22162,920171305015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',24.2,'hutongstore','anastasiyadas','anastasiya_2284@mail.ru','Anastasiya Kuchina','Skobelevskaya street. 1-3-37','Moscow','','RUSSIAN FEDERATION','117624','+79264077087','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 11:58:06',0,NULL,3,1,3,1,'RA184537261CN\r ',NULL),(22163,920185375015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',22,'hutongstore','priyaneha','jasbir.priyavideos@btinternet.com','JASBIR SAHANSARA','9 DEVERILLS WAY','LANGLEY','Berkshire','UNITED KINGDOM','SL3 8WN','01753581454','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 12:51:05',0,NULL,3,1,3,1,'RA184537350CN\r ',NULL),(22164,820708445002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 13:08:14',0,NULL,3,1,25,1,'RT123705045HK\r ',NULL),(22165,820708652002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','mkropfbe','michael.kropfberger@gmail.com','Michael Kropfberger','Rauth 119','Keutschach','','AUSTRIA','9074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 13:08:34',0,NULL,3,1,24,1,'30110984750\r ',NULL),(22166,820712231002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','saratovfoto','titov_vit@mail.ru','Виталий Титов','2 Московский проезд, д.8, кв 32','Саратов','','RUSSIAN FEDERATION','410062','+79042406446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 13:21:16',0,NULL,3,1,17,0,NULL,NULL),(22167,901260529016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','johannesvanderlinden','f2halexandra1975@hetnet.nl','Joop van der Linden','Sint Jorisstrjitte 11','OOSTERBIERUM','','NETHERLANDS','8854AK','0518481927','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 14:45:19',0,NULL,3,0,21,1,' RA184537403CN\r','1.6*3  黑色 '),(22168,777096850001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','juanamary','juanamary@rgv.rr.com','Juana Cantu-Cabrera','1707 Sunrise Ln','Palmhurst','TX','UNITED STATES','78573-8370','(956) 867-2221','NoPaymentFailure','CheckoutComplete','Other','2012-01-03 14:48:54',0,NULL,3,0,1,1,'LK174161263CN\r ','2XL 已入库 '),(22169,920253151015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','colomsmissatgers','colomsmissatgers@hotmail.com','Alejandro Gimenez Liarte','C/ del puig dels tudons,5  talleres 8 nave 14 (MAM)','Barbera del Valles','Cataluña','SPAIN','08210','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-03 15:39:56',0,NULL,3,1,21,1,'RA184537624CN\r ',NULL),(22170,777112464001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',1,'AA2205',3.5,'hermeshine','airus9','joel.farias@telstra.com','joel Farias','71 New Street','Ringwood','Victoria','AUSTRALIA','3134','0398700163','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 15:40:44',0,NULL,3,1,11,1,NULL,NULL),(22171,773834739001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 16:28:09',0,NULL,8,1,17,0,NULL,''),(22172,919571973015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','orenspl56','orenspl@mail.ru','Ilya Zverev Sergeevich','pr.Gazovikov 24<br>KB 48','Orenburg','Orenburg Area','RUSSIAN FEDERATION','460051','89619439839','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-03 16:32:58',0,NULL,3,1,5,1,'CP211275559CN ','欧标 '),(22173,901332403016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','pzizzari','paride_zizzari@yahoo.fr','Paride Zizzari','ch des Grisons 6','Le Mont','','SWITZERLAND','1052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 17:25:27',0,NULL,3,1,17,0,NULL,NULL),(22174,901332406016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',19.98,'hutongstore','pzizzari','paride_zizzari@yahoo.fr','Paride Zizzari','ch des Grisons 6','Le Mont','','SWITZERLAND','1052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 17:25:28',0,NULL,3,1,17,0,NULL,NULL),(22175,901332408016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',2,'AE3103',15.8,'hutongstore','pzizzari','paride_zizzari@yahoo.fr','Paride Zizzari','ch des Grisons 6','Le Mont','','SWITZERLAND','1052','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-03 17:25:29',0,NULL,3,1,17,0,NULL,NULL),(22176,920305233015,250958162625,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',3,'AD1217',66,'hutongstore','pzizzari','paride_zizzari@yahoo.fr','Paride Zizzari','ch des Grisons 6','Le Mont','','SWITZERLAND','1052','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 17:25:29',0,NULL,3,1,17,0,NULL,NULL),(22177,901332411016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','pzizzari','paride_zizzari@yahoo.fr','Paride Zizzari','ch des Grisons 6','Le Mont','','SWITZERLAND','1052','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-03 17:25:30',0,NULL,3,1,5,1,'CP240090778CN','灯架包厚    1 \r铝合金灯座（N）    2\r大力夹云台   2\r2.5m高灯架   3\r新款大力夹（手柄）   1'),(22178,777163148001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','diapersandthings','nakialcook@gmail.com','Nakia L Cook','7 G Auburndale Court','Etobicoke','ON','CANADA','M9W 3T8','(416) 741-7391','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 17:55:59',0,NULL,3,0,11,1,NULL,'1.6*2.1  黑色 '),(22179,777166921001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',4,'AE3103',39.2,'hermeshine','saratovfoto','titov_vit@mail.ru','Виталий Титов','2 Московский проезд, д.8, кв 32','Саратов','','RUSSIAN FEDERATION','410062','+79042406446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 18:04:33',0,NULL,3,1,3,1,'RA184537275CN\r ','伞式柔光箱 60×90cm    2 \r大力夹云台    4'),(22180,901358695016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','regesplanes','reges@onvol.net','roderick agius','block 8 door a flat 3 triq il ballut san gwann','san gwann','san gwann','MALTA','sgn 003','21386139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 18:15:12',0,NULL,3,1,24,1,'30110901623\r ',NULL),(22181,777178283001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mikegerch','m-s-g@live.com','Michael Gerchikov','120 Shelborne ave<br>Apt# 1012','Toronto','ON','CANADA','M6B 2M7','(647) 346-1127','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 18:30:28',0,NULL,8,0,17,0,NULL,NULL),(22182,777176184001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','mikegerch','m-s-g@live.com','Michael Gerchikov','120 Shelborne ave<br>Apt# 1012','Toronto','ON','CANADA','M6B 2M7','(647) 346-1127','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 18:25:17',0,NULL,3,1,11,1,NULL,'麂皮    1\r1..6*2.1  黑色布 1'),(22183,820843060002,120538959115,'NEW Flash Diffuser for Canon 580EX II',5,'AB3332',13,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 19:06:12',0,NULL,3,1,17,0,NULL,NULL),(22184,777195197001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','goinha2011','goinhamuniz2011@hotmail.com','GLÓRIA MARIA MUNIZ DE LIMA','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','PARAÍBA','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 19:06:13',0,NULL,3,1,25,1,'RT123707418HK\r ','肥皂盒 柔光罩   580EX    5 \r肩架    1'),(22185,920369658015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','craft_lyrical','virajnperera@gmail.com','Viraj Perera','3 Charney Avenue<br>Abingdon','Oxford','Oxfordshire','UNITED KINGDOM','OX14 2NY','01235523758','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 19:17:39',0,NULL,3,1,3,1,'RA184537289CN\r ',NULL),(22186,820836874002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','klara.habartova','klara.h@hotmail.co.uk','Klara Habartova','44 Derby Grove','Nottingham','Nottinghamshire','UNITED KINGDOM','NG7 1PF','447780440116','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 19:28:53',0,NULL,8,1,17,0,NULL,NULL),(22187,820838021002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','klara.habartova','klara.h@hotmail.co.uk','Klara Habartova','44 Derby Grove','Nottingham','Nottinghamshire','UNITED KINGDOM','NG7 1PF','447780440116','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 19:28:53',0,NULL,3,1,11,1,NULL,'新款内胆包 M  Nikon     1 \r气吹 + 布+ lenspen   1'),(22188,820884804002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','snail-f108','jplvsmd@gmail.com','Jacobus van Straaten','P.O. Box 791','Fort McLeod','AB','CANADA','T0L 0Z0','(403) 553-4989','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 20:29:20',0,NULL,3,1,3,1,'RA184537329CN\r ',' '),(22189,777258975001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','william44290','william.rosenthal@yahoo.fr','William Rosenthal','9 rue henry fournis','Guémené penfao','Pays de la Loire','FRANCE','44290','0240792863','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 21:23:46',0,NULL,3,0,11,1,' ','1.6*2.1  黑色 '),(22190,820042763002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','soporno','johnnysoporno@yahoo.com','Johnny Epstein','77 Carlton St.<br>suite 901','Toronto','ON','CANADA','M5B2J7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 21:17:33',0,NULL,3,0,3,1,'RA184537301CN\r\r ','XL  2件 已入库'),(22191,820932739002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','lopos17','ricardo@serradolopo.com.br','Ricardo Rodrigues','Rua Tiradentes 296','Extrema','Minas Gerais','BRAZIL','37640 000',' 553534353357','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-03 22:19:22',0,NULL,3,0,25,1,'RT123702565HK\r ','L 已入库 \r称重量算一下\r644'),(22192,820938215002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','fredcot79','fred@fredericcote.ca','frederic cote','386 notre-dame','st-germain-de-grantham','QC','CANADA','j0c1k0','(819) 818-2683','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-03 22:26:56',0,NULL,3,1,11,1,NULL,NULL),(22193,781977242018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','birdh85','shinoda_princess@hotmail.com','holly bird','7 nottingham street','kapunda','South Australia','AUSTRALIA','5373','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-03 22:42:19',0,NULL,3,1,11,1,'BJ01670097\r ',NULL),(22194,920491173015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','gemgems2k1','andy.briddick@btinternet.com','Gemma Garth','9 The Archers Green','Scorton','North Yorkshire','UNITED KINGDOM','DL10 6DJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-03 22:46:43',0,NULL,3,1,3,1,'RA184537690CN\r ',NULL),(22195,820945483002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','mistmonk','mistmonk@gmail.com','James Kelly','4895 55th Ln SE<br>Apt K104','Lacey','WA','UNITED STATES','98503-5128','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-03 22:49:49',0,NULL,3,1,21,1,'RA184537292CN\r ',NULL),(22196,901520968016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','preis01','ptitareis@sapo.pt','Pedro Reis','Avenida 5º de Outubro,nº 70 - 2º Andar','Lisboa','','PORTUGAL','1069 - 192','937210473','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 23:05:26',0,NULL,3,1,23,1,'BP04081201040014 ',NULL),(22197,901526310016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','paidojoao','pai_do_joao@hotmail.com','Fernando Pereira','av. Beato Nuno 26E 1ºB','Fatima','Fatima','PORTUGAL','2495-401','00351917544003','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-03 23:25:07',0,NULL,3,1,23,1,'BP04081201040013 ',' '),(22198,901558395016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','eugeni3022','eugeni.montanuy@gmail.com','Eugeni Montanuy','c/ Jardi, 10-12 3º 1ª<br>Hospitalet Llobregat','Barcelona','Cataluña','SPAIN','08905','934489130','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-04 00:44:21',0,NULL,3,1,2,1,'30110898016\r ',NULL),(22199,821001122002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','dpn7','david.neves@pro.sccgov.org','david neves','4898 Manitoba Dr','San Jose','CA','UNITED STATES','95130-2225','(408) 316-3375','NoPaymentFailure','CheckoutComplete','Other','2012-01-04 01:42:05',0,NULL,8,0,17,0,NULL,NULL),(22200,821003731002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','dpn7','david.neves@pro.sccgov.org','david neves','4898 Manitoba Dr','San Jose','CA','UNITED STATES','95130-2225','(408) 316-3375','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 01:49:29',0,NULL,3,1,21,1,'RA184537363CN\r ','摄影背心 黑色厚 sony   XXL   2件\r镜头筒 小号，中号，\r大号，XL大号 各一个\r '),(22201,8881325644792062,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1006104116','mail2andrewa@gmail.com','Andre Antonov	','85/1 Moo2 Ao Nang Muang Krabi','Krabi','Krabi','THAILAND','81000','+66 89 5619050',NULL,NULL,NULL,'2012-01-04 02:39:52',0,NULL,3,1,3,1,'RA184537417CN\r ',NULL),(22202,8881325644939244,111,'58mm 58 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon',1,'AB1303',5.09,'aliexpress','1006063402','clovisoliveira@terra.com.br','Clovis Oliveira da Silva	','Rua dos Cantores, 265','Vargem Grande Paulista	','SP, Brazil	','BRAZIL','06730-000','+55 11 47023685',NULL,NULL,NULL,'2012-01-04 02:42:19',0,NULL,3,1,17,0,'RA184537607CN\r ',' '),(22203,8881325645005612,111,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006063706','clovisoliveira@terra.com.br','Clovis Oliveira da Silva	','Rua dos Cantores, 265','Vargem Grande Paulista	','SP, Brazil	','BRAZIL','06730-000','+55 11 47023685',NULL,NULL,NULL,'2012-01-04 02:42:19',0,NULL,3,1,3,1,'RA184537607CN\r ','橡胶遮光罩 58mm * 1 \rcanon 三角包  D3 * 1'),(22204,920611467015,250600488479,'New Hairlight  photostudio boom arm and Light stand ',1,'AKT030',32.8,'hutongstore','billywhizzy','jeremy.lanfranco@onvol.net','Jeremy Lanfranco','4 \"Harmony\",<br>Triq Dun Filippu Borg','Birkirkara','','MALTA','BKR 4707','+356 99496657','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 04:15:11',0,NULL,3,1,21,1,'RA184537385CN\r ',NULL),(22205,777394914001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','deewun','atruwcdx@yahoo.com','David Roberts','3760<br>1574 Gulf Road','Point Roberts','WA','UNITED STATES','98281','(360) 945-0740','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-04 05:04:52',0,NULL,3,1,1,1,'LK172246672CN\r ',NULL),(22206,777406887001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','unparadized','larvoire@gmail.com','Jesse Baldwin','Krizkovskeho 1292/13','Prague 3','Praha','CZECH REPUBLIC','130 00','00420731554293','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 06:20:18',0,NULL,3,1,3,1,'RA184537394CN\r ',NULL),(22207,920644892015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','firesphere_83','misak_keshishian@yahoo.com','Misak Keshishian','P.O. BOX 40252','Larnaca','Larnaca','CYPRUS','6302','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 06:42:03',0,NULL,3,1,8,1,'CP244547918CN ','+1.6*2.1  白色布 '),(22208,8881325660350414,111,'反光板 100*150 40*60 5合1',1,'AC3201',0,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Doutor Catrambi, 219<br>Alto da Boa Vista','Rio De Janeiro','Rio de Janeiro','BRAZIL','20531005','5521-3576-0483',NULL,NULL,NULL,'2012-01-04 06:59:10',0,NULL,3,1,25,1,'RT123708435HK\r ',' 申报低值'),(22209,777421906001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','jansant','ebay@jansant.com','wayne jansson','29 wilby rd','lake rowan','Victoria','AUSTRALIA','3727','0400809163','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(22210,777426144001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','valcovalexandru','catalinbogdan.valcov@bcr.ro','bogdan valcov','444 Mihai Bravu, bl. V10, sc. 2, ap. 58<br>sector 3','Bucharest','Bucharest','ROMANIA','030332','0723603946','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 08:27:07',0,NULL,5,0,18,0,NULL,'称一下重量 '),(22211,782131837018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','bishopperth','judgejules04@gmail.com','Julien Lesperance','u49 / 96 Guildford Road<br>Mount Lawley','Perth','Western Australia','AUSTRALIA','6050','0424519344','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-04 09:02:27',0,NULL,3,1,11,1,'BJ01670061\r ',NULL),(22212,782143413018,280695078742,'Aluminium Lightweight 71\" Camera Monopod with 3way head',1,'AE1603',32,'photographyacc','borrimorri','tom.morrison.general@gmail.com','Thomas Morrison','6 June Street','Morwell','Victoria','AUSTRALIA','3840','0458554340','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-04 09:54:34',0,NULL,3,1,3,1,'RA184537540CN\r ',NULL),(22213,821111682002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','nau53','nau@nau.net','Anton Bashurov','Nurmakova 30, kv36','Almaty','kz','KAZAKHSTAN','05000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 10:21:19',0,NULL,3,1,3,1,'RA184537505CN\r ',''),(22214,782170688018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','tcl11','tlandells@hotmail.com','Tess Landells','1/5 Tobias Avenue','Glen Waverley','Victoria','AUSTRALIA','3150','0385552049','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-01-04 11:47:36',0,NULL,3,1,4,1,'YW867739520CN ',NULL),(22215,611576315004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','koobrk','koobrk@gmail.com','Jose Antonio Maté Méndez','Av. Virgen de Montserrat<br>nº 108 4º 3ª','El Prat de Llobregat','Barcelona','SPAIN','08820','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 11:54:12',0,NULL,3,1,2,1,'30111124116\r ',NULL),(22216,821137646002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','powerpack85','bodes85@gmail.com','Bodie Hanrahan','49a Emu Road','Glenbrook','New South Wales','AUSTRALIA','2773','0409221234','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 12:10:59',0,NULL,3,1,11,1,'BJ01670057\r ',NULL),(22217,821138940002,120596229915,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',75,'hermeshine','tautvydas2','tautvydas.banelis@gmail.com','Tautvydas Banelis','Lvovo 11-26','Vilnius','','LITHUANIA','09313','+37066066077','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 12:15:33',0,NULL,3,1,5,1,'CP211275576CN ','欧标 '),(22218,901747367016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','rastitapt','e.ventura@simarsul.pt','Eduardo Ventura','Av. Luisa Todi nº300 - 3º','Setúbal','','PORTUGAL','2900-452','+351 96 6652383','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 12:26:01',0,NULL,3,1,24,1,'30111121154\r ',NULL),(22219,820895495002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','canon600','closet@eircom.net','William Hough','Kilready','Castlmahon','Limerick','IRELAND','','6972933','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 13:08:09',0,NULL,3,1,24,1,'30111122300\r ',NULL),(22220,920758428015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','gradwar','glenvideodagbok@hotmail.com','Gustav Aldin','Liljegatan 4D','Uppsala','Uppland','SWEDEN','75324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 13:46:44',0,NULL,3,1,21,1,'RA184537482CN\r ',NULL),(22221,777513384001,110544743896,'115w x 1 Daylight bulb for Photography 5500K Light Bulb',1,'AE3601',18,'hermeshine','goranavalon','g.ugresic@gmail.com','Goran Ugresic','Borislava Stankovica 5','Gradiska','RS','BOSNIA AND HERZEGOVINA','78400','+387 65 569 189','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 14:33:18',0,NULL,3,1,24,1,'30111124352\r ','350g\r香港小包平邮 29.4'),(22222,782229814018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','lightbox_d','denise.ng.pl@gmail.com','Denise Ng','19, Albert Rd','Hallam','Victoria','AUSTRALIA','3803','0401808417','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-01-04 15:07:50',0,NULL,3,1,4,1,'YW867739531CN ',NULL),(22223,777531713001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','muzdotnet','urbanlicious@gmail.com','María  Catalá García','Av/ Costablanca, bungalow 36<br>Urb. mediterrany park. Arenales del Sol.','Elche (Alicante)','Comunidad Valenciana','SPAIN','03195','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 15:32:41',0,NULL,3,1,21,1,'RA184537479CN\r ','称一下重量 '),(22224,777537793001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','victor-eastbay','victor.eastbay@yahoo.com','PETRESCU VICTOR','OF BUC 3 post restant, sector 2','BUCURESTI','ROMANIA','ROMANIA','021881','0726713192','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 15:49:27',0,NULL,3,1,5,1,'CP211275580CN ',NULL),(22225,920815570015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jakub4478','jaroslav_g@mail.ru','jakub ratajczak','59 vicarage road','tottenham','London','UNITED KINGDOM','N17 0BB','07848809763','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-04 16:00:53',0,NULL,3,1,11,1,'BJ01670065\r ',NULL),(22226,821224920002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 16:41:41',0,NULL,3,1,25,1,'RT123734285HK\r ',''),(22227,900891972016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',14.58,'hutongstore','andrepferreira','andrepintoferreira@gmail.com','Andre Ferreira','Rua 19 nº1434 1ºEsq','Espinho','','PORTUGAL','4500-251','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 16:51:48',0,NULL,3,1,24,1,'30111114143\r ','新式内胆包小号  1 \r反光板  80cm 5合1   1'),(22228,821251160002,120539340436,'New 77mm ring adapter replacement for cokin P series',2,'AA2214',4.36,'hermeshine','whitefunk94','simon.baker@internode.on.net','Simon Baker','69/33 Edmund Rice Dr<br>Summerfields','Southport','Queensland','AUSTRALIA','4215','0755972017','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 17:42:55',0,NULL,3,1,11,1,'BJ01670062\r ',NULL),(22229,901880143016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','marcowacco','marcowacco@wacco.it','Falegnameria Baccega Ornella Wacco','Via Caltana 90','Campodarsego','PD','ITALY','35011','3493708345','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-04 18:17:25',0,NULL,3,1,12,1,'2100844126\r ','欧标 '),(22230,777647096001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','broomer23','pbesemer@gmail.com','Peter Besemer','Jan van Gpyenstraat 51','Papendrecht','','NETHERLANDS','3351 JM','078-6152570','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 20:00:44',0,NULL,3,0,21,1,'RA184537553CN\r ','3XL  已入库 \r称一下重量 465g'),(22231,777652745001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','bilou38','ranka00@free.fr','GOUY-PAILLER Aline','Les ramées','MONTAUD','isère','FRANCE','38210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 20:11:36',0,NULL,3,1,17,0,'RA184537536CN\r ',NULL),(22232,821324104002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','bilou38','ranka00@free.fr','GOUY-PAILLER Aline','Les ramées','MONTAUD','isère','FRANCE','38210','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 20:11:37',0,NULL,3,1,3,1,'RA184537536CN\r ','小号灰卡   1 \r115w 5500k 灯泡  220v   2'),(22233,821355637002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','mspelten','info@actiefotografie.nl','Marco Spelten','Pronkmos 2','HOUTEN','','NETHERLANDS','3994LP','(087)8736301','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 21:15:34',0,NULL,3,0,21,1,'RA184537465CN\r ','L 已入库 '),(22234,777715456001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','spguevara','spguevara@hotmail.com','Umar Corion','68 Corporate Drive<br>Unit 929','Scarborough','ON','CANADA','M1H3H3','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-04 22:35:24',0,NULL,3,1,3,1,'RA184537522CN\r ',NULL),(22235,777721175001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','marrikixox','marriki.schlifer@gmail.com','Marriki Schlifer','Apt 2 - 328 Fourth Street','New Westminster','BC','CANADA','V3L 2T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-04 22:51:26',0,NULL,3,1,3,1,'RA184537519CN\r ','110v\r '),(22236,921072527015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','jmcgreno2011','jmcgreno@portugalmail.pt','José Manuel Gonçalves','R. da Vinha nº 279<br>Lemenhe','Famalicao','Nine','PORTUGAL','4775-423','351 919253845','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-04 23:47:28',0,NULL,3,1,23,1,'BP04081201050002 ',NULL),(22237,821425517002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','derek198610','derekdawn@cogeco.ca','Derek Hillier','270 Beach BLVD','Hamilton','ON','CANADA','L8H6W1','(905) 549-1771','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 00:23:57',0,NULL,3,1,3,1,'RA184537655CN\r ',NULL),(22238,921098116015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','machos84','batistota@abv.bg','mariyan marinov','easter bankton - 105','LIVINGSTON','West Lothian','UNITED KINGDOM','eh549bg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-05 00:58:07',0,NULL,3,1,24,1,'30111119673\r ',NULL),(22239,782484860018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','supersisko99','drtrentrowe@bigpond.com','Trent Rowe','11 Denham Street','Stanthorpe','Queensland','AUSTRALIA','4380','0400300824','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-05 01:06:30',0,NULL,3,1,11,1,'BJ01670060\r ',NULL),(22240,821441614002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','tbrafa','fotografia26@yahoo.com.br','Ademir Francelino Alves','Rua:Serra das Araras Nº365','Londrina','Paraná','BRAZIL','86065-130','(043)3328-8669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 01:14:56',0,NULL,3,1,25,1,'RT123730487HK\r ',NULL),(22241,921106451015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','bigt7m','orlandofotografo@hotmail.com','ORLANDO RUIVO','zona industrial Castelo Branco apartado 1068','CASTELO BRANCO','CASTELO BRANCO','PORTUGAL','6000','351-966632987','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-05 01:22:28',0,NULL,3,1,4,1,'YW868052851CN ',NULL),(22242,8881325726615478,111,'52mm 52 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon',1,'AB1301',4.99,'aliexpress','1006133183','demidov.kgmk@gmail.com','Kirill Demidov	','Gvardeyskij 26a-86','Nikel','Murmanskaya','RUSSIAN FEDERATION	','184421','79600269881',NULL,NULL,NULL,'2012-01-05 01:23:35',0,NULL,3,1,3,1,'RA184537496CN\r ',NULL),(22243,921109341015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',65,'hutongstore','grahamfaulkner1','elise.faulkner495@gmail.com','Graham Faulkner','26 Northgate','Hornsea','East Riding of Yorkshire','UNITED KINGDOM','HU18 1ES','01964532245','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-05 01:29:41',0,NULL,3,1,4,1,'YW867739542CN ','英标 '),(22244,777797491001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','heinerseiner','e.buechner@gmx.de','Erhard Büchner','Mühlenstr. 53 B','Pinneberg','','GERMANY','25421','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 03:18:04',0,NULL,3,0,2,1,'30111117735\r ',NULL),(22245,782536590018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','m-johnston-2008','martin.tyrrell2000@gmail.com','martin tyrrell','7 barritt street','elizabeth downs','South Australia','AUSTRALIA','5113','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-05 04:15:36',0,NULL,3,0,24,1,'30111174516\r ','白色 '),(22246,777812579001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','kelfk','satisfier@gmail.com','Kelvin Ko','47 Wicker Drive','Richmond Hill','ON','CANADA','L4E 4T5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 04:18:19',0,NULL,3,1,3,1,'RA184537995CN\r ',NULL),(22247,777828843001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','vitinbartender','shadowheart@bartending.com','Victor Lopez-Cruz','Lomas de Carolina F-25 Cerro Penuelas','Carolina','PR','UNITED STATES','00987','(787) 396-2090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 05:44:54',0,NULL,3,1,21,1,'RA184537598CN\r ',NULL),(22248,840239968017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.8,'photographyacc','bond007lesen','jarekb007@arcor.de','Jaroslaw Panasewicz','Moritz Str.3','Duisburg','','GERMANY','47053','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-05 05:50:54',0,NULL,3,1,21,1,'RA184537709CN\r ',NULL),(22249,8881325746882469,111,'两件背心样品',1,'',0,'hermeshine','Altug Senel','asenel@ford.com.tr ','Altug Senel','Ford Otomotiv San. A.S,Finance Dept.<br>Izmit-Golcuk Yolu 14. km. Ihsaniye','Golcuk','Kocaeli','TURKEY','41670','',NULL,NULL,NULL,'2012-01-05 07:01:22',0,NULL,3,0,25,1,'RT123732125HK\r ','申报gift\r'),(22250,8881325754394069,111,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm - Wholesale/ Retail ',1,'AC3303',10.49,'aliexpress','1006135225','shevonalli@hotmail.com','naroce vignarajah	','17 hyacinth crecent','scarborough	','Ontario','CANADA','m1x1w6','+1 647 998-4399',NULL,NULL,NULL,'2012-01-05 09:06:34',0,NULL,3,1,3,1,'RA184528004CN\r ',NULL),(22251,782591728018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','princess-sezza87','princess-sezza@hotmail.com','Sarah Anne Woodhouse','unit 1703 22/34 Glenside Drive ROBINA','Gold Coast','Queensland','AUSTRALIA','4226','0755757280','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-05 09:19:19',0,NULL,3,0,24,1,'30111318845\r ','粉色 '),(22252,821561984002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1202',8,'hermeshine','andersonpavosqui','pavosqui@hotmail.com','Anderson Pavosqui','Rua Manoel Jacinto, 667<br>Apto 41 Bloco 09','São Paulo','São Paulo','BRAZIL','05624-001','(11) 3749-2219','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 10:25:53',0,NULL,3,1,24,1,'30111310950\r ',NULL),(22253,902260012016,260894475136,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',19.99,'hutongstore','mjresende2011','mresende@ist.utl.pt','MJose Resende','Av. das Descobertas, nº3','OEIRAS','OEIRAS','PORTUGAL','2780-053',' 351218477165','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 10:55:58',0,NULL,3,1,23,1,'BP04081201060007 ',NULL),(22254,902267441016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','asprass','snoopy@gbg.bg','Asen Stoev','Grad Sofia , Jk.Ovcha Kupel 1 ,bl. 513 , vh.V , ap.39','Sofia','','BULGARIA','1632','+359883331501','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-05 11:19:45',0,NULL,3,1,5,1,'CP211275562CN ','欧标 '),(22255,8881325762638174,111,'New Neoprene Camera Cover Case for Canon Nikon (L) ',1,'AC1302',7.69,'aliexpress','1006138397 ','trition@mail.ru','Vladislav Milovanov	','Shelkovkoe shosse 18-1-91','Moscow','Moscow','RUSSIAN FEDERATION	','105122','89163879633',NULL,NULL,NULL,'2012-01-05 11:23:58',0,NULL,3,1,3,1,'RA184527817CN ',NULL),(22256,821575719002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',2,'AE2102',50,'hermeshine','zz2648','gar.ber@sfr.fr','bernard garcia','3 chemin de l alambic','mezieres en gatinais','Centre','FRANCE','45270','02.38.95.68.15','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-05 11:24:57',0,NULL,3,1,3,1,'RA184527919CN\r ',NULL),(22257,821589089002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','sury10jaf','jjramesh@hotmail.com','Jay Jeyaratnam','11,DE CASTELLA DRIVE','BLACKTOWN','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 12:17:36',0,NULL,3,1,17,0,NULL,NULL),(22258,821591452002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',2.18,'hermeshine','sury10jaf','jjramesh@hotmail.com','Jay Jeyaratnam','11,DE CASTELLA DRIVE','BLACKTOWN','New South Wales','AUSTRALIA','2148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 12:25:54',0,NULL,3,1,24,1,'30111300704\r ','方形滤镜接口环 67mm   1 \r方形滤镜接口环 58mm     1'),(22259,821595547002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 12:44:28',0,NULL,3,1,25,1,'RT124142465HK ',NULL),(22260,921305501015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','smarfik89','a-silk@mail.ru','Artem Silkin','Esenina d.42 kv.43','Nizhnii Novgorod','','RUSSIAN FEDERATION','603070','+7 904 04 98 626','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 13:14:57',0,NULL,3,1,3,1,'RA184527922CN\r ','称一下重量 \r350'),(22261,821618110002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','omegus222','goken222@aol.com','Donovan Nelson','605 Kosciuszko St','Brooklyn','NY','UNITED STATES','11221-3059','(718) 764-7074','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-05 13:57:02',0,NULL,3,1,21,1,'RA184527879CN\r ',NULL),(22262,902339077016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','petcor','peter@ctmsunrise.nl','Peter Cornelissen','Kelvinstraat 36','WIJCHEN','','NETHERLANDS','6601HE','0246451316','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-05 14:47:14',0,NULL,3,1,4,1,'YW867739472CN ','欧标 '),(22263,8881325776257142,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft',2,'AO0005',33.98,'aliexpress','1006139892','alexradlip@gmail.com','Alexander Radishevskiy	','Nedelina st. 49-149','Lipetsk','Lipetskaya obl.	','RUSSIAN FEDERATION	','398059','+7 903 8659227',NULL,NULL,NULL,'2012-01-05 15:10:57',0,NULL,3,1,3,1,'RA184527936CN\r ','1.6X3.0m 背景布 * 2 （黑+白）'),(22264,921388921015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','p.i.k','paulow80@gmail.com','Pawel Wozniak','707 Glashaus Apartments<br>Belgard Square, Tallaght','Dublin','24','IRELAND','24','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 16:32:56',0,NULL,8,1,17,0,NULL,NULL),(22265,902384655016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','p.i.k','paulow80@gmail.com','Pawel Wozniak','707 Glashaus Apartments<br>Belgard Square, Tallaght','Dublin','24','IRELAND','24','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 16:32:57',0,NULL,3,1,4,1,'YW867738875CN ','除了C以外再发\r伞式柔光箱 60×90cm   1\r英标 \r实重  7.9    泡重11.4'),(22266,821687114002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','ihavenostrils','iluvcarpets90@yahoo.com','Danny Kirk','4635 Tilton St','Philadelphia','PA','UNITED STATES','19137','(215) 384-6525','NoPaymentFailure','CheckoutComplete','Other','2012-01-05 17:09:08',0,NULL,3,1,21,1,'RA184527882CN\r ','美标 '),(22267,778000374001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','turk1354','tasso_food@yahoo.com','robert niehus','1371 Jordan Ave','Dayton','OH','UNITED STATES','45410','','NoPaymentFailure','CheckoutComplete','Other','2012-01-05 17:11:26',0,NULL,3,1,1,1,'LK175324997CN ',NULL),(22268,902414527016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','sir.ar','sir.ar@hotmail.com','Asim Rashid','2 Ellesmere Road South, Chorlton','Manchester','Lancashire','UNITED KINGDOM','M21 0TE','07815922551','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-05 17:32:10',0,NULL,3,1,4,1,'YW867739483CN ','英标 '),(22269,821752050002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','julian2905','julian@julianralser.com','Julian Ralser','Nußbaumerstr. 49','Köln','','GERMANY','50825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 19:31:03',0,NULL,3,1,17,0,NULL,NULL),(22270,778063115001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','julian2905','julian@julianralser.com','Julian Ralser','Nußbaumerstr. 49','Köln','','GERMANY','50825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 19:32:18',0,NULL,3,1,17,0,NULL,NULL),(22271,778062998001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','julian2905','julian@julianralser.com','Julian Ralser','Nußbaumerstr. 49','Köln','','GERMANY','50825','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 19:32:59',0,NULL,3,1,23,1,'BP04081201060006 ','白反光伞110cm    1 \r反光伞    1\r小号灰卡   1\r称一下重量\r706'),(22272,612022894004,140666126913,'New Black Camera Case Shoulder Bag PU Leather for Canon 5D ii 7D 60D 40D Strong',1,'AD1216',55,'hermeshine','knyazyan','hkn_us@yahoo.com','Hrachya Knyazyan','3729 Inglewood Ave','Windsor','ON','CANADA','N9E4P4','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 20:02:49',0,NULL,3,1,3,1,'RA184527905CN\r ',NULL),(22273,921525704015,250666866568,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49,'hutongstore','laelia_milleri','electrina@gmail.com','Patrycja Wawrzynkiewicz','1 The Covert, Woodfarmacres<br>Palmerstown','Dublin','Dublin','IRELAND','D20','0862218750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 20:31:24',0,NULL,3,1,4,1,'YW867738886CN ','英标 \r实重 3.26  泡重4.98'),(22274,778094295001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','mr.nice0036','mr.nice@freemail.hu','Mate Balazs','Pipacs u 2 1/9','Herend','','HUNGARY','8440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 20:31:55',0,NULL,3,1,24,1,'30111305674\r ',NULL),(22275,821794936002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','dudewheresmytutu','aeb7311@gmail.com','Amy Lanchester','36 Maple Street','Kingston','Queensland','AUSTRALIA','4114','0404041043','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 20:56:02',0,NULL,3,1,3,1,'RA184527940CN\r ',NULL),(22276,921561113015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:18',0,NULL,3,1,17,0,NULL,NULL),(22277,921561115015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',1.6,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:19',0,NULL,3,1,17,0,NULL,NULL),(22278,902554382016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',1.6,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:19',0,NULL,3,1,17,0,NULL,NULL),(22279,902554383016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.12,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:20',0,NULL,3,1,17,0,NULL,NULL),(22280,902554385016,260660054522,'TianYa NEUTRAL DENSITY ND4 Filter replaces for Cokin P',1,'AA2324',4.65,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:21',0,NULL,3,1,17,0,NULL,' '),(22281,921561117015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','dimitrispapagianakis','dpapagianakis@hotmail.gr','Dimitris Papagiannakis','Grammou 25','Athens','Attiki','GREECE','14564','0302106205747','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:30:21',0,NULL,3,1,21,1,'RA184527896CN\r ','58-58mm 双阳环   1 \r方形滤镜接口环 72mm   1\r方形滤镜接口环 58mm    1\r方形滤镜接口环 67mm   1\r方镜普通托架（三槽）    1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  ND8     1'),(22282,921556839015,250855206578,'New 2500w Photo Complete kit 3m backdrop support system with continue lighting ',1,'AD1148',265,'hutongstore','enzstraaf65','enzstraaf@gmail.com','vincenzo neri','piazzetta g.romano 9','telese terme','BN','ITALY','82037','3473419844','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-05 21:32:46',0,NULL,3,0,4,1,'YW867739494CN ','灯架  2m   7\r3m横杆（4节通用）   1\r背景布 3x6 绿色   1\r5灯头+60-90棚   2\r斜臂     1\r柔光箱 50-70cm 单灯头  3\r45w 5500k 灯泡  220v  10\r115w 5500k 灯泡  220v  3\r牛津布大包   1\r灯架包  1\r欧标    已入库\r'),(22283,821823179002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','shammoo','shemaz@yahoo.com','Ahsan Syed','12300 Brook Forest Cir','Pickerington','OH','UNITED STATES','43147-7993','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-05 21:58:56',0,NULL,3,1,1,1,'LK170112810CN ',NULL),(22284,902577096016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','serocco.by','serocco@gmail.com','Kharanenka Aleh','Golubeva st. 13-301','Minsk','BY','BELARUS','220116','+375(29)7640376','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-05 22:19:22',0,NULL,3,1,5,1,'CP244548555CN\r ','欧标 \rc以外再加45w 220v 灯泡两个 \r申报gift $99 \r可能还有其他东西\r\r'),(22285,778141656001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','halluke','halchico@gmail.com','Häli Joonas','Puru tee 18B-37','Jõhvi','Ida-Virumaa','ESTONIA','41534','(+372) 53439750','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 22:21:33',0,NULL,3,1,24,1,'30111296994\r ',NULL),(22286,782905646018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',66.5,'photographyacc','maksim_95','maksim_01@yahoo.fr','Maxime CALDERARO','12 mail des houssieres','chatenay malabry','Ile-de-France','FRANCE','92290','06.22.30.32.73','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-05 23:08:21',0,NULL,3,1,3,1,'RA184527865CN\r ',NULL),(22287,821865292002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','rrroonn','rwbareis@gmail.com','ron bareis','20 Glencross St','Canberra','Australian Capital Territory','AUSTRALIA','2905','0262918678','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-05 23:48:42',0,NULL,3,1,24,1,'30111303294\r ',NULL),(22288,921631076015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-06 00:02:29',0,NULL,3,1,5,1,'CP244547921CN ','欧标\r申报£20 '),(22289,921634457015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.4,'hutongstore','nikkinoonoo82','nikki_wade82@hotmail.co.uk','nikki wade','22 Park Cliff Road<br>Ingress Park','Greenhithe','Kent','UNITED KINGDOM','DA9 9FX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 00:07:56',0,NULL,3,1,11,1,'BJ01670042\r ',NULL),(22290,782926679018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','nikkinoonoo82','nikki_wade82@hotmail.co.uk','nikki wade','22 Park Cliff Road<br>Ingress Park','Greenhithe','Kent','UNITED KINGDOM','DA9 9FX','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 00:12:24',0,NULL,3,0,11,1,'BJ01670045\r ','1.6*2.1  白色 '),(22291,921635343015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT017',74,'hutongstore','enzstraaf65','enzstraaf@gmail.com','vincenzo neri','piazzetta g.romano 9','telese terme','BN','ITALY','82037','3473419844','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-06 00:12:50',0,NULL,3,0,17,0,NULL,NULL),(22292,821876502002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 00:30:07',0,NULL,3,1,25,1,'RT124152839HK ','申报低值  '),(22293,918495540015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','conrad2*2007','kawuki@hotmail.co.uk','JOHN.TAMALE','192 scotland green north road<br>ponders end','enfield/london','Middlesex','UNITED KINGDOM','en3 7at','02083510895','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-06 00:33:13',0,NULL,3,1,4,1,'YW867738890CN\r ','英标 \r黑色布 1.6x2.1\r\r'),(22294,782936374018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','paulz3938','paulzapa7@optusnet.com.au','Paul  Zapantis','15  Northcote Street, Northcote','Melbourne','Victoria','AUSTRALIA','3070','0394812230','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 00:38:50',0,NULL,3,1,24,1,'30111305840\r ',NULL),(22295,776115338001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','greybandit1','mitchclarke@bigpond.com','mitchell clarke','19 cowan pl','lloyd','New South Wales','AUSTRALIA','2650','0269315778','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 00:42:32',0,NULL,3,1,4,1,'YW867739505CN ',NULL),(22296,902669814016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','nmcabecadas','nmcabecadas@gmail.com','Nuno Cabecadas','R. Desiderio Beca<br>nº5 C/V Esq','Lisboa','Lisboa','PORTUGAL','1000-122','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 02:08:58',0,NULL,3,1,24,1,'30111303482\r ',NULL),(22297,782978959018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',2,'AB3329',93.08,'photographyacc','marchel765','mahoed@live.nl','Marchel Hoedeman','Langerakbaan 479','Utrecht','','NETHERLANDS','3544SR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 03:02:34',0,NULL,3,1,17,0,NULL,NULL),(22298,782978625018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',31.34,'photographyacc','marchel765','mahoed@live.nl','Marchel Hoedeman','Langerakbaan 479','Utrecht','','NETHERLANDS','3544SR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 03:02:34',0,NULL,3,1,4,1,'YW867739461CN ','闪光的柔光箱   60cm   2 \r伞式柔光箱 80cm 8角    1'),(22299,778231443001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','dspon','daniel@versa.net.au','Daniel Sponiar','7/1b Whateley St.','Newtown','New South Wales','AUSTRALIA','2042','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-06 03:19:00',0,NULL,3,1,3,1,'RA184527953CN\r ',NULL),(22300,842015952017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.4,'photographyacc','minkybike','kieran_mcgrane@hotmail.com','Kieran McGrane','IPC Global<br>4 Wadhurst Drive','Boronia','Victoria','AUSTRALIA','3155','0434308973','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 03:49:12',0,NULL,3,1,11,1,'BJ01670039\r ',NULL),(22301,8881325825937685,111,'绿叶 CPL  77mm',1,'AA3314',0,'photographyacc','vitorwood','vmcm@ci.uc.pt','Vítor M. C. Madeira','Centro de Neurociências, Univ. Coimbra<br>L. M. Pombal','Coimbra','','PORTUGAL','3004-517','+351239714759',NULL,NULL,NULL,'2012-01-06 04:58:57',0,NULL,3,1,23,1,'BP04081201060005 ',' '),(22302,842035188017,270745065334,'New Green.L Premium Quality 77mm UV Filter Canon Nikon ',1,'AA3307',4.36,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 05:08:43',0,NULL,3,1,17,0,NULL,NULL),(22303,783009273018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.17,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 05:10:26',0,NULL,3,1,17,0,NULL,NULL),(22304,783009596018,280671626609,'New Green.L Premium Quality 67mm UV Filter Canon Nikon ',1,'AA3305',3.98,'photographyacc','bfg27248937','briangallagher@y7mail.com','brian gallagher','173 flynns road','ercildoune','Victoria','AUSTRALIA','3352','0353435386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 05:12:10',0,NULL,3,1,11,1,'BJ01670043\r ','绿叶 UV  77mm   1 \r绿叶 UV  72mm   1\r绿叶 UV  67mm    1'),(22305,778265487001,110731646314,'New 200w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT085',108,'hermeshine','ckphotography','cntnek@yahoo.ca','Cynthia Korman','4118 Centennial Blvd','Brandon','MB','CANADA','R7B 3K7','(204) 727-4939','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 06:06:09',0,NULL,5,1,18,1,'\r ','不能发，回信确认退款 '),(22306,821972978002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','young74707','longpockets@westnet.com.au','Peter Young','7 Raynuha Crt<br>Ormeau','Gold Coast','Queensland','AUSTRALIA','4208','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 06:58:09',0,NULL,3,1,3,1,'RA184527998CN\r ',NULL),(22307,8881325840157883,111,'8个杆',1,'',0,'hermeshine','santigris','santigris@hotmail.com','Santiago Sanchez moreno','C/ Gran Vía, 17, 1-D (santiago y Mª Jose)','Cehegín','Murcia','SPAIN','30430','686143675',NULL,NULL,NULL,'2012-01-06 08:55:57',0,NULL,3,1,21,1,'RA184535257CN\r ',NULL),(22308,8881325842005565,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',19.99,'aliexpress','1006129345 ','123azz@libero.it','stefano Di Biasi	','Via Rovine 91','Bojon	','Italia','ITALY','30010','3290638604',NULL,NULL,NULL,'2012-01-06 09:26:45',0,NULL,3,1,21,1,'RA184535265CN\r ',NULL),(22309,8881325842309008,111,'Pro Photo Vest for 450D 500D 40D 30D 50D 5D2 user XXXL',1,'AD1134',29.99,'aliexpress','1006142692 ','point@netvision.com.br','Moacir Giacomozzi	','AV. JUSCELINO KUBITSCHECK 410','JOINVILLE','SANTA CATARINA	','BRAZIL','89201-100','+55 47 30276310',NULL,NULL,NULL,'2012-01-06 09:31:49',0,NULL,3,0,25,1,'RT124214989HK ','XXXL (已入库)'),(22310,774348671001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','maayanphoto','yaron@qaz.co.il','Yaron Cohen','P.O.B 2429','Afula','Israel','ISRAEL','18123','972-054-4518877','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:15:11',0,NULL,3,1,24,1,NULL,NULL),(22311,778309934001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','dosegaev','justserg@live.ru','Viktor Ershov','26 Zubkovoy Street, Apartment 226','Ryazan','Ryazanskaya oblast','RUSSIAN FEDERATION','390048','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:17:20',0,NULL,3,1,5,1,'CP244548493CN\r ',NULL),(22312,778314020001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','baraatha','nasia_bar@hotmail.com','Nasia Mparakith','Aristeidou 6','Athens','Agios Dhmhtrios','GREECE','17341','2109328941','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:37:06',0,NULL,3,1,24,1,NULL,'称一下重量 \r93G\r'),(22313,822015648002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','dyu18','sinnedyu@hotmail.com','Dennis Yu','51 Gent street<br>Yarraville','Melbourne','Victoria','AUSTRALIA','3013','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 10:37:36',0,NULL,3,1,11,1,NULL,'称一下重量 \r100g'),(22314,842100517017,270822547911,'4 pcs Lens Pouch s:70mm x 100mm m:85mm x 150mm l:90mm x 180mm xl:95mm x 230mm',1,'AKT086',17.58,'photographyacc','diamond_dave85','drooke175@yahoo.com','David Rooke','14 Mackenzie Blvd','Seven Hills','New South Wales','AUSTRALIA','2147','0296215645','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 10:40:08',0,NULL,3,1,11,1,NULL,NULL),(22315,8881325847515938,111,'1500W  套装',1,'AKT066',0,'hutongstore','zulkeef123','zulkeefly@yahoo.com','Zulkeef Bahadoor','Professor Hassan Raffa Road','Phoenix','Phoenix ','MAURITIUS','230','',NULL,NULL,NULL,'2012-01-06 10:58:35',0,NULL,3,1,12,1,'3436003631\r\r ','+ 1.6*3  绿色背景布 \r申报$100\rTel: (230) 750 0225\r实重7.7  泡重10.7\r\r'),(22316,902807715016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','afosterswailes','angela.foster-swailes@morgan-cole.com','Angela Foster-Swailes','Morgan Cole<br>Bradley Court 11, Park Place,','Cardiff','Cardiff','UNITED KINGDOM','CF10 3DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 11:11:36',0,NULL,3,1,11,1,NULL,NULL),(22317,921827908015,250692240197,'Remote Control Cord for Nikon D300s/D200/D700​/D3 MC-30',1,'AA2220',2.52,'hutongstore','atuulas','albert.tuulas@gmail.com','Albert Tuulas','Harjannetie 5 B 50','Helsinki','Uusimaa','FINLAND','00710','+358468155555','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 11:34:28',0,NULL,3,1,24,1,NULL,' '),(22318,921835327015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','aespinai','albertotahiche@gmail.com','Alberto Espina Iglesias','Cl. Mario Benedetti 7','Tahíche','Canarias','SPAIN','35507','638788851','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 11:58:46',0,NULL,3,1,4,1,'YW867738901CN\r ',NULL),(22319,921856926015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','jfossb','jhf022@student.uit.no','Jostein Fossbakk','Dramsveien 541','Tromsø','Troms','NORWAY','9014','0047 93439402','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 13:01:17',0,NULL,3,1,22,1,'BJ01669953 ',NULL),(22320,778360131001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','shutterbugpd','payments@shutterbugphotodesign.ca','Mark Ingram','11 Coventry Drive','Kitchener','ON','CANADA','N2A 1N2','(519) 504-7218','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 13:32:31',0,NULL,3,1,3,1,'RA184535455CN\r ',NULL),(22321,778374400001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','bonchoo','morekrit@hotmail.com','CHOONIAH LAO','59/72 NAKANIWAS48, Moo4,<br>NAKANIWAS STREET,','LADPROW','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 14:16:44',0,NULL,3,1,17,0,NULL,NULL),(22322,778374401001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','bonchoo','morekrit@hotmail.com','CHOONIAH LAO','59/72 NAKANIWAS48, Moo4,<br>NAKANIWAS STREET,','LADPROW','Bangkok','THAILAND','10230','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-06 14:16:45',0,NULL,3,1,10,1,'RF074689945SG ','45w 5500k 灯泡 220v  2 \r4螺丝井字扳手  1\r565g\r单个井字扳手176g'),(22323,778374415001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',4,'AO0006',43.96,'hermeshine','jacobg0701','olalovesjake@live.com','ola bowling','787 Ham Hollow Rd<br>Apt 1','Manchester','KY','UNITED STATES','40962-7546','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-06 14:17:35',0,NULL,3,0,21,1,'RA184535274CN\r ','1.6x2.1  4\r红 粉  蓝 棕 \r已发货   '),(22324,822080210002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','thepond99','omaralikhan@gmail.com','OMAR  KHAN','2137 ERIN GATE BLVD.','PICKERING','ON','CANADA','L1X2V3','(905) 420-6822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 14:26:24',0,NULL,3,1,3,1,'RA184535362CN\r ',NULL),(22325,842174869017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',28.49,'photographyacc','jiin_eriic','jiineriic@hotmail.com','jan-erick luzuriaga','19a blackdiamond place<br>bulli 2516','wollongong','New South Wales','AUSTRALIA','2516','0402531407','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-06 14:34:54',0,NULL,3,1,3,1,'RA184535376CN\r ',NULL),(22326,783145920018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','albatros-38','patrick.nic@voila.fr','Patrick NICOLAS','196 rte de Vienne','PENOL','Rhône-Alpes','FRANCE','38260','0675244191','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 14:52:57',0,NULL,3,1,11,1,NULL,NULL),(22327,817804800002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','falkone2001','tfalkovskyy@yahoo.co.uk','Taras Falkovskyy','8 Brodivska St.','Zolochiv','Lviv','UKRAINE','80700','+380973149336','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 15:39:28',0,NULL,3,1,21,1,'RA184548511CN\r ',' 之前有可能发错了  \r之前的单号 RA184535274CN'),(22328,822116691002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',2,'AKT017',256,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','00966500051020','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-06 16:09:00',0,NULL,3,1,12,1,'3436002640\r ','灯架  2m  11\r斜臂   1\r背景架2mx 1.6m   1\r背景布 1.6 * 2.1  白色  1\r柔光箱 50-70cm 单灯头  9\r3m 横杆（通用4节）    1\r115w 5500k 灯泡  220v 9\r灯架包薄   1\r灯架包  4\r申报  $720\r实重24.1   泡重32.1\r最终计费重量30'),(22329,921940993015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','mrsf11','heatherfitzgerald49@yahoo.ie','heather fitzgerald','9 rosewood<br>ballincollig','cork','Cork','IRELAND','1','0861638043','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-06 16:22:26',0,NULL,3,1,4,1,'YW867738912CN\r ','英标 \r1.6*2.1 白色布'),(22330,778212676001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','klutz82','mrhenrybennett@hotmail.com','Henry Bennett','1 Coopers Hill, Kimpton','Hitchin','Hertfordshire','UNITED KINGDOM','SG48QT','01438833501','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-06 16:29:32',0,NULL,3,1,3,1,'RA184535447CN\r ',NULL),(22331,778431941001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','rare.and.amazing','theonly2alive@gmail.com','Maria Zak','2 Regal Rd<br>Apt 305','Toronto','ON','CANADA','M6H 2J4','(647) 351-3289','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 16:57:41',0,NULL,3,1,3,1,'RA184535380CN\r ',NULL),(22332,921979048015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',40,'hutongstore','scottrobertphoto','scott@scottrobertgallery.com','Scott Lim','1834 S Mayflower Ave<br>Unit C','Monrovia','CA','UNITED STATES','91016-8305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 17:34:14',0,NULL,3,1,21,1,'RA184535288CN\r ',NULL),(22333,921989111015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','petitebeauty001','tanishaappleton@hotmail.co.uk','Tanisha Appleton','3 Hargrave Masions<br>Hargrave road','Islington','London','UNITED KINGDOM','N19 5SR','07958119848','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 17:52:19',0,NULL,3,1,4,1,'YW867738923CN\r ',NULL),(22334,921991896015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 17:57:24',0,NULL,3,1,21,1,'RA184535685CN ','多发一个50-70棚的柔光罩给他 '),(22335,921996494015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',2,'AKT017',146,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-06 18:08:57',0,NULL,8,1,17,0,NULL,'欧标 \rlighting kit  £40'),(22336,922031997015,250690849529,'Background Support & Light Kit 3m x 6m 10 x 20ft white ',1,'AKT038',130,'hutongstore','sarnysandwich1','sandrahamiltonx@hotmail.com','sandra baitrum','27 chittock mead','basildon','Essex','UNITED KINGDOM','SS14 1RW','01268543340','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-06 19:08:13',0,NULL,3,1,4,1,'YW867738934CN\r ','英标 '),(22337,922039498015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','andreysuchkov','fiap-sas@rambler.ru','Andrey Suchkov','ul.Parovoznaya<br>10-28','Orel','','RUSSIAN FEDERATION','302029','+79103027820','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-06 19:20:39',0,NULL,3,1,5,1,'CP244548564CN\r ',NULL),(22338,922024361015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','jeztastic','jeztastic@yahoo.com','Jeremy Aitkens','5 Ivy Place','Canterbury','Kent','UNITED KINGDOM','CT1 3ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 18:54:17',0,NULL,3,1,3,1,'RA184535570CN\r ',NULL),(22339,922065626015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','vernonldownes','vldownes@gmail.com','Vernon Downes','1 Rue du Chateau d\'eau<br>Pouilloux','La Chapelle Pouilloux','Poitou-Charentes','FRANCE','79190','0033549273893','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-06 20:05:15',0,NULL,3,1,11,1,NULL,NULL),(22340,822253648002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','vitalija2','vitalija219@gmail.com','Vitalija Pabilioniene','Reipslagergata 17','Kristiansund N','Møre og Romsdal','NORWAY','6514','92506070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 21:17:44',0,NULL,3,0,21,1,'RA184535226CN\r ','白色 '),(22341,903089879016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','jessypaston','jessy@paston.biz','Jessy Paston','6 Langley Road','Droitwich','Worcestershire','UNITED KINGDOM','WR97RW','01905795407','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-06 21:20:45',0,NULL,3,1,3,1,'RA184535393CN\r ',NULL),(22342,783315531018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',4.75,'photographyacc','stonestreaker','stonestreeker@aol.com','ian jones','18 nabwood crescent','shipley','West Yorkshire','UNITED KINGDOM','BD184HX','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 21:06:25',0,NULL,3,1,11,1,NULL,NULL),(22343,778576672001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','green_eyes34','cherublady@gmail.com','Sharilee Pontbriand','6762 Rte 10','Upper Salmon Creek','NB','CANADA','E4A1J1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-06 22:37:00',0,NULL,3,0,3,1,'RA184535402CN\r ','110v  （已入库） \r\r\r4个'),(22344,842417664017,270748932432,'New Eye Piece Eyecup For Nikon DK-21 DK21 D200 D90 D80',2,'AA1203',5.52,'photographyacc','joycea_70','lastkiss98@hotmail.com','Anthony D Joyce','150 Green Village Lane','Dartmouth','NS','CANADA','b2y 4v4','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-06 23:21:20',0,NULL,3,1,11,1,NULL,NULL),(22345,778614219001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','oldforsale','speelgoed1@chello.nl','Richard Dolphijn','Caro van eycklaan 36','Zutphen','','NETHERLANDS','7207gg','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-07 00:48:00',0,NULL,3,1,21,1,'RA184535291CN\r\r ',NULL),(22346,783401093018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',23.66,'photographyacc','zankah','zankah@hotmail.com','Peter Zanker','Coroner\'s Court<br>302 King William Street','Adelaide','South Australia','AUSTRALIA','5000','0408835316','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 01:10:59',0,NULL,3,1,3,1,'RA184535464CN\r ',NULL),(22347,822340561002,120661195033,'Green-L 55mm Graduated Neutral Density ND Grey Filter',1,'AA3316',5.95,'hermeshine','catherinekyl0506','catherinekyl@gmail.com','Yen Li Catherine Kok','2515 University Ave SE W102','Minneapolis','MN','UNITED STATES','55414','(612) 812-7516','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 01:41:31',0,NULL,3,1,1,1,NULL,NULL),(22348,777982430001,110782465471,'New 3  filters TianYa brand & Ring adapter holder for Cokin System P Series',1,'AKT071',25,'hermeshine','keltech924','keltech.1@comcast.net','Louis Keller','2 Garfield Ln W','andover','MA','UNITED STATES','01810-5869','(978) 475-6338','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 01:45:41',0,NULL,3,1,1,1,' ',NULL),(22349,778633444001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','m.o.khan','momerkhan81@yahoo.com','MR M KHAN','9/483 Kooyong Road','Elsternwick','Victoria','AUSTRALIA','3185','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 02:08:27',0,NULL,3,1,11,1,NULL,NULL),(22350,8881325904331409,111,'5灯头60x90的棚的柔光罩1个',1,'',0,'hermeshine','andrzejcorkbeg','corkbeg@yahoo.ie','Andrew Dzijak','Unit22 Nordic Enterprise Park','Midleton','CORK','IRELAND','default','',NULL,NULL,NULL,'2012-01-07 02:45:31',0,NULL,3,0,21,1,'RA184548468CN ',NULL),(22351,822359455002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sandraruediger','solution.partner@gmx.de','Rüdiger Hinzmann','Nebelhöhlestrasse 46','Lichtenstein','','GERMANY','72805','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 02:59:39',0,NULL,3,1,21,1,'RA184535305CN\r ',NULL),(22352,783430106018,280672061106,'Video Camera Hands-Free Shoulder Support Pad Tripod ',1,'AE1401',34.1,'photographyacc','frankg1953','fbgalletta@iimetro.com.au','Frank Galletta','14 Edwin Avenue','Tranmere','South Australia','AUSTRALIA','5073','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 03:11:11',0,NULL,3,1,3,1,'RA184535478CN\r ',NULL),(22353,778654010001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','bryanamandac','malachicarter777@msn.com','Bryan Carter','202 22 st','Cold Lake','AB','CANADA','T9M 1E8','(780) 639-4383','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 03:40:58',0,NULL,3,1,3,1,'RA184535481CN\r ',NULL),(22354,783437294018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',28.49,'photographyacc','alanc2730','aandmclish@optusnet.com.au','Alan Clish','69/20 Johnston Street<br>Carnia','Brisbane','Queensland','AUSTRALIA','4152','0731683413','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 03:43:00',0,NULL,3,0,3,1,'RA184535495CN\r ','XXL  (已入库） '),(22355,783452132018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',2,'AD1169',12.16,'photographyacc','protein_world','proteinworld@optusnet.com.au','Charlie Jabbour','393 Mt Alexander Rd','Ascot Vale, Melbourne','Victoria','AUSTRALIA','3032','0409794007','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 04:55:25',0,NULL,3,1,11,1,NULL,NULL),(22356,783463853018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','neuraldisarray','necrophobiac27@hotmail.com','Josh Mitchell-Frey','102 Charles street<br>Seddon','Melbourne','Victoria','AUSTRALIA','3011','0396893173','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 06:06:36',0,NULL,3,1,11,1,NULL,NULL),(22357,778685480001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','andreiwb','toywood@gmail.com','Andrei Smirnov','Zelenograd, Solnechnaya Alleya, 810-192','Moscow','Zelenograd','RUSSIAN FEDERATION','124527','8-926-157-1689','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 06:47:43',0,NULL,3,1,11,1,NULL,NULL),(22358,783480985018,280695077728,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',22.8,'photographyacc','travycan','hung.y.lin@student.uts.edu.au','Travis L.','Suite 27, Jones Bay Wharf<br>26-32 Pirrama Road','Pyrmont','New South Wales','AUSTRALIA','2009','0402244880','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 07:59:25',0,NULL,3,1,3,1,'RA184535504CN\r ',NULL),(22359,778704843001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','monastig3','alayan_arqitecture@yahoo.com','Ramon Alayan','37A The Avenue<br>Albany','North Shore','Auckland','NEW ZEALAND','0632','021 184 6033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 08:56:00',0,NULL,3,1,2,1,NULL,NULL),(22360,778712888001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','soysaucenwasabi','dealz4realz@aol.com','Tony Nguyen','902 N 14th St','San Jose','CA','UNITED STATES','95112-1532','','NoPaymentFailure','CheckoutComplete','Other','2012-01-07 09:34:22',0,NULL,3,1,1,1,NULL,NULL),(22361,922325154015,250636773414,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',49,'hutongstore','dennzil','denny@saltire.org','Denny Conway','Arns House, Arns Road, Arns<br>by Cumbernauld','Glasgow','North Lanarkshire','UNITED KINGDOM','G67 3JW','07743874301','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-07 09:40:45',0,NULL,3,1,4,1,'YW867738945CN\r ','白+ 黑 '),(22362,778726776001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','jeanchris_38','jc.chouillet@gmail.com','Jean-Christophe Chouillet','116 cours Jean-Jaurès','Grenoble','Rhône-Alpes','FRANCE','38000','0665545088','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 10:37:40',0,NULL,3,1,3,1,'RA184535416CN\r ',NULL),(22363,822469291002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','sailing1940','arthurcoates@netspace.net.au','Arthur Coates','3 Glendale Court','Lake Wendouree','Victoria','AUSTRALIA','3350','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 11:56:33',0,NULL,3,1,3,1,'RA184535420CN\r ',NULL),(22364,842606365017,270750687158,'New Camera shoulder bag A1 for Canon Dslr 550D 500D',1,'AO0029',24.51,'photographyacc','kristinaandcon2005','kristinamsydney@hotmail.com','Kristina Manovska','293 Princes Hwy','Sylvania','New South Wales','AUSTRALIA','2224','0405498101','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-07 12:20:30',0,NULL,3,1,3,1,'RA184535654CN\r ',NULL),(22365,778536726001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','manntas-lt','mantas654@gmail.com','Mantas Burokas','Stoties 45-17','Panevezys','_UAES_NULL_','LITHUANIA','35105',' 37065450422','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 13:14:15',0,NULL,3,1,22,1,NULL,NULL),(22366,922409942015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','dcollins1124','dav.collins@bigpond.com','David Collins','107 Cochrane Street','West Kempsey','New South Wales','AUSTRALIA','2440','0265623251','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 13:41:31',0,NULL,3,1,3,1,'RA184535433CN\r ',NULL),(22367,903397036016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','helo3131','rosagirl31_51@hotmail.com','voisenet heloise','30,rue Bacou','saint alban','Midi-Pyrénées','FRANCE','31140','0618870189','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 14:14:22',0,NULL,3,0,3,1,'RA184535566CN\r ','1.6x3m  黑色 '),(22368,922429779015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',2,'AA3306',5.8,'hutongstore','chusgr','jgr_85_bcn@hotmail.com','Jesús Gómez Rodríguez','C/ Ntra. Sra. de Lourdes nº 18 2º  1ª','Molins de Rei','Cataluña','SPAIN','08750','625726498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 14:27:45',0,NULL,3,1,2,1,NULL,NULL),(22369,922459922015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','bjarne2808','bjarkesvej22@gmail.com','Bjarne Sandberg','Bjarkesvej 22','Skanderborg','standard','DENMARK','8660','26161880','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 15:29:09',0,NULL,3,1,4,1,'YW867738956CN\r ','欧标 '),(22370,822581520002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','wmacblue','divamum@yahoo.com','Madeleine Gray','737 Overbrook Rd','Baltimore','MD','UNITED STATES','21212-2106','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-07 17:07:40',0,NULL,3,1,21,1,'RA184535212CN\r ',NULL),(22371,822513461002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','viktorda','viktorda@yahoo.com','VIKTOR DAMATOV c/o Hirani Group','30 Jericho Executive Plz<br>Ste 200C','JERICHO','NY','UNITED STATES','11753-1062','(516) 248-1010 ext.: 3025','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-07 17:10:40',0,NULL,3,1,1,1,NULL,NULL),(22372,922580060015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','alarmas69','alarmas69@yahoo.es','Ruben Quintas Mosquera','Rua Eloy Luis Andre, Nº 6 - 3º B','Ourense','Galicia','SPAIN','32005','615488866','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 18:52:01',0,NULL,3,1,4,1,'YW867738960CN\r ','黑加白 '),(22373,778917848001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','clm3980','clarelouiseweir@hotmail.co.uk','Clare Weir','193 Meldrum Court','Glenrothes','Fife','UNITED KINGDOM','KY7 6UP','01592570312','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-07 19:01:43',0,NULL,3,1,3,1,'RA184535518CN\r ',NULL),(22374,903565786016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','fundraised','chris@waddell.org.uk','Christopher Waddell','8 Clerks Acre','Keymer','West Sussex','UNITED KINGDOM','BN6 8QY','01273842401','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 19:18:35',0,NULL,3,1,3,1,'RA184535708CN\r ','英标 '),(22375,903575812016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','shazayne','howards.home@talktalk.net','Sharon Howard','1 Buttermere, Great Notley','Braintree','Essex','UNITED KINGDOM','CM777UY','01376342535','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 19:35:35',0,NULL,3,1,3,1,'RA184535645CN\r ',NULL),(22376,783768326018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',4.83,'photographyacc','ravcios','chmielewscy@pro.onet.pl','Rafał Chmielewski','Nad Zalewem 23a/6','Zlotoryja','dolnoslaskie','POLAND','59-500','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-07 20:44:00',0,NULL,3,1,23,1,'BP04081201090002 ',NULL),(22377,922647754015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','vlasov63','vlaso-evgenij@yandex.ru','Vlasov Evgenij','Gastello 35a-114','Samara','Samarskaya oblast','RUSSIAN FEDERATION','443011','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 20:44:21',0,NULL,3,1,5,1,'CP244548533CN\r ','欧标 '),(22378,778997278001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','bruppa','klasspappa@hotmail.com','Emil Almberg','Hammarby Allé 111','Stockholm','','SWEDEN','12064','0733996102','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-07 22:02:51',0,NULL,3,1,21,1,'RA184535328CN\r ',NULL),(22379,922664099015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',2,'AKT016',107,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 22:52:55',0,NULL,8,1,17,0,NULL,NULL),(22380,922661287015,250932214054,'New  pro 10 x 20 ft 3m x 6m  backdrop system and continous lighting kit 1000W',1,'AKT050',132,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-07 22:52:56',0,NULL,3,1,12,1,'2100816863\r\r\r ','C里面以外的再加\r灯架  2m  4\r柔光箱 50-70cm 单灯头  4\r灯架包    2\r4套1000W套装\r先包一下试试看布能不能包进去\r申报64\r泡重42.1\r已发货.......\r需要重新拿回来申报40\r泡重 35.8kg\r '),(22381,922735027015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','darrenbull','darren@darrenbull.com','Darren Bull','58 Matthews Green Road','Wokingham','Berkshire','UNITED KINGDOM','RG41 1JU','01189786517','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-07 23:42:15',0,NULL,3,1,3,1,'RA184535756CN ',NULL),(22382,783848812018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','jvcg796','grimaj@tpg.com.au','Joseph Grima','2 Warraba Street','Hurstville','New South Wales','AUSTRALIA','2220','0291505670','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 00:04:53',0,NULL,3,0,3,1,'RA184548542CN ','1.6*2.1 黑色  1\r1.6*2.1  白色   1'),(22383,779036632001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 00:06:01',0,NULL,3,1,17,0,NULL,NULL),(22384,822769197002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',2,'AKT069',115.98,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-08 00:06:00',0,NULL,3,1,17,0,NULL,NULL),(22385,822766987002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',4,'AD1191',239.96,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-08 00:06:02',0,NULL,5,1,5,1,'CP244548547CN\r ','红边套装包    1 \r115w 5500k 灯泡  220v  8\r5灯头+60-90棚    4\r澳转欧标\r申报$30\r\r5灯头都要测试一下，同时测试5个灯泡\r已发货.....'),(22386,779048599001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','comely7911','comelypromotions@bigpond.com','253Amanda Payne','18 Parkview Drive','Murray Bridge','South Australia','AUSTRALIA','5253','0416305785','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-01-08 00:42:39',0,NULL,3,1,4,1,'YW867738971CN\r ',NULL),(22387,779064334001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','swift4tom','ebay@exocosm.net','Blaine Horrocks','43 Winter Gardens Trail','Scarborough','ON','CANADA','M1C 3M8','(416) 287-2935','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-08 01:41:08',0,NULL,3,1,3,1,'RA184535521CN\r ',NULL),(22388,842959858017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',3.79,'photographyacc','cutsnakes','nitsch1@bigpond.net.au','Jeff Nitsch','15 Goolman Street','Brisbane','Queensland','AUSTRALIA','4069','0733782963','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 01:52:14',0,NULL,3,1,11,1,NULL,NULL),(22389,783880308018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',52.75,'photographyacc','cigarluvercanada','mmceathron@cogeco.ca','Michael McEathron','961 western ave','peterborough','ON','CANADA','K9J5W2','(705) 740-0122','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-08 01:57:42',0,NULL,3,1,3,1,'RA184535535CN\r ',NULL),(22390,779081076001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',2,'AD1164',79.8,'hermeshine','savedbygrace888','scottb@visinet.com.au','Scott Bowskill','22a Wesley St','Oatlands','New South Wales','AUSTRALIA','2117','61411889907','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 02:49:52',0,NULL,3,1,4,1,'YW867738982CN\r ',''),(22391,783914409018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.27,'photographyacc','dzierzoniowianka','ei.wojtczak@wp.pl','Ewa Wojtczak','9/5 Bedford Street','North Melbourne','Victoria','AUSTRALIA','3051','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 04:20:01',0,NULL,3,1,11,1,NULL,NULL),(22392,779103513001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','wmonteiro1706','wellington_mont@yahoo.com.br','Luiz Wellington de S. Monteiro','Rua Dr. José Lourenço 2510<br>Apto 1101','Fortaleza','Ceará','BRAZIL','60115282','+55 85 32465022','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 04:33:55',0,NULL,3,1,5,1,'CP244548516CN\r ',NULL),(22393,783935699018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','runderscoren','ryosuke529529@gmail.com','Ryosuke Nakamura','5/30A Lavender Street','North Sydney','New South Wales','AUSTRALIA','2060','0433027851','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 06:15:43',0,NULL,3,1,11,1,NULL,NULL),(22394,779131909001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','1st-idea','dicko3160@gmail.com','Ray Dickinson','25 Hazel Grove','Tecoma','Victoria','AUSTRALIA','3160','0397526443','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 07:30:54',0,NULL,3,1,11,1,NULL,NULL),(22395,783954401018,280687559310,'New Studio Photography Lighting with Boom Arm Kit Set',1,'AKT066',193.75,'photographyacc','teung','to_aha@yahoo.com','SURASIT HARAMI','104 Krongthong Mansion Building B Room No.205<br>Soi Ladphrao81 Rd.Ladphrao Wangtonglang Ladphrao','Bangkok','THAILAND','THAILAND','10310','0849768606','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-08 08:10:36',0,NULL,5,1,6,1,'EE636829192CN\r ','美标 \r已发货..................'),(22396,783960532018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',5.6,'photographyacc','au2ru','au22ru@gmail.com','Alex James','4 Asti Place','Berwick','Victoria','AUSTRALIA','3806','0478224322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 08:45:10',0,NULL,3,1,11,1,NULL,NULL),(22397,779151615001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','bysilversage','mhleonard@comcast.net','Michael Leonard','10967 E Crestline Cir','Englewood','CO','UNITED STATES','80111-3858','(720) 253-8879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 09:18:33',0,NULL,3,1,1,1,NULL,' '),(22398,922661729015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','borowski2008','ggemini9@o2.pl','Grzegorz Borowski','ul.Solipska 33/9<br>mobile: +48 602 712 488','Warszawa','mazowieckie','POLAND','02-482','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 09:22:40',0,NULL,3,1,5,1,'CP244548520CN\r ','欧标 '),(22399,822894797002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','trankilstef','trankilstef@hotmail.fr','Stephane  Tranquillin','10 place de la liberté','Fosses','Île-de-France','FRANCE','95470','06 63 97 54 81','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 09:29:59',0,NULL,3,1,3,1,'RA184535549CN\r ',NULL),(22400,922901488015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','tonybarranco','tony@barranco.co.uk','Antonio Barranco','12 Cumberlands','Kenley','Surrey','UNITED KINGDOM','CR8 5DX','02086602736','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 09:45:51',0,NULL,3,0,3,1,'RA184535552CN\r ','L号  已入库'),(22443,779651698001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','txabiele','doctor.xavier@hotmail.com','JAVIER GONZALEZ ALVAREZ','C RIERA DEN NOFRE 10 A 2 2','SANT JOAN DESPI','Barcelona','SPAIN','08970','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 02:22:21',0,NULL,3,1,21,1,'RA184535359CN\r ',NULL),(22401,779164949001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','33region','kolpakov921@gmail.com','Dmitry Kolpakov','Sovetskaya 29A-24','Murom','Vladimirskaya oblast`','RUSSIAN FEDERATION','602267','+79209032440','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 10:06:48',0,NULL,3,1,5,1,'CP244548502CN\r ',NULL),(22402,8881326019918706,111,'牛津布大包',1,'AD1181',0,'hutongstore','eggyloom','egert.lehtla@gmail.com','Egert Lehtla','Tähe 86-1','Tartu','Tartu','ESTONIA','50107','',NULL,NULL,NULL,'2012-01-08 10:51:58',0,NULL,3,1,24,1,'30111859422\r ',''),(22403,903903459016,260854010827,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',11.9,'hutongstore','teddy_bear2105','dipearson@aapt.net.au','Di Pearson','28 Sheringa Grove','Cordeaux Heights','New South Wales','AUSTRALIA','2526','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 11:22:14',0,NULL,3,1,11,1,NULL,NULL),(22404,922969298015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','cjpxyz','les573@aol.com','mark parvin','42 High Street,','Felling,','Tyne and Wear','UNITED KINGDOM','NE10 9LT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 12:22:14',0,NULL,3,1,11,1,NULL,NULL),(22405,843141350017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',28.49,'photographyacc','igor_km1970','igor_km@gmx.net','Игорь Каймович','Чкалова 8, кв. 20','Славута','','UKRAINE','30000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-08 13:03:27',0,NULL,3,1,17,0,NULL,NULL),(22406,784047280018,280697484849,'Studio 28\"x40\"/ 70x100cm Softbox Universal Mount strobe',1,'AD1141',49.4,'photographyacc','igor_km1970','igor_km@gmx.net','Игорь Каймович','Чкалова 8, кв. 20','Славута','','UKRAINE','30000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-08 13:03:28',0,NULL,3,1,5,1,'CP244548003CN ','伞式柔光箱 60×90cm   1 \r70x100cm通用卡口柔光箱   1\r称一下重量\r2.1'),(22407,921584805015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','serocco.by','serocco@gmail.com','Kharaneka Aliaksandr','Golubeva st. 13-301','Minsk','BY','BELARUS','220116','+375291906840','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 13:47:31',0,NULL,3,1,5,1,'CP244548459CN\r ','\r申报：\rbackground support $45'),(22408,921584618015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','serocco.by','serocco@gmail.com','Kharaneka Aliaksandr','Golubeva st. 13-301','Minsk','BY','BELARUS','220116','+375291906840','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 13:47:32',0,NULL,3,1,17,0,NULL,' '),(22409,822985892002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','kartinkin','bybaby@mail.ru','Volodymyr Gerasymov','36-40 Gogolevskaya str. apt.8','KIEV','','UKRAINE','04053','+380672351927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 13:50:27',0,NULL,3,1,21,1,'RA184535314CN\r ',NULL),(22410,923089172015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','beezerc12','pondside@talk21.com','Leslie Reilly','Heath Bungalow, Woodbastwick Rd, Blofield Heath','Norwich','Norfolk','UNITED KINGDOM','NR134AB','01603715052','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 16:02:11',0,NULL,3,1,11,1,NULL,NULL),(22411,823068606002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','leffehp66','leffehp@gmail.com','Leif Collstam','Jägartorpsvägen 17','Karlstad','','SWEDEN','S-654 65','+46 70 354 76 36','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 16:35:25',0,NULL,3,1,21,1,'RA184535668CN ',NULL),(22412,778996941001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','wadecarey50','bluebandit43@aol.com','Carey Wade','5005 Meadow Lake Dr<br>null','Richton park','IL','UNITED STATES','60471-1189','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 16:44:10',0,NULL,3,1,1,1,NULL,NULL),(22413,784147118018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',57,'photographyacc','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 16:47:59',0,NULL,3,1,17,0,NULL,NULL),(22414,842726604017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',2,'AE2202',107.72,'photographyacc','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 16:47:59',0,NULL,3,1,17,0,NULL,NULL),(22415,843246092017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',28.49,'photographyacc','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 16:48:00',0,NULL,3,1,17,0,NULL,NULL),(22416,784149821018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',36.1,'photographyacc','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 16:48:00',0,NULL,3,1,17,0,NULL,NULL),(22417,784147899018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-08 16:48:01',0,NULL,5,0,4,1,'YW867739096CN\r ','1.6*2.1  白色   1\r115w 5500k 灯泡  220v   4\r4灯头 灯头 孔    2  \r110cm 两用伞    2\r伞式柔光箱 60×90cm    1\r反光板 100*150 40*60 5合1   1\r分开发   两票燕文\r\r反光板是不是要分开发\rYW867739052CN\r已发货.....\r '),(22418,823081700002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9,'hermeshine','raba3244','abadmonching@yahoo.ca','Ramon Abad','1013- 1441Lawrence Avenue East','North york','ON','CANADA','M4a 1w3','(416) 551-1651','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 16:59:18',0,NULL,3,1,11,1,NULL,NULL),(22419,923122569015,250639051110,'1000W PhotoStudio Continuous Light Kit Soft Box Softbox',2,'AKT017',146,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-08 16:47:54',0,NULL,3,1,17,0,NULL,'\r\r\r欧标 申报20'),(22420,779393426001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','we*ma','werner.marcinkowski@t-online.de','Werner Marcinkowski','Weyerstr. 8','Essen','','GERMANY','45131','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-08 18:16:42',0,NULL,3,1,21,1,'RA184535331CN\r ',NULL),(22421,923229157015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','redesau.123','redesau@gmail.com','Ol Rappaport','26 Kingsley Avenue','West Ealing','London','UNITED KINGDOM','W13 0EF','02088104217','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 18:45:32',0,NULL,3,1,11,1,NULL,NULL),(22422,779421638001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','ralsandberg','ral@ral-sandberg.com','Ral Sandberg','630 Spruce St','Boulder','CO','UNITED STATES','80302-5018','(303) 442-7709','NoPaymentFailure','CheckoutComplete','Other','2012-01-08 18:51:58',0,NULL,3,1,1,1,NULL,NULL),(22423,923284160015,250692241476,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.5,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 19:35:21',0,NULL,3,1,17,0,NULL,NULL),(22424,923284045015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 19:35:21',0,NULL,3,1,17,0,NULL,NULL),(22425,923283884015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 19:35:22',0,NULL,3,1,21,1,'RA184535671CN ','4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）  1   欧标\r柔光伞  1 \r闪光灯B座   1'),(22426,923299687015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','glynisray','glynis.gar@googlemail.com','glynis garland','34helmores<br>laindon west','basildon','Essex','UNITED KINGDOM','ss156sa','01268415128','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 19:51:53',0,NULL,3,1,3,1,'RA184535699CN ','英标 '),(22427,779492796001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','webexse','ebay@mycket.com','Hans Maaherra','Rullstensgatan 17','Umea','','SWEDEN','90655','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 20:20:04',0,NULL,3,1,4,1,'YW867739100CN\r ','欧标 '),(22428,903711308016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','llueveylasgotaspoeticasmeexaltan','patricioreig@gmail.com','Patricio Reig','Concilio de Trento 313 pl.14','Barcelona','Cataluña','SPAIN','08020','626684429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 20:29:13',0,NULL,3,1,4,1,'YW867739074CN\r ','欧标 '),(22429,777793500001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','ramiro531','tomasg@rjia.net','Ramiro  Valadez Guzman','531 E Devon Dr','Mount Airy','NC','UNITED STATES','27030-5825','(336) 786-6866','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-08 20:22:44',0,NULL,3,1,1,1,NULL,NULL),(22430,923349575015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','skatepinkbat','josephine.murphy@ukgateway.net','Ruairidh Flint','16 Herongate Road<br>Wanstead','London','London','UNITED KINGDOM','E12 5EG','02089899131','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 20:45:42',0,NULL,3,1,3,1,'RA184535610CN\r ',NULL),(22431,823274054002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','gerryminnich17','gerry.minnich@gmail.com','Gerry Minnich','22349 Boulder Ridge Dr','Mokena','IL','UNITED STATES','60448-8240','(815) 405-7109','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-08 21:07:30',0,NULL,3,1,1,1,NULL,NULL),(22432,823286541002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','cmartin375','cccmartin2001@yahoo.com','christopher martin','601 gibson dr','madison','TN','UNITED STATES','37115','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-08 21:28:35',0,NULL,3,1,21,1,'RA184535345CN\r ',NULL),(22433,923417147015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2101',25,'hutongstore','alexv61','alex.vidis@gmail.com','Alex Vidis','77 Kings Road','Walton-on-Thames','Surrey','UNITED KINGDOM','KT12 2RD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-08 22:21:34',0,NULL,3,0,3,1,'RA184535623CN\r ','XL 已入库 '),(22434,823315106002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','popmarta100','popmarta@gmail.com','Marta Pereira','Rua Cardeal da Mota<br>n.8 - 3. dto','Castelo Branco','Castelo Branco','PORTUGAL','6000-158','00351966460737','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 22:25:23',0,NULL,3,1,23,1,'BP04081201090001 ',' '),(22435,923422016015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',1,'AA1301',1.88,'hutongstore','sean.c.maguire','sean.c.maguire@gmail.com','Sean Maguire','163 Lower Kilmacud Road','Stillorgan','Dublin','IRELAND','default','012789994','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-08 22:29:46',0,NULL,3,1,24,1,NULL,NULL),(22436,823322206002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','ta-152h','nachtjager@virginmedia.com','Carl Hope','19 Rosthwaite Road','Liverpool','Merseyside','UNITED KINGDOM','L128QD','01512334371','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 22:43:01',0,NULL,3,1,11,1,NULL,NULL),(22437,823338081002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','bestyaxc','lrusso63@optusnet.com.au','Phillip Russo','43 Lawrence','Fairfield','New South Wales','AUSTRALIA','2165','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-08 23:20:35',0,NULL,3,1,3,1,'RA184535583CN\r ',NULL),(22438,779220361001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 00:30:45',0,NULL,3,1,17,0,NULL,NULL),(22439,778793466001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 00:30:46',0,NULL,3,1,17,0,NULL,NULL),(22440,923494390015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','mcdarius','mcdarius@gmail.com','Darius Sirvinskas','118A<br>Oakfield Road','London','London','UNITED KINGDOM','SE20 8RQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 01:10:12',0,NULL,3,1,3,1,'RA184535597CN\r ',NULL),(22441,8881326072929481,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',25.99,'aliexpress','1006180654 ','jumaan.sheriff@hotmail.com','Jumaan Sheriff	','1/52 Currunghi Court','St Albans	','Victoria','AUSTRALIA','3021','+614 34108321',NULL,NULL,NULL,'2012-01-09 01:35:29',0,NULL,3,1,3,1,'RA184535606CN\r ',NULL),(22442,823403393002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','keithfay2','cheng_alan@hotmail.com','Ka Wah Cheng','134 Mavrinac Blvd','Aurora','ON','CANADA','L4G0G6','(905) 841-7476','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 02:18:52',0,NULL,3,1,5,1,'CP244548462CN\r ','白 '),(22444,823414157002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','philipof','pacifik27@hotmail.com','Philippe Morissette','166 champagne','acton vale','QC','CANADA','j0h1a0','(450) 501-5001','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 02:49:19',0,NULL,3,1,5,1,'CP244547949CN\r ',NULL),(22445,823417065002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','davidrwfishing','davidrwitham@bigpond.com','David Witham','11 Carmel Crescent','Kariong NSW','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 02:57:31',0,NULL,3,1,11,1,NULL,NULL),(22446,779664443001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','14102512','roman_mukhin@list.ru','Roman Mukhin','Gorskiy str. 8a-48','Novosibirsk','','RUSSIAN FEDERATION','630073','(913)944-4800','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 03:00:14',0,NULL,3,1,3,1,'RA184535637CN\r ',NULL),(22470,823546566002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','geliosso','geliostan@gmail.com','Alexander Trukhan','Gamarnika str., 1 - 44','Minsk','BLR','BELARUS','220090','+375296289982','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 12:24:33',0,NULL,3,1,21,1,'RA184548984CN ',NULL),(22447,823462436002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','caruslau','hymlau@gmail.com','Ho Yee Lau','306 Carmody Road<br>Inst for Molecular Bioscience','UNIVERSITY OF QUEENSLAND','Queensland','AUSTRALIA','4072','0733462011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 05:54:34',0,NULL,3,1,4,1,'YW867739085CN\r ',NULL),(22448,779710806001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','serpsdog','smiles_is_here@hotmail.com','Sean  Serpa','33 Nabiac Ave Gymea Bay','Sydney','New South Wales','AUSTRALIA','2227','0295262665','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:24:23',0,NULL,3,1,11,1,'BJ01669956 ',NULL),(22449,613233241004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','mow_chow','tonyoppedisano@tpg.com.au','Antonio Oppediano','11 Chopin St<br>Seven Hills','Sydney','New South Wales','AUSTRALIA','2147','0422901144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:26:18',0,NULL,3,1,17,0,NULL,NULL),(22450,823467503002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','mow_chow','tonyoppedisano@tpg.com.au','Antonio Oppediano','11 Chopin St<br>Seven Hills','Sydney','New South Wales','AUSTRALIA','2147','0422901144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:26:18',0,NULL,3,1,17,0,NULL,NULL),(22451,779710981001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','mow_chow','tonyoppedisano@tpg.com.au','Antonio Oppediano','11 Chopin St<br>Seven Hills','Sydney','New South Wales','AUSTRALIA','2147','0422901144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:26:19',0,NULL,3,1,17,0,NULL,NULL),(22452,823467348002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','mow_chow','tonyoppedisano@tpg.com.au','Antonio Oppediano','11 Chopin St<br>Seven Hills','Sydney','New South Wales','AUSTRALIA','2147','0422901144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 06:26:19',0,NULL,3,1,4,1,'YW867739063CN\r ','Mini 红外  canon     1 \r白反光伞110cm   2\r反光板 110cm 5合1  1\r反光板支架   1\r灯架  2m   1'),(22453,843675573017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','desktopjunction','northstorm@hotmail.co.uk','Mr Cameron Pollock','10 Flat 2/1 Clarence Street<br>Paisley','Paisley','Renfrewshire','UNITED KINGDOM','pa11pt','07745607070','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-09 06:32:00',0,NULL,3,1,3,1,'RA184548539CN ','1.6x3m 白色 '),(22454,904387000016,260894475136,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',19.99,'hutongstore','ernivy','sue.tyerman@hotmail.co.uk','Susan Tyerman','31 Hemingford Gardens','Yarm','Cleveland','UNITED KINGDOM','TS15 9ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 07:53:08',0,NULL,3,1,3,1,'RA184530060CN ',NULL),(22455,779727441001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','mbru8148','ahines9728@yahoo.com','anthony hines','23 Lincoln St','dorchester','MA','UNITED STATES','02122-1308','(617) 799-6121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 08:01:53',0,NULL,3,1,17,0,NULL,''),(22456,779725720001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','mbru8148','ahines9728@yahoo.com','anthony hines','23 Lincoln St','dorchester','MA','UNITED STATES','02122-1308','(617) 799-6121','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 07:54:02',0,NULL,3,1,1,1,'LK175125293CN ','NIKON 镜头盖 67mm  1\rNIKON 镜头盖 62mm   1\r已入库 \r'),(22457,779722442001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','erdikoetxe','luisibarrola.ld@gmail.com','LUIS IBARROLA','GATZARRIÑE 30','SOPELANA','País Vasco','SPAIN','48600','946763850','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 07:34:43',0,NULL,3,1,21,1,'RA184549004CN ',NULL),(22458,779733415001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','mbakos82','marton.bakos@t-online.hu','Marton Bakos','Vajk u. 56.','Budapest','Budapest','HUNGARY','1183','+36203127289','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 08:35:10',0,NULL,8,1,17,0,NULL,' '),(22459,823491068002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','mbakos82','marton.bakos@t-online.hu','Marton Bakos','Vajk u. 56.','Budapest','Budapest','HUNGARY','1183','+36203127289','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 08:35:12',0,NULL,8,1,17,0,NULL,NULL),(22460,823491067002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','mbakos82','marton.bakos@t-online.hu','Marton Bakos','Vajk u. 56.','Budapest','Budapest','HUNGARY','1183','+36203127289','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 08:35:11',0,NULL,3,1,21,1,NULL,'110cm 两用伞   1 \r伞式柔光箱 60×90cm   2\r85cm 两用伞   1'),(22461,843706061017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',74.1,'photographyacc','hepcat200','hepcat200@optusnet.com.au','Paul Rogers','21B Stevens Street<br>Yeronga','Brisbane','Queensland','AUSTRALIA','4104','0738485710','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-01-09 09:08:49',0,NULL,3,1,4,1,'YW867739030CN ',NULL),(22462,923656697015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','ambulancierosevillano','wifigon@gmail.com','ALBERTO MONTORO ARJONA','DOMINGUEZ GOMEZ 11  BAJO DERECHA','ALCALÁ DE GUADAIRA (SEVILLA)','Andalucía Ceuta y Melilla','SPAIN','41500','668829228','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 10:20:27',0,NULL,3,1,2,1,'30111805065\r ',NULL),(22463,779761561001,110760258379,'7\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1194',28,'hermeshine','kkajasto1961','kimmo.kajasto@welho.com','Kimmo Kajasto','Sakarinkatu 3 B 38','Helsinki','','FINLAND','00500','(358)40-8442714','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 10:45:56',0,NULL,3,1,21,1,'RA184548975CN ',NULL),(22464,607962881003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','itsfyn','mb@itsfyn.dk','Mads Binger','Mandal Allé 8A','Middelfart','Fyn','DENMARK','5500','64403031','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 10:47:08',0,NULL,3,1,4,1,'YW867739111CN ',NULL),(22465,779762833001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','11791','small@mail.ru','Anton Smulskiy','Fontanka, 108-12','St Petersburg','St Petersburg','RUSSIAN FEDERATION','190013','+79119604912','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 10:52:04',0,NULL,3,1,3,1,'RA184548423CN ',NULL),(22466,8881326106976971,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',1,'AA1310',6.99,'aliexpress','1006195605','hisamov@yahoo.com','Bulat Khisamov	','K. Marksa 57 V, 86','Zelenodolsk	','Tatarstan','RUSSIAN FEDERATION	','422540','79196201090',NULL,NULL,NULL,'2012-01-09 11:02:56',0,NULL,3,1,3,1,'RA184548410CN ',NULL),(22467,779772372001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','elfronta','michalzverina@seznam.cz','Michal Zverina','V Kutisti 1','Usti nad Labem','europe','CZECH REPUBLIC','40011','+420773665177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 11:29:05',0,NULL,8,1,17,0,NULL,NULL),(22468,823531493002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','elfronta','michalzverina@seznam.cz','Michal Zverina','V Kutisti 1','Usti nad Labem','europe','CZECH REPUBLIC','40011','+420773665177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 11:29:06',0,NULL,3,1,3,1,'RA184548485CN ','魔术手臂11寸   1 \rks-0 II （绿盒）  1'),(22469,784620130018,280671637827,'Canon EOS 5D Mark II 8GB (4GB + 4GB) USB Drive Box set',4,'',304,'photographyacc','medka4','medka_4@hotmail.com','kane mohamed','2 rue de la pointe a l\'ange<br>digicode 21 ','villepreux','Ile-de-France','FRANCE','78450','0629958303','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-09 11:36:45',0,NULL,3,1,4,1,'YW867739122CN ',NULL),(22471,923719429015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','michelangelouk','darren.frodsham@blueyonder.co.uk','Darren Frodsham','34 Derwent road<br>Hindley','Wigan','Lancs','UNITED KINGDOM','WN2  3QP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 13:19:59',0,NULL,3,1,3,1,'RA184548499CN ',NULL),(22472,904669937016,260660050361,'Camera Body and Rear Lens Cap for CANON EOS - NEW',1,'AA1315',2.2,'hutongstore','hevigfoto','hevig@pandora.be','Ed Groenendijk','Mispel 4','Dilbeek','','BELGIUM','1700','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 13:33:01',0,NULL,3,1,24,1,'30111805496\r ',NULL),(22473,613307644004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','eviltoothbrush','drebin@gis.net','Dan Finnerty','187 Billerica Rd<br>Formscan / Inspectron','Chelmsford','MA','UNITED STATES','01824-3616','(978) 256-6444','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-09 13:52:34',0,NULL,3,1,17,0,NULL,NULL),(22474,779813283001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','eviltoothbrush','drebin@gis.net','Dan Finnerty','187 Billerica Rd<br>Formscan / Inspectron','Chelmsford','MA','UNITED STATES','01824-3616','(978) 256-6444','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 13:52:34',0,NULL,3,1,1,1,'LK177059243CN ','Mini 红外  canon   1 \r反光伞    1'),(22475,904681678016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','fusi0n90','pingw@live.nl','Ka-Yi Wan','Leliekeverstraat 9','\'S-GRAVENHAGE','','NETHERLANDS','2492RH','00310634238084','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 14:02:52',0,NULL,3,0,21,1,'RA184548525CN ','1.6*3  绿色 '),(22476,784701785018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','keithfay2','cheng_alan@hotmail.com','Ka Wah Cheng','134 Mavrinac Blvd','Aurora','ON','CANADA','L4G0G6','(905) 841-7476','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-09 15:33:04',0,NULL,3,1,3,1,'RA184548936CN ','4节 '),(22477,779869725001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','channynova','howivegan@yahoo.com','Chantel Britton','3609 37 Avenue','Leduc','AB','CANADA','T9E6G8','(780) 222-5293','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 16:31:58',0,NULL,3,1,5,1,'CP244547970CN ','黑加白 '),(22478,904770266016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','charlestog75','c.tognazzoni@hotmail.fr','Charles Tognazzoni','24 Rue de Tolbiac','Paris','Ile-de-France','FRANCE','75013','0650068717','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 17:09:58',0,NULL,3,1,3,1,'RA184548922CN ',NULL),(22479,779888537001,110790875316,'New Professional Portable Diffuser for SpeedLight sb900 sb700 580ex metz XL ',1,'AD1210',12.99,'hermeshine','kandk2008','klemen.ramoves@siol.net','Klemen  Ramoves','Nova pot 127d','Vnanje Gorice','Slovenia','SLOVENIA','1351','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 17:14:47',0,NULL,3,1,17,0,NULL,NULL),(22480,613364136004,140642546050,'New Swivel Flash Mount Umbrella Bracket for studio  Light Stand D',1,'AD1122',13.8,'hermeshine','kandk2008','klemen.ramoves@siol.net','Klemen Ramoves','Nova pot 127d','Vnanje Gorice','','SLOVENIA','1351','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 17:17:10',0,NULL,3,1,21,1,'RA184530025CN ','lif通用柔光罩XL   1 \r闪光灯D座    1'),(22481,779906567001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','paulc9409','pee.condon@yahoo.co.uk','paul condon','471 stannington road','sheffield','South Yorkshire','UNITED KINGDOM','s65qp','01142336631','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 17:53:01',0,NULL,8,1,17,0,NULL,NULL),(22482,779907637001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.55,'hermeshine','paulc9409','pee.condon@yahoo.co.uk','paul condon','471 stannington road','sheffield','South Yorkshire','UNITED KINGDOM','s65qp','01142336631','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 17:54:15',0,NULL,3,1,11,1,'BJ01669955 ','橡胶遮光罩 58mm   1 \r绿叶 UV  58mm   1'),(22483,779910822001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','vanda_c_oliveira','vanda.c.oliveira@gmail.com','Vanda de Carvalho Oliveira Marques','Rua Helena Félix, n.º 21 1º Esq.','Quinta do Texugo','Charneca da Caparica','PORTUGAL','2820-266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 18:01:42',0,NULL,3,1,17,0,NULL,NULL),(22484,779911182001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','vanda_c_oliveira','vanda.c.oliveira@gmail.com','Vanda de Carvalho Oliveira Marques','Rua Helena Félix, n.º 21 1º Esq.','Quinta do Texugo','Charneca da Caparica','PORTUGAL','2820-266','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 18:01:41',0,NULL,3,1,23,1,'BP04081201100001 ','单灯头   2 \r欧标'),(22485,904856694016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','nephestima','nihan_kara@yahoo.com','Nihan Kara','1 Bungtown Rd<br>James Bldg','Cold Spring Harbor','NY','UNITED STATES','11724-2209','(631) 413-3010','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 19:22:15',0,NULL,3,1,1,1,'LK170712558CN ',NULL),(22486,779977551001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','josezizu','joseabarra@hotmail.com','jose antonio barragan ortega','c/ montnegre 48 3º 4ª','girona','Cataluña','SPAIN','17006','872033816','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 19:56:58',0,NULL,3,1,4,1,'YW867739133CN ',NULL),(22487,779990557001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','benx769','benx769@hotmail.com','Benoit Deschenes','1383<br>Notre-Dame','St-sulpice','QC','CANADA','j5w3v8','(450) 589-1158','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 20:18:05',0,NULL,3,1,12,1,'3436122745 ','110V  \r美标 \r实重  7.2   泡重9.1'),(22488,823770854002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',1,'AC2303',6.21,'hermeshine','clingfreeze','michael.t.maeder@gmail.com','Michael Maeder','Bruehlstrasse 63<br>Appartment 37','Arbon','','SWITZERLAND','9320','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 20:43:19',0,NULL,3,1,24,1,'30111804984\r ',NULL),(22489,904937017016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','manfromtheweb','mikaraatikainen@gmail.com','Mika Raatikainen','Aatoksenkatu 10 A6','Jyväskylä','Keski-Suomi','FINLAND','40720','0453473995','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 21:13:21',0,NULL,3,1,17,0,NULL,NULL),(22490,924000286015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',2,'AC3302',16,'hutongstore','manfromtheweb','mikaraatikainen@gmail.com','Mika Raatikainen','Aatoksenkatu 10 A6','Jyväskylä','Keski-Suomi','FINLAND','40720','0453473995','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 21:15:04',0,NULL,3,1,4,1,'YW867739144CN ','150-200cm 5in1 反光板   1 \r反光板 80cm 2合1  2\r'),(22491,823786286002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','davidmai','david_t_mai@yahoo.com','David Mai','1117 S 287th St','Federal Way','WA','UNITED STATES','98003-3176','(253) 529-2479','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 21:20:16',0,NULL,3,1,21,1,'RA184548967CN ',NULL),(22492,823793798002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','augarov','aaugus@gmail.com','Aurimas Augus','Keramiku 2b<br>MGF \"Sviesos Konversija\"','Dvarcionys','Vilnius','LITHUANIA','LT-10233','(370) 695-1095 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-09 21:25:40',0,NULL,3,1,23,1,'BP04081201100002 ',NULL),(22493,842463691017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.4,'photographyacc','zachary109.2009','zachary109@hotmail.com','Simon Crodi','190-11880 Hammersmith Way','Richmond','BC','CANADA','V7A5C8','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-09 21:41:20',0,NULL,3,1,11,1,'BJ01669960 ',NULL),(22494,924022730015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','dr_coronet','gpcx@talktalk.net','DR CORONET','2 Sayesbury Manor,<br>Bell Street','sawbridgeworth','Hertfordshire','UNITED KINGDOM','CM21 9AN','01279725711','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 21:51:57',0,NULL,3,1,3,1,'RA184548919CN ','轮换成反光板支架的双轮就可以了\r'),(22495,780048398001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','oakley114','artpic26@yahoo.com','Alex Dela Rosa','2548 Greenwich Dr','Fullerton','CA','UNITED STATES','92833','(714) 600-9064','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-09 22:12:28',0,NULL,3,1,1,1,'LK175345158CN ',NULL),(22496,924038824015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','kelraverbaby','kelodell86@yahoo.co.uk','kelly odell','9 redmarle road<br>braunstone','leicester','Leicestershire','UNITED KINGDOM','LE3 1PJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 22:17:10',0,NULL,3,1,3,1,'RA184530039CN ',NULL),(22497,924046497015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','robsmileruk','applepierock@hotmail.com','Rob Senior','62<br>Cannon Hill Road','Birmingham','West Midlands','UNITED KINGDOM','B129NW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-09 22:31:31',0,NULL,3,1,3,1,'RA184530011CN','重量？ 1.588'),(22498,924057425015,250599345620,'Light Stands 2m /6\'56\" for photo studio lighting ×2 NEW',1,'AKT031',31,'hutongstore','linas565','linas@paintbaleris.lt','Linas Navardauskas','Taikos 84-54','Kaunas','lithuania','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-09 22:54:49',0,NULL,3,1,5,1,'CP244547983CN ','灯架  2m  2 '),(22499,823835122002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','aslethomas','asle.tommerstrand@gmail.com','Asle Thomas Tömmerstrand','Trygve Thesens vei 12','Trondheim','Sör-Tröndelag','NORWAY','7020','97037956','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-09 22:57:57',0,NULL,3,1,21,1,'RA184548437CN ',NULL),(22500,823842091002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','bullshark9669','bullshark1969@yahoo.com','Jason Eanes','892 Devereaux Dr','Virginia Beach','VA','UNITED STATES','23462-5292','(757) 714-6342','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-09 23:15:18',0,NULL,3,1,1,1,'LK178946253CN ',NULL),(22501,823858251002,120568575653,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',11.98,'hermeshine','alexeynik','cosmikos@gmail.com','Alexey Nikishin','Varshavskoe shosse st., 152-8-128','Moscow','','RUSSIAN FEDERATION','117405','+7 916 914 27 09','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:02:37',0,NULL,3,1,17,0,NULL,NULL),(22502,823858252002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','alexeynik','cosmikos@gmail.com','Alexey Nikishin','Varshavskoe shosse st., 152-8-128','Moscow','','RUSSIAN FEDERATION','117405','+7 916 914 27 09','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:02:38',0,NULL,3,1,17,0,NULL,NULL),(22503,780087206001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','alexeynik','cosmikos@gmail.com','Alexey Nikishin','Varshavskoe shosse st., 152-8-128','Moscow','','RUSSIAN FEDERATION','117405','+7 916 914 27 09','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:02:39',0,NULL,3,1,17,0,NULL,NULL),(22504,823858253002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','alexeynik','cosmikos@gmail.com','Alexey Nikishin','Varshavskoe shosse st., 152-8-128','Moscow','','RUSSIAN FEDERATION','117405','+7 916 914 27 09','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:02:39',0,NULL,3,1,17,0,NULL,NULL),(22505,823858254002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','alexeynik','cosmikos@gmail.com','Alexey Nikishin','Varshavskoe shosse st., 152-8-128','Moscow','','RUSSIAN FEDERATION','117405','+7 916 914 27 09','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:02:40',0,NULL,3,1,5,1,'CP244547952CN','反光板 80cm 2合1  1 \r大力夹    1\r牛津布大包   1\r沙袋（普通）    1\r反光板支架  1\r灯架  2m   1'),(22506,777421906001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','jansant','ebay@jansant.com','wayne jansson','29 wilby rd','lake rowan','Victoria','AUSTRALIA','3727','0400809163','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-01-10 00:10:48',0,NULL,3,1,4,1,'YW867739041CN ',NULL),(22507,823841908002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','fontainexx','tonyc@online.no','Tony Claesson','Klauvsteinen 157','Bergen','Fyllingsdalen','NORWAY','5146','+47 92049752','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 00:55:47',0,NULL,3,1,24,1,'30111791894\r ',NULL),(22508,8881326159228956,111,'New Collapsible 190x140 cm backdrop background light green & blue',1,'AC3304',68,'aliexpress','1006194969','lucamendesestudio@gmail.com','Luca Mendes	','Av Francisco Morato, 2203 Apt. 83-B5 Butanta','Sao Paulo	','Sao Paulo	','BRAZIL','05513-300','+55 11 94537909',NULL,NULL,NULL,'2012-01-10 01:31:04',0,NULL,3,1,3,1,'RA184530056CN ','已经补交$14的运费，\r申报$15'),(22509,784988394018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','ceejaytee77','carlyjadetaylor@hotmail.com','Carly Sloan','16 Walls Street','Eaglehawk','Victoria','AUSTRALIA','3556','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 01:39:53',0,NULL,3,1,11,1,'BJ01669959 ',NULL),(22510,780142436001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','azimut-77','mcouillard70@hotmail.com','Michel Couillard','1856, Rue De Villiers','Montréal','QC','CANADA','H4E 1L1','(514) 766-9982','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 03:20:39',0,NULL,3,1,5,1,'CP244547997CN ',NULL),(22511,785024024018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','1959jeh','jane@janehackettphotography.com','Jane Hackett','PO Box 9814','Frenchville','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 03:47:12',0,NULL,3,1,17,0,NULL,NULL),(22512,785023800018,280671626938,'New Green.L Premium Quality 72mm UV Filter Canon Nikon ',1,'AA3306',4.39,'photographyacc','1959jeh','jane@janehackettphotography.com','Jane Hackett','PO Box 9814','Frenchville','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 03:47:13',0,NULL,3,1,11,1,'BJ01669957 ','绿叶 渐变镜 72mm   1 \r绿叶 UV  72mm   1\r中号内胆包 无字 1'),(22513,905101418016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',2,'AE2202',31.18,'hutongstore','xander100_0','da_alex361@yahoo.co.uk','Abayomi Alex Adegoke','10 Waterhouse Close, Great church Lane','Hammersmith','London','UNITED KINGDOM','W68DQ','07951558637','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 03:52:48',0,NULL,3,1,3,1,'RA184548471CN ','英标 '),(22514,844169666017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','1959jeh','jane@janehackettphotography.com','Jane Hackett','PO Box 9814','Frenchville','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 03:47:13',0,NULL,3,1,17,0,NULL,NULL),(22515,785036960018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','edwardoness86','eddie_dickey@hotmail.com','Edward Dickey','40 Bells Hill Rd<br>Research','Melbourne','Victoria','AUSTRALIA','3095','0394372568','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-01-10 04:42:08',0,NULL,3,1,4,1,'YW867739435CN ',NULL),(22516,785037085018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','sweetmysteryscott','skotti@hotmail.co.uk','Scott Allinson','39 Ash Grove','Bradford','West Yorkshire','UNITED KINGDOM','bd7 1bn','07983645865','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 04:42:58',0,NULL,3,1,11,1,'BJ01669954 ',NULL),(22517,785059775018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','bellafocus09','bellafocus@hotmail.com','belinda inglese','27 elamo road<br>Healesville','melbourne','Victoria','AUSTRALIA','3777','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 06:45:47',0,NULL,3,1,4,1,'YW867739446CN ',NULL),(22518,844221555017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.99,'photographyacc','pplondon','pplondon@btinternet.com','Paulo Pimentel','18 Albert Terrace Mews','London','London','UNITED KINGDOM','NW1 7TA','07956365824','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 07:51:32',0,NULL,3,1,11,1,'BJ01669952 ',NULL),(22519,905154426016,260894475316,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',21.5,'hutongstore','gongvfx','saintgong@hotmail.com','Thongchai  Chanyathitikul','936/44 Soi 10 Tranurat Road<br>Sathon Yannawa','Bangkok','Thailand','THAILAND','10120','0865251532','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 07:56:09',0,NULL,3,1,17,0,NULL,NULL),(22520,924222280015,250932215120,'7\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1194',18.9,'hutongstore','gongvfx','saintgong@hotmail.com','Thongchai  Chanyathitikul','936/44 Soi 10 Tranurat Road<br>Sathon Yannawa','Bangkok','Thailand','THAILAND','10120','0865251532','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 07:59:54',0,NULL,3,1,10,1,'RF074752815SG ','魔术手臂11寸   1 \r魔术手臂7寸   1'),(22521,924239446015,250599919893,'New 72mm Ring adapter for Cokin P Series Filter Holder',1,'AA2213',1.6,'hutongstore','jmcgreno2011','jmcgreno@portugalmail.pt','José Manuel Gonçalves','R.dr.Mário Viana - nº10<br>Esposende','Esposende','Esposende','PORTUGAL','4740-266','351919253845','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 09:07:33',0,NULL,3,1,23,1,'BP04081201110002 ',NULL),(22522,780209904001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','ardoms','ariopradipta@yahoo.com','Ario Samudro','PTFI Office Building 1<br>Jl. Mandala Raya Selatan No. 1 Lt.1','Kuala Kencana, Timika','Papua','INDONESIA','99920','+6281240170994','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-10 09:22:54',0,NULL,3,1,10,1,'RF074797255SG ','和香港小包挂号差不多\r都比国内小包挂号便宜 '),(22523,905178907016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','adelleroxanne','adelledrover@hotmail.com','Adelle Drover','66 Elwood Street','Brighton','Victoria','AUSTRALIA','3186','0395964498','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 09:35:56',0,NULL,3,1,24,1,'30111958144\r ',NULL),(22524,785094619018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',43,'photographyacc','wtrio','wtrioebay@yahoo.com.au','Widjaja','3 /  1-7 PELICAN ST<br>SURRYHILLS','SYDNEY','New South Wales','AUSTRALIA','2010','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-10 09:43:29',0,NULL,3,1,3,1,'RA184530688CN\r ',NULL),(22525,924266993015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',2,'AD1176',47,'hutongstore','bigwibb','bigwibb@btinternet.com','Ian R. Wibberley','70 Fydell Street,','Boston','Lincolnshire','UNITED KINGDOM','PE21 8LF','01205350399','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 10:42:49',0,NULL,3,1,4,1,'YW867739413CN ','英标 '),(22526,780244685001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','woutelisa2','woutelisa@gmail.com','wouter van egmond','Heemraadlaan 26','LEIDERDORP','','NETHERLANDS','2352RH','0031639440784','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-10 11:53:33',0,NULL,3,1,23,1,'BP04081201110003 ',NULL),(22527,824023557002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','zabousik','zabous@zabous.cz','Gabriela  Homolova','Rabstejnska 49','Plzen','Czech Republic','CZECH REPUBLIC','32300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 11:59:12',0,NULL,3,1,3,1,'RA184535813CN ','申报$25 '),(22528,784335607018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','susanr7841','lindaegan61@hotmail.com','Susan Redmond','189 Grace Park Heights<br>Drumcondra','Dublin','','IRELAND','9','018375825','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-10 12:58:57',0,NULL,3,0,24,1,'30111959695\r ',NULL),(22529,824041882002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','ralphy2277','billingrs@sympatico.ca','Ralph Billing','47 Cobblestone Drive','Paris','ON','CANADA','N3L4G2','(519) 442-3557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 13:07:06',0,NULL,3,1,11,1,'BJ01669949\r ',NULL),(22530,924316286015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','dorsetdave','freemantle.dave@yahoo.co.uk','David Freemantle','15 Monmouth Drive','Verwood','Dorset','UNITED KINGDOM','BH316TN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 13:12:16',0,NULL,3,0,3,1,'RA184535827CN\r ','2XL  已入库 '),(22531,905245974016,260814164713,'QR Quick Release Plate For Fancier FT-6663A Head 6160H',1,'AB1203',4.85,'hutongstore','antoniodepadua','ajimesteban@telefonica.net','Antonio Jimenez','rio duero 12 1º A','alcorcon','Madrid','SPAIN','28923','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 13:13:29',0,NULL,3,1,2,1,'30111959264\r ',NULL),(22532,780268058001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','leirren','pump1987@gmail.com','Ferenc Regosi','Kiss Janos alt. utca 65. 1/20','Budapest','Budapest','HUNGARY','1211','36205730415','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 13:19:56',0,NULL,3,1,21,1,'RA184535795CN ',NULL),(22533,780275109001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','+79233486117','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 13:46:49',0,NULL,3,1,11,1,'BJ01669947\r ',NULL),(22534,824061505002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','spookydonk','barrkell@gmail.com','Barry Kelly','98 whitestown avenue<br>Clonsilla','Dublin','Dublin','IRELAND','15','0539138663','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 14:11:16',0,NULL,3,1,21,1,'RA184535800CN ',NULL),(22535,780299291001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',11.99,'hermeshine','borodulin_8102','borodulin8102@rambler.ru','Nikolay Borodulin','Krasnay 5-48','Kemerovo','','RUSSIAN FEDERATION','650000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-10 15:48:06',0,NULL,3,1,3,1,'RA184535892CN ',NULL),(22536,905331920016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','sentolas','jlar4444@hotmail.com','jose luis alonso rodriguez','avda ourense nº 72-1-A','cangas del morrazo','Galicia','SPAIN','36940','637709364','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 16:44:08',0,NULL,3,1,21,1,'RA184535711CN ',NULL),(22537,924414193015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','sichellin','rafahellinero@hotmail.com','RAFAEL  IBAÑEZ GONZALVEZ','C/POETA TOMAS PRECIADOS<br>16 1º G ','HELLIN (ALBACETE)','Castilla-La Mancha','SPAIN','02400','629183490','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-10 16:58:34',0,NULL,3,1,4,1,'YW867739424CN ','1.6*2.1  白色布\r欧标 '),(22538,780046432001,110532007118,'72mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1308',2.6,'hermeshine','tombricke','bricke.thomas@att.net','Mary Bricke','2042 Ridgeline Ave','Vista','CA','UNITED STATES','92081','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 17:41:58',0,NULL,3,1,1,1,'LK177955109CN ',NULL),(22539,924516756015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','furre85','ufos85@gmail.com','Jonas Hansson','Bodekullsgatan 34 A','Malmö','Skåne','SWEDEN','214 40','0708511622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 19:43:27',0,NULL,3,1,21,1,'RA184535725CN ',' '),(22540,905449303016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','gavcur','gavincurran@hotmail.com','Gavin Curran','29 Tirran Drive','Dunfermline','Fife','UNITED KINGDOM','ky11 8jg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-10 19:58:50',0,NULL,3,1,11,1,'BJ01669946\r ',NULL),(22541,824215452002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.9,'hermeshine','jazzbear7','realvision@bigpond.com','MARK PERKINS','7 IVY LEA PLACE','GOULBURN','New South Wales','AUSTRALIA','2580','0404485119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 20:05:20',0,NULL,3,1,11,1,'BJ01669950\r ',NULL),(22542,824223070002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','rovor11','rovor@email.cz','Roman Vorisek','Kanice 151','Bilovice nad Svitavou','','CZECH REPUBLIC','66401','+420605845459','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 20:21:16',0,NULL,3,1,3,1,'RA184535835CN ',NULL),(22543,905468075016,260901272243,'New 82mm 82 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT054',3.12,'hutongstore','juantonio7','chiliki2@hotmail.com','Juan Antonio Menacho Salas','calle praga 7--3 -A','Jerez de la Frontera','Andalucía Ceuta y Melilla','SPAIN','11405','619076192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-10 20:27:33',0,NULL,3,1,2,1,'30111961154\r ',NULL),(22544,780448765001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','monastig3','alayan_arqitecture@yahoo.com','Ramon Alayan','37A The Avenue<br>Albany','North Shore','Auckland','NEW ZEALAND','0632','021 184 6033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 20:41:02',0,NULL,5,0,18,0,NULL,'运费有点贵，运费表里没有 。\r这种方式也超过我们的运费了\r不能发'),(22545,824239142002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','omoore0','omoore@pipeline.com','PAUL O\'MOORE','1000 Quinard Ct','Ambler','PA','UNITED STATES','19002','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 20:49:41',0,NULL,3,1,1,1,'LK174498926CN ',NULL),(22546,924582083015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','melissa.m.collins','melissa.m.collins@gmail.com','Melissa Collins','Vordel, Regus,<br>30 Upper Pembroke St','Dublin','Dublin','IRELAND','2','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-10 21:20:14',0,NULL,3,1,21,1,'RA184535739CN\r ',NULL),(22547,824270723002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','larryyclin','lycly@yahoo.com','Larry Lin','39 Somerville Crescent<br>Oaklands','Christchurch','Canterbury','NEW ZEALAND','8025','+64211400609','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 21:54:25',0,NULL,3,1,10,1,'RF074968984SG\r ',''),(22548,824294159002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','sammianderson','sammi_anderson@internode.on.net','sammi j anderson','30 Christopher Crescent','Melton','Victoria','AUSTRALIA','3337','0402463415','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 22:52:28',0,NULL,3,1,3,1,'RA184535844CN\r ','1.6*3  白色，再放点其他布的小块样品 '),(22549,824299741002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','dhsha610','dhsha@hotmail.com','Daohang Sha','133 Agnew Ln','Paoli','PA','UNITED STATES','19301-1268','(610) 590-4559','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-10 23:06:43',0,NULL,3,1,1,1,'LK176588791CN ',' '),(22550,824305869002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','brunorossete','contato@brunorossete.com.br','Bruno Rossete','Rua José Sebastião de Almeida, 250<br>Jardim ana Célia','São José do Rio Preto','São Paulo','BRAZIL','15045-560','+55 1791465807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-10 23:24:53',0,NULL,3,1,25,1,'RT124441230HK ',NULL),(22551,824318047002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','003725580148','konstantin72@msn.com','Konstantin Gordejev','Laanemere<br>17-4','Tallinn','Harjumaa','ESTONIA','13914','+3725580148','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 00:01:44',0,NULL,3,1,24,1,'30111961294\r ',NULL),(22552,924661524015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','shaolinkungfu168','jingwuderek@hotmail.com','DEREK LUI','39 ROSEWOOD GLEN','LISBURN','Antrim','UNITED KINGDOM','BT28 2FH','07745772943','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 00:04:26',0,NULL,3,1,3,1,'RA184535858CN\r ',NULL),(22553,924662826015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','mrcloneme','matus_jaime79@hotmail.com','Helena Antonsson','Norströmsväg 13','Stockholm','Trångsund','SWEDEN','14260','+46707663677','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 00:07:38',0,NULL,3,1,21,1,'RA184535742CN\r ',NULL),(22554,824341770002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','oneunder1','venuecam@gmail.com','Kareem Abdel-Hamid','Apartment 1, 112-118<br>Gardenvale Road','GARDENVALE','Victoria','AUSTRALIA','3185','61401189005','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 01:25:57',0,NULL,3,1,11,1,'BJ01669951\r ',NULL),(22555,785464499018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','mattkempphotography','matt@mattkemp.com','Matt Kemp','Flat 5<br>8 Park Street','Collaroy','New South Wales','AUSTRALIA','2097','0404956624','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-11 02:11:46',0,NULL,3,1,3,1,'RA184535760CN ',NULL),(22556,608540979003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','lmacanuck23','lmcdonald@internode.on.net','Leanne Kilsby','208 Glenferrie Road','Malvern','Victoria','AUSTRALIA','3144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 02:34:10',0,NULL,3,1,4,1,'YW867739166CN ',NULL),(22557,785484155018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','ooowayne','stream@shoal.net.au','wayne evans','735 woollamia rd','woollamia','New South Wales','AUSTRALIA','2540','0244416341','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-11 03:08:57',0,NULL,3,1,3,1,'RA184535773CN\r ',NULL),(22558,824379115002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','makx81x','makx81@inbox.ru','Maxim Sklyarov','Kommunisticheskiy 34, kv 43','Rostov-on-Don','Rostov','RUSSIAN FEDERATION','344091','+7(904)501-4464','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 03:36:23',0,NULL,3,1,5,1,'CP244548017CN ',NULL),(22559,824386570002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','doofboy','temp1@wprasek.com','Warren Prasek','25 Topaz Street','Holland Park','Queensland','AUSTRALIA','4121','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 04:03:31',0,NULL,3,1,3,1,'RA184535787CN\r ','澳标 '),(22560,924748516015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','justinpees','mister_pees@hotmail.com','justin pees','553A Gagne','Montreal','QC','CANADA','H8P 3H5','(514) 243-4234','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,5,0,18,0,' ',' '),(22561,785514342018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT082',51.5,'photographyacc','rusti2100','praise2god_dj@hotmail.com','David Anderson','P.O.Box 1933, Geraldton','Geraldton','Western Australia','AUSTRALIA','6530','0409894423','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-11 05:25:10',0,NULL,3,1,3,1,'RA184535929CN ',NULL),(22562,824412294002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','guigrb','guilhermerochabotelho@msn.com','Guilherme Rocha Botelho','Avenida Tenente Enéas Torno, nº 42<br>Nova Niterói - 2ª VARA','Três Rios','Rio de Janeiro','BRAZIL','25802-330','(24) 8841-1615','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:18:11',0,NULL,3,1,17,0,NULL,NULL),(22563,824412295002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','guigrb','guilhermerochabotelho@msn.com','Guilherme Rocha Botelho','Avenida Tenente Enéas Torno, nº 42<br>Nova Niterói - 2ª VARA','Três Rios','Rio de Janeiro','BRAZIL','25802-330','(24) 8841-1615','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:18:12',0,NULL,3,1,17,0,NULL,NULL),(22564,780615800001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','guigrb','guilhermerochabotelho@msn.com','Guilherme Rocha Botelho','Avenida Tenente Enéas Torno, nº 42<br>Nova Niterói - 2ª VARA','Três Rios','Rio de Janeiro','BRAZIL','25802-330','(24) 8841-1615','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:18:12',0,NULL,3,1,24,1,'30112017714\r ','EW-73B   1 \r绿叶 CPL  67mm   1\r绿叶 UV  67mm  1'),(22565,780617199001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','designs1208','jyeway@yahoo.com','jason acebron','1315 Castle Oaks Dr','stockton','CA','UNITED STATES','95210-2033','(209) 518-9358','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 06:28:15',0,NULL,3,1,1,1,'LK178329287CN ',NULL),(22566,780616925001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','julieb219','dreamy_sweetie@hotmail.com','julie bulwan','11 orlando place','edensor park','New South Wales','AUSTRALIA','2176','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:28:55',0,NULL,3,1,11,1,'BJ01669936 ',NULL),(22567,824413820002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kin2son','kin2son_ebay@tpg.com.au','Kin S Cheng','12/17-19, Busaco Road','Marsfield','New South Wales','AUSTRALIA','2122','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 06:29:40',0,NULL,3,1,3,1,'RA184535932CN ',NULL),(22568,8881326266469772,111,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg.',1,'AD1184',0,'hermeshine','duvidf2011','duvidf@gmail.com','David Yosef Feldmar','Kibutz Kissufim','D.N Negev','','ISRAEL','85130','',NULL,NULL,NULL,'2012-01-11 07:21:09',0,NULL,3,1,3,1,'RA184535946CN ','3m 横杆（通用4节）   1\r伞式柔光箱 60×90cm  1\r已入库\r '),(22569,824424031002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','coconana25','coco_coco999@hotmail.com','chaiwat polddechsathaporn','Square Panel System Co.,Ltd.<br>21/485 Moo 12 Bangna-trad Road, Bangna','Bangkok','Bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 07:31:17',0,NULL,5,0,18,0,NULL,'运费贵，发不了，已经发信了 ，\r三小时之内收不到确认信息，退款\r2.9 已经退款了'),(22570,924826294015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','justinpees','mister_pees@hotmail.com','justin pees','553A Gagne','Montreal','QC','CANADA','H8P 3H5','(514) 243-4234','PayPalPaymentInProcess','CheckoutComplete','UK_SellersStandardInternationalRate','0000-00-00 00:00:00',0,NULL,7,1,18,1,'\\ ',NULL),(22571,824457758002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',5,'AB1307',18.95,'hermeshine','talkative34','1talkative1@mail.ru','Skobelina Anna','Zemlyanskogo 1 apartment 2','Volgograd','','RUSSIAN FEDERATION','400005','89173380220','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 10:18:30',0,NULL,8,1,17,0,NULL,NULL),(22572,824457451002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','talkative34','1talkative1@mail.ru','Skobelina Anna','Zemlyanskogo 1 apartment 2','Volgograd','','RUSSIAN FEDERATION','400005','89173380220','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 10:18:31',0,NULL,3,1,3,1,'RA184530396CN\r ','橡胶遮光罩 77mm   6 '),(22573,613934961004,140642546216,'Studio Light 800W Continuous Lighting e Kit with background support system 2m',1,'AKT087',172,'hermeshine','umm-zain','umm-zain@hotmail.co.uk','NURESSA BEGUM','294 BURDETT ROAD<br>POPLAR','LONDON','ENGLAND','UNITED KINGDOM','E14 7DQ','07903050710','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 11:09:03',0,NULL,3,1,4,1,'YW867739376CN ','英标\r白色布 '),(22574,780674378001,110412396215,'Adjustable Neoprene Padded Camera Neck Strap for Nikon',1,'AB1403',5.49,'hermeshine','mark_ryan1','m.ives77@btinternet.com','MARK A IVES','1 RIDGEWAY COTTAGES SWANBOURNE<br>SWANBOURNE','MILTON KEYNES','Buckinghamshire','UNITED KINGDOM','mk170sj','01296728103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 11:19:27',0,NULL,3,1,11,1,NULL,NULL),(22575,924872965015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dave_edinburgh','dave@davidlove.co.uk','Glam Barbers / Kristina Love','81 Easter Road','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH7 5PW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 12:27:07',0,NULL,3,1,3,1,'RA184558876CN\r ',NULL),(22576,780693370001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','nicoareva','nico.righi@free.fr','Nicolas Righi','30a rue francis chirat','Villeurbanne','Rhône-Alpes','FRANCE','69100','06.58.44.52.16','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-11 12:32:44',0,NULL,3,1,3,1,'RA184559001CN\r ',NULL),(22577,780695616001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','ilya1908','voytolovsky@gmail.com','Ilya Voytolovsky','3 Pivdenno-Kiltseva St Apt 177','Chernivtsi','Chernivtsi Region','UKRAINE','58013','050-6732257','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 12:40:08',0,NULL,3,1,21,1,'RA184558916CN ',NULL),(22578,905798330016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','170jazmin','bobnield@aol.com','Robert Nield','5 Belle Vue Road','Exmouth','Devon','UNITED KINGDOM','EX8 3DR','01395279537','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 13:07:40',0,NULL,3,1,3,1,'RA184535985CN\r ','英标 '),(22579,824505142002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','xisum666','isaakxisum@hotmail.com','isaac perez tortosa','jose maria peman 7-9','onil','Comunidad Valenciana','SPAIN','03430','667751329','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:19:55',0,NULL,3,1,21,1,'RA184558955CN ',NULL),(22580,924901343015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','charlysf2011','carlosbertalo@gmail.com','carlos bertalo lopez','c/ real alta nº2, 1º_La Graña_','ferrol','Galicia','SPAIN','15590','650074688','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-11 13:43:22',0,NULL,3,1,4,1,'YW867739380CN ',NULL),(22581,824517210002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','dannyddrinking','dannyd@imsoc.com.au','D. De Santis','PO Box 8023','South Perth','Western Australia','AUSTRALIA','6151','0417965980','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 13:56:52',0,NULL,3,1,11,1,NULL,NULL),(22582,780718707001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','tim260980','tim-iss@mail.ru','Anton Timofeev','60 LET VLKSM 68-16','Zheleznogorsk','Krasnoyarsk region','RUSSIAN FEDERATION','662980','(913)5502979','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 14:01:43',0,NULL,3,1,5,1,'CP244548034CN ',NULL),(22583,924910251015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 14:08:11',0,NULL,3,0,17,0,NULL,NULL),(22584,905821337016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 14:10:19',0,NULL,3,0,17,0,NULL,NULL),(22585,905822191016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-11 14:12:58',0,NULL,3,0,3,1,'RA184535963CN\r ','1.6*2.1  绿色   1\r1.6*3   绿色  2 \r称一下重量\r1.21'),(22586,780722060001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','legchenkov','antonav@mail.ru','Anton Legchenkov','pr-kt Geroev Stalingrada<br>161-116','Kharkiv','','UKRAINE','61162','380666444682','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 14:18:49',0,NULL,3,1,5,1,'CP244548048CN ',NULL),(22587,780730275001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','tournenrond','tournenrond@laposte.net','dominique teillay','22 rue de nantes','mitry mory','Île-de-France','FRANCE','77290','01.64.27.82.76','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 14:37:49',0,NULL,3,1,3,1,'RA184558893CN\r ','2个 '),(22588,780731079001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3307',4.9,'hermeshine','afeservicesllc','afeservices@gmail.com','Oleg Beneraf','59 Hillair Rd','Lake Peekskill','NY','UNITED STATES','105371013','(917) 692-0847','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-11 14:39:59',0,NULL,3,1,1,1,'LK179706775CN ',NULL),(22589,780774339001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','witiokaz','witiokas@yahoo.com','Vytis Snarskis','Dainavos 1-9<br>Raudondvaris','Kaunas','','LITHUANIA','54123','370 6712 6012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 16:41:25',0,NULL,3,1,17,0,NULL,NULL),(22590,780774340001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','witiokaz','witiokas@yahoo.com','Vytis Snarskis','Dainavos 1-9<br>Raudondvaris','Kaunas','','LITHUANIA','54123','370 6712 6012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 16:41:26',0,NULL,3,1,17,0,NULL,NULL),(22591,780774341001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',5,'AA1212',14.95,'hermeshine','witiokaz','witiokas@yahoo.com','Vytis Snarskis','Dainavos 1-9<br>Raudondvaris','Kaunas','','LITHUANIA','54123','370 6712 6012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 16:41:27',0,NULL,3,1,23,1,'BP04081201120001 ','canon 反接环  58mm    1 \rcanon 反接环  52mm   1\r52-58mm 双阳环   5\r\r'),(22592,780810006001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','kynam11','phamkynam@gmail.com','Ky-Nam Pham','Sem Sælandsvei 12<br>Room 227-KII; IMT-NTNU','Trondheim','Sør-Trøndelag','NORWAY','7491','(+47)41016156','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-11 18:05:10',0,NULL,3,1,21,1,'RA184558947CN\r ','M 已入库 \r申报低值'),(22593,780846060001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','serg13m','svideo13@mail.ru','Sergey Malkov','54-13  Pervomaiskaya ','Izhevsk','','RUSSIAN FEDERATION','426018','89068973609','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 19:15:23',0,NULL,3,0,11,1,NULL,'1.6*2.1  黑色 '),(22594,925094978015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','gaiusbaltarfr','delcourt.r@gmail.com','Rémi Delcourt','22 avenue Edouard Vaillant','Tremblay en France','Ile-de-France','FRANCE','93290','06.72.23.40.62','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 19:47:58',0,NULL,3,1,11,1,NULL,NULL),(22595,925091103015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','5katte2010','tbardorf4@gmail.com','Tom Bardorf','Skriverhusene 54','Albertslund','','DENMARK','2620','(0045) 22434890','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 19:51:52',0,NULL,3,1,24,1,'30112099441\r ',NULL),(22596,824676744002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','kathrynlt123','stphotos@msn.com','Kathryn L . Tirocchi','19 W Orange Ct','Baltimore','MD','UNITED STATES','21234-8020','(410) 256-5633','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-11 20:05:05',0,NULL,3,1,1,1,'LK179676929CN ',NULL),(22597,780880158001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','mpcmike1981','mpcverkruyse@mchsi.com','Michael Verkruyse','PO Box 927<br>419 E. Main','Mahomet','IL','UNITED STATES','61853-0927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-11 20:18:51',0,NULL,3,1,21,1,'RA184558933CN\r ',NULL),(22598,906024167016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',19.98,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 20:23:55',0,NULL,3,1,17,0,NULL,NULL),(22599,906023131016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',2,'AKT090',300,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 20:23:56',0,NULL,3,1,4,1,'YW867739391CN ','除了C里面2套以外再发\r铝合金灯座（N）    2 \r标头发4个 法国那个'),(22600,824694770002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','slamfest44','salexg44@yahoo.com','Santiago Garcia','11105 Hume Ave NE','Albuquerque','NM','UNITED STATES','87112-4341','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-11 20:35:30',0,NULL,3,1,1,1,'LK180762678CN ',NULL),(22601,906038895016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','cassianograndi','cassianograndi@gmail.com','Cassiano Grandi','Rua Dionísio da Costa, 132 apto 42','São Paulo','São Paulo','BRAZIL','04117110','+55 11 82166822','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 20:47:55',0,NULL,3,1,25,1,'RT124448431HK ',NULL),(22602,780902117001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','ae0012forov','conduforov@yandex.ru','Aleksandr Konduforov','Oktyabr\'skaya 11','Lebedyan\'','','RUSSIAN FEDERATION','399610','(905)0438602','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-11 21:02:07',0,NULL,3,1,3,1,'RA184558880CN\r ',NULL),(22603,780905525001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','brzius','mato.brzica@st.htnet.hr','Mato Brzica','Kneza Mislava 93','Podstrana','','CROATIA','21312','(385) 21 582 808','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 21:05:59',0,NULL,3,1,24,1,'30112102510\r ','运费有点贵，\r是不是需要把价格调高到$3.9 \r称一下重量'),(22604,824737126002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','alvaroalo1984','alvaro.alo@hotmail.com','Alvaro fernandez lozano','c/ Gertrudis de hore N3','Torrejon de ardoz','Madrid','SPAIN','28850','618767509','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 22:00:50',0,NULL,3,1,24,1,'30112100900\r ',NULL),(22605,780932287001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','vojpal','info@vojtapalek.com','Vojtech PALEK','Chodoun 222','Zdice','','CZECH REPUBLIC','26751','+420737864039','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 22:04:17',0,NULL,3,1,24,1,'30112097676\r ',NULL),(22606,780949132001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','zoethebrave','zoethebrave@mac.com','Zoe Gemelli','313-135 Bleecker St.','Toronto','ON','CANADA','M4X 1X2','(647) 955-6271','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 22:45:32',0,NULL,3,0,11,1,NULL,'1.6*2.1  黑色 '),(22607,845088799017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',58,'photographyacc','613angel76','jenjen.chicabonita@yahoo.com','jenny thistlethwaite','46<br>pinkwood st.','bellbowrie','Queensland','AUSTRALIA','4070','617424985217','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-11 23:00:21',0,NULL,3,1,4,1,'YW867739181CN ',NULL),(22608,824763664002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','marcostomasi','mctomasi00@yahoo.com.br','Marcos Cleber Tomasi','Rua José Rossini Nº 424<br>Bairro Santa Helena','Bento Goncalves','Rio Grande do Sul','BRAZIL','95700000','54 3454 1547','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 23:09:19',0,NULL,3,1,5,1,'CP244548051CN ',NULL),(22609,925224747015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','danielt4444','dterebus@o2.pl','Daniel Terebus','Apt.59 Raven Hall , Main Street','Swords','Dublin','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 23:44:25',0,NULL,3,1,21,1,'RA184535977CN\r ','英标 '),(22610,780969523001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','nikopolalexander','nikopol61662@yandex.ru','Alexander Peregudov','Mayakovskogo 110','Yuzhno-Sakhalinsk','Sakhalinskaya obl','RUSSIAN FEDERATION','693005','8-924-281-11-64','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-11 23:50:50',0,NULL,3,1,5,1,'CP244548065CN ','欧标 \r白色布'),(22611,925233820015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','rombow1k','rombowik@gmail.com','Imrich Scheffer','Sv. Stefana 57','Sturovo','Slovakia','SLOVAK REPUBLIC','94301','0903374283','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-11 23:56:45',0,NULL,3,1,5,1,'CP244548025CN\r ','+1.6*2.1  白色布  '),(22612,824781241002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',3,'AA1309',7.8,'hermeshine','hansnening','hansboessem@internode.on.net','hans boessem','47 lackmann terrace<br>braitling','alice springs','Northern Territory','AUSTRALIA','0870','0889529694','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 00:05:14',0,NULL,3,1,11,1,NULL,NULL),(22613,824793206002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','kalpesh1970','kmp1970@yahoo.com','Kalpesh Parekh','229 Clark Ter','Cliffside Park','NJ','UNITED STATES','07010-1436','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 00:41:57',0,NULL,3,1,21,1,'RA184558920CN ',NULL),(22614,824748926002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','photobombnz','michael.wilson024@msd.govt.nz','Michael Wilson','77 Ward St','Upper Hutt','','NEW ZEALAND','5013','06448892222','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-12 01:51:02',0,NULL,3,1,24,1,'30112178224\r ','走挂号有点贵，\r走香港小包平邮可以吗 \r还是退款'),(22615,781003989001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.55,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 01:53:14',0,NULL,3,1,17,0,NULL,NULL),(22616,824814637002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 01:53:15',0,NULL,3,1,17,0,NULL,NULL),(22617,781003990001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-12 01:53:15',0,NULL,3,1,25,1,'RT124452303HK ','绿叶 UV  58mm    1 \r单灯头   1  欧标\r肩架     1\r称一下重量'),(22618,824838780002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','tigasn','mygrasshopper@gmail.com','Rodolfo Concepcion','5450 Brittany Way','Cypress','CA','UNITED STATES','90630','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-12 03:20:57',0,NULL,3,1,1,1,'LK179645921CN\r ',NULL),(22619,781037908001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','pcarrona','mario_villalta@hotmail.com','Mario Villalta','8839 160th Street','Surrey','BC','CANADA','V4N 2X8','(604) 957-2605','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 04:06:20',0,NULL,3,1,11,1,'BJ01669907\r ',NULL),(22620,785980782018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1203',11,'photographyacc','retired_cia','ronsaunders@comcast.net','Ronald J.Saundes','3492 Kaylene Dr','San Jose','CA','UNITED STATES','95127-4317','(408) 251-4292','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-12 04:39:59',0,NULL,3,1,17,0,'LK181630948CN ',NULL),(22621,8881326343903547,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',2,'AC2402',39.98,'aliexpress','1006243478','tecfan@tecfan.com.br','Lucas Monteiro Robles	','Rua Pio Antunes de Figueiredo 70','Ribeirao Preto	','Sao Paulo	','BRAZIL	','14070-130','+55 16 81171469',NULL,NULL,NULL,'2012-01-12 04:51:43',0,NULL,3,1,25,1,'RT124481772HK\r ',' '),(22622,781047710001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',3,'AD1218',10.5,'hermeshine','retired_cia','ronsaunders@comcast.net','Ronald Saunders','3492 Kaylene Dr','San Jose','CA','UNITED STATES','95127-4317','(408) 251-4292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 04:53:05',0,NULL,3,1,17,0,'LK181630948CN ',NULL),(22623,781047711001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',3,'AD1220',10.5,'hermeshine','retired_cia','ronsaunders@comcast.net','Ronald Saunders','3492 Kaylene Dr','San Jose','CA','UNITED STATES','95127-4317','(408) 251-4292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 04:53:06',0,NULL,3,1,17,0,'LK181630948CN ',NULL),(22624,614210224004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',3,'AD1219',10.5,'hermeshine','retired_cia','ronsaunders@comcast.net','Ronald Saunders','3492 Kaylene Dr','San Jose','CA','UNITED STATES','95127-4317','(408) 251-4292','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 04:53:06',0,NULL,3,1,1,1,'LK181630948CN ','6片装的滤镜袋   2 \r无牌方镜 渐变灰 （nd2）  3\r无牌方镜 渐变灰 （nd8）   3\r无牌方镜 渐变灰 （nd4）    3\r'),(22625,824716237002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','kcorolla','private86884@gmail.com','kevin chircop','\'sapphire\' triq il-mastrudaxxa','st.venera','','MALTA','SVR 1563','(00356) 99865830','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 05:09:01',0,NULL,3,1,24,1,'30112163362\r ',NULL),(22626,824865960002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27,'hermeshine','todsapon','suwapanont@hotmail.com','Todsapon Suwapanont','555/104 Thongpracha condo<br>Prachauthid road.  Samsennork','Huaykwang','Bangkok','THAILAND','10310','+66 81 7386004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 05:17:23',0,NULL,3,1,25,1,'RT124482985HK\r ',NULL),(22627,781052945001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','smileydr-2008','smileydr@uwec.edu','Danielle Smiley','11782 40th Ave','Chippewa Falls','WI','UNITED STATES','54729-6677','(715) 495-7180','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-01-12 05:21:52',0,NULL,3,1,4,1,'YW867739192CN ','美标 '),(22628,786015745018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','gormaymaxphoto','gormaymax@gmail.com','30Andrew Evans','6 Linear Ave','Mullaloo','Western Australia','AUSTRALIA','6027','0864677106','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-12 07:53:52',0,NULL,3,1,11,1,NULL,NULL),(22629,781089294001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','redbrca','brorcarlsson2@hotmail.com','Bror Karlsson','Sibbohult 2','Burseryd','Sweden','SWEDEN','S33026','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-12 08:55:34',0,NULL,3,1,21,1,'RA184530453CN\r ',NULL),(22630,925383170015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','gribouboucan','achille2009@gmail.com','Jean-luc GRILLOT','11 sq vitruve','Paris','Île-de-France','FRANCE','75020','01.43.61.83.08','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 08:58:56',0,NULL,3,1,3,1,'RA184530440CN\r ','4节 '),(22631,906288129016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','133shaun','sq001x3668@blueyonder.co.uk','shaun quinn','6springroad orrell','wigan','Greater Manchester','UNITED KINGDOM','wn58qb','07834179153','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 09:23:11',0,NULL,3,1,11,1,NULL,NULL),(22632,824913379002,120582352724,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',2.18,'hermeshine','dyohata','andrey.grigorov@yahoo.com','Andrey Grigorov','Ovcha Kupel 2, block 43, entr. A, fl. 8, ap. 27','Sofia','Sofia','BULGARIA','1632','00359887573140','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 09:31:57',0,NULL,3,1,24,1,'30112263753\r ','\r '),(22633,824918533002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','magnavox831','cesargcampos@hotmail.com','Cesar Campos','1830 Massachusetts Dr','SALINAS','CA','UNITED STATES','93905-4617','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 09:56:24',0,NULL,3,1,21,1,'RA184530612CN\r ',NULL),(22634,925402027015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','mosa786','mohsin_ali@ntlworld.com','Mohsin Ali','Abritas<br>Soane Point, 6 - 8 Market Place','Reading','Berkshire','UNITED KINGDOM','RG1 2EG','01189255293','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 10:05:47',0,NULL,8,1,17,0,NULL,NULL),(22635,925407535015,250692240760,'Wireless Remote Control Cord for Canon 500D/550D/450D',1,'AA3203',12.7,'hutongstore','mosa786','mohsin_ali@ntlworld.com','Mohsin Ali','Abritas<br>Soane Point, 6 - 8 Market Place','Reading','Berkshire','UNITED KINGDOM','RG1 2EG','01189255293','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-12 10:23:19',0,NULL,3,1,3,1,'RA184530572CN\r ','爵影无线C1   1\r2B柔     1 '),(22636,824937299002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','onelund','info@getactive.se','Albin Enlund','Törestorp','Reftele','','SWEDEN','33021','0760259765','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 11:12:16',0,NULL,3,1,21,1,'RA184530626CN\r ','ks-0 II （绿盒）  1\r然后再拆一个快装板给他'),(22637,781124124001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','yanis_novikov','gespenst@inbox.ru','Yanis Novikov','Pantusovskaya,80','Kostroma','kostroma','RUSSIAN FEDERATION','156011','(915) 922-8596','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 11:36:46',0,NULL,3,1,11,1,'BJ01669897\r ',NULL),(22638,906332894016,260894475136,'New Twin Flash Bracket for Nikon D700 SB900 SB800 Canon 7D 5DII 580EX O-Shape',1,'AD1192',19.99,'hutongstore','ionesi','ioan@a-kabel.no','Ioan Hurjui','Marcus Thranesvei 92','Fjellhamar','Norwegen','NORWAY','1472','4790658899','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 11:53:19',0,NULL,3,1,21,1,'RA184530630CN\r ',NULL),(22639,781145739001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 12:54:20',0,NULL,3,1,17,0,NULL,NULL),(22640,781145292001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 12:54:20',0,NULL,3,1,5,1,'CP244548414CN ','大力夹云台  1 \r灯架  2m   2'),(22641,925463351015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','085ernestas','eerne92@yahoo.ie','ernestas ivanauskas','13the rise<br>college wood park','clane','Kildare','IRELAND','default','0851495923','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-12 13:09:31',0,NULL,3,1,21,1,'RA184530643CN\r ',NULL),(22642,781151355001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','valex1962','valexan62@gmail.com','Alexander Vasiliev','pr. Slavi<br>d. 60 kv.57','Saint-Petersburg','','RUSSIAN FEDERATION','192236','(812) 9493393','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-12 13:13:25',0,NULL,3,0,3,1,'RA184530586CN\r ','XXL 已入库 '),(22643,925470758015,250971425513,'Promotion ! NEW 3pcs Square Graduated ND2 ND4 ND8 Filter Kit for Cokin P Series',1,'AKT097',9.99,'hutongstore','norbert976','ncordina@onvol.net','Norbert Cordina','\'Capricorn\'<br>Mosta Road','Attard','','MALTA','BZN04','00356 99443984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 13:29:14',0,NULL,3,1,24,1,'30112266236\r ',' 134'),(22644,824948433002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jlribasgr','josep.ribas@gmail.com','Josep Lluís Ribas Gracia','Rambla Xavier Cugat 46, 3-3','GIRONA','Cataluña','SPAIN','17007','609449521','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 13:28:22',0,NULL,3,1,21,1,'RA184530657CN\r ',''),(22645,781172994001,110489671779,'NEW 62mm Snap-on Front Lens Cap for Nikon 62 Lenscap',1,'AA1306',2.6,'hermeshine','vmjcouch','v.mark.j.couch@citi.com','Mark Couch','176 Broadway<br>Apt 15A','New York','NY','UNITED STATES','10038-2518','(212) 276-5828','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-12 14:23:43',0,NULL,3,1,1,1,'LK178245370CN\r ',NULL),(22646,824996792002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','antonvh','antonvanhoek@live.nl','Anton van Hoek','Beukenlaan 2','Vinkel','','NETHERLANDS','5382JW','0646508977','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 14:39:51',0,NULL,3,1,21,1,'RA184530569CN\r ',NULL),(22647,781193347001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','vallone','vallonebras@gmail.com','DIVA VALLONE BRAZ','RUA ENÓTRIA, 89<br>TUCURUVI','SÃO PAULO','SÃO PAULO','BRAZIL','02309100','55 11 96236035','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 15:26:28',0,NULL,3,1,25,1,'RT124719298HK\r ','4节 '),(22648,925546645015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','artesbelas','duartemcbarros@yahoo.com','Duarte Barros','Rua Antero Henriques da Silva, Nº 891, 7º Andar','Guimarães','Braga','PORTUGAL','4810-026','964811220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 16:26:00',0,NULL,3,1,23,1,'BP04081201130001 ',NULL),(22649,825061679002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','brunorossete','contato@brunorossete.com.br','Bruno Rossete','Rua José Sebastião de Almeida, 250<br>Jardim ana Célia','São José do Rio Preto','São Paulo','BRAZIL','15045-560','+55 1791465807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:31:43',0,NULL,3,1,25,1,'RT124497415HK\r ',NULL),(22650,781252553001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',4,'AKT007',75.96,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 17:53:05',0,NULL,3,1,17,0,NULL,NULL),(22651,825072895002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',60,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-12 17:53:06',0,NULL,3,1,5,1,'CP244548428CN ','45w 5500k 灯泡 220v  8 \r115w 5500k 灯泡  220v   4\r申报$30'),(22652,781306798001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','chris_burry','burrychris@hotmail.com','Chris Burry','65 second Ave<br>p.o Box 1626','Wawa','ON','CANADA','P0S1K0','(705) 865-0693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 19:38:13',0,NULL,3,1,12,1,'3436009415\r ','美标\r110V  \r实重7.2  泡重8.8'),(22653,906558719016,260901272225,'New Camera protector case Neoprene bag for Nikon D200 D300s D700 XL',1,'AD1174',7.8,'hutongstore','pordicho64','pordicho@ono.com','Luis Gonzalo-Garcia','c/ Filipinas 13 pta.4','Valencia','Comunidad Valenciana','SPAIN','46006','616011055','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-12 19:44:38',0,NULL,3,1,2,1,'30112266192\r ',NULL),(22654,825133434002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','martinboivin','martyplay@videotron.ca','Martin Boivin','1357 boul de la morille','Quebec','QC','CANADA','g2k 2e9','(418) 914-1158','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 19:46:23',0,NULL,3,1,3,1,'RA184530590CN\r ',NULL),(22655,781345827001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','francoiscusson','francois_cusson@hotmail.com','Francois Cusson','5250 Riviera, Suite 105','Pierrefonds','QC','CANADA','H8Z 2H3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 20:51:39',0,NULL,3,0,11,1,'BJ01669899\r ','1.6*2.1  黑色 '),(22656,786312995018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',28.49,'photographyacc','pat792w','pft.woo@gmail.com','Patrick Woo','26 Balfour street','Lindfield','New South Wales','AUSTRALIA','2070','0298809770','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-12 21:07:49',0,NULL,3,1,3,1,'RA184530691CN\r ','XL 已入库 '),(22657,786350629018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','neeonee','femoeller@yahoo.com.au','Frank Moeller','20 Norfolk Esplanade','Caboolture','Queensland','AUSTRALIA','4510','0419160164','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-12 22:23:15',0,NULL,3,1,11,1,'BJ01669898\r ',NULL),(22658,781416862001,110702640488,'77mm 77 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3307',9.8,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:01',0,NULL,3,1,17,0,NULL,NULL),(22659,781416864001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:01',0,NULL,3,1,17,0,NULL,NULL),(22660,825244831002,120780395413,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',89.99,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:02',0,NULL,3,1,17,0,NULL,NULL),(22661,609173202003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:04',0,NULL,3,1,17,0,NULL,NULL),(22662,825244832002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:05',0,NULL,3,1,17,0,NULL,NULL),(22663,781416866001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','saltstudioas','leila@saltstudio.no','SALT Studio AS','Kipervikgt 26','Aalesund','NORWAY','NORWAY','6003','004799785000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-12 23:46:06',0,NULL,3,1,5,1,'CP244548405CN ','绿叶 UV  77mm  2 \r圆形柔光棚 60cm  1\r观鸟云台    1\r手动升降背景架    1\r反光板 60cm 2合1  1\r反光板  80cm 5合1    1'),(22664,781430309001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','mickeyniki_d79','mickeyniki@aol.com','Nicole Borth','3207 Colchester Rd','Lansing','MI','UNITED STATES','48906-3409','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 00:33:39',0,NULL,3,1,1,1,'LK167014137CN\r ',NULL),(22665,8881326417155168,111,'2m  灯架   1',1,'',0,'hutongstore','zak-zak-zak','m0522670797@gmail.com','zecharia liberman','nahal ein gedi 33/2','beit shemesh','beit shemesh','ISRAEL','99098','508288088',NULL,NULL,NULL,'2012-01-13 01:12:35',0,NULL,3,0,12,1,'3436009426\r ','从重量上看上次确实少发了一个，用dhl补给他 \r实重1.1  泡重1.48'),(22666,781453581001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','brianmustang904','lucky83@netzero.com','brian hunter','5147 Abel Ln','jacksonville','FL','UNITED STATES','32254-2903','(904) 382-4621','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 02:05:50',0,NULL,3,0,1,1,'LK177650977CN\r ','1.6*2.1  白色'),(22667,781454160001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',2,'AA2114',64,'hermeshine','radonja78','jomatkov@inet.hr','josko matkovic','Sv. Lovre 45','Stobrec','croatia','CROATIA','21311','0038521326405','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-13 02:06:04',0,NULL,8,1,17,0,NULL,'XL  已入库 '),(22668,781455557001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','radonja78','jomatkov@inet.hr','josko matkovic','Sv. Lovre 45','Stobrec','croatia','CROATIA','21311','0038521326405','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-13 02:10:32',0,NULL,3,1,21,1,'RA184530705CN\r ','摄影背心 黑色厚 无字 大小无特别标注为XL    3'),(22669,781462284001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','shkonst1979','shkonst@gmail.com','Konstantin Shishkin','Chekalina str. 18-1','Irkutsk','Irkutsk','RUSSIAN FEDERATION','664020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 02:34:05',0,NULL,3,1,11,1,'BJ01669900\r ',NULL),(22670,845674680017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.98,'photographyacc','1959jeh','jane@janehackettphotography.com','Jane Hackett','PO Box 9814','Frenchville','Queensland','AUSTRALIA','4701','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 02:55:37',0,NULL,3,1,11,1,'BJ01669903\r ',NULL),(22671,781471732001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','borismkri','krichevskiy@comcast.net','Boris Krichevskiy','1526 Birchmeadow Ln<br>Apt k-1526','San Jose','CA','UNITED STATES','95131-3722','(408) 718-1135','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-13 03:09:18',0,NULL,3,1,1,1,'LK178990844CN\r ',NULL),(22672,8881326425270679,111,'New Photo Studio Light Stand Umbrella Flash B-Mount set',1,'AKT014',42.99,'aliexpress','1006260358','bruno.kambara@gmail.com','Bruno Kambara	','R. Visconde de Nacar, 1200 - Apto 17','Curitiba','Parana','BRAZIL','80410201','+55 41 96563398',NULL,NULL,NULL,'2012-01-13 03:27:50',0,NULL,3,1,25,1,'RT124496321HK  ',''),(22673,781467871001,110625488411,'Green-L 52mm Graduated Neutral Density ND Grey Filter',1,'AA3315',5.95,'hermeshine','thylacine228','chris_tp1986@yahoo.com','Christopher Plummer','3/36 Augusta Road','Lenah Valley','Tasmania','AUSTRALIA','7008','0405284306','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 02:55:08',0,NULL,3,0,11,1,'BJ01669896\r ',NULL),(22674,8881326427523020,111,'1.6*2.1  灰色',1,'',0,'photographyacc','susanr7841','lindaegan61@hotmail.com','Susan Redmond','189 Grace Park Heights<br>Drumcondra','Dublin','','IRELAND','9','018375825',NULL,NULL,NULL,'2012-01-13 04:05:23',0,NULL,3,0,24,1,'30112268594\r ',NULL),(22675,781479172001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','eyen120819','c_phomphan@hotmail.com','chalermsak Phomphan','Rasisalai Agriculture Extension Office.<br>street Inthong','Rasisalai','SiSaKet','THAILAND','33160','66847285348','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 04:45:15',0,NULL,3,1,24,1,'30112299991\r ',NULL),(22676,786461425018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','paul.sims','paul.sims@bigpond.com','Paul Sims','20 Warragal Court<br>Andrews Farm','Adelaide','South Australia','AUSTRALIA','5114','0428150225','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 04:48:14',0,NULL,3,1,11,1,'BJ01669902\r ',NULL),(22677,845709678017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.9,'photographyacc','gumbie_86','interlopr@hotmail.com','Jordan Botterell','31 Regatta BVD','Wurtulla','Queensland','AUSTRALIA','4575','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 05:25:34',0,NULL,3,1,11,1,'BJ01669906\r ',NULL),(22678,786477208018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','rbetten74','rbetten74@hotmail.com','Rui Bettencourt','23 Maplewood Lane','ILDERTON','ON','CANADA','N0M 2A0','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-13 06:15:15',0,NULL,3,1,11,1,'BJ01669905\r ',NULL),(22679,825352131002,120343540553,'YONGNUO 16CH WIRELESS REMOTE CORD FOR SONY RM-S1AM',1,'AA3214',18,'hermeshine','kentbob65','kent65@live.com.au','kent lumsden','19 river oak dr','helensvale','Queensland','AUSTRALIA','4212','0755297581','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 08:19:29',0,NULL,3,1,11,1,' BJ01669889',NULL),(22680,776773085001,110587046983,'New Camera shoulder bag N2 for Canon with raincover',1,'AD1104',25.99,'hermeshine','ferencmester','vincze.feri@gmail.com','ferenc vincze','Tőkés út 53.','Karcag','Jász- Nagykun','HUNGARY','5300','06308547767','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-13 08:21:27',0,NULL,5,0,18,0,NULL,'缺货 换成1.6*3  绿色背景布了，退剩下的钱给他'),(22681,925965795015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','andreassoufis','andreassikkis@gmail.com','Andreas Sikkis','Georgiou pop 9','Athens','Attica','GREECE','11525','0030 6974334912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 09:31:42',0,NULL,3,1,17,0,NULL,NULL),(22682,925965973015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','andreassoufis','andreassikkis@gmail.com','Andreas Sikkis','Georgiou pop 9','Athens','Attica','GREECE','11525','0030 6974334912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 09:31:43',0,NULL,3,1,17,0,NULL,' '),(22683,925966233015,250932214604,'New Light Stand 80cm  / 32\" for back light studio',1,'AE3501',13,'hutongstore','andreassoufis','andreassikkis@gmail.com','Andreas Sikkis','Georgiou pop 9','Athens','Attica','GREECE','11525','0030 6974334912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 09:31:43',0,NULL,3,1,4,1,'YW867739203CN ','双灯头   1 \r5灯头+60-90棚   1\r灯架 84cm  1\r灯架  2m   1\r2 欧标\r补发一个四灯头\r和一个灯架底下的配件\r申报40\r\r'),(22684,781559774001,110718715286,'Soft Camera Bag Case Cover Canon EOS 5D ii + 24-105mm',1,'AD1214',12.99,'hermeshine','blia8499','liangbingyang@gmail.com','Bingyang Liang','3700 E Jewell Ave<br>Apt 504','Denver','CO','UNITED STATES','80210-3761','(303) 589-9862','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 10:33:03',0,NULL,3,1,1,1,NULL,NULL),(22685,781580474001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','den_boykov','den@boykov.me','Elena Boykova','B.Sherstneva 19 - 4','Vorkuta','Respublika Komi','RUSSIAN FEDERATION','169907','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 11:55:18',0,NULL,3,1,3,1,'RA184530855CN\r ','820g '),(22686,926005401015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','paanikki','paavo.nikkila@gmail.com','Paavo Nikkilä','Olkkolankatu 14 A 4','Mikkeli','','FINLAND','FI-50100','044 3203931','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 12:00:38',0,NULL,3,1,21,1,'RA184526286CN\r ',NULL),(22687,902259373016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',3,'AA1304',5.61,'hutongstore','jok-seller','jerome.brion@neuf.fr','BRION Jérôme','76 Avenue Jean JAURES','STRASBOURG','Alsace','FRANCE','67000','0628528907','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 12:28:45',0,NULL,3,1,11,1,NULL,NULL),(22688,926025928015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','diacdom','diacdom1@tin.it','Diacono Dr. Domenico','Via G.D\'Annunzio, 32','Colonnella','TE','ITALY','64010','+393479038243','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-13 12:50:56',0,NULL,3,1,4,1,'YW867739295CN ','2.7  已经补了配件了\r单号 RT126880980HK '),(22689,906916593016,260838264185,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',9,'hutongstore','oovaskai','mail@dboxi.fi','dBoxi, Olli Ovaskainen','Päivärinteentie 13 a7','Kerava','','FINLAND','04250','+358409101869','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-13 13:10:42',0,NULL,3,1,24,1,NULL,NULL),(22690,926057919015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','mhraposo','marco.raposo@netcabo.pt','Marco Raposo','Rua Fernando Lopes Graça, n 15 2esq','Lisbon','Lisbon','PORTUGAL','1600-067','(351) 968779278','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 13:54:03',0,NULL,3,1,21,1,'RA184526272CN\r ',NULL),(22691,825468095002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','gmzsur','cosasparafotos@gmail.com','Jose Antonio Gamez Mangas','C/ Ronda Sur  Nº 37<br>Valdelacalzada','Badajoz','Extremadura','SPAIN','06184','625622736','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 14:44:15',0,NULL,3,1,2,1,NULL,NULL),(22692,845895079017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',2,'AE1302',19.6,'photographyacc','mr_pum','pum@pum.org','Paul Holman','12 Rushout Avenue<br>Kenton','Harrow','Middlesex','UNITED KINGDOM','HA3 0AR','07785243452','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-13 16:09:32',0,NULL,3,1,11,1,NULL,'英标 '),(22693,786646625018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','chuchudiary','chair_5c_man@hotmail.com','Chi Man Clement  Chu','173/1 Brown St ,','Ashfield','New South Wales','AUSTRALIA','2131','0414798707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 16:16:07',0,NULL,8,1,17,0,NULL,NULL),(22694,786648576018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','chuchudiary','chair_5c_man@hotmail.com','Chi Man Clement  Chu','173/1 Brown St ,','Ashfield','New South Wales','AUSTRALIA','2131','0414798707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 16:20:40',0,NULL,8,1,17,0,NULL,NULL),(22695,786651991018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','chuchudiary','chair_5c_man@hotmail.com','Chi Man Clement  Chu','173/1 Brown St ,','Ashfield','New South Wales','AUSTRALIA','2131','0414798707','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-13 16:28:08',0,NULL,3,1,3,1,'RA184526119CN\r ','反光板支架的夹子（双轮）  2 \r斜臂    1'),(22696,825519668002,120587378716,'Photo Studio Background Support (7×7 ft)+ Free Backdrop',1,'AO0009',70.9,'hermeshine','azgek','azgekstock@gmail.com','Sergey Mostovoy','Nab. Pobedy str., 130/5/65','Dnepropetrovsk','Dnepropetrovsk','UKRAINE','49106','+380503169362','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-13 16:50:44',0,NULL,3,1,5,1,'CP244548365CN ','+1.6*2.1  白色布   '),(22697,926146834015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',4,'AKT007',51.96,'hutongstore','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 16:57:56',0,NULL,3,1,21,1,'RA184526290CN\r ','申报$20 \r8个'),(22698,825549667002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','burinbabe','derekdaphne@eastlink.ca','Daphne Roberts','19 Terraview Dr','Glovertown','NL','CANADA','A0G2L0','(709) 533-9721','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 17:56:19',0,NULL,3,1,3,1,' RA184530776CN\r',' '),(22699,609391218003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','differenteagle','ljubinkod@gmail.com','DIVNIC LJUBINKO','53 DIVIZIJE','DERVENTA','REPUBLIKA SRPSKA','BOSNIA AND HERZEGOVINA','74400','+38753834940','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 18:09:54',0,NULL,3,1,5,1,'CP244548357CN ',NULL),(22700,825565711002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','carlpan2000','carlpan2000@yahoo.com','Guang Pan','6119 10 Ave SW','Edmonton','AB','CANADA','T6X 0M3','(780) 932-5687','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 18:28:17',0,NULL,3,1,3,1,'RA184530780CN\r ',NULL),(22701,781737032001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','elibookie23','jjenaid@live.com','Daria BOwling','243 york st','gettysburg','PA','UNITED STATES','17325-1929','(717) 398-2013','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 18:50:10',0,NULL,3,0,1,1,NULL,'1.6*2.1  黑色 '),(22702,926264377015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','tabs4life','tab4lifes@gmail.com','Denis Vesely','Sevcenkova 19','Bratislava','','SLOVAK REPUBLIC','851 01','00421 908 636 785','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-13 20:04:22',0,NULL,3,1,21,1,'RA184526309CN\r ',NULL),(22703,926269006015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','marilosuamar','marilosm@ono.com','Marilo Suarez Martinez','calle Parque de Cazorla, 3, portal 18, 5ºb','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41015','696038905','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 20:13:49',0,NULL,3,1,2,1,NULL,NULL),(22704,781788448001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','mxvii17','jkaasine@gmail.com','Jussi Kaasinen','Sports Tracking Technologies Oy<br>Teollisuuskatu 21','Helsinki','FIN','FINLAND','00510','+358-50-523 4497','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-13 20:30:21',0,NULL,3,1,17,0,NULL,NULL),(22705,825639501002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','mxvii17','jkaasine@gmail.com','Jussi Kaasinen','Sports Tracking Technologies Oy<br>Teollisuuskatu 21','Helsinki','FIN','FINLAND','00510','+358-50-523 4497','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 20:53:41',0,NULL,3,1,4,1,'YW867739343CN ','灯架  2m  2  \r伞式柔光箱 60×90cm    1'),(22706,926300893015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','elena*emma','relena74@hotmail.com','Elena Rogovtsova','Ordjonikidze str.<br>28-93','Syktyvkar','Komi Republic','RUSSIAN FEDERATION','167000','88212-20-21-25','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 21:05:01',0,NULL,3,1,5,1,'CP244548207CN ','欧标 \r灯架  2m   1\r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）    1'),(22707,781805362001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.99,'hermeshine','marie123.719','secund82517@mypacks.net','connie pfost','PO Box 1253<br>908 7TH.','Limon','CO','UNITED STATES','80828-1253','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-13 21:07:51',0,NULL,3,1,1,1,NULL,NULL),(22708,825651230002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','ashleykukuk09','ashleykukuk@gmail.com','Ashley Kukuk','8960 michigamme rd','clarkston','MI','UNITED STATES','48348','(586) 530-8080','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-13 21:20:55',0,NULL,5,1,18,1,NULL,'货被退回来，发信问重发 还是退款\r客户已回复，退款'),(22709,926345924015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','tellag34','tellag@free.fr','GALLET Philippe','38, impase Andréa PALLADIO','MONTPELLIER','Languedoc-Roussillon','FRANCE','34070','06 31 01 82 38','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 22:26:51',0,NULL,8,1,17,0,NULL,NULL),(22710,926345926015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','tellag34','tellag@free.fr','GALLET Philippe','38, impase Andréa PALLADIO','MONTPELLIER','Languedoc-Roussillon','FRANCE','34070','06 31 01 82 38','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-13 22:26:52',0,NULL,3,1,11,1,NULL,'橡胶遮光罩 52mm  1 \r橡胶遮光罩 62mm    1'),(22711,781839401001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','marrikixox','marriki.schlifer@gmail.com','Marriki Schlifer','Apt 2 - 328 4th St.','New Westminster','BC','CANADA','V3L2T9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 22:30:33',0,NULL,3,1,3,1,'RA184530847CN\r ','110V '),(22712,781841135001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','*whatagem*','rgwarner@bigpond.com','Robert Cooke-Warner','PO Box 43','Seymour','Victoria','AUSTRALIA','3661','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 22:33:51',0,NULL,3,1,11,1,NULL,NULL),(22713,907220560016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','johnh8232','johnandjoyce@blueyonder.co.uk','John Holmes','12 Cherry Vale','Liverpool','Merseyside','UNITED KINGDOM','L255px','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-13 22:38:53',0,NULL,3,1,11,1,NULL,NULL),(22714,825709370002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','mjuanki73','jcleguey@hotmail.com','juan carlos leguey ferrández','pablo surra de garay 45','elche','Alicante','SPAIN','03205','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-13 23:48:33',0,NULL,3,1,2,1,NULL,NULL),(22715,907260397016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','fatimagirl','clairejfinn@hotmail.com','Claire  Finn','51 Quinton Road West','Birmingham','West Midlands','UNITED KINGDOM','B322QB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 00:19:05',0,NULL,3,1,3,1,'RA184530833CN\r ',NULL),(22716,781914807001,110807099999,'Promotion ! NEW 3pcs Square Graduated ND2 ND4 ND8 Filter Kit for Cokin P Series',1,'AKT097',13.88,'hermeshine','lpnan','obk6260@gmail.com','ooi bkai','7, Cangkat Minden Lorong 6,<br>11700 Gelugor, Penang.','Gelugor','Penang','MALAYSIA','11700','012-5856674','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 03:08:36',0,NULL,3,1,2,1,NULL,'192G\r '),(22717,781922686001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mikewbbal','hcwilmot14@gmail.com','Micheal Wilmot','21 Horseshoe Dr','Townsend','MA','UNITED STATES','01474-1058','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-14 04:02:18',0,NULL,3,0,1,1,NULL,'1.6*2.1   黑色 '),(22718,926485191015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','bilalshah1','bilalshah1@aol.com','Bilal Shah','45 Tildsley Street','Bolton','Lancashire','UNITED KINGDOM','BL3 6PN','07833946045','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 06:06:38',0,NULL,3,0,3,1,'RA184530820CN\r ','L （已入库）'),(22719,825804967002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','gr0m03eka','austyancev@mail.ru','Alexander Ustyantsev','Trubnaya, 11b-26','Kamensk-Uralsky','RU','RUSSIAN FEDERATION','623401','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 06:59:39',0,NULL,3,1,3,1,'RA184530816CN\r ',NULL),(22720,926320594015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',65,'hutongstore','coonferret','lespetitsbouddha@gmail.com','magali grun','3 rue de la petite lissey','lissey la petite','Lorraine','FRANCE','55150','0355090011','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 07:35:04',0,NULL,3,1,4,1,' ','欧标 \r实重4.6  泡重 5.9'),(22721,846232823017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',39,'photographyacc','allnamesgonealready','markcbeattie@hotmail.com','Mark BEATTIE','52 Tugun St','Tugun','Queensland','AUSTRALIA','4224','0429182489','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-14 07:37:40',0,NULL,3,1,3,1,'RA184526051CN\r ','澳标 '),(22722,781964263001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','frollojpn','rasufi@mac.com','Raul Suarez','3-60 Era cho','Hyuga','Miyazaki','JAPAN','883-0012','(09)8296 0187','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 07:46:46',0,NULL,3,1,11,1,NULL,NULL),(22723,781965446001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',7.8,'hermeshine','jademina','gypsi_fyre@yahoo.com','Kate Ahokas','12326 Bannock St<br>Unit 13102','Westminster','CO','UNITED STATES','80234-2154','(978) 835-1340','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-14 07:53:08',0,NULL,8,1,17,0,NULL,NULL),(22724,825813883002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',8.99,'hermeshine','jademina','gypsi_fyre@yahoo.com','Kate Ahokas','12326 Bannock St<br>Unit 13102','Westminster','CO','UNITED STATES','80234-2154','(978) 835-1340','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-14 07:53:09',0,NULL,3,1,1,1,' ','3片装的滤镜袋   2 \r新款内胆包 M  Nikon     1'),(22725,846241496017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','narnian99','martinvisser99@gmail.com','Martin Visser','99 Sunrise Road','Yerrinbool','New South Wales','AUSTRALIA','2575','0248839495','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-14 08:22:00',0,NULL,3,1,11,1,NULL,NULL),(22726,846277073017,270744172268,'58mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT020',4.19,'photographyacc','trevandtam','tatclarke1@bigpond.com','Trevor Clarke','315 Crestwood Drive','Port Macquarie','New South Wales','AUSTRALIA','2444','0265825865','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-14 10:30:29',0,NULL,3,1,2,1,NULL,NULL),(22727,926559373015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','bishcred','debbieinlondon@yahoo.co.uk','Chris Walser','29 Onslow Gardens','Chipping Ongar','Essex','UNITED KINGDOM','CM5 9BG','01277365992','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 10:44:27',0,NULL,3,1,11,1,NULL,NULL),(22728,782016102001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','arrkart','aridany@gmail.com','Aridany Ramirez Rodriguez','Calle Isabel Macario Brito Soprano, Numero 7, Piso 4, Puerta C','Las Palmas de Gran Canaria','Canarias','SPAIN','35018','649055805','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 11:25:24',0,NULL,3,1,21,1,'RA184534282CN\r ',NULL),(22729,782048992001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','reite09','espen_reite@hotmail.com','Espen Reite','Karlsebakken 33B','Tønsberg','','NORWAY','3113','(47)92437502','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 13:05:47',0,NULL,3,1,22,1,NULL,NULL),(22730,782072343001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',2,'AD1195',58,'hermeshine','ost-video','a.ostryanin@gmail.com','Artemij Ostryanin','ul.Kalinina d.79b, kv.111','Tula','Tulskaya','RUSSIAN FEDERATION','300040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 14:10:32',0,NULL,3,1,3,1,'RA184526048CN\r ',NULL),(22731,614964637004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','joniadark2012','joniadark@gmail.com','Yevgeniy Davydov','Severnaya street 24 kv.34','Odintsovo','Moskovskaya Oblast','RUSSIAN FEDERATION','143000',' 89265790482','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 14:50:49',0,NULL,3,1,11,1,'BJ01669887 ',NULL),(22732,825944475002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','kkha2916','director.cupoftea@gmail.com','Anamul Haque','Flat 40 pemell house<br>pemell close','london','London','UNITED KINGDOM','E1 4JY','07908287521','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 15:05:18',0,NULL,3,1,3,1,'RA184526198CN\r ','英标 '),(22733,825955271002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','dawidow79','dawidoww@yandex.ru','Aleksey Davidov','Severniy 2-133','Stariy Oskol','Belgorodskaja','RUSSIAN FEDERATION','309516','79803287273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 15:28:53',0,NULL,3,1,3,1,'RA184526388CN\r ','应该是黑色 '),(22734,926672203015,250871319692,'New filter box for 10 pcs P Series Cokin filters holder',1,'AD1170',5.95,'hutongstore','tony230753131067','tmills@milmor.co.uk','Anthony Mills','4 Reid Avenue<br>Short Heath','Willenhall','West Midlands','UNITED KINGDOM','wv12 5pq','01922478353','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-14 15:02:49',0,NULL,3,1,11,1,NULL,NULL),(22735,926705797015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','elena*emma','relena74@hotmail.com','Elena Rogovtsova','Ordjonikidze str.<br>28-93','Syktyvkar','Komi Republic','RUSSIAN FEDERATION','167000','88212-20-21-25','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 16:04:32',0,NULL,3,1,17,0,NULL,NULL),(22736,907580639016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',9.99,'hutongstore','furre85','ufos85@gmail.com','Jonas Hansson','Bodekullsgatan 34 A','Malmö','Skåne','SWEDEN','214 40','0708511622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 16:20:51',0,NULL,3,1,21,1,'RA184526215CN\r ','新款大力夹（手柄）   1 \r铝合金灯座（N）       1'),(22737,926723445015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dutch_43','erwin.degruil@gmail.com','Erwin de Gruil','Suborni 16 A 29','Varna','','BULGARIA','9000','++359 (0)885 088899','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-14 16:36:10',0,NULL,3,1,21,1,'RA184526224CN\r ',NULL),(22738,926752924015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','trusteuk','jokehole@gmail.com','James Leung','Triple Point Technology, 6th Floor<br>24 Chiswell Street','London','London','UNITED KINGDOM','EC1Y 4TY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 17:17:21',0,NULL,3,0,3,1,'RA184526034CN\r ',NULL),(22739,907626622016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','kasia_ii','kasia.kruczkowski@gmail.com','BüSo- Kruczkowski','Altenessener Str. 289','Essen/Ruhr','','GERMANY','45326','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-14 17:33:21',0,NULL,3,1,12,1,'2100867635 ','欧标 \r实重7.2 泡重9.2\r\r'),(22740,782155096001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','lobachi','lobachi88@gmail.com','Pugachev Sergey','Pugachev Sergey<br>ul.Kutuzovskaya, dom 1','Novorossiysk','Krasnodarskiy kray','RUSSIAN FEDERATION','353907','9626267076','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 17:33:52',0,NULL,3,1,11,1,NULL,NULL),(22741,781207663001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','faronwest','andrewshapter@gmail.com','william a shapter','1401 Kenwood Ave','austin','TX','UNITED STATES','78704-2624','(310) 936-1122','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-01-14 17:48:03',0,NULL,3,1,4,1,'YW867739332CN ',NULL),(22742,926789314015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','lee_uk34','leeman30@hotmail.com','Lee Restarick','2 Smithsbarn Farm<br>Comptons Lane','Horsham','West Sussex','UNITED KINGDOM','RH13 5NN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 18:14:07',0,NULL,3,1,11,1,NULL,NULL),(22743,926775417015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','beanie_beanieboy','beanieboy@tiscali.co.uk','John K Bean','22 The Willows','Frodsham','Cheshire','UNITED KINGDOM','WA6 7QS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 18:23:24',0,NULL,3,1,3,1,'RA184526025CN\r ',NULL),(22744,782193090001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',1,'AA1202',2.48,'hermeshine','artbalans2010','artbalans@gmail.com','Leonid Bergman','Borisovskie prudy ylitsa<br>dom 8 korpus 1 kvartira. 243','Moscow','','RUSSIAN FEDERATION','115211','+79269819933','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 18:23:52',0,NULL,8,1,17,0,NULL,NULL),(22745,782193091001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','artbalans2010','artbalans@gmail.com','Leonid Bergman','Borisovskie prudy ylitsa<br>dom 8 korpus 1 kvartira. 243','Moscow','','RUSSIAN FEDERATION','115211','+79269819933','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 18:23:53',0,NULL,8,1,17,0,NULL,NULL),(22746,826048050002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','artbalans2010','artbalans@gmail.com','Leonid Bergman','Borisovskie prudy ylitsa<br>dom 8 korpus 1 kvartira. 243','Moscow','','RUSSIAN FEDERATION','115211','+79269819933','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-14 18:23:56',0,NULL,8,1,17,0,NULL,NULL),(22747,782193093001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','artbalans2010','artbalans@gmail.com','Leonid Bergman','Borisovskie prudy ylitsa<br>dom 8 korpus 1 kvartira. 243','Moscow','','RUSSIAN FEDERATION','115211','+79269819933','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 18:23:57',0,NULL,8,1,17,0,NULL,NULL),(22748,826048051002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','artbalans2010','artbalans@gmail.com','Leonid Bergman','Borisovskie prudy ylitsa<br>dom 8 korpus 1 kvartira. 243','Moscow','','RUSSIAN FEDERATION','115211','+79269819933','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-14 18:23:58',0,NULL,3,0,3,1,'RA184526207CN\r ','眼罩 40D/50D   1\r小号灰卡    1\r爵影碗罩P4   1\r帽子 canon    1\r摄影背心 Canon  老款    XXXL    1  ( 已入库）\r\r '),(22749,826075382002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','burton750207','steve_windt@hotmail.com','Steven de Windt','Laurierstraat 116','Den Haag','','NETHERLANDS','2563SK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:08:38',0,NULL,8,0,17,0,NULL,NULL),(22750,826075384002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','burton750207','steve_windt@hotmail.com','Steven de Windt','Laurierstraat 116','Den Haag','','NETHERLANDS','2563SK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:08:38',0,NULL,8,0,17,0,NULL,NULL),(22751,782219624001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','burton750207','steve_windt@hotmail.com','Steven de Windt','Laurierstraat 116','Den Haag','','NETHERLANDS','2563SK','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:08:39',0,NULL,3,1,21,1,'RA184526238CN\r ','闪光灯B座    1\r伞式柔光箱 80cm 8角     1\r110cm 两用伞     1\r '),(22752,907703233016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','thomasfredejessen','mail@thomasjessen.dk','Thomas Jessen','St. Byhavevej 52','Svendborg','Denmark','DENMARK','5700','(0045) 22968037','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-14 19:18:59',0,NULL,3,1,22,1,NULL,NULL),(22753,782235079001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','shs-records1','shs-records@yandex.ru','Mihail Shahov','Srednya 11 kv 3','Vologda','Vologodskaya oblast','RUSSIAN FEDERATION','160002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:36:52',0,NULL,3,1,11,1,NULL,NULL),(22754,826089573002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','fjmoralessanz','fjmoralessanz@telefonica.net','Francisco Javier Morales Sanz','C/ Cebrián, nº 18. 3º.','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:37:28',0,NULL,3,1,17,0,NULL,NULL),(22755,826089238002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','fjmoralessanz','fjmoralessanz@telefonica.net','Francisco Javier Morales Sanz','C/ Cebrián, nº 18. 3º.','Las Palmas de Gran Canaria','Las Palmas','SPAIN','35003','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 19:37:29',0,NULL,3,1,4,1,'YW867739321CN ','2mx1.5m 背景板（黑，白）    1 \r2B柔    2\r一票两件'),(22756,782243890001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','seybeau60','ericseye@videotron.ca','eric seynave','261 rue arcand','lavaltrie','QC','CANADA','j5t2w7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-14 19:54:49',0,NULL,3,0,3,1,' RA184526017CN\r','XXXL  ( 已入库） \r\r572g\r'),(22757,907745967016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','freeraphaelite','boydhowdle@yahoo.co.uk','Boyd Howdle','144 Maney Hill Road','Sutton Coldfield','West Midlands','UNITED KINGDOM','B72 1JU','01212404787','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-14 20:24:46',0,NULL,3,1,3,1,'RA184530762CN\r ','473g '),(22758,782302211001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','hlaz212','hlaz212@yahoo.com','Hassan Lazrag','1 allée Jacques Offenbach','Suresnes','Ile de France','FRANCE','92150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 21:53:59',0,NULL,3,1,4,1,'YW867739262CN ',NULL),(22759,926962747015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','urmo.ee','bussekas@gmail.com','Urmo Luts','Kähriku tee 2','Muraste küla','Harjumaa','ESTONIA','76905','+37256961569','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-14 22:34:41',0,NULL,3,1,21,1,'RA184526241CN\r ',NULL),(22760,926964512015,250599953036,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',38.99,'hutongstore','doohx','volumen@hotmail.com','Jamil Ceballos','Av. Barcelona 91-A 3º 2ª','Barcelona','Santa Perpetua de Mogoda','SPAIN','08130','93-574-0868','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-14 22:38:04',0,NULL,3,1,4,1,'YW867739310CN ',NULL),(22761,782332432001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','dimamiparis','vesnine@cyberexpert.net','CyberExpert / M. Vesnine Dmitri','19 rue Albert de Mun','Asnieres sur Seine','Ile-de-France','FRANCE','92600','06.33.25.91.17','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-14 23:13:05',0,NULL,8,1,17,0,NULL,NULL),(22762,846653170017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','calypso4858','suzibonning@hotmail.co.uk','Susan Bonning','19 St, Marys Drive','Rhyl','Denbighshire','UNITED KINGDOM','LL18 2LG','07880704889','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-14 23:27:51',0,NULL,3,1,11,1,NULL,NULL),(22763,826199942002,120451748471,'YN462 YN-462 Flash Speedlite for Canon 450D 400D 350D ',2,'AB3305',63.6,'hermeshine','dimamiparis','vesnine@cyberexpert.net','CyberExpert / M. Vesnine Dmitri','19 rue Albert de Mun','Asnieres sur Seine','Ile-de-France','FRANCE','92600','06.33.25.91.17','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-14 23:30:03',0,NULL,5,0,18,0,NULL,NULL),(22764,782342742001,110469599873,'Photo Video Light Stands Studio Photo Stand 7ft 200cm',2,'AE3401',56,'hermeshine','dimamiparis','vesnine@cyberexpert.net','CyberExpert / M. Vesnine Dmitri','19 rue Albert de Mun','Asnieres sur Seine','Ile-de-France','FRANCE','92600','06.33.25.91.17','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-14 23:39:43',0,NULL,3,1,17,0,NULL,NULL),(22765,826204300002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',97.98,'hermeshine','dimamiparis','vesnine@cyberexpert.net','CyberExpert / M. Vesnine Dmitri','19 rue Albert de Mun','Asnieres sur Seine','Ile-de-France','FRANCE','92600','06.33.25.91.17','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-14 23:42:25',0,NULL,3,1,4,1,'YW867739225CN ','2m 灯架   3\r斜臂          1\r闪光的柔光箱   60cm   2\r圆形柔光棚 50cm  1\r '),(22766,787370102018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','phoodphreak53','philkeech@iinet.net.au','Philip Keech','3 Gayton Close','Warners Bay','New South Wales','AUSTRALIA','2282','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-14 23:53:38',0,NULL,3,1,4,1,'YW867739354CN ',NULL),(22767,826226733002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','duv-3','duv411@comcast.net','Duveuil valcena','126 SW 5th Ave','delray beach','FL','UNITED STATES','33444-2514','(561) 900-4600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 00:52:47',0,NULL,8,1,17,0,NULL,' '),(22768,826226735002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','duv-3','duv411@comcast.net','Duveuil valcena','126 SW 5th Ave','delray beach','FL','UNITED STATES','33444-2514','(561) 900-4600','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 00:52:48',0,NULL,3,1,21,1,'RA184526255CN\r ','永诺 SF17- NIKON SB800   1 \r伞式柔光箱 80cm 8角      2'),(22769,782382363001,110597978809,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',10,'hermeshine','haniers','hebalers@gmail.com','Hani E','Reinier de Graafweg 188','DELFT','','NETHERLANDS','2625DE','0619330049','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-15 01:59:14',0,NULL,3,1,22,1,NULL,NULL),(22770,787420080018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','alexlillian','piriatb@optusnet.com.au','Boris Piriatinski','4 Moon St','BRIGHTON EAST','Victoria','AUSTRALIA','3187','61413875053','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-01-15 02:44:18',0,NULL,3,1,4,1,'YW867739273CN ','白+黑 '),(22771,826277957002,120601700098,'New Camera bag fit 1 canon and 2-3 lenses upto 80-200mm',1,'AD1101',29.99,'hermeshine','efrijan2011','efrijan@yandex.ru','Дмитрий Воронов','улица Сады, дом 6, ква. 64','Красноярск','','RUSSIAN FEDERATION','660130','(905)0868006','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 04:02:41',0,NULL,3,1,3,1,'RA184526105CN\r ',NULL),(22772,826294428002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','battie23','batmaster@optusnet.com.au','Colin Wainwright','P.O Box 210','Warilla','New South Wales','AUSTRALIA','2528','0242969974','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 05:21:15',0,NULL,3,1,2,1,NULL,NULL),(22773,826295336002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','tkbrise','moninpungyosmonyrath@ymail.com','Moninpung Yosmonyrath','2/6, Atlantic street','Clayton','Victoria','AUSTRALIA','3168','0450201330','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 05:27:04',0,NULL,3,1,11,1,NULL,NULL),(22774,907962372016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','cms1706','colby.may@westnet.com.au','Colby McGuire','PO Box 310','Wickham','Western Australia','AUSTRALIA','6720','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 06:16:45',0,NULL,3,1,11,1,NULL,NULL),(22775,787465106018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','jungleclown','jungleclown@yahoo.com.au','steven Turnbull','14 burton close','Cairns','Queensland','AUSTRALIA','4870','0740335659','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-15 06:16:50',0,NULL,3,1,3,1,'RA184526096CN\r ',NULL),(22776,787465584018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',34.99,'photographyacc','arturocarras','arturo.carrasco@gmail.com','Arturo Carrasco Ruiz','C/ Antonio Diaz Canabate, 26','Azuqueca de Henares-Guadalajara','Castilla-La Mancha','SPAIN','19200','605091872','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-15 06:20:28',0,NULL,3,1,21,1,'RA184526391CN\r ',NULL),(22777,8881326611163037,111,'ew-73b',1,'A3408',0,'hermeshine','erifnonam09','vonrimsskela@hotmail.com','Aleksander Smirnov','2616 Whitehall Ter<br>Apt 102','Louisville','KY','UNITED STATES','40220-6033','(502) 759-4488',NULL,NULL,NULL,'2012-01-15 07:06:03',0,NULL,3,1,1,1,NULL,'仔细检查一下遮光罩的质量 \r上一个logo印的不好\rLK033100046CN'),(22778,826314382002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','tommy2240','tomjahn@telus.net','tom jahn','18971-87a ave','surrey','BC','CANADA','v4n6e4','(604) 881-0340','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 07:20:14',0,NULL,3,1,3,1,'RA184526082CN\r ',NULL),(22779,787481700018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','aussieshutterbug','aussieshutterbug@virginbroadband.com.au','Paulus S. Tjahjadi','9/52 Victoria Street<br>(No Through Road)','Werrington','New South Wales','AUSTRALIA','2747','61403666760','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-15 07:53:15',0,NULL,3,1,3,1,'RA184526079CN\r ',NULL),(22783,826419782002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','kos-tin','gdoosik@yandex.ru','Евгений Костин','Ул.Нижняя Дуброва, д.37А, кв.63','г. Владимир','','RUSSIAN FEDERATION','600037','8 904 958 01 21','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 12:43:09',0,NULL,3,1,11,1,NULL,NULL),(22780,908047515016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','michaldnb','michal@breakbeat.sk','Michal Cvik','6<br>Hyperion Walk','Horley','Surrey','UNITED KINGDOM','RH6 7DA','07747194873','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 10:39:06',0,NULL,3,1,2,1,NULL,NULL),(22781,908073313016,260675928086,'New Small Camera bag lens case D2 for Canon 500D 450D',1,'AO0033',5,'hutongstore','larchfieldman','rjhcor@aol.com','James Coard','The Laurels<br>376 Upper Ballynahinch Road','Lisburn','Antrim','UNITED KINGDOM','BT27 6XL','07817077947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 11:16:26',0,NULL,5,0,18,0,NULL,'没有货了，已经发信问了退钱给他\r已经退钱了 '),(22782,927218682015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',126,'hutongstore','supermaclou','mike.baudoncq@gmail.com','Mike Baudoncq','6 impasse des Lavandières<br>L.D. Loulappe','St Luperce','Centre','FRANCE','28190','0682843397','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 11:27:47',0,NULL,3,1,4,1,'YW867739365CN ',NULL),(22784,826435943002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','terrold051548','tpayne2381@charter.net','Terrold Payne','1417 Beaumont Ave','Maryville','TN','UNITED STATES','37803','(865) 984-2381','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-15 13:17:44',0,NULL,3,1,1,1,NULL,NULL),(22785,927224661015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.68,'hutongstore','eaglebeagleandy','andy.barley@googlemail.com','andy barley','44 methersgate','basildon','Essex','UNITED KINGDOM','ss14 2lt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 13:23:10',0,NULL,3,1,11,1,NULL,NULL),(22786,908147242016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','joegrech1','joe@joegrech.com','Joe Grech','Ave Marija, St Leonard Str<br>Xewkija','Gozo - Malta','','MALTA','XWK 9073','+35699268784','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-15 13:34:56',0,NULL,3,1,22,1,NULL,NULL),(22787,787613231018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','marcopcovo','marcopcovo@gmail.com','Marco Costa / Carin Weitzenbaur','Rua Professor Machado Macedo nº33 - 1º Esquerdo','Ponta Delgada','SAO MIGUEL - AZORES','PORTUGAL','9500-700','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-15 13:35:54',0,NULL,5,0,18,0,NULL,NULL),(22788,826449485002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','yizzer','k.valdez26@hotmail.com','Karl Valdez','60 Jindabyne circuit woodcroft','Sydney','New South Wales','AUSTRALIA','2767','0296761729','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 13:46:51',0,NULL,3,1,11,1,NULL,NULL),(22789,927324692015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','*supamatt*','matt@nlr-online.co.uk','Matt Killen','40 Tunfield Road','Hoddesdon','Hertfordshire','UNITED KINGDOM','EN119LG','07740339262','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 14:33:46',0,NULL,3,1,3,1,'RA184526065CN\r ',NULL),(22790,927311403015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','2628.john-nyberg','kontakt@ispil.dk','John Nyberg','sallingvej 55, 2.tv.','Vanloese','','DENMARK','2720','+45 20892628','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 14:13:10',0,NULL,3,1,21,1,'RA184526405CN\r ',NULL),(22791,782610035001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','bargainus','amerikatz@gmail.com','Sean Park','1350 66th St','Brooklyn','NY','UNITED STATES','11219-6131','(718) 837-4937','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 14:45:15',0,NULL,3,1,1,1,NULL,NULL),(22792,846960007017,270742403077,'New IR Wireless Remote Control for Pentax Canon Nikon ',1,'AA2205',3.5,'photographyacc','spasso661215','bond661215@aol.com','sungkyun kang','4549 Vauxhall Rd','Richmond','VA','UNITED STATES','23234-3556','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-15 14:54:04',0,NULL,3,1,1,1,NULL,NULL),(22793,782641180001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',2,'AD1218',7,'hermeshine','holophonics','headinfo@gmail.com','Vladimir Troshin','Raspletina 3/3/84','Moscow','RU','RUSSIAN FEDERATION','123060','+79267224133','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 15:41:11',0,NULL,3,1,17,0,NULL,NULL),(22794,782641181001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',2,'AD1220',7,'hermeshine','holophonics','headinfo@gmail.com','Vladimir Troshin','Raspletina 3/3/84','Moscow','RU','RUSSIAN FEDERATION','123060','+79267224133','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 15:41:12',0,NULL,3,1,11,1,' ','无牌方镜 渐变灰 （nd2） 2\r无牌方镜 渐变灰 （nd8）   2\r189g\r '),(22795,782659873001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','c12h24o11','georgi969@gmail.com','Georgi Ivanov','k-s Slaveikov . bl 42 vh8 et 7 ap 21','Burgas','Burgas','BULGARIA','8000',' 359887947514','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 16:11:33',0,NULL,3,1,24,1,NULL,NULL),(22796,782687540001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','nikolaos19','nicyak@gmail.com','Nikolaos Giakoumakis','Chalkidikis 35, Votanikos','Athens','Greece','GREECE','10447','+306945003243','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 16:59:06',0,NULL,3,1,21,1,'RA184526312CN\r ',NULL),(22797,782694774001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','andrew.axe','ebay.axe@gmail.com','Andrew Altukhov','Dushenova st. 10-68','Severomorsk','Murmanskaya obl','RUSSIAN FEDERATION','184606','7921-2730076','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 16:59:16',0,NULL,3,1,3,1,'RA184526153CN\r ',NULL),(22798,927485706015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','jamfotos','jamfotos@eresmas.com','Jose Antonio Macias Navarro','C/ Ocho de Marzo 18 - 2C','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41006','630066032','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 17:44:50',0,NULL,3,1,21,1,'RA184526326CN\r ','申报 $20 '),(22799,782736891001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','greg5208greg','greg5208@aol.com','greg gist','51 Poplar St','Bangor','ME','UNITED STATES','04401-3416','(207) 356-0375','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-15 17:52:58',0,NULL,3,1,1,1,NULL,NULL),(22800,826628838002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','mandiars','helbasani@academicurology.com','Hasen Elbasani','188 Crum Creek Dr','woodlyn','PA','UNITED STATES','19094-1907','(610) 986-5083','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-15 18:12:35',0,NULL,3,1,1,1,NULL,NULL),(22801,927524427015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','scar_blaze','scarblaze@yandex.ru','Роман Стратан','ул. Набережная реки Магаданки 87 квартира 45','Магадан','Магаданская область','RUSSIAN FEDERATION','685000','89148566371','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 18:17:22',0,NULL,3,1,3,1,'RA184526184CN\r ',NULL),(22802,826632031002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','srjois2011','sr-jois@rambler.ru','Shorikov Vladimir V.','Building №1522, apartment № 58','Moscow, Zelenograd','Russian Federation','RUSSIAN FEDERATION','124683','+7-499-733-38-85','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:23:14',0,NULL,3,1,11,1,NULL,NULL),(22803,927534742015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','guihur1','vincent.guihur@free.fr','GUIHUR Vincent','Les Croix','SIXT SUR AFF','Bretagne','FRANCE','35550','06.22.03.53.81','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 18:24:45',0,NULL,3,1,3,1,'RA184526122CN\r ',NULL),(22804,782774059001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','jw.qc','j.waller@videotron.ca','John Waller','311-1200 E - av. Laurier<br>(code interphone = 33)','MONTREAL','QC','CANADA','H2J 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:31:13',0,NULL,8,1,17,0,NULL,NULL),(22805,782772817001,110718715286,'Soft Camera Bag Case Cover Canon EOS 5D ii + 24-105mm',1,'AD1214',12.99,'hermeshine','jw.qc','j.waller@videotron.ca','John Waller','311-1200 E - av. Laurier<br>(code interphone = 33)','MONTREAL','QC','CANADA','H2J 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:31:14',0,NULL,8,1,17,0,NULL,NULL),(22806,782773732001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','jw.qc','j.waller@videotron.ca','John Waller','311-1200 E - av. Laurier<br>(code interphone = 33)','MONTREAL','QC','CANADA','H2J 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:31:15',0,NULL,8,1,17,0,NULL,NULL),(22807,782773393001,110526978662,'58mm 58 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3303',3.55,'hermeshine','jw.qc','j.waller@videotron.ca','John Waller','311-1200 E - av. Laurier<br>(code interphone = 33)','MONTREAL','QC','CANADA','H2J 1G9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:31:15',0,NULL,3,1,3,1,'RA184526140CN\r ','2mx1.5m 白色背景板   1 \r新款内胆包 XL  Canon     1\r热靴保护盖  普通   1\r绿叶 UV  58mm   1'),(22808,782803533001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mbmoh93160','mbmoh93@gmail.com','Mohamed Bouchadekh','2, place Eugène Thomas','NOISY LE GRAND','Ile-de-France','FRANCE','93160','0615090560','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 18:59:25',0,NULL,3,1,3,1,'RA184526175CN\r ','2个 '),(22809,782824899001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ptgslo','modlar@yahoo.com','Peter  CERNIC','ULICA JANEZA PAVLA II  -  14','LJUBLJANA','SLOVENIA','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 19:17:39',0,NULL,3,1,21,1,'RA184526330CN\r ',NULL),(22810,826717163002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','ftdeajos','estebanyelu@yahoo.es','Esteban Belinchón Sánchez','C/ Aragón,3-3º dcha<br>Toledo','Toledo','Castilla-La Mancha','SPAIN','45005','925623243','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 19:36:51',0,NULL,3,1,2,1,NULL,NULL),(22811,908484292016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','top_bitz_uk','top_bitz_uk@blueyonder.co.uk','mark NICHOL','84 belle vue road<br>southchurch','southend on sea','Essex','UNITED KINGDOM','ss2 4jf','07939505621','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-15 19:39:59',0,NULL,3,1,11,1,NULL,NULL),(22812,826734223002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','monciciatko2903','monciciatko@gmail.com','Verlag Dashofer - Moni Kunovska','Zelezniciarska  13','Bratislava','SLOVAKIA','SLOVAK REPUBLIC','81499/323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 19:53:27',0,NULL,3,1,21,1,'RA184526343CN\r ',NULL),(22813,908503437016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','furre85','ufos85@gmail.com','Jonas Hansson','Bodekullsgatan 34 A','Malmö','Skåne','SWEDEN','214 40','0708511622','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-15 19:57:37',0,NULL,3,1,17,0,NULL,NULL),(22814,826776800002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','beauhel','beahel@ebuyclub.com','Hélène Beauudin','BL1, 22 allée des frères Voisin','Paris','Ile-de-France','FRANCE','75015','0661988364','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 20:41:46',0,NULL,3,1,3,1,'RA184526136CN\r ',NULL),(22815,927697832015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','gradwar','glenvideodagbok@hotmail.com','Gustav Aldin','Liljegatan 4D','Uppsala','Uppland','SWEDEN','75324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 20:50:38',0,NULL,3,1,21,1,'RA184526414CN ',' 泡重2.1  实重1.65'),(22816,826807141002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','istomkino','titov-f1a@yandex.ru','Yury Titov','Babushkina str, house 8, flat 1','Noginsk','Moscow region','RUSSIAN FEDERATION','142407','(916) 1349027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 21:23:08',0,NULL,3,1,11,1,NULL,NULL),(22817,782939619001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','joao_andre','andregoncalves87@gmail.com','Andre Gonçalves','Estrada do Pedregal CCI 303<br>Sitio do Pedregal','Funchal','Madeira','PORTUGAL','9350-033','964177794','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 21:37:49',0,NULL,5,0,18,0,NULL,NULL),(22818,826838407002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','lukkoyeole','ole.a.nylund@gmail.com','Ole-Andreas Nylund','Nygårdsplatået 25','Finnsnes','Troms','NORWAY','9300','41444973','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 22:17:33',0,NULL,3,1,17,0,NULL,NULL),(22819,782961299001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','lukkoyeole','ole.a.nylund@gmail.com','Ole-Andreas Nylund','Nygårdsplatået 25','Finnsnes','Troms','NORWAY','9300','41444973','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 22:18:51',0,NULL,3,1,5,1,'CP244548388CN ','灯架  2m  1\r斜臂    1\r闪光的柔光箱   60cm   1\r小号灰卡   1\r '),(22820,927786213015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','lmahy','lma@sema-co.com','Laurent Mahy / CSC Data Centre','12 D Impasse Drosbach - Cloche d\'Or<br>CSC Datacentre','Luxembourg (Lëtzebuerg)','LUXEMBOURG','LUXEMBOURG','L-1882','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 22:28:29',0,NULL,3,1,22,1,NULL,NULL),(22821,615624590004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','hersheyi','hersheyti@gmail.com','Ivanka Hershey','2249 Regina Dr','Clarksburg','MD','UNITED STATES','20871-8527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 22:44:07',0,NULL,8,1,17,0,NULL,NULL),(22822,782973330001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','hersheyi','hersheyti@gmail.com','Ivanka Hershey','2249 Regina Dr','Clarksburg','MD','UNITED STATES','20871-8527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 22:44:08',0,NULL,8,1,17,0,NULL,NULL),(22823,782973331001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','hersheyi','hersheyti@gmail.com','Ivanka Hershey','2249 Regina Dr','Clarksburg','MD','UNITED STATES','20871-8527','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 22:44:09',0,NULL,3,1,1,1,NULL,'无牌方镜 渐变灰 （nd4）   1 \r无牌方镜 渐变灰 （nd2）    1\r无牌方镜 渐变灰 （nd8）    1'),(22824,826854941002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','rmshort1958','rmshortmd@hotmail.com','Mark Short','239 Saddlebrook Dr','Jackson','TN','UNITED STATES','38305-6607','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 22:49:34',0,NULL,3,1,21,1,'RA184526357CN\r ',NULL),(22825,826858943002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.6,'hermeshine','cyraxmmx','andres-zaragoza@hotmail.com','Andrés Castellano Escobar','Juan José Lorente 27-31, oficina G','Zaragoza','Aragón','SPAIN','50005','625054515','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 23:15:49',0,NULL,3,1,17,0,NULL,NULL),(22826,826863580002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','cyraxmmx','andres-zaragoza@hotmail.com','Andrés Castellano Escobar','Juan José Lorente 27-31, oficina G','Zaragoza','Aragón','SPAIN','50005','625054515','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 23:15:48',0,NULL,3,1,4,1,'YW867739284CN ','50-70柔光棚 通用塑料卡口   2 \r斜臂    1\r称一下重量'),(22827,826869885002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','dimamiparis','vesnine@cyberexpert.net','CyberExpert / M. Vesnine Dmitri','19 rue Albert de Mun','Asnieres sur Seine','Ile-de-France','FRANCE','92600','06.33.25.91.17','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-15 23:23:51',0,NULL,3,1,17,0,NULL,NULL),(22828,826870908002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','rhodyguy1','rhodyguy1@yahoo.com','Steve Morris','74 Hermit Dr','Warwick','RI','UNITED STATES','02889','(401) 739-9222','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-15 23:28:06',0,NULL,3,1,1,1,NULL,NULL),(22829,908666199016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','sconto777','kenedis@yahoo.com','Rimvydas Balciunas','Jonazoliu 9-164','Vilnius','','LITHUANIA','LT04139','37052313975','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-15 23:30:22',0,NULL,3,1,22,1,NULL,NULL),(22830,927826409015,250971425921,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.9,'hutongstore','twinshox','xls250@gmail.com','Colin Edden','42 Greenmeadow Drive','Barnstaple','Devon','UNITED KINGDOM','EX31 4HT','01271328848','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-15 23:44:46',0,NULL,3,1,11,1,NULL,NULL),(22831,927809811015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','thedanedk','sinklov@dbmail.dk','Uffe Sinklov','Traedrejerporten 45','Hvidovre','Denmark','DENMARK','DK-2650','+45 36 49 49 53','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-15 23:10:42',0,NULL,3,1,22,1,NULL,NULL),(22832,615671003004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','vedranpetak','vedran.petak1@zg.t-com.hr','Vedran Petak','Cvjetno naselje 6','Velika Gorica','Zagrebačka županija','CROATIA','10410','(+385)915877761','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 01:36:43',0,NULL,3,1,17,0,NULL,NULL),(22833,826917977002,120841733953,'Promotion ! NEW  Square Neutral Density full ND2 Grey Filter for Cokin P Series',1,'AD1221',3.5,'hermeshine','vedranpetak','vedran.petak1@zg.t-com.hr','Vedran Petak','Cvjetno naselje 6','Velika Gorica','Zagrebačka županija','CROATIA','10410','(+385)915877761','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 01:36:44',0,NULL,3,1,17,0,NULL,NULL),(22834,783035430001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','vedranpetak','vedran.petak1@zg.t-com.hr','Vedran Petak','Cvjetno naselje 6','Velika Gorica','Zagrebačka županija','CROATIA','10410','(+385)915877761','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 01:36:43',0,NULL,3,1,24,1,NULL,'无牌方镜 ND8   1 \r无牌方镜 ND2     1\r无牌方镜 ND4     1\r150G\r'),(22835,8881326678168348,111,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',24.99,'aliexpress','1006279639 ','sandra_s1992@hotmail.com','sandra sanchez soto	','sol, 19','Bunol','Valencia','VALENCIA','46360','618879320',NULL,NULL,NULL,'2012-01-16 01:42:48',0,NULL,3,1,21,1,'RA184526269CN\r ',NULL),(22836,8881326678796947,111,'Studio Background Support 7x7 ft + 2 (White and Black) Backdrops + Free Carry bag',1,'AKT015',74.99,'aliexpress','1006281203 ','sigorvic@yandex.ru','Igor Savchenko	','Parkovaya 19-13','Zelenogorsk','Region Krasnojarsk	','RUSSIAN FEDERATION	','663690','89138351737',NULL,NULL,NULL,'2012-01-16 01:53:16',0,NULL,3,1,5,1,'CP244548374CN ','1.6*2.1m 背景布 *2（白+黑） '),(22837,8881326679023386,111,'Studio Light 800W Continuous Lighting Kit w/ background support system 2m',1,'AKT087',167.99,'aliexpress','1006282657','mopsirmile@gmail.com','Irina Milukova	','Irina Milukova	','Moscow','Moscow','RUSSIAN FEDERATION	','117148','+7 962 9621464',NULL,NULL,NULL,'2012-01-16 01:57:03',0,NULL,3,1,17,0,' ',''),(22838,8881326680297322,111,'45w 5500k 灯泡 220v',1,'',0,'hermeshine','mcdebugger','mc_debugger@mail.ru','Maxim Kachur','Volodarskogo ul; d. 34-A; kv. 76','Ivanovo','Ivanovskaya obl','RUSSIAN FEDERATION','153022','+79023150144',NULL,NULL,NULL,'2012-01-16 02:18:17',0,NULL,3,1,3,1,'RA184526167CN\r ','已入库 '),(22839,8881326680553274,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft',2,'AO0005',37.98,'aliexpress','1006282656 ','mopsirmile@gmail.com','Irina Milukova	','Street Brusilova, bild. 27-3 ,ap 107','Moscow','Moscow','RUSSIAN FEDERATION	','117148','+7 962 9621464',NULL,NULL,NULL,'2012-01-16 02:22:33',0,NULL,3,1,5,1,'CP244548198CN ','3.0x1.6m 背景布 *2 （绿+蓝）\r2.0x2.0m 背景架 *1\r1.6x2.1m 背景布 *1 （白）\r2m 灯架 *2\r85cm 反光伞 *2\r双灯头 *2\r45w灯泡 220v *4 （欧标）\r灯架包 *1'),(22840,8881326681646475,111,'Full Set 49mm-82mm 9 Adapter Ring+Cokin P Filter Holder',1,'AKT025',24.99,'aliexpress','1006294279 ','ztopan@sympatico.ca','Zahir Topan	','#605 - 1303 wilson ave. Buzzer Code 5522','Toronto','Ontario','CANADA','M3M 1J1','+416 241 5252',NULL,NULL,NULL,'2012-01-16 02:40:46',0,NULL,3,1,3,1,'RA184526365CN\r ',NULL),(22841,8881326682543068,0,'800w 220v * 5',1,'AKT059',24.99,'aliexpress','paul486 ','sales@hypop.com.au','Paul Romero','31/70 Holbeche Road','Arndell Park','NSW','AUSTRALIA','2148','+611300449767',NULL,NULL,NULL,'2012-01-16 02:55:43',0,NULL,5,1,3,1,'RA184526374CN\r ','Paypal（sales@hypop.com）直接付款 \r一共是5个，不是25个。\rRRPR Pty Ltd\r31/70 Holbeche Road\rArndell Park, New South Wales 2148\rAustralia\r'),(22842,783065965001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',2,'AA2401',67,'hermeshine','yeo9915','yeo1705@hanmail.net','hwansung yeo','124-5 daeheung-dong <br>dongnam-gu','cheonan','asl / kr /ks002 / cheonan','KOREA,REPUBLIC OF','330-010','82-10-3674-5988','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 03:12:37',0,NULL,3,1,3,1,'RA184526459CN\r ',NULL),(22843,927922574015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','style-bay','mattlucas1@ntlworld.com','matthew lucas','9 blenheim road','abbots langley','Hertfordshire','UNITED KINGDOM','wd5 0tg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 03:32:23',0,NULL,3,1,17,0,NULL,NULL),(22844,783077358001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','gl1stenstar','glistenstar@platina.com.au','Y Monck','Parcel Locker C2288<br>2 Herbert Street','St Leonards','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 03:43:37',0,NULL,3,1,11,1,NULL,NULL),(22845,927922575015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','style-bay','mattlucas1@ntlworld.com','matthew lucas','9 blenheim road','abbots langley','Hertfordshire','UNITED KINGDOM','wd5 0tg','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 03:32:23',0,NULL,3,1,3,1,'RA184526445CN\r ','伞式柔光箱 60×90cm    1 \r伞式柔光箱 80cm 8角     1'),(22846,927940668015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','andreassoufis','andreassikkis@gmail.com','Andreas Sikkis','Georgiou pop 9','Athens','Attica','GREECE','11525','0030 6974334912','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 04:31:05',0,NULL,3,1,17,0,NULL,NULL),(22847,826981216002,120601699592,'Neoprene Camera Cover Case for Canon Nikon Large size',1,'AC1302',7.5,'hermeshine','atomictanaka','atomicgerry@gmail.com','GERALD TANAKA','921 Rancho Cir','FULLERTON','CA','UNITED STATES','92835-3336','(714) 526-4667','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-16 05:19:24',0,NULL,3,1,1,1,NULL,NULL),(22848,788173627018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',60,'photographyacc','benny_smurf','benny@netspeed.com.au','Benjamin Rodgers - Ryde Baptist Church','61-69 Lane Cove Rd<br>(Cnr Dobson Cres)','Ryde','New South Wales','AUSTRALIA','2112','0298094977','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-16 06:15:00',0,NULL,3,1,3,1,'RA184526431CN\r ',NULL),(22849,8881326697589246,111,'New Studio Light 800W Continuous Lighting Complete Kit with background ',1,'AKT087',0,'hutongstore','phangazone','phanga@msn.com','Reginaldo Sousa','Rua de Nachingweia Nº487','Maputo','Cidade de Maputo','MOZAMBIQUE','1101','(+258) 823916810',NULL,NULL,NULL,'2012-01-16 07:06:29',0,NULL,3,1,12,1,'2100867646 ','C里面布1.6*2.1 黑色 \r除了C里面以外再发\r2.5高灯架   2\r1.6*2.1  绿色和白色布\r欧标\r实重9.8   泡重10.3\r'),(22850,827006932002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','adrenalin086','xoaz122@hotmail.com','Jason Tam','3370 East 29th Ave','Vancouver','BC','CANADA','V5R1W8','(604) 783-7969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 07:15:56',0,NULL,3,1,3,1,' RA184526428CN\r',NULL),(22851,8881326701613984,111,'2个45W220v灯泡，一个5灯头',1,'',0,'photographyacc','aleksi747','mirzo3@teaser.fr','Dr. Alexandre Serain Shuvaloff','CMPI 61 Bd Carnot','Le Vésinet','Ile-de-France','FRANCE','78110','33672573683',NULL,NULL,NULL,'2012-01-16 08:13:33',0,NULL,3,1,3,1,'RA184526493CN ','灯泡和灯头都要测试一下\r两个法国标头 \r'),(22852,927994999015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','ks070707','gkgore@hotmail.com','Kerry  Gore','4 Sabre Court','Narre Warren','Victoria','AUSTRALIA','3805','0402522024','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 08:21:50',0,NULL,3,1,11,1,NULL,NULL),(22853,827017129002,120632125291,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9,'hermeshine','kappam6a','kravchenko_peter@mail.ru','Petr Kravchenko','Zemlyachki, 32 - 21','Volgograd','Volgograd oblast','RUSSIAN FEDERATION','400048','+7 (960) 884 74 74','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 08:21:52',0,NULL,3,1,11,1,NULL,NULL),(22854,928009035015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','fv222','atena@apollo.lv','Leonids Zerebcovs','Jelgavas iela 36','Kuldiga','Latvija','LATVIA','LV-3301','+371 29296600','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 09:12:41',0,NULL,3,1,24,1,NULL,NULL),(22858,908869066016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0023',169,'hutongstore','mrkwaniesam','mrkwanie@gmail.com','Sam','9 Glenville Road','Newtownabbey, Belfast','Antrim','UNITED KINGDOM','BT37 0TA','07591708031','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-16 10:21:09',0,NULL,3,1,4,1,'YW868898210CN ','申报$30 \rSample for Review\r'),(22855,908856284016,260933198603,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'hutongstore','*supamatt*','matt@nlr-online.co.uk','Matt Killen','40 Tunfield Road','Hoddesdon','Hertfordshire','UNITED KINGDOM','EN119LG','07740339262','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-16 09:38:16',0,NULL,3,1,11,1,NULL,'回信了 \r换成全灰的ND8'),(22915,8881326770420336,111,'1.6*3 绿色背景布',1,'',0,'hermeshine','ferencmester','vincze.feri@gmail.com','ferenc vincze','Tőkés út 53.','Karcag','Jász- Nagykun','HUNGARY','5300','06308547767',NULL,NULL,NULL,'2012-01-17 03:20:20',0,NULL,3,0,21,1,'RA184526808CN\r ',NULL),(22856,827042567002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','rockelis','rokas.rokelis@gmail.com','Rokas Bubelis','Taikos pr. 58-24','Kaunas','','LITHUANIA','51303','+37062769295','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 10:07:12',0,NULL,3,1,21,1,'RA184534185CN\r ','申报$20 '),(22857,8881326708811998,111,'mini 红外canon   1',1,'',0,'hermeshine','mow_chow','tonyoppedisano@tpg.com.au','Antonio Oppediano','11 Chopin St<br>Seven Hills','Sydney','New South Wales','AUSTRALIA','2147','0422901144',NULL,NULL,NULL,'2012-01-16 10:13:31',0,NULL,3,0,3,0,'RA184526480CN\r ','mini 红外  canon  1 '),(22859,782365606001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','mesko-sk','mesko@inmail.sk','Robert Meszaros','Cepenska 3735/121','Sered','Trnavsky','SLOVAK REPUBLIC','92601',' 421915374573','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 11:38:15',0,NULL,3,1,5,1,'CP244674995CN ','欧标 '),(22860,783184548001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','sreckozitnik','zitniks@yahoo.com','Tomislava Pranjic','Copova 4','Split','Croatia','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 12:07:14',0,NULL,3,1,5,1,'CP244674987CN ','欧标'),(22861,827080185002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 12:30:25',0,NULL,3,1,25,1,'RT125135576HK ',''),(22862,788264331018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','edlooedward','edloo@jedlo.com.au','Edward Loo','C/o Jedlo Accountants<br>Level 4, 683 Burke Road','Camberwell','Victoria','AUSTRALIA','3124','0398113833','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-16 12:41:13',0,NULL,3,1,3,1,'RA184534061CN\r ',NULL),(22863,928079154015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',8.4,'hutongstore','rid3334','rid@apollo.lv','Rihards Lebedjoks','Aizpilsetas 33-34','Daugavpils','','LATVIA','LV5417','+371 29482776','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 12:41:48',0,NULL,3,1,24,1,NULL,NULL),(22864,783196012001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 12:45:51',0,NULL,3,1,3,0,'RA184534132CN\r ',NULL),(22865,783196014001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',2,'AD1179',31.8,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 12:45:53',0,NULL,3,1,17,0,NULL,NULL),(22866,928081425015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','kkrz1932','chikusho@wp.pl','Krzysztof Krzeminski','36 Gibbons Grove','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0JF','07565812012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 12:49:40',0,NULL,3,1,17,0,NULL,NULL),(22867,908918359016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','kkrz1932','chikusho@wp.pl','Krzysztof Krzeminski','36 Gibbons Grove','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0JF','07565812012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 12:49:41',0,NULL,3,1,17,0,NULL,NULL),(22868,908918360016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','kkrz1932','chikusho@wp.pl','Krzysztof Krzeminski','36 Gibbons Grove','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0JF','07565812012','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-16 12:49:43',0,NULL,3,1,4,1,'YW868898206CN ','除了C以外再发\r天涯方形滤镜  ND8  1 \rlenspen    1\r4灯头 灯头 孔    1\r50cmx70cm 的柔光箱 (配4灯头）     1                     英标\r3片装的滤镜袋   1'),(22869,928081426015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','kkrz1932','chikusho@wp.pl','Krzysztof Krzeminski','36 Gibbons Grove','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0JF','07565812012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 12:49:44',0,NULL,3,1,17,0,NULL,NULL),(22870,928081427015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.98,'hutongstore','kkrz1932','chikusho@wp.pl','Krzysztof Krzeminski','36 Gibbons Grove','Wolverhampton','West Midlands','UNITED KINGDOM','WV6 0JF','07565812012','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 12:49:44',0,NULL,3,1,17,0,NULL,NULL),(22871,783204859001,110609032219,'Redhead Red head 800w w bulb + Spring Cushioned Stand ',1,'AKT057',130,'hermeshine','d*e*j*a*n','dejan@mistatechcomputers.com.au','Dejan Topkoski','32 Deakin Avenue<br>Lalor','Melbourne','Victoria','AUSTRALIA','3075','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 13:17:56',0,NULL,3,1,4,1,'YW867739240CN ',NULL),(22872,783196013001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','zonagrib','hrun.los@gmail.com','Natalya Babina','9a Revolucye Str.App.28','Perm','Perm Permskiy kray','RUSSIAN FEDERATION','614007','0079824884191','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 12:45:52',0,NULL,3,1,5,1,'CP244674973CN ','除了C以外再发\r150-200cm 5in1 反光板   1 \r反光板支架的夹子（双轮）  2\r反光板单发'),(22873,928099990015,250845745737,'New Stainless Steel Spanner Wrenches for lens repair',1,'AD1123',28,'hutongstore','dcc_supplies','office@dccsupplies.com','Andrew Forty','Unit 17A, Top Barn Business Centre<br>Worcester road','Holt Heath','Worcestershire','UNITED KINGDOM','WR6 6NH','08452241601','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 13:38:23',0,NULL,3,1,3,1,'RA184534150CN\r ',NULL),(22874,928110725015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','dumpertrucky','pgarethp@aol.com','gareth john phillips','2 st brides close<br>llanyrafon','cwmbran','Torfaen','UNITED KINGDOM','np44 8sl','07846575279','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-16 14:05:06',0,NULL,3,1,4,1,'YW867739236CN ','英标 \r1.6*2.1 白色布'),(22875,928128863015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',2,'AB1301',4.3,'hutongstore','barrybarry1951','rafalgolf@terra.es','BARRY SHEARMAN','Vereda las barracas 12.1<br>Mudamiento, Rafal,','Alicante','Comunidad Valenciana','SPAIN','03369','966193417','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 14:47:34',0,NULL,3,1,24,1,NULL,NULL),(22876,827126312002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','ibrogerson','ibrogerson@yahoo.com','ian rogerson','891 palm ave<br>pobox 1240','BOCA GRANGE','FL','UNITED STATES','33921','(941) 964-0036','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-01-16 14:52:55',0,NULL,3,1,1,1,'42033921\r ',NULL),(22877,827142725002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','adrenalin086','xoaz122@hotmail.com','Jason Tam','3370 East 29th Ave','Vancouver','BC','CANADA','V5R1W8','(604) 783-7969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 15:38:46',0,NULL,3,1,3,1,'RA184534146CN\r ',NULL),(22878,827147229002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','limp636','limpvoicevideo@yahoo.com','Adrian Lupascu','Str. Alex Serbanescu, Nr. 45, Bl. 20F, Sc.1, Ap.5, Sector 1','Bucharest','','ROMANIA','014284','40724297594','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-16 15:50:59',0,NULL,3,1,5,1,'CP244674960CN ',' '),(22879,928144832015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','poozer-roozer','andy_saunders81@hotmail.co.uk','Andrew Saunders','9 Grey Street','Darlington','Durham','UNITED KINGDOM','DL1 2LY','07554994938','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 15:23:07',0,NULL,3,1,3,1,'RA184534305CN\r ',NULL),(22880,908998659016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','tincek80','valentin.pavlin@gmail.com','Valentin Pavlin','Ozeljan 134','Sempas','Slovenia','SLOVENIA','5261','00386(0)41517338','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-01-16 16:04:51',0,NULL,3,1,5,1,'CP244674956CN ','除了C以外再发\r背景布 3x6 绿色 \r欧标'),(22881,928168930015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',1,'AO0018',38,'hutongstore','tincek80','valentin.pavlin@gmail.com','Valentin Pavlin','Ozeljan 134','Sempas','Slovenia','SLOVENIA','5261','00386(0)41517338','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 16:12:54',0,NULL,3,0,17,0,NULL,NULL),(22882,788328895018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','anthony877430','anthonydoheny@eircom.net','Anthony Doheny','The Dell Mount Pleasant, Mount Pleasant Estate<br>Mount Pleasant Estate','Waterford City (1st R 1st L 3rd Hse L)','Waterford','IRELAND','051','0872902197','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-16 15:49:47',0,NULL,3,0,24,1,NULL,'1.6*2.1  白色 '),(22883,909022207016,260901272183,'New Camera protector case Neoprene bag for Nikon D40 D3000 D3100 50mm 18-55mm',1,'AD1171',5.2,'hutongstore','joseandres1973','jgarciao2@hotmail.com','JOSE ANDRES GARCIA ORTIZ','C/ MANUEL GARCIA JUNCO 18A<br>CASTILLEJA DE LA CUESTA','SEVILLA','Andalucía Ceuta y Melilla','SPAIN','41950','607941434','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 16:50:49',0,NULL,3,1,24,1,NULL,NULL),(22884,783285186001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','bobmech1','r.nicholls1@btinternet.com','Bob Nicholls','21 Mount Pleasant Road','Risca','Caerphilly','UNITED KINGDOM','NP11 6QB','01633615106','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 17:01:24',0,NULL,3,0,3,1,'RA184534092CN\r ','3XL 已入库 '),(22885,928190599015,250599942701,'77mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1307',2.56,'hutongstore','il-lostia','il.lostia@gmail.com','Alexey M.','Automation Technologies UNIT 1140<br>KBIC Kordin Industrial Estate','Paola','','MALTA','PLA3000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 16:52:17',0,NULL,3,1,24,1,NULL,NULL),(22886,827193844002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','zozo2004horvath','horvath.zoltan524@upcmail.hu','Horvath Zoltan','Irinyi Janos 12','Komlo','Baranya','HUNGARY','7300','+36703343482','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 17:34:06',0,NULL,3,1,21,1,'RA184534115CN\r ',NULL),(22887,928140276015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','llueveylasgotaspoeticasmeexaltan','patricioreig@gmail.com','Patricio Reig','Concilio de Trento 313 pl.14','Barcelona','Cataluña','SPAIN','08020','626684429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 17:34:53',0,NULL,3,1,4,1,'YW868898221CN ',' C里面布白色\r除了C以外再发\r1.6*2.1 绿色布\r\r'),(22888,928218590015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','llueveylasgotaspoeticasmeexaltan','patricioreig@gmail.com','Patricio Reig','Concilio de Trento 313 pl.14','Barcelona','Cataluña','SPAIN','08020','626684429','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 17:39:25',0,NULL,3,0,17,0,NULL,NULL),(22889,928253626015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','manfred1768','onlineshop1768@gmx.at','Manfred Lueger','Traubengasse 13B','Gramatneusiedl','','AUSTRIA','2440','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 18:32:45',0,NULL,3,1,24,1,NULL,NULL),(22890,827261150002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','andrey9*4','andrey.zarow@gmail.com','Andrey Zharov','Altaiskaya 12A, kvartira 155.','Orenburg','Orenburg','RUSSIAN FEDERATION','460040','89878888172','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 19:35:45',0,NULL,3,1,3,1,'RA184534101CN\r ',NULL),(22891,783367662001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','villetura','willetura@gmail.com','Tuulikki Salopaju','Piilikuja 1 D23','Oulunsalo','','FINLAND','90460','+358504855757','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 19:37:06',0,NULL,3,1,21,1,'RA184534203CN\r ','2个 '),(22892,825677259002,120565576753,'YONGNUO Flash Battery Pack SF-18 Nikon SB800  SD-8A ',1,'AB3309',49.99,'hermeshine','cppltd','colinpeddle@gmail.com','Colin Peddle','1 Gosse\'s Lane','Torbay','NL','CANADA','A1K1J5','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 19:39:27',0,NULL,3,1,3,1,'RA184534089CN\r ',NULL),(22893,783375318001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','maykomaniac','micke@rout.se','Mikael Bjuhr','Timotejvägen 18','Umeå','Västerbotten','SWEDEN','90352','0703788425','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 19:50:38',0,NULL,3,1,4,1,'YW868898195CN ','欧标\r除了C以外再发\r1.6*3 布\r先别包，布的颜色没有确定\r因为布的颜色没确定  所以1.6*3的布没发给他  过完年补发给他 '),(22894,827274481002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','maykomaniac','micke@rout.se','Mikael Bjuhr','Timotejvägen 18','Umeå','Västerbotten','SWEDEN','90352','0703788425','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 19:56:31',0,NULL,3,0,17,0,NULL,NULL),(22895,909174633016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',2,'AA1211',3.8,'hutongstore','negoitescudragos','nego_777@yahoo.com','NEGOITESCU DRAGOS','Bd. IULIU MANIU 128; BL. 22, SC. 1;<br>AP. 152; SECTOR 6','BUCHAREST','BUCHAREST','ROMANIA','061114','0726530551','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 20:32:43',0,NULL,3,1,17,0,NULL,NULL),(22896,909160005016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',2,'AA1211',3.8,'hutongstore','negoitescudragos','nego_777@yahoo.com','NEGOITESCU DRAGOS','Bd. IULIU MANIU 128; BL. 22, SC. 1;<br>AP. 152; SECTOR 6','BUCHAREST','BUCHAREST','ROMANIA','061114','0726530551','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 20:32:44',0,NULL,3,1,17,0,NULL,NULL),(22897,909160689016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','negoitescudragos','nego_777@yahoo.com','NEGOITESCU DRAGOS','Bd. IULIU MANIU 128; BL. 22, SC. 1;<br>AP. 152; SECTOR 6','BUCHAREST','BUCHAREST','ROMANIA','061114','0726530551','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 20:32:44',0,NULL,3,1,25,1,'RT125140721HK ','52-52mm 双阳环  4\r52-58mm 双阳环   1\r称一下重量再算运费\r42'),(22898,788493144018,280666834436,'New Small Camera bag lens case D2 for Canon 500D 450D ',1,'AO0033',8,'photographyacc','nbharrier','wanjan.thomson@paradise.net.nz','Warren Thomson','5a Fantail Lane Ferrymead','Christchurch','','NEW ZEALAND','8023','61 3 3841894','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-16 20:51:22',0,NULL,3,1,24,1,NULL,'\r发 sony 三角包  D3'),(22899,928373841015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','jackschapira','jacks_indahouse@hotmail.co.uk','jack schapira','18 red road<br>borehamwood','london','Hertfordshire','UNITED KINGDOM','wd6 4sr','07713098308','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-16 21:14:13',0,NULL,3,1,3,1,'RA184534251CN\r ','4节 '),(22900,928376198015,250692235965,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15.45,'hutongstore','lobo89','lobodu89@gmail.com','BARBE CHARLES','4 RUE DES ALOUETTES','APPOIGNY','Bourgogne','FRANCE','89380','0619294089','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 21:18:55',0,NULL,3,1,3,1,'RA184534075CN\r ',NULL),(22901,928382918015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',135,'hutongstore','abajec5','ales.bajec78@gmail.com','ALES BAJEC','CESTA IX. KORPUSA 18','AJDOVSCINA','','SLOVENIA','5270','0038641605117','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-16 21:28:24',0,NULL,3,1,5,1,'CP244674942CN ','欧标 '),(22902,827330057002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','silou08','cyril.ottaviani@wanadoo.fr','Cyril OTTAVIANI','3 Rue des abattoirs','SALERNES','Provence-Alpes-Côte d\'Azur','FRANCE','83690','06.03.33.57.76','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 21:40:36',0,NULL,3,1,3,1,'RA184534225CN\r ',NULL),(22903,928396896015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',2,'AD1184',42.4,'hutongstore','cb_1957_uk','cb_uk@talktalk.net','chris brown','4, lavendar close','witham','Essex','UNITED KINGDOM','CM8 2YG','01376516200','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-01-16 21:50:31',0,NULL,3,1,3,1,'RA184534217CN\r ','4节 2个 '),(22904,928410042015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','razc786','areezcharania@hotmail.com','Areez Charania','54 Taunton Way','Stanmore','Middlesex','UNITED KINGDOM','HA71DG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-16 22:14:33',0,NULL,3,1,3,1,'RA184534163CN\r ',NULL),(22905,827364583002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','joowls','juleskd61@hotmail.com','J DAVIS','3 BANK COURT','NORTH SHIELDS','Tyne and Wear','UNITED KINGDOM','NE30 1NY','07881406235','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-16 22:57:55',0,NULL,3,0,3,1,'RA184534035CN\r ','2XL 已入库 '),(22906,783468862001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','sugarplum_jewellery','i_killed_the_radio_star@hotmail.com','Sally Gilbert','31 Marsh Street<br>Maidstone','Melbourne','Victoria','AUSTRALIA','3012','0421766568','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,7,1,18,1,NULL,''),(22907,783205365001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','ghie_2008','glenndz28@yahoo.com','glennda reyes','157 tonbridge road','maidstone','Kent','UNITED KINGDOM','me16 8na','07587921078','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-16 22:57:56',0,NULL,3,1,11,1,NULL,NULL),(22908,827406226002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-17 01:12:45',0,NULL,3,1,5,1,'CP244674939CN ','澳转欧标\r申报低于50\r '),(22909,847964054017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','yssyboo','getyourjolleys@tsn.cc','Rebecca Jolley','52 Amaroo Drive','Smiths Lake','New South Wales','AUSTRALIA','2428','610265544441','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 01:43:12',0,NULL,3,1,11,1,NULL,NULL),(22910,8881326765373527,111,'3-in-1 Cleaning Kit - Lenspen Rubber Air Blower Cloth',1,'AKT067',11.99,'aliexpress','1006310074 ','dugy@ya.ru','Gennady Solntsev	','Pobedy 132/40','Pobedy 132/40','Stavropolsky kray	','RUSSIAN FEDERATION	','357701','+7 919 7501505',NULL,NULL,NULL,'2012-01-17 01:56:13',0,NULL,8,1,17,0,NULL,NULL),(22911,8881326765475204,111,'IR Remote Control for Canon 7D/550D/450D/500D',1,'AA2202',5.99,'aliexpress','1006310073 ','dugy@ya.ru','Gennady Solntsev	','Pobedy 132/40','Kislovodsk','Stavropolsky kray	','RUSSIAN FEDERATION	','357701','+7 919 7501505',NULL,NULL,NULL,'2012-01-17 01:57:55',0,NULL,3,1,3,1,'RA184534027CN\r ','Lenspen+气吹+布 *1\r爵影红外 canon  *1\r '),(22912,8881326765732236,111,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',24.99,'aliexpress','1006311963','santleo@yandex.ru','Sazhin Anton	','Esenina st. 3-6','Ekaterinburg','Sverdlovskaya	','RUSSIAN FEDERATION	','620138','79030802443',NULL,NULL,NULL,'2012-01-17 02:02:12',0,NULL,3,1,3,1,'RA184534013CN\r ',NULL),(22913,8881326765919124,111,'33.5\" 85cm Black Silver Reflector Studio Light Umbrella',1,'AD1401',8.99,'aliexpress','1006315231','jungis38@gmail.com','Mats Jungmyren	','Krakrisvagen 5A 2tr','Motala	','Sweden','SWEDEN','59154','+0046 70 5158982',NULL,NULL,NULL,'2012-01-17 02:05:19',0,NULL,3,1,21,1,'RA184534194CN\r ',NULL),(22914,827425195002,120566694479,'Set of 2 Grey Card\'s size 4\"x6\" and 6\"x8\", 18% Gray',1,'AA2217',8.99,'hermeshine','newtonbr','newtonnogueira@gmail.com','Newton Nogueira da Silva','Rua Dr Jonas Deocleciano Ribeiro, 869<br>Vila Champagnat','Franca','Sao Paulo','BRAZIL','14400-230','1681249004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 02:12:31',0,NULL,3,1,24,1,NULL,NULL),(22916,827445986002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','418scar28','scarboys@hotmail.com','Danny Jenkins','14, Marie de l\'incarnation # 206','Québec','QC','CANADA','G1M 1A9','(418) 353-2933','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 03:21:28',0,NULL,3,1,3,1,'RA184534248CN\r ',NULL),(22917,928529050015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',40,'hutongstore','zoolook888','alfa147@ntlworld.com','Robert Corry','50 Beechgrove Avenue','Belfast','Antrim','UNITED KINGDOM','BT6 0NF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 03:24:45',0,NULL,3,1,3,1,'RA184534058CN\r ',NULL),(22918,928530125015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','adlera2001is','ebay@hakon.org','Hakon Sveinsson','Flat 1<br>181 Dawes Road','London','London','UNITED KINGDOM','SW6 7QP','07707867937','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 03:28:38',0,NULL,3,1,3,1,' RA184534234CN\r',NULL),(22919,783547671001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','tom2077','schoolguy98@hotmail.com','Li Chen','168 Bloor St W','Oshawa','ON','CANADA','L1J 1P7','(416) 836-3991','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-17 03:53:41',0,NULL,3,1,3,1,'RA184534044CN\r ',NULL),(22920,827470795002,120752324312,'Protect Soft Camera Bag Case Skin Cover Canon EOS 7D',1,'AD1115',11.99,'hermeshine','shengru1','shengruchen@hotmail.com','Shenru Chen','550 Darling St<br>Unit 7A','Southington','CT','UNITED STATES','06489-2608','(860) 833-0808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 05:20:57',0,NULL,3,1,1,1,'LK177773123CN\r ','新款内胆包 大号 canon logo   1  \rEW-73B   1'),(22921,827471216002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','shengru1','shengruchen@hotmail.com','Shenru Chen','550 Darling St<br>Unit 7A','Southington','CT','UNITED STATES','06489-2608','(860) 833-0808','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 05:20:56',0,NULL,3,1,21,1,'RA184534296CN\r ',NULL),(22922,783562913001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','shengru1','shengruchen@hotmail.com','Shenru Chen','550 Darling St<br>Unit 7A','Southington','CT','UNITED STATES','06489-2608','(860) 833-0808','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-17 05:20:57',0,NULL,8,1,17,0,NULL,''),(22923,783567936001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','djsousa','djpaulsousa@hotmail.com','Paul Sousa','841 Ferrie Road','Victoria','BC','CANADA','v8z3c7','(250) 727-8688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 05:40:27',0,NULL,3,1,3,1,'RA184534129CN\r ',NULL),(22940,928642768015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','luciaflendrovska','completeautomatic606@gmail.com','Lucia Flendrovska','Zarnovicka 1','Bratislava','Slovakia','SLOVAK REPUBLIC','83106','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-17 10:53:11',0,NULL,3,1,21,1,'RA184548953CN ',NULL),(22925,827495792002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','adamlamb86','lambadam@bigpond.com','adam lamb','196 Enterprise Street Bohle','townsville','Queensland','AUSTRALIA','4818','0419172243','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-17 07:39:50',0,NULL,3,1,3,1,'RA184534279CN\r ','M 已入库 '),(22924,827493668002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kpkmur2010','kpkmur@yandex.ru','Belyaev Alexey','svjazi 3-32','Murmansk','','RUSSIAN FEDERATION','183071','+79113139056','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 07:28:03',0,NULL,3,1,3,1,'RA184534265CN\r ',NULL),(22926,848047345017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',9,'photographyacc','aoa_vic','abel.abella@hotmail.com','Abel Abella','73 Pacific Drive','Aspendale Gardens','Victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-17 07:40:42',0,NULL,3,1,11,1,NULL,NULL),(22927,783589154001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','mrstodgy','kolrat@pisem.net','Evgeniy Donets','Timoshenko str. 28 kv 24','Rostov-on-Don','Rostovskaya obl','RUSSIAN FEDERATION','344069','(928)270-9036','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 07:53:38',0,NULL,3,1,24,1,NULL,NULL),(22928,909413945016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','miro.x','a.fandeev@mail.com','Andrey Fandeev','Malenkovskaya st.<br>9/11-67','Moscow','Moscow','RUSSIAN FEDERATION','107113','(926) 130-1024','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 07:53:47',0,NULL,3,1,24,1,NULL,NULL),(22929,783590442001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','9-tong','t.9tong@hotmail.com','T.Thongkham','1111 N Gilbert Rd<br># 101-103','gilbert','AZ','UNITED STATES','85234-2313','','NoPaymentFailure','CheckoutComplete','Other','2012-01-17 08:07:38',0,NULL,3,1,1,1,'LK183297644CN\r ',NULL),(22930,783598982001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',32,'hermeshine','axonalex','alexbycomp@gmail.com','Alexandr Axon','pr. Mira 180 / 5','Chernigov','','UKRAINE','14037','0634690949','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 08:45:39',0,NULL,3,1,21,0,'RA184534340CN\r ',NULL),(22931,928606069015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','spicegirls1758','camilla1758@hotmail.com','Camilla Mathiasen','Bag Volden 23','Bolderslev','','DENMARK','6392','0045-51951758','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 08:49:10',0,NULL,3,1,22,1,NULL,NULL),(22932,928608465015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','noport2010','nportelli@euroweb.net.mt','Emanuel Portelli','289 Peacehaven<br>St. Thomas Street','Tarxien','','MALTA','TXN1603','+356 21895494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 08:58:21',0,NULL,3,1,24,1,' ',NULL),(22933,928609102015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 09:01:00',0,NULL,8,1,17,0,NULL,NULL),(22934,928608833015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 09:01:01',0,NULL,3,1,4,1,'YW867739251CN ','反光板支架   2 \r斜臂    1'),(22935,827513442002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','jsomby','juha@somby.fi','Juha Somby','Lintulammenkatu 13 B 26','Kerava','Uusimaa','FINLAND','04250','358-45-78801511','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-17 09:12:33',0,NULL,3,1,21,1,'RA184548865CN ',NULL),(22936,927834322015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','gribouboucan','achille2009@gmail.com','Jean-luc GRILLOT','11 sq vitruve','Paris','Île-de-France','FRANCE','75020','01.43.61.83.08','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 09:12:37',0,NULL,3,1,3,1,'RA184534319CN ',NULL),(22937,827516075002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','hazi_zsolt','hazi.zsolt@gmail.com','Zsolt Hazi','Deak Ferenc 49.','Szombathely','','HUNGARY','9700','36 30 2384080','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 09:24:53',0,NULL,3,1,21,1,'RA184534438CN ',NULL),(22938,928608748015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','bc6027','chunthanom@hotmail.com','bunsuk chunthanom','64 koorana road','mullaloo','Western Australia','AUSTRALIA','6027','0894010276','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 09:01:01',0,NULL,8,1,17,0,NULL,NULL),(22939,8881326793251278,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds',1,'AC2403',25.99,'aliexpress','1006318074','zyurij@gmail.com','Yurij Zagranichnij	','Esenina 40-1-401','Saint-Petersburg	','Russia','RUSSIAN FEDERATION	','194358','+7 921 3332675',NULL,NULL,NULL,'2012-01-17 09:40:51',0,NULL,3,1,3,1,'RA184534322CN ',NULL),(22941,783659324001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','gjkbgfrtn','mail@abc-design.ru','Ruslan Pospelov','Prospekt Veteranov, 160, 353','St. Petersburg','','RUSSIAN FEDERATION','198264','+7921','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 13:06:02',0,NULL,3,1,5,1,'CP244674580CN ','欧标 \r白色背景布'),(22942,928693382015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','micleyb','micas@swet.us','Michail Storozhinskiy','Seslawinskaya,32-2-179<br>Moskva','default','','RUSSIAN FEDERATION','121309','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 13:31:24',0,NULL,3,1,5,1,'CP244674576CN ','除了C以外再发\rNG128 柔光罩    1\r欧标'),(22943,928698966015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','micleyb','micas@swet.us','Storozhinskij Mikhail','SILIKATNAYA, 24-1','MUTISCHI MOSKOWSKAYA','','RUSSIAN FEDERATION','141004','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 13:36:47',0,NULL,3,1,17,0,NULL,NULL),(22944,783675717001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','tyzerxp','johanvantilt@hotmail.com','johan vantilt','pieter bortierlaan 40','gistel','','BELGIUM','8470','0489451090','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 14:01:59',0,NULL,3,1,21,1,'RA184534441CN ',NULL),(22945,909531816016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','mrmous','mous@live.nl','Maurice Coonen','Stadhoudersstraat 115','ARNHEM','','NETHERLANDS','6828 SH','','PayPalPaymentInProcess','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','0000-00-00 00:00:00',0,NULL,7,1,18,1,NULL,NULL),(22946,783700246001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','kevinkimm','kevinkimm@gmx.de','Kevin Kimm','Uhlandstrasse 4','Helsa','Hessen','GERMANY','34298','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 15:21:13',0,NULL,3,0,24,1,NULL,'1.6*2.1  灰色'),(22947,928728949015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','vitalikpt','vptashnik@gmail.com','Vitalii Ptashnik','Lenina 9','Pilipovitschi','','UKRAINE','11760','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-17 14:53:09',0,NULL,3,1,5,1,'CP244674562CN ',NULL),(22948,928745401015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','jibitoye','jibitoye@hotmail.com','Jide Ibitoye','4 Fitzroy Sq','London','London','UNITED KINGDOM','W1T 5HQ','07958142454','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 15:31:26',0,NULL,3,1,3,1,'RA184504467CN\r','之前发过，忘发出去了。\r重发一次 '),(22949,827619725002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','ripropp','riprop@gmail.com','Denis Đukić','Janševa ulica 1','Ljubljana','','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 15:42:52',0,NULL,3,1,24,1,NULL,'Please include bill in package,\rso customs office can process item. \r做个发票放进包装里'),(22950,928053559015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','christinasenchenko','christa@rambler.ru','Christina Senchenko','Molodezhnaya street bilding 10 flat 51','Novorossiysk','Krasnodar region','RUSSIAN FEDERATION','353913','0079887628186','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 16:09:17',0,NULL,3,1,5,1,'CP244674559CN ','黑加白\r最后那块黑布发给他\r'),(22951,783722660001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','mrohtera','mrothera@cypresscollege.edu','mary rothera','435 s fann st','anaheim','CA','UNITED STATES','92804-2619','(714) 484-7166','NoPaymentFailure','CheckoutComplete','Other','2012-01-17 16:28:07',0,NULL,3,1,1,1,'LK177352749CN ',NULL),(22952,827653449002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:07:09',0,NULL,8,1,17,0,NULL,NULL),(22953,783743009001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','veszvet','andy-lebedev@inbox.ru','Andrey Lebedev','Kirova 6-52','Rybinsk','Yaroslavskaya obl','RUSSIAN FEDERATION','152903','+79106655417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:15:06',0,NULL,3,1,17,0,NULL,NULL),(22954,827657648002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','veszvet','andy-lebedev@inbox.ru','Andrey Lebedev','Kirova 6-52','Rybinsk','Yaroslavskaya obl','RUSSIAN FEDERATION','152903','+79106655417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:15:07',0,NULL,3,1,3,1,'RA184534398CN ','3m 横杆（通用4节）  1 \rlenspen   2'),(22955,928778532015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','anastasiyadas','anastasiya_2284@mail.ru','Anastasiya Kuchina','Skobelevskaya street. 1-3-37','Moscow','','RUSSIAN FEDERATION','117624','+79264077087','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 16:41:00',0,NULL,3,1,11,1,NULL,NULL),(22956,827675490002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 17:56:56',0,NULL,8,1,17,0,NULL,NULL),(22957,909645001016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','25121979kamil','k.kudla@yahoo.pl','Kamil Kudla','21 Southpoint<br>Parnell Rd','Bray','Wicklow','IRELAND','default','872773406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 18:14:27',0,NULL,3,1,24,1,NULL,NULL),(22958,827684250002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 18:16:36',0,NULL,3,1,3,1,'RA184534407CN ','伞式柔光箱 80cm 8角    1 \r闪光的柔光箱   40cm   1\r伞式柔光箱 60×90cm    1'),(22959,928853150015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1301',19.8,'hutongstore','harislojo','haris_lojo@hotmail.com','Haris Lojo','Köpmangatan 33','Örebro','none','SWEDEN','70223','+46(0)707504966','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 18:53:30',0,NULL,3,1,24,1,NULL,'欧标 \r1027G\r'),(22960,783789828001,110514122833,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',208,'hermeshine','fpmsparkour','faf02@mail.ru','Vladimir Egorov','ul.Ulyanovih d.27 kv.15','Podolsk','Moskovskaya Oblast','RUSSIAN FEDERATION','142116','8 985 293 69 64','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 18:59:51',0,NULL,3,1,5,1,'CP244674545CN ','\r '),(22961,928859670015,250845745737,'New Stainless Steel Spanner Wrenches for lens repair',1,'AD1123',28,'hutongstore','wurzburg61','p.helm@planet.nl','EKB groep tav.    P. van der  Helm','wijkermeerweg 31','Beverwijk','','NETHERLANDS','1948nt','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-17 19:04:39',0,NULL,3,1,21,1,'RA184534455CN ',NULL),(22962,902787845016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','magneakvag','magne@akvag.no','Magne Akvag','Toyenhogda 27','Hakadal','Hakadal','NORWAY','1487','004790707575','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-17 19:09:06',0,NULL,3,1,5,1,'CP244674531CN ','欧标 '),(22963,783835245001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','karlan77','karlan@bonetmail.com','Andreas Karlsson','Svedalavägen 129a','Oxie','','SWEDEN','23841','0739370818','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 20:22:34',0,NULL,8,1,17,0,NULL,NULL),(22964,827759328002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','maingateproductions','rob@maingatellc.com','Rob O\'Sullivan','626 Veteran Ave<br>Apt B','Los Angeles','CA','UNITED STATES','90024-1984','(215) 264-6237','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-17 20:41:36',0,NULL,3,1,21,1,'RA184534367CN ',NULL),(22965,782746200001,110807099999,'Promotion ! NEW 3pcs Square Graduated ND2 ND4 ND8 Filter Kit for Cokin P Series',1,'AKT097',13.88,'hermeshine','gatomarianoluisfernando','lfortiz@ono.com','Luis Fernando Ortiz Verdu','Av. Conde Soto Ameno 6, 2º C','Alicante','Comunidad Valenciana','SPAIN','03005','966084974','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 20:42:08',0,NULL,5,0,18,0,NULL,'没有渐变灰ND8，已经发信了 ，\r已经退款了'),(22966,827764517002,120752324774,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',11.99,'hermeshine','charlesb6049','ishootpeople@hotmail.com','Charles Bamford','3 Ensay court<br>Endeavour Hills','Melbourne','Victoria','AUSTRALIA','3802','0414381333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 20:47:09',0,NULL,3,1,11,1,NULL,NULL),(22967,928906376015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','jpuddy','jdpuddy@gmail.com','John Puddy','26 Lakewood Road<br>Henleaze','Bristol','Avon','UNITED KINGDOM','BS10 5HH','07970069226','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-17 20:10:51',0,NULL,3,1,3,1,'RA184548879CN ',NULL),(22968,783839685001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','carlosrichardomega','carlosomega@msn.com','carlos benitez','calle mossen Lluis pañellas 16 bajos 1<br>hospitalet de llobregat','barcelona','Cataluña','SPAIN','08901','603212913','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 21:17:19',0,NULL,3,1,4,1,'YW868898140CN ',NULL),(22969,827781401002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','cooking4adventure','xcaddict@unwired.com.au','Michael Sullivan','PO Box 1047','Cooma','New South Wales','AUSTRALIA','2630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 21:19:18',0,NULL,3,1,11,1,NULL,NULL),(22970,827807128002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ph3nx77','nico060291@hotmail.fr','barbe nicolas','3 impasse françois coli','Ozoir la ferrière','Île-de-France','FRANCE','77330','0689400250','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 22:16:25',0,NULL,3,1,3,1,'RA184548940CN ',NULL),(22971,827813068002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',2,'AB1407',10.98,'hermeshine','fendermann66','johntp66@gmail.com','John Terje Pedersen','Gullskårveien 21','Rolvsøy','','NORWAY','1664','+4790559094','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 22:32:23',0,NULL,3,1,24,1,NULL,NULL),(22972,783896289001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','karlan77','karlan@bonetmail.com','Andreas Karlsson','Svedalavägen 129a','Oxie','','SWEDEN','23841','0739370818','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-17 22:39:38',0,NULL,3,1,21,1,'RA184534375CN ','反光板支架   2 \r称一下重量\r1.6kg'),(22973,827844006002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','jopica','jovukic@inet.hr','Josip Vukic','Luke Sorkocevica','Zadar','','CROATIA','23000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 00:01:46',0,NULL,3,1,21,1,'RA184534384CN ',NULL),(22974,827853773002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 00:36:07',0,NULL,5,0,18,0,NULL,'走香港小包挂号也不合适，需要加运费 差$6\r申报gift低值 \r发信了 加$9\r10：45发信了，3小时之内没有确认信息就先退款'),(22975,827855734002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 00:42:27',0,NULL,5,0,18,0,NULL,'走香港小包挂号也不合适，需要加运费 \r申报gift低值 \r发信了 加$9\r10：40发信了，3小时之内没有确认信息就先退款'),(22976,783941341001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','srodionov95aa','srodionov@verizon.net','Sergey Rodionov','1 Thornton Ct','East Brunswick','NJ','UNITED STATES','08816-4075','(732) 651-6923','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-18 01:14:02',0,NULL,3,1,1,1,'LK184100374CN ','挑一下发好的 '),(22977,783945653001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.95,'hermeshine','digital_jen','jennifer.reddy@bigpond.com','Jennifer Reddy','3, Fulmar Mews','Ballajura','Western Australia','AUSTRALIA','6066','0405267550','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 01:29:42',0,NULL,3,1,11,1,NULL,NULL),(22978,8881326852225491,111,'斜臂的杆',1,'',0,'photographyacc','gerson0909','fotomota@hotmail.com','GERSON MOTA','RUA ALFREDO ROBERTO VELTEN<br>13/101 BAIRRO: JARDIM MAYLI','PIÚMA','ESPIRITO SANTO','BRAZIL','29.285-000','28-3520-1041',NULL,NULL,NULL,'2012-01-18 02:03:45',0,NULL,3,1,25,1,'RT125206286HK ',NULL),(22979,8881326852596452,111,'1.6*2.1  蓝色背景布',1,'',0,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884',NULL,NULL,NULL,'2012-01-18 02:09:56',0,NULL,3,0,21,1,'RA184548882CN ',NULL),(22980,848503091017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','au2ru','au22ru@gmail.com','Alex James','4 Asti Place','Berwick','Victoria','AUSTRALIA','3806','0478224322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 03:41:30',0,NULL,3,1,11,1,NULL,NULL),(22981,789107961018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',5.08,'photographyacc','trickythepom','richhollow@smartchat.net.au','Richard Holloway','3 Pacific Avenue','Atwell','Western Australia','AUSTRALIA','6164','0894987883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 03:44:07',0,NULL,3,1,11,1,NULL,NULL),(22982,783990963001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',5,'AA1312',7.5,'hermeshine','jsb_tech','jeff@codefusion.com','Codefusion Communications Inc.','29 Gervais Drive<br>Suite 310','Toronto','ON','CANADA','M3C 1Y9','(416) 335-9390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 04:28:15',0,NULL,8,1,17,0,NULL,NULL),(22983,783990962001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','jsb_tech','jeff@codefusion.com','Codefusion Communications Inc.','29 Gervais Drive<br>Suite 310','Toronto','ON','CANADA','M3C 1Y9','(416) 335-9390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 04:28:15',0,NULL,8,1,17,0,NULL,NULL),(22984,827917597002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',3,'AA3317',17.85,'hermeshine','jsb_tech','jeff@codefusion.com','Codefusion Communications Inc.','29 Gervais Drive<br>Suite 310','Toronto','ON','CANADA','M3C 1Y9','(416) 335-9390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 04:28:16',0,NULL,3,1,3,1,'RA184548896CN ','麂皮   5 \r橡胶遮光罩 58mm  1\r绿叶 渐变镜 58mm   3'),(22985,929125183015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','buyingyeah','buying007@live.com.au','george stephan','18 Tarrant Drive','Mudgeeraba','Queensland','AUSTRALIA','4213','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-18 04:51:17',0,NULL,3,1,11,1,NULL,NULL),(22986,789147009018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','scottm2468','sjmorphew@hotmail.com','Scott Morphew','3 Adelaide Circuit','BEENLEIGH','Queensland','AUSTRALIA','4207','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-18 07:04:57',0,NULL,3,0,11,1,NULL,'1.6*2.1  白色'),(22987,783220263001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','nfal42','plopes16@sapo.pt','Nuno Lopes','Rua Tristao Vaz Teixeira<br>Nº5 3º Frente','Sintra','Rio de Mouro','PORTUGAL','2635-399','+351962995065','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-18 09:40:39',0,NULL,3,1,24,1,NULL,NULL),(22988,8881326933447838,111,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',0,'hutongstore','miky31694','mike31694@hotmail.com','Michael CRESSON','30 rue Antonin Bacou','Saint Alban','Midi-Pyrénées','FRANCE','31140','0619642070',NULL,NULL,NULL,'2012-01-19 00:37:27',0,NULL,3,1,3,1,'RA184534747CN ',NULL),(22989,8881326936746139,111,'双灯头',1,'',0,'hutongstore','sarnysandwich1','sandrahamiltonx@hotmail.com','sandra baitrum','27 chittock mead','basildon','Essex','UNITED KINGDOM','SS14 1RW','01268543340',NULL,NULL,NULL,'2012-01-19 01:32:26',0,NULL,3,1,3,1,'RA184534755CN ',NULL),(22990,783468862001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','sugarplum_jewellery','i_killed_the_radio_star@hotmail.com','Sally Gilbert','31 Marsh Street<br>Maidstone','Melbourne','Victoria','AUSTRALIA','3012','0421766568','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-20 00:09:31',0,NULL,3,0,11,0,NULL,NULL),(22991,924748516015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','justinpees','mister_pees@hotmail.com','justin pees','553A Gagne','Montreal','QC','CANADA','H8P 3H5','(514) 243-4234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-20 14:38:38',0,NULL,5,0,18,0,NULL,NULL),(22992,924826294015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','justinpees','mister_pees@hotmail.com','justin pees','553A Gagne','Montreal','QC','CANADA','H8P 3H5','(514) 243-4234','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-20 14:39:08',0,NULL,3,0,11,0,NULL,NULL),(22993,8881327112250519,111,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'aliexpress','1006347137','lumem@lumem.ind.br','julio cezar pereira	','Rodovia da Uva , 4839 Pq do Embu','Colombo','Parana','BRAZIL','83402000','+55 41 36565385',NULL,NULL,NULL,'2012-01-21 02:17:30',0,NULL,3,1,25,1,'RT125535300HK ','AD1198*1\r'),(22994,8881327112978847,111,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',24.99,'aliexpress','1006335228','pryanik87@list.ru','Bulat','N-Maktama Sadykovoi 23 Street Sadykovoi the house 23','Almetyevsk','Tatarstan','RUSSIAN FEDERATION	','423440','+7 937 5837311',NULL,NULL,NULL,'2012-01-21 02:29:38',0,NULL,3,1,3,1,'RA184536059CN',NULL),(22995,8881327113682153,111,'New Camera protector case bag f Nikon D40 D60 D3000 D3100 Size:S',1,'AD1171',8.99,'aliexpress','1006356666 ','nicolas.felber@gmail.com','Nicolas Felber	','PickPost 86102024 Bankstrasse 2','Uster','Zurich','SWITZERLAND','8610','+041 79 6094667',NULL,NULL,NULL,'2012-01-21 02:41:22',0,NULL,3,1,21,1,'RA184536310CN ',NULL),(22996,8881327205353240,111,'New Studio 1000W Continuous Lighting kit with 3x6m Green backdrop',1,'AKT063',211.99,'aliexpress','1006351505','adrienperthuis@hotmail.com','Adrien PERTHUIS	','75 Avenue de la Republique','BESSANCOURT','FRANCE','FRANCE','95550','+0 33 0620203920',NULL,NULL,NULL,'2012-01-22 04:09:13',0,NULL,3,1,5,1,'Cp244674868CN ','欧标 220v \r多送一个220v 115w灯泡'),(22997,8881327205425908,111,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0018',78.99,'aliexpress','1006351506','adrienperthuis@hotmail.com','Adrien PERTHUIS	','75 Avenue de la Republique','BESSANCOURT','FRANCE','FRANCE','95550','+0 33 0620203920',NULL,NULL,NULL,'2012-01-22 04:09:13',0,NULL,7,0,18,0,NULL,NULL),(22998,8881327205473314,111,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20 ft)',1,'AO0050',69.02,'aliexpress','1006351507','adrienperthuis@hotmail.com','Adrien PERTHUIS	','75 Avenue de la Republique','BESSANCOURT','FRANCE','FRANCE','95550','+0 33 0620203920',NULL,NULL,NULL,'2012-01-22 04:09:13',0,NULL,7,0,18,0,NULL,NULL),(23003,8881327409776732,111,'45w x 1',1,'',0,'hutongstore','llueveylasgotaspoeticasmeexaltan','patricioreig@gmail.com','Patricio Reig','Concilio de Trento 313 pl.14','Barcelona','Cataluña','SPAIN','08020','626684429',NULL,NULL,NULL,'2012-01-24 12:56:16',0,NULL,3,0,21,1,'RA184536323CN ',NULL),(22999,8881327205937995,111,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.99,'aliexpress','1006365021','balabimbox@gmail.com','Dmitry Gorev	','Shilkinskaya 15, 366','Vladivostok','Primorskiy Kray	','RUSSIAN FEDERATION	','690066','+7 950 2812730',NULL,NULL,NULL,'2012-01-22 04:18:57',0,NULL,3,1,3,1,'RA184536155CN ',NULL),(23000,782165583001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','13jpierre','jean.pierre1@videotron.ca','Jean-Pierre Bernard','362 rue de champs','Boucherville','QC','CANADA','J4B6N7','(450) 641-1311','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-22 20:57:10',0,NULL,3,1,3,1,'RA184536062CN ',NULL),(23001,8881327376434542,111,'New 68\"inch/1720mm Pro Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',78.99,'aliexpress','1006382376','efr_vadim@mail.ru','Vadim Efremov	','Tvardovskogo 16 - 261','Balashikha','Moskovskaya obl	','RUSSIAN FEDERATION	','143900','+7 916 6503936',NULL,NULL,NULL,'2012-01-24 03:40:34',0,NULL,3,1,17,0,NULL,NULL),(23002,8881327376499813,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',1,'AA1310',6.99,'aliexpress','1006382377','efr_vadim@mail.ru','Vadim Efremov	','Tvardovskogo 16 - 261','Balashikha','Moskovskaya obl	','RUSSIAN FEDERATION	','143900','+7 916 6503936',NULL,NULL,NULL,'2012-01-24 03:40:34',0,NULL,3,1,5,1,'Cp244674885CN ','lenspen * 1\r三脚架 伟峰 WF-6663A * 1'),(23004,8881327464765339,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head',1,'AE1603',30.99,'aliexpress','1006390910','samosa1@mail.ru','Andrey Samokhvalov	','Rostovka 9-67','Omsk','Omskaya obl.	','RUSSIAN FEDERATION	','644527','79136004476',NULL,NULL,NULL,'2012-01-25 04:12:45',0,NULL,3,1,3,1,'RA184536076CN ',NULL),(23005,8881327465009907,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag',1,'AD1183',92.99,'aliexpress','1006394502','marco.baretta@gmail.com','Marco Baretta	','45 merrick beach rd','Merricks beach	','Victoria','AUSTRALIA	','3926','+61 416767643',NULL,NULL,NULL,'2012-01-25 04:16:49',0,NULL,3,1,4,1,'YW868896891CN ',NULL),(23006,909531816016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','mrmous','mous@live.nl','Maurice Coonen','Stadhoudersstraat 115','ARNHEM','','NETHERLANDS','6828 SH','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-25 23:40:56',0,NULL,3,0,24,1,'30119369862\r ',NULL),(23007,8881327570726099,111,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',15.99,'aliexpress','1006406811','mohwar@hotmail.com','Nail Adam	','30 Hazel Close','Brentford	','Middlesex	','UNITED KINGDOM	','tw88ng','+44 0208 2308183',NULL,NULL,NULL,'2012-01-26 09:38:46',0,NULL,3,1,3,1,'RA184536080CN ',NULL),(23008,8881327632224000,111,'x2 45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',2,'AKT007',33.98,'aliexpress','1006415872','1@1.1','ph thevenon - MOSAIQUE	','18 rue neuve','dax','landes	','FRANCE	','40100','+033 0973842113',NULL,NULL,NULL,'2012-01-27 02:43:44',0,NULL,3,1,3,1,'RA184536093CN ','一共4个 '),(23009,8881327632815598,111,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006417976','anel61@mail.ru','Elena Osipova	','Dubninskaja 16-1-16','Moscow','Moscow','RUSSIAN FEDERATION	','127540','+7 495 4809313',NULL,NULL,NULL,'2012-01-27 02:53:35',0,NULL,3,1,3,1,'RA184536014CN ',NULL),(23010,8881327633216166,111,'67mm 67 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon',1,'AB1305',5.49,'aliexpress','1006419790','axel.flam@gmail.com','Alexey Kuznecov	','ul.bakovskaya, d.2, kv.43,','g.Odincovo,	','Moskovskaya oblast,	','RUSSIAN FEDERATION	','143005','+7 916 183-94-24',NULL,NULL,NULL,'2012-01-27 03:00:16',0,NULL,3,1,3,1,'RA184536028CN ',NULL),(23011,8881327633559187,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush',1,'AA1310',6.99,'aliexpress','1006422044','krom2000@pisem.net','Konstantin Myalitsin	','Parashyutnaya st. 33/1-116','Saint-Petersburg	','--	','RUSSIAN FEDERATION	','197371','+7 906 2612681',NULL,NULL,NULL,'2012-01-27 03:05:59',0,NULL,8,1,17,0,NULL,NULL),(23012,8881327633609134,111,'IR Remote Control for Sony a230/a330/a450/a500/a700',1,'AA2203',5.99,'aliexpress','1006422045','krom2000@pisem.net','Konstantin Myalitsin	','Parashyutnaya st. 33/1-116','Saint-Petersburg	','--	','RUSSIAN FEDERATION	','197371','+7 906 2612681',NULL,NULL,NULL,'2012-01-27 03:05:59',0,NULL,3,1,3,1,'RA184536102CN ','爵影红外 sony * 1 \rlenspen * 1'),(23013,8881327634222044,111,'Atheros AR5B93 WiFi Wireless Half Mini PCI-E Card 300Mbp',2,'WLAT008',17.98,'aliexpress','1006420482','trifonov@inbox.ru','Vitaly Trifonov	','yl. Krasnaya Presnia, dom. 23 korpys 1, kv. 97','Moscow','Moscow','RUSSIAN FEDERATION	','123022','+7 905 530-50-90',NULL,NULL,NULL,'2012-01-27 03:17:02',0,NULL,7,0,18,0,NULL,NULL),(23014,935122464015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','photodepiction','eventdepiction@gmail.com','Spencer William','Jackdaw Studio<br>Unit D, The Paintworks, Bath Road','Bristol','Bristol','UNITED KINGDOM','BS4 3EH','07527229334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 00:44:35',0,NULL,8,1,17,0,'RA184536045CN  ',NULL),(23015,935163455015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','photodepiction','eventdepiction@gmail.com','Spencer William','Jackdaw Studio<br>Unit D, The Paintworks, Bath Road','Bristol','Bristol','UNITED KINGDOM','BS4 3EH','07527229334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 03:04:30',0,NULL,3,1,3,1,'RA184536045CN ','伞式柔光箱 60×90cm   2 '),(23016,788675847001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','fashionandtyme','rwalt11@yahoo.com','Rita Walters','2870 N Towne Ave<br>Apt 146','Pomona','CA','UNITED STATES','91767-2037','(909) 489-4744','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 05:16:38',0,NULL,3,0,1,1,'LK187081201CN ','发信确认颜色，\r已回信，等黑色'),(23017,794134950018,280779017578,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',14,'photographyacc','exposurenet','exposure@rogers.com','Alff Henry','48 Ken Wagg Cress.','Stouffville','ON','CANADA','L4A 0J7','(905) 591-1483','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 05:47:40',0,NULL,3,1,11,1,'BJ01669664 ',NULL),(23018,788700111001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fremean','ebay@priya.2y.net','Shannon Wynter','79 Rosemary St','Caboolture','Queensland','AUSTRALIA','4510','0405060165','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 07:54:16',0,NULL,3,1,11,1,'BJ01669674 ',NULL),(23019,794159996018,280774576148,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',37.99,'photographyacc','ouh_desire','zaitsev.nn@gmail.com','Alexander Zaitsev','Chaadaeva 8-108','Nighniy Novgorod','Nizhegorodskaya obl','RUSSIAN FEDERATION','603035','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 08:10:16',0,NULL,3,1,3,1,'RA184536218CN ','欧标 '),(23020,619915380004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',3,'AD1219',10.5,'hermeshine','fodi64','fojola@digikabel.hu','Fodor Jozsef','Tulipan u. 1. II/8.','Bekescsaba','','HUNGARY','5600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 09:35:01',0,NULL,3,1,11,1,'BJ01714477\r ',NULL),(23021,832826473002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','imaxtasty','max@tastyconcepts.es','maksimiliano sablayrrolles','c/ Ignacio Ellacuria 8, 4 piso C','madrid','Madrid','SPAIN','28017','917130671','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-28 09:49:19',0,NULL,3,1,12,1,'3125479464 ','欧标 '),(23022,832845508002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','2011akam','akamspog@yahoo.com','Akam Pertamawan','Jl. Melati Bintang no.1<br>Bukit Palem','Cilegon','Banten','INDONESIA','42434','+62818376666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 10:50:46',0,NULL,3,1,2,1,'30119365360\r ',NULL),(23023,788786606001,110524447188,'32\" 80CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3301',15.98,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:00:19',0,NULL,8,1,17,0,NULL,NULL),(23024,832887120002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','richardg2970','richardgittings@ymail.com','Richard Gittings','1826 E Lakeshore Dr','Carriere','MS','UNITED STATES','39426-7804','(504) 912-4848','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 13:00:32',0,NULL,3,1,21,1,'RA184536337CN ',NULL),(23025,788787530001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',59.98,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:02:56',0,NULL,8,1,17,0,NULL,NULL),(23026,832890570002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-28 13:06:40',0,NULL,3,1,5,1,'Cp244674871CN ','反光板  80cm 5合1   1\r反光板 100*150 40*60 5合1   1\r反光板支架    2\r '),(23027,788794537001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','fernando.fabiao562012','fernando.fabiao56@gmail.com','Fernando Fabião','PLASFIL - Plásticos da Figueira, SA<br>Zona Industrial da Gala, Lote 6','FIGUEIRA DA FOZ','','PORTUGAL','3080-852','+351919353008','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:23:35',0,NULL,3,1,5,1,'CP244674854CN',NULL),(23028,788805313001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','sarahjwentzell','sarahjwentzell@hotmail.com','sarah sweeny','308-197 dufferin street','bridgewater','NS','CANADA','B4V2G9','(902) 543-0055','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 13:52:10',0,NULL,8,0,17,0,NULL,NULL),(23029,788807785001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',1,'AO0005',20.8,'hermeshine','sarahjwentzell','sarahjwentzell@hotmail.com','sarah sweeny','308-197 dufferin street','bridgewater','NS','CANADA','B4V2G9','(902) 543-0055','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 13:59:56',0,NULL,3,0,3,1,'RA184548613CN ','1.6*3  白色   1\r1.6*2.1  黑色   1\r客户回信愿意等黑色布'),(23030,916002192016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','chili2106','johnwhite0010@yahoo.co.uk','JOHN WHITE','101 VICTORIA ROAD','BROMLEY','KENT','UNITED KINGDOM','BR2 9PL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 14:14:07',0,NULL,3,1,11,1,'BJ01669671 ',NULL),(23031,832950025002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','cheko86','azazel116@hotmail.com','jose manuel garzon garcia','c/Sevilla,nº13','camas','Andalucía Ceuta y Melilla','SPAIN','41900','954395084','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-28 15:32:52',0,NULL,3,0,21,1,'RA184536345CN ','XXL  （已入库）'),(23032,832963173002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','gregoremiranda','gregorerodrigues@hotmail.com','Gregore Miranda','Rua Desembargador F. Emilio Povoa<br>Nº1269 Crimeia Leste','Goiania','Goias','BRAZIL','74660320','55 62 91960993','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 16:00:17',0,NULL,3,1,24,1,'30119373233\r ',NULL),(23033,794333959018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','velvetschmuck','molecule@iinet.net.au','Brian Liau','10 McDonald Street<br>Como','Perth','Western Australia','AUSTRALIA','6152','0406688283','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 16:07:10',0,NULL,3,1,17,0,NULL,NULL),(23034,794339695018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','velvetschmuck','molecule@iinet.net.au','Brian Liau','10 McDonald Street<br>Como','Perth','Western Australia','AUSTRALIA','6152','0406688283','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 16:19:02',0,NULL,3,1,3,1,'RA184521385CN\r ','斜臂的夹子（单轮）   1\r 反光板支架的夹子（双轮）    1'),(23035,794340689018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.5,'photographyacc','buggzy25','mybayoz@gmail.com','Wayne Burkin','9 O\'Dell Place','Vineyard','New South Wales','AUSTRALIA','2765','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-28 16:20:31',0,NULL,3,1,2,1,'30119364704\r ',NULL),(23036,935451929015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','pudzi82','kosa_25@o2.pl','ANNA OSTRACH','29 NEW ROAD<br>EXNING','NEWMARKET','Suffolk','UNITED KINGDOM','CB8 7JP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 16:27:21',0,NULL,3,1,11,1,'BJ01669675 ',NULL),(23037,788886644001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','edmizaca','emzdistributors@hotmail.com','Edson Zapata','URB.COSTA NORTE CALLE ARENA 198','HATILLO','PR','UNITED STATES','00659','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-28 16:53:15',0,NULL,3,1,1,1,'LK188192141CN\r ',NULL),(23038,832995618002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','christophermuckle1234','nvent@att.net','Christopher Muckle','53 Copperfield Dr','Madison','CT','UNITED STATES','06443-1887','(203) 747-5198','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-28 17:02:26',0,NULL,3,1,1,1,'LK182832535CN\r ',NULL),(23039,788916308001,110606834550,'Tungsten bulb 800W for redhead light  X 5 3200K 220V',2,'AKT059',59.98,'hermeshine','pristipoma','aplapa@gmail.com','Anatoly Lapshov','Tuhachevskogo street 11-24','Saint-Petesburg','','RUSSIAN FEDERATION','195253','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 17:48:15',0,NULL,3,1,3,1,'RA184536283CN ','10个 \r再有订单补两个800w  220v 灯泡\r2012年3月5日'),(23040,788915378001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',1,'AO0005',20.8,'hermeshine','69alma','svideo@globonet.hu','Olej Jámos','Petőfi út 14','Mezőberény','','HUNGARY','5650','+36309386892','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 17:53:02',0,NULL,5,0,21,1,NULL,'1.6mx3m 绿色 \r这票已经发了吧'),(23041,788935054001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','2naumannik1982','naumannik2@mail.ru','Андрей Науменко','Российская Федерация<br>Курчатова, дом 5, кв. 318','Волгоград','Волгоградская область','RUSSIAN FEDERATION','400059','8-905-333-63-36','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 18:22:43',0,NULL,3,1,3,1,'RA184536221CN ','apartment 318. \rKurchatov street, house 5, \rcity of Volgograd, \r400059, Russian Federation,\rPhone +7-905-333-63-36.\r\r电话号码有点不一样\r实重： 1.688kg\r泡重： 6.6kg\r\r\r\r\r\r '),(23042,794407440018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','33region','kolpakov921@gmail.com','Dmitry Kolpakov','Sovetskaya 29A-24','Murom','Vladimirskaya oblast`','RUSSIAN FEDERATION','602267','+79209032440','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-28 18:19:36',0,NULL,3,1,3,1,'RA184536235CN ','XL '),(23043,935568601015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ewel69','mrrrauuu@o2.pl','Ewelina Dobrosiewicz','58 Appleby Way','Lincoln','Lincolnshire','UNITED KINGDOM','LN6 0BU','07731393627','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 19:15:34',0,NULL,3,1,3,1,'RA184536252CN ',NULL),(23044,788974882001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','tygrrr_eb','tygrrr@seznam.cz','Zuzana Kovarikova','Nad Kajetankou 1402/3b','Praha','','CZECH REPUBLIC','16900','(0420) 774 214 723','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 19:32:34',0,NULL,3,1,3,1,'RA184536249CN ',NULL),(23045,833085550002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','msantos.1964','m.santos1964@uol.com.br','Marcelo dos Santos','Av. Dr. Durval Accioli, 215','Sao Carlos','Sao Paulo','BRAZIL','13564-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 19:40:16',0,NULL,3,1,3,1,'RA184536164CN ',NULL),(23046,788982336001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','66jewell','trevert@excite.com','Trevor Powell','66 Jewell St','Red Deer','AB','CANADA','T4P 3W3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 19:46:02',0,NULL,3,1,11,1,'BJ01669672 ',NULL),(23047,833094842002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','proftcc2012','proftcc@gmail.com','Ronnie Farias','Rua Monsenhor José Paulino 1071','natal','RN','BRAZIL','59022-200',' 558488040416','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 19:56:06',0,NULL,3,1,24,1,'30119367342\r ',NULL),(23048,916221578016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',29.98,'hutongstore','wilsonfreitas10','wilsonantoniodefreitas@bol.com.br','Wilson Antônio de Freitas','Rua 98, nº 6<br>Bairro João XXIII','Timóteo','Minas Gerais','BRAZIL','35.180-364','3187183484','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 19:57:46',0,NULL,3,1,5,1,'CP244674620CN\r','50-70柔光棚 通用塑料卡口    4'),(23049,935592117015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','pink_van_man','ebay@pinkvan.com','Richard Bryan','Lime Tree Farm,<br>Streetway','Wyberton, Boston','Lincolnshire','UNITED KINGDOM','PE20 1BE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 19:58:29',0,NULL,3,1,2,1,'30119362862\r ',NULL),(23050,916240380016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','mark-mx5','mark.ball@sky.com','MARK BALL','32 WINDERMERE GARDENS<br>TOTTON','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO40 3JZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-28 20:24:18',0,NULL,3,1,11,1,'BJ01669670 ',NULL),(23051,789010445001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','fjcamelo','fjcfpereira@gmail.com','Fernando Pereira','Rua de Zambeze, 289','Porto','','PORTUGAL','4250-505 Por','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 20:39:11',0,NULL,3,1,24,1,'30119372275\r ',NULL),(23052,789003370001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','alexey.camponotus','alex.camponotus@gmail.com','Alexey Vasilenko','ulitsa Akademika Kargina, dom 40, korpus 1, kvartira 152','Mytishy','Moskovskaya oblast','RUSSIAN FEDERATION','141007','+79099691337','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 20:25:35',0,NULL,3,1,5,1,'Cp244674908CN ',NULL),(23053,789017860001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',29.99,'hermeshine','xavier_pr14','xavier_pr14@yahoo.com','Eric Aleman','HH13 Calle 40','Canovanas','PR','UNITED STATES','00729-4111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-28 20:58:12',0,NULL,3,1,21,1,'RA184536266CN ',NULL),(23054,789023885001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','hapening','vuitton@three.blackberry.com','Nixon Tjen','10 Dame Mary Gilmore Place','Oakleigh East','Victoria','AUSTRALIA','3166','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 21:05:24',0,NULL,3,1,3,1,'RA184536031CN ','新地址：\rNixon Tjen\r10 Dame Mary Gilmore Place\rOakleigh East 3166\rMelbourne, VIC\rAustralia\r\r '),(23055,789042343001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','oltmannv','vanessa@oltmann.ca','Muse Creations Inc','910 St David Street','Nanaimo','BC','CANADA','V9S2H9','(250) 755-1610','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 21:43:59',0,NULL,3,1,11,1,'BJ01669673 ',NULL),(23056,789057400001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','garciamompean123','mariomompe@hotmail.es','mario garcia mompean','c la union 18','portman','Murcia','SPAIN','30364','968548253','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 22:20:08',0,NULL,3,0,22,1,NULL,'发信确认颜色,已回信\r黑色有货之后发黑色'),(23057,789078216001,110498125541,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',83,'hermeshine','julio2410','julioruiz1@reterioja.net','JULIO RUIZ NALDA','ANTONIO MACHADO 24 1º A','CALAHORRA','La Rioja','SPAIN','26500','629119776','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-28 23:13:54',0,NULL,3,1,4,1,'YW868896902CN ',NULL),(23058,916341734016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','gribouboucan','achille2009@gmail.com','Jean-luc GRILLOT','11 sq vitruve','Paris','Ile-de-France','FRANCE','75020','07 61 94 88 19','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-28 23:27:49',0,NULL,3,1,4,1,'YW868896924CN ',NULL),(23059,833181609002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','zombiecruncher','denis.valeev@gmail.com','Denis Valeev','ul. Nizhegorodskaya d. 25 kv. 317','Moscow','MOSCOW','RUSSIAN FEDERATION','109029','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-28 22:55:36',0,NULL,3,1,3,1,'RA184536178CN ',NULL),(23060,916346356016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','homezd8000','andrew_tihi@yahoo.com','Tihi Andrei','Calle Belice , Nr  1','Roquetas de Mar','Andalucía Ceuta y Melilla','SPAIN','04740','642878685','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-28 23:38:26',0,NULL,3,1,22,1,'BJ01669548\r ',NULL),(23061,789096968001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','kampanilla86','azaharadg@hotmail.com','Azahara Dios García','del Nogal, 16, 2º 5','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14006','670312683','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 00:10:23',0,NULL,3,1,21,1,'RA184536297CN ',NULL),(23062,833243035002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','paul10002008','bp00@bell.net','Pawel Biernat','2542 Argyle Road Apt#605','Mississauga','ON','CANADA','L5B2H5','(905) 279-1290','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 02:11:27',0,NULL,3,1,3,1,'RA184536204CN ',NULL),(23063,789148584001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','maxtec1','maxtec1@yahoo.com','Richard Maxfield','113 W Avenue G','Garland','TX','UNITED STATES','75040','(214) 494-4737','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-29 03:28:59',0,NULL,3,1,1,1,'LK187744957CN\r ',NULL),(23064,789159574001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','drmiguel133','drmiguel@estadao.com.br','Miguel Sousa','rua Paz n.1 apto.22','Santos','São Paulo','BRAZIL','11045-520','(13)32891718','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-29 04:17:08',0,NULL,3,1,25,1,'RT125535786HK ',NULL),(23065,854402039017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','jglo8410','jlgloser@bigpond.com.au','John Gloser','Preferred Gas Plumbing Supplies<br>Unit 1/9 Freemantle Street','Burleigh Heads','Queensland','AUSTRALIA','4220','0755220507','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 05:11:44',0,NULL,3,1,11,1,'BJ01669678 ',NULL),(23066,916453592016,260814193555,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.80m',1,'AO0023',169,'hutongstore','zeblechov','bag-of-monkeys@hotmail.com','Stephen Murphy','17<br>Rossdarragh Hill','Portlaoise','Laois','IRELAND','00','0877517987','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 05:45:10',0,NULL,3,1,4,1,'YW868896880CN ',NULL),(23067,833297951002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','actionbleem','phaitoons@hotmail.com','phaitoon sutunyawatchai','117/4 Bumroungraj Road Tumbon Watket','muang','Chiang Mai','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-29 06:15:00',0,NULL,3,1,6,1,'EE667838716CN','英标 '),(23068,935850337015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','zmeya11','kozhievk@gmail.com','Kazbek Kozhiev','K.Marksa 46-38','Vladikavkaz','North Osetia','RUSSIAN FEDERATION','362003','901-497-0001','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 06:35:17',0,NULL,3,1,11,1,'BJ01669681 ',NULL),(23069,833334254002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',245,'hermeshine','anton-kant','kant-irk@yandex.ru','Anton Kabardin','ul.Michurina 7 , kv 8','Irkutsk','oblIrkutskay','RUSSIAN FEDERATION','664013','79025123979','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 09:07:16',0,NULL,3,1,5,1,'CP244674899CN ','C以外再发\r可调ND镜 77mm    1 \r\r欧标'),(23070,916510190016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','sufertashu','mihai.stanimir@gmail.com','Mihai Stanimir','Petre Ramneantu nr 15A ap 12','Timisoara','Timis','ROMANIA','300595','0040764177508','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-29 09:09:56',0,NULL,3,1,22,1,'','已发货 '),(23071,789226252001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','feyn333','tlsmith@caltech.edu','Tristan L. Smith','2806 Regent St.<br>Apt. A','Berkeley','CA','UNITED STATES','94705','','NoPaymentFailure','CheckoutComplete','Other','2012-01-29 09:32:45',0,NULL,3,1,1,1,'LK188502356CN ',NULL),(23072,789229254001,110717761104,'New 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',36.99,'hermeshine','anton-kant','kant-irk@yandex.ru','Anton Kabardin','ul.Michurina 7 , kv 8','Irkutsk','oblIrkutskay','RUSSIAN FEDERATION','664013','79025123979','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 09:42:07',0,NULL,8,1,17,0,NULL,NULL),(23073,833357874002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','frenchdirector','manusapo@gmail.com','emmanuel sapolsky','8 place saint germain<br>des longs pres','boulogne billancourt','Ile-de-France','FRANCE','92100','+33674007184','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-29 10:08:17',0,NULL,3,0,17,0,NULL,NULL),(23074,789239915001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','frenchdirector','manusapo@gmail.com','emmanuel sapolsky','8 place saint germain<br>des longs pres','boulogne billancourt','Ile-de-France','FRANCE','92100','+33674007184','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 10:08:18',0,NULL,3,1,4,1,'YW868896961CN\r ',' C以外再\r法标\r2mx2m背景架     1\r1.6mx2.1m 背景布   2  白+绿\r5灯头+60-90棚      2  （转法标）\r实重：12.9\r抛重：17.1\r\r'),(23075,833357875002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','frenchdirector','manusapo@gmail.com','emmanuel sapolsky','8 place saint germain<br>des longs pres','boulogne billancourt','Ile-de-France','FRANCE','92100','+33674007184','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-29 10:08:19',0,NULL,3,1,17,0,NULL,'\r '),(23076,789239916001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','frenchdirector','manusapo@gmail.com','emmanuel sapolsky','8 place saint germain<br>des longs pres','boulogne billancourt','Ile-de-France','FRANCE','92100','+33674007184','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 10:08:18',0,NULL,3,0,17,0,NULL,NULL),(23077,916554761016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','vyciokas55','vmalisauskas@gmail.com','Vytenis Malisauskas','Bellavista,Lower Kilmoney Road','Carrigaline','Cork','IRELAND','default','0214834450','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 10:42:40',0,NULL,3,1,4,1,'YW868896876CN ',NULL),(23078,794764595018,280727837597,'Soft Camera Cover protector L Nikon D90 D7000 18-200mm',1,'AD1173',11.99,'photographyacc','deaton5151','dto@aapt.net.au','Natasha Deaton','16 Letona Place','Leeton','New South Wales','AUSTRALIA','2705','0427014548','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 11:19:23',0,NULL,3,1,11,1,'BJ01669649 ',NULL),(23079,794766327018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','netshopau','ebay@netshop.net.au','Elias Gourvelos','67 Allingham Street','Condell Park','New South Wales','AUSTRALIA','2200','0287130061','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-29 11:19:29',0,NULL,3,1,11,1,'BJ01669645 ',NULL),(23080,833399754002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','nagibatorepic','ops91@inbox.ru','Alexander Pankov','Kirova st.,124., flat 7','Perm','Perm region','RUSSIAN FEDERATION','614000','89097301557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 11:45:35',0,NULL,3,1,11,1,'BJ01669665 ',NULL),(23081,833403858002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','olim99','olsf@hotmail.com','Oscar Lim','PO Box 25','Croydon','New South Wales','AUSTRALIA','2132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 11:54:55',0,NULL,8,1,17,0,NULL,NULL),(23082,833410775002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','olim99','olsf@hotmail.com','Oscar Lim','PO Box 25','Croydon','New South Wales','AUSTRALIA','2132','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 12:07:15',0,NULL,3,1,3,1,'RA184536181CN ','伞式柔光箱 60×90cm    1\r伞式柔光箱 80cm 8角     1\r '),(23083,935999439015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','chimanathan','ccu.nathan@gmail.com','Chima Ibemere','28 Wood Close','Hatfield','Hertfordshire','UNITED KINGDOM','AL10 8TX','07507187855','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 12:25:48',0,NULL,3,1,11,1,'BJ01669666 ',NULL),(23084,936017086015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','punkrural','vmsfonseca@sapo.pt','Vitor Fonseca','WIT-Software, IC2/EN1, km185,6<br>Banhos Secos, Santa Clara','Coimbra','Coimbra','PORTUGAL','3040-032','+351916182514','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 12:55:29',0,NULL,3,1,24,1,'30119369722\r ',NULL),(23085,789333738001,110566017753,'18% Grey card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',12.68,'hermeshine','iv-skaya','elena-ivashkovskaya@rambler.ru','Elena Ivashkovskaya','59 RUE NAVIGATEURS','ST GILLES LES BAINS','Réunion','FRANCE','97434','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 13:32:12',0,NULL,3,1,11,1,'BJ01669648 ',NULL),(23086,789377260001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','raniel22','einar@bkkfiber.no','Einar Langøen','Tjødnavegen 75','Straume','Straume','NORWAY','5353','004798236130','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 14:52:17',0,NULL,3,1,24,1,'21556 ',NULL),(23087,936103272015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 15:03:12',0,NULL,8,1,17,0,NULL,NULL),(23088,916803729016,260901272264,'New Tungsten bulb 800W for redhead light X 1 3200K 220V',1,'AO0015',4.5,'hutongstore','edheds','edheds@hotmail.com','edwin li','128 Heaton Park Road','Newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','NE6 5NR','07912992636','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 16:44:57',0,NULL,3,1,11,1,'BJ01669662 ',NULL),(23089,916826181016,260660052109,'New 58mm Ring adapter for Cokin P Series Filter Holder',1,'AA2210',1.6,'hutongstore','maggottinho','maggott_inho@hotmail.com','Jose Antonio Couso Rodríguez','calle arrecife Nº6, 4ºB, Cangas del Morrazo<br>Pontevedra','Cangas del Morrazo','Galicia','SPAIN','36940','670886192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 17:06:27',0,NULL,8,1,17,0,NULL,NULL),(23090,936215605015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',1.6,'hutongstore','maggottinho','maggott_inho@hotmail.com','Jose Antonio Couso Rodríguez','calle arrecife Nº6, 4ºB, Cangas del Morrazo<br>Pontevedra','Cangas del Morrazo','Galicia','SPAIN','36940','670886192','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 17:07:19',0,NULL,3,1,2,1,'30119364822\r ','方形滤镜接口环 58mm   1 \r方形滤镜接口环 67mm   1'),(23091,916828180016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',105,'hutongstore','diixiirkazan','diixiir@gmail.com','Dmitri Kochnev','Cheluskina street, house (dom) 60, flat (kvartira) 13','Kazan','Tatarstan','RUSSIAN FEDERATION','420037','89625603803','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 17:08:49',0,NULL,3,1,5,1,'Cp244674925CN ','欧标 '),(23092,789514944001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','slickhorvatic','slickhorvatic@hotmail.com','Nicholas Horvatic','1411 Fairmont St','Cheswick','PA','UNITED STATES','15024-1460','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-29 17:53:48',0,NULL,3,1,1,1,'LK187864226CN ',NULL),(23093,789532639001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','mij909','sflynn@iolfree.ie','James Flynn','Rose Cottage<br>Knockauharast , Ballysaggart','Lismore','Waterford','IRELAND','01','0868050931','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 18:12:46',0,NULL,3,1,21,1,'RA184536270CN ',NULL),(23094,936291066015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 18:13:53',0,NULL,3,1,5,1,'CP240090849CN','4灯头 灯头 孔    2 \r50cmx70cm 的柔光箱 (配4灯头）   2\r放4个欧标头给他'),(23095,936399388015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','q-tums','fran@franguy.co.uk','Frances Guy','Amtek Engineering Solutions Ltd<br>Ferndown Ind Est','Wimborne','Dorset','UNITED KINGDOM','BH21 7RU','01202868644','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 19:30:46',0,NULL,3,0,11,1,NULL,'发信确认颜色 ,\r已回信，等黑色布'),(23096,917010032016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','kaynny','nygren.karl@gmail.com','Karl Nygren','Frejagatan 5b 2tr<br>c/o Sandström','Kalmar','','SWEDEN','39246','+46731502727','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-29 19:34:26',0,NULL,3,1,21,1,'RA184536368CN ',NULL),(23097,936422619015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','thomkaran','thomkaran@gmail.com','THOMAS KARANIKAS','EFFIMOU 3-5<br>AGIOS ARTEMIOS','ATHENS','','GREECE','11632','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-29 19:53:23',0,NULL,3,1,21,1,'RA184536371CN ',NULL),(23098,917034191016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','ernivy','sue.tyerman@hotmail.co.uk','Susan Tyerman','31 Hemingford Gardens','Yarm','Cleveland','UNITED KINGDOM','TS15 9ST','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-29 19:54:27',0,NULL,3,1,3,1,'RA184536195CN ',NULL),(23099,833801412002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','pronikkia','nikkiaredd@yahoo.com','Nikkia Redd','8300 Staplehurst Dr','Jacksonville','FL','UNITED STATES','32244','','NoPaymentFailure','CheckoutComplete','Other','2012-01-29 20:32:47',0,NULL,3,1,21,1,'RA184536385CN ',NULL),(23100,795209505018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',28.49,'photographyacc','ivan_capi','ivan_capi@hotmail.com','manuel ivan roldan giraldez','oviedo 6, casa 2','alcala de guadaira','Sevilla','SPAIN','41500','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-29 20:49:46',0,NULL,3,1,21,1,'RA184536399CN ','xl '),(23101,833890698002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',85,'hermeshine','trombonoher','trombonefather@yahoo.com','George Kukushin','Smolenskiy bulvar, 6-8, kv. 284','Moscow','Moscow','RUSSIAN FEDERATION','119034','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-29 22:47:34',0,NULL,3,1,5,1,'Cp244674911CN',' 欧标 '),(23102,936603555015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','jossse23','jossse21@hotmail.com','Jose Manuel Ramos Anton','Calle Pedro Rico numero 11 5º C','madrid','Madrid','SPAIN','28029','609316487','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-29 23:23:20',0,NULL,3,1,4,1,'YW868896913CN ',NULL),(23103,833909242002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','tuliovianna','prof@tuliovianna.org','Tulio Vianna','Rua Nestor Soares de Melo, 59 ap. 300','Belo Horizonte','Minas Gerais','BRAZIL','31160540','(55) 31 - 91919450','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-29 23:29:33',0,NULL,3,1,24,1,'30119371914\r ',NULL),(23104,917215866016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','gregsearle','greg_searle@yahoo.co.uk','Gregory Searle','Kew Green Preparatory School<br>Layton House, Ferry Lane, Kew','Richmond, London','Middlesex','UNITED KINGDOM','TW9 3AF','07515034827','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-29 23:41:54',0,NULL,3,1,3,1,'RA184536116CN ',NULL),(23105,833940844002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','cdsilva2011','chamath.d.silva@gmail.com','Chamath DeSilva','Canberra Grammar School<br>Monaro Crescent, Red Hill','CANBERRA','Australian Capital Territory','AUSTRALIA','2603','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 00:57:05',0,NULL,3,1,11,1,'BJ01669661 ',NULL),(23106,936654579015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','pudinsudeyh','adin231090@yahoo.com','muhammad saifuddin arif','40, trimbleston<br>goatstown road','clonskeagh','DUBLIN','IRELAND','14','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 01:18:27',0,NULL,3,1,24,1,'30119371903\r ',NULL),(23107,8881327888092939,111,'45W 220V 5500K Studio Light Bulb Daylight with E27 Socket',1,'AKT007',16.99,'aliexpress','1006118363','hpgc696@speedpost.net','Heeva Shahriari	','Unit 4 94 Maroubra Rd','Maroubra','New South Wales','AUSTRALIA	','2035','61 02 83239492',NULL,NULL,NULL,'2012-01-30 01:48:12',0,NULL,3,1,21,1,'RA184536408CN ','45w 220v 灯泡 *2  '),(23108,833964045002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mrazifmahmood','mohamadrazif@hotmail.com','Mohamad Razif Mahmood','No. 10, Jalan Teluk 4, Taman Tanjung,','Batu Pahat','Johor','MALAYSIA','83000','0123899450','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 01:56:35',0,NULL,3,1,25,1,'RT125862888HK\r	 ','已付$8运费'),(23109,8881327888617069,111,'New Collapsible 190cm * 140cm backdrop background light green & blue',1,'AC3304',54.99,'aliexpress','1006429939','yan9802@yandex.ru','Yana Medvedeva	','yakysheva 117 kv 2','novoibirsk','novoibirsk','NOVOIBIRSK','630009','+7 953 7815779',NULL,NULL,NULL,'2012-01-30 01:56:57',0,NULL,3,1,3,1,'RA184536120CN ',NULL),(23110,8881327888935069,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2402',23.99,'aliexpress','1006440941','alla_nan@yahoo.com','Alla Egorova	','Gamalei 3-4','Moscow','Russia','RUSSIAN FEDERATION	','123098','+7 926 2490339',NULL,NULL,NULL,'2012-01-30 02:02:15',0,NULL,3,1,3,1,'RA184536133CN ',NULL),(23111,8881327889097588,111,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',14.99,'aliexpress','1006459358','snysny@ya.ru','Bukreeva Alla	','124498, Moscow, Zelenograd, Korp 456, Kv 125','Moscow Zelenograd	','Moscow','RUSSIAN FEDERATION	','124498','+8 915 3348930',NULL,NULL,NULL,'2012-01-30 02:04:57',0,NULL,3,1,3,1,'RA184536147CN ',NULL),(23112,834010122002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','doggy.styles','doggystyles@optusnet.com.au','David Latimore','12 Salisbury St<br>Penshurst','NSW','New South Wales','AUSTRALIA','2222','0400484215','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 04:08:12',0,NULL,3,1,11,1,NULL,NULL),(23113,855179060017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','bymblack','ebay@bymblack.com','Alana Black','91 Chestwood Crescent','Sippy Downs','Queensland','AUSTRALIA','4556','0754770171','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 04:12:02',0,NULL,3,1,11,1,NULL,NULL),(23114,8881327897981583,111,'反光伞+单灯头',1,'',0,'hutongstore','miky31694','mike31694@hotmail.com','Michael CRESSON','30 rue Antonin Bacou','Saint Alban','Midi-Pyrénées','FRANCE','31140','0619642070',NULL,NULL,NULL,'2012-01-30 04:33:01',0,NULL,3,1,3,1,'RA184521377CN\r ','欧标   '),(23115,855185452017,270750635851,'Neoprene Camera Cover Case for Canon 450D 550D M Size ',1,'AC2305',5.98,'photographyacc','mantas65','voyzey@exemail.com.au','David Voyzey','13 Graham st','Boat Harbour','New South Wales','AUSTRALIA','2316','0249819092','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 04:38:15',0,NULL,3,1,11,1,NULL,NULL),(23116,834010088002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','eluve','mekans@terra.es','Jesus Jimenez Romero','C/Gran Canaria, 28, Urb. Parque del Retiro','Jerez de la Frontera','Andalucía Ceuta y Melilla','SPAIN','11406','620440613','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 04:05:11',0,NULL,3,1,21,1,'RA184521244CN\r ',NULL),(23117,789882137001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','suwen','suwen.chee@gmail.com','Suwen Chee','C-10-1, Megan Avenue II<br>12 Jalan Yap Kwan Seng','Kuala Lumpur','','MALAYSIA','50450','0192666910','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-30 04:46:33',0,NULL,3,1,25,1,'RT125715638HK ',NULL),(23118,834025523002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','(819) 239-3099','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 05:07:43',0,NULL,3,1,3,1,NULL,' '),(23119,789891984001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','flashorl','h1nt@mail.ru','Ludmila Borzenkova','Katykova d.1, kv.44','Mtsensk','Orlovskaya obl','RUSSIAN FEDERATION','303031','(920)2878714','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 05:32:08',0,NULL,3,1,3,1,'RA184521289CN ',NULL),(23120,834030379002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','kpkmur2010','kpkmur@yandex.ru','Belyaev Vitaliy','st. poljarnye zori 33/1-86','Murmansk','','RUSSIAN FEDERATION','183025','+7(911)311-9988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 05:33:27',0,NULL,3,1,5,1,'CP244674593CN ',NULL),(23121,8881327905057520,111,'灯架最上面配件',1,'',0,'hutongstore','orenspl56','orenspl@mail.ru','Ilya Zverev Sergeevich','pr.Gazovikov 24<br>KB 48','Orenburg','Orenburg Area','RUSSIAN FEDERATION','460051','89619439839',NULL,NULL,NULL,'2012-01-30 06:30:57',0,NULL,3,0,3,1,'RA184538134CN\r','灯架最上面的配件，红头灯网格，一个800w 220v灯泡 '),(23122,8881327905270364,111,'一个4灯头，2个50-70 柔光箱',1,'',0,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA','10040','',NULL,NULL,NULL,'2012-01-30 06:34:30',0,NULL,3,0,21,1,'RA184521292CN\r ','欧标 '),(23123,936761115015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','paultickle2011','ticklep@live.com','Paul Tickle','75 Triq il Vitorja','B\'kara','','MALTA','BKR 2695','0035679463544','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 06:43:38',0,NULL,3,1,5,1,'CP244674602CN ','白加灰 ');
INSERT INTO `hmsh_ebay_transaction` VALUES (23124,8881327906367357,111,'天涯方形滤镜系列 10片装 盒子',1,'',0,'hutongstore','1205osiris','lumiere1205@hotmail.com','Ben Yap','Blk 530 Bukit Batok St 51#02-34','default','','SINGAPORE','650530','92293913',NULL,NULL,NULL,'2012-01-30 06:52:47',0,NULL,3,0,25,1,'RT125714487HK\r ','再加 天涯方形滤镜  ND8\r是天涯10片装盒子的盖'),(23125,8881327911212834,111,'50-70通用卡口柔光箱里的卡口',1,'',0,'hermeshine','falkone2001','tfalkovskyy@yahoo.co.uk','Taras Falkovskyy','8 Brodivska St.','Zolochiv','Lviv','UKRAINE','80700','+380973149336',NULL,NULL,NULL,'2012-01-30 08:13:32',0,NULL,3,0,21,1,'RA184521301CN\r ','塑料的 '),(23126,936798033015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','freddiepinoy','alfredohobden@gmail.com','Alfredo James Hobden','32B Dixon Street','Swindon','Wiltshire','UNITED KINGDOM','SN1 3PL','01793979286','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 09:10:37',0,NULL,3,1,3,1,'RA184520561CN ',NULL),(23127,834072298002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vsaxis','vsaxis@gmail.com','Sergey A Vasyuk','Kahovka d.16 k.1 kv.6','Moscow','','RUSSIAN FEDERATION','117461','+79261700999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 09:10:48',0,NULL,3,1,11,1,NULL,NULL),(23312,790952036001,110553841885,'Studio Light 2300W Continuous Lighting Kit Set ',1,'AKT041',230,'hermeshine','sergunya72','zs_sergey@list.ru','Sergey Koryukaev','ul. Stroiteley, d.49<br>korp. 1, kv. 74','Tyumen','RU','RUSSIAN FEDERATION','625055','7-922-480-10-50','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 11:37:16',0,NULL,5,1,5,1,'CP244548330CN\r ','欧标\rC里面布换成1.6*3m 黑，白，灰\r已发货.........'),(23128,789945780001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','vidas13','karavidas13@hotmail.com','Dionisis Karavidas','B Par Tsimiski 6','Katerini','Pieria','GREECE','60100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:07:20',0,NULL,3,1,24,1,'30119551851\r ',NULL),(23129,620830039004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','wow1166','geoffrey.malpas@mail.com','Geoff Malpas','8 Tindall Court<br>Alligator Creek','Townsville','Queensland','AUSTRALIA','4816','0747805002','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:12:35',0,NULL,3,1,24,1,'30119532306\r ',NULL),(23130,789951594001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','santigris','santigris@hotmail.com','Santiago Sanchez moreno','C/ Gran Vía, 17, 1-D (santiago y Mª Jose)','Cehegín','Murcia','SPAIN','30430','686143675','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:30:00',0,NULL,3,1,21,1,'RA184521332CN\r ',NULL),(23131,795485187018,280722265640,'New 10 pcs Landscape Color Filters Kit for Cokin P',1,'AKT077',42,'photographyacc','jjchircopmalta','jjchircop.com@gmail.com','JJ Chircop','7, Triq Dun Gwann Theuma','Attard','Malta','MALTA','atd2069','77112112','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 10:35:57',0,NULL,3,1,21,1,'RA184594618CN   ','SAL小包挂号便宜一些 \r已发货'),(23142,790017276001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','t0pace','topace@rocketmail.com','Edwin Tamtomo','71A Metella Road','Toongabbie','New South Wales','AUSTRALIA','2146','0298506411','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 14:40:24',0,NULL,3,1,17,0,NULL,NULL),(23132,795485836018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','typht','tripoz.typhaine@neuf.fr','Typhaine TRIPOZ','9 rue beaugeard lancelot<br>rdc gauche','Rennes','Bretagne','FRANCE','35700','02.90.02.23.49','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 10:37:56',0,NULL,3,1,11,1,NULL,NULL),(23133,834098815002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jessdaisy1993','jessicad935@hotmail.com','Jessica McGovern','16 Basico ave','Sinagra','Western Australia','AUSTRALIA','6065','0892062834','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 10:54:40',0,NULL,3,1,3,1,'RA184520575CN ',NULL),(23134,855259766017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',4,'AO0005',238.96,'photographyacc','vetals777','vitaliy.nechiporenko@gmail.com','Vitaliy Nechiporenko','pereulok SHTABNOY 6,<br>kvartira 220,','Dnepropetrovsk','','UKRAINE','49049','+38(067)563-60-64','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 11:30:14',0,NULL,3,0,5,1,'CP244674823CN ','1.6mx3m 背景布    4\r（绿色， 灰色， 蓝色， 黄色）\r2mx2m 背景架   2 （夹子）\r1.6mx2.1m 背景布   4\r（ 橙色， 棕色，粉色， 红色）\r\r已回信，等棕色布\r \r '),(23135,789961588001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','murikoff','murik70@mail.ru','Murov Sergey','Kosinskaya st., 4-2-262','Moscow','','RUSSIAN FEDERATION','111538','(916) 734-8392','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 12:21:16',0,NULL,3,1,11,1,NULL,'1.6x2.1  黄色 '),(23136,834127673002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','rasikaambe','rasika@ambepitiyage.com','Rasika Ambepitiyage','Unit: 5, Bella Vista,<br>No: 1, Wilkins Street','Mawson','Australian Capital Territory','AUSTRALIA','2607','610457899419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 12:38:46',0,NULL,3,1,3,1,'RA184520650CN ',NULL),(23137,8881327928733287,111,'canon 5Dii u盘',1,'',0,'photographyacc','atomic.blue','pete@blueturtle.com.au','Pete Hall','94 - 96 Fullarton Road','Norwood','South Australia','AUSTRALIA','5067','61883629764',NULL,NULL,NULL,'2012-01-30 13:05:33',0,NULL,3,0,3,1,'RA184520986CN\r ',NULL),(23138,789994897001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','stigmg','stig.garcia@gmail.com','Stig Morten Garcia','Bentsegt 25','Oslo','','NORWAY','0465','+4795211338','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-30 13:06:45',0,NULL,3,1,21,1,'RA184521213CN\r ','申报  Damaged lens  $20'),(23139,8881327929110912,111,'115w 灯泡',2,'',0,'hermeshine','luberon01','jaimeleluberon@hotmail.fr','Philippe chaupin','111','111','','11','11','11',NULL,NULL,NULL,'2012-01-30 13:11:50',0,NULL,3,0,3,1,'RA184521451CN\r ',NULL),(23140,8881327930406270,111,'155 的 717脚架',1,'AO0022',0,'hermeshine','anya_ab','abramovy@mksat.net','serg abramov','31, Novoselskaya str.','Nikolaev','Nikolaev region','UKRAINE','54002','+380677902355',NULL,NULL,NULL,'2012-01-30 13:33:26',0,NULL,3,0,5,1,'CP244674810CN ','申报 198 USD'),(23141,936899884015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','katonaa1','katona1@freemail.hu','Pamela Nicoara','98 Chatsworth Crescent<br>Hounslow    tw3 2pd','London','London','UNITED KINGDOM','tw3 2pd','7581227845','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 13:47:57',0,NULL,3,1,2,1,'30119552245\r\r ','\r\r\r\r '),(23143,790017167001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','t0pace','topace@rocketmail.com','Edwin Tamtomo','71A Metella Road','Toongabbie','New South Wales','AUSTRALIA','2146','0298506411','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 14:40:25',0,NULL,3,1,11,1,NULL,'橡胶遮光罩 58mm  1 \r橡胶遮光罩 52mm   1'),(23144,790028036001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','csveva','csveva@gmail.com','Karl Christoffer Sveva','Asnesåsen 4','Sandefjord','','NORWAY','3222','91915111','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 14:48:00',0,NULL,3,1,5,1,'CP244674616CN ',''),(23145,834234542002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','planksponderings','info@andrewplank.com','Andrew Plank','637 Goldie Avenue','Victoria','BC','CANADA','v9b 6c2','(250) 360-6106','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 17:20:28',0,NULL,3,0,3,1,'RA184521346CN\r ','1.6*3  灰色  1 '),(23146,790100154001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','balabalak','bala.negra@yahoo.com','Javier Moyano','C/ Isabel Clara Eugenia, 14<br>portal C, 4º D','Madrid','Madrid','SPAIN','28050','649939631','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-30 17:46:06',0,NULL,3,1,21,1,'RA184520425CN ',NULL),(23147,795646950018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.5,'photographyacc','hipermarko','marek-81@o2.pl','Marek Rykaczewski','8 Hewitt Street<br>Ground Floor, \"City Docs\"','Manchester','Lancashire','UNITED KINGDOM','M15 4GB','07851809462','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-30 17:46:49',0,NULL,3,1,2,1,NULL,NULL),(23148,937024865015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',2,'AB1202',8.4,'hutongstore','natxodom81','idomingvar@telefonica.net','IGNACIO DOMÍNGUEZ','GRAN VÍA CARLES III, 85bis','BARCELONA','Cataluña','SPAIN','08028','627470965','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 17:51:16',0,NULL,3,1,2,1,NULL,NULL),(23149,834263143002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',50,'AA1310',274.5,'hermeshine','blinker-182','blinker1983@gmail.com','Georgii Klochkov','Tovarischeskii prospekt 8-19','Saint-Petersburg','','RUSSIAN FEDERATION','193312','+79117119119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 18:27:07',0,NULL,3,1,3,1,'RA184521275CN ','不要原包装，只包笔就行 '),(23150,834307655002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','guilhermepavan','gui.pavan@hotmail.com','Guilherme Pavan','Alvaro Ribeiro, 136<br>Vila Rehder (centro)','Americana','São Paulo','BRAZIL','13465-400','(19) 3461-3037','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 19:35:07',0,NULL,3,1,17,0,NULL,NULL),(23151,834311319002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','guilhermepavan','gui.pavan@hotmail.com','Guilherme Pavan','Alvaro Ribeiro, 136<br>Vila Rehder (centro)','Americana','São Paulo','BRAZIL','13465-400','(19) 3461-3037','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 19:36:16',0,NULL,3,1,5,1,'CP244674845CN ','2B柔  2套 '),(23152,790187177001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','sabrem3','jbhrealty@comcast.net','Sarah Hollingsworth','59 Standish Rd','Wellesley','MA','UNITED STATES','02481-5318','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-30 20:15:30',0,NULL,3,1,1,1,'LK84162189C n',NULL),(23153,937135162015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',57.9,'hutongstore','lolidelosanto','jvallefdz@gmail.com','Eneroliza de los Santos Encarnacion','Luxemburgo 15, 7-3','Fuenlabrada','Madrid','SPAIN','28943','671087375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 20:18:57',0,NULL,3,1,17,0,NULL,NULL),(23154,790191987001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','daveboertje','boertje@swiftdsl.com.au','David W Boertje','PO Box 47','Swansea','New South Wales','AUSTRALIA','2281','61249720070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 20:23:16',0,NULL,3,1,3,1,'RA184521261CN ',NULL),(23155,937139769015,250600500598,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT068',65,'hutongstore','lolidelosanto','jvallefdz@gmail.com','Eneroliza de los Santos Encarnacion','Luxemburgo 15, 7-3','Fuenlabrada','Madrid','SPAIN','28943','671087375','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 20:23:22',0,NULL,3,1,4,1,'YW868896935CN','除了C以外再发\r灯架  2m  2 \r柔光箱 50-70cm 单灯头   2\r灯架包    1\r欧标\r抛重：9.54\r实重：7.845\r燕文合适'),(23156,790212867001,110790875316,'New Professional Portable Diffuser for SpeedLight sb900 sb700 580ex metz XL ',1,'AD1210',12.99,'hermeshine','sqais','genmo@sympatico.ca','Guennadi Momot','45 Carlton Street, #710','Toronto','ON','CANADA','M5B 2H9','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-30 20:59:58',0,NULL,3,1,17,0,NULL,NULL),(23157,790212868001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',2,'AD1195',58,'hermeshine','sqais','genmo@sympatico.ca','Guennadi Momot','45 Carlton Street, #710','Toronto','ON','CANADA','M5B 2H9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-30 20:59:58',0,NULL,3,1,3,1,'RA184521350CN\r ','lif通用柔光罩XL   1 \r魔术手臂11寸   2'),(23158,937194078015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','job_78','job@adslhome.dk','Jens Ole Bach','Kr. Zahrtmanns Plads 78, st','Frederiksberg','','DENMARK','DK 2000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-30 21:39:07',0,NULL,3,1,21,1,'RA184521227CN\r ',NULL),(23159,937211386015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','e_jeavons','eddie@edjeavons.co.uk','Ed Jeavons','Orphans Press, Arrow Close<br>Leominster Enterprise Park','Leominster','Herefordshire','UNITED KINGDOM','HR6 0LD','01568612460','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 22:07:15',0,NULL,3,1,3,1,'RA184520632CN ',NULL),(23160,937233341015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','shutterbugsam','sam@samanthahook.co.uk','Samantha Hook','28 Thomas Road<br>Fernwood','Newark on Tremt','Nottinghamshire','UNITED KINGDOM','NG24 3FU','01636673800','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-30 22:47:13',0,NULL,3,1,3,1,'RA184521160CN\r ',NULL),(23161,795841938018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','oz_wino','marklane@westnet.com.au','Mark Lane','46 Hermitage Road','Maiden Gully','Victoria','AUSTRALIA','3551','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-30 23:49:56',0,NULL,3,1,11,1,' ',NULL),(23162,834439278002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','bzs007','bzs07@citromail.hu','Zsolt Bodnár','Bem utca 2','Rétság','','HUNGARY','2651','+36-30-596-9993','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 00:07:07',0,NULL,3,1,24,1,'30120016006\r ',''),(23163,917853495016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','coolmrc','colineclark@hotmail.com','COLIN CLARK','3 DURHAM GROVE','EDINBURGH','Edinburgh City','UNITED KINGDOM','EH15 1PX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 00:17:05',0,NULL,3,1,11,1,NULL,NULL),(23164,790305565001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','gmzsur','cosasparafotos@gmail.com','Jose Antonio Gamez Mangas','C/ Ronda Sur  Nº 37<br>Valdelacalzada','Badajoz','Extremadura','SPAIN','06184','625622736','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 01:27:53',0,NULL,3,1,21,1,'RA184521235CN\r ',NULL),(23165,8881327975239179,111,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',0,'hermeshine','coorykoray','korayturkay@gmail.com','Koray Turkay','kurucesme mah. sakarya cad no:46<br>Osmangazi','bursa','bursa','TURKEY','16050','+902242236064',NULL,NULL,NULL,'2012-01-31 02:00:39',0,NULL,3,1,25,1,'RT125718705HK ','已付运费 '),(23166,8881327975526839,111,'New Pro 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND Filters of Cokin P Series',2,'AE1202',10.78,'aliexpress','1006476443','ztopan@sympatico.ca','Zahir Topan	','#605 - 1303 wilson ave. Buzzer Code 5522','Toronto','Ontario','CANADA','M3M 1J1','+416 241 5252',NULL,NULL,NULL,'2012-01-31 02:05:26',0,NULL,3,1,17,0,NULL,NULL),(23167,8881327975601646,111,'New Pro 6-Pockets Black Filter Wallet Case Fits UV CPL MCUV ND Filters of Cokin P Series',2,'AE1203',11.58,'aliexpress','1006476444','ztopan@sympatico.ca','Zahir Topan	','#605 - 1303 wilson ave. Buzzer Code 5522','Toronto','Ontario','CANADA','M3M 1J1','+416 241 5252',NULL,NULL,NULL,'2012-01-31 02:05:26',0,NULL,3,1,3,1,'RA184521258CN\r ','4片装的滤镜袋 *2 \r6片装的滤镜袋 *2'),(23168,8881327975954797,111,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',34.99,'aliexpress','1006477775','burmistroff@mail.ru','Vadim B	','Kolomenskaia 5 ap. 410','Moscow','Moscow','RUSSIAN FEDERATION	','115142','+7 985 2814562',NULL,NULL,NULL,'2012-01-31 02:12:34',0,NULL,3,1,17,0,NULL,NULL),(23169,8881327975994862,111,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',34.99,'aliexpress','1006478201','burmistroff@mail.ru','Vadim B	','Kolomenskaia 5 ap. 410','Moscow','Moscow','RUSSIAN FEDERATION	','115142','+7 985 2814562',NULL,NULL,NULL,'2012-01-31 02:12:34',0,NULL,3,1,5,1,'CP244674837CN ','欧标\r4灯头 灯头 孔  *2\r60x60cm 的柔光箱（配4灯头） *2'),(23170,795883615018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',3,'AO0005',31.32,'photographyacc','dkktaylor','kleighphotography@gmail.com','Dale Taylor','77Atthow Street','Kilcoy','Queensland','AUSTRALIA','4515','0754981338','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 02:14:40',0,NULL,3,0,3,1,'RA184548560CN ','1.6*2.1  黑色，棕色，蓝色\r回信等黑色布 ，棕色。\r'),(23171,8881327977345049,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included',1,'AC2403',33.99,'aliexpress','1006372057','ronaldoeleuterio@gmail.com','NASCIMENTO PRISCILA','Rua Conrado Schiffer 350, Sao luis, portaria','Ponta Grossa','Parana','BRAZIL','84050-280','+55 42 84014844',NULL,NULL,NULL,'2012-01-31 02:35:45',0,NULL,3,1,25,1,'RT125717537HK ','申报：$8 ，Gift '),(23172,790322983001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',3,'AD1195',87,'hermeshine','teung','to_aha@yahoo.com','SURASIT HARAMI','P.O.Box NO.128 LADPRAO POST OFFICE','BANGKOK','THAILAND','THAILAND','10310','0849768606','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 02:06:57',0,NULL,3,1,25,1,'RT126452615HK ','称一下重量，算运费 \r857'),(23173,8881327978355604,111,'1600W 套装',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-01-31 02:52:35',0,NULL,3,1,12,1,'3125439785 ','灯架  2m   2 \r柔光箱 60-60cm  四灯头    2\r45w 5500k 灯泡 110v     11\r灯架包    1 \r实重：6.38\r抛重：9.03'),(23174,8881327978827392,111,'115W 220V灯泡',1,'',0,'hermeshine','dkolega','danijel.kolega1@zd.t-com.hr','Danijel Kolega','Bana Josipa Jelacica 1c','Zadar','','CROATIA','23000','',NULL,NULL,NULL,'2012-01-31 03:00:27',0,NULL,3,0,21,1,'RA184521329CN\r ',NULL),(23175,937333561015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',5,'AD1198',100,'hutongstore','scottrobertphoto','scott@scottrobertgallery.com','Scott Lim','1834 S Mayflower Ave<br>Unit C','Monrovia','CA','UNITED STATES','91016-8305','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 03:10:56',0,NULL,3,1,4,1,'YW868896950CN\r ',NULL),(23176,937338762015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','macrick33','srhoff@aapt.net.au','Rick Hoffschulze','15 Dunbar Avenue','Cranbourne','Victoria','AUSTRALIA','3977','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 03:24:44',0,NULL,3,1,11,1,NULL,NULL),(23177,917924318016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 03:43:40',0,NULL,3,1,17,0,NULL,NULL),(23178,937345093015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 03:43:41',0,NULL,3,1,17,0,NULL,NULL),(23179,937342782015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 03:37:18',0,NULL,3,1,17,0,NULL,NULL),(23180,834511794002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:14:30',0,NULL,3,1,17,0,NULL,NULL),(23181,917924316016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',2,'AE3103',15.8,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 03:43:40',0,NULL,3,1,3,1,'RA184521315CN\r ','反光板  80cm 5合1  1 \r伞式柔光箱 60×90cm   1\r伞式柔光箱 80cm 8角    1\r大力夹云台  2'),(23182,834513172002,120448404654,'New Camera Body & Lens Rear Cap For EOS 450D 40D AF02',1,'AA1315',2.99,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:20:19',0,NULL,3,1,17,0,NULL,''),(23183,855720162017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',190,'photographyacc','beejay_i17','beejay_i@yahoo.com.au','Bronwin Illing-Smith','1 Dumbarton Dr','Kenmore','Queensland','AUSTRALIA','4069','0430454017','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-01-31 04:26:56',0,NULL,3,1,4,1,'YW868896946CN ','澳标 '),(23184,834516792002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','mickflag','michael_drapeau@hotmail.com','Michael Drapeau','1505 Des Roses','Sherbrooke','QC','CANADA','J1E 4J2','(819) 239-3099','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:36:24',0,NULL,3,1,3,1,'RA184521403CN\r ',NULL),(23185,621141110004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:50:01',0,NULL,3,1,17,0,NULL,NULL),(23186,621141471004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:51:34',0,NULL,3,1,17,0,NULL,NULL),(23187,790364982001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',3.9,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:53:16',0,NULL,3,1,17,0,NULL,NULL),(23188,834521371002,120448640631,'62mm 62 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT021',4.1,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 04:59:09',0,NULL,3,1,17,0,NULL,NULL),(23189,790370402001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 05:21:47',0,NULL,3,1,17,0,NULL,NULL),(23190,790371095001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','gematogen1917','stas_moshnyakov@mail.ru','Stas Moshnyakov','Leninskiy Prospekt d95 k2 kv412','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198330','+79045546053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 05:25:44',0,NULL,3,1,3,1,'RA184521394CN\r ','橡胶遮光罩 72mm  1 \r机身盖/镜头后盖  Canon  1 \r无牌方镜 渐变灰 （nd4）   1\r无牌方镜 ND8   1\r3片装的滤镜袋  1\r方镜普通托架（三槽  1\r方形滤镜接口环 62mm  1\r橡胶遮光罩 52mm   1\r方形滤镜接口环 52mm  1\r'),(23370,8881328255564807,111,'灯架底座',1,'',0,'hermeshine','antonvh','antonvanhoek@live.nl','Anton van Hoek','Beukenlaan 2','Vinkel','','NETHERLANDS','5382JW','0646508977',NULL,NULL,NULL,'2012-02-03 07:52:44',0,NULL,3,1,21,1,'RA184548692CN\r ',NULL),(23365,791770275001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','newportts','esphysio@bellnet.ca','Timo Puhakka','84 Dearham Wood','Toronto','ON','CANADA','M1E 1S4','(416) 910-6316','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 04:36:47',0,NULL,3,1,11,1,'BJ01669540 ',NULL),(23200,795528598018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','photofil33','gm.verdier@free.fr','Gilles VERDIER','3, boulevard Franklin Roosevelt','Talence','Aquitaine','FRANCE','33400','0664451608','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-31 10:41:22',0,NULL,3,1,3,1,'RA184520527CN ',NULL),(23191,937420838015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','johannesrask','krmsms@mail.dk','Søren Meng Sørensen','Vestermarksvej 14','Storvorde','','DENMARK','9280','+45 23257155','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-01-31 08:55:37',0,NULL,3,1,21,1,'RA184521363CN\r ',NULL),(23192,795972088018,280780674267,'6 six TianYa filters for cokin p series with Ring adapter & holder Kit with case',1,'AKT070',42.75,'photographyacc','ashstar_16','ashstar_16@hotmail.com','Ashley Woodward','4 Boyce Place<br>Ruse','Ruse','New South Wales','AUSTRALIA','2560','0246268204','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 08:59:39',0,NULL,3,1,3,1,'RA184538179CN\r\r ',NULL),(23193,790413291001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','bimuff72','bigmuff@newsguy.com','Sebastien VINEL','3 Rue guillaume','ORLEANS','Centre','FRANCE','45000','0660022752','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-31 09:17:10',0,NULL,3,1,17,0,NULL,NULL),(23194,834570486002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',2,'AA1305',5.2,'hermeshine','bimuff72','bigmuff@newsguy.com','Sebastien VINEL','3 Rue guillaume','ORLEANS','Centre','FRANCE','45000','0660022752','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 09:17:10',0,NULL,3,1,3,1,'RA184538063CN\r','4螺丝井字扳手  1 \rNIKON 镜头盖 52mm  2'),(23195,795801064018,280683441770,'Professional Diffuser Softbox f Pop-up Build-in Flash ',1,'AB3304',11,'photographyacc','falkmetal','n.b.falk@gmail.com','Nina Falk','CO/ Øivinn Berger<br>Bandadalen 21','stord','hordaland','NORWAY','5417','004746675611','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-31 09:37:44',0,NULL,3,1,24,1,'30119674211\r ',' '),(23196,790417306001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','cihlik','cihlar.m@valachnet.cz','Marek Cihlar','Dubkova 1531','Roznov pod Radhostem','Zlinsky kraj','CZECH REPUBLIC','75661','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 09:45:46',0,NULL,3,1,3,1,'RA184520439CN ','新地址：\rMarek Cihlar\rJiriho Wolkera 873\r756 61 Roznov pod Radhostem\rCZECH REPUBLIC\r\r '),(23197,834575018002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','deliveryguynz','avss.carl@gmail.com','Carl Butler','33 Aniseed gr','Upper Hutt','Wellington','NEW ZEALAND','5018','64 21 435087','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 09:36:56',0,NULL,3,1,2,1,'30119683473\r ',NULL),(23198,834583281002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','rcwtan','rcwtan@ausdoctors.net','Roger Tan','20 Bernier Rd','Shelley','Western Australia','AUSTRALIA','6148','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 10:11:14',0,NULL,3,1,3,1,'RA184538341CN\r',NULL),(23199,621193349004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','ekorchak','evgeniykorchak@gmail.com','Evgen Korchaka','Gvardeyskaya 4','Vorzel','Kyiv region','UKRAINE','08296','80505847686','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 10:30:25',0,NULL,3,1,24,1,NULL,'原来缺货，客户2.6 问为什么没发货，改成已发货。告诉客户是2.1发的，忘改状态了 。'),(23201,937469074015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','bettyboop-latvia','ribkka@inbox.lv','Olga Krasjko-Ņikonova','Stadiona<br>4-39','Daugavpils','','LATVIA','LV-5400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 11:24:49',0,NULL,3,1,17,0,NULL,NULL),(23202,937470163015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','bettyboop-latvia','ribkka@inbox.lv','Olga Krasjko-Ņikonova','Stadiona<br>4-39','Daugavpils','','LATVIA','LV-5400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 11:27:36',0,NULL,3,1,5,1,'CP244674797CN','灯架  2m  1 \r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头） 1\r欧标'),(23203,834605825002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','mayskiy1','vytik@mail.ru','Vladimir Moiseyenko','3737 S Hereford Ln','Philadelphia','PA','UNITED STATES','19114-1910','(267) 679-4874','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-01-31 11:34:16',0,NULL,3,1,1,1,'LK189067281Cn ',NULL),(23204,834549441002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','fimkajane','fimka_@mail.ru','Evgeniya Mironova','Oslyabinskiy pereulok 3-33','Moscow','','RUSSIAN FEDERATION','115280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 11:47:21',0,NULL,3,1,11,1,'BJ01669549\r ',NULL),(23205,834623677002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','kennyj0n5','kjong91@live.com','Kenny Jong','2 Norris Court Noble Park north 3174','Melbourne','Victoria','AUSTRALIA','3174','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 12:43:57',0,NULL,3,1,2,1,'30119683366\r ',NULL),(23206,918088949016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',29.98,'hutongstore','wilsonfreitas10','wilsonantoniodefreitas@bol.com.br','Wilson Antônio de Freitas','Rua 98, nº 6<br>Bairro João XXIII','Timóteo','Minas Gerais','BRAZIL','35.180-364','3187183484','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 13:23:50',0,NULL,3,1,17,0,NULL,NULL),(23207,8881328017224021,111,'MC 定时遥控器',50,'',1360,'hermeshine','Pierro Astro','pierro@pierro-astro.com','TEST','TEST','TEST','','TEST','','',NULL,NULL,NULL,'2012-01-31 13:40:24',0,NULL,3,0,12,1,'3125548510\r ','泡重  9.1  实重9.28 '),(23208,834644919002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','ksimonsen-2012','kms@kmd.dk','Kim Lennert Simonsen','KMD A/S<br>Lautrupparken 42','Ballerup','','DENMARK','2750','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 13:41:58',0,NULL,3,1,21,1,'RA184520495CN ',NULL),(23209,855873320017,270745552070,'NEW Photo Studio Soft Box Cube 50x50cm /20\'\' Light Tent',1,'AC2402',21.38,'photographyacc','$chibli','philschibli@gmail.com','Phillip Schibli','26 Raymond street','Perth','Western Australia','AUSTRALIA','6153','61437997743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-01-31 14:05:18',0,NULL,3,1,11,1,NULL,NULL),(23210,937542425015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','cpor7865','cporritt@sherlingsteeluk.com','Clive Porritt','61 Northfield Place<br>Rothwell','Leeds','West Yorkshire','UNITED KINGDOM','LS26 0SL','07770845233','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-01-31 14:32:34',0,NULL,3,1,11,1,'BJ01669529\r ',NULL),(23211,834678654002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','kaspo2010','a_kaspo@yahoo.com','ayad kaspo','skiftesvagen 12,2tr','Sodertalje','stockholms lan','SWEDEN','151 54','0046704973212','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 15:19:05',0,NULL,3,1,21,1,'RA184538355CN\r',NULL),(23212,621259680004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','awhipwell01','awhipwell@me.com','Emelia Boughen','Stallvägen 22:1003<br>Linnaeus University','Växjö','Småland','SWEDEN','35256','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 15:26:12',0,NULL,3,1,24,1,' ','已发货 '),(23213,834740947002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','iso9020','kaliko81@hotmail.com','Christian Lavoie','672<br>Chenier','Sherbrooke','QC','CANADA','J1N 2B2','(819) 820-7173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 17:43:30',0,NULL,3,1,11,1,'BJ01669551\r ',NULL),(23214,834743410002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',3,'AD1198',98.97,'hermeshine','cedevitagrape','radosavljevic_trade@yahoo.com','Robert Radosavljevic','Hrvatske Bratske Zajednice 11b','Karlovac','Karlovacka Zupanija','CROATIA','47000','+385977962256','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 17:47:50',0,NULL,3,1,21,1,'RA184520487CN ',NULL),(23215,937660511015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','2628.john-nyberg','kontakt@ispil.dk','John Nyberg','sallingvej 55, 2.tv.','Vanloese','','DENMARK','2720','+45 20892628','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 18:12:25',0,NULL,3,1,21,1,'RA184520473CN ',NULL),(23216,834783813002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','salomonelaps','cyanura@iinet.net.au','Michael McCoy','PO Box 501','Kuranda','Queensland','AUSTRALIA','4881','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 19:06:29',0,NULL,3,1,11,1,NULL,NULL),(23217,834784561002,120632127120,'New Camera shoulder bag a1 for Sony a500 a33 a580',1,'AO0028',27.9,'hermeshine','revikom','revikom1@gmail.com','Eugene Herman','3415 Howard St','Skokie','IL','UNITED STATES','60076-4011','(847) 485-9395','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-01-31 19:06:51',0,NULL,3,1,1,1,'LK188403716CN',NULL),(23218,937703924015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','rlm19510','r1951mac@hotmail.com','Ray McIntyre','4A Dimitriou Mitropoulou Street<br>Strovolos','Nicosia','CYPRUS','CYPRUS','2013','97634750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 19:13:38',0,NULL,3,1,17,0,NULL,NULL),(23219,937703925015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','rlm19510','r1951mac@hotmail.com','Ray McIntyre','4A Dimitriou Mitropoulou Street<br>Strovolos','Nicosia','CYPRUS','CYPRUS','2013','97634750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 19:13:39',0,NULL,3,1,17,0,NULL,NULL),(23220,790632711001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',33.98,'hermeshine','pietrobelli2011','pietrobelli@sercomtel.com.br','NORBERTO PIETROBELLI','RUA MÁRIO ONCKEN 90 BLOCO 12 APT. 1221<br>JARDIM DAS AMÉRICAS','LONDRINA','PARANÁ','BRAZIL','86076-090','043-3338-2697','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 19:26:59',0,NULL,3,1,24,1,'30119860971\r ',''),(23221,937703923015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','rlm19510','r1951mac@hotmail.com','Ray McIntyre','4A Dimitriou Mitropoulou Street<br>Strovolos','Nicosia','CYPRUS','CYPRUS','2013','97634750','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 19:13:37',0,NULL,3,1,24,1,'30119701765\r ','58-58mm 双阳环  1 \r橡胶遮光罩 58mm   1\rcanon 反接环  58mm   1'),(23222,834801737002,120544017355,'YONGNUO Flash Battery Pack SF-17 Nikon SB800 SD-8A ',1,'AB3315',41.99,'hermeshine','demunich3000','demunich@hotmail.com','Matt deMunck','25 Normlyttle Pde','Miners Rest','Victoria','AUSTRALIA','3352','0438346456','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 19:36:51',0,NULL,3,1,3,1,'RA184538240CN\r',NULL),(23223,937735056015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','carlos30358','c_costa_@msn.com','Carlos Costa','Rua Escolas Nº 2 Vivenda Costa<br>2680-321 Apelação','Lisboa','Lisboa','PORTUGAL','2680-321','+351 917613125','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 19:56:29',0,NULL,3,1,21,1,'RA184520460CN ',NULL),(23224,790659675001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','titobazar','thierry.anson@orange.fr','ANSON Thierry','1, rue de Provence','ELZANGE','Lorraine','FRANCE','57970','0382501583','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 20:13:36',0,NULL,3,1,2,1,'30119791111\r ',NULL),(23225,918323212016,260856847288,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',25,'hutongstore','dave60001','davidstringer5799@sky.com','DAVID STRINGER','70 FRANKLYN ROAD','CANTERBURY','Kent','UNITED KINGDOM','CT28PS','01227761915','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-01-31 20:31:12',0,NULL,3,1,3,1,'RA184538015CN\r',NULL),(23226,621383323004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','bridgeburners2011','petrik.jan@centrum.sk','Jan Petrik','Krizovatka 9','Banska Stiavnica','SC','SLOVAK REPUBLIC','96901','00421908289693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 21:12:06',0,NULL,3,1,17,0,NULL,NULL),(23227,621385822004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','bridgeburners2011','petrik.jan@centrum.sk','Jan Petrik','Krizovatka 9','Banska Stiavnica','SC','SLOVAK REPUBLIC','96901','00421908289693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 21:18:28',0,NULL,3,1,24,1,'30119687452\r ','无牌方镜 ND8   1 \r无牌方镜 渐变灰 （nd4）  1'),(23228,834867502002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',129.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-01-31 21:32:16',0,NULL,3,1,25,1,'RT125863818HK',NULL),(23229,796300250018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.54,'photographyacc','esbenras','esben72@gmail.com','Esben Rasmussen','Fuglefængervej 7, 4. th','Kbh NV','copenhagen','DENMARK','2400',')45= 60651972','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-01-31 22:02:21',0,NULL,3,1,24,1,'30119685013\r ',NULL),(23230,790726845001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','luis.andre.santos','ladcs1976@gmail.com','André Cadima','Banco BPI Rua 25 de Abril Lt4 Lj 425 Gândara dos Olivais,Leiria,Leiria,Portugal','Leiria','','PORTUGAL','2415-605','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-01-31 22:27:30',0,NULL,3,1,21,1,'RA184520558CN ',NULL),(23231,834924156002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',56.5,'hermeshine','felsenkrabbe','dirk.buttgereit@googlemail.com','dirk buttgereit','Heideweg 4a','Windhagen','','GERMANY','53578','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-01-31 23:52:48',0,NULL,3,1,21,1,'RA184538032CN\r',NULL),(23232,937901736015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','zebikerboy','josecrramalho@hotmail.com','jose ramalho','rua da primavera, 45 labruge','vila do conde','porto','PORTUGAL','4485-301','(+351)918691468','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 01:00:38',0,NULL,3,1,24,1,'30119663114\r ',NULL),(23233,937902649015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','yvermette','y_vermette@hotmail.com','Yves Vermette','991 Pierre-Audette','St-Jerome','QC','CANADA','J7Y 5B5','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 01:02:13',0,NULL,3,1,3,1,'RA184520513CN ',NULL),(23234,856186231017,270804543231,'Soft Camera Cover protector M for Nikon D5100 18-200mm',1,'AD1172',8.54,'photographyacc','rpdp1954','ross@meboat.com.au','Ross Proud','PO Box 4360','South Mackay','Queensland','AUSTRALIA','4740','0749441718','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-01 00:38:02',0,NULL,3,1,11,1,'BJ01669550\r ',NULL),(23235,790781865001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','pipefitter64','webbfam@sympatico.ca','Gerry  Webber','81 Ravina Avenue','GARSON','ON','CANADA','P3L1C2','(705) 564-3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 01:25:18',0,NULL,3,1,11,1,'BJ01669544\r ',NULL),(23236,796373092018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.42,'photographyacc','mohitisbest','mohitgarg2011@hotmail.com','Mohit Garg','39 Torbert Ave','Quakers Hill','New South Wales','AUSTRALIA','2763','0415065076','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-01 01:32:06',0,NULL,3,1,2,1,'30119688826\r ',NULL),(23237,796377805018,280674125495,'New Neoprene Neck Shoulder Strap for  SLR camera',2,'AB1407',43.85,'photographyacc','hey_happy_guy','happy.guy934@gmail.com','Mark Fung','934 Greenwood Ave','Toronto','ON','CANADA','M4J 4C3','(416) 461-9490','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-01 02:30:30',0,NULL,3,1,3,1,'RA184538165CN\r','肩带 无字  2 \r铝合金灯座（N）  2\r普通有线快门线N1  1\r申报Shoulder straps $25\r'),(23246,8881328077380206,111,'1.6*4 白色背景布，2m灯架侧面的杆',1,'',0,'photographyacc','eandy2010','t467838@yahoo.com','Андрей Колчанов','ул. Красных Партизан 5-12','Н. Тагил, Свердловская область','','RUSSIA','622042','',NULL,NULL,NULL,'2012-02-01 06:23:00',0,NULL,3,0,3,1,'RA184520615CN ',NULL),(23238,918491747016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','bien29','nan_exjoker@yahoo.com','Renante Rosales','41 walkinstown green<br>walkinstown','dublin','Dublin','IRELAND','12','0877780598','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-01 02:37:17',0,NULL,3,1,21,1,'RA184520368CN ',NULL),(23239,8881328064966566,111,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',10.99,'aliexpress','1006493326','3858@bk.ru','Gulnara Sagadieva	','Voroshilova street build 37 - 215','Magnitogorsk','Chelyabinskaya area	','RUSSIAN FEDERATION	','455000','+7 912 3095790',NULL,NULL,NULL,'2012-02-01 02:56:06',0,NULL,3,1,3,1,'RA184538338CN\r',NULL),(23240,834982210002,120753010104,'New Official Canon Photo Vest Size L T2i 7D 5D Mark ii',1,'AD1158',56.5,'hermeshine','boubou09031974chouchou','o.rysermans@gmail.com','Rysermans-Tshimanga snc','Rue Notre Dame au Bois, 12','Braine-le-Château','','BELGIUM','1440','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-01 03:08:00',0,NULL,3,1,21,1,'RA184538219CN\r',NULL),(23241,8881328068572638,111,'Free shipping & Tracking # - Light Soft Box x 1 for Studio Strobes 50cm x 70cm - Wholesale/Retail ',1,'AE2401',29.99,'aliexpress','1006505139','jopchr@online.no','John Christensen	','Roineveien 21','Sylling','Buskerud	','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-01 03:56:12',0,NULL,3,1,17,0,NULL,'欧标 '),(23242,8881328069772108,111,'Free shipping & Tracking # - New Manual Background Support System-3-ROLLER WALL-MOUNTED - AD1147',1,'AD1147',96.04,'aliexpress','1006505405','jopchr@online.no','John Christensen	','Roineveien 21','Sylling','Buskerud	','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-01 04:16:12',0,NULL,3,1,5,1,'CP244548215CN\r ','柔光箱 50-70cm 单灯头 *1 （欧标） \r手动升降背景架  *1\r'),(23243,790832871001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','verbatim10000','waiminwong@telus.net','Tyson Yong','8-9451 granville ave','richmond','BC','CANADA','v6y1p9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 04:42:49',0,NULL,3,1,2,1,NULL,NULL),(23244,790834945001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','cameron_foley','cameronfoley93@gmail.com','Cameron Foley','PO Box 273','Blackwater','Queensland','AUSTRALIA','4717','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 04:53:17',0,NULL,3,1,2,1,'30119789000\r ',NULL),(23245,856270745017,270804605505,'400w Studio Strobe Kit flashs + 2m stands + soft boxes',1,'AKT080',199.5,'photographyacc','glor3133','gloriaz1@live.com','Gloria Zahra','31 - 33 Hood Street','ROSEDALE','Victoria','AUSTRALIA','3847','0412060513','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-02-01 05:46:37',0,NULL,3,1,4,1,'YW868898070CN ','澳标 \r抛重：7.1808\r实重：5.64'),(23247,790859481001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','knopikov13','knopikov@gmail.com','Alexandr Novoselcev','Kuskovskaya d.23 k.3 kv.33','Moscow','Moscow','RUSSIAN FEDERATION','111141','495-309-5822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 07:16:19',0,NULL,3,1,11,1,'BJ01669526\r ',NULL),(23249,835060750002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'hermeshine','monciciatko2903','monciciatko@gmail.com','Verlag Dashofer - Moni Kunovska','Zelezniciarska  13','Bratislava','SLOVAKIA','SLOVAK REPUBLIC','81499/323','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 09:17:41',0,NULL,3,1,21,1,'RA184536685CN\r ',NULL),(23248,835046248002,120753012046,'Brand New Official Original Nikon Photo Vest for D300 D90 D700 D80 Size M ',1,'AD1159',50,'hermeshine','myisr','gold.david@gmail.com','David Goldenshluger','Adar 16/6<br>Rova Yud-Bet','Ashdod','Israel','ISRAEL','77300','972545597941','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-01 08:28:15',0,NULL,3,1,3,1,'RA184538236CN\r','已经付了8美金运费了 '),(23250,835070053002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','shan*u','phwahh@gmail.com','Douglas Chan','3 Carruthers st','Penshurst','New South Wales','AUSTRALIA','2222','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 09:56:38',0,NULL,3,1,11,1,'BJ01669590\r ',NULL),(23251,835063830002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','jagomsah11','jagomsah@hotmail.com','Jaime Gomez','Hernandez de Tejada, 1','Madrid','Madrid','SPAIN','28027','636976632','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 09:29:08',0,NULL,3,1,21,1,'RA184536677CN\r ',NULL),(23252,835072826002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','ts317','ctgintl@ix.netcom.com','Tony Shih','140 COMMERCE WAY','WALNUT','CA','UNITED STATES','91789-2714','(909) 598-9251','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-01 10:05:58',0,NULL,3,1,1,1,'LK188192861CN\r ',NULL),(23253,796493609018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','stew_art666','redman68au@yahoo.com.au','stewart low','142 terry st','connells point','New South Wales','AUSTRALIA','2221','0421508382','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-01 10:14:54',0,NULL,3,1,2,1,'30119885106\r ',NULL),(23254,938063804015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','springwellvilla','colinliddle@hotmail.co.uk','william liddle','32 recreation road<br>parkstone','poole','Dorset','UNITED KINGDOM','bh122eb','01202738298','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 10:19:23',0,NULL,3,1,3,1,'RA184536751CN\r ',NULL),(23255,796505315018,280680853908,'JYC-C1 Wireless Remote Control for Canon 60D 550D 450D',1,'AA3203',17.1,'photographyacc','nabut201002','nabutov@mail.ru','Alexey Nabutov','Krasnoarmejskaya, 11-53','Gorno-Altaisk','Altai Republic','RUSSIAN FEDERATION','649006','79139990205','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-01 10:58:51',0,NULL,3,1,11,1,'BJ01669588\r ',NULL),(23256,796521566018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','sonic-321','henning.ogx@gmail.com','Henning Müller','Georg-Schroeder-Str. 3c','Berlin','','GERMANY','13591','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-01 11:52:50',0,NULL,3,0,2,1,'30120087550\r ','1.6*2.1  黑色'),(23257,835126793002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','nagelm73','marcos.nagelstein@gmail.com','Marcos Nagelstein','Avenida Chuí nº 30, ap. 203<br>Cristal','Porto Alegre','Rio Grande do Sul','BRAZIL','90820-080','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 13:16:12',0,NULL,3,1,24,1,'30119887792\r ',NULL),(23258,835148361002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ivandunas','ipcdunas@hotmail.com','IVAN PASCUAL CONTRERAS','C/ DEL ALAMO nº 3','GETAFE','Madrid','SPAIN','28903','654 53 24 34','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-01 14:21:27',0,NULL,3,1,17,0,NULL,NULL),(23259,790967995001,110678545752,' IR Remote Control for Canon/Nikon/Pentax DSLR-Cameras',2,'AA2205',7,'hermeshine','ivandunas','ipcdunas@hotmail.com','IVAN PASCUAL CONTRERAS','C/ DEL ALAMO nº 3','GETAFE','Madrid','SPAIN','28903','654 53 24 34','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 14:21:28',0,NULL,3,1,21,1,'RA184536941CN\r ','三脚架  伟峰 WF-6662A  1 \r爵影红外 5 in 1  2'),(23260,938169891015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','joaour','joao.sobral@unrealimage.com','Joao Sobral','Rua Joao Deus nº242 2ºDto Tires','Sao Domingos Rana','Sao Domingos Rana','PORTUGAL','2785-140','960132224','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 14:52:33',0,NULL,3,1,21,1,'RA184537006CN\r ',NULL),(23261,789906753001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','lbenac13','lucbenac@telus.net','LUC BENAC','7550 KRAFT CRESCENT','BURNABY','BC','CANADA','V5A 1Z7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-01 15:01:17',0,NULL,3,1,3,1,'RA184536867CN\r ',NULL),(23262,790986117001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','isoman3200','ramonlperez@gmail.com','Ramón L. Pérez Pinar','C/ Paseillo 13','Granada','Andalucía Ceuta y Melilla','SPAIN','18014','649928064','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 15:10:59',0,NULL,3,1,2,1,'30119878784\r ',NULL),(23263,937982004015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','alexpotapov_tlt','bob008@list.ru','Aleksej Potapov','Larina street, 106<br>0','Togliatti','Samara region','RUSSIAN FEDERATION','445007','(903) 331 - 7772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 15:35:19',0,NULL,3,1,3,1,'RA184536875CN\r ',NULL),(23264,621635404004,140651224725,'New Mini IR Wireless Remote Control for Canon 450D 500D 550D 600D 7D 60D',1,'AD1117',3.3,'hermeshine','evrythincool','chunyeen24@gmail.com','chan chun yeen','8, jalan 5/58<br>gasing indah','petaling jaya','Selangor','MALAYSIA','46000','0122479063','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 17:03:53',0,NULL,3,1,2,1,'30119879344\r ',NULL),(23265,938283413015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 18:19:50',0,NULL,3,1,21,1,'RA184536915CN\r ','澳转欧标 '),(23266,791108379001,110414374652,'New Graduated color Filter for Cokin P Series Tian Ya',2,'AA2322',14.4,'hermeshine','itechul12','itedehu@hotmail.es','Juan José Villarejo Fernández','Avda. Fray Albino, 13, bajo izqdo.<br>13, bajo izqdo.','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14009','638059474','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 19:34:49',0,NULL,3,1,2,1,'30119886930\r ','天涯方形滤镜  渐变红  1\r天涯方形滤镜  渐变棕   1 \r'),(23267,938353014015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','pke1n0t0a0x','lennart@roros.net','Bjørn Hagaseth','Vollberget 63','Glåmos','','NORWAY','7372','004747637170','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 19:55:59',0,NULL,3,1,21,1,'RA184536924CN\r ',NULL),(23268,835319040002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','mkylmaniemi','mika.kylmaniemi@gmail.com','Mika Kylmaniemi','Valjakonkatu 6 B 27','TAMPERE','','FINLAND','33580','+358-50-5005060','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-01 20:20:35',0,NULL,3,1,21,1,'RA184536938CN\r ',NULL),(23269,938386192015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','fifi-lapew','gregory.glenn@lineone.net','Gregory Glenn','52 Eastworth Road','Chertsey','Surrey','UNITED KINGDOM','KT16 8DP','07840937384','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 20:39:56',0,NULL,3,1,2,1,'30119884141\r ',NULL),(23270,938395076015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','adeleleeoliver24','adeleoliver24@hotmail.com','adele oliver','41 kirklinton rd<br>marden est','north shields','Tyne and Wear','UNITED KINGDOM','ne30 3ax','01912596214','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 20:51:53',0,NULL,3,0,11,1,'BJ01669534 ','1.6*2.1 黑色'),(23271,918953622016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','jjkkjack','jackwalker12@hotmail.co.uk','Gary Walker','24 Barnard Close<br>Gorleston','Great Yarmouth','Norfolk, England','UNITED KINGDOM','NR31 7RN','0796350332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-01 21:28:16',0,NULL,3,1,2,1,'30119882671\r ',NULL),(23272,835341014002,120539730838,'New Spirit Level Hot Shoe Hotshoe Cover Protector ',1,'AA1206',3.99,'hermeshine','winbin.sales','ebay2@winbin.com.au','The University of Notre Dame','Ben Wilding - IT department<br>19-21 Buckland Street','Chippendale','New South Wales','AUSTRALIA','2008','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-01 21:03:01',0,NULL,3,1,2,1,'30119874050\r ',NULL),(23273,796782837018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',36.1,'photographyacc','sysadd01','sysadd@bigpond.net.au','Maurice Waters','8 Elysium Road','Rochedale South','Queensland','AUSTRALIA','4123','0733411741','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-01 21:28:45',0,NULL,3,1,3,1,'RA184536663CN\r ',NULL),(23274,835364453002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','nfb5259','nanlix_marie@yahoo.com','Nanlix Frontany','F24 Calle Ruisenor','Toa Baja','PR','PUERTO RICO','00949-3472','(787) 203-4481','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-01 21:50:51',0,NULL,3,1,21,1,'RA184536986CN\r ',''),(23275,938454193015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','caos_s.a','nuno7@hotmail.com','Nestor Nuño Martínez','Avenida San Diego 146, 4ºb Escalera Izquierda','Madrid','Madrid','SPAIN','28018','655769170','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-01 22:45:49',0,NULL,3,1,21,1,'RA184536972CN\r ',NULL),(23276,938468716015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','cederberg1972','chc@damplokomotiv.dk','Christian Cederberg','Vigerslev Alle 176C, 3.sal','Valby, Copenhagen','','DENMARK','DK-2500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 23:04:41',0,NULL,3,1,24,1,'30119886016\r ',NULL),(23277,918999810016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','johnnycorcoran','email@johnnycorcoran.ie','Johnny Corcoran','Apt 67 Block F Rossecourt Heights<br>Balgaddy','Lucan','Dublin','IRELAND','default','0872499895','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-01 23:07:37',0,NULL,3,1,21,1,'RA184536955CN\r ',NULL),(23278,835424676002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','mtp-mtp02','manuel.torrespaniagua@gmail.com','Manuel Torres','313 Calle Urayoan<br>Los Caciques','Carolina','PR','PUERTO RICO','00987-8721','787-396-7727','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 00:39:17',0,NULL,3,1,21,1,'RA184536990CN\r ',''),(23279,938510483015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0022',149,'hutongstore','sandrethanh','sandrine.loncke@free.fr','Sandrine Loncke','73, rue des Ruffins','Montreuil','Ile-de-France','FRANCE','93100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 00:57:36',0,NULL,3,1,4,1,'YW868898055CN\r ',NULL),(23280,938515337015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','mikezao','mike_az93@hotmail.com','Micael Azevedo','largo gama barros nº13/3º dto cacem','lisboa','lisboa','PORTUGAL','2735-476','969217464','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 01:06:54',0,NULL,3,1,24,1,'30119881271\r ',NULL),(23281,8881328146726294,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail ',1,'AA1310',6.99,'aliexpress','1006510946','rijii123@yandex.ru','Dmitry Gryaznov	','Zarevii proezd, 5-1-133','Moscow','Moscow','RUSSIAN FEDERATION	','127282','+7 926 2848701',NULL,NULL,NULL,'2012-02-02 01:38:46',0,NULL,3,1,3,1,'RA184536748CN\r ',NULL),(23282,8881328146914412,111,'Free shipping & Tracking # - YN Flash Battery Pack SF-18 for Canon Flash 580EXII CP-E4 - Wholesale/Retail ',1,'AB3307',49.99,'aliexpress','1006512660','kykykis@gmail.com','Dmitriy Zaharov	','Ak Chelomeya 10-325','Moscow','Moscow','RUSSIAN FEDERATION	','117630','+7 926 9673744',NULL,NULL,NULL,'2012-02-02 01:41:54',0,NULL,3,1,3,1,'RA184536725CN\r ',NULL),(23283,8881328147098107,111,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount - Wholesale/ Retail [AE1602]',1,'AE1602',24.99,'aliexpress','1006514785','zhukovperepiska@mail.ru','Vladimir Zhukov	','Norilskaya st. 16-45','Nizhny Novgorod','RUSSIA','RUSSIAN FEDERATION	','603073','+7 920 2505772',NULL,NULL,NULL,'2012-02-02 01:44:58',0,NULL,3,1,3,1,'RA184536734CN\r ',NULL),(23284,8881328147329707,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft - Whole/ Retail [AO0005]',1,'AO0005',18.99,'aliexpress','1006520142','andrei@astranet.ru','Andrey Myasnikov	','Vlasova 2, 131','ASTRAKHAN','ASTRAKHAN','RUSSIAN FEDERATION	','414045','+7 8512 704008',NULL,NULL,NULL,'2012-02-02 01:48:49',0,NULL,3,1,3,1,'RA184536717CN\r ','1.6x3.0m 背景布 *1 (白色） '),(23285,796879486018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',81.48,'photographyacc','alpettersen','doh180575@yahoo.no','Are Lofstad Pettersen','Sagtjernvegen 10B','Elverum','Elverum','NORWAY','2408','+47 91837613','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 02:03:58',0,NULL,8,1,17,0,NULL,NULL),(23286,856743412017,270804590820,'200w Studio Strobe Kit flash+ 2m stand + soft umbrella',1,'AKT085',99.75,'photographyacc','alpettersen','doh180575@yahoo.no','Are Lofstad Pettersen','Sagtjernvegen 10B','Elverum','Elverum','NORWAY','2408','+47 91837613','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 02:10:03',0,NULL,3,1,5,1,'CP244548309CN ','除了C以外再发\r50-70柔光棚 通用塑料卡口  1\r背景架2mx2m  + 3个夹子  1\r1.6*4 白加黑\r发账单了，付款后发货'),(23287,796881920018,280666791794,'New foto Studio 20x27\"/50​x70cm Softbox Universal Mount',1,'AE2203',25.46,'photographyacc','alpettersen','doh180575@yahoo.no','Are Lofstad Pettersen','Sagtjernvegen 10B','Elverum','Elverum','NORWAY','2408','+47 91837613','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 02:12:05',0,NULL,8,1,17,0,NULL,NULL),(23288,835459236002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','pyewarren','warren.pye@sympatico.ca','Warren Pye','214 Dufferin Street','Stratford','ON','CANADA','N5A 2H2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 02:36:04',0,NULL,3,1,11,1,'BJ01669592\r ',NULL),(23289,835459513002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',5.9,'hermeshine','roinides','production@enatv.gr','ILIAS KLETSAS','ENATV-PAPAKYRIAZH 6','LAMIA','','GREECE','35100','306973381539','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 02:40:20',0,NULL,3,1,17,0,NULL,NULL),(23290,835459354002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','roinides','production@enatv.gr','ILIAS KLETSAS','ENATV-PAPAKYRIAZH 6','LAMIA','','GREECE','35100','306973381539','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 02:40:21',0,NULL,3,1,24,1,'30119884093\r ','绿叶 ND4  58mm  1 \r防寒罩  1'),(23291,791275709001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','xmarkesthespot','xavier@chariot.net.au','Xavier Wills','PO Box 21','Sellicks Beach','South Australia','AUSTRALIA','5174','0885574308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 02:57:24',0,NULL,3,1,11,1,'BJ01669583\r ',NULL),(23292,835470785002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','wikran','wikran66@gmail.com','Wikran Chanpaetrak','748/4 moo 4 Phaholyothin Rd.<br>Tumbol Kukot ,Lam Luk Ka','default','PT','THAILAND','12130','66866105090','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-02 03:15:19',0,NULL,3,0,25,1,'RT126018655HK\r ','3XL 已入库 '),(23293,791291949001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','miwal10','mirawaldner@gmail.com','Miranda Waldner','Box 453','Portage La Prairie','MB','CANADA','R1N 3B7','(204) 428-3366','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:01:53',0,NULL,3,1,11,1,'BJ01669585\r ',NULL),(23294,791301253001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','kasem.lim','kasem_lim@hotmail.com','Kasem Limsathit','354 Sanphawut Road','Bangna','Bangkok','THAILAND','10260','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:44:49',0,NULL,3,1,24,1,'30119924446\r ',NULL),(23295,791302677001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',3,'AA1212',8.97,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:50:09',0,NULL,3,1,17,0,NULL,NULL),(23296,791302678001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',3,'AA1211',8.97,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:50:09',0,NULL,3,1,17,0,NULL,NULL),(23297,791302679001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',3,'AA1213',8.97,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:50:10',0,NULL,3,1,17,0,NULL,NULL),(23298,791302681001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:50:10',0,NULL,3,1,17,0,NULL,NULL),(23299,835494323002,120792099042,'New Twin Flash Bracket for Nikon  D700  SB900 SB800 Canon 7D 5DII  580EX O-Shape',2,'AD1192',70,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-02 04:50:11',0,NULL,5,0,18,0,NULL,NULL),(23300,835494324002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',5,'AKT067',49.5,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 04:50:12',0,NULL,3,1,3,1,'RA184524740CN\r ','52-58mm 双阳环  3 \r52-52mm 双阳环  3\r58-58mm 双阳环  3\r倒影板（白黑）    1\rO型闪光灯支架     2\rlenspen    5\r气吹 + 布   5\r爵影红外 sony   5\r用小箱子装\rO型闪光灯支架不发了'),(23301,8881328167167826,111,'Free shipping & Tracking # - New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto - AD1186',2,'AD1186',59.98,'aliexpress','1006528640','jeremy_canterbury@yahoo.com','Jeremy Canterbury	','27931 Cabot Road Suite B','Laguna Niguel	','California','UNITED STATES	','92677','+1 949 338-1500',NULL,NULL,NULL,'2012-02-02 07:19:27',0,NULL,3,1,1,1,'LK178721887CN',NULL),(23302,791331813001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','carlos_irk','alexippolitov@gmail.com','Alexander Ippolitov','2-ya Zheleznodorozhnaya, 6-68','Irkutsk','','RUSSIAN FEDERATION','664005','79643517726','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-02 07:31:34',0,NULL,5,1,5,1,'CP244548343CN\r ','除了C以外再加\r背景架2mx2m  + 3个夹子 \r1.6*2.1 黑加白\r已发货...............'),(23303,791332446001,110503298181,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.99,'hermeshine','tlikitkererat','likitkererat@hotmail.com','Tanawat Likitkererat','27/1 Soi Somdejchaopraya 12','Klongsan','Bangkok','THAILAND','10600','(669) 003-2251 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 07:35:07',0,NULL,8,1,17,0,NULL,NULL),(23304,835524700002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','tlikitkererat','likitkererat@hotmail.com','Tanawat Likitkererat','27/1 Soi Somdejchaopraya 12','Klongsan','Bangkok','THAILAND','10600','(669) 003-2251 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 07:35:08',0,NULL,8,1,17,0,NULL,NULL),(23305,835524701002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','tlikitkererat','likitkererat@hotmail.com','Tanawat Likitkererat','27/1 Soi Somdejchaopraya 12','Klongsan','Bangkok','THAILAND','10600','(669) 003-2251 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 07:35:09',0,NULL,8,1,17,0,NULL,NULL),(23306,835524702002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','tlikitkererat','likitkererat@hotmail.com','Tanawat Likitkererat','27/1 Soi Somdejchaopraya 12','Klongsan','Bangkok','THAILAND','10600','(669) 003-2251 ext.: 0','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 07:35:10',0,NULL,3,1,6,1,'EE667838755CN\r ','热靴保护盖  普通  1 \rlenspen   1\r斜臂   1\r伞式柔光箱 80cm 8角    1\r'),(23307,791331815001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','carlos_irk','alexippolitov@gmail.com','Alexander Ippolitov','2-ya Zheleznodorozhnaya, 6-68','Irkutsk','','RUSSIAN FEDERATION','664005','79643517726','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-02 07:31:35',0,NULL,3,1,17,0,NULL,NULL),(23308,938636108015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0038761914941','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 08:13:08',0,NULL,3,1,21,1,'RA184520867CN ','申报$10 '),(23309,938628901015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','nunoisidro','nuno.isidro@sapo.pt','Nuno Isidro','Avenida 6 de Novembro 1836, N.º 312 - 1ºD.','Seixal','Seixal','PORTUGAL','2840-401','+351969813999','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 07:46:08',0,NULL,3,1,22,1,'BJ01669522 ',' '),(23310,937385113015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','+79233486117','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 09:23:51',0,NULL,3,1,3,1,'RA184520938CN ','欧标 '),(23311,835567281002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 10:42:06',0,NULL,3,1,25,1,'RT126435342HK ',NULL),(23313,791392554001,110464631140,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',5.4,'hermeshine','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 11:55:39',0,NULL,3,1,11,1,'BJ01669541\r ',NULL),(23314,835594354002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','josevpf','josevpf@hotmail.com','JOSE FCO VALLEJO APARICIO','Avenida de España 45<br>Coslada','Madrid','Madrid','SPAIN','28822','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 12:22:55',0,NULL,3,1,17,0,NULL,NULL),(23315,835593835002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','josevpf','josevpf@hotmail.com','JOSE FCO VALLEJO APARICIO','Avenida de España 45<br>Coslada','Madrid','Madrid','SPAIN','28822','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 12:22:56',0,NULL,3,1,2,1,'30120010255\r ','c型大力夹 2'),(23316,938720837015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','catmayas','omaildamaya@gmail.com','Cristina Maya','Praça Infante D. Henrique, 6, 6º Dto','LOURES','LOURES','PORTUGAL','2670-390','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-02 12:35:35',0,NULL,3,1,21,1,'RA184548587CN ',NULL),(23317,791410846001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','missaj8585','amanda.porter.1985@hotmail.com','Amanda Porter','54 Barton drive<br>Trott park','Adelaide','South Australia','AUSTRALIA','5158','61402217465','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 12:59:01',0,NULL,3,1,11,1,'BJ01669545 ',NULL),(23318,938755838015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','46racing46','pedrolan16@googlemail.com','Dupont de nemours','att. toni resta<br>rue general patton','luxembourg','','LUXEMBOURG','L-2984','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 14:02:20',0,NULL,3,0,21,1,'RA184520924CN ','2XL 已入库 '),(23319,938769743015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','kerri_j','kerri-j@hotmail.co.uk','Kerri Summers','37 The Boundary','Bedford','Bedfordshire','UNITED KINGDOM','MK41 9HB','01234212309','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 14:34:29',0,NULL,3,1,11,1,'BJ01669531\r ',NULL),(23320,938784740015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','baiveliko','veliko.stoykov@gmail.com','Veliko Stoykov','1 akad. Boris Stefanov str magazin 36','Sofia','Sofia city','BULGARIA','1700','+359 887 310 393','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 15:08:09',0,NULL,3,0,24,1,'30120019053\r ','1.6*2.1  黑色 '),(23321,791456311001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',68.99,'hermeshine','anna_z_10','annamari.west@gmail.com','Anna-Mari West','Eteläinen Heikelintie 12 C 6','Kauniainen','','FINLAND','02700','+358 40 7338488','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 15:19:10',0,NULL,3,1,21,1,'RA184520955CN ',NULL),(23322,835659432002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'hermeshine','tokarev24','verakot@gmail.com','Alexey Tokarev','Akademika Kirenskogo str., 2i, 559','Krasnoyarsk','','RUSSIAN FEDERATION','660074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 15:37:11',0,NULL,3,1,3,1,'RA184548635CN ',NULL),(23323,797109292018,280714978182,'Dual-Layer Soft Reflective Umbrella Studio 110cm 43\"',1,'AD1157',28.4,'photographyacc','rekuen','danirecuenco@hotmail.com','Daniel Recuenco Berenguel','C/ Jardines 12 Esc.1ª Bajo B','Salamanca','Castilla y León','SPAIN','37008','675142310','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 16:08:45',0,NULL,3,1,21,1,'RA184520907CN ',NULL),(23324,938843473015,250932214054,'New  pro 10 x 20 ft 3m x 6m  backdrop system and continous lighting kit 1000W',1,'AKT050',132,'hutongstore','chenetc','christian.chenet@yahoo.fr','chenet','14 b rue Lt colonel Girard','LYON','Rhone-Alpes','FRANCE','69007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 17:03:46',0,NULL,5,1,4,1,'YW868898033CN\r ','欧标 \r布换成黑色的\r已发货...............'),(23325,919369327016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','liddle2009','liddle1@hotmail.co.uk','francis liddle','71, 72 market place','Darlington','Durham','UNITED KINGDOM','DL1 5PL','07966465823','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 17:13:35',0,NULL,3,1,2,1,'30120009080\r ',NULL),(23326,835700873002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','prayz2jzus','portraitcreations@live.com','brad reynolds','RR 2 Box 146','tower hill','IL','UNITED STATES','62571-9654','(217) 565-2470','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 17:16:31',0,NULL,3,1,21,1,'RA184520915CN ',NULL),(23327,919383641016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',14.99,'hutongstore','alexpotapov_tlt','bob008@list.ru','Aleksej Potapov','Larina street, 106<br>0','Togliatti','Samara region','RUSSIAN FEDERATION','445007','(903) 331 - 7772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 17:38:34',0,NULL,3,1,3,1,'RA184520819CN ',NULL),(23328,919384004016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','asnapper','astronotusuk@yahoo.co.uk','john howell, c/o Bob Davis','29 Saffron Way<br>Tiptee','Colchester','Essex','UNITED KINGDOM','CO5 0AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 17:40:04',0,NULL,8,1,17,0,NULL,NULL),(23329,919384005016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.12,'hutongstore','asnapper','astronotusuk@yahoo.co.uk','john howell, c/o Bob Davis','29 Saffron Way<br>Tiptee','Colchester','Essex','UNITED KINGDOM','CO5 0AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 17:40:05',0,NULL,8,1,17,0,NULL,NULL),(23330,919384007016,260933199108,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.9,'hutongstore','asnapper','astronotusuk@yahoo.co.uk','john howell, c/o Bob Davis','29 Saffron Way<br>Tiptee','Colchester','Essex','UNITED KINGDOM','CO5 0AY','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-02 17:40:06',0,NULL,8,1,17,0,NULL,NULL),(23331,919384006016,260682370867,'67mm CPL Circular Polarizing Filter 67 CPL Green.L New',1,'AA3312',4.12,'hutongstore','asnapper','astronotusuk@yahoo.co.uk','john howell, c/o Bob Davis','29 Saffron Way<br>Tiptee','Colchester','Essex','UNITED KINGDOM','CO5 0AY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-02 17:40:06',0,NULL,8,1,17,0,NULL,NULL),(23332,938864553015,250971425577,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.9,'hutongstore','asnapper','astronotusuk@yahoo.co.uk','john howell, c/o Bob Davis','29 Saffron Way<br>Tiptee','Colchester','Essex','UNITED KINGDOM','CO5 0AY','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-02 17:40:06',0,NULL,3,1,3,1,'RA184548658CN ','天涯方形滤镜  渐变灰   1 \r方形滤镜接口环 67mm   1\r方镜普通托架（三槽）  1\r无牌方镜 渐变灰 （nd2）  1\r绿叶 CPL  67mm   1\r无牌方镜 渐变蓝   1'),(23333,835692428002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','hedonistsrus','jordan@jkburke.com','Jordan Burke','5836 Page Crescent','Burlington','ON','CANADA','L7L 7N9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 16:56:26',0,NULL,3,1,3,1,'RA184548600CN ',NULL),(23334,835718203002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',3,'AD1199',89.97,'hermeshine','digitalguy5416','info@jacobsonstudio.com','Jacobson Studio','12 Main St W','Mayville','ND','UNITED STATES','58257-1314','(701) 788-2611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-02 17:54:59',0,NULL,3,1,21,1,'RA184520941CN ',NULL),(23335,791526670001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-02 18:08:30',0,NULL,3,1,25,1,'RT126445795HK ',NULL),(23336,835746830002,120694613630,' IR Remote Control for Sony a230/a330/​a450/a500/​a700',5,'AA2203',17.5,'hermeshine','budda001','isaev.foto@gmail.com','Guz Andrey Vladimirovich','Neftehimikov d.23 kv.59','Kirishi','Leningradskaya obl','RUSSIAN FEDERATION','187110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 18:49:20',0,NULL,3,1,17,0,NULL,NULL),(23337,938922687015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0038761914941','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 19:10:10',0,NULL,3,1,21,1,'RA184520898CN ','申报$10  '),(23338,622032710004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','mlinho','mika.linho@gmail.com','Mika Linho','Kiitäjäntie 10 E 13','Pori','Satakunta','FINLAND','28200','+358400270484','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 19:45:50',0,NULL,3,1,24,1,NULL,'已发货 '),(23339,834764051002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','nikonlars','larsmagnuskvamme@gmail.com','Lars-Magnus Kvamme','Lund','Fauske','Fauske','NORWAY','8200','90686989','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 20:32:06',0,NULL,3,1,24,1,'30120016835\r ',NULL),(23340,835836048002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','rsmi6410','rlsmith@austin.rr.com','Richard L Smith','1801 West 29th Street','Austin','TX','UNITED STATES','78703','(512) 478-0951','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-02 21:31:44',0,NULL,3,1,1,1,'LK188028729CN ',NULL),(23341,857163554017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.01,'photographyacc','thanks.for.viewing','draveuallknowme@hotmail.com','David Ross','Apartment 8, Platt House<br>5 Elmira Way','Salford','Greater Manchester','UNITED KINGDOM','M5 3DR','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-02 21:35:58',0,NULL,3,1,11,1,'BJ01669542\r ',NULL),(23342,791638665001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','bigl28090','bigl28090@yahoo.com','lamont carpenter','811 charles rd','shelby','NC','UNITED STATES','28152-6319','(704) 974-6339','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-02-02 21:41:02',0,NULL,5,1,4,1,'YW868896972CN\r ','黑加白 \r已发货...............'),(23343,919546243016,260901880795,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',2.18,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:10',0,NULL,8,1,17,0,NULL,NULL),(23344,919546244016,260901272165,'New Mini IR Wireless Remote Control for Olympus E520E E420',1,'AD1119',2.18,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:11',0,NULL,3,1,17,0,NULL,NULL),(23345,919546246016,260660054359,'Softbox Flash Bounce Diffuser Fits Canon 430ex II & 430',1,'AB3331',1.58,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:12',0,NULL,3,1,17,0,NULL,NULL),(23346,939032756015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:12',0,NULL,3,1,17,0,NULL,NULL),(23347,939032758015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:13',0,NULL,3,1,17,0,NULL,NULL),(23348,919546248016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-02 21:44:14',0,NULL,3,1,17,0,NULL,NULL),(23349,939032759015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:15',0,NULL,3,1,17,0,NULL,NULL),(23350,939032760015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:16',0,NULL,3,1,17,0,NULL,NULL),(23351,939032761015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-02 21:44:17',0,NULL,3,1,21,1,'RA184548701CN\rRA184520884CN\r ','Mini 红外  canon   1 \rMini 红外  olympus   1\r肥皂盒 柔光罩  430EX  1\r肥皂盒 柔光罩   580EX   1\r反光板 100*150 40*60 5合1         1     1\rc型大力夹  1\r闪光灯B座    1\r3m 横杆（通用4节）    1\r麦克风   1\r反光板分开发'),(23352,835873670002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','pepablodg','pepablo@gmail.com','pablo dominguez','planeta, 15-3º','barcelona','Cataluña','SPAIN','08012','932372346','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-02 23:02:45',0,NULL,3,1,21,1,'RA184548573CN ',NULL),(23353,939113941015,250599931689,'New TianYa Star 6 points filters for Cokin P Series',1,'AE2316',6.7,'hutongstore','garethf77','gareth.finlay@gmail.com','Gareth Finlay','4 Raydale Close<br>Lwoton','WARRINGTON','Cheshire','UNITED KINGDOM','WA3 2TP','01942748324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 00:33:10',0,NULL,3,1,11,1,'BJ01669543\r ',NULL),(23354,835914282002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','biggtizi','timlobanov@gmail.com','Timur Lobanov','244 Biscayne Blvd<br>Apt 1005','Miami','FL','UNITED STATES','33132-2328','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 01:01:56',0,NULL,3,1,1,1,'LK181384725CN ',NULL),(23355,857252482017,270745173616,'New Photo 4 x E27 Sockets Bulb Holder Umbrella holder',1,'AE2202',25.46,'photographyacc','derweep','tkhuu@netspace.net.au','Minh Khuu','388 Bulwer St','West Perth','Western Australia','AUSTRALIA','6005','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 01:25:24',0,NULL,3,1,3,1,'RA184521006CN ','澳标 '),(23356,8881328234135977,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail [AA1310]',2,'AA1310',13.98,'aliexpress','1006532065 ','bugor2424@yandex.ru','Vitaliy Belousow','Belgorod Oblast, Starooskolskiy region village Shatalovka, street Begovaya 23/2','village Shatalovka	','Belgorod Oblast	','RUSSIAN FEDERATION	','309550','+7 920 5551661',NULL,NULL,NULL,'2012-02-03 01:55:35',0,NULL,3,1,3,1,'RA184520990CN\r ',NULL),(23357,8881328234247846,111,'Free shipping & Tracking # - New Camera shoulder bag a1 for Nikon D80 D90 D3000 - AO0030',1,'AO0030',25.99,'aliexpress','1006539442','tom-and_cat@hotmail.com','AILTON CASSIN	','RUA OSWALDO CRUZ , 520 VILA MOREIRA','SAO JOSE DO RIO PRETO	','SAO PAULO	','BRAZIL','15030400','+55 17 91581137',NULL,NULL,NULL,'2012-02-03 01:57:27',0,NULL,3,1,25,1,'RT126448479HK ',NULL),(23358,8881328234670647,111,'Free shipping & Tracking # - New Camera bag topload D3 for Canon 550D 500D - AO0034',1,'AO0034',9.99,'aliexpress','1006540355','ms.antonya@mail.ru','Anna Dvortsova	','territoriya Voennogo gorodka ob.3 kom.8','Novosibirsk','Novosibirskaya obl.	','RUSSIAN FEDERATION	','630017','+8 913 3728616',NULL,NULL,NULL,'2012-02-03 02:04:30',0,NULL,3,1,3,1,'RA184520875CN\r ',NULL),(23359,835934612002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','3300jorge','jorgehern123@msn.com','jorge hernandez','55 ethel st','valley stream','NY','UNITED STATES','11580-3107','(516) 808-7944','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-03 02:07:50',0,NULL,3,1,1,1,'LK188207773CN ',NULL),(23360,791730907001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','worldeyez','worldwide4everyone@gmail.com','Shar Melik','PO Box 1742<br>Double Bay','Sydney','New South Wales','AUSTRALIA','1360','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 02:09:56',0,NULL,3,1,3,1,'RA184548595CN ',NULL),(23361,857275001017,270818885655,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 1.5m x 2m',1,'AD1182',74.1,'photographyacc','dnov79','dennyboy2100@gmail.com','Denis Novkovic','44 Monash St.','Wentworthville','New South Wales','AUSTRALIA','2145','0402298121','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-02-03 02:34:35',0,NULL,5,1,4,1,'YW868896983CN\r ','已发货............... '),(23362,835965976002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','mikhailofromhell','bigiron@mail.ru','Mikhail Potapov','Pichugina street 14-2','Vladimir','Vladimirskaya oblast','RUSSIAN FEDERATION','600001','+79101751400','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 03:53:12',0,NULL,3,1,11,1,'BJ01669538 ',NULL),(23363,857298502017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','farsaba','arminsaba1@gmail.com','Armin Saba','8020 Minler Rd','Richmond','BC','CANADA','V7C 3T7','(604) 447-0657','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-03 03:53:39',0,NULL,3,1,11,1,'BJ01669539 ',NULL),(23364,835967304002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','escada38','tlupeterson@aol.com','Tracy Peterson','3250 61st Ave SW','Seattle','WA','UNITED STATES','98116-3013','(206) 933-1160','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-03 03:56:41',0,NULL,3,1,1,1,'LK188638813CN ',NULL),(23366,791785699001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','tinhago','tpmachado@ig.com.br','Thiago Machado','Rua Barão São Francisco,245 - Bloco H - Apto 508 - Andarai','Rio de Janeiro','RJ/Rio de Janeiro/ Andarai','BRAZIL','20560031','78740816','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-03 05:56:15',0,NULL,3,1,25,1,'RT126456625HK ','M '),(23367,791796440001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ytrewjim','jim@cflx.qc.ca','Jean-Michel L. Boulay','9725 Trianon','Sherbrooke','QC','CANADA','j1n3h8','(450) 546-3679','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 06:59:38',0,NULL,3,1,3,1,'RA184548627CN ',NULL),(23368,836006922002,120824638021,'Brand New Lens Repair Tool Stainless Steel Spanner Wrench with swap-able tips',1,'AD1207',40,'hermeshine','nukemall01','weasel@guns.ru','Igor Stratienko','Kalinina 41 kv.48','Blagoveschensk','Amurskaya oblast','RUSSIAN FEDERATION','675000','+79098938794','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-03 07:11:45',0,NULL,3,1,3,1,'RA184548644CN\r ',NULL),(23369,8881328253166119,111,'补个螺丝',1,'',0,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','',NULL,NULL,NULL,'2012-02-03 07:12:46',0,NULL,3,0,3,1,'RA184548689CN\r ',NULL),(23371,939244146015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','jdmyuh','ogranster@googlemail.com','Oliver Grange','103 Loke road','kings lynn','Norfolk','UNITED KINGDOM','pe302az','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 07:54:27',0,NULL,3,1,11,1,'BJ01669533\r ',NULL),(23372,790827958001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','vinceng3','vincengchunhoi@yahoo.com','Vincent Ng','Himalaya Ltd., 3F Toko Building<br>3-4-8 Azuchimachi, Chuo-ku','Osaka','Osaka','JAPAN','541-0052','(090) 655-6226 ext.: 4','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 08:09:04',0,NULL,3,1,11,1,'BJ01669536\r ',NULL),(23373,939257031015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','ashleyb1230_0','haydenabird@yahoo.co.uk','Hayden Bird','52 Summerhill Road','Saffron Walden','Essex','UNITED KINGDOM','CB11 4AJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 08:41:13',0,NULL,3,1,3,1,'RA184548661CN\r ',NULL),(23374,919772834016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','bludlivijkot','arturas@speleo.lt','Artūras Artiušenka','Gedvydžių 4-36','Vilnius','','LITHUANIA','06306','37065999637','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 09:06:21',0,NULL,3,1,5,1,' CP244548224CN',NULL),(23375,836033613002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','valex1962','valexan62@gmail.com','Alexander Vasiliev','pr. Slavi<br>d. 60 kv.57','Saint-Petersburg','','RUSSIAN FEDERATION','192236','(921) 9493393','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-03 09:18:43',0,NULL,3,1,17,0,NULL,NULL),(23376,836033614002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','valex1962','valexan62@gmail.com','Alexander Vasiliev','pr. Slavi<br>d. 60 kv.57','Saint-Petersburg','','RUSSIAN FEDERATION','192236','(921) 9493393','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-03 09:18:44',0,NULL,3,0,17,0,NULL,NULL),(23377,836033615002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','valex1962','valexan62@gmail.com','Alexander Vasiliev','pr. Slavi<br>d. 60 kv.57','Saint-Petersburg','','RUSSIAN FEDERATION','192236','(921) 9493393','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-03 09:18:45',0,NULL,3,1,3,1,'RA184538925CN\r ','爵影碗罩P4   1 \r摄影背心 Canon  老款 XL 已入库\r永诺 64LED 灯  1'),(23378,791839750001,110562295901,'68\"inch/1720mm Very Professional Camera Complete Tripod',1,'AE1502',79.96,'hermeshine','veszvet','andy-lebedev@inbox.ru','Andrey Lebedev','Kirova 6-52','Rybinsk','Yaroslavskaya obl','RUSSIAN FEDERATION','152903','+79106655417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 10:18:55',0,NULL,8,1,17,0,NULL,NULL),(23379,938664142015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',66.8,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 10:22:04',0,NULL,3,1,4,1,'YW868897996CN ','115w 220v   x   4\r50-70 单灯头   x   1\r一转四灯头    x    1\r \r '),(23380,791856514001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','boxer-dogs-tas','georgygirl_1967@moocow.com','C Kemp','78 Gormanston Rd','Moonah','Tasmania','AUSTRALIA','7009','','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,NULL),(23381,836068887002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','dfreuden','dfreuden@gmail.com','David Freuden','Unit 2, 11-13 Penkivil Street','Bondi','New South Wales','AUSTRALIA','2026','0468870431','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 11:34:06',0,NULL,3,1,2,1,'30120358822\r ',NULL),(23382,857420026017,270747045317,'New 77mm Snap-on Front Lens Cap for Nikon 77 mm lenscap',1,'AA1309',2.38,'photographyacc','kirstm8','kirst_maz@yahoo.co.uk','Mrs Kirsty M Whitt','9 School close<br>Barby','Rugby','Warwickshire','UNITED KINGDOM','CV238TA','01788891558','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-03 12:02:50',0,NULL,3,1,2,1,'30120365391\r ',NULL),(23383,836091850002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 12:57:35',0,NULL,3,1,25,1,'RT126606400HK ',NULL),(23384,836090114002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','esmo_australia','esantoso@gmail.com','Erick Santoso','38 Osten Drive','Langford','Western Australia','AUSTRALIA','6147','0402230775','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 12:46:50',0,NULL,3,1,11,1,NULL,NULL),(23385,857450635017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',55.6,'photographyacc','pedrojesus8788','cmc_wear@hotmail.com','pedro jesus camacho romero','plaza 28 de febrero<br>nº 4 4drcha','linares','Andalucía Ceuta y Melilla','SPAIN','23700','622319882','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-03 13:34:04',0,NULL,3,1,21,1,'RA184521893CN\r ',NULL),(23386,919875193016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','skewater','ake_stenlund@hotmail.com','Åke Stenlund','Södra Järnvägsgatan 27','Skellefteå','Västerbotten','SWEDEN','93133','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 13:59:10',0,NULL,3,1,21,1,'RA184521536CN\r ',NULL),(23387,797580996018,280774576148,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',36.09,'photographyacc','lmm4672','lmmans@terra.es','Luis Molina Mansilla','Lope de Rueda, 1, 3º D','Alcalá de Henares','Madrid','SPAIN','28805','918894672','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-03 14:37:47',0,NULL,3,1,21,1,'RA184521845CN\r ','欧标 '),(23388,791920474001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wgnfl','ngw@cfl.rr.com','Nigel Worrall','Florida Leisure<br>4924 W Irlo Bronson Mem Highway','Kissimmee','FL','UNITED STATES','34746','','NoPaymentFailure','CheckoutComplete','Other','2012-02-03 14:47:05',0,NULL,3,0,1,1,'LK191285356CN\r ','XL  (已入库） '),(23389,836133727002,120841734374,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',13.88,'hermeshine','stwin82','smariocosta@gmail.com','MARIO COSTA','AV. INDUSTRIA, LOTE 2B<br>APT. 1102','GUIMARAES','BRAGA','PORTUGAL','4805-019','+351 91 79 11 302','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 14:55:34',0,NULL,3,1,24,1,'30120368073\r ','已发货 '),(23390,939416680015,250726215492,'Neoprene Protector Camera Cover Case 4 Canon 450D ',1,'AC2303',4.2,'hutongstore','cjevans01','carla.evans@duke-energy.com','Carla Evans','1676 Juniper Ln','Greenwood','IN','UNITED STATES','46143-7248','(317) 292-2064','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 15:50:39',0,NULL,3,1,1,1,NULL,NULL),(23391,791964684001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','joonie11','melinda2@dkip.com','melinda kiplinger','130 ridgewood st','kalamazoo','MI','UNITED STATES','49001-4244','(269) 998-9220','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 16:39:06',0,NULL,3,1,21,1,'RA184521522CN\r ',NULL),(23392,791968335001,110745494635,'Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D ',1,'AD1188',73.49,'hermeshine','larryb2529','ltb.1@insightbb.com','Larry Brannin','13420 Eastpoint Centre Dr','Louisville','KY','UNITED STATES','40223-4160','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-03 16:46:03',0,NULL,3,1,21,1,'RA184521519CN\r ',NULL),(23393,836193765002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','motorfoto','motorind@mail.ru','Dmitry Vladimirovich Motorin','Mira st.76 kv 100<br>Tel 8(912)939-43-61','Nizhnevartovsk','HMAO-Ugra, RU','RUSSIAN FEDERATION','628624','(912)936-07-29','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 17:18:09',0,NULL,3,1,3,1,'RA184521757CN\r ',NULL),(23394,836197007002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','tidmag','innespj@yahoo.ca','Paul Innes','56 Hazelwood Drive','Guelph','ON','CANADA','N1C1A9','(519) 837-9053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 17:25:06',0,NULL,3,1,17,0,'BJ01669387\r ',NULL),(23395,622329218004,140651224761,'New Mini IR Wireless Remote Control for Nikon D90 D3000 D80 D7000 D5100',1,'AD1116',3.3,'hermeshine','tidmag','innespj@yahoo.ca','Paul Innes','56 Hazelwood Drive','Guelph','ON','CANADA','N1C1A9','(519) 837-9053','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 17:25:07',0,NULL,3,1,11,1,'BJ01669387\r ','新款内胆包 S  Nikon     1 \rMini 红外  nikon      1'),(23396,797655557018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','redrabbit123','somersjackie@hotmail.com','Jackie Ure','39 Daniels Crescent','Regina','SK','CANADA','s4n1m5','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-03 17:31:05',0,NULL,3,0,11,1,NULL,'1.6x2.1  白色 '),(23397,939505849015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','sailensphotography','paumc.bcn@gmail.com','Pau Martínez Calvet','c/ Ballester num. 3 piso 6','Barcelona','Cataluña','SPAIN','08023','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-03 18:18:32',0,NULL,3,1,21,1,'RA184521607CN\r ',NULL),(23398,920027208016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',19.98,'hutongstore','furre85','ufos85@gmail.com','Jonas Hansson','Bodekullsgatan 34 A','Malmö','Skåne','SWEDEN','214 40','0708511622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-03 18:53:16',0,NULL,3,1,21,1,'RA184521598CN\r ',NULL),(23399,939546612015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','104nick','karl.n.brown@hotmail.co.uk','KARL BROWN','7 RIDGE CLOSE<br>NEWSOME','HUDDERSFIELD','WEST YORKSHIRE','UNITED KINGDOM','HD4 6DT','01484531401','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 19:20:50',0,NULL,3,1,11,1,NULL,NULL),(23400,857640516017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',37.05,'photographyacc','1reatl2','lineker@ansonic.com.au','Brian Lineker','73 Bentinck St','Portland','Victoria','AUSTRALIA','3305','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-03 20:06:36',0,NULL,3,1,3,1,'RA184521712CN\r ','澳标 '),(23401,836284834002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','dougie501','dpaproski@gmail.com','Dave Paproski','116 Veterinary Road','Saskaton','SK','CANADA','S7N 2R3','(306) 975-8919','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 20:22:14',0,NULL,3,1,11,1,NULL,NULL),(23402,792081621001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mbmoh93160','mbmoh93@gmail.com','Mohamed Bouchadekh','2, place Eugène Thomas','NOISY LE GRAND','Ile-de-France','FRANCE','93160','0615090560','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-03 20:39:20',0,NULL,3,1,3,1,'RA184521743CN\r ',NULL),(23403,920124387016,260901272183,'New Camera protector case Neoprene bag for Nikon D40 D3000 D3100 50mm 18-55mm',1,'AD1171',5.2,'hutongstore','zorakimo93811124','zorakimo@gmail.com','hHSIN-JUNG WU','27 Barstow Avenue','York','North Yorkshire','UNITED KINGDOM','YO10 3HE','7403855774','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 21:32:54',0,NULL,3,1,11,1,'BJ01669386\r ',NULL),(23404,920127090016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','lamia10','kelly.e.boyce@btinternet.com','Philip Boyce','30 Dereham Rd','Shipdham','Norfolk','UNITED KINGDOM','IP25 7NA','07759004512','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 21:34:21',0,NULL,3,1,2,1,'30120370895\r ',NULL),(23405,939679854015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','mitchelljp4269','mitchell-satchel@live.co.uk','Mitchell Plume','61 Northfield Road','Enfield','London','UNITED KINGDOM','En3 4bp','02084435132','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 23:10:39',0,NULL,3,1,3,1,'RA184521730CN\r ',NULL),(23406,939695616015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','virtualkev','virtualkev@blueyonder.co.uk','Kevin Haughton','Culina Logistics<br>Unit 9 Poplar Way East','Avonmouth, Bristol','Avon','UNITED KINGDOM','BS110YH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-03 23:44:25',0,NULL,3,1,11,1,NULL,NULL),(23407,836377259002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','dmcl2984','irunzalot2@aol.com','Dona;d McLean','15054 Harding Ave','Midlothian','IL','UNITED STATES','60445-3435','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-04 00:04:34',0,NULL,3,1,21,1,'RA184521584CN\r ',NULL),(23408,792167066001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','softclick','comercial@softclick.com.br','Vinicius Schneider','R. Ricalde Marques, 7<br>Jd. Sao Pedro','Porto Alegre','Rio Grande do Sul','BRAZIL','91040-280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 00:27:56',0,NULL,3,0,24,1,'30120463166\r ','1.6x2.1  x  2\r黄色    黑色 \r705\r如果是挂号需要加$8运费，\r不挂号可以发香港小包平邮'),(23409,792169068001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','antonio_batonio','shirok_anton@mail.ru','Anton Shirokov','60 let VLKSM 36-13','Zheleznogorsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','662978','8-913-8386728','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 00:35:01',0,NULL,3,1,17,0,NULL,NULL),(23410,836385771002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','antonio_batonio','shirok_anton@mail.ru','Anton Shirokov','60 let VLKSM 36-13','Zheleznogorsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','662978','8-913-8386728','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 00:35:01',0,NULL,3,1,3,1,'RA184521726CN\r ','   新款内胆包 L  Nikon     x   1\rNG200 柔光罩     x   1\r '),(23411,836394967002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','kookydisco','ckakoufas@cbusproperty.com.au','Chris Kakoufas','20 Euston Street','Malvern','Victoria','AUSTRALIA','3144','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 01:06:44',0,NULL,3,1,11,1,NULL,NULL),(23412,939752964015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','nolan8213','nolan8213@yahoo.co.uk','Mr Nolan Regent','Brasserie Toulouse Lautrec<br>140 Newington Butts','London','London','UNITED KINGDOM','SE11 4RN','07747110160','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-04 02:33:31',0,NULL,3,1,3,1,'RA184521828CN\r ',NULL),(23413,797893537018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',3.98,'photographyacc','fireproof-life','rachiesim@hotmail.com','Rachel Sim','8 Landsdale Crescent','Melbourne','Victoria','AUSTRALIA','3152','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 03:11:15',0,NULL,3,1,2,1,'30120374594\r ',NULL),(23414,836445680002,120454220127,'Green.L 58mm Neutral Density ND4 Filter ND 4 58',1,'AE2303',5.9,'hermeshine','aldrsv','sav@partizansk.com','Alexander V Stepanets','P.O. Box 1','Partizansk, 3','Primorye','RUSSIAN FEDERATION','692853','79147157320','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 04:22:28',0,NULL,3,1,17,0,NULL,NULL),(23415,836445644002,120571006733,'Green.L 58mm Neutral Density ND8 Filter 58 EF 18-55mm',1,'AE2310',5.9,'hermeshine','aldrsv','sav@partizansk.com','Alexander V Stepanets','P.O. Box 1','Partizansk, 3','Primorye','RUSSIAN FEDERATION','692853','79147157320','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 04:22:28',0,NULL,3,1,11,1,NULL,'绿叶 ND4  58mm   x  1\r绿叶 ND8  58mm   x   1\r '),(23416,857829921017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',8.55,'photographyacc','qzl1203','qzl1203@hotmail.com','Allen Qu','Unit B20, 52 Boadle Rd,<br>Bundoora,','melbourne','Victoria','AUSTRALIA','3083','61432762743','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 05:59:53',0,NULL,3,1,11,1,NULL,NULL),(23417,792245259001,110549879599,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1163',29.99,'hermeshine','veszvet','andy-lebedev@inbox.ru','Andrey Lebedev','Kirova 6-52','Rybinsk','Yaroslavskaya obl','RUSSIAN FEDERATION','152903','+79106655417','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 06:07:20',0,NULL,3,1,5,1,'CP244548290CN ','三脚架 伟峰 WF-6663A     1\rNikon D8 单肩包       1\r '),(23418,836487967002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','mr.m9ic','m9ic@rambler.ru','Alexander Bykov','800 years of Moscow street 26-2-213','Moscow','','RUSSIAN FEDERATION','127591','89199950709','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:13:39',0,NULL,3,1,11,1,' ',NULL),(23419,836490932002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','argelit','ntonkih@mail.ru','Tonkikh Nikolay','Donskoy pereylok, dom 9,  kvartira 45','Sochi','Krasnodar region','RUSSIAN FEDERATION','354068','+7 (918) 617-5615','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 08:28:35',0,NULL,3,1,11,1,NULL,NULL),(23420,836507137002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','prtay3','dr_zoidburg_whoop@hotmail.com','Patrick Taylor','37 Tynong Road','Tynong','Victoria','AUSTRALIA','3813','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 09:31:23',0,NULL,3,1,2,1,'30120373846\r ',NULL),(23421,836508324002,120593062257,'New Pro Photo Vest for all DSLR fans  Size: XL',1,'AA1104',30,'hermeshine','19akinin69','19aaa69@mail.ru','Andrey Alikin','Stroitelei 1-3','Dobryanka','Perm region','RUSSIAN FEDERATION','618740','834226539430','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 09:35:35',0,NULL,3,1,3,1,'RA184521859CN\r ',NULL),(23422,792298842001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','kcarver2','kcarver2@bellsouth.net','Kevin Carver','962 S Shady Grove Rd<br>Ste 309','Memphis','TN','UNITED STATES','38120-4117','(770) 778-1321','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-04 10:21:23',0,NULL,3,1,1,1,'LK187847639CN\r ',NULL),(23423,836521624002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','sidabrogysla','mastermillione@gmail.com','Richard Lochinskij','L.Asanaviciutes46-9','Vilnius','karoliniskes','LITHUANIA','04319','+37067978695','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 10:23:55',0,NULL,3,1,24,1,'30120374292\r ',NULL),(23424,797997994018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',40.85,'photographyacc','watch27','wilkinson27@hotmail.com','Michael Wilkinson','Tudhope Farm<br>Whiteditch Lane','Newport','Essex','UNITED KINGDOM','CB11 3UD','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-04 10:51:16',0,NULL,3,1,3,1,'RA184521765CN\r ',NULL),(23425,792329817001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','jolitakey','jolita.kimsaite@gmail.com','Jolita Kimsait','Paupio 11-1','Vilnius','','LITHUANIA','01201','+37080079881','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-04 12:05:02',0,NULL,3,1,21,1,' ','欧标 '),(23426,939956059015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','sweetmysteryscott','skotti@hotmail.co.uk','Scott Allinson','39 Ash Grove','Bradford','West Yorkshire','UNITED KINGDOM','bd7 1bn','07983645865','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-04 13:24:51',0,NULL,5,0,18,0,NULL,'客户要取消订单 '),(23427,857928466017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','jabrda','sunshine1406@bigpond.com','Jayne Field','35 Monterey Crescent','Warnbro','Western Australia','AUSTRALIA','6169','0438934620','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-04 15:08:46',0,NULL,3,1,11,1,NULL,NULL),(23428,836623788002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','curiousdude','rex_hogan@msn.com','Avery Hogan','313 Leeward Way','Newport News','VA','UNITED STATES','23601-1082','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-04 15:12:38',0,NULL,3,1,1,1,NULL,NULL),(23429,920518623016,260933199108,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.9,'hutongstore','chiu-tin','hk520@ymail.com','Chiu Tin Lam','Seconds House<br>Lancing College','Lancing','West Sussex','UNITED KINGDOM','BN150RW','07544186698','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-04 16:02:22',0,NULL,3,1,11,1,NULL,'已发货 '),(23430,920569614016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','dennisbek','dbek@spacecube.gr','Dionissios Bekatoros','61 Klious Str','Athens','Attiki','GREECE','15561','00306972425985','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 17:18:16',0,NULL,3,1,24,1,'30120355381\r ',NULL),(23431,792469232001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','lalamer','la-fae@hotmail.com','Lara Jamison','3551 Highway 101','Roberts Creek','BC','CANADA','V0N 2W2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 17:32:30',0,NULL,3,1,11,1,NULL,NULL),(23432,920627775016,260767466741,'Genuine LENSPEN Lens Cleaning Pen Kit for DSLR/VCR',1,'AA1310',3.78,'hutongstore','joegrech1','joe@joegrech.com','Joe Grech','Ave Marija, St Leonard Str<br>Xewkija','Gozo - Malta','','MALTA','XWK 9073','+35699268784','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 18:42:55',0,NULL,3,1,24,1,'30120375530\r ',NULL),(23433,792507466001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','tookotook','tooko.took@gmail.com','François Le Blond','78 Königsbrücker Strasse','Dresden','','GERMANY','01099','0033632689322','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-04 18:43:48',0,NULL,3,1,21,1,'RA184521505CN\r ',NULL),(23434,792509547001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',3,'AC2401',50.97,'hermeshine','pongg007','thoon4@hotmail.com','Paithoon Moonsadang','777/45  Wongsawat Village  Soi. Lasale 24<br>Sukhumvit 105 Rd. Bangna','Bangna','Bangkok','THAILAND','10260','(668)1560-6000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 18:46:54',0,NULL,3,1,10,1,'RF076270847SG\r ','称一下重量 算运费 \r1.172\r.'),(23435,836742007002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',30.9,'hermeshine','aldi77aldi77','aldialdi@gmail.com','Alexander Dimitrov','18 Nikolay Gogol Str.<br>UnrealSoft, A-4','Plovdiv','Plovdiv','BULGARIA','4000','359887648009','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 18:56:42',0,NULL,3,1,21,1,'RA184521814CN\r ','欧标 '),(23436,940173758015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','3141antoniod','tonydigilio@hotmail.it','Domenico Digilio','Via Mario Pagano<br>n°53','CAMPOMAGGIORE','PZ','ITALY','85010','3207289305','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-04 19:12:58',0,NULL,3,1,4,1,'YW868897985CN ','黑加白 '),(23437,836772520002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','paez4','trefoil4@yahoo.com','Gil Paez','19111 Apelt Dr','Cleveland','OH','UNITED STATES','44135-1732','(440) 353-3518','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-04 19:49:16',0,NULL,3,1,1,1,NULL,NULL),(23438,792606479001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','maxwell_funk','maxwell_funk@hotmail.com','Cory Hicks','921A 39th Street','Calgary','AB','CANADA','T3C 1V1','(403) 246-1900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-04 22:02:22',0,NULL,3,1,3,1,'RA184521624CN\r ','新地址：\rCory Hicks\r91 Windermere Road SW, \rCalgary AB, T3C3K6\rCANADA\r(403) 246-1900\r '),(23439,940321086015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',1,'AB3332',1.58,'hutongstore','shedimus','shedimus@hotmail.com','James Shead','19 Strand Street','Poole','Dorset','UNITED KINGDOM','BH151SB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-04 23:18:22',0,NULL,3,1,2,1,'30120372984\r ',NULL),(23440,836875087002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','macfrickins','macfrickins@gmail.com','Jakub Kris','Skroupova 12','Brno','','CZECH REPUBLIC','63600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-04 23:34:13',0,NULL,3,1,3,1,'RA184521774CN\r ',NULL),(23441,836913713002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','ubong688','ubong688@yahoo.com','Anthony Inyang','590 Chancellor Dr W','Jacksonville','FL','UNITED STATES','32225-8143','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 01:37:46',0,NULL,3,1,21,1,'RA184521482CN\r ',NULL),(23442,836916148002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','ir','rejwan@emberweb.com','Elan Rejwan','3006 Bernadette Ln','Houston','TX','UNITED STATES','77043-1302','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-05 01:47:17',0,NULL,3,1,1,1,NULL,'发那个大的，有扣的那个 '),(23443,792716759001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','dan5206','dlapasha@lticorp.com','Dan LaPasha','5206 Duraleigh Rd','Raleigh','NC','UNITED STATES','27612','(919) 783-6900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 04:02:02',0,NULL,3,1,1,1,NULL,NULL),(23444,798443151018,280674125495,'New Neoprene Neck Shoulder Strap for  SLR camera',1,'AB1407',5.08,'photographyacc','bdq30','bdq304@hotmail.com','Tanya Reus','PO Box 2257<br>Wandal Post Office','Rockhampton','Queensland','AUSTRALIA','4700','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 04:32:10',0,NULL,3,1,11,1,NULL,NULL),(23445,795921989018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',19.1,'photographyacc','grgilmour','boosta-image@hotmail.com','Rochelle Gilmour','18a Leonard Street','Frankston','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-05 05:07:04',0,NULL,3,1,3,1,'RA184521615CN\r ',NULL),(23446,792737983001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',4,'AE1203',20,'hermeshine','new_england2','nengland2@myfairpoint.net','RC NH Crafts','21 Jennifer Ln','Jaffrey','NH','UNITED STATES','03452-5726','(603) 933-3794','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-05 05:47:19',0,NULL,3,1,1,1,'LK190248343CN\r ',NULL),(23447,792752397001,110533632347,'Super heavy clamp photography all metal capacity15kg',1,'AD1148',27.5,'hermeshine','eternal_matt','m.b@fullmail.de','Matthias Brellochs','Barbarosssastrasse 24','Schwäbisch Gmünd','','GERMANY','73529','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 07:08:34',0,NULL,3,1,21,1,'RA184521496CN\r ',NULL),(23448,836158215002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','roman.kamko','r.kamko@gmail.com','Roman Kamko','kv. Jukova 4/75','Lugansk','UA','UKRAINE','91051',' 380503262212','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 09:35:07',0,NULL,3,1,21,1,'RA184521479CN\r ',' '),(23449,940554003015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','saturoldan','saturoldan@hotmail.com','jose luis roldan sosa','virgen de todos los santos nº 11,4ª,9ª','Sevilla','Andalucía Ceuta y Melilla','SPAIN','41011','685815521','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 10:54:32',0,NULL,3,1,2,1,'30120374314\r ',NULL),(23450,798552110018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','scr142','scr142eb@yahoo.co.uk','Paul Johnson','6, Heather Close,<br>St Leonards,','Ringwood,','Hants,','UNITED KINGDOM','BH24 2QJ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 11:03:49',0,NULL,3,1,11,1,NULL,NULL),(23451,921028430016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',2,'AD1177',35.8,'hutongstore','dkjellgr','dave@djswedish.com','David Kjellgren','5 Harrisons Rise, waddon','Croydon','London','UNITED KINGDOM','CR04LL','07956191143','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 11:04:59',0,NULL,3,1,3,1,'RA184533582CN ',NULL),(23452,837090872002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','rrsq1308','monti1967@hotmail.com','Rosa María Rísquez Ortega','C/ El Capricho, 4<br>14610-Alcolea','Córdoba','Andalucía Ceuta y Melilla','SPAIN','14610','957321482','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 12:01:32',0,NULL,3,1,2,1,'30120371746\r ',' '),(23453,858538515017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',68,'photographyacc','phillipsese','phillipmhatton@gmail.com','Phillip Hatton','16 Herne Street','Herne Hill','Victoria','AUSTRALIA','3218','0352295650','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-05 12:22:47',0,NULL,3,1,4,1,'YW868898000CN ','澳标\r换成弹簧灯架吧'),(23454,792860524001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','rashuli','raulbaena@hotmail.es','Raúl Baena Casado','Torre Abenzoar nº12','Benacazón (Sevilla)','Andalucía Ceuta y Melilla','SPAIN','41805','955705455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 12:23:38',0,NULL,3,1,2,1,'30120370722\r ',NULL),(23455,792892137001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','sergeyellad','ellad@ngs.ru','Sergey Popadenkin','Ivanova 15, 43','Novosibirsk','','RUSSIAN FEDERATION','630055','383-316-5682','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 13:27:59',0,NULL,3,1,5,1,'CP244548326CN ',NULL),(23456,921108284016,260901272211,'New Camera protector case Neoprene bag for Nikon D90 D7000 D80 L',1,'AD1173',6.5,'hutongstore','garyosono','hoyingyin@hotmail.com','Gary HO','98 EASTBOURNE ROAD<br>EAST HAM','LONDON','London','UNITED KINGDOM','E6 6AS','07774707091','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 13:28:46',0,NULL,3,1,11,1,' ',NULL),(23457,940663621015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','jpakaerc','jpakaerc@yahoo.fr','Jean philippe Carlier','34 Bd Laennec','rennes','Bretagne','FRANCE','35000','+33642443615','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 13:59:50',0,NULL,3,1,3,1,'RA184521709CN\r ',NULL),(23458,857553055017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',10,'AA2202',33.2,'photographyacc','swissdolphin','christian.marchon@edu.ge.ch','Christian  Marchon','c/o Sophie de Mazières<br>6, Impasse des Grandes Vignes','MARGENCEL','Rhône-Alpes','FRANCE','74200','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-05 14:24:40',0,NULL,1,0,3,1,NULL,'爵影红外 5 in 1   10 '),(23459,940701916015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',5.5,'hutongstore','ajantas1537','ragnarokas@gmail.com','Aleksandras Sevcik','Zolynu 1-25','Klaipeda','Klaipedos 9-asis pastas','LITHUANIA','92325','+37067658811','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 14:56:11',0,NULL,3,1,24,1,'30120373080\r ',NULL),(23460,921177504016,260661735026,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',29,'hutongstore','jamesh7061','deshalliday50@talktalk.net','James Halliday','Prescott Street Garage<br>Prescott Street','Halifax','West Yorkshire','UNITED KINGDOM','HX1 2LF','01422363300','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 15:11:58',0,NULL,3,1,3,1,'RA184521690CN\r ',NULL),(23461,921192380016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',29.98,'hutongstore','andressony10','andresgomezcanarte@hotmail.com','andres  gomez','lobez pueyo 8, ppal izda','zaragoza','Aragón','SPAIN','50007','630254774','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 15:33:49',0,NULL,3,1,21,1,'RA184521465CN\r ',NULL),(23462,837222082002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','klaeslinden','klaes@hotmail.com','Klaes Lindenstroem','Skovbakkevej 10','Brabrand','DK','DENMARK','8220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 16:02:21',0,NULL,3,1,24,1,'30120375062\r ',NULL),(23463,921221753016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','grandad0123','sandralaverack@yahoo.co.uk','Sandra Laverack','108 Scholes Park Road','Scarborough','North Yorkshire','UNITED KINGDOM','YO12 6RA','01723352325','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 16:11:23',0,NULL,3,1,3,1,'RA184521686CN\r ','XL 已入库 '),(23464,837274416002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','ivan-77','iv-os@rambler.ru','Ivan O Osipov','app. 15, bld. 16/3, 15-aya Parkovaya str.','Moscow','','RUSSIAN FEDERATION','105203','932-9086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 17:11:41',0,NULL,3,1,3,1,'RA184521672CN\r ',NULL),(23465,837277471002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','yngvar.woxmyhr','yngvar@fortoyning.no','Yngvar Woxmyhr','Haumyrlia 13','Kristiansand','','NORWAY','4637','91324667','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-05 17:14:35',0,NULL,3,0,21,1,'RA184521553CN\r ','L  已入库 '),(23466,940853968015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',49.98,'hutongstore','olamb2','olamb@free.fr','Lambert olivier','30 rue de Turbigo','Paris','Île-de-France','FRANCE','75003','06 08 95 89 26','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 17:43:11',0,NULL,3,1,4,1,'YW868898011CN ','两套 '),(23467,940867760015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','optinoss','lempersjo@gmail.com','Kim Roos','Aallokko 3 A 28','Espoo','','FINLAND','FI-02320','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 17:56:10',0,NULL,3,1,21,1,'RA184521540CN\r ','4节 '),(23468,940883884015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','futuristicnick','fttproductions@hotmail.com','nick hardy','2c lutterworth drive','doncaster','South Yorkshire','UNITED KINGDOM','dn6 7bx','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 18:08:20',0,NULL,3,1,3,1,'RA184521669CN\r ',NULL),(23469,837330735002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','nikosfra','nikosfra@gmail.com','NIKOS FRAGKOULIS','2 STHNIDON STR','MEGARA','MEGARA','GREECE','19100','+302296021041','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 18:10:48',0,NULL,3,1,24,1,'30120368633\r ',NULL),(23470,940895647015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','greaseh','sam.revel@gmail.com','Samuel J Revel','Little Dean, Nairdwood Lane<br>Prestwood','Great Missenden','Buckinghamshire','UNITED KINGDOM','HP16 0QF','01494865761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 18:17:45',0,NULL,3,1,3,1,'RA184521902CN\r ',NULL),(23471,940896358015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','celiuki','carmenpieiroboo@hotmail.com','Carmen Mª Piñeiro Sanchez','c/ Pozo San Antonio, 5, 1º derecha','Moreda de Aller','Asturias','SPAIN','33670','985480748','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 18:20:18',0,NULL,3,1,21,1,'RA184521805CN\r ',NULL),(23472,921369233016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','smarston2610','stuart.marston@ntlworld.com','stuart marston','10<br>Malton Road','North Hykeham, Lincoln','Lincolnshire','UNITED KINGDOM','LN6 8HR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 18:34:26',0,NULL,3,1,2,1,'30120367664\r ',NULL),(23473,793185427001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','d.irina1975','dumon74.13@gmail.com','Dzhangirova Irina','ul Shelaeva dom 10 kv 52','Kaluzhskaja obl.','gKirov','RUSSIAN FEDERATION','249444','(910)8664425','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 19:43:28',0,NULL,3,1,11,1,NULL,NULL),(23474,793216820001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','chicagoprints','pjwarneka@yahoo.com','Patrick Warneka Photography','4814 N Clark St<br>Apt 210','Chicago','IL','UNITED STATES','60640-7768','(773) 915-3178','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-05 20:16:37',0,NULL,3,1,1,1,NULL,NULL),(23475,941088342015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','fine2011art','gdg2011@yahoo.com','Georges Djambov','309 B<br>Cann Hall Road','Leytonstone','London','UNITED KINGDOM','E11 3NL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-05 20:52:21',0,NULL,3,1,4,1,'YW868897974CN ','1.6*2.1  白色布\r英标 '),(23476,940932746015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','sfessey','stephenfessey@hotmail.com','Stephen Fessey','58 St Mary\'s Road<br>Bearwood','Birmingham','West Midlands','UNITED KINGDOM','B67 5DH','01214203054','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-05 20:57:11',0,NULL,3,1,11,1,NULL,NULL),(23477,837550738002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','fek07','fekdani@hotmail.com','Fekete Dani','Szent Miklós street 4/A','Szigetszentmiklós','Pest','HUNGARY','2310','3670-2973508','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 22:23:03',0,NULL,3,1,21,1,'RA184521788CN\r ',NULL),(23478,921631249016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',2,'AD1122',13,'hutongstore','thomkaran','thomkaran@gmail.com','THOMAS KARANIKAS','EFFIMOU 3-5<br>AGIOS ARTEMIOS','ATHENS','','GREECE','11632','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-05 22:56:05',0,NULL,3,1,24,1,'30120375655\r ',NULL),(23479,837583223002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',36,'hermeshine','trimman99','trimman99@shaw.ca','Tony Hansen','133 Jewell St','Red Deer','AB','CANADA','T4P 3W3','(403) 314-1243','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 23:45:24',0,NULL,3,0,3,1,'RA184521575CN\r ','1.6*3  黑   1\r1.6*3  灰    1 '),(23480,837576599002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','java_head85','dewaals@internode.on.net','Aaron de Waal','32 Thomas Street<br>Kangaroo Point','Brisbane','Queensland','AUSTRALIA','4169','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-05 23:37:46',0,NULL,3,1,3,1,'RA184521567CN\r ',NULL),(23481,941222079015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ajt3103','andytaylor3103@btinternet.com','andy taylor','143 Bourton Way','wellingborough','Northamptonshire','UNITED KINGDOM','NN82NU','07921757850','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 00:39:31',0,NULL,3,1,3,1,'RA184521655CN\r ',NULL),(23482,941226511015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','rus306','russ.falkingham@btconnect.com','russell falkingham','12 Cholmley Villas, Portsmouth Rd','Thames Ditton','Surrey','UNITED KINGDOM','KT7 0XU','0208339089','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 00:53:01',0,NULL,3,1,11,1,NULL,NULL),(23483,837615596002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','grapitix','jorgealberca@gmail.com','Jorge Alberca','c/. Ramon Gomez de la Serna 117<br>3ºB','Madrid','Madrid','SPAIN','28035','695628759','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 01:29:09',0,NULL,3,1,17,0,NULL,NULL),(23484,8881328492286368,111,'New Photo Studio Light Stand Umbrella Flash B-Mount set -Wholesale/ Retail ',1,'AKT014',42.99,'aliexpress','1006554769 ','vladsemenkov@rambler.ru','Vlad Semenkov	','pr. Engelsa, d.130, k.1, kv.50','Saint-Petersburg	','Saint-Petersburg	','RUSSIAN FEDERATION	','194356','+8 812 5132678',NULL,NULL,NULL,'2012-02-06 01:38:06',0,NULL,3,1,3,1,'RA184521641CN\r ',NULL),(23485,941180358015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','lloureiro1','loureiro.miguel@sapo.pt','luis loureiro','rua jose afonso 66 3 esq<br>são vicente','braga','braga','PORTUGAL','4700-392','00351964727286','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 01:39:31',0,NULL,3,1,21,1,'RA184521791CN\r ','欧标 '),(23486,8881328492753637,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included Wholesale/ Retail [AC2402]',1,'AC2402',23.99,'aliexpress','1006572347 ','nikgontar@ya.ru','Gontar Nikolay	','Kashirskoe shosse','Moscow','Moscow','RUSSIAN FEDERATION	','115201','+7 916 4897597',NULL,NULL,NULL,'2012-02-06 01:45:53',0,NULL,3,1,3,1,'RA184521638CN\r ','115201, Moscow, \"Kashirskoe shosse, 16-241'),(23487,837623800002,120462363779,'CTR-301 P Wireless Flash Trigger Kit with PC Port ',1,'AKT013',25.8,'hermeshine','grapitix','jorgealberca@gmail.com','Jorge Alberca','c/. Ramon Gomez de la Serna 117<br>3ºB','Madrid','Madrid','SPAIN','28035','695628759','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 01:54:09',0,NULL,3,1,4,1,'YW868898022CN ','三脚架  伟峰 WF-6662A    1 \r永诺 CTR-301P 触发器    1\r永诺 CTR-301P 接受器    1\r2B柔      1'),(23488,837633249002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','grapitix','jorgealberca@gmail.com','Jorge Alberca','c/. Ramon Gomez de la Serna 117<br>3ºB','Madrid','Madrid','SPAIN','28035','695628759','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 02:21:12',0,NULL,3,1,17,0,NULL,NULL),(23489,8881328495627236,111,'伟峰 6662A 快装板',1,'AB1202',0,'hermeshine','ftdeajos','estebanyelu@yahoo.es','Esteban Belinchón Sánchez','C/ Aragón,3-3º dcha<br>Toledo','Toledo','Castilla-La Mancha','SPAIN','45005','925623243',NULL,NULL,NULL,'2012-02-06 02:33:47',0,NULL,3,1,21,1,'RA184521831CN\r ',NULL),(23490,793400337001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',2,'AC1303',15,'hermeshine','guilherme4x4','guilherme@dtecnologia.net','Guilherme Netto','Rua Americo Vasone,78','Itapecerica da Serra','SP','BRAZIL','06850-600','+5511 9486-0862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 03:39:11',0,NULL,3,1,24,1,'30120462282\r ',NULL),(23491,793408118001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','tay.cru.productions','tay.cru.productions@gmail.com','Ariane De La Cruz: Desk 8.53','c/o AXA Mailroom<br>Level 7, 750 Collins Street','Docklands','Victoria','AUSTRALIA','3008','0386885356','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 04:18:13',0,NULL,3,1,11,1,NULL,NULL),(23492,793435350001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','karyshev','akaryshev@gmail.com','Aleksandr Karyshev','Sovhoznaya 103','Abakan','Respublika Khakassia','RUSSIAN FEDERATION','655009',' 79832793054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 06:08:29',0,NULL,3,1,5,1,'CP244548312CN ','欧标 '),(23495,799245619018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',8.5,'photographyacc','shugga_75','andrewshugg@hotmail.com','Andrew Shugg','97 Goddard Street<br>Lathlain','Perth','Western Australia','AUSTRALIA','6100','0407021485','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-06 10:05:30',0,NULL,3,1,11,1,'BJ01669425\r ',NULL),(23493,793469032001,110723333926,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT075',310,'hermeshine','vladaliska','vlada@liskovic.cz','vladislav liska','Jezuitska 6','Litomerice','Czech','CZECH REPUBLIC','412 01','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 09:09:13',0,NULL,3,1,5,1,'CP244548286CN ','欧标 '),(23494,793473845001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','minhnguyenab66','m-c.nguyen@bluewin.ch','Minh-Chanh Nguyen','Rue de la Laiterie 3','Montmagny','','SWITZERLAND','1587','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 09:29:55',0,NULL,3,1,21,1,'RA184522001CN\r ',NULL),(23496,837742929002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',2,'AD1226',7,'hermeshine','mineralwave','dalbor@hotmail.com','Boris Daljevic','Archipel 3423','Lelystad','','NETHERLANDS','8224 HG','+31645346446','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 10:07:10',0,NULL,3,1,24,1,'30120560842\r ',NULL),(23497,941396238015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','andrej_86_2008','jegorov.andrej@mail.ru','Andrej Jegorov','Debreceno 10-41','KLAIPEDA','','LITHUANIA','LT94140','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 10:18:24',0,NULL,3,1,24,1,'30120570966\r ',NULL),(23498,921848427016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','drew0011296','drew0011296@yahoo.co.uk','Andrew J Cunningham','Flat 10 / 2J<br>2 Rosefield Street','Dundee','Angus','UNITED KINGDOM','DD1 5PP','01382522308','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 10:37:12',0,NULL,3,1,3,1,'RA184521876CN\r ',NULL),(23499,793477798001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','ilya-narizniy','narizniy@ukr.net','dmitro naryzhnyi','Gritsevca st., 11-a, 22','Kharkiv','','UKRAINE','61172','(050) 403-6544','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 10:38:22',0,NULL,3,1,21,1,'RA184521933CN\r ',NULL),(23500,859245489017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',29.99,'photographyacc','lishalinski','lishalinski@hotmail.com','Alicia Weston','73 Parkholme Road','London','London','UNITED KINGDOM','E8 3AQ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 10:54:42',0,NULL,3,1,3,1,'RA184521981CN\r ','XL 已入库 '),(23501,921861913016,260894475419,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',19.98,'hutongstore','kalletappinen','timo.flinkkila@kolumbus.fi','Timo Flinkkilä','Hyökkäläntie 10 A 6','Tuusula','','FINLAND','04300','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 11:14:27',0,NULL,3,1,25,1,'RT126880375HK ',NULL),(23502,941423862015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','marikanator2012','marikanator@gmail.com','Marika Hyldmar','dalvejen 181','Silkeborg','Denmark','DENMARK','8600',' 50486223','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 11:33:50',0,NULL,3,1,4,1,'YW868897893CN\r ','黑加白 '),(23503,941435212015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','zhivko_mironov','jivko.mironov@hotmail.com','Zhivko Mironov','34 Drury House, Patmore Estate','London','London','UNITED KINGDOM','SW8 4JJ','07882547263','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 12:03:31',0,NULL,3,1,11,1,'BJ01669419\r ',NULL),(23504,939615756015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','stanislavaslavcheva','stanislava_sl@abv.bg','Stanislava Slavcheva','bul. \"6-ti septemvri 74\" -optika Solaris','Plovdiv','','BULGARIA','4000','00359886181008','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 12:26:42',0,NULL,3,0,24,1,'30120564434\r ',NULL),(23505,837785659002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','chechelecuatro','chechelecuatro@yahoo.es','Jose Manuel  Mata Casado','Carretera de la Coria, 4A, BJC M','Gijon','Asturias','SPAIN','33209','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 12:35:32',0,NULL,3,1,22,1,'BJ01669417\r ',NULL),(23506,941448211015,250692241258,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.45,'hutongstore','tobymasonuk','tobywm@gmail.com','Toby Mason','64a Chesterton Lane','Cirencester','Gloucestershire','UNITED KINGDOM','GL7 1TR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-06 12:36:58',0,NULL,3,1,11,1,'BJ01669423\r ',NULL),(23507,793544585001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','nmnk2010','naumenkopharma@gmail.com','Helen Naumenko','16/6, Kirova prospekt','Rubezhnoe','Ukraine','UKRAINE','93010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 13:37:34',0,NULL,3,1,5,1,'CP244674704CN\r ','黑加白 '),(23508,837803799002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','chudaming522','chudaming@hotmail.com','Daming CHU','F1 /47 Dynnyrne Rd','Dynnyrne','Tasmania','AUSTRALIA','7005','0412703888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 13:37:59',0,NULL,3,1,11,1,'BJ01669422\r ',NULL),(23509,941476329015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','katheknit','lewis.kathe@gmail.com','Kathe Lewis','Ejstrupvej 52','Faarup','DK','DENMARK','8990','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 13:43:39',0,NULL,3,1,22,1,'BJ01669424\r ',NULL),(23510,793559025001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','paulo27','paul.skakavy@seznam.cz','Pavel Sikora','Karla Pokorneho 1396/38','Ostrava','','CZECH REPUBLIC','70800','+420776696423','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 14:19:54',0,NULL,3,1,24,1,'30120551134\r ',NULL),(23511,837854044002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','bapbap451','bap451@gmail.com','Oleg Shcherbakov','123 Slavy Street, Appartment 184','Belgorod','Belgorod State','RUSSIAN FEDERATION','308015','79155227478','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 15:48:02',0,NULL,3,1,3,1,'RA184521862CN\r ',NULL),(23512,941558479015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',5,'AD1199',94.5,'hutongstore','belogor83','akoshechkin@gmail.com','Aleksey Koshechkin','Demjana Bednogo dom22 korp2 kv58','Sankt-Petersburg','','RUSSIAN FEDERATION','195276','921-6370242','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 16:29:30',0,NULL,3,1,5,1,'CP244548272CN ',''),(23513,793609500001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','tandre-hu','andras@e-vista.hu','Evista Kft.','Attila u. 11. I. em.','Szeged','','HUNGARY','6722','003662452239','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 16:32:00',0,NULL,3,1,5,1,'CP244674735CN\r ','黑加白 '),(23514,793611207001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','aleks0074','zecawell@mail.ru','Alexey Bryuhov','Lesnaya 22a','poselok Zaozerniy goroda Kopeyska','Chelyabinskaia oblast','RUSSIAN FEDERATION','456659',' 79049463748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 16:35:57',0,NULL,3,1,17,0,NULL,NULL),(23515,837875059002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',2,'AE3104',19.36,'hermeshine','aleks0074','zecawell@mail.ru','Alexey Bryuhov','Lesnaya 22a','poselok Zaozerniy goroda Kopeyska','Chelyabinskaia oblast','RUSSIAN FEDERATION','456659',' 79049463748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 16:35:58',0,NULL,3,1,3,1,'RA184521955CN\r ','反光板支架   1 \rc型大力夹      2'),(23516,859375627017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',4.19,'photographyacc','blackvwgolf2','emailrossy2003@yahoo.co.uk','Ben Ross','2 Highfield House, Regency Park Road','Pudsey, Leeds','West Yorkshire','UNITED KINGDOM','LS288PW','07782198535','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 16:38:03',0,NULL,3,1,11,1,'BJ01669421\r ',NULL),(23517,837886553002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','christgoodbuy','sdanila@gmail.com','Danila Stupakov','Oktyabrskiy pr. 118/1-48','Syktyvkar','KOMI','RUSSIAN FEDERATION','167031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 17:01:39',0,NULL,3,1,3,1,'RA184521947CN\r ',NULL),(23518,793644209001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','josiasfreitasjr','freitasfotos@gmail.com','josias Freitas junior','SRES Quadra 5 Bloco B Casa 51<br>Cruzeiro Velho','Brasília','Distrito Federal - DF','BRAZIL','70.640-027','556199253766','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-06 17:50:00',0,NULL,3,1,25,1,'RT126877915HK ','M 已入库 '),(23519,837930404002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 18:27:35',0,NULL,3,1,25,1,'RT126881923HK ',NULL),(23520,793666804001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','tomcat6997','dstey27@yahoo.com','Derek Stey','1015 Mohawk Rd. East<br>Apt#401','Hamilton','ON','CANADA','L8T 2R9','(905) 521-9541','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 18:29:01',0,NULL,3,1,11,1,NULL,' 已发货'),(23521,793672641001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','thefuryka','gergo.vamos@gmail.com','Gergő Vámos','Báthori út 25.','Tiszavasvári','Szabolcs-Szatmár-Bereg Megye','HUNGARY','4440','36209725882','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 18:39:48',0,NULL,3,1,21,1,'RA184521916CN\r ',NULL),(23522,859469579017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','boxeopatricia6498','patricia6498@hotmail.com','marta pinillos del castillo','plaza del coso,4-2ºc','logroño','La Rioja','SPAIN','26001','941259409','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 19:18:47',0,NULL,3,1,17,0,NULL,NULL),(23523,859482268017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','boxeopatricia6498','patricia6498@hotmail.com','marta pinillos del castillo','plaza del coso,4-2ºc','logroño','La Rioja','SPAIN','26001','941259409','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 19:37:30',0,NULL,3,1,2,1,'30120569356\r ','眼罩 450D/500D   1 \r灯架包薄    1'),(23524,941693914015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',45.98,'hutongstore','albertocabasca','cabasca@terra.com','alberto cabañas','calle cañal nº 31<br>nambroca','toledo','Castilla-La Mancha','SPAIN','45190','620476778','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-06 19:48:10',0,NULL,3,1,4,1,'YW868897926CN ','2套 '),(23525,941719440015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','matt_zd','mfrey86@googlemail.com','Matthew Frey','64 Victoria Street<br>Briton Ferry','Neath','Neath Port Talbot','UNITED KINGDOM','sa11 2rb','','PayPalPaymentInProcess','CheckoutComplete','UK_EconomyShippingFromOutside','0000-00-00 00:00:00',0,NULL,5,0,18,0,'\r ',NULL),(23526,941728866015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-06 20:31:22',0,NULL,3,1,21,1,'RA184521920CN\r ','欧标\r包好一点 '),(23527,859556783017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','mariusz007-1984','suchy007-1984@tlen.pl','Mariusz Suszynski','49 Victoria Road   FLAT 2','Northampton','Northamptonshire','UNITED KINGDOM','NN1 5ED','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-06 21:33:37',0,NULL,3,1,11,1,'BJ01669416\r ',NULL),(23528,838044436002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','fth_17','fthyalcinkaya@gmail.com','Fatih Yalçınkaya','Anadolu Caddesi No: 23 Salhane İş Merkezi B Blok Kat: 5','İzmir','Bayraklı','TURKEY','35580','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 21:41:00',0,NULL,3,1,5,1,'CP244548241CN ',NULL),(23529,838074157002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','brianjen10','guitarstrum1@yahoo.com','brian browning','522 E Clay St','Collinsville','IL','UNITED STATES','62234','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-06 22:46:53',0,NULL,3,1,1,1,'LK191064451CN ',NULL),(23530,793820901001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','magman36','gilles.bujold@videotron.ca','gilles Bujold','1830 rue pruneau','st-maurice','QC','CANADA','G0x2x0','(819) 909-0871','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-06 23:27:53',0,NULL,3,1,11,1,'BJ01669418\r ',NULL),(23531,838100692002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','ky0587','smartalyk_05@hotmail.com','Kyla Macdonald','33133 Myrtle Avenue','Mission','BC','CANADA','V2V 4R6','(604) 820-2646','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 00:05:19',0,NULL,3,1,5,1,'CP244548238CN ',' '),(23532,838108249002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','fun4fitness','tapiomann82@hotmail.com','Erkko Tapio Manninen','Vaasankatu 20 A b 38','Helsinki','','FINLAND','00500','+358045884962','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 00:28:17',0,NULL,3,1,21,1,'RA184521978CN\r ',NULL),(23533,793840037001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','quixomo','suhyoonc@yahoo.com','Suhyoon CHo','2122 stillwater ave','olympia','WA','UNITED STATES','98502-4452','(360) 471-6383','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 00:31:39',0,NULL,3,1,1,1,'LK191217577CN ',NULL),(23534,799657894018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','mryan744','markry1@gmail.com','Mark Ryan','21 Hamish Grove','Rostrevor','South Australia','AUSTRALIA','5073','080432855744','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 02:03:05',0,NULL,3,1,3,1,'RA184521880CN\r ',NULL),(23535,8881328581663014,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head - Wholesale/ Retail',1,' AE1603',30.99,'aliexpress','Tania Cygl','123.hotmail@.com','Tatiana Tsyglakova','d.Kostrovo, ul. Centralnaja, d.23, kv.48<br>Moskovskaja oblast, Russian Federation','Istrinskij rajon,','Moskovskaja oblast','RUSSIAN FEDERATION','143522','+7 916 4843484',NULL,NULL,NULL,'2012-02-07 02:27:43',0,NULL,7,0,18,0,NULL,NULL),(23536,8881328581690150,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head - Wholesale/ Retail',1,' AE1603',30.99,'aliexpress','Tania Cygl','123.hotmail@.com','Tatiana Tsyglakova','d.Kostrovo, ul. Centralnaja, d.23, kv.48<br>Moskovskaja oblast, Russian Federation','Istrinskij rajon,','Moskovskaja oblast','RUSSIAN FEDERATION','143522','+7 916 4843484',NULL,NULL,NULL,'2012-02-07 02:27:43',0,NULL,7,0,18,0,NULL,NULL),(23537,8881328581798030,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head - Wholesale/ Retail ',1,'AE1603',30.99,'aliexpress','Tania Cygl','123.hotmail.com','Tatiana Tsyglakova','d.Kostrovo, ul. Centralnaja, d.23, kv.48<br>Moskovskaja oblast, Russian Federation','Istrinskij rajon,','Moskovskaja oblast','RUSSIAN FEDERATION','143522','+7 916 4843484',NULL,NULL,NULL,'2012-02-07 02:29:58',0,NULL,3,1,3,1,'RA184533375CN ','订单号： 1006611468'),(23538,618390402003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','613angel76','jenjen.chicabonita@yahoo.com','jenny thistlethwaite','46<br>pinkwood st.','bellbowrie','Queensland','AUSTRALIA','4070','617424985217','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 02:35:14',0,NULL,3,1,4,1,'YW868897915CN ',' '),(23539,8881328582374526,111,'Free shipping & Tracking # - YN Flash Battery Pack SF-18 for Canon Flash 580EXII CP-E4 - Wholesale/Retail ',1,'AB3307',49.99,'aliexpress','1006608028 ','123.hotmail@.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102<br>Aichi-ken, Japan','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-07 02:39:34',0,NULL,3,1,3,1,'RA184533335CN ','永诺 SF18- CANON   3 '),(23540,8881328582606333,111,'Free shipping & Tracking # - YN Flash Battery Pack SF-18 for Canon Flash 580EXII CP-E4 - Wholesale/Retail ',2,'AB3307',99.98,'aliexpress','1006608028 ','123.hotmail@.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102<br>Aichi-ken, Japan','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-07 02:43:26',0,NULL,7,0,18,0,NULL,NULL),(23541,8881328582624159,111,'Free shipping & Tracking # - YN Flash Battery Pack SF-18 for Canon Flash 580EXII CP-E4 - Wholesale/Retail ',2,'AB3307',99.98,'aliexpress','1006607651','123.hotmail@.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102<br>Aichi-ken, Japan','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-07 02:43:26',0,NULL,8,1,17,0,NULL,NULL),(23542,8881328586877142,111,'2m 灯架底座',1,'',0,'aliexpress','1006281203 ','sigorvic@yandex.ru','Igor Savchenko	','Parkovaya 19-13','Zelenogorsk','Region Krasnojarsk	','RUSSIAN FEDERATION	','663690','89138351737',NULL,NULL,NULL,'2012-02-07 03:54:37',0,NULL,3,0,3,1,'RA184521995CN\r ',NULL),(23543,799478156018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','andreyklychnikov','klychnikov@gmail.com','Andrey Klychnikov','Hachaturiana<br>20-69','Moscow','-','RUSSIAN FEDERATION','127273','+7 985 3604490','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 04:28:29',0,NULL,3,1,11,1,'BJ01669415\r ',NULL),(23544,799707300018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','lindibrey5563','lindibrey@gmail.com','Lindi Beckett','16B  Cabell  St','Yokine','Western Australia','AUSTRALIA','6060','0452188225','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-07 05:12:36',0,NULL,3,1,4,1,'YW868897005CN\r','黑加白 '),(23545,799724856018,280676581684,'New Hot Shoe Protector Cover Cap for Canon Nikon Pentax',5,'AA1204',12.5,'photographyacc','terrywl1','cleer1@optusnet.com.au','Terry Leer','3 Baden Powell Place','Winston Hills','New South Wales','AUSTRALIA','2153','0294286318','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 06:44:32',0,NULL,3,1,3,1,'RA184521964CN\r ',NULL),(23546,8881328601568919,111,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',2,'AD1217',71.98,'hermeshine','cannonneer','arlan.logan@gmail.com','ARLAN LOGAN','BOWLING CENTER--JEDDAH LANESMOSADIA 3, MADINAH ROAD','JEDDAH ','','SAUDI ARABIA','21573','',NULL,NULL,NULL,'2012-02-07 07:59:28',0,NULL,3,1,8,1,'CP244548255CN ','2.5m高灯架   2 \r伞式柔光箱 60×90cm    1\r已入库\r申报SAMPLE 20'),(23547,793833313001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',93.28,'hermeshine','ladyicexkaye','kaysianxxx@hotmail.com','kerry miles','70<br>laurel road','tipton','West Midlands','UNITED KINGDOM','dy49qz','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 08:43:20',0,NULL,3,1,3,1,'RA184533097CN\r ','新款内胆包 中号 canon logo   2\r摄影背心 Canon  老款  M     1\r摄影背心 Canon  老款  3XL     1\rMini 红外  canon    1\r已入库'),(23548,793952801001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','val5736','val195736@gmail.com','VALERY OTIN','yl.Galyhina,19-176','Arhangelsk','RU','RUSSIAN FEDERATION','163065','(906)285-0449','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 08:46:06',0,NULL,3,1,3,1,'RA184533083CN\r ',NULL),(23549,838228892002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','poster6ivan','ivanov_ivan6@abv.bg','Ivan Ivanov','Aleksandar Malinov 25 -et.2 -ap.6','Varna','Varna','BULGARIA','9000','0883347642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 08:46:24',0,NULL,3,0,21,1,'RA184533171CN\r ','1.6*3  黑色 '),(23550,838233675002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','fearhole86','fearhole@bk.ru','Andrey Golovanov','Lesnaya 57<br>39','Severodvinsk','Arhangelskaya','RUSSIAN FEDERATION','164501','9021930836','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 09:07:43',0,NULL,3,1,3,1,'RA184533145CN\r ',NULL),(23551,838226934002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','derbj390','bluesky123@live.co.uk','Bjorn Derik','03 Kansas Grove<br>Totara Park','Upper Hutt, Wellington','Wellington','NEW ZEALAND','5018','64211116294','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 08:35:05',0,NULL,3,1,2,1,'30120667065\r ',NULL),(23552,836531358002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','robson8710','robson_87@o2.pl','Robert Chmara','Napierskiego 42/18','Szczecin','zachodniopomorskie','POLAND','70783','691 449975','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 09:35:53',0,NULL,3,1,24,1,'30120691543\r ',NULL),(23553,838248519002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',2,'AA3301',6.5,'hermeshine','evgcom','evgvideo@yandex.ru','Evgeni Komoniuk','prospekt Gongadze 28, kv. 1','Kiev','Kievskaya oblast','UKRAINE','04215','380965232409','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 10:03:33',0,NULL,3,1,24,1,'30120680575\r ',NULL),(23554,922456439016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.4,'hutongstore','samantha101687','samantha1016@csu.fullerton.edu','Samantha Peterson','20160 Paseo Del Prado<br>Ste F','Walnut','CA','UNITED STATES','91789-2670','(626) 224-6006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 10:20:33',0,NULL,3,1,17,0,NULL,NULL),(23555,942033839015,250607841646,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',18,'hutongstore','samantha101687','samantha1016@csu.fullerton.edu','Samantha Peterson','20160 Paseo Del Prado<br>Ste F','Walnut','CA','UNITED STATES','91789-2670','(626) 224-6006','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-07 10:20:34',0,NULL,5,0,18,0,NULL,'客户要取消这个\r '),(23556,922456639016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',2.9,'hutongstore','samantha101687','samantha1016@csu.fullerton.edu','Samantha Peterson','20160 Paseo Del Prado<br>Ste F','Walnut','CA','UNITED STATES','91789-2670','(626) 224-6006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 10:20:34',0,NULL,3,1,17,0,NULL,''),(23557,922463163016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','samantha101687','samantha1016@csu.fullerton.edu','Samantha Peterson','20160 Paseo Del Prado<br>Ste F','Walnut','CA','UNITED STATES','91789-2670','(626) 224-6006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 10:36:13',0,NULL,3,1,1,1,'LK192399805CN\r ','麂皮   2 \rlenspen     1\r气吹 + 布   1 '),(23558,838260441002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 10:48:51',0,NULL,3,1,25,1,'RT126937596HK ',NULL),(23559,922486521016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','lysnapper','pictures_lyoung@yahoo.co.uk','Ms Lucy Young','23 Harold Road<br>Seven Sisters','London','London','UNITED KINGDOM','N15 4PL','07736564640','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 11:46:27',0,NULL,3,1,3,1,'RA184533295CN ',NULL),(23560,922489666016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','jpakaerc','jpakaerc@yahoo.fr','Jean philippe Carlier','34 Bd Laennec','rennes','Bretagne','FRANCE','35000','+33642443615','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-07 11:54:54',0,NULL,3,1,3,1,'RA184533450CN ',NULL),(23561,838279375002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','fotoroom','postofoto@gmail.com','Руслан Муртазин','ул.Школьная 10 - 25','Санкт - Петербург','','RUSSIAN FEDERATION','197183','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 11:57:52',0,NULL,3,1,3,1,'RA184533287CN ',NULL),(23562,794003719001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','sinapsi68','salviolil@libero.it','Salvioli Luca','Antonio da Firenze n.1','Rivolto','UD','ITALY','33030','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 12:06:52',0,NULL,3,1,12,1,'3125419146\r ','欧标 \r实重7.2 泡重10.1'),(23563,794005938001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','xc6.tiger','yonex@ua.fm','ILYA GELFER','Plehanov street,16/44','DNEPROPETROVSK','','UKRAINE','49000','+380562340647','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-07 12:14:18',0,NULL,3,1,5,1,'CP244674766CN\r ',NULL),(23564,794006315001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','ignigevi2011','pahomov_i_e@mail.ru','Igor Pahomov','Naberegnaya Gazovikov 3-52','Ukhta','Komi','RUSSIAN FEDERATION','169313','89125446044','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 12:15:37',0,NULL,3,1,3,1,'RA184533358CN\r ',NULL),(23565,922503287016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',2,'AD1182',92,'hutongstore','dosegaev','justserg@live.ru','Sergey Dosegaev','59 Gastello Street, Apartment 8','Tambov','Tambovskaya oblast','RUSSIAN FEDERATION','392001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 12:34:26',0,NULL,3,1,5,1,'CP244674752CN\r ',NULL),(23566,838311396002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 13:45:41',0,NULL,3,1,25,1,'RT126932829HK ','申报gift低值   '),(23567,838347649002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','alex_lykov','alexander_lykov@list.ru','Александр Лыков','ул. Греческая 72, кв 1','Таганрог','','RUSSIAN FEDERATION','347900','8-928-108-91-03','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 15:28:25',0,NULL,3,1,3,1,'RA184533401CN ',NULL),(23568,799878792018,280666892492,'New Green.L 67mm  Gradual Grey ND4 Filter 2-Stop 67 mm',1,'AA3319',6.27,'photographyacc','inzseller1','gdv@t-online.hu','Tibor Borbely','Remete koz 7','Budapest','','HUNGARY','1037','36 309516797','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 15:36:52',0,NULL,3,1,24,1,'30120688835\r ',NULL),(23569,922592538016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','arts-luxe-design','alexaebay@free.fr','alexandra sevlian','La Charmeraie A<br>7 av brown sequard','nice','Provence-Alpes-Côte d\'Azur','FRANCE','06000','06.23.15.29.87','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-07 16:05:04',0,NULL,3,1,3,1,'RA184533260CN ','欧标 '),(23570,838371212002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','dolphin-friend','cbbarzee@yahoo.com','Christy Barzee','730 Matchpoint Dr','Ammon','ID','UNITED STATES','83406-4531','(208) 523-1813','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 16:23:39',0,NULL,3,1,17,0,NULL,NULL),(23571,838371214002,120610363618,'CTR-301P Wireless Flash Trigger 2 Receiver w/ PC Sync',1,'AKT001',41.95,'hermeshine','dolphin-friend','cbbarzee@yahoo.com','Christy Barzee','730 Matchpoint Dr','Ammon','ID','UNITED STATES','83406-4531','(208) 523-1813','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 16:23:41',0,NULL,3,1,1,1,'LK192987506CN\r ','闪光灯B座   1 \r永诺 CTR-301P 触发器  1\r永诺 CTR-301P 接受器   2'),(23572,794085571001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','serge9093','scroge@wanadoo.fr','serge roge','le cil du roc<br>la rouquette','port ste foy et ponchapt','Aquitaine','FRANCE','33220','05.53.58.29.83.','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-07 16:14:07',0,NULL,3,1,3,1,'RA184532834CN ',NULL),(23573,922612385016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','fran9841','franmoledo@hotmail.com','Fran Moledo Millan','Bellavista, 13-3º','A Coruña','Galicia','SPAIN','15010','622029944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:51:00',0,NULL,3,1,17,0,NULL,NULL),(23574,922611396016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','fran9841','franmoledo@hotmail.com','Fran Moledo Millan','Bellavista, 13-3º','A Coruña','Galicia','SPAIN','15010','622029944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:51:01',0,NULL,3,1,17,0,NULL,NULL),(23575,922611670016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','fran9841','franmoledo@hotmail.com','Fran Moledo Millan','Bellavista, 13-3º','A Coruña','Galicia','SPAIN','15010','622029944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:51:01',0,NULL,3,1,17,0,NULL,NULL),(23576,922612605016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','fran9841','franmoledo@hotmail.com','Fran Moledo Millan','Bellavista, 13-3º','A Coruña','Galicia','SPAIN','15010','622029944','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 16:51:02',0,NULL,5,1,4,1,'YW868897871CN\r ','背景布 1.6*3  白色 \r灯架  2m  5\r柔光箱 50-70cm 单灯头  1\r斜臂   1\r5灯头+60-90棚   2\r115w 5500k 灯泡  220v   1\r45w 5500k 灯泡 220v   10\r3m 横杆（通用4节）   1\r灯架包    2\r灯架包薄    1\r澳转欧标\r已发货.........'),(23577,942199822015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','arta123arta','sirarta@gmail.com','arturas sirvelis','flat-52 Princethorpe house woodchester square','london','London','UNITED KINGDOM','w25su','07590183695','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 16:51:52',0,NULL,3,1,11,1,'BJ01669390 ',NULL),(23578,922618856016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','peternelfil','filip@peternel.info','Filip Peternel','Bacicev Prilaz 12','Pula','','CROATIA','52100','00385 98 464646','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-07 17:00:38',0,NULL,3,1,21,1,'RA184533239CN ',NULL),(23579,794113568001,110584165959,'10 x 20 ft backdrop system and continous lighting kit ',1,'AKT050',214,'hermeshine','as_rus_2011','godlikeblackk@gmail.com','Alexander Semin','Admiral Makarov Street, 45, 135','Moscow','Moscow','RUSSIAN FEDERATION','125212',' 9167934691','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 17:19:29',0,NULL,3,1,5,1,'CP244674783CN\r ','背景布换成绿色的\r再加几个夹子\r欧标 '),(23580,794161127001,110586906325,'Shoulder Support Pad for Video Camcorder Camera DV/DC',1,'AE1401',35.99,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-07 18:57:32',0,NULL,3,1,25,1,'RT126931899HK ',NULL),(23581,838218748002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',67.94,'hermeshine','mr-tyler.xmas','tc3jumps@hotmail.com','tyler','11b pinedale lane','christchurch','','NEW ZEALAND','8062','0210682137','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 19:28:25',0,NULL,3,1,25,1,'RT126935900HK ','85cm 两用伞   1 \r2B柔   1 \r已入库'),(23582,794191125001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','trasnidaren','trasnid@yahoo.se','Anders Johansson','Östermalmsgatan 36 A','Umeå','Sweden','SWEDEN','90332','070-6792177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 19:46:59',0,NULL,3,1,4,1,'YW868897882CN\r ',NULL),(23583,838459549002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','paulhub','paulhub@ebuyclub.com','Hubert PAULIN','Vigne Manay-Vaudrenant','MEZERIAT','Ain/Rhône Alpes','FRANCE','01660','0619575501','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 19:54:07',0,NULL,3,1,17,0,NULL,NULL),(23584,623940955004,140642546050,'New Swivel Flash Mount Umbrella Bracket for studio  Light Stand D',1,'AD1122',13.8,'hermeshine','paulhub','paulhub@ebuyclub.com','Hubert PAULIN','Vigne Manay-Vaudrenant','MEZERIAT','Ain/Rhône Alpes','FRANCE','01660','0619575501','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 19:54:08',0,NULL,3,1,3,1,'RA184533392CN ','反光伞110cm   2\r闪光灯D座    1 '),(23585,838477550002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','monokia79','monokia@gmail.com','Mónika Sáfár, Attila Monoki','2. street Kelemen László<br>building 4.  2./11.','Budapest','Budapest','HUNGARY','1026','+36304006392','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 19:59:42',0,NULL,3,1,5,1,'CP244548269CN\r ',NULL),(23586,942214014015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','philomene_7','elise.tabet@hec.ca','Elise Tabet','650 BOUL MARCEL-LAURIN APP 126','SAINT-LAURENT','QC','CANADA','H4M 0A1','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 20:29:01',0,NULL,3,1,3,1,'RA184532848CN ',NULL),(23587,922771686016,260677592103,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',49.99,'hutongstore','capaca_em','emilie.atkinson@gmail.com','emilie atkinson','7A Upper Leeson street','Dublin 4','','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-07 20:47:35',0,NULL,3,1,21,1,'RA184533225CN\r ','英标 '),(23588,922775737016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','stg123blue','info@stgpictures.com','Ian Rhodes','Polska 52<br>Vinohrady','Praha 2','Prague','CZECH REPUBLIC','120 00','420773930146','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 20:57:04',0,NULL,3,1,3,1,'RA184533313CN ','欧标 '),(23589,794232138001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','enck429','enck429@hotmail.com','Ignacio Martínez Soler','c Rocafort nº3 pta1','Moncada','Comunidad Valenciana','SPAIN','46113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 20:57:48',0,NULL,3,1,4,1,'YW868897904CN\r ',NULL),(23590,942391245015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','votabolha','leopinjor@hotmail.com','Leonel Pinto Jorge','Rua 23 nº1220 Espinho','Espinho','Aveiro','PORTUGAL','4500-274','936870308','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-07 21:31:09',0,NULL,3,1,24,1,'30120683191\r ',NULL),(23591,942413225015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','eloutay_83','bustertay11@yahoo.co.uk','emma taylor','25 chillerton road<br>west derby','liverpool','Merseyside','UNITED KINGDOM','l12 4ya','07581438301','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-07 22:07:11',0,NULL,3,1,11,1,'BJ01669389 ',NULL),(23592,860093630017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','amyvause','niallandrewnugent@gmail.com','Niall Nugent','17 Rowlagh Park','Clondalkin','Dublin','IRELAND','22','0857045078','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-07 22:15:18',0,NULL,3,1,24,1,'30120687170\r ',NULL),(23593,800098167018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',33.24,'photographyacc','oxenham_jimbob','blairjam@hotmail.com','James Tibbetts','33 Halsmere Street','Geebung','Queensland','AUSTRALIA','4034','0412144118','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 22:32:42',0,NULL,3,1,3,1,'RA184533168CN ',NULL),(23594,794290856001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','evae23','v23oly@aol.com','Sarah Olson','919 Scheffer Ave','Saint Paul','MN','UNITED STATES','55102-4011','(952) 367-6088','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-07 23:17:18',0,NULL,3,1,1,1,'LK194113117CN\r ',NULL),(23595,838572095002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','moosedusty','ingrid@perfectoarts.com.au','Ingrid Douglas','18-20 Woodridge Close','Redlynch','Queensland','AUSTRALIA','4870','0740391226','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 23:00:48',0,NULL,3,1,3,1,'RA184533256CN ',NULL),(23596,794082034001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','mettronomo','mettro@gmail.com','Eva Ferrandis Peris','C/ Poeta Artola, 11, Pta.5','Valencia','Comunidad Valenciana','SPAIN','46022','627257535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-07 23:40:48',0,NULL,3,1,21,1,'RA184533211CN ',NULL),(23597,860159377017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',8.55,'photographyacc','kumloong','joshmui@tpg.com.au','Joshua Mui','20 Heidelberg Avenue','Newington','New South Wales','AUSTRALIA','2127','0296471440','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-07 23:57:28',0,NULL,3,1,11,1,'BJ01669388\r ',NULL),(23598,794301816001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',8,'AC1301',49.92,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 00:16:20',0,NULL,3,1,25,1,'RT126922906HK ',NULL),(23599,922886120016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','larsenhannes','hannes.larsen@gmail.com','Hannes Larsen','Femkamsvägen 4','Skillingaryd','Småland','SWEDEN','56830','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 00:37:40',0,NULL,3,1,21,1,'RA184533300CN ',NULL),(23600,794326007001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','igorkd1','igorkdr@gmail.com','Igor Korduner','950 Warwick Ct,apt 308','Burlington','ON','CANADA','L7T 3Z5','(902) 218-4383','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 01:16:55',0,NULL,3,1,3,1,'RA184532825CN ',NULL),(23601,942507552015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','wakefield0512','stevenwakefield@sky.com','Steven Wakefield','144 Lowry Hill Road<br>Lowry Hill','Carlisle','Cumbria','UNITED KINGDOM','CA3 0ER','01228674808','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-08 01:52:11',0,NULL,3,1,3,1,'RA184533242CN ',NULL),(23602,838649181002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','thepond99','omaralikhan@gmail.com','OMAR  KHAN','2137 ERIN GATE BLVD.','PICKERING','ON','CANADA','L1X2V3','(905) 420-6822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 03:04:43',0,NULL,3,1,3,1,'RA184533361CN\r ','hermeshine\r申报gift'),(23603,800193249018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',17.1,'photographyacc','guilderton','roger.severn@bigpond.com','Roger Severn','13 Collinson Way','Leeming','Western Australia','AUSTRALIA','6149','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 03:30:56',0,NULL,3,1,3,1,'RA184533327CN ','photographyacc'),(23604,794365036001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','befriend2u','justaminutenow@gmail.com','Cyndi  Easterly','364 Monmouth Ave S','Monmouth','OR','UNITED STATES','97361-2110','(503) 606-0242','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 03:32:01',0,NULL,3,1,1,1,'LK193535374CN\r ','hermeshine'),(23605,922949594016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','asuvser','asuv@mail.ru','Alexander Suvorov','Zarubina str. 12a-38','Yoshkar-Ola','Mari El','RUSSIAN FEDERATION','424006','(917)709-2302','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 03:37:51',0,NULL,3,1,3,1,'RA184532905CN ','hutongstore'),(23606,838675116002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','nolz7873','nolen7873@iglide.net','Noel Curammeng','98-2053 Kikala St','Aiea','HI','UNITED STATES','96701-1649','(808) 484-1326','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-08 04:41:14',0,NULL,3,1,17,0,NULL,'hermeshine'),(23607,794381077001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1301',6.68,'hermeshine','nolz7873','nolen7873@iglide.net','Noel Curammeng','98-2053 Kikala St','Aiea','HI','UNITED STATES','96701-1649','(808) 484-1326','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-08 04:41:15',0,NULL,3,1,1,1,'LK194706251CN\r ','hermeshine\r橡胶遮光罩 72mm  1\r橡胶遮光罩 52mm   2'),(23608,794389957001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wizard-of-wonders','tweaked_out@shaw.ca','Paul W. Sharpe','17986 67 Ave','surrey','BC','CANADA','v3s8c3','(604) 220-4716','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 05:26:46',0,NULL,3,0,17,0,NULL,'hermeshine'),(23609,838688386002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','stagnant_vagrant','wongja+ebay@gmail.com','Jason Wong','#605 1053 10th St. SW','Calgary','AB','CANADA','T2R1S6','(403) 297-3040','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 05:47:37',0,NULL,3,1,3,1,'RA184532817CN ','hermeshine'),(23610,800224712018,280678920963,'Neoprene Protector Camera Cover Case for Canon Nikon L ',1,'AC1302',6.63,'photographyacc','fee160302','teamk@aapt.net.au','Fiona Kouwenberg','11 Corryton Court','Wattle Grove','New South Wales','AUSTRALIA','2173','0297310943','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 05:49:53',0,NULL,3,1,11,1,'BJ01669385 ','photographyacc'),(23611,794389958001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','wizard-of-wonders','tweaked_out@shaw.ca','Paul W. Sharpe','17986 67 Ave','surrey','BC','CANADA','v3s8c3','(604) 220-4716','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 05:26:46',0,NULL,3,0,3,1,'RA184533389CN ','hermeshine\r摄影背心 Nikon 老款 XL 和2XL  各一件'),(23612,838695387002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','webzabor','int4@webzabor.ru','Sergey Pogudin','Indystry street 53-33','Ekaterinburg','','RUSSIAN FEDERATION','620042','+79221522224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 06:22:43',0,NULL,3,1,3,1,'RA184532851CN ','hermeshine\r欧标'),(23613,794400952001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','psvehv82','teunehv@kunen.nl','Ton Kunen','Boschdijk 275','EINDHOVEN','','NETHERLANDS','5612HD','0647312898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 06:29:32',0,NULL,3,1,21,1,'RA184533344CN ','hermeshine'),(23614,8881328686083923,111,'摄影背心 黑色厚 3XL',2,'',0,'hermeshine','radonja78','jomatkov@inet.hr','josko matkovic','Sv. Lovre 45','Stobrec','croatia','CROATIA','21311','0038521326405',NULL,NULL,NULL,'2012-02-08 07:28:03',0,NULL,3,0,21,1,'RA184533273CN ','已入库 '),(23615,618790136003,130497954344,'New Fancier Complete Tripod 531BT with Ball head 531BH ',1,'AE1102',75,'hermeshine','thexelol','pavol.halmes@gmail.com','Pavol Halmes','Mostna 1/31<br>0918858246','Handlova','','SLOVAK REPUBLIC','97251','00421918858246','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 08:26:41',0,NULL,3,1,5,1,'CP244674633CN\r ','hermeshine'),(23616,923041850016,260660052658,'New Camera shoulder bag D1 for Canon body and 1-2 lens',1,'AO0031',13.9,'hutongstore','tonyduke5','tbamiedakis@gmail.com','Themistoklis Bamiedakis','Chrisostomou 43','Heraklion','Crete','GREECE','71306','0030 6942406932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 09:29:43',0,NULL,3,1,17,0,NULL,'hutongstore'),(23617,923041853016,260901880795,'Mini IR Wireless Remote Control for Canon 550D 7D 500D',1,'AD1117',2.18,'hutongstore','tonyduke5','tbamiedakis@gmail.com','Themistoklis Bamiedakis','Chrisostomou 43','Heraklion','Crete','GREECE','71306','0030 6942406932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 09:29:44',0,NULL,3,1,17,0,NULL,'hutongstore'),(23618,942639588015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','tonyduke5','tbamiedakis@gmail.com','Themistoklis Bamiedakis','Chrisostomou 43','Heraklion','Crete','GREECE','71306','0030 6942406932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 09:29:45',0,NULL,3,1,17,0,NULL,'hutongstore'),(23619,942639590015,250635197300,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',2.79,'hutongstore','tonyduke5','tbamiedakis@gmail.com','Themistoklis Bamiedakis','Chrisostomou 43','Heraklion','Crete','GREECE','71306','0030 6942406932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 09:29:45',0,NULL,3,1,17,0,NULL,'hutongstore'),(23620,923041855016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','tonyduke5','tbamiedakis@gmail.com','Themistoklis Bamiedakis','Chrisostomou 43','Heraklion','Crete','GREECE','71306','0030 6942406932','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 09:29:46',0,NULL,3,1,21,1,'RA184533962CN ','hutongstore\rCanon 单肩包  D1  1\r\r热靴保护盖  普通     1\rcanon 反接环  52mm    1\r52-58mm 双阳环   1'),(23621,794449659001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',35.99,'hermeshine','adreym','adrey_m@inbox.ru','Andrei Maslennikov','Sovetov<br>5-61','Kondopoga','Karelia','RUSSIAN FEDERATION','186225','+79212269969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 10:11:57',0,NULL,3,1,3,1,'RA184533619CN\r','hermeshine'),(23622,942661461015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','trasnidaren','trasnid@yahoo.se','Anders Johansson','Östermalmsgatan 36 A','Umeå','Sweden','SWEDEN','90332','070-6792177','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 10:35:18',0,NULL,3,1,21,1,'RA184533463CN ','hutongstore'),(23623,838460116002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','ekulesh','kuleshz@yandex.ru','Katsiaryna Kuspits','Lobanka 13/2 - 53','Minsk','','BELARUS','220136','375297022013','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 10:55:30',0,NULL,3,0,21,1,'RA184533551CN ','hermeshine\r1.6*3  灰色\r\r\r'),(23624,8881328699177889,111,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output ',1,'AKT090',0,'hermeshine','fpmsparkour','faf02@mail.ru','Vladimir Egorov','ul.Ulyanovih d.27 kv.15','Podolsk','Moskovskaya Oblast','RUSSIAN FEDERATION','142116','8 985 293 69 64',NULL,NULL,NULL,'2012-02-08 11:06:17',0,NULL,3,1,5,1,'CP244674695CN\r ','除了C以外再发\r1.6*3 白色和绿色 \r115w 5500k 灯泡  220v  2\r反光板  80cm 5合1   1\r澳转欧标\r已入库'),(23625,800302025018,280680109009,'YongNuo 1m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AD1113',16.14,'photographyacc','lmrabbitohs95','lbkmendes@gmail.com','Liam Mendes','1 Rosebridge Avenue Castle Cove ','Sydney','New South Wales','AUSTRALIA','2069','0294170501','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 11:15:27',0,NULL,3,1,11,1,NULL,'photographyacc'),(23626,794467777001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','tomick82','info@tomaskejha.com','Tomas Kejha','Bezrucova 3','Brno','','CZECH REPUBLIC','60200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 11:18:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(23627,942682397015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','heriaboutique1','heria@live.fr','Laurent Larminier','6 rue des Glaireaux','St Michel en l\'herm','Pays de la Loire','FRANCE','85580','06.98.80.85.00','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 11:32:57',0,NULL,3,1,11,1,NULL,'hutongstore'),(23628,942688210015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','barbarellaf','b.lambourne@hotmail.com','Mrs Babs Lambourne','A D P Dealer Services UK Ltd<br>1 Cygnet Way','Hungerford','Berkshire','UNITED KINGDOM','RG17 0YL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-08 11:52:46',0,NULL,3,1,4,1,'YW868897016CN\r ','hutongstore\r黑加白'),(23629,800316238018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',36.1,'photographyacc','stevenpop','steven.p@tpg.com.au','steven popovich','7 nowill street','Condell park','New South Wales','AUSTRALIA','2200','61410411255','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 12:02:21',0,NULL,3,1,3,1,'RA184533485CN ','photographyacc'),(23630,794491213001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','riftemp3','riftemp@mail.ru','Grigoriy Fedorov','MOGES 28-135','Ryazan','','RUSSIAN FEDERATION','390013','+7 920 6345397','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 12:42:07',0,NULL,3,1,5,1,'CP244674664CN\r ','hermeshine'),(23631,838789549002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','samsoniansergey','nikonometria@gmail.com','Sergey Tokar','Gorkogo, 220, 4','Kanevskaya','Krasnodarsky kray','RUSSIAN FEDERATION','353730','+79604981228','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 12:45:54',0,NULL,3,1,11,1,NULL,'hermeshine'),(23632,838795977002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','clampr','clamp_feehily@yahoo.ie','Warangkun Punyanitya','19/44 Sriharach Road, Sriphoom Sub-District, Muang Chiang Mai','Chiang Mai','','THAILAND','50200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 13:10:29',0,NULL,3,1,24,1,'30120825210\r ','hermeshine'),(23633,942726434015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','missvalley1','glamourandpixieduststudios@gmail.com','linda hutchinson','24 westcliff place northfield','birmingham','West Midlands','UNITED KINGDOM','b311qj','07970985978','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-08 13:23:10',0,NULL,3,1,4,1,'YW868897020CN\r ','hutongstore\r英标'),(23634,838819271002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','professorarmando','contato@professorarmando.com.br','Armando Ferreira','Rua Antonio Domingues Vasconcelos, 41<br>Jardim das Indústrias','São José dos Campos','São Paulo','BRAZIL','12240690','1239334096','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 14:14:58',0,NULL,3,1,24,1,'30120822830\r ','hermeshine'),(23635,794540887001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','samzynikon','samzy75@yahoo.com','samir misira','aleja lipa 15','Sarajevo','Kanton Sarajevo','BOSNIA AND HERZEGOVINA','71000','(387)61 712-616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 15:11:42',0,NULL,3,1,17,0,NULL,'hermeshine'),(23636,838840435002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','samzynikon','samzy75@yahoo.com','samir misira','aleja lipa 15','Sarajevo','Kanton Sarajevo','BOSNIA AND HERZEGOVINA','71000','(387)61 712-616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 15:11:43',0,NULL,3,0,21,1,'RA184533525CN ','hermeshine\rnikon 反接环  52mm   1\r1.6*3  灰色'),(23637,838849249002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','thepraetorianone','thebobooo@gmail.com','Sergey Smolyaninov','pr. Svobodniy 28-12','Krasnoyarsk','','RUSSIAN FEDERATION','660018','+7(963)1919341','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 15:36:46',0,NULL,3,1,3,1,'RA184533596CN ','hermeshine'),(23638,838856885002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','gsantalucci','gisamo36@hotmail.com','Giselle Santalucci','15453 SW 12th Ter','miami','FL','UNITED STATES','33194-2447','(786) 374-6890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 15:53:09',0,NULL,3,1,17,0,NULL,'hermeshine'),(23639,794556610001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','gsantalucci','gisamo36@hotmail.com','Giselle Santalucci','15453 SW 12th Ter','miami','FL','UNITED STATES','33194-2447','(786) 374-6890','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-08 15:53:09',0,NULL,3,1,1,1,'LK192351989CN ','hermeshine\rc型大力夹   1\r倒影板（白黑）   1'),(23640,942797070015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','tempertantrumsltd','temper.tantrums@live.com','Everton Thomas','36 Augustus Court<br>94 Old Kent Road','London','London','UNITED KINGDOM','SE1 4NY','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-08 15:54:09',0,NULL,3,1,4,1,'YW868897042CN\r ','hutongstore\r黑加白'),(23641,860457535017,270767170942,'100% Cotton Photo Vest for Sony Canon Nikon color Black',1,'AA2114',28.49,'photographyacc','artomen','artomen@hotmail.com','Derek Liversidge','76a Duncan Street','Calne','Wiltshire','UNITED KINGDOM','SN119QB','01249811962','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-08 16:12:24',0,NULL,3,0,3,1,'RA184533534CN ','photographyacc\r摄影背心 黑色厚 无字 2XL 1\r已入库'),(23642,794561239001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','mamrecords','mam_records@yahoo.com','Jose McGraw','710 N Milton Ave','Baltimore','MD','UNITED STATES','21205-2509','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-02-08 16:13:14',0,NULL,3,1,4,1,'YW868897031CN\r ','hermeshine\r美标'),(23643,860461770017,270767170462,'100% Cotton Photo Vest for Sony a200 a300 a700 a900user',1,'AA2113',28.49,'photographyacc','dou_cheang','dou_cheang@yahoo.com','Douglas Cheang','5, Jln Kg. Cina,','Pantai Remis','Perak','MALAYSIA','34900','0125012666','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-08 16:24:31',0,NULL,3,1,25,1,'RT127039294HK ','photographyacc\rXL 已入库\r称一下重量，算运费\r615'),(23644,838872680002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','lachose777666','martin_diotte@hotmail.com','Martin Diotte','14495 des Peupliers','Mirabel','QC','CANADA','J7N 3H3','(450) 475-0353','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 16:29:58',0,NULL,3,1,3,1,'RA184533477CN ','hermeshine'),(23645,800455667018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','gregokoi','ian_grego@yahoo.co.uk','IAN GREGORY','4 HAYFIELD CLOSE, BELPER','derby','Derbyshire','UNITED KINGDOM','DE561FA','01773825030','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-08 17:46:58',0,NULL,3,1,11,1,NULL,'photographyacc'),(23646,800477164018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',28.49,'photographyacc','bushtracker5','charlesnlinley@bigpond.com','charles prime','7 Arlingtion Tce','Mount Gambier','South Australia','AUSTRALIA','5290','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-08 18:26:09',0,NULL,3,0,3,1,'RA184533636CN ','photographyacc\r摄影背心（河北，厚）nikon  3XL 1\r已入库'),(23647,838932906002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','bushtracker5','charlesnlinley@bigpond.com','charles prime','7 Arlingtion Tce','Mount Gambier','South Australia','AUSTRALIA','5290','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 18:33:04',0,NULL,3,0,3,1,'RA184533622CN ','hermeshine\r摄影背心 Canon   3XL  1\r\r\r已入库'),(23648,838951731002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','val5736','val195736@gmail.com','VALERY OTIN','yl.Galyhina,19-176','Arhangelsk','RU','RUSSIAN FEDERATION','163065','(906)285-0449','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 19:07:31',0,NULL,3,1,3,1,'RA184533605CN ','hermeshine'),(23649,794657323001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','arolen','davidfanego@davidfanego.es','David Fanego','C/Grañón, 24 5º 2ª','Madrid','Madrid','SPAIN','28050','620959168','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 19:24:29',0,NULL,3,1,12,1,'2100973254 ','hermeshine\r放两个欧标\r白色布\r实重6.7  泡重7.3'),(23650,791757577001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','tpantazo','tpantazopoulos@ieee.org','Theo Pantazopoulos','3752 Twin Falls Place','Ottawa','ON','CANADA','K1V 1W5','(613) 240-2330','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 19:47:37',0,NULL,3,1,3,1,'RA184533548CN ','hermeshine'),(23651,838977079002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','dirty_mac_g','va3tna@hotmail.com','Martin Lang','170 Sunset Blvd. Apt 3','Stouffville','ON','CANADA','L4A4E1','(905) 640-0627','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 19:48:38',0,NULL,3,1,11,1,' ','hermeshine'),(23652,838993992002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','irina.aykova','irina_kost@abv.bg','IRINA AYKOVA','3 Zdravko Chakarov Str.<br>floor 4, app. 13','Varna','Varna','BULGARIA','9020','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 20:29:29',0,NULL,3,1,24,1,'30120822561\r ','hermeshine'),(23653,943013456015,250790265292,'Pro Video Tripod Fluid Pan Head EI717 EI-717 Bowl 1.55m',1,'AO0022',154,'hutongstore','konruludmila','kon-ru@yandex.ru','Lydmila Tolstova','Army 60, house 25 apartment 58','Voronezh','Voronezh region','RUSSIAN FEDERATION','394077','79102479231','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 21:19:20',0,NULL,3,1,5,1,'CP244674655CN\r ','hutongstore'),(23654,794732086001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','isv-flashing','flashing@email.cz','Jan Veselý','Hálkova 1012','Valašské Meziříčí','','CZECH REPUBLIC','75701','420739293051','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-08 21:35:05',0,NULL,3,1,11,1,NULL,'hermeshine'),(23655,943047260015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','djpuffe','uuffffee@gmail.com','Ulrik Christensen','Lundensgade 11','Vrå','','DENMARK','9760','40511549','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-08 22:11:14',0,NULL,3,1,24,1,'30120828710\r ','hutongstore'),(23656,839056765002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',2,'AKT049',60,'hermeshine','leifs123','leifsorvik@hotmail.com','Leif Sorvik','Bremsnes','Averoy','','NORWAY','6530','41205294','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-08 22:18:31',0,NULL,3,1,21,1,'RA184533494CN\r ','hermeshine\r4个  申报$30'),(23657,943068318015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','kiugphuc','kiugfractal161@gmail.com','Phuc Doan','Raviradantie 9 B 25, MIkkeli, Finland','Mikkeli','Finland','FINLAND','50100','+358 44 0707 293','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-08 22:51:13',0,NULL,3,1,21,1,'RA184533503CN\r ','hutongstore'),(23658,800535254018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.24,'photographyacc','jgrieves1976','judithgrieves@blueyonder.co.uk','Judith Grieves','14 Coventry Way<br>Fellgate Estate','Jarrow','Tyne and Wear','UNITED KINGDOM','NE324TQ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-08 23:25:14',0,NULL,3,1,11,1,NULL,'photographyacc'),(23659,791856514001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','boxer-dogs-tas','georgygirl_1967@moocow.com','C Kemp','78 Gormanston Rd','Moonah','Tasmania','AUSTRALIA','7009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 01:06:03',0,NULL,3,1,11,1,NULL,'hermeshine'),(23660,839115328002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','ivanime','ihundric@yahoo.com','Ivan Hundric','13970 Millbrook Dr','Victorville','CA','UNITED STATES','92395-4760','(760) 954-7473','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 01:06:09',0,NULL,3,1,21,1,'RA184533415CN\r ','hermeshine'),(23661,8881328754117422,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head - Wholesale/ Retail ',1,'AE1603',30.99,'aliexpress','1006653740','123hotmail.com','Fernando L. Romera','Jazmin 2<br>Cadiz, Spain','Chiclana de la Frontera','Cadiz','SPAIN','11130','',NULL,NULL,NULL,'2012-02-09 02:21:57',0,NULL,3,1,21,1,'RA184533888CN\r ','电话\r+0034 956 530288 \r'),(23662,8881328754327171,111,'Free shipping & Tracking # - New Camera bag topload D3 for Canon 550D 500D ',1,'AO0034',9.99,'aliexpress','1006654091','123hotmail.com','roseli de Andrade Dias','Rua Cel. Caetano Costa, 365 Jardim Atlantico<br>SC, Brazil','Florianopolis','SC','BRAZIL','88090340','+55 48 32444703',NULL,NULL,NULL,'2012-02-09 02:25:27',0,NULL,3,1,25,1,'RT127058761HK ',''),(23663,8881328754714572,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail ',1,'AB3329',48.99,'aliexpress','1006658632','123@hotmail。com','Natalia Penyasova','Babushkina 291 - 44<br>Krasnodarskiy kray, Russian Federation','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350020','+7 926 1870996',NULL,NULL,NULL,'2012-02-09 02:31:54',0,NULL,8,1,17,0,NULL,NULL),(23664,8881328754842746,111,'Non Woven Fabric Backdrop 3m(L) x 1.6m(W) 5.2x9.8 ft - Whole/ Retail',1,' AO0005',18.99,'aliexpress','1006658634','123@hotmail。com','Natalia Penyasova','Babushkina 291 - 44<br>Krasnodarskiy kray, Russian Federation<br>SC, Brazil','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350020','+7 926 1870996',NULL,NULL,NULL,'2012-02-09 02:34:02',0,NULL,8,0,17,0,NULL,'1.6*3  绿色 '),(23665,8881328754945433,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail',1,' AKT052',42.99,'aliexpress','1006658633','123@hotmail.com','Natalia Penyasova','Babushkina 291 - 44<br>Krasnodarskiy kray, Russian Federation<br>SC, Brazil','Krasnodar','Krasnodarskiy kray','RUSSIAN FEDERATION','350020','+7 926 1870996',NULL,NULL,NULL,'2012-02-09 02:35:45',0,NULL,3,1,5,1,'CP243056047CN\r ','闪光的柔光箱   60cm  1 \r1.6*3  绿色    1\r2云柔   1'),(23679,794913643001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','beecheli','vernonlpeter@gmail.com','Vernon PETER','135 Altone Road','Beechboro','Western Australia','AUSTRALIA','6063','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-09 09:17:05',0,NULL,3,0,3,1,'RA184533786CN\r ','hermeshine\r3XL 已入库'),(23666,8881328755384013,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m - Wholesale/ Retail ',1,'AE2501',25.99,'aliexpress','1006660595','te.ru@mail.ru','Tokarev Evgeny','Sverdlovskaya 158-64<br>Penza, Russian Federation','Kuznezk-12','Penza','RUSSIAN FEDERATION','442542','+7 937 4154447',NULL,NULL,NULL,'2012-02-09 02:43:04',0,NULL,3,1,3,1,'RA184533790CN\r ',NULL),(23667,839142710002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','afrothunderr86','bmwstu@gmail.com','Stuart Gaskins','PO Box 18164','Parris Island','SC','UNITED STATES','29905-8164','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 02:44:50',0,NULL,3,1,21,1,'RA184533429CN\r ','hermeshine'),(23668,943170247015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','l3g7','presker@gmail.com','Miha Presker','Laimgrubengasse 12/5','Wien','','AUSTRIA','1060','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 03:31:47',0,NULL,3,1,24,1,'30120883612\r ','hutongstore\rMiha Presker\rpod Koron\rHudovernikova 13\r1000 Ljublana\rSlovenia\r\r\r\r'),(23669,800718510018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',19,'photographyacc','zack8a','zack8a@optusnet.com.au','Jonathan Gardiner','11 Easton Avenue','Sylvania','New South Wales','AUSTRALIA','2224','0295761039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 04:00:44',0,NULL,3,1,11,1,NULL,'photographyacc'),(23670,8881328760341664,111,'800W 220V*10',1,'',49.98,'aliexpress','paul486 ','sales@hypop.com.au','Paul Romero','31/70 Holbeche Road<br>Krasnodarskiy kray, Russian Federation','Arndell Park','NSW','AUSTRALIA','2148','+611300449767',NULL,NULL,NULL,'2012-02-09 04:05:41',0,NULL,3,0,3,1,'RA184533653CN ','Paypal（sales@hypop.com）直接付款 \r一共是10个\r已入库\rHYPOP\rPaul Romero\r31/70 Holbeche Road\rArndell Park, NSW 2148\rAUSTRALIA\r'),(23671,839181545002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-09 05:08:13',0,NULL,3,1,5,1,'CP243056055CN ','hermeshine\r澳转欧标\r申报低于$40\r\r '),(23672,943089575015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','jelkodesign','reg@jelko.com','Jelena Tshebotar','J. Koorti 19-15','Tallinn','','ESTONIA','13623','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 05:27:15',0,NULL,3,1,21,1,'RA184533640CN ','hutongstore'),(23673,860807291017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.4,'photographyacc','brownishtrout','shellandfadz@internode.on.net','Andrew Mcfadzean','17 Andrews St','Watson','Australian Capital Territory','AUSTRALIA','2602','0412047300','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 05:37:19',0,NULL,3,1,11,1,NULL,'photographyacc'),(23674,839168310002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','+79233486117','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 05:46:20',0,NULL,3,1,3,1,'RA184533565CN ','hermeshine'),(23675,839191212002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','hendertuckyliving','nicksnowebay@gmail.com','Nick Snow','4622 La Mirada Ave<br>Apt 35','Los Angeles','CA','UNITED STATES','90029-1863','(702) 301-6795','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 05:59:51',0,NULL,3,1,1,1,'LK195307661CN ','hermeshine'),(23676,794418551001,110568758656,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',242.4,'hermeshine','supermagnar','magnar.westbye@gmail.com','Magnar Westbye','Ringgata 2D','Oslo','','NORWAY','0577','+47 95159914','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 07:33:34',0,NULL,5,1,5,1,'CP244674718CN\r ','hermeshine\r除C里面的以外再发\r1.6*3  黑，白，绿背景布\rJJC 腕带  JJC-2  1\r3 片装滤镜袋    1\r爵影红外 canon     1\r72橡胶遮光罩   1\r新款内胆包 大号 canon logo   1\rNG128 柔光罩   1\rlenspen    1\r带水平仪 热靴保护盖   1\r都已入库\r欧标\r申报gift $150\r已发货.......'),(23677,800764713018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','kennyy03','dies.chan@hotmail.fr','Kévin Louzoun','37 rue belgrand','Paris','Ile-de-France','FRANCE','75020','0143646722','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 07:56:59',0,NULL,3,1,11,1,'BJ01669375\r ','photographyacc'),(23678,794493632001,110531023204,'JJC Leather Hand Strap Grip comfort stable D700 5DII',1,'AB1409',55.99,'hermeshine','supermagnar','magnar.westbye@gmail.com','Magnar Westbye','Ringgata 2D','Oslo','','NORWAY','0577','+47 95159914','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 08:33:50',0,NULL,8,1,17,0,NULL,'hermeshine'),(23680,794919594001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','engineereric71','eric@tecy.com.au','Eric Freund','16 Teringie Dr','Teringie','South Australia','AUSTRALIA','5072','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 09:42:39',0,NULL,3,1,11,1,NULL,'hermeshine'),(23681,839255158002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','azrabaran','bayu.andhikajaya@gmail.com','Bayu Andhikajaya','Taman Duren Sawit B3/3<br>Kompleks Taman Duren Sawit','default','JK','INDONESIA','13440','+628119302801','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 10:58:53',0,NULL,3,1,2,1,'30120952492\r ','hermeshine'),(23682,800814862018,280663806243,'Photo Video Light Stands Studio Photo Stand 6ft 200cm ',1,'AE3401',24.69,'photographyacc','martinjago7','martin@jagoproductions.com.au','Martin P Jago','Unit 10, 2-4 Gubbuteh Rd.<br>Little Bay','Sydney','New South Wales','AUSTRALIA','2036','0449185711','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 11:11:10',0,NULL,3,1,3,1,'RA184533772CN\r ','photographyacc'),(23683,860894114017,270806843120,'New Photo Studio 110cm Reflective Silver Umbrella 43“ ',2,'AD1126',27.56,'photographyacc','besthubbytt','tim.procter@exemail.com.au','Tim Procter','10 Fiona Crescent','Rankin Park','New South Wales','AUSTRALIA','2287','0438007971','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 11:38:53',0,NULL,3,1,11,1,NULL,'photographyacc'),(23684,943323536015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','rk01753','rkrakowski@btopenworld.com','Richard Krakowski','1 Salt Hill Avenue','Slough','Berkshire','UNITED KINGDOM','SL1 3XP','07757148018','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 12:22:44',0,NULL,3,1,3,1,'RA184533843CN\r ','hutongstore'),(23685,800830606018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.6,'photographyacc','walkinvintagewardrobe','jichuan.cao@student.uts.edu.au','Jichuan Cao','14 Mentmore','Rosebery','New South Wales','AUSTRALIA','2018','61402230319','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 12:02:37',0,NULL,3,1,11,1,NULL,'photographyacc'),(23686,839283388002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','goneth','tekgizmo@gmail.com','W Gamage','8<br>Padua Court,','Glen Waverley','Victoria','AUSTRALIA','3150','0398924325','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:39:13',0,NULL,3,1,17,0,NULL,'hermeshine'),(23687,624530802004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','goneth','tekgizmo@gmail.com','W Gamage','8<br>Padua Court,','Glen Waverley','Victoria','AUSTRALIA','3150','0398924325','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:40:35',0,NULL,3,1,11,1,NULL,'hermeshine\r方形滤镜接口环 77mm  1\r无牌方镜 渐变灰 （nd4）   1'),(23688,794956663001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',35.99,'hermeshine','encorevogler','tv05richard@yahoo.fr','richard didier','29 bis 1er etage, chemin canto laouzetto','toulouse','Midi-Pyrénées','FRANCE','31100','09 54 52 28 07','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 12:47:38',0,NULL,3,1,3,1,'RA184533857CN\r ','hermeshine'),(23689,923723814016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','cecilia_julie','adore@tiscali.dk','Cecilia Julie Mogensen','Krebsen 103','Oelstykke','','DENMARK','3650','4524607647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 13:10:26',0,NULL,3,1,5,1,'CP243056033CN\r ','hutongstore\r换弹簧灯架'),(23690,794998168001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','bichovsky','zar@midsemi.net','Luis Salazar','33523 W. 8 Mile Road A-3 #204','Livonia','MI','UNITED STATES','48152','','NoPaymentFailure','CheckoutComplete','Other','2012-02-09 14:22:08',0,NULL,3,0,1,1,'LK194163100CN ','hermeshine\r3XL   已入库'),(23691,943373378015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','sms6140','sudha6140@gmail.com','Sudhakar Panner Selvam','21 Corbett Grove','Wood Green','London','UNITED KINGDOM','N22 8DQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 14:29:19',0,NULL,3,1,11,1,NULL,'hutongstore'),(23692,800880088018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',4.29,'photographyacc','elizjad77','nika7@live.com.au',' Nicole Ashton','13 Bendee Dr','Atwell','Western Australia','AUSTRALIA','6164','0422484386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-09 14:30:19',0,NULL,3,1,2,1,'30120951405\r ','photographyacc'),(23693,839308790002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','dodyyao','dodyyao@yahoo.com','John Yao','19 Ironclad Dr','Columbus','OH','UNITED STATES','43213-7606','(614) 746-9210','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 13:58:04',0,NULL,3,1,21,1,'RA184519081CN\r ','hermeshine'),(23694,923757817016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','darrenr2539','uplifting_beats@hotmail.com','Darren Robinson-Scott','28<br>creamery court','Letchworth Garden City','Hertfordshire','UNITED KINGDOM','SG6 2UA','07961700249','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 14:33:41',0,NULL,3,1,3,1,'RA184533830CN\r ','hutongstore'),(23695,795017154001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','vallone','vallonebras@gmail.com','DIVA VALLONE BRAZ','RUA ENÓTRIA, 89<br>TUCURUVI','SÃO PAULO','SÃO PAULO','BRAZIL','02309100','01138855027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 15:16:45',0,NULL,3,1,25,1,'RT127212474HK ','hermeshine\r4节'),(23696,839338140002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 16:34:03',0,NULL,3,1,17,0,NULL,'hermeshine\rTEL 55-11-20471770'),(23697,800936057018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',40.85,'photographyacc','doll201','bmadzar@cogeco.ca','Borko Madzar','1189 Glidden ave','Windsor','ON','CANADA','N8S2P2','(519) 948-0619','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 16:46:22',0,NULL,3,0,3,1,'RA184533826CN\r ','photographyacc'),(23698,839361491002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','chaiyacha2012','chaiyacha@gmail.com','Chaiyaporn Charoensuk','218 M 4 Soi.Pracha U-Thit 17 Pracha U-Thit Road','Ratburana','Bangkok','THAILAND','10140','668 208 3444','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 16:17:43',0,NULL,3,1,24,1,'30120952142\r ','hermeshine'),(23699,800943850018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',37.05,'photographyacc','26millhouse','makeyebay@gmail.com','Oleg Makey','127 Fearann Ri<br>Doughiska','Galway','Galway','IRELAND','default','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-09 17:03:30',0,NULL,3,1,21,1,'RA184533905CN\r ','photographyacc'),(23700,943491001015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 18:08:58',0,NULL,3,1,21,1,'RA184533891CN\r ','hutongstore\r欧标'),(23701,839417700002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','dannordal','dan.nordal@gmail.com','Dan Sigurd Nordal','Sikdalsveien 26 A','Bjørnevatn','Finnmark','NORWAY','9910','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 18:19:44',0,NULL,3,1,24,1,'30120956471\r ','hermeshine'),(23702,839461693002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',3.98,'hermeshine','ciberdrolo','cegogo01@hotmail.com','CESAR GOMEZ GOMEZ','MAYOR, 52','SAN ANTONIO DE REQUENA','Comunidad Valenciana','SPAIN','46390','676626119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 19:41:26',0,NULL,3,1,2,1,'30120950845\r ','hermeshine'),(23703,839476385002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','photomilo78','brian.milo@gmail.com','Brian Milo','4829 Arlington St','Loves Park','IL','UNITED STATES','61111-5814','(815) 520-4657','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-09 20:05:15',0,NULL,3,1,21,1,'RA184519095CN\r ','hermeshine'),(23704,923961627016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','borsa77','bozena.czyz@yahoo.co.uk','Bozena Czyz','EPR  Architects<br>30 Millbank','London','London','UNITED KINGDOM','SW1P 4DU','07828068512','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 20:27:49',0,NULL,3,1,3,1,'RA184533769CN\r ','hutongstore\r英标'),(23705,795173768001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','gerrdunne','gerrdunne@eircom.net','Gerard Dunne','69 Fern Court Green<br>Old Court Road','Ballycullen','Dublin','IRELAND','24','014629898','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-09 20:47:37',0,NULL,3,1,24,1,'30120952912\r ','hermeshine'),(23706,943627270015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','speedbird247','asmah_hu@hotmail.com','Asmah Hussain','Flat 6 Duncansby House','Slough','Berkshire','UNITED KINGDOM','SL1 1UD','01753524023','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 21:22:39',0,NULL,3,1,3,1,'RA184533812CN\r ','hutongstore'),(23707,924015742016,260660050792,'FlashLight Diffuser Cover Dome for Nikon SB600 SB-600',1,'AB3330',1.58,'hutongstore','iangiuoni','igor-av@hotmail.co.uk','FAO igor angiuoni','Creatve Staging Ltd, Innovation House<br>17-27 Stirling Road','Acton','London','UNITED KINGDOM','W38DJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 21:48:09',0,NULL,3,1,11,1,NULL,'hutongstore'),(23708,943649815015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','bipede38','m.laurentis@hotmail.com','Marcos De Laurentis','AV. AGUIA DE HAIA, 873','SÃO PAULO','sao paulo','BRAZIL','03694000','11-20471770','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-09 21:57:41',0,NULL,5,1,5,1,'CP243056020CN\r ','hutongstore\r伞式柔光箱 60×90cm   4\r称一下重量\r已发货.....\r\r'),(23709,943662536015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','framemakermkltd','sales@framemakermk.co.uk','Framemaker MK Ltd','Units 13 & 14 Stacey Bushes Trading Centre<br>Erica Road, Stacey Bushes','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk12 6hs','08448488222','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-09 22:19:09',0,NULL,3,1,4,1,'YW868897860CN\r ','hutongstore\r英标'),(23710,839551731002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','mkylmaniemi','mika.kylmaniemi@gmail.com','Mika Kylmaniemi','Valjakonkatu 6 B 27','TAMPERE','','FINLAND','33580','+358-50-5005060','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-09 22:35:30',0,NULL,3,1,24,1,'30120954850\r ','hermeshine'),(23711,839560820002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',2,'AB3302',29.98,'hermeshine','drunkenmaster138','peter138@comcast.net','peter lai','9310 180th Ave E','Bonney Lake','WA','UNITED STATES','98391','(253) 826-1028','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-09 22:59:11',0,NULL,3,1,1,1,'LK188923022CN ','hermeshine'),(23712,924066178016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','jcfitnut','babyblinkman@hotmail.com','Mr James Carlsson','Apartment 49, 2 Stuart Street','Manchester','Greater Manchester','UNITED KINGDOM','M11 4DG','07951529979','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-09 23:27:48',0,NULL,3,1,3,1,'RA184533959CN\r ','hutongstore\r英标'),(23713,924079300016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','dejioshe','oscarkicken@hotmail.com','Oscar Kickén','Barkvägen 3c','Skövde','Västra Götaland','SWEDEN','54164','(+46)732441516','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 00:03:04',0,NULL,3,1,21,1,'RA184533874CN\r ','hutongstore'),(23714,801169008018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',27.07,'photographyacc','sandfordlock','smuldal@rm.com','Sylfest Muldal','Research Machines plc<br>183 Milton Park','Abingdon','Oxfordshire','UNITED KINGDOM','OX14 4SE','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 00:42:27',0,NULL,3,0,3,1,'RA184533945CN\r ','photographyacc\rXXL   (已入库）'),(23715,839622039002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','jtalada77','smt91304@email.phoenix.edu','Jason Talada','113 Maple St<br>Apt 2','Athens','PA','UNITED STATES','18810','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 02:15:58',0,NULL,3,1,21,1,'RA184533865CN\r ','hermeshine'),(23716,795289916001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','newtonbr','newtonnogueira@gmail.com','NEWTON NOGUEIRA DA SILVA','RUA JOÃO BATISTA D\'ELIA, 1270<br>PARQUE PROGRESSO','FRANCA','SÃO PAULO','BRAZIL','14403-102','551681249004','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-10 02:18:53',0,NULL,3,1,5,1,'CP243056016CN\r ','hermeshine'),(23717,839631630002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','friedotto01','crgrab@xplornet.com','Rudi Grab','P.O. Box 3301<br>49049 - Range Rd. 253','Leduc','AB','CANADA','T9E 6M1','(780) 980-3891','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 02:48:28',0,NULL,3,1,11,1,NULL,'hermeshine'),(23718,795312957001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.25,'hermeshine','tonyandrebecca01','tonyandrebecca@westnet.com.au','Bec & Tony Hassam','117 Red Cedar Cres','Jimboomba','Queensland','AUSTRALIA','4280','0755477539','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 03:43:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(23719,839647037002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','marxvideo','marxvideo@aol.com','Russell S. Kern','729 Crown Ridge Dr','Colorado Springs','CO','UNITED STATES','80904','','NoPaymentFailure','CheckoutComplete','Other','2012-02-10 03:43:50',0,NULL,3,0,1,1,'LK192702725CN ','hermeshine\r2XL 已入库'),(23720,924162000016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','maccardin','marcdarkin@gmail.com','Manuel Fernández González','Brion, 2 - 3º','Santiago de Compostela','Galicia','SPAIN','15702','981940643','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 03:57:53',0,NULL,3,1,4,1,'YW868897856CN ','hutongstore\r除了C以外再发\r摄影背心 黑色厚 无字 大小无特别标注为XL    1\r摄影背心 驼色厚 无字 大小无特别标注为 XL    1\r'),(23721,924162001016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','maccardin','marcdarkin@gmail.com','Manuel Fernández González','Brion, 2 - 3º','Santiago de Compostela','Galicia','SPAIN','15702','981940643','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 03:57:54',0,NULL,3,1,17,0,NULL,'hutongstore'),(23722,943792511015,250939065816,'New 100% Cotton Photo photographya Vest for Sony Nikon Canon color: kaqi',1,'AA2123',18,'hutongstore','maccardin','marcdarkin@gmail.com','Manuel Fernández González','Brion, 2 - 3º','Santiago de Compostela','Galicia','SPAIN','15702','981940643','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 03:57:54',0,NULL,3,1,17,0,NULL,'hutongstore'),(23723,943815645015,250600495049,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',5.5,'hutongstore','ruby_ambrotype','smieglitz@gmail.com','Joe Smigiel','2021 Bronson Blvd<br>Apartment #3','Kalamazoo','MI','UNITED STATES','49008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 05:44:29',0,NULL,3,1,17,0,NULL,'hutongstore'),(23724,943815433015,250600496385,'33.5\" 85cm Studio Flash Translucent soft White Umbrella',1,'AD1402',5.4,'hutongstore','ruby_ambrotype','smieglitz@gmail.com','Joe Smigiel','2021 Bronson Blvd<br>Apartment #3','Kalamazoo','MI','UNITED STATES','49008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 05:44:29',0,NULL,3,1,1,1,'LK194122388CN ','hutongstore\r反光伞   1\r柔光伞   1'),(23725,8881328852806423,111,'Free shipping & Tracking # - New Neoprene Camera Cover Case for Nikon (L)',1,'AC1303',7.69,'aliexpress','1006685974 ','warhorse@aapt.net.au','John Brown','70 coronation AV.<br>Queensland, Australia','Beachmere','Queensland','AUSTRALIA','4510','+061 07 54968000',NULL,NULL,NULL,'2012-02-10 05:46:46',0,NULL,3,1,17,0,'RA184594167CN\r ',''),(23726,8881328852962801,111,'Free shipping & Tracking # - New Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm ',1,'AC1202',5.99,'aliexpress','1006685973 ','warhorse@aapt.net.au','John Brown','70 coronation AV.<br>Queensland, Australia','Beachmere','Queensland','AUSTRALIA','4510','+061 07 54968000',NULL,NULL,NULL,'2012-02-10 05:49:22',0,NULL,3,1,17,0,'RA184594167CN\r ',NULL),(23727,8881328853052312,111,'Free shipping & Tracking # - New Large size Neoprene Lens Pouch / Case 90mm x 220mm',1,'AC1203',6.48,'aliexpress','1006685972 ','warhorse@aapt.net.au','John Brown','70 coronation AV.<br>Queensland, Australia','Beachmere','Queensland','AUSTRALIA','4510','+061 07 54968000',NULL,NULL,NULL,'2012-02-10 05:50:52',0,NULL,3,1,3,1,'RA184594167CN\r ','大号内胆包 nikon   1 \r镜头筒 中号   1\r镜头筒 大号    1'),(23728,839677524002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 06:05:13',0,NULL,3,1,3,1,'RA184533931CN ','hermeshine'),(23729,801252979018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','infmaj','infernalmajesty@netspace.net.au','Leanne Hardy','58 Koona Street','Albion Park Rail','New South Wales','AUSTRALIA','2527','0242579408','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-10 06:08:29',0,NULL,3,0,11,1,NULL,'photographyacc\r1.6*2.1   白色'),(23730,839694213002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','32kernel','ibanezp2002@yahoo.com.ar','Pablo Ibanez','13237 Heather Moss Dr<br>Apt 1006','Orlando','FL','UNITED STATES','32837-5541','(407) 744-7372','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 07:35:03',0,NULL,3,1,21,1,'RA184519078CN\r ','hermeshine'),(23731,801276755018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',37.05,'photographyacc','339514884','kamikazi@inbox.ru','Andrey Pirinov','yl. Nekrasova d.11','Voronezh','Voronezh','RUSSIAN FEDERATION','394071','+79081349541','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 08:07:03',0,NULL,3,1,3,1,'RA184519064CN\r ','photographyacc'),(23732,924223455016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','cjmbomz','cjmahony@hotmail.com','cristina mahony','127<br>WYADRA AVE','NORTH MANLY','New South Wales','AUSTRALIA','2100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 08:07:35',0,NULL,3,1,3,1,'RA184519104CN\r ','hutongstore'),(23733,624825457004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',2,'AD1219',7,'hermeshine','pritisk','prit@inbox.ru','Yuri Pritisk','10 Pyatiletki, 26-152','Novocheboksarsk','Chuvashia','RUSSIAN FEDERATION','429959','89278452122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 08:16:24',0,NULL,3,1,11,1,NULL,'hermeshine\r已发货'),(23734,943874370015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','ballessss','ballesss@gmail.com','Alejandro Ballesta','C Ricardo Marcos 21/6 3ºC','SANTA MARTA DE TORMES (Salamanca)','Castilla y León','SPAIN','37900','655118914','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 09:16:30',0,NULL,3,1,2,1,'30121052415\r','hutongstore'),(23735,795378272001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','loveyou246','turboball01@optusnet.com.au','Carol Porter','27 Cutler Road, Lansvale','Sydney','New South Wales','AUSTRALIA','2166','0297260011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 09:08:37',0,NULL,3,1,11,1,NULL,'hermeshine'),(23736,861394091017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',8.55,'photographyacc','rezaimka','reza57@hotmail.com','Reza Mohammed','146 St James Road','Heidelberg','Victoria','AUSTRALIA','3084','61423463271','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-10 09:37:18',0,NULL,3,1,11,1,'BJ01669336\r ','photographyacc'),(23737,800211165018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',141.8,'photographyacc','selinadonn','selina.m.wallace@gmail.com','Selina Wallace, Origin Energy','135 Coronation Drive<br>Milton','Brisbane','Queensland','AUSTRALIA','4064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-10 09:47:55',0,NULL,3,1,4,1,'YW868897845CN\r ','photographyacc\r反光板支架  1\r灯架  2m    2\r斜臂   1\r闪光的柔光箱   60cm   1\r已入库'),(23738,839730409002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 10:34:22',0,NULL,5,0,18,0,NULL,'hermeshine\r需要加$8运费，已经发信了'),(23739,839738435002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tremayne14','s_thaw@mail.com','Shane Thaw','24 Fircroft Way','Hamersley','Western Australia','AUSTRALIA','6022','61421213616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 10:45:01',0,NULL,3,1,3,1,'RA184594286CN\r ','hermeshine'),(23740,943913101015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','aalejandroariel','elinformemensual@yahoo.es','alejandro ariel horenstein','calle chipre 8 bajo 3','santa pola','Comunidad Valenciana','SPAIN','03130','966699726','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 11:10:58',0,NULL,3,1,4,1,'YW868897801CN\r ','hutongstore\r白+黑'),(23741,943927991015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','chronicles.batcave','steve@ghekko-photography.co.uk','Mr Steven Galloway','School of Biology, University of Nottingham<br>University Park','Nottingham','Nottinghamshire','UNITED KINGDOM','NG7 2RD','07980620771','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 11:49:25',0,NULL,3,1,3,1,'RA184594255CN\r ','hutongstore'),(23742,924293323016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 11:50:29',0,NULL,8,1,17,0,NULL,'hutongstore'),(23743,943924464015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 11:50:30',0,NULL,8,1,17,0,NULL,'hutongstore'),(23744,943924267015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',2,'AD1125',15.8,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 11:50:30',0,NULL,3,1,17,0,NULL,'hutongstore'),(23745,924301276016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','doriannedzewicz','dorneed@hotmail.com','Dorian Nedzewicz','57 Pelham Road','Beckenham Kent','London','UNITED KINGDOM','br3 4sq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 12:07:21',0,NULL,3,1,3,1,'RA184594309CN\r ','hutongstore'),(23746,795426431001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','tatianaatv83','atv83@inbox.ru','Svetlana Anosova','81/2 Pionerskay','Voronezh','Central-charnozemey','RUSSIAN FEDERATION','394057','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 12:09:39',0,NULL,3,0,11,1,'BJ01715704 ','hermeshine\r1.6*2.1  黑色'),(23747,943924371015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','zzzacko','lighter_flame@gmx.net','Giedrius Kanauka','Lydos 16','Siauliai','Lietuva','LITHUANIA','77167','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 11:50:31',0,NULL,3,1,21,1,'RA184594555CN ','hutongstore\r反光板  80cm 5合1   1\r闪光灯B座    1\r柔光伞110cm    2\r灯架包薄   1\r申报低值'),(23748,861450006017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','fondoimagen5','fondoimagen@yahoo.es','ANA BELEN LOPEZ PINA','AVENIDA DE ANDALUCIA, 65','DOS HERMANAS','Andalucía Ceuta y Melilla','SPAIN','41701','652928940','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 12:42:25',0,NULL,3,1,21,1,'RA184594581CN ','photographyacc\r1.6x3m 绿色  1'),(23749,924332436016,260894475033,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k 312AS for 5D2 7D 60D',1,'AD1149',139,'hutongstore','moondog1311','bruno@residentbroker.com','Stuart Anderson','Resident Studios Ltd.<br>57A Windsor Road','Willesden','London','UNITED KINGDOM','NW2 5DT','02088304321','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-10 13:26:11',0,NULL,3,1,4,1,'YW868897834CN\r ','hutongstore'),(23750,839789609002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-10 13:36:23',0,NULL,3,1,17,0,NULL,'hermeshine'),(23751,795452856001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','trudhein','kleynhanslaw@gmail.com','Heine Kleynhans','4 Kinglake road<br>Yanchep','Perth','Western Australia','AUSTRALIA','6035','0434836920','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:37:21',0,NULL,3,1,11,1,'BJ01669345\r ','hermeshine'),(23752,839791731002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:41:56',0,NULL,3,1,25,1,'RT127324351HK\r ','hermeshine\r'),(23753,795455168001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 13:44:19',0,NULL,3,1,5,1,'CP243056064CN','hermeshine\r115w 5500k 灯泡  220v   4\r45w 5500k 灯泡 220v    2'),(23754,839800043002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','vasily77','kovalev.2mail@gmail.com','Kovaleva Anastasia','Rechnaya dom 9 kv. 226<br>Moskovskaya oblast','g. Zheleznodorozhny','Russia','RUSSIAN FEDERATION','143981','+7 926 1390103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 14:03:42',0,NULL,3,1,17,0,NULL,'hermeshine'),(23755,839800044002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','vasily77','kovalev.2mail@gmail.com','Kovaleva Anastasia','Rechnaya dom 9 kv. 226<br>Moskovskaya oblast','g. Zheleznodorozhny','Russia','RUSSIAN FEDERATION','143981','+7 926 1390103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 14:03:43',0,NULL,3,1,5,1,'CP243056285CN\r ','hermeshine\r2.4x3m背景架+ 白布   1  夹子\rlenspen   1'),(23756,944013494015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','gribouboucan','achille2009@gmail.com','Jean-luc GRILLOT','11 sq vitruve','Paris','Ile-de-France','FRANCE','75020','07 61 94 88 19','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 15:10:08',0,NULL,3,1,3,1,'RA184594241CN\r ','hutongstore'),(23757,944009087015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','kise009','kise09@citromail.hu','Tomás Kiss','Smetanov háj 290/24','Dunajská Streda','Trnavsky','SLOVAK REPUBLIC','92901','+421905864794','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 15:06:13',0,NULL,3,1,21,1,'RA184594493CN\r ','hutongstore'),(23758,861522091017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',3.79,'photographyacc','ilikeeatingintherain','ilikeeatingintherain@hotmail.com','James Rawkins','22 Saint Pauls Square','Preston','Lancashire','UNITED KINGDOM','PR1 1XA','01904644817','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 15:44:29',0,NULL,3,1,11,1,'BJ01669343 ','photographyacc'),(23759,944031062015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.45,'hutongstore','schwantz100','schwantz34@iol.pt','vitor barros','av. timor lorosae edi1,nº2,2dto mira-sintra','caçem','sintra','PORTUGAL','2735','963613600','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 15:44:41',0,NULL,3,1,24,1,'30121256605\r ','hutongstore'),(23760,924417656016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','guti1978wojciech','guti78@interia.pl','wojciech bruchal','53 grosvenor crescent','uxbridge','London','UNITED KINGDOM','ub10 9es','01895251476','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 16:25:44',0,NULL,3,1,3,1,'RA184594238CN\r ','hutongstore'),(23761,795520645001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ptgslo','modlar@yahoo.com','Peter  CERNIC','ULICA JANEZA PAVLA II  -  14','LJUBLJANA','SLOVENIA','SLOVENIA','1000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 16:36:48',0,NULL,3,1,21,1,'RA184594502CN\r ','hermeshine'),(23762,795534978001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','lfstresser','lfstresser@vegaturbo.com.br','Luis Fernando Stresser','Rua Vinicius de Morais, 94 Pilarzinho','Curitiba','PR','BRAZIL','82115-060','55 4133383750','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-10 17:09:17',0,NULL,3,1,25,1,'RT127327300HK\r ','hermeshine'),(23763,839870094002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','leffehp66','leffehp@gmail.com','Leif Collstam','Jägartorpsvägen 17','Karlstad','','SWEDEN','S-654 65','+46 70 354 76 36','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 16:59:25',0,NULL,3,1,21,1,'RA184594462CN ','hermeshine'),(23764,839898274002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','camdela07','camdela07@hotmail.com','carmen delgado','manuel mantero, 21<br>sanlucar la mayor','sevilla','Andalucía Ceuta y Melilla','SPAIN','41800','955703925','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-10 18:01:40',0,NULL,3,1,21,1,'RA184529645CN\r ','hermeshine'),(23765,924472626016,260838264614,'New Large High quality heavy duty sand bag Empty',1,'AD1168',8.99,'hutongstore','fishmaskboy1','meddys_boathat_adventure@hotmail.com','Christopher Coll','19 Corradinna Road<br>Tattysalagh','Omagh','Tyrone','UNITED KINGDOM','BT785BN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 18:02:59',0,NULL,3,1,11,1,'BJ01669342\r ','hutongstore'),(23766,839898499002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','melvileneg21','melvilenebookings@gmail.com','melvilene gomez','202 Outwater Ln','Garfield','NJ','UNITED STATES','07026-2633','(862) 703-1693','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 18:07:12',0,NULL,3,1,21,1,'RA184594476CN ','hermeshine'),(23767,795554529001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','csigabiiiga','sunshine_@freemail.hu','Gabriella Olláry','Galagonyás út 2.','Esztergom','Komarom-Esztergom megye','HUNGARY','2500','+36202521512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 17:55:57',0,NULL,3,1,24,1,'30121263351\r ','hermeshine'),(23768,839907205002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','france26france','chatonne96656@hotmail.com','france pelletier','3 rue beland','saint-quentin','NB','CANADA','e8a1c4','(506) 235-9888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 18:19:13',0,NULL,3,1,11,1,NULL,'hermeshine'),(23769,944157790015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','thee-ou','pascal.wibaut@gmail.com','Pascal Wibaut','Av de Beloeil,21','Bruxelles','','BELGIUM','1180','0477-398308','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-10 19:15:16',0,NULL,3,1,21,1,'RA184594480CN ','hutongstore'),(23770,801557629018,280678918166,'Neoprene Camera Cover Case for small Canon & semi slr S',1,'AC2303',5.6,'photographyacc','babsbazaar1','junebanderson@hotmail.com','june anderson','102 new road<br>minster','Sheerness','Kent','UNITED KINGDOM','ME12 3PT','07956508462','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 20:12:13',0,NULL,3,1,11,1,'BJ01669341\r ','photographyacc'),(23771,861672262017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',11.88,'photographyacc','mikcak','mikcak@email.cz','Mikulas Petrik','Na Radouci 1134','Mlada Boleslav','','CZECH REPUBLIC','29301','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 20:27:47',0,NULL,3,1,11,1,'BJ01669340\r ','photographyacc'),(23772,795635214001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','jawiin','jawiin@hotmail.com','Jason Inman','5925 Canterbury Dr<br>APT 310','Culver City','CA','UNITED STATES','90230-6726','(213) 435-6647','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 20:33:46',0,NULL,3,0,1,1,'LK191059173CN\r ','hermeshine\r1.6*2.1  红色'),(23773,839983780002,120508272094,'Super Spanner Wrench 4 Lens Repair Tool Stainless Steel',1,'AD1123',44.99,'hermeshine','y2kgus','comfrtnumb@msn.com','GUS LAZZARI','4554 Chestnut Street Ext','High Point','NC','UNITED STATES','27265-8642','(336) 307-2126','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 20:47:02',0,NULL,3,1,1,1,'LK194677895CN\r ','hermeshine'),(23774,943412946015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','rich19822010','nikunpoop@aol.com','Richard Dunford','63 Littlehampton Road','Worthing','West Sussex','UNITED KINGDOM','BN13 1QP','01903268248','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 20:48:45',0,NULL,3,1,3,1,'RA184594343CN\r ','hutongstore'),(23775,944224113015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','dimmichel','dmtmixel@yahoo.gr','Dimitrios Michelakis','kontomari 8<br>dimos platania','chania','crete','GREECE','73014','00306977423204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-10 20:57:15',0,NULL,3,1,5,1,'CP243056271CN\r ','hutongstore\r白'),(23776,795650538001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','pavilionseller','drspiro@yahoo.com','Matthew Spiro','7414 Singing Hills Dr','Boulder','CO','UNITED STATES','80301-3768','(303) 530-1308','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 21:06:04',0,NULL,3,1,1,1,'LK189305176CN\r ','hermeshine'),(23777,924598200016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','jimmielx','email@jameswhiteside.com','James Whiteside','Ground Floor Flat<br>3 Stella Road','London','London','UNITED KINGDOM','SW17 9HG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 21:18:57',0,NULL,3,1,3,1,'RA184594224CN\r ','hutongstore'),(23778,840001371002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','tmgerhard','toddgerhard@yahoo.com','todd gerhard','135 n 7th st','olean','NY','UNITED STATES','14760-2309','(716) 244-1354','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-10 21:23:15',0,NULL,3,1,21,1,'RA184594365CN ','hermeshine'),(23779,944252701015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','justsmile1909sharon','justsmile1909@hotmail.co.uk','sharon rabjohns','3 Foxglove Way','Chard','Somerset','UNITED KINGDOM','TA20 1HT','07747606387','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 21:42:54',0,NULL,3,0,11,1,'BJ01715703 ','hutongstore\r1.6x2.1  黑色'),(23780,924625764016,260660052031,'New 55mm Ring adapter for Cokin P Series Filter Holder',1,'AA2209',1.6,'hutongstore','eggychap','dave.chapman@hotmail.co.uk','dave  chapman','63 verna road<br>St Beudeux','plymouth','Devon','UNITED KINGDOM','pl5 2by','01752362027','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 22:09:10',0,NULL,3,1,17,0,NULL,'hutongstore'),(23781,944267134015,250692237909,'New 49mm Ring adapter for Cokin P Series Filter Holder',1,'AA2207',1.6,'hutongstore','eggychap','dave.chapman@hotmail.co.uk','dave  chapman','63 verna road<br>St Beudeux','plymouth','Devon','UNITED KINGDOM','pl5 2by','01752362027','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-10 22:09:11',0,NULL,3,1,2,1,'30121260606\r ','hutongstore\r方形滤镜接口环 55mm   1\r方形滤镜接口环 49mm    1'),(23782,861726123017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',11.88,'photographyacc','m.deptula0770','m.deptula@yahoo.co.uk','marek deptula','Thame Workholding<br>Field End,Thame Road,','Long Crendon,Aylesbury','Buckinghamshire','UNITED KINGDOM','HP18 9EJ','01844208050','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-10 22:09:15',0,NULL,3,1,11,1,'BJ01669350\r ','photographyacc'),(23783,795689060001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.5,'hermeshine','rennie.7241','rpolanecky@seznam.cz','Rene Polanecky','Komenskeho 35','Sestajovice','Czech Republic','CZECH REPUBLIC','25092','724156773','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-10 22:36:16',0,NULL,3,1,11,1,'BJ01669339\r ','hermeshine'),(23784,944281064015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-10 22:37:45',0,NULL,3,1,21,1,'RA184594374CN ','hutongstore'),(23785,840055615002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','sram6430','rnramales@yahoo.com','ronald ramales','1337 Pine St','port huron','MI','UNITED STATES','48060-5141','(810) 987-5062','NoPaymentFailure','CheckoutComplete','Other','2012-02-10 23:45:38',0,NULL,3,1,1,1,'LK165878299CN\r','hermeshine\rL  已入库'),(23786,795716688001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','donnys_element','coopross81@hotmail.com','G Cooper Ross','1800 Fawn Valley Ln','Edmond','OK','UNITED STATES','73003-2417','(405) 413-9300','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-11 00:01:07',0,NULL,3,1,1,1,'LK188556059CN\r ','hermeshine'),(23787,801666187018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','tizmisskerry','kerryfredman@hotmail.co.uk','Kerry-Ann Fredman','Marley House 15L<br>7, University Way','GB','London','UNITED KINGDOM','E16 2GH','0781785752','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 00:23:25',0,NULL,3,1,11,1,'BJ01669349\r ','photographyacc'),(23788,861784088017,270891544454,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.7,'photographyacc','misc_items_2010','misc-sales@hotmail.com','Ricky Gamble','1 Flanders Row<br>Railway Road','Wisbech','Cambridgeshire','UNITED KINGDOM','PE13 2UP','01945584112','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 00:48:51',0,NULL,3,1,11,1,'BJ01669337\r ','photographyacc'),(23789,944332163015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','alexroll11','ajudezb@gmail.com','Alejandro Judez Benavente','Del Pilar 68 2 2','Premia De Mar','Cataluña','SPAIN','08330','672185652','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 00:49:16',0,NULL,3,1,21,1,'RA184594388CN ','hutongstore'),(23790,861815100017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',55.6,'photographyacc','mrdenmac','nkwells75@gmail.com','Nicole Wells','23 Hughes St','Point Clare','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 02:42:28',0,NULL,3,1,17,0,NULL,'photographyacc'),(23791,801702197018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',52.75,'photographyacc','mrdenmac','nkwells75@gmail.com','Nicole Wells','23 Hughes St','Point Clare','New South Wales','AUSTRALIA','2250','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 02:42:28',0,NULL,3,1,4,1,'YW868897812CN\r ','photographyacc\r斜臂    1\r反光板支架   1\r灯架  2m    2\r看看换成弹簧灯架是否会加一个数量级'),(23792,795776857001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','filo1','asianskinwhitening@yahoo.com','N Delola','61 Alvine Drive, Eagleby','Brisbane','Queensland','AUSTRALIA','4207','0433164789','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 04:08:03',0,NULL,3,1,11,1,'BJ01669351\r ','hermeshine'),(23793,795785967001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','ttonik2011','krasnovav@mail.com','Anton Krasnov','proezd Krupskoy, 19','Engels,','Saratovskaya obl,','RUSSIAN FEDERATION','413105',' 79053680076','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-11 04:53:31',0,NULL,3,1,3,1,'RA184594215CN\r ','hermeshine'),(23794,840143124002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','wardyfa18','wardyf18@yahoo.com.au','Aaron Ward','Unit 1<br>36 Caldwell Street','Merewether','New South Wales','AUSTRALIA','2291','(046) 691-2116','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 05:44:51',0,NULL,3,1,2,1,'30121260665\r ','hermeshine'),(23795,795800947001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','syber_cat1','sybercat1@gmail.com','Cynthia Franco','593 N 3rd St','Porterville','CA','UNITED STATES','93257-2435','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 06:15:04',0,NULL,3,0,1,1,'LK197730405CN\r ','hermeshine\r1.6*2.1  白色'),(23796,795789744001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','robycake','davesubileau@hotmail.com','David Subileau','10, rue Eugéne Pergeline','Nantes -Pays de Loire- FRANCE','Pays de la Loire','FRANCE','44200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 06:26:54',0,NULL,3,1,11,1,'BJ01669348\r ','hermeshine\r申报gift'),(23797,840153903002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','v-ogorodov','ogorodov@ngs.ru','Viktor Ogorodov','Akademicheskaya str., 21-35','Novosibirsk','Novosibirskaya obl','RUSSIAN FEDERATION','630090','8-9139556553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 06:49:44',0,NULL,3,1,17,0,NULL,'hermeshine'),(23798,801757582018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.08,'photographyacc','lethargy_com_au','bartek.czyz@gmail.com','Bart Czyz','2/4 Westgate Ave','Albion','Victoria','AUSTRALIA','3020','0430036749','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 06:59:08',0,NULL,3,1,17,0,'RA184594119CN\r ','photographyacc'),(23799,801758159018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',31.34,'photographyacc','lethargy_com_au','bartek.czyz@gmail.com','Bart Czyz','2/4 Westgate Ave','Albion','Victoria','AUSTRALIA','3020','0430036749','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 07:01:17',0,NULL,3,1,3,1,'RA184594119CN\r ','photographyacc\r沙袋（普通）      1\r伞式柔光箱 80cm 8角      1'),(23800,795808699001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','v-ogorodov','ogorodov@ngs.ru','Viktor Ogorodov','Akademicheskaya str., 21-35','Novosibirsk','Novosibirskaya obl','RUSSIAN FEDERATION','630090','8-9139556553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 07:03:12',0,NULL,3,1,17,0,NULL,'hermeshine'),(23801,840156896002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',73.9,'hermeshine','v-ogorodov','ogorodov@ngs.ru','Viktor Ogorodov','Akademicheskaya str., 21-35','Novosibirsk','Novosibirskaya obl','RUSSIAN FEDERATION','630090','8-9139556553','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 07:08:12',0,NULL,3,1,5,1,'CP243056308CN\r ','hermeshine\r闪光的柔光箱   60cm  1\r灯架  2m   1\r2B柔  2套'),(23802,840181087002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','masyama1','masyama@mail.ru','Maxim Stepanov','prospekt Pobedy, 388B-29','Chelyabinsk','Chelyabinskaya oblast\'','RUSSIAN FEDERATION','454021','(912) 792 - 8126','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 09:00:53',0,NULL,3,1,3,1,'RA184594207CN\r ','hermeshine'),(23803,861921188017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','rssayani','raheemasayani@hotmail.co.uk','raheema sayani','9 parvian road','leicester','Leicestershire','UNITED KINGDOM','le26ts','07885985688','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 10:06:43',0,NULL,3,0,3,1,'RA184594706CN ','photographyacc\r1.6x3m 白色'),(23804,944504328015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','gideon6032','jaman@simnet.is','Gudmundur Árnason','Hólagata 37','Reykjanesbær','','ICELAND','260','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 10:50:01',0,NULL,3,1,21,1,'RA184594520CN ','hutongstore'),(23805,840229220002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','mwngz9wz','autohelp.volg@mail.ru','YURIY YURASOV','64 Armii dom 67, kv. 14','Volgograd','Russian Federation','RUSSIAN FEDERATION','400059','89173334439','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 11:41:14',0,NULL,3,1,17,0,'RA184594175CN\r ','hermeshine'),(23806,801837793018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',10,'AA1312',14.3,'photographyacc','mandalas','tealskye@optusnet.com.au','Zena Beardsmore','8 Deeside Close','Penrith','New South Wales','AUSTRALIA','2750','0247367013','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 11:43:53',0,NULL,3,1,3,1,'RA184594198CN\r ','photographyacc\r10块，挑好的发'),(23807,795880447001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','madfireblade','madfireblade@hotmail.com','mer bruno','11 ter rue roger sallengro','caullery','Nord-Pas-de-Calais','FRANCE','59191','00.00.00.00.00','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 11:44:44',0,NULL,3,1,3,1,'RA184594184CN\r ','hermeshine\r已退款'),(23808,840231808002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mwngz9wz','autohelp.volg@mail.ru','YURIY YURASOV','64 Armii dom 67, kv. 14','Volgograd','Russian Federation','RUSSIAN FEDERATION','400059','89173334439','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 11:55:03',0,NULL,3,1,3,1,'RA184594175CN\r ','hermeshine\r伞式柔光箱 80cm 8角    1\r伞式柔光箱 60×90cm     1'),(23809,840234262002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','pilten-2008','pilt@foto.no','Pål Terje Støtvig','Tagtvedtveien 57','Larvik','','NORWAY','3274','+47 916 68 112','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 11:57:52',0,NULL,3,1,21,1,'RA184594391CN\r ','hermeshine'),(23810,861981942017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','jaf*','jewel_lee6@hotmail.com','julie freeman','65 Mahogany Drive','Gulmarrad','New South Wales','AUSTRALIA','2463','0422389646','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 12:58:56',0,NULL,8,0,17,0,NULL,'photographyacc'),(23811,861976882017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.38,'photographyacc','jaf*','jewel_lee6@hotmail.com','julie freeman','65 Mahogany Drive','Gulmarrad','New South Wales','AUSTRALIA','2463','0422389646','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 12:59:49',0,NULL,3,1,3,1,'RA184594697CN ','photographyacc\r1.6x3m 背景布  黑色    1\rCANON 镜头盖  58mm    1\r'),(23812,795915261001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','kokscoder','kokscoder@gmx.de','Benjamin Stangneth','Guipavasring 60','Barsbüttel','','GERMANY','22885','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 13:27:26',0,NULL,3,1,21,1,'RA184594405CN\r ','hermeshine'),(23813,801885488018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',19,'photographyacc','kym1510','kcs@chariot.net.au','Kym Ogilvie','1 bass court','woodcroft','South Australia','AUSTRALIA','5162','0883228398','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-11 13:49:28',0,NULL,3,1,11,1,'BJ01669347\r ','photographyacc'),(23814,795928749001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','ninafox1984','nina_fox@mail.ru','Nina Gorskaya','Tipanova 4/31','Saint-Petersburg','','RUSSIAN FEDERATION','196066','+79218884471','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 14:02:45',0,NULL,3,1,11,1,'BJ01669346\r ','hermeshine'),(23815,924975044016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',2,'AO0005',24,'hutongstore','preggybird','dear.ethanalan@gmail.com','Becki Jeffries ','36 Douglas Lane <br>Wraysbury ','Staines ','Middlesex','UNITED KINGDOM','TW195NG ','01784488108','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 15:05:17',0,NULL,3,0,3,1,'RA184594683CN ','hutongstore\r1.6*3  黑色和白色'),(23816,836457563002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','phillydude1985','delske1985@gmail.com','delfin aponte','2038 glendale ave','philadelphia','PA','UNITED STATES','19152-4013','(267) 414-8215','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-11 16:02:07',0,NULL,3,0,1,1,'LK196148326CN\r ','hermeshine\r1.6*3  黑色'),(23817,795986725001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','dimitriskouroublis','dkouroublis@gmail.com','DIMITRIS KOUROUBLIS','CHAOU 6','CHANIA','CHANIA','GREECE','73131','00302821988928','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-11 16:43:15',0,NULL,3,1,24,1,'30121263141\r ','hermeshine'),(23818,840371666002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','derek198610','derekdawn@cogeco.ca','Derek Hillier','270 Beach BLVD','Hamilton','ON','CANADA','L8H6W1','(905) 549-1771','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 17:19:39',0,NULL,3,1,17,0,'BJ01669354\r ','hermeshine\r美标'),(23819,796027235001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','pakkert','george2236@gmail.com','Georgy Pakkert','Krupskaya 42-47','Bataysk','Rostovskaya oblast','RUSSIAN FEDERATION','346880','89054873663','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 17:33:15',0,NULL,3,1,3,1,'RA184594516CN ','hermeshine'),(23820,840380565002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','jlizel','jean-loup.izel@maison-blanche.org','Jean-Loup IZEL','1 rue d\'en bas','MONTMIRAIL','Champagne-Ardenne','FRANCE','51210','0607949827','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 17:34:18',0,NULL,3,1,11,1,'BJ01669344\r ','hermeshine'),(23821,840402496002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','audioclip.ru','rinatkin@gmail.com','Salimov Rinat','Mitinskaya 17k2-491','Moscow','','RUSSIAN FEDERATION','125222','+79160633670','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 18:09:37',0,NULL,3,1,3,1,'RA184594136CN\r ','hermeshine'),(23822,802030086018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT082',48.92,'photographyacc','jarleon','jarleon22@yahoo.es','Jose Antonio Rodriguez de Leon','c/ Aguadulce nº 56, 2º piso','Las Palmas de Gran Canaria','Canarias','SPAIN','35004','616731725','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 18:32:50',0,NULL,3,1,21,1,'RA184594564CN','photographyacc\r环是72mm的\r申报gift 低值\r'),(23823,796085887001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.5,'hermeshine','sarvabhauma108','sarvabhauma108@gmail.com','Silvo Matulic','Dulwich street 76, Bennett Springs','Perth','Western Australia','AUSTRALIA','6063','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 19:17:21',0,NULL,3,1,11,1,'BJ01669338\r ','hermeshine'),(23824,840478556002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','alma3scami11a','kingleonphotography@yahoo.com','ALMA ESCAMILLA','964 San Antonio Ave<br>Apt 4','Seguin','TX','UNITED STATES','78155-2440','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 20:21:33',0,NULL,3,1,21,1,'RA184594312CN\r ','hermeshine'),(23825,840510811002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','andrey.polishko','apolishko@gmail.com','Andrey Polishko','Pushkin, p.Aleksandrovskaya, Zemledelcheskaya 15','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','196631','(950)040-7725','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 21:23:02',0,NULL,3,1,17,0,'RA184594096CN\r ','hermeshine'),(23826,796153145001,110407889244,'77mm CPL Circular Polarizing Filter 77 CPL Green.L ',1,'AA3314',7.2,'hermeshine','andrey.polishko','apolishko@gmail.com','Andrey Polishko','Pushkin, p.Aleksandrovskaya, Zemledelcheskaya 15','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','196631','(950)040-7725','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 21:23:03',0,NULL,3,1,3,1,'RA184594096CN\r ','hermeshine\r2mx1.5m 背景板（黑，白）   1\r绿叶 CPL  77mm  1'),(23827,944883599015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','juancarlos_mad_hotmail_com','juancarlos_mad@hotmail.com','Juan Carlos Martínez Blázquez','C/ALONDRA Nº2 PISO 4 LETRA C','GETAFE','Madrid','SPAIN','28904','620813459','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 21:34:20',0,NULL,3,1,24,1,'30121243876\r ','hutongstore'),(23828,796167765001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','6667.778','perrywalter@live.com','walter perry','4161 mcClellan hwy','branchland','WV','UNITED STATES','25506-8717','(304) 778-2667','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-11 21:55:48',0,NULL,3,1,1,1,'LK194479400CN\r ','hermeshine'),(23829,944886119015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','crimsonliar','keith.alger@ntlworld.com','Keith Alger','78 Gibson Drive','Rugby','Warwickshire','UNITED KINGDOM','CV214LL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-11 21:56:12',0,NULL,3,1,3,1,'RA184594122CN\r ','hutongstore'),(23830,796181530001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','angusfrangus','gusholliday@gmail.com','Angus','1/106 Greenacre Drive','Parkwood','Queensland','AUSTRALIA','4214','0425000050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-11 22:25:49',0,NULL,3,1,2,1,'30121263163\r ','hermeshine'),(23831,925290794016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','pepicortes','periodismocreativo@hotmail.com','Gabriela Sabbatella','Leopoldo Atenzo 639','Capital Federal','Buenos Aires','ARGENTINA','1408','541143004109','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-11 23:24:15',0,NULL,3,1,5,1,'CP243056299CN\r ','hutongstore\r还有夹子'),(23832,802191684018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',28.49,'photographyacc','dwajn','mail@wajnman.com','Dan Wajnman','Mellemvangen 22','Bronshoj','Copenhagen','DENMARK','DK 2700','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-11 23:48:49',0,NULL,3,1,21,1,'RA184594604CN ','photographyacc\rXL'),(23833,840583973002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','tomick82','info@tomaskejha.com','Tomas Kejha','Bezrucova 3','Brno','','CZECH REPUBLIC','60200','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 00:27:20',0,NULL,3,1,3,1,'RA184594082CN\r ','hermeshine\r'),(23834,944997190015,250846996647,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',64.9,'hutongstore','alfredteh','alfredteh@gmail.com','Alfred Teh','17,Queens Drive,','Stokesley','North Yorkshire','UNITED KINGDOM','TS9 5HA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 01:48:57',0,NULL,3,1,3,1,'RA184594079CN\r ','hutongstore'),(23835,840618844002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ssangjjangxd','hgweun@gmail.com','Hannah Gweun','3188 Cherrydale Dr','Diamond Bar','CA','UNITED STATES','91765','(909) 569-2214','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-12 02:23:27',0,NULL,3,1,1,1,'LK193248501CN\r ','hermeshine'),(23836,796267172001,110790874430,'New Professional Portable Diffuser for SpeedLight sb900 sb700 580ex metz  ',1,'AD1209',8.95,'hermeshine','quilles.2009','hotte.marcel@videotron.ca','Marcel Hotte','13 bourget apt 6','vaudreuil-dorion','QC','CANADA','j7v6t4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-12 03:06:21',0,NULL,3,1,11,1,' ','hermeshine'),(23837,840635820002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','787_amaury','sufiros23@hotmail.com','Edwin Amaury Marrero Perez','HC 67<br>PO Box 13158','Bayamon','PR','UNITED STATES','00956-9801','(787) 607-7061','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-12 03:27:13',0,NULL,3,1,1,1,'LK196569607CN\r ','hermeshine'),(23838,840636809002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','cooking4adventure','xcaddict@unwired.com.au','Michael Sullivan','2A Poulton Ave','Beverley Park,,','New South Wales','AUSTRALIA','2217','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 03:35:20',0,NULL,3,1,11,1,'BJ01669357\r ','hermeshine'),(23839,945033859015,250939065999,'New JueYing Lambency Flash Bowl Diffuser for Nikon SB600 SB800 YN460 467 565 P1',1,'AB3306',11,'hutongstore','promd74','quesixu@yahoo.es','Laura Jimena Gonzalez Moral','Vicente Aleixandre 25, 2º-C','Murcia','Murcia','SPAIN','30011','666876494','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 03:41:01',0,NULL,3,1,21,1,'RA184594414CN ','hutongstore'),(23840,840643064002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','panagar1978','mayur.panagar@gmail.com','mayur panaghar','34-Zabriskie Street<br>APT -3','jersey city','NJ','UNITED STATES','07307','(201) 892-4571','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 03:53:29',0,NULL,3,1,1,1,'LK190266090CN\r ','hermeshine'),(23841,0,280822901702,'New 72mm Snap-on Front Lens Cap for Canon 72mm lenscap',1,'AA1303',6,'photographyacc','st.elias','mbilak@epix.net','Mark J. Bilak','41 Ealer Hill Rd','Kintnersville','PA','UNITED STATES','18930-9606','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 04:16:09',0,NULL,3,1,1,1,'LK197196518CN\r ','photographyacc\rCANON 镜头盖  72mm   2'),(23842,840654733002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','ilokano_ak','ilokano_ak_kunak@yahoo.com','Erwin Piga','117 Omni Drive<br>Unit 3','Scarborough','ON','CANADA','M1P5A5','(416) 901-0335','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 04:43:37',0,NULL,3,1,3,1,'RA184594330CN\r ','hermeshine'),(23843,802272732018,280683086856,'Mini IR Wireless Remote Control for Nikon D90 D5000 D40',1,'AD1116',3.23,'photographyacc','strippingfaeries','magick_artist@hotmail.com','Miranda Leigh','16 Trethowan Ave','West Melton','Victoria','AUSTRALIA','3337','0397433953','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 05:24:23',0,NULL,3,1,2,1,'30121256712\r ','photographyacc'),(23844,840674351002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','joshalizer','joshua.rodriguez@holtcat.com','Joshua Rodriguez','8010 Shumard Oak Dr','San Antonio','TX','UNITED STATES','78223-3887','(210) 648-8879','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 06:22:47',0,NULL,3,1,21,1,'RA184594428CN ','hermeshine'),(23845,802302690018,280714535694,'Strong Camera shoulder bag D8 for Canon 550D 60D 7D ',1,'AD1101',28.49,'photographyacc','ausqualityproduct','jayroly@gmail.com','jay ralston','185 Invermay Rd.','Invermay','Tasmania','AUSTRALIA','7248','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 07:15:41',0,NULL,3,1,3,1,'RA184594065CN\r ','photographyacc'),(23846,802320707018,280666847406,'Nikon Original Photo Vest D3s D3x D300 D300s D700 D90 L',1,'AA2111',49.4,'photographyacc','peckhamgooner2012','stockwelllee@yahoo.com','Lee Byron Stockwell','8 rowan court<br>Garnies close','Peckham','London','UNITED KINGDOM','Se15 6pe','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 08:32:17',0,NULL,3,1,3,1,'RA184594153CN\r ','photographyacc'),(23847,796340306001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','peterd004','dallt@mentonegrammar.net','Taylor Dall','11A Laburnum St<br>Parkdale','Melbourne','Victoria','AUSTRALIA','3195','0395871910','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 08:44:28',0,NULL,3,1,17,0,'BJ01669356\r ','hermeshine'),(23848,802325678018,280805178322,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.7,'photographyacc','peterd004','dallt@mentonegrammar.net','Taylor Dall','11A Laburnum St<br>Parkdale','Melbourne','Victoria','AUSTRALIA','3195','0395871910','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 08:45:47',0,NULL,3,1,11,1,'BJ01669356\r ','photographyacc\r无牌方镜 ND4     1\r无牌方镜 渐变橙    1'),(23849,802338614018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',23.66,'photographyacc','a_hut10','ahut10@gmail.com','Alistair Hutten','1503 Ocean Drive','Lake Cathie','New South Wales','AUSTRALIA','2445','61404522807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:47:52',0,NULL,3,1,3,1,'RA184594140CN\r ','photographyacc\rC以外再发：\r\r无牌方镜 渐变蓝     1\r无牌方镜 渐变橙     1\r无牌方镜 渐变灰 （nd4）     1\r3片装的滤镜袋    1\r方镜广角托架（ 一槽）   1\r方形滤镜接口环 67mm    1\r方镜普通托架（三槽）    1\r透明10片装盒    1'),(23850,802337627018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',1,'AD1170',8.54,'photographyacc','a_hut10','ahut10@gmail.com','Alistair Hutten','1503 Ocean Drive','Lake Cathie','New South Wales','AUSTRALIA','2445','61404522807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:47:52',0,NULL,3,1,17,0,'RA184594140CN\r','photographyacc'),(23851,862467833017,270744174583,'67mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT022',3.98,'photographyacc','a_hut10','ahut10@gmail.com','Alistair Hutten','1503 Ocean Drive','Lake Cathie','New South Wales','AUSTRALIA','2445','61404522807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:47:53',0,NULL,3,1,17,0,'RA184594140CN\r ','photographyacc'),(23852,802328737018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',4.75,'photographyacc','a_hut10','ahut10@gmail.com','Alistair Hutten','1503 Ocean Drive','Lake Cathie','New South Wales','AUSTRALIA','2445','61404522807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:47:53',0,NULL,3,1,17,0,'RA184594140CN\r ','photographyacc'),(23853,802336208018,280805178543,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',13.29,'photographyacc','a_hut10','ahut10@gmail.com','Alistair Hutten','1503 Ocean Drive','Lake Cathie','New South Wales','AUSTRALIA','2445','61404522807','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 09:47:54',0,NULL,3,1,17,0,'RA184594140CN\r ','photographyacc'),(23854,8881329041272652,111,'Free shipping & Tracking # - 52mm 52 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon ',1,'AB1301',4.99,'aliexpress','1006706246',' hexplorer@yandex.ru','Alexandr Chudakov','ul. Ermaka dom 68 kv 135<br>Perm kray, Russian Federation','Berezniki','Perm kray','RUSSIAN FEDERATION','618419','79028391869',NULL,NULL,NULL,'2012-02-12 10:07:52',0,NULL,3,1,3,1,'RA184594051CN\r ',NULL),(23855,8881329041855976,111,'6 pcs Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs - Wholesale/ Retail ',1,'AKT081',28.99,'aliexpress','1006708733','mgl@proxy-service.ru','George Mischenko','Komsomolskiy prospekt 39b-151<br>Chelyabinskaya oblast, Russian Federation','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454112','+7 351 2803371',NULL,NULL,NULL,'2012-02-12 10:17:35',0,NULL,3,1,17,0,'RA184594048CN\r ',NULL),(23856,8881329042029980,111,'Free shipping & Tracking # - Full Set 49mm-82mm 9 Adapter Ring+Cokin P Filter Holder',1,'AKT025',24.99,'aliexpress','1006708732','mgl@proxy-service.ru','George Mischenko','Komsomolskiy prospekt 39b-151<br>Chelyabinskaya oblast, Russian Federation','Chelyabinsk','Chelyabinskaya oblast','RUSSIAN FEDERATION','454112','+7 351 2803371',NULL,NULL,NULL,'2012-02-12 10:20:29',0,NULL,3,1,3,1,'RA184594048CN\r ','除了C以外再发\r无牌方镜 渐变灰 （nd4）  1\r无牌方镜 渐变灰 （nd8）  1\r无牌方镜 渐变蓝    1\r无牌方镜 ND2     1\r无牌方镜 ND4    1\r无牌方镜 ND8     1\r6片装的滤镜袋    1\r '),(23857,802351551018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','joec123_123','joe.cowan123@btinternet.com','Joe Cowan','35 Antons Road<br>Pensby','wirral','Cheshire','UNITED KINGDOM','CH619PT','01516481086','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 09:56:26',0,NULL,3,1,11,1,'BJ01669355\r ','photographyacc'),(23858,840746249002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','kelisa1850','floranceya@gmail.com','florance yap','No.423 Happy Garden','Port Dickson','Negeri Sembilan','MALAYSIA','71000','6016253879','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 10:38:36',0,NULL,3,1,6,1,'EE651291480CN\r ','hermeshine\r夹子'),(23859,945183597015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','photosnapper2008','cassi@blueyonder.co.uk','liza petrenko','9 consett road','gateshead','Tyne and Wear','UNITED KINGDOM','ne11 0an','01914606340','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 11:04:49',0,NULL,3,1,3,1,'RA184594034CN\r ','hutongstore\r2个'),(23860,862532728017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','rickstar007','rickyozcan@yahoo.co.uk','A Ozcan','389B City Road<br>Angel','Islington','London','UNITED KINGDOM','EC1V 1NA','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 11:19:01',0,NULL,3,1,11,1,'BJ01669352\r ','photographyacc'),(23861,796395678001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','jovitacindy','jjowitulia@gmail.com','Jovita Namajuškaitė','Ukmergės 27-27','Kaunas','','LITHUANIA','49241','37069523272','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 11:06:57',0,NULL,3,1,24,1,'30121249314\r ','hermeshine\r已退款'),(23862,840769269002,120457062962,'Professional Tripod for DSLR SLR ballhead Free P&P New',1,'AE1601',39.98,'hermeshine','pipiolo1981','pipiolo81@gmail.com','Paco Tomás Fuster','C/ Pedreguer 20 3º 5','Denia','Comunidad Valenciana','SPAIN','03700','606534295','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 11:28:26',0,NULL,3,1,21,1,'RA184529424CN\r ','hermeshine'),(23863,802455262018,280708864662,'YongNuo WR159 Wireless Remote Control Nikon D300s D700',1,'AD1146',17.1,'photographyacc','seiyaz','seiyaz.ebay@gmail.com','Peter To','PO Box 8407','Sunnybank','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 13:30:50',0,NULL,3,1,17,0,'RA184594025CN\r ','photographyacc'),(23864,862596621017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','seiyaz','seiyaz.ebay@gmail.com','Peter To','PO Box 8407','Sunnybank','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 13:30:51',0,NULL,3,1,17,0,'RA184594025CN\r ','photographyacc'),(23865,802454004018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',40.85,'photographyacc','seiyaz','seiyaz.ebay@gmail.com','Peter To','PO Box 8407','Sunnybank','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 13:30:51',0,NULL,3,1,3,1,'RA184594025CN\r ','photographyacc\r永诺无线 YN159-N1     1\rlenspen     1\r井字扳手 可换头      1'),(23866,840831516002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','antonlarry','anton.larionov@gmail.com','Антон Ларионов','Krasnozvezdnaya Street, 7A-70','Nizhny Novgorod','Nizhegorodskaya oblast\'','RUSSIAN FEDERATION','603104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 13:40:19',0,NULL,3,1,17,0,NULL,'hermeshine'),(23867,840831517002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','antonlarry','anton.larionov@gmail.com','Антон Ларионов','Krasnozvezdnaya Street, 7A-70','Nizhny Novgorod','Nizhegorodskaya oblast\'','RUSSIAN FEDERATION','603104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 13:40:19',0,NULL,3,1,17,0,NULL,'hermeshine'),(23868,840831518002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','antonlarry','anton.larionov@gmail.com','Антон Ларионов','Krasnozvezdnaya Street, 7A-70','Nizhny Novgorod','Nizhegorodskaya oblast\'','RUSSIAN FEDERATION','603104','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 13:40:20',0,NULL,3,1,5,1,'CP243056325CN\r ','hermeshine\r2.4x3m背景架+ 白布  + 夹子    1\r反光伞110cm      1\r4灯头 灯头 孔   欧标   1\r'),(23869,801357449018,280805178284,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.7,'photographyacc','5858dwight','pjdwight@bigpond.net.au','Peter Dwight','496 Terrace Road','Freemans Reach','New South Wales','AUSTRALIA','2756','0245796630','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 14:03:04',0,NULL,3,1,11,1,'BJ01669334\r ','photographyacc'),(23870,945296541015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','ludwig59182','lquestroy@gmail.com','Ludwig Questroy','20 impasse Victor Hugo','Lys Lez Lannoy','Nord-Pas-de-Calais','FRANCE','59390','0658231615','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 14:11:30',0,NULL,3,1,11,1,'BJ01669353\r ','hutongstore'),(23871,925653391016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','joanjuanmiguel','videoartpedreguer@yahoo.es','JUAN MIGUEL JIMENEZ TORRENS','ALFARRASI 15','JAVEA','Comunidad Valenciana','SPAIN','03730','606735971','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 14:28:29',0,NULL,3,1,4,1,'YW868897823CN\r ','hutongstore\r澳转欧标'),(23872,795819552001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','danrojek','dandys@danielrojek.cz','Daniel Rojek','Dělnická<br>377/52','Proboštov','Ústecký','CZECH REPUBLIC','417 12','+450 774-328-895','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 15:03:13',0,NULL,3,1,5,1,'CP243056311CN\r ','hermeshine\r欧标'),(23873,802510249018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',23.66,'photographyacc','kapa1','kpanholzer@aol.com','Kai Panholzer','Friedrich-Ebert-Str. 5','Haar','','GERMANY','85540','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 15:05:52',0,NULL,3,1,21,1,'RA184594578CN\r ','photographyacc'),(23874,796515417001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','gytiswb','gytis.grigaravicius@gmail.com','Gytis Grigaravicius','Rutu g. 10-1<br>Vijuku km.','Kauno raj.','','LITHUANIA','LT-54306','37067435888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 15:09:36',0,NULL,3,1,24,1,'30121257795\r ','hermeshine'),(23875,925696263016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','narf1981','chines666@hotmail.com','Fco Javier Medina Delagado','C/Garcia orcoyen nº 7','azagra','Navarra','SPAIN','31560','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 15:28:40',0,NULL,3,1,4,1,'YW868897790CN\r ','hutongstore'),(23876,945362642015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dimitridjuric','dimitri.djuric@gmail.com','Dimitri Djuric','67<br>Rushmore Road','London','London','UNITED KINGDOM','e5 0ex','07940573382','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 15:40:06',0,NULL,3,1,3,1,'RA184594269CN\r ','hutongstore'),(23877,625692790004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','r1seup','nico_luethi@hotmail.com','Nico Lüthi','Auenstrasse 42','Kloten','','SWITZERLAND','8302','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 16:12:31',0,NULL,3,1,24,1,'30121260536\r ','hermeshine'),(23878,840957891002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','tolis1365','flioukas@yahoo.gr','Tolis Flioukas','herostratous 11','Chios','Greece','GREECE','82100','030 6945885305','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 17:02:54',0,NULL,3,1,21,1,'RA184594431CN ','hermeshine'),(23879,796603647001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','cvarsos','kostantinos2030@msn.com','Varsos Constantinos','Loukaki , Naxos','Chora Naxou','cyclades','GREECE','84300','2285022357','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 17:14:14',0,NULL,3,1,24,1,'30121248356\r ','hermeshine'),(23880,840371283002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','derek198610','derekdawn@cogeco.ca','Derek Hillier','270 Beach BLVD','Hamilton','ON','CANADA','L8H6W1','(905) 549-1771','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 17:12:11',0,NULL,3,1,11,1,'BJ01669354\r ','hermeshine\r单灯头  3  美标'),(23881,945469163015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','nbc1312','nikicoppard@hotmail.co.uk','Niki Coppard','24 Maugersbury Park','Stow on the Wold','Gloucestershire','UNITED KINGDOM','GL54 1DU','07891775653','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 17:31:59',0,NULL,3,0,3,1,'RA184519824CN ','hutongstore\rL  已入库'),(23882,796630790001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','esgomar','jemaro1@hotmail.com','Jesús Martín Rodríguez','C/Rambla, 2 4ºC','Santa Pola','Comunidad Valenciana','SPAIN','03130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 17:46:49',0,NULL,3,1,21,1,'RA184594445CN ','hermeshine'),(23883,802653765018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','sonic-321','henning.ogx@gmail.com','Henning Müller','Georg-Schroeder-Str. 3c','Berlin','','GERMANY','13591','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-12 18:07:25',0,NULL,3,0,2,1,'30121255614\r ','photographyacc\r1.6*2.1  绿色'),(23884,795487804001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',21.98,'hermeshine','ahundley23','angel_2832@yahoo.com','Amy Hundley','120 Joe Abbey Ln','Darby','MT','UNITED STATES','59829-8649','(406) 381-9530','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-12 19:09:12',0,NULL,3,0,1,1,'LK197969892CN\r ','hermeshine\r1.6*2.1  黑加白'),(23885,945646897015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','kr_821','ricky_kemp@yahoo.com','Richard Kemp','Holly Cottage<br>Canterbury Road, Palmers Hill,','Folkestone','Kent','UNITED KINGDOM','CT18 7EQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 19:50:24',0,NULL,3,1,11,1,'BJ01669358\r ','hutongstore'),(23886,925987321016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','vakulenko_sergiy','vakula_s_s@inbox.ru','Sergiy Vakulenko','ulitsa Kartvilishvili 3v, kv.34','Kiev','','UKRAINE','03148','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 19:54:34',0,NULL,3,1,24,1,'30121263885\r ','hutongstore'),(23887,841148231002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','litukis','aidas.pikiotas@lituka.com','Aidas Pikiotas','(Lituka) S.Zukausko str. 49-90','Vilnius','','LITHUANIA','LT-09131','+37068730909','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-12 20:18:48',0,NULL,3,0,21,1,'RA184594547CN ','hermeshine\r3XL  已入库'),(23888,796186243001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','mareesky54','mareem@westnet.com.au','Maree Mercer','P O Box 3','HYDE PARK','Queensland','AUSTRALIA','4812','0747747168','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 20:19:33',0,NULL,3,1,3,1,'RA184594290CN\r ','hermeshine'),(23889,945692442015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','judicus02','jo.cutler73@gmail.com','Jo Anderson','1 Broadgates Road<br>Wandsworth Common','London','London','UNITED KINGDOM','SW18 3NL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 20:27:32',0,NULL,3,1,11,1,'BJ01669359\r ','hutongstore'),(23890,944906946015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','uitacoom','uitagreg@hotmail.com','greg coomer','23 carlton terrace','crosskeys','Caerphilly','UNITED KINGDOM','NP117BU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-12 21:45:36',0,NULL,3,1,3,1,'RA184594017CN\r ','hutongstore'),(23891,945768964015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','sharondevoy','sharoncomerford@eircom.net','sharon devoy','Baunoge<br>callan','Callan','Kilkenny','IRELAND','056','08577264213','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-12 21:56:23',0,NULL,3,1,24,1,'30121261564\r ','hutongstore'),(23892,802876471018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','billysbargainsbazar','ssspayments@gmail.com','Joanne Gregory','2 Teleta Crescent','Corio','Victoria','AUSTRALIA','3214','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-12 22:15:05',0,NULL,3,0,11,1,'BJ01715682 ','photographyacc\r1.6*2.1  白色'),(23893,841225250002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','mcelestereis2012','mcelestereis@ig.com.br','Maria Celeste Reis','Rua Paissandu, 146/602, Flamengo','Rio de Janeiro','Rio de Janeiro','BRAZIL','22210080','5521 4106 0795','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 22:07:07',0,NULL,3,1,3,1,'\r ','hermeshine'),(23894,796873465001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','thkr23','thkr_23@hotmail.com','Thor Oeyvind Kristiansen','Verksgata 24','Oslo','OSLO','NORWAY','0566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 22:38:15',0,NULL,3,1,21,1,'RA184594459CN ','hermeshine'),(23895,841259406002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-12 23:18:54',0,NULL,3,1,11,1,'BJ01669335\r ','hermeshine'),(23896,796894373001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','ecaron50','etienne.snow@hotmail.com','Etienne Caron','11450 26e avenue','st-georges','QC','CANADA','G6A 1E7','(418) 227-0289','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,5,0,18,0,'\r ','hermeshine'),(23897,839655933002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',75.98,'hermeshine','dsa121177','davidainslie77@gmail.com','David Ainslie','17 Madaliene St<br>Torquay','Hervey bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-12 23:50:59',0,NULL,3,1,3,1,'RA184594105CN\r ','hermeshine\r2云柔   1\r伞式柔光箱 60×90cm   1\r已入库\r'),(23898,796910546001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',8,'AC1301',49.92,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 00:17:30',0,NULL,3,1,25,1,'RT127322188HK\r ','hermeshine\r申报gift低值   '),(23899,841283538002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',6,'AC1302',45,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 00:24:54',0,NULL,3,1,25,1,'RT127319161HK\r ','hermeshine\r申报gift低值   '),(23900,945861221015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','dandude2004','leeds244@hotmail.co.uk','Dan Clark','16 Park court<br>Hampton Wick','Kingston Upon Thames','Surrey','UNITED KINGDOM','KT1 4AU','07974301349','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 00:45:09',0,NULL,3,1,3,1,'RA184594357CN\r ','hutongstore'),(23901,841315452002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','shutterbeak','goodwinf001@hawaii.rr.com','William Goodwin','94-1146 Kukula St','WAIPAHU','HI','UNITED STATES','96797-5260','(808) 676-1137','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-13 01:43:52',0,NULL,3,1,1,1,'LK195752703CN\r ','hermeshine\r'),(23902,841327572002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','gallant303','gagan303@gmail.com','Gagan Jangra','9 Elaine Court','Cranbourne','Victoria','AUSTRALIA','3977','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 02:13:53',0,NULL,3,1,2,1,'30121260061\r ','hermeshine'),(23903,8881329099905453,111,'Free shipping & Tracking # - New Pro 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND Filters of Cokin P Series',1,'AE1202',5.39,'aliexpress','1006729784','123hotmail.com','filippo mastrantoni','c/o studio Franco Mastrantoni via foggini 61<br>italia, Italy','firenze','italia','ITALY','','+0039 335 1760889',NULL,NULL,NULL,'2012-02-13 02:25:05',0,NULL,3,1,3,1,'RA184519965CN ',NULL),(23963,8881329185600755,111,'Aluminium UltraLightweight 68\" Camera Monopod with ballhead - Wholesale/ Retail',1,'AE1604',36.99,'aliexpress','1006749419','christian.gielen@hotmail.com','gielen christian','rue du Tilleul 1A - A02<br>Liege, Belgium','Hannut','Liege','BELGIUM','4280','+0032 493 988646',NULL,NULL,NULL,'2012-02-14 02:13:20',0,NULL,3,1,3,1,'RA184519890CN ',''),(23904,863156258017,270781492027,'3-Roller Wall-Mounted MANUAL Background Support System',1,'AD1147',123.5,'photographyacc','nicoleroseart','nicole@nicoleroseart.com.au','nicole rose','13 bellevue st<br>richmond','melbourne','Victoria','AUSTRALIA','3121','0394286630','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-13 02:50:36',0,NULL,3,1,17,0,NULL,'photographyacc'),(23905,863160609017,270843604665,'New Fancier Professional Complete Tripod kit  Damped Pan Head with Carry bag',1,'AD1196',61.75,'photographyacc','nicoleroseart','nicole@nicoleroseart.com.au','nicole rose','13 bellevue st<br>richmond','melbourne','Victoria','AUSTRALIA','3121','0394286630','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-13 03:01:26',0,NULL,3,1,4,1,'YW868897646CN ','photographyacc\r手动升降背景架   1\r伟峰6714   1\r'),(23906,796975772001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','drtechno1','rtanjuakio@gmail.com','Robert Tanjuakio','39632 N Queensbury Ln','Beach Park','IL','UNITED STATES','60083-3056','(847) 204-4535','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 03:10:48',0,NULL,3,1,1,1,'LK196550058CN\r ','hermeshine'),(23907,841365051002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','mousesammy','samkingwang@hotmail.com','Hao Wang','1107-40 Tuxedo Court','Scarborough','ON','CANADA','m1g 3s7','(416) 438-7853','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 03:57:56',0,NULL,3,1,3,1,'RA184594326CN\r ','hermeshine'),(23908,841369545002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',2,'AA3408',19.98,'hermeshine','beagledenis','rodesia@q-net.net.au','denis taylor','7 dower st','mandurah','Western Australia','AUSTRALIA','6210','0895354638','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 04:10:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(23909,841378507002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','chrismonster24','bobbydigital86@yahoo.com','Lidia Cruz','3415 S Sepulveda Blvd<br>Ste 440','Los Angeles','CA','UNITED STATES','90034-6016','(323) 640-1410','NoPaymentFailure','CheckoutComplete','Other','2012-02-13 04:45:53',0,NULL,3,1,1,1,'LK196603586CN\r ','hermeshine'),(23910,797020557001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','nativeideas','masterwaki@hotmail.com','Robert Cooper','14 damson place<br>bucklands beach','Auckland','Akl','NEW ZEALAND','2012','2645924','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 06:20:30',0,NULL,3,1,25,1,'RT127476493HK\r ','hermeshine\r1.6*2.1     黑加黄'),(23911,841403456002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','trevor_qld','trevorcook1@bigpond.com.au','Trevor Cook','10 Flametree st<br>Bridgeman Downs','Brisbane','Queensland','AUSTRALIA','4035','0738630167','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 06:52:53',0,NULL,3,0,3,1,'RA184594595CN\r ','hermeshine\rL  已入库'),(23912,8881329118391881,111,'EW-78D',1,'',0,'hermeshine','danielaires','daniel_aires@globo.com','Daniel Pereira','SQN 307 bloco D apt 207','Brasilia','Distrito Federal','BRAZIL','70746-040','+556191076948',NULL,NULL,NULL,'2012-02-13 07:33:11',0,NULL,3,0,25,1,'RT127481520HK\r ',NULL),(23913,803032481018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','infmaj','infernalmajesty@netspace.net.au','Leanne Hardy','58 Koona Street','Albion Park Rail','New South Wales','AUSTRALIA','2527','0242579408','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-13 07:36:07',0,NULL,3,0,11,1,'BJ01715678 ','photographyacc\r1.6*2.1   黑色'),(23914,8881329120438391,111,'1.6*2.1  背景布',1,'',0,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884',NULL,NULL,NULL,'2012-02-13 08:07:18',0,NULL,3,0,21,1,'RA184594670CN ','1.6*2.1   黑色，黄色，橙色，粉色布 '),(23915,803064541018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.22,'photographyacc','89arippingtons','rippingtons89a@yahoo.co.uk','Mr J.M Curtain','Qualplast (1991) Ltd<br>Old Walsall Road, Great Barr','Birmingham','West Midlands','UNITED KINGDOM','B42 1EA','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 08:12:31',0,NULL,3,1,11,1,'BJ01669333\r ','photographyacc'),(23916,797048789001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','fd-camera','nlaptst@gmx.com','Toni Tuomainen','Peräkyläntie 215','Pori','Lassila','FINLAND','29680','0509101187','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 08:50:00',0,NULL,3,1,21,1,'RA184594533CN ','hermeshine'),(23917,797053842001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','wladimir116','wladimir880@rambler.ru','Владимир Сакрюкин','Ул.Донская дом 116','Камышин','Волгоградская область','RUSSIAN FEDERATION','403870','+79275164156','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 09:09:48',0,NULL,3,1,5,1,'CP243056197CN','hermeshine\r黑加白'),(23918,926327262016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','senya_yar','senyalaz@mail.com','Lazarev Sergey','Prospekt Mashinostroiteley 7-16','Yaroslavl','','RUSSIAN FEDERATION','150062','203201','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 09:15:23',0,NULL,3,1,3,1,'RA184594635CN  ','hutongstore\r超重的话告诉我一下'),(23919,946031337015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','matiaspeterpan','matilike@hotmail.com','matias diaz','ctra hardu nº3 p 2 1ºd urb nuevo real','melila','Andalucía Ceuta y Melilla','SPAIN','52006','647660958','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 09:25:41',0,NULL,3,1,4,1,'YW868897650CN ','hutongstore\r粉色加黑色'),(23920,946032202015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','zvkroy','roy78howell@btinternet.com','Roy Howell','Tunstal<br>Station Road','Grimsby','Lincolnshire','UNITED KINGDOM','DN365QP','01472840862','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-13 09:25:55',0,NULL,3,1,4,1,'YW868897661CN ','hutongstore\r黑加白'),(23921,946045532015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','einnor2224','einnor2224@yahoo.com','Ronnie de los Santos','33 Moredun Park View','Edinburgh','Edinburgh City','UNITED KINGDOM','EH17 7LR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 10:04:20',0,NULL,3,1,11,1,'\\ ','hutongstore'),(23922,797083299001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','chrisroko','rokosch@gmx.de','Christian Rokosch','Kreuzstr. 32','Freiburg','','GERMANY','79106','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 11:06:36',0,NULL,3,1,21,1,'RA184594652CN ','hermeshine'),(23923,797085374001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','sickofitallnyhc','markturner3@me.com','Mark Turner','Po Box R91','Royal Exchange','New South Wales','AUSTRALIA','1225','61403041795','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 11:13:29',0,NULL,3,1,11,1,'\\ ','hermeshine'),(23924,839281676002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','spookydonk','barrkell@gmail.com','Barry Kelly','98 whitestown avenue<br>Clonsilla','Dublin','Dublin','IRELAND','15','0858076969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 11:13:34',0,NULL,3,1,21,1,'RA184594649CN  ','hermeshine'),(23925,941719440015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','matt_zd','mfrey86@googlemail.com','Matthew Frey','64 Victoria Street<br>Briton Ferry','Neath','Neath Port Talbot','UNITED KINGDOM','sa11 2rb','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 12:13:42',0,NULL,3,1,11,1,'BJ01669420 ','hutongstore'),(23926,797107419001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','drijeka','davor.dragicevic.rijeka@gmail.com','Davor Dragicevic','Vlade Grozdanica 5','Rijeka','Hrvatska','CROATIA','51000','385 98 327 632','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 12:31:02',0,NULL,3,1,3,1,'RR658650641CN\r ','hermeshine'),(23927,797109817001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','weeis','wee_is@hotmail.com','Weeraphan Issavasopon','4/922 M.8<br>Dorkmai','Pravat','Bangkok','THAILAND','10250','66891199793','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 12:39:03',0,NULL,3,1,11,1,NULL,'hermeshine'),(23928,797115558001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','stsmhn2012','stsmhn@gmail.com','Stanislav Mukhin','Sribnokolska','Kiev','','UKRAINE','02068',' 380987176111','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 12:58:42',0,NULL,3,1,17,0,NULL,'hermeshine'),(23929,797117908001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','stsmhn2012','stsmhn@gmail.com','Stanislav Mukhin','Sribnokolska','Kiev','','UKRAINE','02068',' 380987176111','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 13:06:08',0,NULL,3,1,11,1,NULL,'hermeshine\r58-58mm 双阳环   1\r52-58mm 双阳环    1'),(23930,946126865015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','pawnster413','omid@massali.net','Omid Massali','Övre Slottsgatan 11A<br>Övre Slotts','Uppsala','Uppland','SWEDEN','75312','0736546522','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 13:36:09',0,NULL,3,1,3,1,'RA184519974CN ','hutongstore\r没发货，我点的。\r客户问，我输了个单号进去\r2.15   冯'),(23931,797128638001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','evgcom','evgvideo@yandex.ru','Evgeni Komoniuk','prospekt Gongadze 28, kv. 1','Kiev','Kievskaya oblast','UKRAINE','04215','380965232409','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 13:38:54',0,NULL,3,1,21,1,'RA184507450CN ','hermeshine\rSAL挂号便宜10块钱'),(23932,926448669016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','lem120','lem120_@hotmail.com','Mario Bruno','Hotel Sansicario Majestic, Via Clos de la Mais, H22<br>Sansicario Alto','Cesana Torinese','TO','ITALY','10054','3356525963','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-02-13 13:46:31',0,NULL,3,1,12,1,'3125518266\r ','hutongstore\r欧标\r泡重10.2.\r\r9.5\r'),(23933,863306143017,270805298251,'New 6pcs Filters Set Kit for Cokin p series 6 slot Case',1,'AKT081',26.12,'photographyacc','kapa1','kpanholzer@aol.com','Kai Panholzer','Friedrich-Ebert-Str. 5','Haar','','GERMANY','85540','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 14:07:24',0,NULL,3,1,3,1,'RA184509067CN\r ','photographyacc'),(23934,841535562002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','fimkajane','fimka_@mail.ru','Evgeniya Mironova','Oslyabinskiy pereulok 3-33','Moscow','','RUSSIAN FEDERATION','115280','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 14:51:12',0,NULL,3,0,3,1,'RA184529336CN\r ','hermeshine\r1.6*3   蓝色'),(23935,946169096015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',22.99,'hutongstore','211893484','s211893484@yahoo.com.hk','Kin Pong Chow','23 webb St<br>gosnells, WA,','perth','Western Australia','AUSTRALIA','6110','0297865482','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-13 15:10:11',0,NULL,3,1,3,1,'RA184523228CN ','hutongstore'),(23936,841543650002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','maxvelio','maxvelio@hotmail.com','Maximiliano Saiz Noeda','Apdo. de Correos 6001<br>(Universidad de Alicante)','Alicante','Alicante','SPAIN','03080','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 15:13:31',0,NULL,3,0,3,1,'RA184519841CN ','hermeshine\rXL  已入库'),(23937,946183204015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','invictus*2010','lorna.rodgers@flanagan-flooring.com','Jenna Jordan','Millpond Business Park<br>Belfast Road','Saintfield','Down','UNITED KINGDOM','BT24 7NL','02897510932','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 15:39:26',0,NULL,3,1,3,1,'RA184519855CN ','hutongstore'),(23938,863379302017,270750637482,'Neoprene Camera Cover Case for Canon Nikon Sony M Size ',1,'AC1301',5.68,'photographyacc','haske75','hveck@hotmail.com','Haske van Eck','Henri Dunantstraat 23','BENEDEN LEEUWEN','','NETHERLANDS','6658XA','0487-594663','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 15:21:27',0,NULL,3,1,11,1,NULL,'photographyacc'),(23939,841563315002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','sv10soua','soua77@yahoo.com','soua vang','1566 wilson ave','saint paul','MN','UNITED STATES','55106-5918','(651) 497-1904','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-13 16:01:13',0,NULL,3,1,1,1,'LK198448218CN\r ','hermeshine'),(23940,946191689015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','tibko1968','tibko68@gmail.com','Tibor Kovac','Vinicna cesta 70','Nova Bana','','SLOVAK REPUBLIC','96801','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 15:55:10',0,NULL,3,1,5,0,'CP243056223CN ','hutongstore\r欧标'),(23941,863400605017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','bingbing333','anya_bing@hotmail.com','anya pinsent','1241 high st','north bay','ON','CANADA','p1b 6t3','(705) 497-7540','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 16:14:23',0,NULL,3,0,3,1,'RA184529322CN\r ','photographyacc\r1.6*3  白色'),(23942,946215491015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','leon7179','lvm.9bad@yahoo.co.uk','Leon Mitchell','Highgate Wood School<br>Montenotte Road','London','London','UNITED KINGDOM','N8 8RN','07958717208','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 16:42:33',0,NULL,3,0,3,1,'RR658650791CN\r ','hutongstore\rL  已入库'),(23943,926543925016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','denlvrus','denisezi@rambler.ru','Denis Lavin','Constantinou Kavafi 10, Eva crt, 201','Limassol','','CYPRUS','3076','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-13 17:01:07',0,NULL,3,1,3,1,'RR658650788CN\r ','hutongstore\r加$5运费，已付款'),(23944,797210336001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','ptjoe','piafinho@gmail.com','Paulo Santos','R. Victor Damas Lt 36, 2-C<br>Urb. Serra de Carnaxide','Amadora','','PORTUGAL','2720-801','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 17:14:40',0,NULL,3,1,11,1,NULL,'hermeshine'),(23945,797229177001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','b_drift','bdrift@gmail.com','Barry Lai','1717 Colburn St','Honolulu','HI','UNITED STATES','96819-3244','(808) 479-5695','NoPaymentFailure','CheckoutComplete','Other','2012-02-13 17:54:45',0,NULL,3,1,1,1,'LK198327815CN\r ','hermeshine'),(23946,863460503017,270862492371,'New Studio Lighting Kit Stands Large Carry Carrying Bag Material Oxford cloth',1,'AD1181',20,'photographyacc','1976nibbs','nibbs_2001@hotmail.com','Neil  Hodgson BSc','33 AMBERTON PLACE<br>OAKWOOD','LEEDS','West Yorkshire','UNITED KINGDOM','LS8 3AH','01132480777','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 18:04:27',0,NULL,3,1,11,1,NULL,'photographyacc'),(23947,946299612015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dwil3408','dwilkinsonphoto@gmail.com','David Wilkinson','7 Briarsfield<br>Barmby Moor','Pocklington','East Riding of Yorkshire','UNITED KINGDOM','YO42 4HN','01759302074','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 18:51:03',0,NULL,3,1,3,1,'RR658650765CN\r ','hutongstore'),(23948,946321120015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','justintimejac','jacqueline.bellew@btopenworld.com','JACQUELINE  BELLEW','APPLETREES 68 WILLINGTON ROAD','BEDFORD','Bedfordshire','UNITED KINGDOM','MK443TN','01234838639','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-13 19:15:33',0,NULL,3,0,3,1,'RR658650805CN\r ','hutongstore\rL  已入库\r\r'),(23949,797282804001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',32,'hermeshine','tigravi2011','tigravi@yandex.ru','Roman Beltukov','1 maya 125-9','Votkinsk','Udmurtiya','RUSSIAN FEDERATION','427430','+79199161930','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 19:28:53',0,NULL,3,1,3,1,' ','hermeshine'),(23950,0,280822902058,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',3.25,'photographyacc','lauriesavingstoyou','lovetobuy303@yahoo.com','lovetobuy.303@ebay','827 NE A St<br>Apt 5','Grants Pass','OR','UNITED STATES','97526-2273','(541) 264-1377','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 19:46:03',0,NULL,3,1,1,1,'LK193434486CN\r ','photographyacc'),(23951,841693238002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','svetangen','sversimon@gmail.com','Sverre Tangen Simonsen','936 Camino del Sur','Goleta','CA','UNITED STATES','93117-4913','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-13 20:05:18',0,NULL,3,1,3,1,'RR658650774CN\r ','hermeshine'),(23952,926674404016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 20:12:59',0,NULL,3,1,17,0,NULL,'hutongstore'),(23953,926666747016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 20:12:59',0,NULL,3,1,17,0,NULL,'hutongstore'),(23954,841708673002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','mspelten','info@actiefotografie.nl','Marco Spelten','Pronkmos 2','HOUTEN','','NETHERLANDS','3994LP','(087)8736301','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-13 20:31:15',0,NULL,3,1,3,1,'RR658650920CN\r ','hermeshine\rM  已入库'),(23955,863557797017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',3.98,'photographyacc','ozhkutis','kristina.akulova@gmail.com','Kristina Akulova','Kestucio g. 67','Prienai','Kauno raj','LITHUANIA','59130','037060084734','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-13 20:39:00',0,NULL,3,1,11,1,NULL,'photographyacc'),(23956,946386768015,250939650416,'New in box 52mm 52 Haze UV Filter For Canon SONY Pentax Nikon Protect lens',1,'AA3301',2.18,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 20:40:39',0,NULL,3,1,17,0,NULL,'hutongstore'),(23957,946386588015,250599387297,'52mm CPL Circular Polarizing Filter 52 CPL Green.L New',1,'AA3308',3.68,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 20:40:39',0,NULL,3,1,4,1,'YW868897086CN ','hutongstore\r帽子 nikon   1\r灯架  2m    1\r反光板支架   1\r绿叶 UV  52mm   1\r绿叶 CPL  52mm    1\r超重了   '),(23958,841722720002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','julia-sha1983','julia-sha@rambler.ru','Шишкова Юлия','Алтуфьевское шоссе, д.92, кв.477','Москва','','RUSSIAN FEDERATION','127349','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 20:56:03',0,NULL,3,1,11,1,'\\ ','hermeshine\r没发货'),(23959,946428159015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','linas565','linas@paintbaleris.lt','Linas NAVARDAUSKAS','TAIKOS pr. 84-54','Kaunas','LITHUANIA','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-13 21:41:55',0,NULL,3,1,3,1,'RA184519815CN ','hutongstore\r倒影板（白黑）   1\r反光板 100*150 40*60 5合1       1\r'),(23960,797392346001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','plefish','slirty8@hotmail.com','Maurice Aucoin','p.o. box 733','Cheticamp','NS','CANADA','b0e1h0','(902) 224-3542','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-13 23:16:51',0,NULL,3,1,3,1,'RA184523452CN\r ','hermeshine\r'),(23961,803489057018,280666794780,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',18.99,'photographyacc','cass2836','william.clay@ntlworld.com','william clay','36 wheatear lane, ingleby barwick','stockton-on-tees','Cleveland','UNITED KINGDOM','ts170tb','01642762989','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 01:23:41',0,NULL,3,1,3,1,'RA184523449CN ','photographyacc'),(24117,842905605002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','hartip69','pascal@hartip.ch','Pascal Hartmann','12 Corella Ct','Carrum Downs','Victoria','AUSTRALIA','3201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 10:28:28',0,NULL,3,1,2,1,'30121834120\r ','hermeshine'),(23962,863696832017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',55.6,'photographyacc','ijustwanttobuystuffcheap','langfordliz@hotmail.com','Kieran Langford','Unit 2/723 Bell st','Preston','Victoria','AUSTRALIA','3072','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 02:02:02',0,NULL,3,1,4,1,'YW868897672CN ','photographyacc'),(23964,8881329185767913,111,'Free shipping & Tracking # - New Spirit Level Hot Shoe Hotshoe Cover Protector for Canon Nikon ',2,'AA1206',9.98,'aliexpress','1006750143','post@linddal.net','Michael Linddal','Dalager 111','Ringe','Fyn','DENMARK','5750','+45 29 710950',NULL,NULL,NULL,'2012-02-14 02:16:07',0,NULL,3,1,3,1,'RA184520005CN ',NULL),(23965,8881329189635783,111,'dreamboxprod75',1,'',0,'hutongstore','dreamboxprod75','julien@dreamboxprod.com','Julien Dhordain','265 rue du Faubourg St-Martin<br>B8914 Esc E B2024 4etage','Paris','Ile-de-France','FRANCE','75010','',NULL,NULL,NULL,'2012-02-14 03:20:35',0,NULL,3,0,3,1,'RA184519991CN','45w 5500k 灯泡 220v   1 '),(23966,797459869001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','dmidon','vizexpo@gmail.com','DMITRII DONOV','Komsomolskaya Street house 12 apartment 54','Yekaterinburg','Sverdlovskaya region','RUSSIAN FEDERATION','620066','+7 952 725 1918','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 03:05:26',0,NULL,3,1,3,1,'RA184519988CN ','hermeshine\r没发货，客户问，\r我改了状态\r输了个单号进去。\r2.15  冯'),(23967,8881329192111622,111,'4螺丝井字扳手',1,'',0,'hermeshine','suwen','suwen.chee@gmail.com','Suwen Chee','C-10-1, Megan Avenue II<br>12 Jalan Yap Kwan Seng','Kuala Lumpur','','MALAYSIA','50450','0192666910',NULL,NULL,NULL,'2012-02-14 04:01:51',0,NULL,3,0,25,1,'RT127680772HK','仔细检查一下 '),(23968,797481584001,110541876049,'Photography Telescopic Background Backdrop Cross Bar 3m',1,'AO0012',35.99,'hermeshine','stan2ugt','stan_davis@comcast.net','Stan Davis','415 Avenida Arboles','San Jose','CA','UNITED STATES','95123-1410','(408) 431-0461','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-14 04:34:46',0,NULL,3,1,3,1,'RA184594771CN ','hermeshine\r2节'),(23969,841883277002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','olivierortiz','olivier_ortiz@hotmail.com','olivier lavigne ortiz','16 rue nobel','Sainte-Catherine-de-la-Jacques-Quartier','QC','CANADA','g3n 0n5','(438) 238-2510','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 04:51:14',0,NULL,8,1,17,0,NULL,'hermeshine'),(23970,797484751001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','olivierortiz','olivier_ortiz@hotmail.com','olivier lavigne ortiz','16 rue nobel','Sainte-Catherine-de-la-Jacques-Quartier','QC','CANADA','g3n 0n5','(438) 238-2510','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 04:51:14',0,NULL,3,1,3,1,'RA184508013CN ','hermeshine\r伞式柔光箱 60×90cm   1\r灯架  2m   1'),(23971,797490291001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','luche03','luchipher@live.com','Preecha Suriyamanee','107 , 107-121 <br>Quay Street','Hey Maket','New South Wales','AUSTRALIA','2000','0411368695','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 05:20:06',0,NULL,3,1,17,0,NULL,'hermeshine'),(23972,626382245004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','luche03','luchipher@live.com','Preecha Suriyamanee','107 , 107-121 <br>Quay Street','Hey Maket','New South Wales','AUSTRALIA','2000','0411368695','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 05:26:03',0,NULL,3,1,11,1,'BJ01714469\r ','hermeshine\r无牌方镜 ND4   1\r无牌方镜 渐变灰 （nd4）  1'),(23973,797510537001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.25,'hermeshine','alintay5','alintay@yahoo.com','Alice Lin','401 Sargent St','San Francisco','CA','UNITED STATES','94132-3151','(415) 586-4523','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-14 07:19:53',0,NULL,3,1,17,0,NULL,'hermeshine'),(23974,863779317017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',2,'AO0005',32.28,'photographyacc','miskovci84','kockyxxx@azet.sk','michal koczkas','536 ABITO, 4 clipers quay<br>Salford quays','Manchester','Greater Manchester','UNITED KINGDOM','M503BP','07578113280','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 07:42:30',0,NULL,3,0,3,1,'RA184529340CN\r ','photographyacc\r1.6x3m  白+黑'),(23975,841910503002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','alintay5','alintay@yahoo.com','Alice Lin','401 Sargent St','San Francisco','CA','UNITED STATES','94132-3151','(415) 586-4523','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 07:19:52',0,NULL,3,1,3,1,' RA184523174CN','hermeshine\r绿叶 UV  55mm      1\r2B柔     1'),(23976,797518017001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','shamannet','pathfindervg@gmail.com','Василий Александрович Гнеушев','Крылова, 33','Кузнецк','Пензенская область','RUSSIAN FEDERATION','442537','(7-927) 648-45-61','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 08:00:46',0,NULL,3,1,3,1,'RA184519943CN ','hermeshine'),(23977,803582942018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','capga','capgaphotography@bigpond.com','CHERYL GREGSON','19 ALLAOPS RD','LAUNCHING PLACE','Victoria','AUSTRALIA','3139','0359646509','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 08:09:37',0,NULL,3,0,11,1,NULL,'photographyacc\r白色'),(23978,797520891001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','lecongduy1989','lecongduy89@gmail.com','Cong Duy Le','1/15 Wareham St Springvale','Melbourne','Victoria','AUSTRALIA','3171','0435949999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 08:15:27',0,NULL,3,1,2,1,'30121834621\r ','hermeshine'),(23979,946647437015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','5_alf','vitalf@yandex.ru','Vitaly Fedorov','ul. Dimitrova; dom 11; kv. 15','Sankt-Peterburg','RU','RUSSIAN FEDERATION','192284','+7 (904) 515 94 89','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 08:40:45',0,NULL,3,1,3,1,'RR658650757CN\r ','hutongstore'),(23980,841939335002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 09:38:11',0,NULL,3,1,17,0,NULL,'hermeshine'),(23981,797539181001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 09:38:10',0,NULL,3,1,17,0,NULL,'hermeshine'),(23982,797539180001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 09:38:10',0,NULL,3,1,17,0,NULL,'hermeshine'),(23983,797539182001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 09:38:11',0,NULL,3,1,17,0,NULL,'hermeshine'),(23984,841939337002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','c_byn','saint-sage@mail.ru','Alexey Tyurin','Tihvinskij pereulok, 10/12-1-15','Moscow','','RUSSIAN FEDERATION','127055','79262034819','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 09:38:12',0,NULL,3,1,3,1,'RA184507945CN ','hermeshine\r大力夹     1\r大力夹云台      1\r麂皮    2\r2m 弹簧灯架     1\r肥皂盒 柔光罩   580EX     1'),(23985,803606188018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',94.05,'photographyacc','profo33','pjphotography1@live.com','Peter James','1 orrong place<br>craigieburn','melbourne','Victoria','AUSTRALIA','3064','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-02-14 09:44:56',0,NULL,3,1,4,1,'YW868897683CN ','photographyacc\r换弹簧灯架'),(23986,803616454018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',28.49,'photographyacc','boppg123','bopp-limburg@t-online.de','Hans Georg Bopp','Hydrotechnik GmbH<br>Holzheimerstr. 94...96','Limburg','','GERMANY','65549','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 10:24:42',0,NULL,3,0,3,1,'RR658650726CN\r ','photographyacc\rXXL  已入库'),(23987,841953192002,120754977662,'2400w Red Head Continuous Light Kit 800w x 3 bulb x 6',1,'AKT072',278,'hermeshine','goldenbay01','goldenbay01@hotmail.com','EDWARD ZHENSHENG LEE','12/124 GURNEY ROAD','CHESTER HILL','New South Wales','AUSTRALIA','2162','0287108904','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 10:36:07',0,NULL,3,1,4,1,'YW868897694CN ','hermeshine\r转澳标（用大的那种转换头）'),(23988,803616229018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',4.29,'photographyacc','randalla0','swainra@internode.on.net','Randall Swain','37A Morris Circuit','Thornlands','Queensland','AUSTRALIA','4164','0732864328','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-14 10:24:19',0,NULL,3,1,2,1,'30121833372\r ','photographyacc'),(23989,841958011002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','kastorhagen2012','krs@krs-srk.com','Kai Rune Storhagen','Grottenveien 10 B','Oslo','Oslo','NORWAY','1177',' 94435731','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 10:53:52',0,NULL,3,1,3,1,'RA184523214CN ','hermeshine'),(23990,946708550015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','aktbladet2020','aktbladet@gmail.com','Kai Pedersen','Banevej 22','Sorø','','DENMARK','4180','20408057','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 11:52:04',0,NULL,3,1,11,1,NULL,'hutongstore'),(23991,841999020002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','vdfotografia','prochico@hotmail.com','Victor Francisco D\'Alcantara','Rua Bernardino dos Santos ,93','Porto Alegre','Rio Grande Do Sul','BRAZIL','91720-220','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 13:20:32',0,NULL,3,1,3,1,'RR658650672CN\r ','hermeshine'),(23992,842002460002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',2,'AKT040',149.8,'hermeshine','altegeorge','george.giban@gmail.com','Gheorghe Giban','l\'Arzillier 51','Vufflens-la-Ville','','SWITZERLAND','1302','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-14 13:33:06',0,NULL,3,1,5,1,'CP243056237CN ','hermeshine\r欧标'),(23993,797619458001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','greppgunnar','gunnargren@hotmail.com','Jonas Gunnarsson','Skravelsjövägen 18B','Umea','Sweden','SWEDEN','90440','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 14:30:15',0,NULL,3,1,3,1,'RA184529438CN\r ','hermeshine'),(23994,927080512016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','iamtim2','timoatley@gmail.com','Tim Oatley','47 Swans Reach','Falmouth','Cornwall','UNITED KINGDOM','TR11 5GG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 14:49:10',0,NULL,3,1,17,0,NULL,'hutongstore'),(23995,927087965016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','iamtim2','timoatley@gmail.com','Tim Oatley','47 Swans Reach','Falmouth','Cornwall','UNITED KINGDOM','TR11 5GG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 15:05:48',0,NULL,3,1,3,1,'RA184524223CN\r ','hutongstore\r新款大力夹（手柄）  1\r闪光的柔光箱   60cm    1\r'),(23996,842041913002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','niservic','niservic@mail.ru','Sergey Nizovtsev','Vokzalnaya ul., dom 25, kv.3','Irkutsk ,','Irkutskaya obl','RUSSIAN FEDERATION','664013','+73952636528','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 15:25:05',0,NULL,3,1,3,1,'RA184538559CN\r ','hermeshine'),(23997,946808573015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','endrominado','marctoin@gmail.com','Helena Cabrita','Rua de Damao n 32, 9E','Setúbal','Setúbal','PORTUGAL','2900-340','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 15:53:28',0,NULL,3,1,11,1,NULL,'hutongstore'),(23998,797651697001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','ainis10','ainoras.v@gmail.com','Ainoras Vaskys','Kudirkos 51','Prienai','','LITHUANIA','59113','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 16:03:03',0,NULL,3,1,3,1,'RA184538545CN\r ','hermeshine'),(23999,946833663015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',6.9,'hutongstore','cpor7865','cporritt@sherlingsteeluk.com','Clive Porritt','61 Northfield Place<br>Rothwell','Leeds','West Yorkshire','UNITED KINGDOM','LS26 0SL','07770845233','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 16:43:04',0,NULL,3,1,11,1,NULL,'hutongstore\r英标'),(24000,797686933001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',2,'AD1206',84,'hermeshine','mpcmike1981','mpcverkruyse@mchsi.com','Michael Verkruyse','PO Box 927<br>419 E. Main','Mahomet','IL','UNITED STATES','61853-0927','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 17:27:36',0,NULL,3,1,4,1,'YW868897705CN ','hermeshine'),(24001,946864369015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','ruperjm','rubenjim@gmail.com','La Fábrica de Experiencias S.L.','CIF ESB85793891<br>Castilla 44','Las Matas','Madrid','SPAIN','28290','918501136','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-02-14 17:43:45',0,NULL,5,1,12,1,'3125518303\r ','hutongstore\r欧标\r泡重15.1\r\r15\r已发货.............'),(24002,797695175001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','mgua6854','mario.guay@umontreal.ca','Mario Guay','16545, Avenue Guy','St-Hyacinthe','QC','CANADA','J2R 1V6','(450) 799-4861','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 17:47:07',0,NULL,3,1,2,1,'30121834455\r ','hermeshine'),(24003,842144068002,120459833952,'New Flash Softbox Diffuser for external flash LargeSize',1,'AB3302',14.99,'hermeshine','alant168','jalant@telus.net','Alan Tong','625B Belmont Street','New Westminster','BC','CANADA','V3M 5Z8','(604) 777-8880','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 19:10:59',0,NULL,3,1,11,1,NULL,'hermeshine\r申报gift低值'),(24004,842154712002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','deymosd','gordan.gledec@fer.hr','Gordan Gledec','Vladimira Ruzdjaka 9','Zagreb','Croatia','CROATIA','HR10000','+385992513689','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 19:30:34',0,NULL,3,1,3,1,'RR658650669CN\r ','hermeshine'),(24005,927247762016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.4,'hutongstore','oli17182009','oli1718@live.co.uk','OLIVER BENT','4 GROVE END<br>SOUTH WOODFORD','LONDON','Essex','UNITED KINGDOM','E18 2LE','07889068832','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-14 19:51:15',0,NULL,3,1,2,1,'30121834606\r ','hutongstore'),(24006,797788149001,110477082535,'YN Flash Battery Pack SF-18 Canon Flash 580EXII CP-E4',3,'AB3307',149.97,'hermeshine','angeltoncp1','angeltonalencar@gmail.com','Angelton Freire de Alencar','CaixaPostal 42<br>Centro','Cuiaba','Mato Grosso','BRAZIL','78005-970','6599496565','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-14 20:48:29',0,NULL,3,1,3,1,'RA184529398CN\r ','hermeshine\r国内挂号110\r香港挂号107'),(24007,797790793001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','rockcity54','stig.jarle.hauko@ntebb.no','Stig Jarle Haukø','Guldalveien 9','Namsos','','NORWAY','N-7800','+4790501469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 20:52:41',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1   黑色'),(24008,626602477004,140628962835,'New Arrival Fancier Professional Tripod WT-6714 with Damped Pan Head  w/ Case',1,'AD1196',65,'hermeshine','tuffnutz1022','tbogaert22@gmail.com','TOM BOGAERT','925 SHERMAN PL','UTICA','NY','UNITED STATES','13502-5321','(315) 281-9051','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-14 20:58:15',0,NULL,3,1,4,1,'YW868897716CN ','hermeshine'),(24009,864098051017,270742432772,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.9,'photographyacc','tag.line','shaun2harrison@hotmail.com','Shaun Harrison','97 Stanstead Road','Hoddesdon','Hertfordshire','UNITED KINGDOM','EN11 0QA','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-14 20:59:58',0,NULL,3,1,2,1,'30121820186\r ','photographyacc'),(24010,842204135002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','novacurtis','canderson@ieee.org','Curtis Anderson','Nexteq Navigation<br>Suite 204, 3016-19 Street NE','Calgary','AB','CANADA','T2E 6Y9','(403) 250-8186','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 21:05:42',0,NULL,3,1,3,1,'RR658650615CN\r ','hermeshine'),(24011,947001426015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','linas565','linas@paintbaleris.lt','Linas NAVARDAUSKAS','TAIKOS pr. 84-54','Kaunas','LITHUANIA','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 21:05:25',0,NULL,8,1,17,0,NULL,'hutongstore\r'),(24012,797834582001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','alex.chehlov','yellowcat@ua.fm','Alexandr Chehlov','Gvardeytsev Shironintsev 26 b, 126','Kharkov','','UKRAINE','61120','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 22:32:40',0,NULL,3,1,21,1,'RA184523523CN ','hermeshine\r欧标\r还有其他东西，\r发账单了，没付款\r如果加其他的，可能sal挂号便宜一些'),(24013,797837898001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','fpycjibay','legibe@legibe.com','Jean-Baptiste Debauche','1, rue Maurice Muller','Bischheim','Alsace','FRANCE','67800','0689739488','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-14 22:41:53',0,NULL,3,1,3,1,'RA184525855CN ','hermeshine'),(24014,927382241016,260751540435,'77mm Snap-on Front Cap for Canon 77mm Filters Lens New',1,'AA1304',1.87,'hutongstore','amam3436','jolantaspustek@gmail.com','Artur Mamelko','10 Royal Terrace East<br>Dun Laoghaire','Dublin','Dublin','IRELAND','Co','0872978215','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-14 23:55:48',0,NULL,3,1,11,1,NULL,'hutongstore'),(24015,797492649001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','ryanmcc281','ryan281@iprimus.com.au','Ryan McCulloch','2/42 Spinaker Quays<br>Mandurah','Mandurah','Western Australia','AUSTRALIA','6210','61406511521','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 00:15:14',0,NULL,3,1,11,1,NULL,'hermeshine'),(24016,947114942015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','tarmacsun','rhfhernandez@gmail.com','Ricardo Hernandez','Rua Pedro Alvares Cabral, nº 9<br>Urb. Quinta do Vale - S. Romão','Mealhada','Aveiro','PORTUGAL','3050 010','+351962395949','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 01:12:12',0,NULL,3,1,3,1,'RR658650624CN\r ','hutongstore'),(24017,947123915015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','jlpoletti','jabespoletti@terra.com.br','Jabes Levi Poletti','Rua 8A nº 828 - Vila Nova','Rio Claro','São Paulo','BRAZIL','13506544','(55-19) 3524-1208','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 01:38:41',0,NULL,3,1,3,1,'RR658650686CN\r ','hutongstore\r算一下是否还是香港小包挂号便宜？\r国内挂号54\r香港挂号59'),(24018,947132606015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','traceyshearman','tracey@foldingslidingdoors.com','Tracey Shearman','17 Western Place<br>Queensbury','Bradford','West Yorkshire','UNITED KINGDOM','BD13 1DU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-15 02:03:59',0,NULL,3,0,3,1,'RA184538562CN\r ','hutongstore\rL  已入库'),(24019,797899865001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',2,'AC2301',12.42,'hermeshine','ty-creek','tycreek@tycreek.com','Rod Kost','9014 W Halstead Dr','Boise','ID','UNITED STATES','83704-6831','(208) 484-2268','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-15 02:10:15',0,NULL,3,1,1,1,'LK193095054CN\r ','hermeshine'),(24020,8881329274024174,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included Wholesale/ Retail ',1,'AC2402',23.99,'aliexpress','1006773431 ','h2005@inbox.ru','Oleg Ananin','ul. Kudrjashova, dom 106, kv 61','Ivanovo','Ivanovskaja oblast','RUSSIAN FEDERATION','153038','79203444445',NULL,NULL,NULL,'2012-02-15 02:47:04',0,NULL,3,1,3,1,'RA184529455CN\r ',NULL),(24021,8881329274254999,111,'x1 Tungsten bulb 800W 220V 3200K for redhead light - Whole sale/ Retail ',1,'AO0015',6.99,'aliexpress','1006772923 ','123@hotmail.com','Jose Manuel Requena Plens','Avda. Adolfo Munoz Alonso 10, bajo','Alicante','Alicante','SPAIN','03005','0034691115015',NULL,NULL,NULL,'2012-02-15 02:50:54',0,NULL,3,1,17,0,NULL,NULL),(24022,8881329274451800,111,'New Photo Studio Light Stand Umbrella Flash B-Mount set -Wholesale/ Retail ',1,'AKT014',42.99,'aliexpress','1006772924 ','123@hotmail.com','Jose Manuel Requena Plens','Avda. Adolfo Munoz Alonso 10, bajo','Alicante','Alicante','SPAIN','03005','0034691115015',NULL,NULL,NULL,'2012-02-15 02:54:11',0,NULL,3,1,17,0,NULL,'\r'),(24023,8881329274619959,111,'x4 115W 220V 5500K Studio Light Bulb Daylight with E27 Socket ',2,'AKT069',119.98,'aliexpress','1006772925','123@hotmail.com','Jose Manuel Requena Plens','Avda. Adolfo Munoz Alonso 10, bajo','Alicante','Alicante','SPAIN','03005','0034691115015',NULL,NULL,NULL,'2012-02-15 02:56:59',0,NULL,3,1,17,0,NULL,NULL),(24024,797883725001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','petrovich24','ram3ay@gmail.com','Alexander Tanasiychuk','Borisevich<br>13 -101','Krasnoyarsk','','RUSSIAN FEDERATION','660124','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 02:57:24',0,NULL,3,1,3,1,'RA184525780CN ','hermeshine\r4个'),(24025,8881329274703049,111,'Free shipping & Tracking # - 1600w Photo Studio Bulb Continuous Lighting Kit NEW - Wholesale/Retail ',1,'AKT039',167.99,'aliexpress','1006772926 ','123@hotmail.com','Jose Manuel Requena Plens','Avda. Adolfo Munoz Alonso 10, bajo','Alicante','Alicante','SPAIN','03005','0034691115015',NULL,NULL,NULL,'2012-02-15 02:58:23',0,NULL,3,1,4,1,'YW868897720CN ','除了C以外再发\r800w  220v 灯泡   1 \r115w 5500k 灯泡  220v   8\r灯架  2m    1\r闪光灯B座   1\r柔光伞    1 \r欧标'),(24026,8881329275340034,111,'Free shipping & Tracking # - New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite - Whole/Retail ',2,'AD1198',65.98,'aliexpress','1006759176 ','marcoacbotelho@hotmail.com','Marco Aurelio Botelho','Joaquim Goncalves Pimenta, 470 casa 5 Camargos','Belo Horizonte','Minas Gerais','BRAZIL','30520450','+55 31 3333-1560',NULL,NULL,NULL,'2012-02-15 03:09:00',0,NULL,8,1,17,0,NULL,NULL),(24027,8881329275440683,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail ',1,'AB3329',48.99,'aliexpress','1006759177','marcoacbotelho@hotmail.com','Marco Aurelio Botelho','Joaquim Goncalves Pimenta, 470 casa 5 Camargos','Belo Horizonte','Minas Gerais','BRAZIL','30520450','+55 31 3333-1560',NULL,NULL,NULL,'2012-02-15 03:10:40',0,NULL,3,1,5,1,' CP243056245CN','伞式柔光箱 80cm 8角    2 \r闪光的柔光箱   60cm  1'),(24161,798804316001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','mbsfotografo','marcossilva59@gmail.com','Marcos batista da silva','QE 13 Conjunto E casa 54<br>Guara 2','Brasilia','Distrito Federal','BRAZIL','71050-050','6138791854','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 01:19:20',0,NULL,3,1,25,1,'RT127870309HK\r ','hermeshine'),(24052,842499620002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mandariiinka','sojakru@seznam.cz','Rudolf Soják','17. listopadu 584 - Blok B','Liberec 15','Czech Republic','CZECH REPUBLIC','46015','00420773657783','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 14:39:56',0,NULL,3,1,3,1,'RA184594808CN\r ','hermeshine'),(24037,804072010018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','bowley5','mark151189@hotmail.com','mark bowley','9 obrien street<br>davoren park','adelaide','South Australia','AUSTRALIA','5113','0421449675','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 08:04:54',0,NULL,3,0,11,1,NULL,'photographyacc\r白色'),(24028,8881329279448797,111,'Free shipping & Tracking # - New 77mm Fader ND Neutral Density filter ND2 to ND400 ',1,'AD1143',32.99,'aliexpress','1006779639','qqs644md@solid.ocn.ne.jp','Takashi Kitabatake','akatutumi4-19-8 bonelfakatutumi#111','setagaya','tokyo','JAPAN','1560044','+090 4433 6408',NULL,NULL,NULL,'2012-02-15 04:17:28',0,NULL,3,1,3,1,'RA184529441CN\r ',NULL),(24029,804028879018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','scottbotdot','burntcitizen@iprimus.com.au','Scott Gelston','1 Milles St','Mowbray','Tasmania','AUSTRALIA','7248','0363266275','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 04:22:49',0,NULL,3,1,3,1,'RA184529375CN\r ','photographyacc'),(24030,842340752002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','driatma0712','dbs0712@gmail.com','Adri Riviadhi','PT. Boral Indonesia, Graha Mobisel 3rd Floor<br>Jl. Buncit Raya No. 139','Jakarta','DKI Jakarta','INDONESIA','12740','62 21 - 95113359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 03:53:16',0,NULL,3,1,3,1,NULL,'hermeshine\rM'),(24031,804034740018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','mikeyvbroadrick','kane.broadrick@hotmail.com','kane broadrick','10 malindi pl','giralang','Australian Capital Territory','AUSTRALIA','2617','0262417064','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 04:49:20',0,NULL,3,0,11,1,NULL,'photographyacc\r1.6*2.1   白色'),(24032,8881329281640075,111,'115w 5500k 灯泡  220v',1,'',0,'hutongstore','laelia_milleri','electrina@gmail.com','Patrycja Wawrzynkiewicz','1 The Covert, Woodfarmacres<br>Palmerstown','Dublin','Dublin','IRELAND','D20','0862218750',NULL,NULL,NULL,'2012-02-15 04:54:00',0,NULL,3,0,3,1,'RA184529407CN\r ','已入库 '),(24033,797943015001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','dr_erni','ernest.barbaric@gmail.com','Ernest Barbaric','1243 Mackid Rd NE','Calgary','AB','CANADA','T2E6A8','(403) 561-8363','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 05:17:56',0,NULL,3,1,3,1,'RA184529217CN\r ','hermeshine'),(24034,797947352001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','johnnyb14','ballinger14@yahoo.com.au','John Ballinger','14 Arunga Drive','Wonga Park','Victoria','AUSTRALIA','3115','0397221624','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 05:30:54',0,NULL,3,1,11,1,NULL,'hermeshine'),(24035,797960818001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','longy9010','longy79@gmail.com','Gareth Long','PO BOX 661','Eltham','Victoria','AUSTRALIA','3095','0477282660','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 06:53:20',0,NULL,3,1,11,1,NULL,'hermeshine'),(24036,797972654001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','bart8119331','yichenyue@hotmail.com','YiChen Yue','825 Rue Beauregard Apt.717','Quebec','QC','CANADA','G1V 4L7','(819) 580-0550','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 07:55:33',0,NULL,3,1,3,1,'RA184529384CN\r ','hermeshine'),(24038,842397982002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mandrivkin','mandrivko@gmail.com','Max Savenko','A.Barbusa 56, kv 50,','Kiev','','UKRAINE','03150','+380932927202','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 08:44:07',0,NULL,3,1,3,1,'RR658650712CN\r ','hermeshine'),(24039,864323590017,270751579144,'New Camera Bag Cover for Canon 550D/600D 18-135/18-200',1,'AD1162',9,'photographyacc','kempisty1','kempisty1@wp.pl','damian kempka','169a Mitcham Road','london','London','UNITED KINGDOM','Sw17 9PG','07535683102','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 09:23:29',0,NULL,3,1,11,1,NULL,'photographyacc'),(24040,8881329298143736,111,'橡胶遮光罩 77mm',1,'',0,'hutongstore','il-lostia','il.lostia@gmail.com','Alexey M.','Automation Technologies UNIT 1140<br>KBIC Kordin Industrial Estate','Paola','','MALTA','PLA3000','',NULL,NULL,NULL,'2012-02-15 09:29:03',0,NULL,3,1,3,1,'RA184519912CN',' 已入库\r检查一下是否可以停在3个高度\r'),(24041,864329999017,270855429736,'New Studio Light 2300W Continuous Lighting Kit with background backdrop support',1,'AKT041',178,'photographyacc','jmck6016','northshorejames@hotmail.com','james Mckinnon','1311 / 77 Berry Street (Beaumonde Apartments)<br>North Sydney','Sydney','New South Wales','AUSTRALIA','2060','020419227847','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-15 09:46:46',0,NULL,3,1,4,1,'YW868897731CN ','photographyacc\r澳标\r黑色布两块\r'),(24042,842422181002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','beachbuddy1303','builtfornic@xtra.co.nz','Greg Denby','113B Bethlehem Road','Tauranga','','NEW ZEALAND','3110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 10:23:07',0,NULL,3,1,2,1,'30121833825\r ','hermeshine'),(24043,798018356001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','gedixss','gediss@gmail.com','Gediminas Saržickas','Gedvydžių<br>12-60','Vilnius','Vilnius','LITHUANIA','06303','+37067251755','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 11:07:27',0,NULL,3,1,11,1,' ','hermeshine'),(24044,804127095018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','mark_s_reeves','marksreeves@gmail.com','Mark Reeves','16 Combermere Street','Goulburn','New South Wales','AUSTRALIA','2580','0421000675','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 11:33:14',0,NULL,3,1,4,1,'YW868897075CN','photographyacc'),(24045,842441122002,120448751271,'Remote Shutter Release for SONY A100 A200 A900 =RM-S1AM',1,'AA3212',4.45,'hermeshine','dolors33','xinxo@wanadoo.es','Dolors Rius','A. Forrellad, 28','Sabadell','Cataluña','SPAIN','08208','662208333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 11:38:05',0,NULL,3,1,11,1,NULL,'hermeshine'),(24046,842458032002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','geliosso','geliostan@gmail.com','Alexander Trukhan','Gamarnika str., 1 - 44','Minsk','BLR','BELARUS','220090','+375296289982','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 12:31:41',0,NULL,3,1,3,1,'RA184524325CN\r ','hermeshine'),(24047,798043955001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',1,'AA1308',2.6,'hermeshine','testeqseller','dick_craig36@yahoo.com','David Pawlak','1531 Wedgewood Pl','Essexville','MI','UNITED STATES','48732-3203','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 12:43:55',0,NULL,3,1,1,1,'LK193415014CN\r ','hermeshine'),(24048,842464914002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',54,'hermeshine','budavvvladimir','budavv@mail.ru','Vladimir Budantsev','Severnaya 11/1-116','Nizhnevartovsk','Tyumenskaya','RUSSIAN FEDERATION','628616','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 12:56:49',0,NULL,3,0,3,1,'RA184529296CN\r ','hermeshine\r1.6X3m   3\r黑， 绿， 灰'),(24049,804157429018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',29.99,'photographyacc','roberto_domingo','roberto@discomovil.es','Roberto Domingo / ADM Comunicacion','Azagador de la Torre, 71<br>P.I. Horno de Alcedo','Valencia','Comunidad Valenciana','SPAIN','46026','630078746','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 13:11:45',0,NULL,3,0,3,1,'RA184519930CN ','photographyacc\rXXXL  ( 已入库）'),(24050,842478721002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','amptc','maybormann@yahoo.com.au','May Bormann','916 Milendella Rd','Sanderston','South Australia','AUSTRALIA','5237','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 13:41:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(24051,842484715002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',25,'hermeshine','kandis8846','klannigan01@hotmail.ca','Kandis Lannigan','251 St. Mary\'s Road','Montague','PE','CANADA','C0A 1R0','(902) 962-2697','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 13:55:08',0,NULL,3,1,3,1,'RA184594799CN ','hermeshine'),(24053,842416595002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',2,'AA1310',10.98,'hermeshine','big_jeka','yevgen@vynnyk.com','Yevgen Vynnyk','Mikoyana str. 14 / 59<br>Mikoyana str. 14 / 59','Zaporozhye','Zaporizkaja','UKRAINE','69120','00380503415966','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 14:44:03',0,NULL,3,1,11,1,NULL,'hermeshine'),(24054,798086313001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','etel-film','enyedi.lajos@yahoo.com','Lajos Enyedi','Hargita u.12','Dunakeszi','alapértelmezés','HUNGARY','2120','36209443793','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 14:55:19',0,NULL,3,1,3,1,'RA184525820CN ','hermeshine'),(24055,798094568001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','benoname','urbana_100x100@hotmail.com','sara centeno suarez','c/ Hacienda de Pavones,31  2ºC','Madrid (ESPAÑA)','Madrid','SPAIN','28030','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 15:16:00',0,NULL,3,1,3,1,'RA184594710CN\r ','hermeshine'),(24056,798101476001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','whatawatch','gavrielisra1@gmail.com','Israel Gavrilov','Haim Huri 21','Lod','','ISRAEL','71282','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 15:36:23',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24057,842523503002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','stalker792','k_photo@fromru.com','Konstantin Eskin','Suvorova street 5-43','Novokuznetsk','Kemerovskaya region','RUSSIAN FEDERATION','654027','+7-923-623-53-43','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 15:41:41',0,NULL,3,1,3,1,'RA184523302CN ','hermeshine'),(24058,626829039004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','fnogueira00','maisumpralista@hotmail.com','Filipe Nogueira','Fua Firmino Rebelo, nº9 R/C Direito','Porto Salvo','Oeiras','PORTUGAL','2740-062','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 15:43:33',0,NULL,3,1,11,1,NULL,'hermeshine'),(24059,927694570016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','dod0872','marcusdodridge@hotmail.com','Marcus Dodridge','6 Lutener Road,Easebourne','Midhurst','West Sussex','UNITED KINGDOM','GU299AT','01730813070','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-15 15:46:56',0,NULL,3,1,4,1,'YW868897742CN ','hutongstore\r英标\r如果有弹簧灯架就换，没有就算了'),(24060,800335396018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',2,'AO0005',20.88,'photographyacc','drdj2005','drohare@iinet.net.au','Rebecca O\'Hare','6 Lundie Street','Bungendore','New South Wales','AUSTRALIA','2621','0467552130','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-15 15:49:09',0,NULL,3,0,3,1,'RA184529305CN\r ','photographyacc\r1.6*2.1   白  黑'),(24061,947421998015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','sophums2010','kimbo417@btinternet.com','kimberly rosie','37 argyle square','wick','Highland','UNITED KINGDOM','kw1 5aj','01955602457','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-15 16:25:50',0,NULL,3,0,11,1,NULL,'hutongstore\r1.6*2.1  黑色'),(24062,842543629002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','kevint2628','kevintregunna@hotmail.com','Kevin Tregunna','23 Leap Park<br>Threemilestone','Truro','Cornwall','UNITED KINGDOM','TR3 6UB','01872270621','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:29:37',0,NULL,3,1,11,1,NULL,'hermeshine'),(24063,798123582001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','knuterik2990','skistad@airfoto.no','Knut Erik Skistad','Soleieveien 8','Hokksund','Buskerud','NORWAY','3300','004793054666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 16:30:45',0,NULL,3,1,3,1,'RA184523157CN\r ','hermeshine\r看看重量'),(24064,798125519001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 16:38:56',0,NULL,3,1,3,1,'RA184594723CN\r ','hermeshine\r国内挂号114.\r香港挂号133.'),(24065,927729725016,260856847288,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',25,'hutongstore','bombelrafal','bombelgarbaciak@gmail.com','Rafal Garbaciak','157 Willow Park<br>tullow road','Carlow','Carlow','IRELAND','default','0857023321','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 16:55:21',0,NULL,3,1,3,1,'RA184594737CN\r ','hutongstore'),(24066,842567647002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','snoopybeau','snoopybeau@yahoo.ca','Lee Marshall','7 Vivaldi Cres','Brampton','ON','CANADA','L6Y 2X3','(905) 450-5097','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 17:23:46',0,NULL,3,1,11,1,NULL,'hermeshine'),(24067,842573919002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',85,'hermeshine','pauljavor','attila@hujman.hu','Attila Hujman','Frankenburg út 14','Sopron','Hungary','HUNGARY','9400',' 06205332292','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 17:36:27',0,NULL,3,1,5,0,' CP243056121CN','hermeshine\r放两个欧标头'),(24068,842578459002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','anchovies8','rodlages@gmail.com','Rodrigo Lages','SGAN 914 Modulo A Bl. B Ap. 223<br>Cond. South Beach - Asa Norte','Brasilia','DF','BRAZIL','70790-140','+55 61 8478-8878','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 17:46:24',0,NULL,3,1,17,0,NULL,'hermeshine'),(24069,842580019002,120440082054,'New Air Dust Blower Cleaner Pump for Lens DSLR Camera',1,'AA1311',4.99,'hermeshine','anchovies8','rodlages@gmail.com','Rodrigo Lages','SGAN 914 Modulo A Bl. B Ap. 223<br>Cond. South Beach - Asa Norte','Brasilia','DF','BRAZIL','70790-140','+55 61 8478-8878','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 17:49:46',0,NULL,3,1,5,0,'CP243056210CN ','hermeshine\r2.4x3m背景架+ 白布   1\r气吹 + 布  1'),(24070,864314993017,270855429736,'New Studio Light 2300W Continuous Lighting Kit with background backdrop support',1,'AKT041',178,'photographyacc','bermabot','smooligan@orcon.net.nz','Bernice Botha','2/73 Stredwick Drive<br>Torbay','North Shore City','Auckland','NEW ZEALAND','0630','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 18:06:16',0,NULL,3,1,6,1,'EE667838764CN ','photographyacc\rc以外，补一共是2块\r1.6*2.1  黑色和白色布\r澳标\r'),(24071,947483564015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','xbody123','mrxbody@gmail.com','Vadim Zaitsev','L. Tolstogo str., 1a, 74','Pushkino','','RUSSIAN FEDERATION','141206','+79037996583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 18:13:03',0,NULL,3,1,3,1,'RA184594745CN\r ','hutongstore'),(24072,804290056018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','bermabot','smooligan@orcon.net.nz','Bernice Botha','2/73 Stredwick Drive<br>Torbay','North Shore City','Auckland','NEW ZEALAND','0630','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 18:23:17',0,NULL,3,0,17,0,NULL,'photographyacc'),(24073,842594621002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ariff_mmc','ariff_mmc@yahoo.com','Ariff Imran','17-B Kampung Hiliran Surau Baru,<br>21000, Kuala Terengganu.','Terengganu','Kuala Terengganu','MALAYSIA','21000','0194294291','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 18:23:22',0,NULL,3,1,11,1,NULL,'hermeshine'),(24074,804315347018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','forestablue','jienajien@onvol.net','Carmel Pisani','94, Santa Rosa Court, Flat 02,<br>Triq il-Fuxa,','San Gwann','','MALTA','SGN1305','(+356)  21384448','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 19:06:55',0,NULL,3,1,11,1,NULL,'photographyacc'),(24075,842619202002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','bollin83','cuuls@hotmail.com','Jan Mattfolk','Skolhusgatan 57-61 A2','Vasa','','FINLAND','65100','+358504012870','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 19:06:59',0,NULL,3,1,24,1,'\\\r ','hermeshine\r50g左右香港小包比国内小包便宜'),(24076,927811494016,260901880779,'Mini IR Wireless Remote Control for Nikon D90 D80 D5000 D40',5,'AD1116',10.9,'hutongstore','petrs4321','freedomphoto@email.cz','Petr Svoboda','Palachova 425/22<br>tel.: 608177730','Poděbrady','-','CZECH REPUBLIC','29001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 19:08:52',0,NULL,3,1,3,1,'RA184594754CN\r ','hutongstore'),(24077,842633891002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','jcondic','josipcondic@yahoo.com','Miranda Cikotic','Dubrovacka 17','Split','','CROATIA','21000','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 19:34:06',0,NULL,3,1,5,1,' CP243056104CN','hermeshine\r欧标'),(24078,798239027001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','littleyogin','omnispark@gmail.com','Yauheni Bolshakov','26 Logoyski trakt st. App. 92.','Minsk','Minsk','BELARUS','220090','375 (29) 860 7119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 20:24:45',0,NULL,3,1,11,1,NULL,'hermeshine\r不要申报成摄影配件或者跟摄影有关的东西'),(24079,798242328001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',3,'AD1220',10.5,'hermeshine','paulo27','paul.skakavy@seznam.cz','Pavel Sikora','Karla Pokorneho 1396/38','Ostrava','','CZECH REPUBLIC','70800','+420776696423','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 20:39:35',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变灰 （nd8）   3'),(24080,927889267016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','krol-rvdw','rudy.vandewalle@telenet.be','Rudy Vandewalle','Noorderveld 21','Sint-Job-in-\'t-Goor','','BELGIUM','2960','0477-572675','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 20:59:38',0,NULL,3,1,3,1,'RR658650933CN\r ','hutongstore'),(24081,797615271001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',19.8,'hermeshine','njmgnaomelembro','norbertogomesdesign@gmail.com','Norberto Joel Martins Gomes','Travessa de Reimonde, nº28<br>Carreira','Barcelos','Minho','PORTUGAL','4775-066','(+351) 911986956','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 21:16:59',0,NULL,3,1,17,0,NULL,'hermeshine'),(24082,947618907015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','furre85','ufos85@gmail.com','Jonas Hansson','Bodekullsgatan 34 A','Malmö','Skåne','SWEDEN','214 40','0708511622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-15 21:28:44',0,NULL,3,1,3,1,'RR658650607CN\r ','hutongstore'),(24083,842697800002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','marcelo2010dom','mastronellima@yahoo.com','Marcelo Lima','189 Lincoln St<br># 2','Revere','MA','UNITED STATES','02151-5711','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-15 21:33:43',0,NULL,3,1,3,1,'RA184523165CN ','hermeshine'),(24084,804406759018,280680231232,'Neoprene Camera Cover Case for small Nikon & semi slr S',1,'AC2302',5.9,'photographyacc','werethefoxhat','steve959vwb@hotmail.com','Stephen Ayton','36 Humbie Terrace<br>Aberdour','Burntisland','Fife','UNITED KINGDOM','KY3 0XP','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-15 21:48:24',0,NULL,3,1,11,1,NULL,'photographyacc'),(24085,842636346002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','njmgnaomelembro','norbertogomesdesign@gmail.com','Norberto Joel Martins Gomes','Travessa de Reimonde, nº28<br>Carreira','Barcelos','Minho','PORTUGAL','4775-066','(+351) 911986956','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 21:16:58',0,NULL,3,1,3,1,'RA184524311CN\r ','hermeshine\r肥皂盒 柔光罩  430EX  1\r闪光灯B座   1\r反光伞 83cm   1\r2B柔   1\r称一下重量，重新算运费'),(24086,842716142002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','rbulletoe','raybulatao@gmail.com','Raymond Bulatao','3535- 106A Street NW','Edmonton','AB','CANADA','T6J1A7','(780) 935-7178','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-15 22:14:12',0,NULL,3,1,3,1,'RR658650655CN\r ','hermeshine\r2云柔'),(24087,798293219001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','ministryofminifigs','ctbrophy087867@gmail.com','Chris Brophy','22 St Aubyn Square','Moonah','Tasmania','AUSTRALIA','7009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 22:15:53',0,NULL,5,1,11,1,NULL,'hermeshine\r不确定发没发  就当发了，点不了已发货'),(24088,798295465001,110565908228,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',82,'hermeshine','magellanvoile','denys@pixelcreation.ch','Denys Jaquet','Grand rue 39','Rolle','Vaud','SWITZERLAND','1180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 22:22:07',0,NULL,3,1,17,0,NULL,'hermeshine'),(24089,798295314001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','magellanvoile','denys@pixelcreation.ch','Denys Jaquet','Grand rue 39','Rolle','Vaud','SWITZERLAND','1180','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 22:22:07',0,NULL,3,0,5,0,'CP243056095CN ','hermeshine\rWT600   1\r1.6*2.1  黑色'),(24090,842751041002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','bebas_aja','bebas.aja@gmail.com','David Sudjono','Taman Cibaduyut Indah A-132','Bandung','Jawa Barat','INDONESIA','40239','62 81322355558','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-15 23:50:39',0,NULL,3,1,2,1,'30121832403\r ','hermeshine'),(24091,947717594015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','minaya76','jcgrandecasas@gmail.com','Juan Carlos Grande Casas','C/ Carros, 8, bajo','Minaya (Albacete)','Castilla-La Mancha','SPAIN','02620','653879071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 01:06:06',0,NULL,3,1,3,1,'RA184523276CN ','hutongstore\reBay需要调价格'),(24092,928006912016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','rem0ter_ru','erik.russia@mail.ru','Ernest Malyushin','Karl Marks 417 - 12','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426000','+7 904 839 5000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 01:18:02',0,NULL,3,1,11,1,NULL,'hutongstore'),(24093,798353109001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','boffin766','ian.eadie@gmail.com','Ian Eadie c/- O-I GOSC','Building 2<br>310 Ferntree Gully Road','North Clayton','Victoria','AUSTRALIA','3168','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 01:31:10',0,NULL,3,1,2,1,'30121832930\r ','hermeshine'),(24094,798362813001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',59.98,'hermeshine','wmphotostudio','wagnermenezesfotografo@gmail.com','Wagner Tadeu Menezes','Rua: Demétrio Ghirardello, 249<br>Jardim Las Vegas','Santo andré','São Paulo','BRAZIL','09182-520','0551149723715','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 02:04:57',0,NULL,8,1,17,0,NULL,'hermeshine'),(24095,842792843002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','wmphotostudio','wagnermenezesfotografo@gmail.com','Wagner Tadeu Menezes','Rua: Demétrio Ghirardello, 249<br>Jardim Las Vegas','Santo andré','São Paulo','BRAZIL','09182-520','0551149723715','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-16 02:04:56',0,NULL,3,1,17,0,NULL,'hermeshine'),(24096,842792844002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','wmphotostudio','wagnermenezesfotografo@gmail.com','Wagner Tadeu Menezes','Rua: Demétrio Ghirardello, 249<br>Jardim Las Vegas','Santo andré','São Paulo','BRAZIL','09182-520','0551149723715','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 02:04:57',0,NULL,3,1,17,0,NULL,'hermeshine'),(24097,842792845002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','wmphotostudio','wagnermenezesfotografo@gmail.com','Wagner Tadeu Menezes','Rua: Demétrio Ghirardello, 249<br>Jardim Las Vegas','Santo andré','São Paulo','BRAZIL','09182-520','0551149723715','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 02:04:58',0,NULL,3,1,5,1,' CP243056254CN','hermeshine\r反光板支架   2\r反光板 100*150 40*60 5合1  1\r伞式柔光箱 60×90cm   1\r伞式柔光箱 80cm 8角    1\r'),(24098,947741345015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','skatedelicate','mattdelicate@live.co.uk','Matt Delicate','46 Somervell Drive','Fareham','Hampshire','UNITED KINGDOM','PO167QN','01329234688','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 02:14:05',0,NULL,3,1,2,1,'30121825241\r ','hutongstore'),(24099,8881329358455621,111,'10块布',1,'',102,'hermeshine','viktoriavt','viktoria.vt@gmail.com','Viktoria Tumasova','2100 de Maisonneuve West<br>apartment 1110','Montreal, H3H 1K6','','CANADA','1110','',NULL,NULL,NULL,'2012-02-16 02:14:15',0,NULL,3,0,5,1,'CP243056206CN  ','1.6*2.1\r白, 黑, 绿, 灰, 粉, 蓝, 红, 橙, 棕，黄'),(24100,842808787002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','myhotrod9','rlcurry1031@comcast.net','Randy Curry','1823 Anne Ln','Morris','IL','UNITED STATES','60450-2518','(815) 941-2488','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 02:57:55',0,NULL,3,1,3,1,'RA184523231CN ','hermeshine'),(24101,947755822015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','mbsfotografo','marcossilva59@gmail.com','Marcos batista da silva','QE 13 Conjunto E casa 54<br>Guara 2','Brasilia','Distrito Federal','BRAZIL','71050-050','6138791854','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 02:59:14',0,NULL,3,1,25,1,'RT127868225HK\r ','hutongstore\r香港挂号135.\r国内挂号143.\r基本上没有利润，需要加运费'),(24102,8881329361649198,111,'Black/Whilte Reflection board 20X30cm Reflection effect - Wholesale/ Retail ',1,'AB1201',15.99,'aliexpress','1006795479','ninahellesoe@gmail.com','Nina Hellesoe','Fossane 161','Bergen','Nyborg','NORWAY','5132','+0047 45616233',NULL,NULL,NULL,'2012-02-16 03:07:29',0,NULL,8,1,17,0,NULL,NULL),(24103,804511840018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','99shellbell99','bronwen99@bigpond.com','Bronwen Jones','PO Box U227<br>UNE','Armidale','New South Wales','AUSTRALIA','2351','0267735293','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 03:08:38',0,NULL,3,1,3,1,'RA184509005CN\r ','photographyacc'),(24104,8881329361737093,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included - Wholesale/ Retail ',1,'AC2403',33.99,'aliexpress','1006795478','ninahellesoe@gmail.com','Nina Hellesoe','Fossane 161','Bergen','Nyborg','NORWAY','5132','+0047 45616233',NULL,NULL,NULL,'2012-02-16 03:08:57',0,NULL,3,1,3,1,'RR658650567CN\r ','倒影板（白黑）  1 \r圆形柔光棚 60cm   1'),(24105,8881329362025205,111,'Free shipping & Tracking # - New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite - Whole/Retail ',1,'AD1198',32.99,'aliexpress','1006800404','lumem@lumem.ind.br','julio cezar pereira','Rodovia da Uva , 4839 Pq do Embu','Colombo','Parana','BRAZIL','83402000','+55 41 36565385',NULL,NULL,NULL,'2012-02-16 03:13:45',0,NULL,3,1,3,1,'RA184519807CN  ','这个有单号 \rRA184519807CN  '),(24106,8881329365324202,111,'1.6*3  黑色布',1,'',0,'hermeshine','dawidow79','dawidoww@yandex.ru','Aleksey Davidov','Severniy 2-133','Stariy Oskol','Belgorodskaja','RUSSIAN FEDERATION','309516','79803287273',NULL,NULL,NULL,'2012-02-16 04:08:44',0,NULL,3,0,3,1,'RA184519926CN ',NULL),(24107,842835507002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',36.95,'hermeshine','borrimorri','tomozzo94@gmail.com','Thomas Morrison','6 June Street','Morwell','Victoria','AUSTRALIA','3840','0458554340','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 04:40:46',0,NULL,3,1,3,1,'RA184523293CN ','hermeshine'),(24108,947801832015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','diixiirkazan','diixiir@gmail.com','Dmitri Kochnev','Cheluskina street, house (dom) 60, flat (kvartira) 13','Kazan','Tatarstan','RUSSIAN FEDERATION','420037','89625603803','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 05:48:45',0,NULL,3,1,3,1,'RA184538531CN\r ','hutongstore\r45w 5500k 灯泡 220v  3\r两个灯架底座\r一个灯架腿\r一个灯架最上面的配件'),(24109,8881329375459810,111,'摄影背心 黑色厚 无字 2XL',1,'',0,'hermeshine','leandroeiki2011','leandroiwaki@gmail.com','Leandro Eiki Iwaki','av. João Dias 1331<br>apartment 1110','São Paulo','São Paulo','BRAZIL','04723-001','551196888928',NULL,NULL,NULL,'2012-02-16 06:57:39',0,NULL,3,0,3,1,'RA184519838CN ','已入库 \r是xxxl'),(24110,947828552015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','patrmarin','pat.marin@skynet.be','patrick marin','a . demaeghtlaan 173/11','halle','','BELGIUM','1500','0495268753','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 07:45:30',0,NULL,3,1,11,1,NULL,'hutongstore\r欧标\r已发货'),(24111,928115536016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-16 07:57:50',0,NULL,3,1,3,1,'RA184519775CN ','hutongstore\r申报20'),(24112,947847370015,250932248783,'New Studio soft box 28\"x39\"/ 70x100cm Softbox  Universal Metal Mount  for strobe',1,'AD1141',32,'hutongstore','vsbabakhan','vbabakhan@gmail.com','VSEVOLOD BABAKHANOV','Dzerginskogo 15-26','Kokoshkino','Moscow Region','RUSSIAN FEDERATION','143390','903-001-4217','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 08:54:53',0,NULL,3,1,3,1,'RA184519767CN ','hutongstore'),(24113,947849095015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','mrcloneme','hellan22@hotmail.com','Helena Antonsson','Norströmsväg 13','Stockholm','Trångsund','SWEDEN','14260','+46707663677','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 09:02:31',0,NULL,3,1,3,1,'RA184519909CN ','hutongstore\r申报gift'),(24114,842889331002,120841734374,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',13.88,'hermeshine','vs5883152','svadimus73@gmail.com','Вадим Сырчин','ул.Сетевая, д.4, кв.66','Поселок Софрино','Московская область','RUSSIAN FEDERATION','141270','(905) 5883152','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 09:21:11',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24115,798463170001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',9.99,'hermeshine','abzyga','yoy-yoy@yandex.ru','Elvira Rakhmanova','Prospekt Pobedy 176 - 141','Orenburg','Orenburgski','RUSSIAN FEDERATION','460048','+79878560614','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-16 10:04:41',0,NULL,3,1,11,1,' ','hermeshine'),(24116,804604719018,280666851812,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG ',1,'AO0011',82,'photographyacc','zfyre','a-zed@triathlon-link.com','Andrew Zielinski','4 Grant Court','Granton','Tasmania','AUSTRALIA','7030','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-16 10:14:08',0,NULL,3,1,4,1,'yw868897753cn ','photographyacc'),(24118,947884632015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','jahtriguero','jatriguero@terra.es','JOSE ANTONIO HERNANDEZ TRIGUERO','C/ PROGRESO Nº 22','BARCARROTA','Extremadura','SPAIN','06160','655527492','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 10:54:11',0,NULL,3,1,4,1,'YW868897764CN ','hutongstore\r白+黑'),(24119,798483800001,110668199161,'HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',43,'hermeshine','evgcom','evgvideo@yandex.ru','Evgeni Komoniuk','prospekt Gongadze 28, kv. 1','Kiev','Kievskaya oblast','UKRAINE','04215','380965232409','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 11:25:50',0,NULL,3,1,3,1,'RA184519798CN ','hermeshine'),(24120,798500427001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','lisa_a_murphy','steve_p32@hotmail.com','Lisa Murphy','7 elderberry way','Pakenham','Victoria','AUSTRALIA','3810','0432453258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 12:28:28',0,NULL,8,1,17,0,NULL,'hermeshine'),(24121,842937653002,120841733953,'Promotion ! NEW  Square Neutral Density full ND2 Grey Filter for Cokin P Series',1,'AD1221',3.5,'hermeshine','lisa_a_murphy','steve_p32@hotmail.com','Lisa Murphy','7 elderberry way','Pakenham','Victoria','AUSTRALIA','3810','0432453258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 12:29:09',0,NULL,8,1,17,0,NULL,'hermeshine'),(24122,798501042001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','lisa_a_murphy','steve_p32@hotmail.com','Lisa Murphy','7 elderberry way','Pakenham','Victoria','AUSTRALIA','3810','0432453258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 12:30:41',0,NULL,8,1,17,0,NULL,'hermeshine'),(24123,627120384004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','lisa_a_murphy','steve_p32@hotmail.com','Lisa Murphy','7 elderberry way','Pakenham','Victoria','AUSTRALIA','3810','0432453258','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 12:31:29',0,NULL,3,1,3,1,'RA184509141CN\r ','hermeshine\r无牌方镜 渐变灰 （nd8）   1\r无牌方镜 ND2     1\r无牌方镜 ND4      1\r无牌方镜 ND8     1'),(24124,842950572002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454135','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 13:19:34',0,NULL,3,1,3,1,'RR658650598CN\r ','hermeshine'),(24125,842950571002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','galaher57','galaher@inbox.ru','Konstantin Puhov','Kopeyskoe shosse, 47 - 335','Cheljabinsk','Cheljabinskaya obl','RUSSIAN FEDERATION','454135','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 13:19:34',0,NULL,3,1,5,1,' CP243056268CN','hermeshine\r欧标\r\r'),(24126,798532931001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','blenheimgal','dscottwells@hotmail.com','Mr David Wells','78 Coldstream Close<br>Cinnamon Brow','Warrington','Cheshire','UNITED KINGDOM','WA2 0LL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 14:17:46',0,NULL,3,1,17,0,NULL,'hermeshine'),(24127,798532392001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','blenheimgal','dscottwells@hotmail.com','Mr David Wells','78 Coldstream Close<br>Cinnamon Brow','Warrington','Cheshire','UNITED KINGDOM','WA2 0LL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 14:20:01',0,NULL,3,1,11,1,NULL,'hermeshine\r橡胶遮光罩 58mm   1\rEW-73B    1'),(24128,804677132018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','pursuit_ford','dympl3z@hotmail.com','michelle wooltorton','51 sunningdale chase','Mandurah','Western Australia','AUSTRALIA','6210','0417941946','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-16 14:16:28',0,NULL,3,0,11,1,NULL,'photographyacc\r白色'),(24129,798548067001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','copetin2009','rafael-harue@hotmail.com','rafael ribera sikujara','shiratsuka cho 58-7<br>shiratsuka danchi p8 304','Stu shi','Mie','JAPAN','514-0101','81592317707','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 15:01:03',0,NULL,3,1,3,1,'RR658650584CN\r ','hermeshine'),(24130,798565837001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','dw1313','dw1313@gmail.com','David Y. Wang','46580 Hollymead Pl','Potomac Falls','VA','UNITED STATES','20165-6416','(703) 430-4065','NoPaymentFailure','CheckoutComplete','Other','2012-02-16 15:53:01',0,NULL,3,1,1,1,'LK193595789CN\r ','hermeshine'),(24131,798578205001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','chutton2012','yellowboyc.h2007@yahoo.com','Cornelius Hutton','4129 Cedar St','Jackson','MS','UNITED STATES','39206','(601) 564-5388','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 16:24:23',0,NULL,3,0,1,1,'LK193456169CN\r ','hermeshine\r黑色'),(24132,798580166001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','sssm2007','sssm@rambler.ru','Burmatov Denis','Leningradskiy prospekt 4/2 kv.16','Moscow','','RUSSIAN FEDERATION','125040','+79267029022','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-16 16:28:26',0,NULL,3,1,5,1,' CP244674681CN','hermeshine'),(24133,843040550002,120752153194,'Photo Studio Background Support Carrying Carry Bag',1,'AD1129',9.9,'hermeshine','vchuksin','fstereof@gmail.com','Vladimir Chuxin','Stroiteley 38-134','Pereslavl-Zalesskiy','Yaroslavskay','RUSSIAN FEDERATION','152025','+7 915 994 13 53','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 17:18:59',0,NULL,3,1,11,1,NULL,'hermeshine'),(24134,928338697016,260895487153,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',18.7,'hutongstore','vladid1969','vladid@012.net.il','Vladimir Derevyan','Dugit<br>41/2','Dimona','','ISRAEL','86000','050-810-6889','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 17:43:25',0,NULL,3,1,3,1,'RR658650522CN\r ','hutongstore'),(24135,948081070015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2101',25,'hutongstore','bar20ham','barryhamilton2000@yahoo.ie','Barry Hamilton','Glen Oaks, Blessington,Co. Wicklow','Blessington','Wicklow','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 18:21:21',0,NULL,3,0,3,1,'RA184523090CN\r ','hutongstore\r已发信问大小\rXL  已入库'),(24136,798646318001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','luminairefoto','karl@luminairefoto.com','Karl Rouwhorst','3387 Timberwood Cir','Naples','FL','UNITED STATES','34105','(239) 848-8926','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-02-16 18:57:14',0,NULL,3,1,3,1,'RA184519784CN ','hermeshine'),(24137,798658475001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','raff3665','evobob@yahoo.com','ROBERT AFFELDT','9708 hirsch rd','santee','CA','UNITED STATES','92071-1306','(619) 851-7416','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-16 19:18:04',0,NULL,3,1,1,1,'LK194103415CN\r ','hermeshine'),(24138,804796743018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','ianmartin68','ian.vogler@gmx.co.uk','Mr ian vogler','12 Mile House Lane','St Albans','Hertfordshire','UNITED KINGDOM','AL1 1TB','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-16 18:51:24',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24139,948126090015,250692240685,'TianYa NEUTRAL DENSITY ND8 Filter replaces for Cokin P',1,'AA2325',4.65,'hutongstore','thanks.for.viewing','draveuallknowme@hotmail.com','David Ross','Apartment 8, Platt House<br>5 Elmira Way','Salford','Greater Manchester','UNITED KINGDOM','M5 3DR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 19:27:17',0,NULL,3,1,11,1,NULL,'hutongstore'),(24140,798693149001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','acbustillo0','acbustillo@hotmail.com','Andres Cruz Bustillo','11909 Auburn Rd<br>Ste 15515','Laredo','TX','UNITED STATES','78045','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-16 20:24:33',0,NULL,3,1,3,1,'RA184519722CN ','hermeshine\r新地址：\rAndrés Cruz Bustillo\rFrancisco Canal 327 Colonia Centro, Veracruz, Veracruz, México. CP 91700.\rTel. (229) 150.3950'),(24141,948178516015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',25.99,'hutongstore','greaseh','sam.revel@gmail.com','Samuel J Revel','Little Dean, Nairdwood Lane<br>Prestwood','Great Missenden','Buckinghamshire','UNITED KINGDOM','HP16 0QF','01494865761','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 20:38:33',0,NULL,3,1,3,1,'RA184523280CN ','hutongstore'),(24142,798707257001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','quintanaderueda','quintanarueda@gmail.com','Javier Cebreros','C/ Oscar Wilde, 11 Bl. 2. 7D','Málaga','Andalucía Ceuta y Melilla','SPAIN','29010','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-16 20:50:41',0,NULL,3,0,3,1,'RR658650575CN\r ','hermeshine\r3XL  已入库'),(24143,948199385015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','cocorose10','darenanddi@yahoo.co.uk','Daren summerfield','10 Jago CLOSE','liskeard','Cornwall','UNITED KINGDOM','pl143FJ','01579346708','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 21:09:22',0,NULL,3,1,3,1,'RA184524197CN\r ','hutongstore'),(24144,843158771002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.6,'hermeshine','geeky425','jinsanlee@gmail.com','Jinsan John Lee','919 Broadway St','Boulder','CO','UNITED STATES','80302-7044','(425) 761-4824','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-16 21:11:40',0,NULL,3,1,3,1,'RA184519872CN ','hermeshine\rSAL挂号便宜三块钱。\r还改吗'),(24145,865133817017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.85,'photographyacc','epice_douce','rusina@hotmail.fr','Rusina SHIKHATOVA','1, rue du Docteur Woehrlin','Strasbourg','Alsace','FRANCE','67000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-16 21:38:44',0,NULL,3,1,11,1,NULL,'photographyacc'),(24146,798748912001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','carloshferrari','flanker414@hotmail.com','Carlos Hilgert Ferrari','Rua Duque de Caxias, 426 Apto 305<br>Centro','Porto Alegre','Rio Grande Do Sul','BRAZIL','90010280','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-16 22:21:02',0,NULL,3,1,3,1,'RA184594785CN ','hermeshine\rXL  已入库\r国内挂号84\r香港挂号'),(24147,928524326016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','t4b2348','metalcrow@gmx.de','Malte Bayer','Warendorfer Str. 20','Münster','','GERMANY','48145','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-16 22:38:07',0,NULL,3,1,4,1,'YW868897521CN','hutongstore'),(24148,843205823002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','bronnieleigh','bronnieleigh@hotmail.com','Bronwyn Papandrea','P O Box 210','West Ryde','New South Wales','AUSTRALIA','2114','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 22:58:58',0,NULL,3,1,11,1,NULL,'hermeshine'),(24149,843206084002,120564178382,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3306',4.5,'hermeshine','bume003','gregpullen@playbillvenues.com.au','Greg Pullen','Playbill Venues, Building 16,<br>Fox Studios Australia, Lang Road','Moore Park','New South Wales','AUSTRALIA','2021','61299215330','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:00:37',0,NULL,3,1,17,0,NULL,'hermeshine'),(24150,798762348001,110407120397,'55mm 55 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3302',3.25,'hermeshine','bume003','gregpullen@playbillvenues.com.au','Greg Pullen','Playbill Venues, Building 16,<br>Fox Studios Australia, Lang Road','Moore Park','New South Wales','AUSTRALIA','2021','61299215330','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:00:37',0,NULL,3,1,17,0,NULL,'hermeshine'),(24151,798763090001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','bume003','gregpullen@playbillvenues.com.au','Greg Pullen','Playbill Venues, Building 16,<br>Fox Studios Australia, Lang Road','Moore Park','New South Wales','AUSTRALIA','2021','61299215330','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:00:38',0,NULL,3,1,11,1,NULL,'hermeshine\r绿叶 UV  72mm   1\r绿叶 UV  55mm    1\r绿叶 UV  67mm    1'),(24152,948268696015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','wwoofwoof','mark.mulcahy@hotmail.co.uk','Mark Mulcahy','The Hayloft<br>Astwood Lane','Stoke Prior','Worcestershire','UNITED KINGDOM','B60 4BB','01527821893','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-16 23:16:23',0,NULL,3,1,3,1,'RA184519957CN ','hutongstore'),(24153,798774968001,110717754884,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1201',11.7,'hermeshine','camera_bloke','fangio@netspace.net.au','Angelo Sartore','4 Southward Avenue','Port Melbourne','Victoria','AUSTRALIA','3207','0417522748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:38:13',0,NULL,8,1,17,0,NULL,'hermeshine'),(24154,798774843001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',4,'AE1203',20,'hermeshine','camera_bloke','fangio@netspace.net.au','Angelo Sartore','4 Southward Avenue','Port Melbourne','Victoria','AUSTRALIA','3207','0417522748','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-16 23:38:14',0,NULL,3,1,3,1,'RA184519869CN ','hermeshine\r3片装的滤镜袋  3\r6片装的滤镜袋   4'),(24155,865235539017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'photographyacc','grigas09','lfgreg@hotmail.com','Francisco Gregório','Rua Padre Martinho Mourão Nº20','Entroncamento','','PORTUGAL','2330-024','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-17 00:11:08',0,NULL,3,1,11,1,NULL,'photographyacc'),(24156,948290493015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','2212rebecca','r.randle1@ntlworld.com','R Randle','58<br>Lucas Road','Hinckley','Leicestershire','UNITED KINGDOM','LE10 2NA','01455445653','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 00:11:45',0,NULL,3,1,11,1,NULL,'hutongstore'),(24157,798783636001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','marek9','marekdiug@gmail.com','Marek Diug','1 Dunster crt Endeavour Hills','Melbourne','Victoria','AUSTRALIA','3802','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 00:05:35',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24158,843238682002,120661195845,'Green-L 72mm Graduated Neutral Density ND Grey Filter',1,'AA3320',8.47,'hermeshine','kew91156','k.white911@yahoo.com.au','Kathy White','15 Government Rd<br>Beacon Hill','Sydney','New South Wales','AUSTRALIA','2100','0294524620','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 00:40:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(24159,928577017016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','gustavpsi','gustavpsi@gmail.com','Gustavo Borges Moreno e Mello','Rua João Bastos 3, 1º Esquerdo','Lisboa','Portugal','PORTUGAL','1400-125','934482159','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-02-17 00:50:39',0,NULL,3,1,12,1,'3125518336\r ','hutongstore\r欧标\r泡重8.2\r\r9'),(24160,798797051001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','vierwols','javierbolea@yahoo.es','Javier Bolea (bei Karagöl)','Eisenbahnstraße 44, 1-OG','Berlin','','GERMANY','10997',' 01788032570','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 00:51:43',0,NULL,3,1,11,1,NULL,'hermeshine'),(24162,798810780001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','madfireblade','madfireblade@hotmail.com','mer bruno','11 ter rue roger sallengro','caullery','Nord-Pas-de-Calais','FRANCE','59191','00.00.00.00.00','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 01:40:51',0,NULL,3,1,11,1,NULL,'hermeshine'),(24163,8881329447222418,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail',1,'AKT052',42.99,'aliexpress','1006814182','maklux@mail.ru','NICK BARANOV','Ul. Moskovskiy prospect, dom 116, kv 54','Kaliningrad','Kaliningrad region','RUSSIAN FEDERATION','236006','+7 9114 546515',NULL,NULL,NULL,'2012-02-17 02:53:42',0,NULL,3,1,3,1,'RA184523086CN\r ','2云柔   1 '),(24164,843294656002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','jinky77','jeni_kay77@yahoo.com','Jennifer Smoody','624 3rd St','Kenyon','MN','UNITED STATES','55946-1303','(414) 704-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 03:58:31',0,NULL,3,1,17,0,NULL,'hermeshine'),(24165,843294307002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','jinky77','jeni_kay77@yahoo.com','Jennifer Smoody','624 3rd St','Kenyon','MN','UNITED STATES','55946-1303','(414) 704-7475','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 03:58:31',0,NULL,3,1,1,1,'LK195532185CN\r ','hermeshine\r闪光灯B座   2'),(24166,8881329452034873,111,'85cm  反光伞',1,'AD1401',0,'hutongstore','framemakermkltd','sales@framemakermk.co.uk','Framemaker MK Ltd','Units 13 & 14 Stacey Bushes Trading Centre<br>Erica Road, Stacey Bushes','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk12 6hs','08448488222',NULL,NULL,NULL,'2012-02-17 04:13:54',0,NULL,3,1,3,1,'RR658650536CN\r ',NULL),(24167,805023769018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','dq..qb','mrmemomnm@yahoo.co.jp','MEG CODOTTO','suite 11, 128-130 Lyons St<br>Bungalow','CAIRNS','Queensland','AUSTRALIA','4870','0740356006','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 04:37:06',0,NULL,3,1,3,1,'RR658650540CN\r ','photographyacc'),(24168,798860499001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','2000eclipses','mchenry_cody@yahoo.com','Cody McHenry','702 Funston Ave','Williamsport','PA','UNITED STATES','17701-4316','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 04:58:06',0,NULL,3,1,1,1,'LK195583338CN\r ','hermeshine\r1.6*2.1  黑色'),(24169,8881329455109947,111,'2.4x3m背景架+ 白布 ',1,'AD1183',0,'hutongstore','pattypatritsia','patty.p9@gmail.com','Patritsia Panayi','Georgiou Sfrantzi 5/101<br>Strovolos','Nicosia','','CYPRUS','2047','00357-99565946',NULL,NULL,NULL,'2012-02-17 05:05:09',0,NULL,3,1,5,1,' CP244674678CN',NULL),(24170,928661367016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','benssp','benssp@hotmail.com','Benali Eddy','Chemin Saint Colomé<br>Résidence les Bartavelles Bat A','Pertuis','Provence-Alpes-Côte d\'Azur','FRANCE','84120','+33650706543','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-17 05:25:28',0,NULL,3,1,11,1,NULL,'hutongstore'),(24171,948389386015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','h_p1981','helderpinho777@gmail.com','Helder Pinho','APARTADO 6 EC ANTA','ESPINHO','AVEIRO','PORTUGAL','4501-908','00351916094390','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 05:25:43',0,NULL,3,1,11,1,NULL,'hutongstore'),(24172,798866286001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','benzther','benz.ang@hotmail.com','korawit sriputtachote','45/1 Egkhanek House Room 202<br>Prachautith road','Tungkru','Bangkok','THAILAND','10140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 05:29:39',0,NULL,5,1,11,1,NULL,'hermeshine\r不确定发没发  就当发了吧，点不了已发货'),(24173,843318046002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','gchen1900','ch.gideon@gmail.com','Gideon Chen','5 Sharona st.','Rishon Lezion','','ISRAEL','75289','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 05:50:23',0,NULL,3,1,3,1,'RA184508985CN\r ','hermeshine\r欧标'),(24174,798866182001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','yossiburmad1','yossiburmad@gmail.com','yossi BURMAD','Shmuel Rozovsky 4/9','ASHDOD','ISRAEL','ISRAEL','77376','0544737692','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 05:28:09',0,NULL,3,1,3,1,'RR658650519CN\r ','hermeshine'),(24175,8881329466517078,111,'柔光伞110cm ',1,'AD1125',0,'photographyacc','mariusz007-1984','suchy007-1984@tlen.pl','Mariusz Suszynski','49 Victoria Road   FLAT 2','Northampton','Northamptonshire','UNITED KINGDOM','NN1 5ED','',NULL,NULL,NULL,'2012-02-17 08:15:17',0,NULL,3,1,3,1,'RA184523072CN\r ',NULL),(24176,865366369017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','fuzz_racing','fuzzauction@msn.com','George Dib','PO BOX 351','GRANVILLE','New South Wales','AUSTRALIA','2142','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 08:39:31',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24177,798905845001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','jewmanymore','jirapaebay2012@gmail.com','jirapa duangchan','420/134 soisetthakij 46 bangcare nue<br>bangcare bangkok','default','BA','THAILAND','10160','66814219333','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 09:01:26',0,NULL,3,1,11,1,NULL,'hermeshine'),(24178,805092854018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','xavi_jm','xavijm@gmail.com','Xavier Jiménez Marimón','Panissars 20 Atico 1','Barcelona','Cataluña','SPAIN','08028','699824501','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-17 10:00:52',0,NULL,3,1,17,0,NULL,'photographyacc'),(24179,928730369016,260838264614,'New Large High quality heavy duty sand bag Empty',1,'AD1168',8.99,'hutongstore','xavi_jm','xavijm@gmail.com','Xavier Jiménez Marimón','Panissars 20 Atico 1','Barcelona','Cataluña','SPAIN','08028','699824501','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-17 10:03:31',0,NULL,3,1,2,1,'\\ ','hutongstore\r沙袋（普通）   1\r沙袋（大）   1'),(24180,843381345002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','akrasnikov','alekseykrasnikov@gmail.com','Алексей Красников','Садовая, 13А, 35','Белгород','Белгородская область','RUSSIAN FEDERATION','308007','+7 (910) 2223332','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 10:47:40',0,NULL,3,1,5,1,'CP243056183CN ','hermeshine'),(24181,948479526015,250600325630,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',4.2,'hutongstore','396408','s.whent@btinternet.com','Mr Steve Whent','149 Greenstead Road','Colchester','Essex','UNITED KINGDOM','co1 2sp','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 10:52:38',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24182,798943336001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',35.99,'hermeshine','anchovies8','rodlages@gmail.com','Rodrigo Lages','SGAN 914 Modulo A Bl. B Ap. 223<br>Cond. South Beach - Asa Norte','Brasilia','DF','BRAZIL','70790-140','+55 61 8478-8878','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 11:30:25',0,NULL,3,1,3,1,'RA184523069CN\r ','hermeshine\r运费需要再算一下'),(24183,798673463001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','quztozzz','quztoz@gmail.com','Sergey Kharitonov','Jakova Eshpaja str. 113A-3','Yoshkar-Ola','Mari-El','RUSSIAN FEDERATION','424031','(8362) 652070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 11:16:32',0,NULL,3,1,3,1,'RA184523126CN\r ','hermeshine'),(24184,627447669004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','sekelskypavol','pavolsekelsky@gmail.com','Pavol Sekelsky','Tomasikova<br>22','Presov','PRESOV','SLOVAK REPUBLIC','08001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 11:58:37',0,NULL,3,1,11,1,'BJ01714475\r ','hermeshine'),(24185,798953654001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','dfcorreia','forrepe@hotmail.com','Daniel Correia','51, Rue Raymond Losserand - Porte verte à droite.<br>DIGICODE: 96B13','Paris','Ile-de-France','FRANCE','75014','0672609642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 12:11:35',0,NULL,3,1,3,1,'RA184523038CN\r ','hermeshine'),(24186,798955053001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','jolitakey','jolita.kimsaite@gmail.com','Jolita Kimsait','Paupio 11-1','Vilnius','','LITHUANIA','01201','+37080079881','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-17 12:15:06',0,NULL,3,1,21,1,'RA184523130CN\r ','hermeshine\r欧标\r便宜8块钱'),(24187,865431106017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','lisem44','lise.m.cooney@gmail.com','Elise Cooney','26 Castleton Rd','Herne Hill','Victoria','AUSTRALIA','3218','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,1,18,0,'YW867610930CN ','photographyacc'),(24188,948517843015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','niv5406582','dw@bezeqint.net','niv ben avat','simha 2','beer sheva','ISRAEL','ISRAEL','84225','0503036200','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 12:38:38',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24189,865449625017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','johngrechphoto','johnny_grecko@hotmail.com','John Grech','5 Norfolk Street','Mount Druitt','New South Wales','AUSTRALIA','2770','0298648535','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'photographyacc'),(24190,798990077001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','sa0timjak','thesavage78@gmail.com','Tim Jakszewicz','108B St Kilda Road','Rivervale','Western Australia','AUSTRALIA','6103','0411050816','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 14:07:58',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24191,843456841002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','northstar0_4','pasan@ntl.sympatico.ca','Manju Dangalle','264 Rondeau Road','New Liskeard','ON','CANADA','P0J 1P0','(705) 647-9595','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 14:49:57',0,NULL,3,1,3,1,'RA184524166CN\r ','hermeshine'),(24192,799013477001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','gfd628','mgroves912@yahoo.com','mike groves','310 york st','greenville','KY','UNITED STATES','42345-1342','(270) 543-7428','NoPaymentFailure','CheckoutComplete','Other','2012-02-17 15:14:26',0,NULL,3,0,1,1,'LK197194358CN  ','hermeshine\rXL  已入库'),(24193,799017753001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','dan5206','dlapasha@lticorp.com','Dan LaPasha','5206 Duraleigh Rd','Raleigh','NC','UNITED STATES','27612','(919) 783-6900','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 15:26:13',0,NULL,3,1,1,1,'LK197206507CN  ','hermeshine'),(24194,799028246001,110781580134,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',68.99,'hermeshine','owkixz27','fmallari727@yahoo.com','Francis Mallari','P.O Box 62013<br>3rd Floor, RHS Building, Mankhool Road','Bur Dubai','Dubai, Dubayy','UNITED ARAB EMIRATES','0917','0502422600','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 15:56:25',0,NULL,5,1,18,1,'RA184523024CN\r ','hermeshine\r已退款'),(24195,843489626002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','nicolas4208','nicolasmonteban@gmail.com','Nicolas Monteban','6 Cambridge St Willoughby','Sydney','New South Wales','AUSTRALIA','2068','0299070103','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 16:13:17',0,NULL,3,1,3,1,'RA184523259CN ','hermeshine\r邮件里有两个拍的信，两个付款信\r但是数量没有少\r'),(24196,928889272016,260895487153,'Photo Studio Barn Door & Honeycomb Grid & Gel Set NEW',1,'AD1166',18.7,'hutongstore','elgato67x','photobella@mac.com','Efrain Hernandez','580 Orange Dr','Vacaville','Ca','UNITED STATES','95687-3104','(530) 520-5349','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 16:35:42',0,NULL,3,1,1,1,'LK197368235CN ','hutongstore'),(24197,948632045015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','michelangelouk','darren.frodsham@blueyonder.co.uk','Darren Frodsham','34 Derwent road<br>Hindley','Wigan','Lancs','UNITED KINGDOM','WN2  3QP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 16:48:30',0,NULL,3,1,3,1,'RA184519360CN\r ','hutongstore'),(24198,948658079015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','russian_federation','region35rus@gmail.com','Voyakin Denis Viktorovich','ul. Latskova, dom 4, korpus 1, kv. 24','g. Zhukovskiy','Moskovskaya oblast','RUSSIAN FEDERATION','140188','89115470888','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-17 17:34:29',0,NULL,3,1,17,0,NULL,'hutongstore'),(24199,799071072001,110559997267,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',82,'hermeshine','russian_federation','region35rus@gmail.com','Voyakin Denis Viktorovich','ul. Latskova, dom 4, korpus 1, kv. 24','g. Zhukovskiy','Moskovskaya oblast','RUSSIAN FEDERATION','140188','89115470888','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-17 17:36:32',0,NULL,3,1,17,0,NULL,'hermeshine'),(24200,843525569002,120800186941,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',245,'hermeshine','russian_federation','region35rus@gmail.com','Voyakin Denis Viktorovich','ul. Latskova, dom 4, korpus 1, kv. 24','g. Zhukovskiy','Moskovskaya oblast','RUSSIAN FEDERATION','140188','89115470888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 17:36:33',0,NULL,3,1,5,0,'CP244439895CN ','hermeshine\r除了C以外再发\r背景架2mx2m  + 3个夹子  1\r1.6*2.1  黑加白\r灯架  2m  1\r柔光箱 50-70cm 单灯头  1\r斜臂    1\r115w 5500k 灯泡  220v  1\r灯架包    1\r欧标\r\r'),(24201,799085778001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','geraldo.viannini-br','geraldo.luiz@ig.com.br','GERALDO Luiz','Rua Mario Regallo Pereira, 242','Sao Paulo','SP','BRAZIL','05550-060',' 551196959178','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 18:09:02',0,NULL,3,1,3,1,'RA184523109CN\r ','hermeshine'),(24202,799088965001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mmazzio','mmazzio2000@aol.com','Kristine Dong','5900 arlington ave<br>Apt 10P','Bronx','NY','UNITED STATES','10471-1312','(917) 723-8834','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 18:19:25',0,NULL,3,0,1,1,'LK197332876CN  ','hermeshine\r1.6*2.1  黑色'),(24203,843545355002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','ozmongrel','falcon25@optusnet.com.au','Paul TAN','25 Constance Street','Guildford','New South Wales','AUSTRALIA','2161','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 18:20:34',0,NULL,3,1,3,1,'RA184523245CN ','hermeshine'),(24204,805284514018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','ssucipto','suryo.sucipto@gmail.com','Suryo Sucipto','2/114 Swansea Street','East Victoria Park','Western Australia','AUSTRALIA','6101','0863611320','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-17 18:37:16',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24205,843559975002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','pampacondor','rich.busch7@gmail.com','Rich Busch','2001 Colorado Blvd','Denver','CO','UNITED STATES','80205','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 18:53:14',0,NULL,3,1,3,1,'RA184523015CN\r ','hermeshine'),(24206,928965854016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','alasdaire2005','ali.ewing@tiscali.co.uk','Alasdair Ewing','6 Chaucer Close','Fareham','Hampshire','UNITED KINGDOM','PO16 7PD','01329234753','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 18:53:17',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24207,948685708015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dhjrtw','theatricalz@gmail.com','David Jones','19 Blaencwm Terrace, Tynewydd','Treorchy','Rhondda Cynon Taff','UNITED KINGDOM','CF425ND','01443775812','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 18:21:04',0,NULL,3,1,3,1,'RA184524957CN ','hutongstore'),(24208,843575504002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','hmtur1961','hmtur@yahoo.com','Hugo M. Tovar','4608 Palma Blanca Dr','Brownsville','TX','UNITED STATES','78521-4971','(956) 592-9789','NoPaymentFailure','CheckoutComplete','Other','2012-02-17 19:20:39',0,NULL,3,0,1,1,'LK197236954CN ','hermeshine\r3XL  已入库'),(24209,865630457017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','stratotrade','jfcox@telecomplus.org.uk','John Cox','14 Walnut Grove<br>Whitby','Ellesmere Port','Cheshire','UNITED KINGDOM','CH662JZ','01513568948','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-17 19:44:03',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24210,799144533001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mbmoh93160','mbmoh93@gmail.com','Mohamed Bouchadekh','2, place Eugène Thomas','NOISY LE GRAND','Ile-de-France','FRANCE','93160','0615090560','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 20:07:38',0,NULL,3,1,3,1,'RA184525762CN ','hermeshine'),(24211,843605408002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','yvictors','addblock@gmail.com','Victor Yarkin','232 Lenina Avenue, Apt.50','Zaporizhzhya','Zaporizhska region','UKRAINE','69006','+380959161115','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 20:18:57',0,NULL,3,1,21,1,'RA184524373CN\r ','hermeshine\rSAL挂号便宜5块钱。\r利润少，sal 合适一些'),(24212,799171918001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','photo484','macspeter@gmail.com','Peter Macs','Lehar Ferenc utca 8','Komlo','','HUNGARY','7300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 21:03:09',0,NULL,3,1,3,1,'RA184523055CN\r ','hermeshine'),(24213,799161735001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','brosgak','dkmueller@mac.com','Daniel K. Mueller','8542 E Via De Viva','Scottsdale','AZ','UNITED STATES','85258-3949','(602) 315-9189','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-17 20:42:28',0,NULL,3,1,4,1,'YW867610882CN\r ','hermeshine\r美标'),(24214,799179413001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','gidi_bendor','gidi_bendor@hotmail.com','Gidi Ben Dor','Golan Hights','Neve Ativ','none','ISRAEL','12493','972544810588','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 21:21:08',0,NULL,3,1,11,1,' \\','hermeshine'),(24215,948799384015,250600319241,'Flash Bounce Diffuser for CANON Speedlite 580EX 580EXII',2,'AB3332',3.16,'hutongstore','stu.1804','stuart@skreid.com','Stuart Reid','19 Lomond PLace<br>Balmullo','St Andrews','Fife','UNITED KINGDOM','KY16 0DL','01334870080','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 21:21:39',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24216,843641073002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','zigital*photo','ziglawsha@earthlink.net','Stevie Lawsha','2321 McKinleyville Ave<br>McKinleyville Apt 8','Mckinleyville','CA','UNITED STATES','95519-3498','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-17 21:33:54',0,NULL,3,1,1,1,'LK197206405CN  ','hermeshine'),(24217,843622089002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','eddiebaby_baby','mrbutlerjr@aol.com','edward butler','620 Mississippi Ave SE<br>Apt 7','washington','DC','UNITED STATES','20032','(202) 253-1102','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 21:07:02',0,NULL,3,1,3,1,'RA184519458CN\r ','hermeshine'),(24218,799205225001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jpcomao','jpcperso@free.fr','jean paul catherine','5 av du chateau','sartrouville','Île-de-France','FRANCE','78500','0130869802','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-17 22:21:43',0,NULL,3,1,3,1,'RA184525847CN ','hermeshine'),(24219,799219563001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','glam_moocher','branscumcasey@yahoo.com','Denise Brewer','1722 N College Ave<br>Ste C','Fayetteville','AR','UNITED STATES','72703-2640','(870) 213-5251','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-17 23:00:06',0,NULL,3,1,3,1,'RA184523143CN\r ','hermeshine'),(24220,948860152015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','infinity_plus_1','richard@rogersuk.me.uk','Richard Rogers','21 Colenso Road','Blackburn','Lancashire','UNITED KINGDOM','BB1 8DR','01254725141','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-17 23:22:36',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24221,948878532015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','adamski_raz','adam@adamski-online.co.uk','Adam Chalmers','12 Broomy Close, Dibden','Southampton','Hampshire','UNITED KINGDOM','SO45 5WB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 00:12:29',0,NULL,3,1,3,1,'RA184519444CN\r ','hutongstore'),(24222,799245932001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','javier.rodelgo','jrodelgo1@yahoo.es','javier rodelgo','plaza mayor, 1<br>dulcería de chinchón','chinchón','Madrid','SPAIN','28370','620959823','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 00:27:38',0,NULL,3,1,17,0,NULL,'hermeshine'),(24223,929143720016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','javier.rodelgo','jrodelgo1@yahoo.es','javier rodelgo','plaza mayor, 1<br>dulcería de chinchón','chinchón','Madrid','SPAIN','28370','620959823','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 00:28:45',0,NULL,3,1,4,1,'YW868897565CN ','hutongstore\r灯架  2m  1\r闪光的柔光箱   60cm   1'),(24224,843710380002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 00:53:10',0,NULL,3,1,3,1,'RA184523041CN\r ','hermeshine'),(24225,843278414002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',42.99,'hermeshine','codsalmon2011','codsalmon@gmail.com','Ryan Schatz','2493 Richter St','Kelowna','BC','CANADA','V1Y 2P7','(250) 862-6993','PayPalPaymentInProcess','CheckoutComplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184525440CN ','hermeshine\r电子账单已经清了'),(24226,8881329531879882,111,'1.6m*4m  黑，粉，蓝，白',1,'',48,'hutongstore','dean19662011',' hewlett@live.co.uk','dean hewlett','91 sladebrook road','bath ','ba21lp','UNITED KINGDOM','','',NULL,NULL,NULL,'2012-02-18 02:24:39',0,NULL,3,1,3,1,'RA184523205CN ',' YW867965830CN'),(24227,8881329532659707,111,'Free shipping & Tracking # - New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',9.99,'aliexpress','1006834573','yura600@rambler.ru','Yuriy Mukhin','kadomtseva 11-1-35','moscow','','RUSSIAN FEDERATION','129128','+7 903 100-66-09',NULL,NULL,NULL,'2012-02-18 02:37:39',0,NULL,3,1,3,1,'RA184508937CN\r',''),(24228,929186096016,260762351314,'Photo Light Head with 4 x E27 Socket Umbrella Bracket',1,'AE2202',15.59,'hutongstore','kia-peaches','sturgeonteressa@gmail.com','teressa sturgeon','1018 Parry St','RICHMOND','IN','UNITED STATES','47374-6965','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 02:49:52',0,NULL,3,1,3,1,'RA184508999CN\r ','hutongstore'),(24229,8881329533530018,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail',1,'AA1310',6.99,'aliexpress','1006825042 ',' ruslan@galiev.ru','Ruslan Galiev','Korolenko 59-98','Kazan','Tatarstan','RUSSIAN FEDERATION','420044','+7 927 2496609',NULL,NULL,NULL,'2012-02-18 02:52:10',0,NULL,3,1,3,1,'RA184594825CN ',NULL),(24230,865817151017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','denn199','jill1927@internode.on.net','Charles Heathcote','136 harrington road<br>Dennington','Warrnambool','Victoria','AUSTRALIA','3280','0355625784','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-18 04:08:19',0,NULL,3,1,3,1,'RA184523112CN\r ','photographyacc'),(24231,948947578015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','bilalshah1','bilalshah1@aol.com','Bilal Shah','45 Tildsley Street','Bolton','Lancashire','UNITED KINGDOM','BL3 6PN','07833946045','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 04:03:16',0,NULL,3,0,3,1,'RA184523355CN ','hutongstore\rL 已入库，发信确认一下'),(24232,799306688001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','maxboniche','maxxlocc@gmail.com','Maxdiel Boniche','De la Clinica Don Bosco 2c abajo 125 vrs al sur','Managua. Nicaragua','managua','NICARAGUA','505','83843421','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 04:55:06',0,NULL,5,0,18,0,NULL,'hermeshine\r先称下重量吧，运费可能贵\r好像怎么发都不合适，\r在燕文网站算的\r只有国内小包挂号和DHL能到，\r其他都不到\r1.864kg\r已发信，需要加$28美金运费\r'),(24233,799320269001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','scarletfever','necrolantry@hotmail.com','Kate MacDonald','62 Lakefront Road<br>Apt. 6','Dartmouth','NS','CANADA','B2Y3C6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 06:05:51',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24234,843803578002,120768244318,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',85,'hermeshine','ant_trader','metalstorm@abv.bg','Stefan Anastasov','Hristo Botev 18','Sopot','','BULGARIA','4330','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-18 08:11:13',0,NULL,3,1,5,1,'CP244439944CN ','hermeshine\r除C以外再发\r1.6*2.1  黑色布\r欧标'),(24235,799341991001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ant_trader','metalstorm@abv.bg','Stefan Anastasov','Hristo Botev 18','Sopot','','BULGARIA','4330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 08:11:14',0,NULL,8,0,17,0,NULL,'hermeshine'),(24236,805547654018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','themattjackson6','matthew.g.jackson@gmail.com','Matthew Jackson','9 Taylor St','Oakleigh','Victoria','AUSTRALIA','3166','0422762584','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-18 08:28:26',0,NULL,3,1,3,1,'RA184523262CN ','photographyacc'),(24237,949030138015,250692239327,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',28,'hutongstore','normrc1','richard_candler@hotmail.com','Richard Candler','42 Frank Large Walk','Northampton','Northamptonshire','UNITED KINGDOM','NN54UP','07789798556','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 09:33:08',0,NULL,3,1,3,1,'RA184523347CN ','hutongstore\r2云柔  1'),(24238,805573632018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','iceno9','iceno9@ntlworld.com','Matthew Stevens','31 Adlington road<br>Windmill Hill','Runcorn','Cheshire','UNITED KINGDOM','WA7 6ND','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 09:58:48',0,NULL,3,1,11,1,'BJ01669186 ','photographyacc'),(24239,799369960001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','candyman_4ever','candyman_4ever@yahoo.com','Angel A. Zazueta / Jose Alvarado','8223 S 53rd Dr','Laveen','AZ','UNITED STATES','85339-2854','(928) 503-7797','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-18 10:04:19',0,NULL,3,1,1,1,'LK200540902CN\r ','hermeshine'),(24240,805584766018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','analiavc70','analia2@bigpond.com','Analia Cahill','14 Carlton Crescent','Kogarah Bay','New South Wales','AUSTRALIA','2217','0295464738','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-02-18 10:36:03',0,NULL,3,1,4,1,'YW868897580CN ','photographyacc'),(24241,843843351002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','nukels','lordvairon@hotmail.com','jose gabriel gonzalez botias','c/aurora nº 14 2º b','el puerto de santa maria','Andalucía Ceuta y Melilla','SPAIN','11500','615412678','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 10:40:38',0,NULL,3,1,3,1,'RA184524064CN\r ','hermeshine'),(24242,843835209002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','kamawanai','isshoukenmei@gmail.com','Alexander  Mitkov','Respubliki 17-41','Usolie-Sibirskoe','Irkutskaya','RUSSIAN FEDERATION','665462','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 10:47:27',0,NULL,3,1,5,1,'CP244439533CN ','hermeshine\r布要灰色的'),(24243,805595065018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.86,'photographyacc','tzatxiko','patxi.valeraotero@gmail.com','Patxi Valera Otero','C/ San Pedro de Visma Nº 9','A Coruña','Galicia','SPAIN','15011','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 11:14:00',0,NULL,8,1,17,0,NULL,'photographyacc'),(24244,843863589002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mutzike','nedelcu_l_m@yahoo.com','Nedelcu Liviu-Mihael','Marasesti<br>nr. 98, sc. C, ap. 8','Bacau','Bacau','ROMANIA','600114','+40745397204','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 11:45:38',0,NULL,3,1,3,1,'RA184519395CN\r ','hermeshine'),(24245,805591089018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.4,'photographyacc','tzatxiko','patxi.valeraotero@gmail.com','Patxi Valera Otero','C/ San Pedro de Visma Nº 9','A Coruña','Galicia','SPAIN','15011','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 11:14:00',0,NULL,3,1,11,1,'BJ01714472\r ','photographyacc\r麂皮   2\r沙袋（普通）   1'),(24246,949097783015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','lorn4321','elldee-dean@hotmail.co.uk','Lorina Dean','187 Queensway<br>Coney Hall','West Wickham','Kent','UNITED KINGDOM','BR4 9DU','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-18 12:24:20',0,NULL,3,1,4,1,'YW868897543CN ','hutongstore\r白 + 黑'),(24247,949131634015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','norulakp','noro22@centrum.sk','Peter Norulak','Popradska 84/B','Kosice','','SLOVAK REPUBLIC','04011','00421949416265','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 13:40:32',0,NULL,3,1,3,1,'RA184524016CN\r ','hutongstore'),(24248,805653569018,280726880012,'New 10 slots filter box for 10 Pcs filters Cokin  P',5,'AD1170',44.95,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:17',0,NULL,3,1,17,0,NULL,'photographyacc'),(24249,805652870018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',1,'AA2216',5,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:18',0,NULL,3,1,17,0,NULL,'photographyacc'),(24250,865979371017,270750130191,'TianYa Star 8 points  cross filter for Cokin P Series',1,'AE2317',12.9,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:19',0,NULL,3,1,17,0,NULL,'photographyacc'),(24251,805653122018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',5,'AE1203',27.5,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:19',0,NULL,3,1,17,0,NULL,'photographyacc'),(24252,805653239018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',1,'AE2316',12.9,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:19',0,NULL,3,1,17,0,NULL,'photographyacc'),(24253,865979479017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:20',0,NULL,3,1,17,0,NULL,'photographyacc'),(24254,805652983018,280706324097,'9 Ring Adapter+ 2 Filter Holder set for Cokin P series',1,'AKT025',24.9,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:21',0,NULL,3,1,17,0,NULL,'photographyacc'),(24255,805652773018,280670211455,'82mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT054',4.19,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:20',0,NULL,3,1,17,0,NULL,'photographyacc'),(24256,805652676018,280670210119,'77mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT024',4.19,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 13:48:21',0,NULL,3,1,3,1,'RA184507812CN ','photographyacc\r透明10片装盒    5\r方镜广角托架（ 一槽）   1\r天涯方形滤镜系列  CPL    1\r天涯方形滤镜系列  星光镜  star6   1\r天涯方形滤镜系列  星光镜  star8   1\r6片装的滤镜袋   5\r9个环 + 2个托架      1\r82mm 接口环   + 普通托架    1\r77mm 接口环  + 普通托架    1\r'),(24257,843921860002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','ibisabelle','isa.vgl@gmail.com','bertrand maquin','5 rue trieu maquette','sirault','','BELGIUM','7332','065622070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 14:23:58',0,NULL,3,1,3,1,'RA184524435CN ','hermeshine'),(24258,949158757015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ajt3103','andytaylor3103@btinternet.com','andy taylor','143 Bourton Way','wellingborough','Northamptonshire','UNITED KINGDOM','NN82NU','07921757850','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 14:33:13',0,NULL,3,1,3,1,'RA184519400CN\r ','hutongstore'),(24259,949164443015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','daz_in_space','daz_in_space@hotmail.com','darren mack','15 bracken road<br>fern park','stockton on tees','Cleveland','UNITED KINGDOM','ts19 0nj','07535616752','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 14:43:52',0,NULL,3,1,3,1,'RA184524210CN\r ','hutongstore'),(24260,799494271001,110422375839,'Aluminium Lightweight 68\" Camera Monopod with ballhead',1,'AE1604',36.86,'hermeshine','gluxx','gluxx@yandex.ru','Olga Glushchenko','Pobeda str.18-33','Belgorod','Belogorod','RUSSIAN FEDERATION','308600','+7 920 585 7208','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 15:45:07',0,NULL,3,1,3,1,'RA184524245CN\r ','hermeshine'),(24261,805741901018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',2,'AE1201',8.8,'photographyacc','ripson76','ripe@ripestudio.com','Pawel Nowakowski','184 Winchmore Hill Road','London','London','UNITED KINGDOM','N21 1QP','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 16:50:59',0,NULL,3,1,11,1,'BJ01714496\r ','photographyacc'),(24262,949247079015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','william10terry','t_bewsey@sky.com','terry bewsey','36 lee way<br>glashougton','castleford','West Yorkshire','UNITED KINGDOM','wf10 4tq','01977513405','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 17:00:54',0,NULL,3,1,3,1,'RA184524081CN\r ','hutongstore'),(24263,799534990001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','saintamand32','saintamand@hotmail.es','jose torres martinez','reino unido 3 p5 bajo b','torrejon de ardoz','Madrid','SPAIN','28850','637535730','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 17:07:08',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24264,799547003001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','pmaciolek','pakero@gazeta.pl','Przemyslaw Maciolek','ul. Radzikowskiego 67/31','Cracow','małopolskie','POLAND','31315','608 337023','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-18 17:31:00',0,NULL,3,1,3,1,'RA184509084CN\r ','hermeshine'),(24265,799572059001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','sergei2306','lubashev@mail.ru','Lubashev Sergey','Raskolnikova 21, apartment 168, (36/5-168)','naberezhnye chelny','tatarstan','RUSSIAN FEDERATION','423822','+79272404477','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-18 18:16:01',0,NULL,3,0,3,1,'RA184509040CN\r ','hermeshine\rXXL  已入库'),(24266,799572385001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0038761914941','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:16:43',0,NULL,3,1,3,1,'RA184519736CN ','hermeshine\r申报 $14'),(24267,844038974002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','xurde2010','xurdefs@gmail.com','MEDICENTRO - Jorge Fernández Sáez','Pz Humedal 6<br>Bajo','Gijón','Asturias','SPAIN','33207','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:17:23',0,NULL,3,1,11,1,'BJ01714497\r ','hermeshine'),(24268,799572561001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',39.8,'hermeshine','mcdebugger','mc_debugger@mail.ru','Maxim Kachur','ul. Volodarskogo, d. 34A, kv. 76','Ivanovo','Ivanovskaya obl','RUSSIAN FEDERATION','153022','+79023150144','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:17:26',0,NULL,3,1,3,1,'RA184509155CN\r ','hermeshine'),(24269,799593614001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','systemop63','oac1.6@mail.ru','Petr Grachev','Taskentskaya street 132-24','Samara','Samara','RUSSIAN FEDERATION','443095','+7 906 3451006','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 18:53:49',0,NULL,3,1,5,1,'CP244439520CN ','hermeshine'),(24270,929614745016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','nutzyflorian','florianraducu@yahoo.com','Bognar Iren','b-dul 21 decembrie 1989, No.140, Bl. X1<br>Ap.161','Cluj Napoca','Cluj','ROMANIA','400604','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-18 19:48:27',0,NULL,3,1,11,1,'BJ01714493\r ','hutongstore'),(24271,799620800001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','idan.tayree','idan_t@zahav.net.il','Adi Ezra','Ha\'anafa 17','Tel-Mond','','ISRAEL','40600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 20:01:37',0,NULL,3,1,3,1,'RA184524308CN\r ','hermeshine'),(24272,805858003018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',15.8,'photographyacc','mickwik71','michel.picard71@laposte.net','Michel PICARD','1197 Rue de Chalon','Virey le Grand','Bourgogne','FRANCE','71530','0614922406','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 20:13:35',0,NULL,3,0,11,1,'BJ01714498\r ','photographyacc\r欧标'),(24273,844120932002,120502180201,'Neoprene Protector Camera Cover Case Nikon D80 D90 M',1,'AC2304',6.24,'hermeshine','hsgs1976','heinesaeboe@hotmail.com','Heine Sæbø','Gruvevegen 46','Stord','Hordaland','NORWAY','5415','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 20:45:30',0,NULL,3,1,11,1,'BJ01714455\r ','hermeshine'),(24274,799655576001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','mickwik71','michel.picard71@laposte.net','Michel PICARD','1197 Rue de Chalon','Virey le Grand','Bourgogne','FRANCE','71530','0614922406','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 20:50:17',0,NULL,3,1,3,1,'RA184524121CN\r ','hermeshine'),(24275,949423683015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','alarmsafeuk','mcs1948@btinternet.com','Michael C Smith','15 Springwood avenue<br>West Bowling','Bradford','West Yorkshire','UNITED KINGDOM','BD58BY','01274371544','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-18 21:16:08',0,NULL,3,1,11,1,'BJ01714484\r ','hutongstore'),(24276,844137230002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','albanramadani','alban@envinion.com','Alban Ramadani','Rr. Bill Clinton Su5/8E Nr.41','Prishtina','Kosovo','ALBANIA','10000','+38649373738','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-18 21:18:01',0,NULL,3,1,3,1,'RA184524427CN\r ','hermeshine\r欧标'),(24277,844146416002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','lopos17','ricardo@serradolopo.com.br','Ricardo Rodrigues','Rua Tiradentes 296','Extrema','Minas Gerais','BRAZIL','37640 000',' 553534353357','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 21:38:37',0,NULL,3,1,3,1,'RA184524299CN\r ','hermeshine'),(24278,866257270017,270750650117,'Small size Lens Pouch Case fit 50mm f1.8 18-55mm New S',1,'AC1201',3.99,'photographyacc','terminator_no2','vx@quasar.me.uk','Dejan Vuksanovic','18A Nunnery Avenue','Droitwich Spa','Worcestershire','UNITED KINGDOM','WR9 8BJ','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-18 22:13:02',0,NULL,3,1,11,1,'BJ01714491\r ','photographyacc'),(24279,799723223001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','anstar04','coralryder@hotmail.com','Coral Ryder','2 Inchcape Road','Hartlepool','Cleveland','UNITED KINGDOM','TS25 3HF','01429423076','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-18 23:27:20',0,NULL,3,1,3,1,'RA184524342CN\r ','hermeshine'),(24280,949525256015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','kelvinjak','k31vin@hotmail.com','Kelvin Pak Jak Yong','2/15A, Collegelands, 10 Havannah Street','Glasgow Merchant City','Glasgow','UNITED KINGDOM','G4 0UB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 00:49:43',0,NULL,3,1,3,1,'RA184524268CN\r ','hutongstore'),(24281,929781689016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','gyn9388','glimbu9388@hotmail.com','Gyanendra Limbu 69388','2 RGR C COMPANY<br>TUKER LINES','SERIA','BRUNEI','BRUNEI DARUSSALAM','BFPO-11','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 01:16:52',0,NULL,3,1,11,1,'BJ01714462\r ','hutongstore'),(24282,844263403002,120819585584,'New Mini IR Wireless Remote Control for Pentax K10D K20D K100D K200D KX K7',1,'AD1118',3.3,'hermeshine','leebows','leebows01@bigpond.com','Lee Ellis','25 Tuena st','Mudgeeraba','Queensland','AUSTRALIA','4213','0755229843','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 03:25:00',0,NULL,3,1,2,1,'30122408212\r ','hermeshine'),(24283,844267515002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','cafe2020_com','john@eastsidesun.com','John Gilday','229 Wells Ave S<br># 123','Renton','WA','UNITED STATES','98057-2131','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 03:39:54',0,NULL,3,1,3,1,'RA184524285CN\r ','hermeshine'),(24284,799793312001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','tincho2248','smalltechnology@hotmail.com','MARTIN OTERO','AV JOSE MARIA MORENO 1457','CAPITAL FEDERAL','buenos aires','ARGENTINA','1424','54111567171220','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-19 03:45:00',0,NULL,3,0,3,1,'RA184509124CN\r ','hermeshine\rM'),(24285,799807673001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',5,'AC2302',31.05,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','(5411) 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 04:37:49',0,NULL,3,1,3,1,'RA184509138CN\r ','hermeshine'),(24286,929866185016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','blufotokat','hamiltonchurton@hotmail.com','Hamilton Churton','18A Old Berowra rd, Hornsby','Sydney','New South Wales','AUSTRALIA','2077','0294762180','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-19 06:10:20',0,NULL,3,1,11,1,'BJ01714502\r ','hutongstore'),(24287,866420406017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','bowley5','mark151189@hotmail.com','mark bowley','9 obrien street<br>davoren park','adelaide','South Australia','AUSTRALIA','5113','0421449675','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-19 07:55:07',0,NULL,3,1,3,1,'RA184519373CN\r ','photographyacc'),(24288,844334618002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','foto14lexa','lea.hult@luukku.com','Lea Hult','Metsänhoitajankuja 1 A 6','VANTAA','','FINLAND','01370','358500658717','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 08:53:46',0,NULL,3,1,3,1,'RA184519387CN\r ','hermeshine'),(24289,844351425002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','andresb2h','b2hmusic@yahoo.com','Andres Selgoja','Kuldse Kodu 5 - 277','Pärnu','Pärnumaa','ESTONIA','80035','+372 566 86 499','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 09:42:48',0,NULL,3,1,5,1,'CP244439516CN ','hermeshine\r欧标\r布换成白色的'),(24290,949699884015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','mrspitt33','cardiffkitten@gmail.com','karen  kozaczynski','188 the hawthorns<br>cyncoed','cardiff','south glamorgan','UNITED KINGDOM','cf23 7at','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 10:14:37',0,NULL,3,0,11,1,'BJ01715646\r ','hutongstore\r1.6*2.1  黑色'),(24291,799907804001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','alberto_monte','markspitz83@hotmail.com','ALBERTO MONTEAVARO PEREZ','Calle Amsterdam 14, 4ºA','OVIEDO','Asturias','SPAIN','33011','651049188','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 11:02:14',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24292,949727493015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',2.48,'hutongstore','cederberg1972','chc@damplokomotiv.dk','Christian Cederberg','Vigerslev Alle 176C, 3.sal','Valby, Copenhagen','','DENMARK','DK-2500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 11:03:35',0,NULL,3,1,11,1,'BJ01714499\r ','hutongstore'),(24293,929979879016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','fbuis','fbuis52@aliceadsl.fr','Francois Buis','221, route de Bourg','Dagneux','Rhône-Alpes','FRANCE','01120','04.78.06.38.83','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-19 11:19:36',0,NULL,3,1,11,1,'BJ01714500\r ','hutongstore'),(24294,804962218018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',2,'AE1202',9.8,'photographyacc','17southfilms','webmail@17south.com.au','Dan Wood','PO Box 2323','Broome','Western Australia','AUSTRALIA','6725','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-19 11:34:43',0,NULL,3,1,11,1,'BJ01714487\r ','photographyacc'),(24295,799924285001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','chad030708','richardpureza08@yahoo.com','Richard Pureza','National Lead Smelting Co. Ltd.<br>Road 313 corner Road 303','2nd Industrial Area, New Sanaiya','Riyadh','SAUDI ARABIA','11561','00966531237940','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 11:43:32',0,NULL,3,1,11,1,'BJ01714501\r ','hermeshine'),(24296,844401571002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','nik0d1n2012','nik0d1n@mail.ru','Александр Кутейницин','Россия, г. Самара, ул. Стара-Загора, д.114, кв. 125','Samara','самарская область','RUSSIAN FEDERATION','443087',' 89277548864','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-19 11:44:47',0,NULL,3,1,3,1,'RA184524047CN\r ','hermeshine'),(24297,799934638001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','nachetea36','ignacio_j00@hotmail.com','ignacio Rodriguez','C/Camino Viejo, nº51','Tegueste - S/C de Tenerife','Canarias','SPAIN','38280','626914230','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 12:05:41',0,NULL,3,1,3,1,'RA184525833CN ','hermeshine'),(24298,806197073018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'photographyacc','gaimardi','finelinefotos@gmail.com','matthew heeb','2/57 mattocks rd<br>burleigh waters','gold coast','Queensland','AUSTRALIA','4220','0755203302','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-19 13:02:44',0,NULL,3,1,3,1,'RA184525997CN ','photographyacc'),(24299,800001330001,110531023268,'JJC Leather Hand Strap Grip HS-3A D80 D90 40D',1,'AB1410',11.99,'hermeshine','matvita','tap85@yandex.ru','Tatyana Matvienko','Komsomolskaya st. 241b-35','Yushno-Sakhalinsk','','RUSSIAN FEDERATION','693023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 14:24:44',0,NULL,8,1,17,0,NULL,'hermeshine'),(24300,800001331001,110447567729,'Neoprene Protector Camera Cover for Nikon D700 D300s',1,'AC1303',7.5,'hermeshine','matvita','tap85@yandex.ru','Tatyana Matvienko','Komsomolskaya st. 241b-35','Yushno-Sakhalinsk','','RUSSIAN FEDERATION','693023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 14:24:45',0,NULL,8,1,17,0,NULL,'hermeshine\r'),(24301,800011892001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','liordrz','liordrz@gmail.com','Lior Darzi','3a Avizohar st<br>apartment 5','Jerusalem','Israel','ISRAEL','96267','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 14:47:25',0,NULL,3,1,3,1,'RA184529353CN\r ','hermeshine'),(24302,949923219015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','simi-f-e-d','simone1_dawson@hotmail.com','simone Dawson','Hendy<br>Llangoedmor','Cardigan','Ceredigion','UNITED KINGDOM','SA43 2LH','01239615774','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 16:08:41',0,NULL,3,1,3,1,'RA184519501CN\r ','hutongstore'),(24303,844543116002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','jimbo130567','james.f.hooper@gmail.com','JAMES HOOPER','46 SPRINGFIELD CRESCENT','DUDLEY','West Midlands','UNITED KINGDOM','DY27EX','07957252936','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-19 16:13:16',0,NULL,3,0,3,1,'RA184509053CN\r ','hermeshine\r3XL 已入库'),(24304,844544811002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','gacela_roja','chary.lucas@gmail.com','Chary Lucas Clar','C/ Pedro Cano Izquierdo, 10 - 3º A','Muchamiel','Comunidad Valenciana','SPAIN','03110','609682493','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 16:15:35',0,NULL,8,1,17,0,NULL,'hermeshine'),(24305,800068173001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','gacela_roja','chary.lucas@gmail.com','Chary Lucas Clar','C/ Pedro Cano Izquierdo, 10 - 3º A','Muchamiel','Comunidad Valenciana','SPAIN','03110','609682493','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 16:17:25',0,NULL,3,1,11,1,NULL,'hermeshine\r方形滤镜接口环 52mm  1\r方镜普通托架（三槽）  1\r无牌方镜 渐变灰 （nd8）   1'),(24306,930212446016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','tanb0017','philips170t@yahoo.com','BENG KEAT TAN','BLK 414 PANDAN GARDEN<br>#06-144','SINGAPORE','SINGAPORE','SINGAPORE','600414','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 17:04:56',0,NULL,3,1,2,1,'30122411270\r ','hutongstore'),(24307,844658230002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','haiqi','haiqi@protyle.com','Haiqi Fu','2117 Palomar Trace Dr','Lexington','KY','UNITED STATES','40513-1120','(859) 219-1176','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 18:31:08',0,NULL,3,1,3,1,'RA184519413CN\r ','hermeshine'),(24308,930306116016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','vintage.at.number.18','hello@no18maisonboutique.co.uk','Andy Robson','Studio 1, Squidgy Designs<br>18A Blandford Square','Newcastle','Tyne And Wear','UNITED KINGDOM','NE1 4HZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 18:32:43',0,NULL,3,1,3,1,'RA184524237CN\r ','hutongstore\r英标'),(24309,800182718001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',1,'AD1222',3.5,'hermeshine','jl51x','genshikenni@gmail.com','Jacky Liang','21 Foxden place','Ottawa','ON','CANADA','k1g6a5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 18:36:36',0,NULL,3,1,11,1,'BJ01714507\r ','hermeshine'),(24310,800201980001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','93svtcobrared','joedunkle@gmail.com','Joseph Dunkle','4461 Park Run CT','Riverside','CA','UNITED STATES','92505-5158','','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-02-19 18:55:03',0,NULL,3,1,4,1,'YW868897554CN ','hermeshine\r'),(24311,844699258002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','vain1979','inezenets@gmail.com','Иван Неженец','Tyumen, Sherbakova st. 142/3 19','Tyumen','Tyumenskaya','RUSSIAN FEDERATION','625031','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:09:53',0,NULL,3,1,3,1,'RA184519427CN\r ','hermeshine'),(24312,930363365016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','alan_grech','linu.grech@gmail.com','Alan Grech','International Hotel Investments plc<br>Europa Centre','Floriana','','MALTA','FRN1400','+35679211671','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 19:14:34',0,NULL,3,1,11,1,'BJ01714550\r ','hutongstore'),(24313,844704817002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','(844) 223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:13:55',0,NULL,8,1,17,0,NULL,'hermeshine'),(24314,800229008001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','mpapakyr','m.papakyriakou@softlab.ntua.gr','Michalis Papakyriakou','Anakreontos 6','Athens','Athens','GREECE','11633','+302107722476','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:18:47',0,NULL,3,1,11,1,'BJ01714454\r ','hermeshine'),(24315,844712213002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','dreamwalker90','crazy_edvin@hotmail.com','Edvin Kalic','Zeljeznicka b.b.','Sanski Most','','BOSNIA AND HERZEGOVINA','79260','+38761754086','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:22:41',0,NULL,3,1,3,1,'RA184525921CN ','hermeshine'),(24316,628391727004,140679559505,'Promotion ! NEW Square Gradual Graduated Brown Color Filter for Cokin P Series',1,'AD1227',3.5,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','(844) 223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:29:06',0,NULL,8,1,17,0,NULL,'hermeshine'),(24317,844719363002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','(844) 223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:29:07',0,NULL,8,1,17,0,NULL,'hermeshine'),(24318,844719364002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','denisdryashkin','dryashkin@gmail.com','Denis Dryashkin','pr. Lenina, d.48/2, kv.32','Volgograd','RU','RUSSIAN FEDERATION','400005','(844) 223-5287','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 19:29:07',0,NULL,3,1,3,1,'RA184524118CN\r ','hermeshine\r斜臂   1\r无牌方镜 渐变棕   1\r无牌方镜 渐变日落   1\r无牌方镜 渐变蓝   1'),(24319,800275467001,110489671880,'NEW 72mm Snap-on Front Lens Cap for Nikon 72 Lenscap',2,'AA1308',5.2,'hermeshine','hendricus02','hazenleger@skynet.be','Henry de Haas','budelpoort 40','Hamont','','BELGIUM','3930BE','0653358229','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 20:10:48',0,NULL,3,1,11,1,'BJ01714495\r ','hermeshine'),(24320,844760321002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','bandoggy','alexander_duelli@gmx.at','Heidi Duelli','Pfarrer Allgäuerweg 16','Feldkirch','','AUSTRIA','6800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 20:13:17',0,NULL,3,1,3,1,'RA184524149CN\r ','hermeshine'),(24321,930068927016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','tabs4life','tab4lifes@gmail.com','Denis Vesely','Sevcenkova 19','Bratislava','','SLOVAK REPUBLIC','851 01','00421 908 636 785','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-19 19:47:22',0,NULL,3,1,11,1,NULL,'hutongstore'),(24322,930442369016,260676114483,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',32.99,'hutongstore','terryrodell','terryrodell@eircom.net','Terry Smith','10 Cappaneale','Birr','Offaly','IRELAND','default','0862094902','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 20:24:05',0,NULL,3,1,3,1,'RA184524206CN\r ','hutongstore'),(24323,800324745001,110464631160,'Small size Lens Pouch / Case fit 50mm 1.8 18-55mm',1,'AC1201',4.9,'hermeshine','ndouvris','ndouvris@yahoo.com','Nicolette Douvris','PO BOX 111','Pahoa','HI','UNITED STATES','96778-0111','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 21:14:07',0,NULL,3,1,1,1,'LK200513990CN\r ','hermeshine'),(24324,800313781001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','bazhenova.53','bazhenov.73@yandex.ru','Tatiana Bazhenova','140-23<br>Vorovskogo','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426063','+79225202404','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 21:25:48',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24325,844819242002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','khaled2013','k.benedah@gmail.com','khaled al otibi','twaqe - alghadeer street<br>B.O.BOX 6337-14914-2749','RIYADH','Riyadh','SAUDI ARABIA','14914','00966569614500','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-19 21:29:18',0,NULL,3,0,3,1,'RA184508968CN\r ','hermeshine\rL  已入库'),(24326,930507035016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','bochmacher','col@lisboa67.wanadoo.co.uk','colin w mcclure','2  abbot street','maybole','Strathclyde','UNITED KINGDOM','ka197bq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 21:33:45',0,NULL,3,1,2,1,'30122410452\r ','hutongstore'),(24327,800340187001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','thkr23','thkr_23@hotmail.com','Thor Oeyvind Kristiansen','Verksgata 24','Oslo','OSLO','NORWAY','0566','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 21:36:22',0,NULL,3,1,3,1,'RA184524183CN\r ','hermeshine'),(24328,844832882002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','rmshort1958','rmshortmd@hotmail.com','Ronald Mark Short','616 W Forest Ave','Jackson','TN','UNITED STATES','38301-3902','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-19 21:49:53',0,NULL,3,1,3,1,'RA184525881CN ','hermeshine'),(24329,800353310001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','mialko','mi_al@front.ru','Alena Chebotareva','Ispitateley prospect, 33-107','Saint-Petersburg','','RUSSIAN FEDERATION','197349','7-921-397-7151','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 21:56:29',0,NULL,3,1,11,1,NULL,'hermeshine'),(24330,930535318016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','sydceller','sydneybowling@hotmail.com','sydney bowling','1 Beale House<br>45 Lingham Street','London','London','UNITED KINGDOM','SW9 9HG','07985335903','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-19 22:14:26',0,NULL,3,0,3,1,'RA184508954CN\r ','hutongstore\r2XL 已入库'),(24331,842833802002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mayamodeler','berniewempe@gmail.com','Bernie Wempe','6190 Lakeview Ave','Burnaby','BC','CANADA','V5E 2P2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 22:45:13',0,NULL,8,1,17,0,NULL,'hermeshine'),(24332,844298741002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mayamodeler','berniewempe@gmail.com','Bernie Wempe','6190 Lakeview Ave','Burnaby','BC','CANADA','V5E 2P2','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-19 22:45:13',0,NULL,3,1,3,1,'RA184519435CN\r ','hermeshine\r伞式柔光箱 60×90cm   2'),(24333,950358598015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','astreazul','yolatmartin@yahoo.es','yolanda martín','la mina, 11,barberà del vallés','barcelona','Cataluña','SPAIN','08210','620228745','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-19 23:50:55',0,NULL,3,1,11,1,'BJ01714488\r ','hutongstore'),(24334,806682338018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',20,'photographyacc','nunzio7930','ndan@optusnet.com.au','Nunzio D\'Angelo','20 Lobb Street','Coburg','Victoria','AUSTRALIA','3058','0425709423','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 00:47:48',0,NULL,3,1,11,1,'BJ01714510\r ','photographyacc'),(24335,800466571001,110807100036,'Promotion ! NEW 3pcs Square ND2+ND4+ND8 Neutral Density Filter Kit for Cokin P',1,'AKT096',13.88,'hermeshine','pigusso','mr.pratya@gmail.com','PRATYA TOYAI','21/141 Soi.Chinnaket2, Ngamwongwan Road, ','Laksi','Bangkok','THAILAND','10210','66814288455','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 02:33:34',0,NULL,3,1,11,1,'BJ01714459\r ','hermeshine'),(24336,8881329705694272,111,'永诺 SF18- NIKON SB800',1,'AB3309',0,'hermeshine','piotrpj','piotr.jaruga@gmail.com','Piotr Jaruga','Lędzian 100','Lublin','lubelskie','POLAND','20828','501 386497',NULL,NULL,NULL,'2012-02-20 02:41:34',0,NULL,3,1,3,1,'RA184519719CN ','这个有单号\rRA184519719CN'),(24337,8881329707298448,111,'Free shipping & Tracking # - New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.98,'aliexpress','1006866929','paulinemcken@videotron.ca','Remy Savard','16 Rue Albert-Trudel','Quebec','','CANADA','G2A 2R9','+1 418 845-1397',NULL,NULL,NULL,'2012-02-20 03:08:18',0,NULL,3,1,3,1,'RA184508910CN\r ',NULL),(24338,800509475001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','srx3cheergirl','screilly91@gmail.com','Shannon Reilly','2952 Thunderhead Rd','Roslyn','PA','UNITED STATES','19001-2228','(215) 421-6683','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-20 04:54:14',0,NULL,3,0,1,1,'LK200486906CN\r ','hermeshine\r1.6*2.1  黑色'),(24339,806762397018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','kiahandcharlie','tom-kez@bigpond.net.au','Kerry Devereaux','4 Whiteley Circuit','Baranduda','Victoria','AUSTRALIA','3691','0260208300','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 04:54:24',0,NULL,3,1,11,1,'BJ01714461\r ','photographyacc'),(24340,845002948002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','ppnc12','pollux_chung@yahoo.com','Pollux Chung','3019 Graveley Street','Vancouver','BC','CANADA','V5K 3K5','(604) 258-9498','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 05:42:22',0,NULL,3,1,3,1,'RA184524095CN\r ','hermeshine'),(24341,845020837002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','matvita','tap85@yandex.ru','Tatyana Matvienko','Komsomolskaya st. 241b-35','Yushno-Sakhalinsk','','RUSSIAN FEDERATION','693023','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 07:19:30',0,NULL,3,1,3,1,'RA184524339CN\r ','hermeshine\rJJC 腕带  JJC-3A  1\r大号内胆包 nikon   1 \r2mx1.5m 背景板（黑，白）   1'),(24342,845021095002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','shimishake','advanshimi@gmail.com','shimi amrani','inbar 4','rosh ha\'ain','israel','ISRAEL','48542','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 07:21:45',0,NULL,3,1,3,1,'RA184519489CN\r ','hermeshine'),(24343,950532653015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','rocifoto01','rocifoto@citromail.hu','Balogh Roland','Előre<br>utca 2','Dunapataj','Bács-Kiskun','HUNGARY','6328','+36703375385','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 08:21:46',0,NULL,3,1,3,1,'RA184524930CN ','hutongstore'),(24344,867199705017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',1,'AA2326',15.8,'photographyacc','darrylcramd29','cazndaz1@bigpond.com','Darryl Cram','29 Balmoral street','Portland','Victoria','AUSTRALIA','3305','0355234856','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-20 08:25:52',0,NULL,3,1,11,1,'BJ01714505\r ','photographyacc'),(24345,930758240016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','janika535','janos.tar85@gmail.com','Janos Tar','Hajdudorog<br>Matyas krt. 57.','APO','AP','HUNGARY','4087','(+36)703-889852','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 08:19:27',0,NULL,3,1,11,1,'BJ01714460\r ','hutongstore'),(24346,628625484004,140642546050,'New Swivel Flash Mount Umbrella Bracket for studio  Light Stand D',1,'AD1122',13.8,'hermeshine','jmm01972','javier.monteromartinez@gmail.com','Javier Montero','Velazquez 12<br>Planta 1','Madrid','MADRID','SPAIN','28001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:02:11',0,NULL,3,1,17,0,NULL,'hermeshine'),(24347,845037663002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','jmm01972','javier.monteromartinez@gmail.com','Javier Montero','Velazquez 12<br>Planta 1','Madrid','MADRID','SPAIN','28001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:02:11',0,NULL,3,1,17,0,NULL,'hermeshine'),(24348,845036843002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','jmm01972','javier.monteromartinez@gmail.com','Javier Montero','Velazquez 12<br>Planta 1','Madrid','MADRID','SPAIN','28001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:02:17',0,NULL,3,1,17,0,NULL,'hermeshine'),(24349,845036586002,120792111172,'11\" Articulating Magic Arm + 15KG Supper Heavy Clamp for LCD Monitor / LED light',1,'AKT089',55,'hermeshine','jmm01972','javier.monteromartinez@gmail.com','Javier Montero','Velazquez 12<br>Planta 1','Madrid','MADRID','SPAIN','28001','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-20 09:02:18',0,NULL,3,1,17,0,NULL,'hermeshine'),(24350,800554885001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',37.98,'hermeshine','jmm01972','javier.monteromartinez@gmail.com','Javier Montero','Velazquez 12<br>Planta 1','Madrid','MADRID','SPAIN','28001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 09:02:17',0,NULL,3,1,4,1,'YW867610996CN ','hermeshine\r闪光灯D座   1\r4灯头 灯头 孔   1\r肥皂盒 柔光罩   580EX  1\r魔术手臂11寸   1\r新款15kg大力夹   1\r45w 5500k 灯泡 220v  4'),(24351,800576413001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','skilletbay','jacques@lesco.co.za','Jacques Wainwright','2nd Floor, OVK Building<br>c/o Mcabe & Erwee Street','Ficksburg','Freestate','SOUTH AFRICA','9730','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:22:24',0,NULL,3,1,3,1,'RA184524104CN\r ','hermeshine'),(24352,800576821001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','heather990_0','shukey2001@yahoo.com','Heather SHuker','47 Coleman street','Brighton','East Sussex','UNITED KINGDOM','bn2 9sq','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:23:24',0,NULL,3,1,3,1,'RA184524360CN\r ','hermeshine'),(24353,845070053002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','10gsa','flaviojc@hotmail.com','Flavio Cañoto','C.Cañada Real 37 B18 4ºE','Colmenarejo','Madrid','SPAIN','28270','622473350','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-20 10:47:58',0,NULL,3,1,21,1,'RA184524170CN\r ','hermeshine'),(24354,800585013001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',33.9,'hermeshine','georgedubbyabush','thaimls@gmail.com','Graeme Henderson','Unit 307 28-30 Flinders Street<br>Darlinghurst','Sydney','New South Wales','AUSTRALIA','2010','04669965555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 10:52:49',0,NULL,3,1,3,1,'RA184524078CN\r ','hermeshine'),(24355,867239950017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',200,'photographyacc','cat_beauty','jskamppi@hotmail.com','Sari Kamppi','11 Napthali Close','Charnwood','Australian Capital Territory','AUSTRALIA','2615','','PayPalPaymentInProcess','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'photographyacc\r澳标'),(24356,947010091015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','linas565','linas@paintbaleris.lt','Linas NAVARDAUSKAS','TAIKOS pr. 84-54','Kaunas','LITHUANIA','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 11:19:31',0,NULL,3,1,3,1,'RA184525904CN ','hutongstore'),(24357,845080448002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','clicknshop2011','nath.shirley@gmail.com','Hirman','245 Sunshine Road','Tottenham','Victoria','AUSTRALIA','3012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 11:27:44',0,NULL,3,1,3,1,'RA184524254CN\r ','hermeshine'),(24358,950622874015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','michael16-42','mj.watts@btinternet.com','Michael Watts','16 Hill park<br>Congresbury','Nr Bristol','Somerset','UNITED KINGDOM','BS49 5BT','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-20 12:46:31',0,NULL,3,1,4,1,'YW868897532CN ','hutongstore\r+1.6*2.1  白布'),(24359,800530187001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','polarer24','reot@bk.ru','ILYA Egorov','Sudostroitelnaya st.<br>dom 109, kv. 197','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660012','+79659146584','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 12:56:49',0,NULL,3,1,11,1,'、 ','hermeshine'),(24360,930728318016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','brairma','bra_man7@hotmail.com','Bryan Lee','unit 4 number 5 Henry Street','East Cannington','Western Australia','AUSTRALIA','6107','0424363640','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 13:12:42',0,NULL,3,1,4,1,'YW868897576CN ','hutongstore'),(24361,930861581016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','missvalley1','glamourandpixieduststudios@gmail.com','linda hutchinson','24 westcliff place northfield','birmingham','West Midlands','UNITED KINGDOM','b311qj','07970985978','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 13:21:09',0,NULL,3,0,3,1,'RA184524413CN\r ','hutongstore\r1.6*3  白色'),(24362,845119038002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','pkritsin','pavel.kritsin@gmail.com','Pavel Kritsin','Genkinoy str, 82-17','Nizhny Novgorod','','RUSSIAN FEDERATION','603024',' 79601727000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 13:38:01',0,NULL,3,1,11,1,'BJ01714458\r ','hermeshine'),(24363,930869023016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','acornsareus','celticlittleacorns@googlemail.com','linz mccann','1 CARSEVIEW','tullibody','Clackmannan','UNITED KINGDOM','fk102sr','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-20 13:39:38',0,NULL,3,1,12,1,'3125535652 ','hutongstore\r英标'),(24364,800635928001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','ernest_photography','ben.ernst.barnard@gmail.com','Ben Barnard','1 gairloch st<br>applecross','perth','Western Australia','AUSTRALIA','6153','6141700900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 13:47:46',0,NULL,3,1,2,1,'30122407254\r ','hermeshine'),(24365,950648564015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','delihayatx','delihayat@gmail.com','Sinan Dönmez','ALTINSEHIR MH. 305. SK. NO:8 SARISOY SITESI A BLOK DAIRE: 3 NILUFER','BURSA','0','TURKEY','16120','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 13:50:26',0,NULL,3,1,3,1,'RA184526003CN ','hutongstore'),(24366,930885463016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','radtweak','jasonsmith.15@blueyonder.co.uk','Jason Smith','Flat 3 , 19 Claremont Gardens','Surbiton','Surrey','UNITED KINGDOM','KT6 4TL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 14:19:19',0,NULL,3,1,11,1,'BJ01714506\r ','hutongstore'),(24367,845166491002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',3,'AA1305',7.8,'hermeshine','sj-manning','arrow.of.jade@gmail.com','skyler Hoffos','52255 Range Road 213','Sherwood Park','AB','CANADA','T8G 1B6','(780) 922-5303','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 15:48:25',0,NULL,3,1,11,1,'BJ01714504\r ','hermeshine'),(24368,800682658001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','dimidrol_852012','dimidrol_85@bk.ru','Dmitry Syshchikov','Kalinin prospectus, 22-8','Barnaul','Altaysky','RUSSIAN FEDERATION','656011',' 9236613640','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 16:00:19',0,NULL,3,1,3,1,'RA184524356CN\r ','hermeshine'),(24369,950739457015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','totalpears','pbartlett2@sky.com','PAUL BARTLETT','210,BUTTS ROAD<br>SHOLING','SOUTHAMPTON','Hampshire','UNITED KINGDOM','SO19 1BQ','02380431642','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 16:52:50',0,NULL,3,1,3,1,'RA184519492CN\r ','hutongstore'),(24370,950752763015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','ribatejano','capeleiromiguel@gmail.com','Miguel Bento','Rua Combatentes do Ultramar nº 8 Rc Frt','Cartaxo','','PORTUGAL','2070-089','+351914907691','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 17:15:51',0,NULL,3,1,11,1,'BJ01714552\r ','hutongstore'),(24371,930987909016,260901272264,'New Tungsten bulb 800W for redhead light X 1 3200K 220V',1,'AO0015',4.5,'hutongstore','capaca_em','emilie.atkinson@gmail.com','Emilie Atkinson','12 Orwell Gardens','Rathgar','Dublin','IRELAND','6','0863627870','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-20 17:39:27',0,NULL,3,1,11,1,'BJ01714544\r ','hutongstore'),(24372,950780093015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','dmikasin','hihihihi@net.hr','Dejan Mikašinović','Kasar 19','Duga Resa','Karlovac','CROATIA','47250',' 0958007323','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 18:00:03',0,NULL,3,1,11,1,'BJ01714545\r ','hutongstore'),(24373,845230170002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','salvador709','spv11@hotmail.com','Salvador Peralta','2370 Rue Gold<br>Apartment 209','Saint-Laurent','QC','CANADA','H4M1S4','(514) 658-9083','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 18:18:30',0,NULL,3,1,11,1,'BJ01714492\r ','hermeshine'),(24374,950796717015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','albert0829','albertbekman@hotmail.com','A. Bekman','Pruylenborg 182','Zwijndrecht','','NETHERLANDS','3332 PE','0031 6 54761619','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-20 18:24:23',0,NULL,3,1,3,1,'RA184524271CN\r ','hutongstore'),(24375,845275473002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','chapaev13','goncharenko1@narod.ru','Aleksey Goncharenko','pr-t Lenina  22 - 48','Yaroslavl','Yaroslavl','RUSSIAN FEDERATION','150054','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 19:28:10',0,NULL,3,1,11,1,'BJ01714490\r ','hermeshine'),(24376,800785493001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','dary1234','zhenwen@live.com.au','Joseph  Gan','21 Goodhart Cres','Dunlop','Australian Capital Territory','AUSTRALIA','2615','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 19:30:25',0,NULL,3,1,11,1,'BJ01714509\r ','hermeshine'),(24377,931072970016,260894475632,'43\" Dual double layer reflective and translucent soft  umbrella 110cm',1,'AD1157',18,'hutongstore','cyborgrd','oleg.meier@gmail.com','Oleg  Meier','Grevesmuehlener Str. 28','Berlin','','GERMANY','13059','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 19:41:16',0,NULL,3,1,11,1,'BJ01714456\r ','hutongstore'),(24378,800796273001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','utinmaxim','maximutin@rambler.ru','Максим Утин','ул. Полиграфическая, дом 69 кв. 56','Энгельс','Саратовская обл','RUSSIAN FEDERATION','413115','+9172110000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 19:54:10',0,NULL,3,1,11,1,'BJ01714503\r ','hermeshine'),(24379,800800228001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','shoppbrx','vendascomph@yahoo.com.br','wagner andrade','Dr. muricy 839  ap 154','curitiba','parana','BRAZIL','80020040','4185024177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 19:55:52',0,NULL,3,1,11,1,'、 ','hermeshine'),(24380,800810573001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','eech1158','eduardojosejulio@gmail.com','Eduardo Echaguibel Fernandez','Honduras 1 10º F','Vitoria','País Vasco','SPAIN','01009','945 273 281','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 20:40:43',0,NULL,3,1,3,1,'RA184524387CN\r ','hermeshine'),(24381,800808706001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','jozsi65','1nemethjozsi@gmail.com','József Németh','Sulyok u. 1.','Budapest','','HUNGARY','1031','+36-30-988-24988','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-20 20:14:14',0,NULL,3,1,3,1,'RA184508971CN\r ','hermeshine\r欧标'),(24382,800841496001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','modelfotograaf','hobbyfotograaf@home.nl','Richard Endstra','Statensingel 37','Maastricht','','NETHERLANDS','6211 PL','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 21:06:51',0,NULL,3,0,11,1,'BJ01715645\r ','hermeshine\r1.6*2.1   黄色'),(24383,931146763016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','scic_123','atlesl@broadpark.no','Atle Slettingdalen','Kodalveien 506','Kodal','','NORWAY','3243','+4791176939','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 21:28:51',0,NULL,3,1,3,1,'RA184524020CN\r ','hutongstore'),(24384,931151041016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','chrisyking','bisherltd@yahoo.co.uk','Chris C King','14a Essex Road<br>Watford','LONDON','London','UNITED KINGDOM','WD17 4EP','07769504882','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 21:29:28',0,NULL,3,1,11,1,'BJ01714489\r ','hutongstore'),(24385,845365188002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','fitole55','fitole5@hotmail.com','alejandro vega perdomo','la higuera n 6 tinajo lanzarote','tinajo lanzarote','Canarias','SPAIN','35560','928 840182','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-20 22:11:11',0,NULL,3,1,21,1,'RA184524135CN\r ','hermeshine'),(24386,950965757015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','shreyhull','agrawal.shrey@gmail.com','Shrey Agrawal','Flat 315, The Vista Building<br>30 Calderwood Street','London','London','UNITED KINGDOM','SE186JK','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 22:27:57',0,NULL,3,1,11,1,'BJ01714494\r ','hutongstore'),(24387,845382122002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',41.5,'hermeshine','liveinstylerus','agapovstudio@gmail.com','Evgeny Baranov','Planernaya 45-1-238','Saint-Petersburg','','RUSSIAN FEDERATION','197373','89062452268','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 22:50:56',0,NULL,3,1,3,1,'RR184524458CN ','hermeshine'),(24388,950980234015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','ull059','johnbt92@yahoo.co.uk','John Beattie','Kings Laggan<br>Gatehouse of Fleet','Castle Douglas','Dumfries and Galloway','UNITED KINGDOM','DG7 2HQ','07958380648','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-20 22:56:20',0,NULL,3,1,11,1,'BJ01714547\r ','hutongstore'),(24389,800894493001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','libby_anne','libbyanne1@gmail.com','Elizabeth Krzyzkowski','8 Teri Street','Frankston','Victoria','AUSTRALIA','3199','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-20 23:05:19',0,NULL,3,1,11,1,' ','hermeshine'),(24390,931207735016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',2.9,'hutongstore','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 23:17:04',0,NULL,3,1,17,0,NULL,''),(24391,931207348016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-20 23:17:05',0,NULL,3,0,3,1,'RA184524492CN\r ','hutongstore\r气吹 + 布  1\r摄影背心 黑色厚 无字 2XL  已入库\r'),(24392,800901208001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','sboxer','bruinista@gmail.com','James Le','20572 E Peach Blossom Rd','Walnut','CA','UNITED STATES','91789-4449','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-20 23:22:21',0,NULL,3,1,1,1,'LK200556385CN\r ','hermeshine'),(24393,845438509002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',5,'AD1226',17.5,'hermeshine','alex_lx4','lxa4@yandex.ru','Alexey Chernyshov','Pushkinskaya str. 68-83','Vladivostok','Primorskiy kr','RUSSIAN FEDERATION','690001','+79147901077','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 01:45:30',0,NULL,3,1,3,1,'RA184523554CN ','hermeshine'),(24394,8881329791551422,111,'Free shipping & Tracking # - New Camera bag topload D3 for Sony A550 A330',1,' AD1102',9.99,'aliexpress','1006885037','490376@mail.ru','Pavel Yakovlev','Voroshilova 4A - 96','Togliatti','Samarskaya','RUSSIAN FEDERATION','445042','+7 8482 490376',NULL,NULL,NULL,'2012-02-21 02:32:31',0,NULL,3,1,3,1,'RA184523395CN ',NULL),(24395,8881329791701708,111,'Free shipping & Tracking # - New Camera shoulder bag a1 for Canon 500D 550D 7D',1,'AO0029',25.99,'aliexpress','1006882732','huynht02@hotmail.com','Tony','10 Timbercrest Road, Thornlie','Perth','Western Australia','AUSTRALIA','6108','+61 08 93490893',NULL,NULL,NULL,'2012-02-21 02:35:01',0,NULL,3,1,3,1,'RA184523381CN ',NULL),(24396,800969551001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','toyz_joe','jaffyjaf99@hotmail.com','Joe Fleury','356, av. Fiset','Donnacona','QC','CANADA','G3M 2P5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 03:14:07',0,NULL,3,1,3,1,'RA184524152CN\r ','hermeshine'),(24397,807259023018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.43,'photographyacc','case540','lukecasey2003@yahoo.ca','Luke Casey','13 Boyanda St','Wishart','Queensland','AUSTRALIA','4122','0731629667','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 03:20:23',0,NULL,3,1,2,1,'30122410286\r ','photographyacc'),(24398,845483627002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','pringajp','nakagami@cslabo.co.jp','Noboru Nakagami','457-22 Hazama-cho','Kasugai-shi','Aichi','JAPAN','4870031','090-3932-4025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 04:21:31',0,NULL,3,1,6,1,'EE651291493CN\r ','hermeshine\r2.4x3m背景架  1\r1.6*2.1  白色布  1\r1.6*3  灰色布  1\r1.6*3  黑色布  1'),(24399,845484559002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','gorey131','gorey@onthenet.com.au','Mark Gore','15 Wattle Glen Place','Robina','Queensland','AUSTRALIA','4226','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 04:27:15',0,NULL,3,1,11,1,'BJ01714453\r ','hermeshine'),(24400,845486340002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','pringajp','nakagami@cslabo.co.jp','Noboru Nakagami','457-22 Hazama-cho','Kasugai-shi','Aichi','JAPAN','4870031','090-3932-4025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 04:33:43',0,NULL,3,0,17,0,NULL,'hermeshine'),(24401,845489660002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','pringajp','nakagami@cslabo.co.jp','Noboru Nakagami','457-22 Hazama-cho','Kasugai-shi','Aichi','JAPAN','4870031','090-3932-4025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 04:48:15',0,NULL,3,0,17,0,NULL,'hermeshine'),(24402,0,270910040035,'Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',81.96,'photographyacc','wicanc','luluatnc@gmail.com','Jason Lu','909 Eagle Hts<br>null','Madison','WI','UNITED STATES','53705-1611','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 05:10:49',0,NULL,3,0,1,1,'、 ','photographyacc'),(24403,8881329802148359,111,'柔光箱 50-70cm 单灯头',1,'',0,'hermeshine','arolen','davidfanego@davidfanego.es','David Fanego','C/Grañón, 24 5º 2ª','Madrid','Madrid','SPAIN','28050','620959168',NULL,NULL,NULL,'2012-02-21 05:29:08',0,NULL,3,0,3,1,'RA184509075CN\r ','已入库 '),(24404,845486509002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','pablovallejos87','jvallejos@berklee.net','Hugo Mika','1103 Oak Ave','Prospect Heights','IL','UNITED STATES','60070-1026','(847) 215-7831','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 06:28:05',0,NULL,3,1,1,1,'LK200507583CN\r ','hermeshine'),(24405,845508509002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','farrjc55','farrjc@hotmail.com','Justin Farr','1929 Gordon Ave','Lansing','MI','UNITED STATES','48910-2425','(517) 927-3384','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 06:28:35',0,NULL,3,1,3,1,'RA184524055CN\r ','hermeshine'),(24406,801010066001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','garvis','garvikas@gmail.com','Arvydas Gurkšnis','Dariaus ir girėno g. 60, Salantai','Salantai','Kretinga','LITHUANIA','97324',' 862385022','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 06:31:12',0,NULL,3,1,3,1,'RA184524395CN\r ','hermeshine'),(24407,8881329808069712,111,'三个灯架底座',1,'',0,'hutongstore','abajec5','ales.bajec78@gmail.com','ALES BAJEC','CESTA IX. KORPUSA 18','AJDOVSCINA','','SLOVENIA','5270','0038641605117',NULL,NULL,NULL,'2012-02-21 07:07:49',0,NULL,3,1,3,1,'RA184525983CN\r ',NULL),(24408,8881329808133448,111,'伞式柔光箱 80cm 8角   柔光布',1,'',0,'photographyacc','lethargy_com_au','bartek.czyz@gmail.com','Bart Czyz','2/4 Westgate Ave','Albion','Victoria','AUSTRALIA','3020','0430036749',NULL,NULL,NULL,'2012-02-21 07:08:53',0,NULL,3,0,3,1,'RA184525918CN ',''),(24409,801018892001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','digital_art_01','manuelcab94112@hotmail.com','manuel caballero','1261 Pine Creek way apt H','concord','CA','UNITED STATES','94520','','NoPaymentFailure','CheckoutComplete','Other','2012-02-21 07:21:13',0,NULL,3,0,1,1,'LK201226536CN ','hermeshine\r2XL  已入库'),(24410,801019646001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','thumb5650','thumb25@hotmail.com','Aree Boonyayatra','970/17 Udomsuk24 Sukumvit103 Bangna','Bangna','Bangkok','THAILAND','10260','66813467871','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 07:26:41',0,NULL,3,1,2,1,NULL,'hermeshine'),(24411,801023073001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','brooksa-2008','brooksa@netspace.net.au','Austin Brooks','C/- St George U/W, 75 North Lake Road','Myaree','Western Australia','AUSTRALIA','6154','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 07:44:17',0,NULL,3,1,3,1,'RA184523378CN\r ','hermeshine\rXL  已入库'),(24412,845531049002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','chavaoth','europost2006@mail.ru','Alexey Korovkin','Mihailova, 8-21','Moscow','','RUSSIAN FEDERATION','109428','+7(905)155-0344','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 08:25:04',0,NULL,3,1,3,1,'RA184523364CN ','hermeshine'),(24413,931379840016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','kupacup1925','kirasir08@yandex.ru','ALEKSANDR SHUT','Centralnaja dom 8 kv.33','KASHIRA','Moscow region','RUSSIAN FEDERATION','142904','(916)775-9744','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 08:47:12',0,NULL,3,1,11,1,NULL,'hutongstore'),(24414,807329762018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','sufertashu','mihai.stanimir@gmail.com','Mihai Stanimir','Petre Ramneantu nr 15A ap 12','Timisoara','Timis','ROMANIA','300595','0040764177508','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 08:49:51',0,NULL,3,0,11,1,' ','photographyacc\r1.6*2.1  白色'),(24415,801033166001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','luv_me_10der','jeniferi@hotmail.com','Jenifer Dickinson','5 Temby Road','Iona','Victoria','AUSTRALIA','3815','0407545296','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-21 08:58:25',0,NULL,3,1,4,1,'YW867610856CN\r ','hermeshine'),(24416,807340772018,280666794780,'New Camera shoulder bag D1 for Canon 450D 500D 550D',1,'AO0031',19.99,'photographyacc','triplet_papa','speedymars_52@hotmail.com','Marina Papalitsas','18 Chevalier Cres','Mooroolbark','Victoria','AUSTRALIA','3138','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-21 09:34:36',0,NULL,3,1,3,1,'RA184523404CN ','photographyacc'),(24417,951178259015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','auber2gine','ed@edphoto.com','Ed Horwich','18 Guest Road','Manchester','Greater Manchester','UNITED KINGDOM','M25 3DL','07976407472','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 09:39:00',0,NULL,3,1,17,0,NULL,'hutongstore'),(24418,951179875015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','auber2gine','ed@edphoto.com','Ed Horwich','18 Guest Road','Manchester','Greater Manchester','UNITED KINGDOM','M25 3DL','07976407472','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 09:42:52',0,NULL,3,1,3,1,'RA184524926CN ','hutongstore\r伞式柔光箱 80cm 8角    1\r反光板支架  1'),(24419,8881329818541009,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included - Wholesale/ Retail ',1,'AC2403',33.99,'aliexpress','1006896157 ','tildalina@gmail.com','Alina Nazarova','Letchika Kolesnichenko, 44a, 93','Voronezh','','RUSSIAN FEDERATION','394055','+8 920 2197353',NULL,NULL,NULL,'2012-02-21 10:02:21',0,NULL,3,1,3,1,'RA184524550CN\r ',NULL),(24420,8881329820174536,111,'1600W 套装',1,'AKT039',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-02-21 10:29:34',0,NULL,3,1,12,1,'3125477471 ','灯泡110V\r泡重7.7 \rFco Xavier Hernández Gtz\rCalle Jardines # 4 Yabuku Ajusco\rMexico Federal District Delegation Tlalpan Federal Distrito Federal  14200\rMexico City.\rMexico.\r(52 55) 56 45 39 74\r\r\r\r '),(24421,931414543016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',2,'AD1182',92,'hutongstore','jeanlime','jean-elie.eftekhari@hotmail.fr','jean elie eftekhari','10 rue arago','toulouse','Midi-Pyrénées','FRANCE','31500','0603872550','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 10:38:36',0,NULL,3,1,4,1,'YW867610860CN\r\r ','hutongstore'),(24422,951231023015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','william10terry','t_bewsey@sky.com','terry bewsey','36 lee way<br>glashougton','castleford','West Yorkshire','UNITED KINGDOM','wf10 4tq','01977513405','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-21 12:13:58',0,NULL,3,1,4,1,'YW867610871CN\r ','hutongstore\r英标'),(24423,845618330002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','hseut','hans.seuters@home.nl','Primaned / Hans Seuters','PO Box 247','Capelle ad IJssel','','NETHERLANDS','2900AE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 13:53:44',0,NULL,3,1,11,1,NULL,'hermeshine'),(24424,845122317002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','kkpoligon21','kkpoligon@mail.ru','Nikolay Shapoval','Nikopolska str. 36-140','Dneprodzerzhinsk','_UAES_NULL_','UKRAINE','51906',' 80633685902','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 13:57:04',0,NULL,3,1,21,1,'RA184523497CN ','hermeshine\rSAL挂号便宜6块钱。\r利润少，sal 合适一些'),(24425,796894373001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','ecaron50','etienne.snow@hotmail.com','Etienne Caron','11450 26e avenue','st-georges','QC','CANADA','G6A 1E7','(418) 227-0289','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 14:45:32',0,NULL,3,1,11,1,'BJ01669360 ','hermeshine'),(24426,845639869002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 14:57:48',0,NULL,3,1,3,1,'RA184524872CN ','hermeshine\r申报  gift   $25\r应该是发了  但是没单号'),(24427,845639870002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 14:57:49',0,NULL,3,1,17,0,NULL,'hermeshine'),(24428,801137472001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 14:57:49',0,NULL,8,1,17,0,NULL,'hermeshine'),(24429,801137473001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 14:57:50',0,NULL,8,1,17,0,NULL,'hermeshine'),(24430,845639873002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 14:57:51',0,NULL,8,1,17,0,NULL,'hermeshine'),(24431,845639874002,120601699344,'JueYing Lambency Flash Diffuser for 430EX F36AM P2',1,'AB3308',18,'hermeshine','dbygnes123','post@dbygnes.com','Dag Vidar Bygnes','Østrembruvegen 35','Kopervik','Rogaland','NORWAY','4250','+4791800027','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 14:57:51',0,NULL,3,1,3,1,'\rRA184525802CN','hermeshine\r伞式柔光箱 80cm 8角    1\r反光板支架   1\r斜臂的夹子（单轮）   1\r爵影碗罩P4   1\r爵影碗罩P2    1\r申报 gift  $25\rRA184525966CN 之前错误单号\rCP244596202CN'),(24432,801185647001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','robyn_design','stinks@rogers.com','Robyn Davis','C/o EGNB 440 Wilsey Rd<br>Ste 101','Fredericton','NB','CANADA','E3B 7G5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 17:02:38',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24433,951395839015,250692238517,'NEW Adjustable Neoprene Padded shoulder Strap for DSLR',1,'AB1407',2.99,'hutongstore','12bluemarlin','coolblue.marlin@virgin.net','Barry Taylor','7 Larch Close<br>Marple','Stockport','Cheshire','UNITED KINGDOM','SK6 7RH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 18:09:03',0,NULL,3,1,11,1,NULL,'hutongstore'),(24434,801219643001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','mi_neniu','mi.neniu@gmail.com','Natal\'ya Anisimova','Lyapidevskogo st., 4, 113','Moscow','','RUSSIAN FEDERATION','125581','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 18:19:00',0,NULL,8,1,17,0,NULL,'hermeshine'),(24435,807526207018,280805178524,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.9,'photographyacc','dimmy6664','damianart@yahoo.co.uk','Eoin Banahan','123 Dromintee Rd<br>Dromintee','Newry','Armagh','UNITED KINGDOM','BT35 8SW','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 18:19:56',0,NULL,3,1,11,1,NULL,'photographyacc'),(24436,845726022002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','mi_neniu','mi.neniu@gmail.com','Natal\'ya Anisimova','Lyapidevskogo st., 4, 113','Moscow','','RUSSIAN FEDERATION','125581','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 18:21:12',0,NULL,3,1,3,1,'RA184523435CN\r ','hermeshine\r圆形柔光棚 40cm  1\r圆形柔光棚 50cm   1'),(24437,867961433017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',1,'AD1168',15,'photographyacc','pibscam','pibscam@hotmail.com','paul davies','Falt 3, Beauchamp House<br>4 Beauchamp Road','EAST MOLESEY','Surrey','UNITED KINGDOM','KT80PA','07711528724','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-21 18:21:37',0,NULL,3,1,11,1,NULL,'photographyacc'),(24438,801234344001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','antonbalaban','ebay@balaban.ru','Anton Balaban','Akademika Pilugina street 22-1 apt 86','Moscow','','RUSSIAN FEDERATION','117393','+7-903-794-67-14','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 18:48:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(24439,951422647015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',15.99,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 18:53:56',0,NULL,3,1,3,1,'RA184523421CN ','hutongstore'),(24440,845749946002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',2,'AD1128',45.8,'hermeshine','a_doreanmode','a_lydian@aol.jp','Akihiro Yokoo','180-1,Konemoto','Matsudo-shi','Chiba','JAPAN','2710073','81-47-368-8669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 19:05:26',0,NULL,3,1,3,1,'RA184525970CN ','hermeshine'),(24441,931674018016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','mrtrivett','barrytrivett@gmail.com','Barry Trivett','35 Radnor drive','Wallasey','Merseyside','UNITED KINGDOM','CH45 7PS','01516390775','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 19:48:28',0,NULL,3,1,2,1,NULL,'hutongstore'),(24442,951495895015,250892627378,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',58.55,'hutongstore','bogdani26bezeqint','bogdani@bezeqint.net','bogdan babitz','Inbalim 70','arad','Israel','ISRAEL','89049','0524437835','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 20:36:40',0,NULL,3,1,3,1,'RA184523418CN \rRA184523483CN','hutongstore\r分开发'),(24443,845803020002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','igor_gelendzhik','inttec@inbox.ru','Igor Podymov','Oceanologiya, 19, apt. 17<br>Blue bay','Gelendzhik-7','Krasnodarskiy kray','RUSSIAN FEDERATION','353467','79184811752','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:38:51',0,NULL,3,1,17,0,NULL,'hermeshine'),(24444,629169319004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','igor_gelendzhik','inttec@inbox.ru','Igor Podymov','Oceanologiya, 19, apt. 17<br>Blue bay','Gelendzhik-7','Krasnodarskiy kray','RUSSIAN FEDERATION','353467','79184811752','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:38:52',0,NULL,3,1,17,0,NULL,'hermeshine'),(24445,801293237001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','igor_gelendzhik','inttec@inbox.ru','Igor Podymov','Oceanologiya, 19, apt. 17<br>Blue bay','Gelendzhik-7','Krasnodarskiy kray','RUSSIAN FEDERATION','353467','79184811752','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:38:52',0,NULL,3,1,11,1,'\\ ','hermeshine\r无牌方镜 渐变蓝   1\r无牌方镜 渐变灰 （nd4）  1\r无牌方镜 渐变灰 （nd2）  1'),(24446,845806380002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','alexperl120','sony3000@gmail.com','Perel Alexander','Gordon 13/5','Kiriyat Motzkin','Krayot','ISRAEL','26370','0525789523','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:45:56',0,NULL,3,1,3,1,'RA184523506CN ','hermeshine'),(24447,845807285002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sorin.cristea','sorin@inet.hr','Sorin Cristea','Ul.Sv.Roka 54A','Osijek','','CROATIA','31000','+385959063237','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 20:47:42',0,NULL,3,1,3,1,'RA184529279CN ','hermeshine'),(24448,951506908015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','anunlikelystory','chrisjwharton@hotmail.co.uk','Chris Wharton','30 Swindon Lane','Cheltenham','Gloucestershire','UNITED KINGDOM','GL50 4NY','01242245462','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-21 20:53:41',0,NULL,3,1,3,1,'RA184507905CN ','hutongstore'),(24449,801311880001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','seherez','zoltanphoto@yahoo.com','Zoltan Varga','1 Sheldon Court<br>Lansdowne Green','London','London','UNITED KINGDOM','SW8 2BE','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 21:15:57',0,NULL,3,1,3,1,'RA184529282CN\r ','hermeshine'),(24450,951522722015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','photofoto4','discount13@laposte.net','boronat renée ( perez )','21 rue du grand madier','la ciotat','Provence-Alpes-Côte d\'Azur','FRANCE','13600','0442083793','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-21 21:16:36',0,NULL,5,1,18,1,'RA184523320CN\r ','hutongstore\r退钱了'),(24451,951531576015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','gunwharfweb','david@gunwharf.co.uk','David Miller','12 Bluebell Close','Waterlooville','Hampshire','UNITED KINGDOM','PO78BU','07913665623','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-21 21:31:02',0,NULL,3,1,3,1,'RA184524869CN ','hutongstore'),(24452,801362100001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','luchochm','luischm@gmail.com','Katty Alarcón Juñuruco','Calle Trapiche Mz. I4 LT 2 Urb. Portada del Sol - La Molina','Lima','Lima','PERU','LIMA 12','+51 997233286','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-21 23:21:38',0,NULL,3,1,5,1,'CP244439547CN\r ','hermeshine\r黑加白'),(24453,845877706002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','bobkez53','jacksonkerrybob@gmail.com','Bob Jackson','Kincora Cottage 7986 Waterfall Way<br>PO Box 33','Ebor','New South Wales','AUSTRALIA','2453','0439261642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:28:11',0,NULL,8,1,17,0,NULL,'hermeshine'),(24454,845877707002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','bobkez53','jacksonkerrybob@gmail.com','Bob Jackson','Kincora Cottage 7986 Waterfall Way<br>PO Box 33','Ebor','New South Wales','AUSTRALIA','2453','0439261642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:28:12',0,NULL,8,1,17,0,NULL,'hermeshine'),(24455,801364302001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',4.25,'hermeshine','bobkez53','jacksonkerrybob@gmail.com','Bob Jackson','Kincora Cottage 7986 Waterfall Way<br>PO Box 33','Ebor','New South Wales','AUSTRALIA','2453','0439261642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:28:12',0,NULL,8,1,17,0,NULL,'hermeshine'),(24456,801364303001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',2,'AA1314',5.98,'hermeshine','bobkez53','jacksonkerrybob@gmail.com','Bob Jackson','Kincora Cottage 7986 Waterfall Way<br>PO Box 33','Ebor','New South Wales','AUSTRALIA','2453','0439261642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-21 23:28:13',0,NULL,3,1,3,1,'RA184529265CN\r ','hermeshine\r绿叶 UV  52mm  1\r绿叶 UV  62mm   1\r绿叶 UV  67mm   1\r机身盖/镜头后盖  Nikon  2'),(24457,845759236002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','hgordondavisiv','gordondavis4@gmail.com','Henry G. Davis IV','307A Nan St','Valdosta','GA','UNITED STATES','31601-5137','(229) 300-6291','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-21 23:49:06',0,NULL,3,1,1,1,'LK201198720CN ','hermeshine'),(24458,801390070001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','cybermees','cybermees.pro@gmail.com','Salvador MEES','19, cité de la clouterie,Rdch','EPPEVILLE','Picardie','FRANCE','80400','03.23.81.27.92','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-22 00:58:37',0,NULL,3,1,3,1,'RA184523333CN\r ','hermeshine'),(24459,8881329875957873,111,'Free shipping & Tracking # - New Super-energy 12000 mAh li-ion Battery for GPS tracker TK102 - ',1,'GPS0010',26.99,'aliexpress','1006911644','miroslav.hanes@yahoo.ie','Miroslav Hanes','97 old kilmainham village ','Kilmainham','Dublin 8','IRELAND','D8','+00353 85124 6513',NULL,NULL,NULL,'2012-02-22 01:59:17',0,NULL,5,1,18,0,NULL,'GPS0010\r没到账 '),(24460,931855087016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','gustavpsi','gustavpsi@gmail.com','Gustavo Borges Moreno e Mello','Rua João Bastos 3, 1º Esquerdo','Lisboa','Portugal','PORTUGAL','1400-125','934482159','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-22 01:59:17',0,NULL,3,1,3,1,'RA184523470CN ','hutongstore'),(24461,8881329876159879,111,'New Atheros AR5008 802.11N Wireless WiFi Mini PCI-E Card + Tyco 2.4/5.0GHz Antenna *3 - ',1,'WLAT001+ ANTY002',15.99,'aliexpress','1006906224','emi6600@yahoo.com','Emanuel Nastase','Backhaustrasse 28 ','Philippsburg','Karlsruhe','GERMANY','76661','+0049 01577 5143713',NULL,NULL,NULL,'2012-02-22 02:02:39',0,NULL,5,1,18,1,NULL,'WLAT001+ ANTY002 '),(24462,8881329877221834,111,'手动升降背景架配件',1,'',0,'aliexpress','1006505405','jopchr@online.no','John Christensen	','Roineveien 21','Sylling','Buskerud	','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-22 02:20:21',0,NULL,3,0,3,1,'RA184523316CN\r ','2个 '),(24463,801415002001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','evandunville','evandunville@gmail.com','Evan Dunville','101-11110 127 Street','Edmonton','AB','CANADA','T5M 0T4','(780) 660-3118','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 02:27:27',0,NULL,3,1,2,1,NULL,'hermeshine'),(24464,931881634016,260894475364,'Universal two-wheel Light Stand Double Dual Grip Clamp',2,'AD1179',19.6,'hutongstore','cbjairamreddy','cbjairamreddy@yahoo.com','jai ram reddy chowdri b','23<br>ashford street','stoke on trent','Staffordshire','UNITED KINGDOM','st4 2eh','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 03:17:13',0,NULL,3,1,11,1,' ','hutongstore'),(24465,798758165001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','paulomedeiros1982','paulo_medeiros@iol.pt','Paulo Medeiros','Rua Padre Francisco da Cruz, n.º 60<br>São Bartolomeu','Angra do Heroísmo','','PORTUGAL','9700-520','924137542','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 03:41:05',0,NULL,3,1,3,1,'RA184523466CN ','hermeshine'),(24466,8881329885130757,111,'1.6*2.1  黑色布',1,'',0,'hutongstore','serocco.by','serocco@gmail.com','Kharaneka Aliaksandr','Golubeva st. 13-301','Minsk','BY','BELARUS','220116','+375291906840',NULL,NULL,NULL,'2012-02-22 04:32:10',0,NULL,3,0,3,1,'RA184523510CN\r ',NULL),(24467,845966780002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','dracoshelties','hray@hotmail.com','Hallie Ray','12398 Ripon Ct','King George','VA','UNITED STATES','22485-4238','(540) 775-3524','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-22 04:37:35',0,NULL,3,1,1,1,'LK201217211CN ','hermeshine\rHallie Ray\r6 Autumn CT\rEdgewood, NM 87015\rUNITED STATES\r(540) 775-3524'),(24468,845974307002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','deanda-studios','carlos@marquez.com','Carlos Blake','233 Paulin Ave<br># 7233','Calexico','CA','UNITED STATES','92231-2615','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 05:10:10',0,NULL,3,1,3,1,'RA184525949CN ','hermeshine'),(24469,807780485018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','zonaid.sharafi','zonaid@gmail.com','Zonaid Sharafi','AlphaSalmon, Ogilvy House, Level 5<br>72 Christie Street, St Leonards','Sydney','New South Wales','AUSTRALIA','2065','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 05:18:23',0,NULL,3,1,11,1,NULL,'photographyacc'),(24470,8881329890899510,111,'Marvell 88W8363 Mini PCI Wireless Card 300Mbps 802.11N - ',1,'WLIN013',17.99,'aliexpress','1006916471','takimoto@inter7.jp','Junya TAKIMOTO','2-8-8, Miyakono, Oami-Shirasato-machi ','Sanbu-gun','Chiba-ken','JAPAN','299-3236','+81 475 2302',NULL,NULL,NULL,'2012-02-22 06:08:19',0,NULL,5,0,18,1,NULL,'WLIN013 '),(24471,845989545002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','trevor_qld','trevorcook1@bigpond.com.au','Trevor Cook','10 Flametree st<br>Bridgeman Downs','Brisbane','Queensland','AUSTRALIA','4035','0738630167','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 06:31:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(24472,801471542001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','zakibatarfi','zaki.batarfi@hotmail.com','Zaki Batarfi','default','Dammam','Eastern Region zip code 32414 Building No5343','SAUDI ARABIA','7501','+966552236663','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 06:46:10',0,NULL,3,1,11,1,NULL,'hermeshine'),(24473,951733578015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','geezermarshy','stevenrobertmarsh@hotmail.co.uk','Steven Marsh','36 Mulberry Avenue','Stubbington','Hampshire','UNITED KINGDOM','po142sn','01329667671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 07:06:09',0,NULL,3,1,3,1,'RA184523545CN ','hutongstore'),(24474,801480126001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','denisrus79','denis.v79@mail.ru','Denis Velmyakin','Svobody 177-11','Samara','','RUSSIAN FEDERATION','443077','89272033541','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 07:34:57',0,NULL,3,1,3,1,'RA184523537CN ','hermeshine'),(24475,867825528017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.9,'photographyacc','tlc286','tlconstable@bigpond.com','Tracey Constable','75  Nanbaree  Dr','Bray Park','Queensland','AUSTRALIA','4500','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 07:38:25',0,NULL,3,1,11,1,NULL,'photographyacc'),(24476,846008398002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','shulenok','aliven@gmail.com','Fedir Shulenok','Banduziu 14-10','Klaipeda','Klaipeda','LITHUANIA','95223','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 08:09:41',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24477,801492735001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','dunkmydonuts','bobthesausage@gmail.com','Nathan Anderson','8 Mayfield Street','Stanhope Gardens','New South Wales','AUSTRALIA','2768','0402732932','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 08:38:06',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24478,801494587001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','internetsonne21','bru_@hotmail.de','Katja Müller','Lilo-Herrmann-Strasse 30','Erfurt','','GERMANY','99086','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 08:46:46',0,NULL,3,1,3,1,'RA184525816CN ','hermeshine'),(24479,801493160001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',3,'AE3401',77.97,'hermeshine','alexvshyriaev','lombard@mail.ru','Alexey Shyriaev','Stepana Khalturina 47-25','Ufa','','RUSSIAN FEDERATION','450006','+79173440394','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 08:52:05',0,NULL,3,1,5,1,'CP244439564CN','hermeshine'),(24480,801530570001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','molenviergang00','thony@live.nl','Thony de Bruin','Jan van Henegouwenstraat 38','Alphen aan den Rijn','','NETHERLANDS','2405ZJ','0172441224','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 11:13:08',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24481,846051428002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','rocketman9-2007','r@juvodden.net','Rolf Georg Juvodden','Gundersensgt. 16','Horten','','NORWAY','3181','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 11:04:55',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24482,629344594004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','icoicophoto','ht2@abv.bg','Hristo Todorov','F. Canec<br>9000 P.O.B. 528','Varna','Varna','BULGARIA','9000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 11:06:41',0,NULL,3,1,11,1,' \\','hermeshine'),(24483,801533247001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',1,'AB1301',3.34,'hermeshine','bst1t','trvrsmall@gmail.com','Trevor Small','59 Willara Street','Carseldine','Queensland','AUSTRALIA','4034','0732633913','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 11:23:37',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24484,796324874001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',2,'AA1312',3,'hermeshine','hayley11*2011','hayley_jade11@hotmail.com','Hayley Jade','17 Kapala Ave','Bradbury','New South Wales','AUSTRALIA','2560','0422559651','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 11:24:20',0,NULL,3,1,2,1,'\\ ','hermeshine'),(24485,800619841001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','07031979vs','singerova@design4.cz','Veronika Singerová','Trávnice 902','Turnov','výchozí','CZECH REPUBLIC','51101','605548227','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-22 12:05:38',0,NULL,3,0,3,1,'RA184524532CN\r ','hermeshine\r3XL 已入库\r'),(24486,801546015001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','agora.online','john.kapeleris@agoraonline.com.au','John Kapeleris','32 Balmoral Street<br>Kuraby','Brisbane','Queensland','AUSTRALIA','4112','0413051605','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-22 12:10:02',0,NULL,3,0,3,1,'RA184524515CN\r ','hermeshine\r3XL  已入库\r'),(24487,951830876015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','joelkaran','joel_zia@ig.com.br','Joel Zia','Rua Assunção 241','Santo André','São Paulo','BRAZIL','09220-750','055 11 - 4997-0387','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-22 12:19:59',0,NULL,3,1,3,1,'RA184524603CN\r ','hutongstore\r称一下重量，算运费'),(24488,801562866001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','administratsia','kumi51@yandex.ru','Evgeny Frolov','Zelionaya st. 29','Kurganinsk','Krasnodarsky kray','RUSSIAN FEDERATION','352430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 13:07:01',0,NULL,3,1,17,0,NULL,'hermeshine'),(24489,846087120002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','administratsia','kumi51@yandex.ru','Evgeny Frolov','Zelionaya st. 29','Kurganinsk','Krasnodarsky kray','RUSSIAN FEDERATION','352430','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 13:07:02',0,NULL,3,1,11,1,'\\ ','hermeshine\r无牌方镜 渐变灰 （nd8）  1\r无牌方镜 渐变日落    1'),(24490,801570441001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','mkibbe2012','melody.kibbe.mk@gmail.com','Melody Kibbe','16331 Tyler St','Liberty Center','IA','UNITED STATES','50145-7729','(515) 979-9840','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 13:32:25',0,NULL,3,0,1,1,'LK201688975CN\r ','hermeshine\r1.6*2.1  黑色'),(24491,951870553015,250932248783,'New Studio soft box 28\"x39\"/ 70x100cm Softbox  Universal Metal Mount  for strobe',1,'AD1141',32,'hutongstore','jfarenden','jason@cowgirlindustries.ltd.uk','Jason Farenden','Daitenhausener Str 32','Eching','','GERMANY','85386','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 13:56:25',0,NULL,3,1,3,1,'RA184524585CN\r ','hutongstore'),(24492,846113930002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','blachtom','tom@tomblachford.com','Tom Blachford','147 Kerferd Road Albert Park','Melbourne','Victoria','AUSTRALIA','3206','0396963525','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 14:28:50',0,NULL,3,1,3,1,'RA184524594CN\r ','hermeshine'),(24493,868396380017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','jahspot','freek.lauwers@gmail.com','Freek Lauwers','Marksesteenweg 97','KORTRIJK','','BELGIUM','8500','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 15:14:18',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24494,932119203016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','adriansmithepsom','ebay@rwsuk.com','Adrian Smith','London Web Factory<br>Global House, 1 Ashley Ave','Epsom','Surrey','UNITED KINGDOM','KT18 5AD','07951589009','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-22 15:39:33',0,NULL,3,1,12,1,'3125540040 ','hutongstore\r英标\r泡重9.3'),(24495,951947038015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-22 16:39:16',0,NULL,3,1,3,1,'RA184524529CN\r ','hutongstore\r申报$21\r4个'),(24496,951946463015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','vmr1983','veronik_m.r@hotmail.com','Verónica Mena Rodríguez','Emperador Trajano, 16 3º A','Andújar','Andalucía Ceuta y Melilla','SPAIN','23740','667 382 223','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 16:40:48',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24497,932152177016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','octaviosaez','octavio.saez@fotografosdesevilla.es','Octavio Sáez Ariza','C/REAL, 55','GUILLENA (SEVILLA)','Andalucía Ceuta y Melilla','SPAIN','41210','618296713','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 16:45:09',0,NULL,3,1,4,1,'YW867610985CN\r ','hutongstore\r澳转欧标'),(24498,932157459016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','time9231','tbevans@uwclub.net','Tim Evans','10 Sargent Avenue, Bishopthorpe','York','North Yorkshire','UNITED KINGDOM','YO23 2QY','01904704092','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 16:53:52',0,NULL,3,1,2,1,'\\ ','hutongstore'),(24499,932159470016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','ragey-0','xxxxxxie@yahoo.com','Jane Johnston','9 Kings Parade','Newtownabbey','Antrim','UNITED KINGDOM','BT37 0DL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-22 16:56:59',0,NULL,3,1,12,1,'3125540051 ','hutongstore\r英标\r泡重9.4'),(24500,846183148002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','semselectronics2012','semselectronics@rambler.ru','Sergey Samoylovich','Koroleva 16. 53','Omsk','Omskaya','RUSSIAN FEDERATION','644045',' 89131446793','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 17:18:35',0,NULL,3,1,3,1,'RA184525864CN ','hermeshine'),(24501,951984390015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 17:44:53',0,NULL,3,1,3,1,'RA184525935CN ','hutongstore\r申报$14\r'),(24502,951995686015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','mem29jsm','memjsm@hotmail.com','Marta Egea Martin','C/ Medico Vicente Reyes Nº 19 <br>Bloque B 3º J','Alicante','Comunidad Valenciana','SPAIN','03015','649669640','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 18:01:34',0,NULL,3,1,3,1,'RA184524617CN\r ','hutongstore'),(24503,952002470015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','optinoss','lempersjo@gmail.com','Kim Roos','Aallokko 3 A 28','Espoo','','FINLAND','FI-02320','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 18:11:54',0,NULL,3,1,3,1,'RA184525952CN ','hutongstore'),(24504,846221725002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','arnorolf10','arno.rolf@yahoo.com.br','Roberta Silva Wersdoerfer','Rua Monsenhor Gercino, 73<br>Itaum','Joinville','Santa Catarina','BRAZIL','89210-145','47 30256406','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-22 18:46:44',0,NULL,5,0,18,0,NULL,'hermeshine\r称一下重量，算运费\r加$8 运费\r发信了'),(24505,932226995016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','norgate55','advice@pinholesolutions.co.uk','Timothy Norgate','77 Fountain Road<br>Edgbaston','Birmingham','West Midlands','UNITED KINGDOM','B17 8NP','01214292790','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 18:48:40',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24506,801709440001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','sparkling_stars2006','rinat_peleg1@walla.com','R. Peleg','16/2 Michael Ashbel st.','Be\'er Sheva','Israel','ISRAEL','84255','97286108640','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 19:04:49',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24507,801737628001,110717850313,'43\" double layers reflective and translucent umbrella',1,'AD1157',29.99,'hermeshine','nunorealinho','nunorealinho@yahoo.co.uk','Nuno Realinho','Rua Angola nº 26 3º dto','Cacém','Lisboa','PORTUGAL','2735-230','938417680','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 19:53:17',0,NULL,3,1,3,1,'RA184524625CN\r ','hermeshine'),(24508,808066832018,280678256434,'6 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1203',5.5,'photographyacc','natalie5834','dnnac10@btinternet.com','Natalie Coleman','31 Bingham Park Road','Sheffield','South Yorkshire','UNITED KINGDOM','S11 7BD','01142660568','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-22 19:28:03',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24509,846301259002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','buenpedal','buenpedal@hotmail.com','elena fernandez facius','plaza mediterraneo 2- Edif mediterraneo (soltour)','palma de mallorca','Baleares','SPAIN','07014','620081050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 21:01:30',0,NULL,3,1,2,1,'\\ ','hermeshine'),(24510,808127239018,280687907688,'3mx6m Background Backdrop Photography Studio Non-Woven',1,'AO0018',60,'photographyacc','leighannj71','leighannj@hotkey.net.au','Leighann Jackson','14 Richardson St','Portland','Victoria','AUSTRALIA','3305','0355217371','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-22 21:10:22',0,NULL,3,0,17,0,NULL,'photographyacc'),(24511,808126063018,280667759852,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.9,'photographyacc','leighannj71','leighannj@hotkey.net.au','Leighann Jackson','14 Richardson St','Portland','Victoria','AUSTRALIA','3305','0355217371','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 21:10:23',0,NULL,3,1,17,0,NULL,'photographyacc'),(24512,868588336017,270742432772,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.9,'photographyacc','leighannj71','leighannj@hotkey.net.au','Leighann Jackson','14 Richardson St','Portland','Victoria','AUSTRALIA','3305','0355217371','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 21:10:23',0,NULL,3,1,17,0,NULL,'photographyacc'),(24513,868588073017,270742432910,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.9,'photographyacc','leighannj71','leighannj@hotkey.net.au','Leighann Jackson','14 Richardson St','Portland','Victoria','AUSTRALIA','3305','0355217371','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 21:10:24',0,NULL,3,1,17,0,NULL,'photographyacc'),(24514,808125257018,280670209999,'72mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT023',4.19,'photographyacc','leighannj71','leighannj@hotkey.net.au','Leighann Jackson','14 Richardson St','Portland','Victoria','AUSTRALIA','3305','0355217371','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-22 21:10:24',0,NULL,3,1,4,1,'YW867610926CN ','photographyacc\r背景布 3x6 黑色  1\r方形滤镜接口环 82mm   1\r方形滤镜接口环 72mm  1\r方形滤镜接口环 77mm   1\r方形滤镜接口环 72mm   1\r方镜普通托架（三槽）  1\r'),(24515,801801696001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','csigabiiiga','sunshine_@freemail.hu','Gabriella Olláry','Galagonyás út 2.','Esztergom','Komarom-Esztergom megye','HUNGARY','2500','+36202521512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-22 21:55:01',0,NULL,3,1,11,1,'\\ ','hermeshine'),(24516,952158787015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',2,'AB3327',47.36,'hutongstore','imrek70','actoris@hot.ee','Imre Klaasen','Loode str 1A-11','Tallinn','Harjumaa','ESTONIA','10137','003725018345','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 21:56:24',0,NULL,3,1,21,1,'RA184524461CN\r ','hutongstore\rSAL 便宜 用SAL '),(24517,801808434001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.99,'hermeshine','nothing-is','cookiekluski@earthlink.net','alfred snyder','414 N Ridgewood Ave<br>Lot 20','edgewater','FL','UNITED STATES','32132-1645','(386) 416-9662','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-22 22:08:40',0,NULL,3,1,1,1,'LK201703200CN\r ','hermeshine'),(24518,932324861016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','ianw7857','woods58@hotmail.co.uk','Ian Woods','7 brooksbottom close<br>Ramsbottom','Bury','Greater Manchester','UNITED KINGDOM','bl09yp','01706821660','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-22 22:02:39',0,NULL,3,1,3,1,'RA184524634CN\r ','hutongstore'),(24519,952190344015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','warrenh3973','warrenharley@hotmail.com','Warren Harley','Kinsale Further Education College<br>Old Bandon Road','Kinsale','Cork','IRELAND','default','0860791850','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 22:58:10',0,NULL,3,1,4,1,'YW867610904CN ','hutongstore\r英标'),(24520,952204193015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','tasssos8','tassos_pasalis@mac.com','Anastasios Pasalis','Buikslotermeerplein 497','Amsterdam','','NETHERLANDS','1025WR','(020) 7891482','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-22 23:27:06',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24521,932429583016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','nikolas8878','nikolas887@yahoo.com','Nikolas Kostis','19 Allenby Road','LONDON','London','UNITED KINGDOM','SE28 0BF','07842419860','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-23 00:47:06',0,NULL,3,1,4,1,'YW867610915CN ','hutongstore\r英标'),(24522,952239731015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','seion_cris2008','seion_cris@hotmail.com','Crispin Telesforo','Blk 326 Hougang Ave. 7  #11-337<br>Singapore','default','','SINGAPORE','530326','90184246','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 01:03:37',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24523,846397168002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','j9n9','miss.jana.chan@gmail.com','Jana Krcmarova','40 - 44 Redlion Street<br>Rozelle','Sydney','New South Wales','AUSTRALIA','2039','0434529157','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 01:06:22',0,NULL,3,1,3,1,'RA184524648CN\r ','hermeshine'),(24524,846401708002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',79.98,'hermeshine','tankards','finearts@vaxxine.com','Josiah Grimmitt','5, Garrison Village Drive','Niagara on the Lake','ON','CANADA','L0S 1J0','(905) 468-1744','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 01:23:02',0,NULL,3,1,5,1,'CP244439555CN ','hermeshine'),(24525,801877302001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','tlgdnr','dnrtlg@hotmail.com','tolga doner','Çetin Emeç Mahahllesi Metin Oklay Sokak. Mizan Sitesi C blok<br>no:15/2 Daire 2','izmir balcova','izmir','TURKEY','35330','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-23 01:43:39',0,NULL,3,1,3,1,'RA184524651CN\r ','hermeshine\r欧标'),(24526,846413025002,120568891550,'77mm Lens lenscap for Nikon 77 D80 D90 D200 D300s D700',1,'AA1309',2.6,'hermeshine','wizard-of-wonders','tweaked_out@shaw.ca','Paul W. Sharpe','17986 67 Ave','surrey','BC','CANADA','v3s8c3','(604) 220-4716','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 01:59:13',0,NULL,8,1,17,0,NULL,'hermeshine'),(24527,846413026002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','wizard-of-wonders','tweaked_out@shaw.ca','Paul W. Sharpe','17986 67 Ave','surrey','BC','CANADA','v3s8c3','(604) 220-4716','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 01:59:14',0,NULL,3,1,2,1,'\\ ','hermeshine\rNIKON 镜头盖 77mm  1\rNIKON 镜头盖 52mm   1'),(24528,865449625017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','johngrechphoto','johnny_grecko@hotmail.com','John Grech','5 Norfolk Street','Mount Druitt','New South Wales','AUSTRALIA','2770','0298648535','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 02:16:53',0,NULL,3,1,3,1,'RA184524705CN\r ','photographyacc'),(24529,8881329964475696,111,'Free Shippng & Tracking # - 16\" Photo Softbox Table Top Light Lighting Cube Kit - Wholesale/ Retail ',1,'AKT091',82.99,'aliexpress','1006923174','olbelrabot40@rambler.ru','Oleg Belyaev','Georgievskaya d 16 kv 75','Tver','Tverskaya obl.','RUSSIAN FEDERATION','170023','+74822 334718',NULL,NULL,NULL,'2012-02-23 02:34:35',0,NULL,3,1,5,1,'CP244439935CN ','欧标\r速卖通 '),(24530,8881329964611016,111,'Free shipping & Tracking # - New Neoprene Protector Camera Cover for Canon Nikon ',1,'AC1305',8.99,'aliexpress','1006925416',' kyrf.pda@gmail.com','Igor Kyrf','Serafimy Deryabinoy street. d. 11, kv. 33','Ekaterinburg','Sverdlovsk Region','RUSSIAN FEDERATION','620102','+7 903 0793148',NULL,NULL,NULL,'2012-02-23 02:36:51',0,NULL,3,1,3,1,'RA184594842CN  ',NULL),(24531,8881329964729015,111,'x2 45W 110V 5500K Studio Light Bulb Daylight with E27 Socket ',2,'AD1133',33.98,'aliexpress','1006930609',' h2005@inbox.ru','Oleg Ananin','ul. Kudrjashova, dom 106, kv 61','Ivanovo','Ivanovskaja oblast','RUSSIAN FEDERATION','153038','79203444445',NULL,NULL,NULL,'2012-02-23 02:38:49',0,NULL,3,1,3,1,'RA184525714CN','4个 \r需要确认一下灯泡多少伏\r我觉得不用确认了 发220V的吧'),(24532,846417278002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','nacho1855','nachojiab@hotmail.com','juan Ignacio alvarez','av cerviño 4490 piso 9 depto 63<br>Palermo','capital federal','buenos aires','ARGENTINA','1425','011 1533593409','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 02:13:19',0,NULL,3,1,3,1,'RA184524489CN\r ','hermeshine'),(24533,8881329965332944,111,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','palamuda387','vlado.cubak@gmail.com','Vladimir Cubak','Cekalusa 17','Sarajevo ','','BOSNIA AND HERZEGOVINA','71000','',NULL,NULL,NULL,'2012-02-23 02:48:52',0,NULL,3,1,3,1,'RA184524696CN\r ','hermeshine\r申报 $13'),(24534,8881329965834255,111,'New 77mm Ring adapter for Cokin P Series Filter Holder ',1,'AA2214',1.6,'hutongstore','tomekd76 ','tomekdrush@interia.eu','Tomasz Dlubacz','2 Moorings Cove','Skerries','Dublin ','IRELAND','','',NULL,NULL,NULL,'2012-02-23 02:57:14',0,NULL,3,1,11,1,'\\ ',NULL),(24535,801895157001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','belklin','steviesung@o2.co.uk','Steven Sung','8 Leglen Wood Drive<br>Wallacewell Park','Glasgow','Glasgow (City of)','UNITED KINGDOM','G21 3PL','01411112233','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 03:06:07',0,NULL,3,1,17,0,NULL,'hermeshine'),(24536,846429603002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','belklin','steviesung@o2.co.uk','Steven Sung','8 Leglen Wood Drive<br>Wallacewell Park','Glasgow','Glasgow (City of)','UNITED KINGDOM','G21 3PL','01411112233','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 03:06:09',0,NULL,3,1,11,1,'\\ ','hermeshine\r无牌方镜 渐变灰 （nd2）  1\r无牌方镜 渐变日落   1'),(24537,952298910015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','sai_cat','saikit.to@gmail.com','Sai To','57 Merrifield Circle<br>Leeming','Perth','Western Australia','AUSTRALIA','6149','0402821835','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 03:58:08',0,NULL,3,1,3,1,'RA184524475CN\r ','hutongstore'),(24538,846451494002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','vyroy','jorge_411@msn.com','Jorge Tortosa Gassó','C/Molí 54','La Font de la Figuera','Comunidad Valenciana','SPAIN','46630','660760419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 04:12:36',0,NULL,3,1,3,1,'RA184524577CN\r ','hermeshine'),(24539,801912127001,110745502182,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',36,'hermeshine','ctsnipes','snipesct@aol.com','Carl Snipes','3109 Oxford Dr','Durham','NC','UNITED STATES','27707-3842','(919) 490-6210','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 03:49:51',0,NULL,3,1,1,1,'LK201978500CN\r ','hermeshine'),(24540,846455589002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',5,'AA1303',13,'hermeshine','glennp3oed','glennp@przyborski.com','Glenn Przyborski','40 24th St<br>Fl 3','Pittsburgh','PA','UNITED STATES','15222','(412) 261-9011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 04:30:30',0,NULL,8,1,17,0,NULL,'hermeshine'),(24541,801921663001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',5,'AA1304',13,'hermeshine','glennp3oed','glennp@przyborski.com','Glenn Przyborski','40 24th St<br>Fl 3','Pittsburgh','PA','UNITED STATES','15222','(412) 261-9011','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 04:30:31',0,NULL,3,1,1,1,'LK201959721CN\r ','hermeshine\rCANON 镜头盖  72mm  5\rCANON 镜头盖  77mm   5'),(24542,801922670001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','marygold070977','marie-gold@hotmail.com','mélanie chaput','4640 app 4 rue Dubois','drummondville','QC','CANADA','J2E 1R4','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-23 04:50:18',0,NULL,3,1,5,1,'CP244439992CN ','hermeshine\r黑加白'),(24543,846468803002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 05:36:49',0,NULL,3,1,3,1,'RA184524546CN\r ','hermeshine'),(24544,801934989001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','muscooler','ag_v@mail.ru','Chernousov Denis','ul. Ametistovaya 57','Barnaul','Altay region','RUSSIAN FEDERATION','656065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 05:39:36',0,NULL,3,1,3,1,'RA184524665CN\r ','hermeshine'),(24545,8881329978205416,111,'Free Shipping & Tracking # - Flash Softbox Diffuser for internal flash of DSLR - Wholesame/Retail ',1,'AB3304',9.99,'aliexpress','1006937537','jopchr@online.no','John Christensen','Roineveien 21','Sylling','Buskerud','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-23 06:23:25',0,NULL,3,1,17,0,NULL,NULL),(24546,8881329978333192,111,'Free shipping & Tracking # - Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',32.99,'aliexpress','1006937535','jopchr@online.no','John Christensen','Roineveien 21','Sylling','Buskerud','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-23 06:25:33',0,NULL,3,1,17,0,NULL,NULL),(24547,8881329978384010,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail ',1,'AKT056',50,'aliexpress','1006937536','jopchr@online.no','John Christensen','Roineveien 21','Sylling','Buskerud','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-23 06:26:24',0,NULL,3,1,17,0,NULL,NULL),(24548,8881329978429955,111,'C Clip Clamp Holder Mount for Studio Backdrop Camera - Wholesale/ Retail ',1,'AE3104',13.99,'aliexpress','1006937539','jopchr@online.no','John Christensen','Roineveien 21','Sylling','Buskerud','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-23 06:27:09',0,NULL,3,1,17,0,NULL,NULL),(24549,8881329978474138,111,'Free shipping & Tracking # - New High quality heavy duty sand bag Shipped Empty ',1,'AD1168',14.99,'aliexpress','1006937538','jopchr@online.no','John Christensen','Roineveien 21','Sylling','Buskerud','NORWAY','3410','+47 41 231346',NULL,NULL,NULL,'2012-02-23 06:27:54',0,NULL,3,1,5,1,'CP244439652CN ','NG128 柔光罩   1 \r新款大力夹（手柄）  1\r反光板支架  1\r灯架  2m   1\rc型大力夹  1\r沙袋（大）   1\r速卖通'),(24550,952335005015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','alexalena38','alexalena6@gmail.com','Bezyazychy A.','per. Partizanskii 38','Belorechensk,','KRASNODARSKII KRAI','RUSSIAN FEDERATION','352600','89184488100','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 06:33:47',0,NULL,3,1,3,1,'RA184524753CN\r ','hutongstore\r4节'),(24551,846479188002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','andreiphotografy','photomaestro@mail.ru','Andrey Aksenov','Vologodskaya 25-74','Arkhangelsk','','RUSSIAN FEDERATION','163001','89210725205','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-23 06:34:28',0,NULL,3,1,3,1,'RA184524679CN\r ','hermeshine'),(24552,808299814018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','mia6456','mia007@westnet.com.au','Trevor & Mia Parks','11 Richards St','Beelbangera','New South Wales','AUSTRALIA','2680','0415452513','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 06:42:33',0,NULL,3,0,3,1,'RA184524682CN\r ','photographyacc\r2XL 已入库'),(24553,8881329984951646,111,'70cm  横杆',1,'',0,'hutongstore','fine2011art','gdg2011@yahoo.com','Georges Djambov','309 B<br>Cann Hall Road','Leytonstone','London','UNITED KINGDOM','E11 3NL','',NULL,NULL,NULL,'2012-02-23 08:15:51',0,NULL,3,0,3,1,'RA184524719CN ','还有\r1.6*3白色布，115W  220V灯泡\r灯架最上面配件 '),(24554,801966932001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','vladimir_bashkirtsev','vladimir@bashkirtsev.com','Vladimir Bashkirtsev','Suite 5, Level 5<br>19 North Terrace','Hackney','South Australia','AUSTRALIA','5069','0882661951','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 08:38:10',0,NULL,3,1,11,1,'BJ01715606 ','hermeshine'),(24555,846504749002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','boristlibor','boris.t@vip.hr','Boris Tomljanović','Diračje 95a','Rijeka','','CROATIA','51000','0916316666','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 08:44:17',0,NULL,3,1,3,1,'RA184524784CN ','hermeshine'),(24556,868819290017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',59.98,'photographyacc','julebarbier','julecourrier@yahoo.fr','Julien Barbier','Avaldsnesgata 33','Stavanger','','NORWAY','4014','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 09:57:33',0,NULL,3,1,3,1,'RA184524838CN ','photographyacc'),(24557,868824265017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'photographyacc','masuimis_dragon','derrickjphotography@yahoo.com','derrick john macnish','45 union street','greenock','Inverclyde','UNITED KINGDOM','pa16 8dn','07912965868','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 10:14:38',0,NULL,8,1,17,0,NULL,'photographyacc'),(24558,846525529002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','baytago','tago@rho.forthnet.gr','Panagiotis Angouras','Londinou 6','Rhodes','','GREECE','85100','+302241069061','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 10:15:29',0,NULL,3,1,3,1,'RA184524736CN ','hermeshine'),(24559,808347868018,280805178508,'Promotion ! NEW Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.9,'photographyacc','masuimis_dragon','derrickjphotography@yahoo.com','derrick john macnish','45 union street','greenock','Inverclyde','UNITED KINGDOM','pa16 8dn','07912965868','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 10:24:16',0,NULL,3,1,11,1,'BJ01715611 ','photographyacc\r无牌方镜 渐变灰 （nd8）   1\r无牌方镜 ND8   1'),(24560,932595926016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','larsdok7.5','larsdok@hotmail.com','Lars Doksæter','Valkendorfsgaten 2c','Bergen','Hordaland','NORWAY','5012','92410814','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-23 10:33:49',0,NULL,3,1,5,1,'CP244439989CN\r ','hutongstore\r欧标'),(24561,802007913001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','magal_2007','magal53@hotmail.com','Antonio Magalhaes','Rua do Centro 75','São Mamede de Infesta','São Mamede de Infesta','PORTUGAL','4465-071','351914958784','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 11:22:58',0,NULL,3,1,3,1,'RA184524909CN ','hermeshine\r称重量\r4节\r退一半'),(24562,802009160001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','volodymyrk2005','prodigydenstudio@yahoo.com','Volodymyr Kuzmin','422 Whittaker Ave<br>Prodigy Dental Studio','Trenton','NJ','UNITED STATES','08611-1228','(609) 649-8012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 11:29:11',0,NULL,8,1,17,0,NULL,'hermeshine'),(24563,629695910004,140666126913,'New Black Camera Case Shoulder Bag PU Leather for Canon 5D ii 7D 60D 40D Strong',1,'AD1216',55,'hermeshine','volodymyrk2005','prodigydenstudio@yahoo.com','Volodymyr Kuzmin','422 Whittaker Ave<br>Prodigy Dental Studio','Trenton','NJ','UNITED STATES','08611-1228','(609) 649-8012','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-23 11:29:11',0,NULL,3,1,3,1,'RA184524991CN ','hermeshine\r新款内胆包 中号 canon logo   1\rPU单肩包  黑色  canon   1'),(24564,808367527018,280714977904,'New Dual-Layer Soft Reflective Umbrella Studio 85cm 33\"',1,'AD1156',19.8,'photographyacc','geolasvegas89','geolasvegas@hotmail.com','George A Sneddon','89 Croftside Ave<br>Croftfoot','Glasgow','Glasgow (City of)','UNITED KINGDOM','G44 5NF','07500907812','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 11:29:23',0,NULL,3,1,11,1,'BJ01715610 ','photographyacc'),(24565,802011256001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','rosh8111','roshan@imcsl.com','M.Roshan Deshapriya','Four Films - PAD<br>P.O Box 68364','Kaifan','','KUWAIT','71964','+965 66970953','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 11:38:10',0,NULL,3,1,11,1,'BJ01715609 ','hermeshine'),(24566,846532861002,120568073111,' New Desktop Photography light Stand 10-15\" Tall',2,'AKT010',61.8,'hermeshine','bahrialtay10','altaybahri@hotmail.com','Bahri Altay','Veliefendi mah. Saha Yolu No:22 Celik apt. k:2 d:4<br>zeytinburnu','istanbul','','TURKEY','34025','+905549040829','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 11:50:14',0,NULL,3,1,5,1,'CP244439975CN\r ','hermeshine\r欧标'),(24567,629702066004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',52,'hermeshine','anchovies8','rodlages@gmail.com','Rodrigo Lages','SGAN 914 Modulo A Bl. B Ap. 223<br>Cond. South Beach - Asa Norte','Brasilia','DF','BRAZIL','70790-140','+55 61 8478-8878','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-23 12:00:56',0,NULL,3,1,3,1,'RA184524798CN ','hermeshine'),(24568,802085235001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','sharkey_ward','tft20045@hotmail.com','Rodrigo Loyola','Avda Goycolea 086 Depto 302<br>La Cisterna','Santiago','Metropolitana','CHILE','7990333','56-2-6618204','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 15:38:29',0,NULL,3,1,3,1,'RA184524807CN ','hermeshine'),(24569,846625354002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','vsace','qavu1@verizon.net','Anh Q. Vu','5704 Parkway Dr','Laurel','MD','UNITED STATES','20707-5400','(301) 725-3421','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-23 15:49:00',0,NULL,3,1,1,1,'LK202643215CN ','hermeshine'),(24570,868925500017,270749088949,'NEW Hairlight Photo Studio Boom Arm and Stand 75-135cm',1,'AKT030',58,'photographyacc','dreamyphoto','abuhamed@hotmail.co.uk','Yousuf Al-Musawi','33 LAVENDON HOUSE<br>8 PAVELEY STREET','London','London','UNITED KINGDOM','NW8 8TJ','02072249985','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 15:25:38',0,NULL,3,1,3,1,'RA184524722CN ','photographyacc'),(24571,808466667018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','scubastu','stewart@scan-conversions.com','Stewart Sy','218-21300 Gordon Way','Richmond','BC','CANADA','V6W 1M2','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 16:20:27',0,NULL,3,1,11,1,'BJ01715612 ','photographyacc'),(24572,846784322002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',4,'AD1126',50,'hermeshine','selmajorson','guerraselma@hotmail.com','Selma Guerra','Rua Geraldo Amorim,122','São Paulo','SP','BRAZIL','05594110','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 21:15:14',0,NULL,3,1,3,1,'RA184524775CN ','hermeshine'),(24573,869100369017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','kevint3378','kevin_thomas@tiscali.co.uk','kevin thomas','6 abbots cres, doonfoot','ayr','South Ayrshire','UNITED KINGDOM','ka74jr','01292445513','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-23 20:58:58',0,NULL,3,1,11,1,'BJ01715600 ','photographyacc'),(24574,802263810001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','jpupa','johnpupa@comcast.net','John J. Pupa','78 REDBERRY LN','MARSTONS MILLS','MA','UNITED STATES','02648','(508) 420-0047','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-23 21:51:29',0,NULL,3,1,1,1,'LK202623176CN ','hermeshine'),(24575,808635735018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',38,'photographyacc','vitothiago','thiagovito@gmail.com','Thiago Vito - Nextgen Gaming','Level 5<br>189 Miller Street','North Sydney','New South Wales','AUSTRALIA','2060','0299649111','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 21:54:59',0,NULL,3,1,3,1,'RA184524988CN ','photographyacc'),(24576,952767615015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','xarko','xarkito@gmail.com','David Pardo Noya','C/ O Recreo Nº56, 1º','Ordes','Galicia','SPAIN','15680','696863410','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 22:20:30',0,NULL,3,1,11,1,'BJ01715601 ','hutongstore\r已退款'),(24577,932955075016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','beguilled','ebay@tbldirect.com','Mr Ian Plummer','9 Ballinger Court','Berkhamsted','Hertfordshire','UNITED KINGDOM','HP4 3BX','01442863103','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-23 22:30:19',0,NULL,3,1,11,1,'BJ01715607 ','hutongstore'),(24578,952772517015,250932215266,'Photo Studio Barn Door & Honeycomb Grid & Gel Set ',1,'AD1166',18.7,'hutongstore','lubo.forro','500demigod@gmail.com','Lubos Forro','Sibirska 62','Bratislava','','SLOVAK REPUBLIC','83107','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-23 22:27:25',0,NULL,3,1,3,1,'RA184524974CN ','hutongstore'),(24579,802296213001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','petslane_est','peeter.normak@eesti.ee','Peeter Normak','Tammsaare tee 83 - 29','Tallinn','Harjumaa','ESTONIA','13416','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-23 23:13:27',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(24580,808683236018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','mukeshsmarumm','mukeshsmaru@hotmail.com','Mukesh Maru','1/1 Orchard Crs','Ashfield','New South Wales','AUSTRALIA','2131','6197976342','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-23 23:46:21',0,NULL,3,1,11,1,'BJ01715616 ','photographyacc'),(24581,952809316015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-23 23:51:31',0,NULL,3,1,5,1,'CP244439927CN ','hutongstore\r申报$21\r115w 5500k 灯泡  220v  4个\r80cm 5 合1  1\r牛津布大包   1\r两个单子系统没下来，\r有拍的信和付款信 \r\r\r'),(24582,629920250004,140642546216,'Studio Light 800W Continuous Lighting e Kit with background support system 2m',1,'AKT087',172,'hermeshine','lexus775','clm0221@hotmail.com','Claudia Michael','496 av de la Cathédrale','Rimouski','QC','CANADA','G5L5N3','(418) 723-0221','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 00:17:04',0,NULL,3,1,5,1,'CP244439961CN\r ','hermeshine\r美标\r110V\r1.6*2.1  白色布'),(24583,802317908001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','scpharmacist','bolarosa@aol.com','rl boland','2080 Lakeside St','orangeburg','SC','UNITED STATES','29118','(803) 535-2222','NoPaymentFailure','CheckoutComplete','Other','2012-02-24 00:23:03',0,NULL,3,0,1,1,'LK202605107CN ','hermeshine\r2XL  已入库'),(24584,808695371018,280666850702,'Studio Background Support 7x7 ft White Black Backdrops ',1,'AKT015',80.5,'photographyacc','8_bit_boy','ebay@hazyinseptember.com','anthony smith','10/74 kent st','newfarm','Queensland','AUSTRALIA','4005','0414677173','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-24 00:24:54',0,NULL,5,1,4,0,'YW867610952CN\r ','photographyacc\r黑加白\r已发货.................'),(24585,846868691002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','adamoscz','red.dog@email.cz','Adam Strojsa','Pruchova 3169','Kladno','','CZECH REPUBLIC','27201','+420721102097','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 00:59:29',0,NULL,3,1,11,1,' ','hermeshine'),(24586,846870178002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 01:05:56',0,NULL,3,1,3,1,'RA184507931CN ','hermeshine\r发信问灯泡多少伏\r110V\r申报低值\r'),(24587,8881330051031787,111,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','janettenettyand ','nettyand@iinet.net.au','Janette anderson','c/- Seasol International<br>1027 Mountain Highway','Bayswater','Victoria ','AUSTRALIA','3153','',NULL,NULL,NULL,'2012-02-24 02:37:11',0,NULL,3,1,3,1,'RA184524965CN ','系统没下来单子，\r有拍的信和付款信 '),(24588,8881330051337496,111,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','johnrae1989','john-rae@live.co.uk','John Rae','5 Victoria place','Stirling ','','UNITED KINGDOM','FK8 2QX','',NULL,NULL,NULL,'2012-02-24 02:42:17',0,NULL,3,1,11,1,'BJ01715613 ','系统没下来单子，\r有拍的信和付款信  '),(24589,8881330051513415,111,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.12,'hutongstore','trevatxtal','trevatxtal@aol.com','Trevor Brownen','43 Great Rea Rd','Brixham','Devon ','UNITED KINGDOM','TQ5 9SW','',NULL,NULL,NULL,'2012-02-24 02:45:13',0,NULL,3,1,11,1,'BJ01715621 ','系统没下来单子，\r邮件里有拍的信和付款信 '),(24590,867239950017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',200,'photographyacc','cat_beauty','jskamppi@hotmail.com','Sari Kamppi','11 Napthali Close','Charnwood','Australian Capital Territory','AUSTRALIA','2615','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-02-24 02:45:50',0,NULL,3,1,4,1,'YW867610974CN ','photographyacc\r澳标'),(24591,8881330052074079,111,'1.6m x 2.1m Background Backdrop Photography Non-Woven',1,'',10.99,'photographyacc','ashtonng070509','joe-regina@hotmail.com','Joe Ng','207 Beamish St<br>Campsie','Sydney','New South Wales','AUSTRALIA','2194','',NULL,NULL,NULL,'2012-02-24 02:54:34',0,NULL,3,0,11,1,'BJ01715618 ','1.6*2.1  白色 \r系统没下来单子，\r有拍的信和付款信 '),(24592,8881330052240364,111,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',48.99,'photographyacc','station2stationtennis','s2stebay@googlemail.com','michael piper','46 redwood gardens','chingford','London ','UNITED KINGDOM','e4 7nz','',NULL,NULL,NULL,'2012-02-24 02:57:20',0,NULL,3,1,3,1,'RA184524841CN ','系统没下来单子，\r有拍的信和付款信  '),(24593,8881330052909205,111,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','redcap118','jpaik@optusnet.com.au','jay paik','14 medley st','chifley','Australian Capital Territory','AUSTRALIA','2606','61414818122',NULL,NULL,NULL,'2012-02-24 03:08:29',0,NULL,3,1,11,1,'BJ01715619 ','系统没下来单子。\r邮件只有拍的信 ，\r去后台显示已付款'),(24594,8881330053183899,111,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','zhdan_vyaz','pluzh.ser@gmail.com','Sergey Pluzhnikov','ul. Metallistov 9-32','Vyazniki','Vladimirskaya obl.','RUSSIAN FEDERATION','601445','9209033706',NULL,NULL,NULL,'2012-02-24 03:13:03',0,NULL,3,1,3,1,'RA184524855CN ','系统没下来单子。\r邮件只有拍的信 ，\r去后台显示已付款 '),(24595,8881330053518397,111,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA, REPUBLIC OF','10040','',NULL,NULL,NULL,'2012-02-24 03:18:38',0,NULL,3,1,3,1,'RA184525895CN ','系统没下来单子。\r邮件只有拍的信 ，\r去后台显示已付款  '),(24596,808745999018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','nickip911','nperi816@gmail.com','Nick Peri','2749 Chestnut St.','York','NY','UNITED STATES','14592','(585) 991-9880','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 03:24:46',0,NULL,3,1,1,1,'LK202623304CN ','photographyacc'),(24597,8881330053904752,111,'New 72mm Snap-on Front Lens Cap for Nikon 72 mm lenscap',2,'AA1308',5,'photographyacc','xcaliber1954','x_caliber@optusnet.com.au','Peter  Williams','90 May Terrace<br>Ottoway','Adelaide','South Australia','AUSTRALIA','5013','0884471742',NULL,NULL,NULL,'2012-02-24 03:25:04',0,NULL,3,1,11,1,'BJ01715615 ','系统没下来单子，\r有拍的信\r去后台看显示已付款'),(24598,8881330054180441,111,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','markes1987 ','victormarques_@hotmail.com','Victor Marques Fernandez','c/ eloy reigada nº33   1º','Bembibre','Castilla y León','SPAIN','24300','690656923',NULL,NULL,NULL,'2012-02-24 03:29:40',0,NULL,3,1,3,1,'RA184524767CN ','系统没下来单子。\r邮件只有拍的信 ，\r去后台显示已付款  '),(24599,846920294002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','prettywomen_1969','sylvieland121@hotmail.com','Sylvie Landry','5175 Jalobert app 7','St-Hyacinthe','QC','CANADA','J2S3Y4','(450) 768-7638','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 03:57:24',0,NULL,3,0,3,1,'RA184525793CN ','hermeshine\r1.6*3  黑色'),(24600,802378970001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','photo_core','deaction@gmail.com','Pavel Tiutiunicov','Vasilievsky Ostrov, 21-liniya, 14/43','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','199106','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 04:02:46',0,NULL,3,1,11,1,'BJ01715617 ','hermeshine'),(24601,8881330059300104,111,'无牌方镜 渐变灰 （nd2）',1,'AD1218',0,'photographyacc','misc_items_2010','misc-sales@hotmail.com','Ricky Gamble','1 Flanders Row<br>Railway Road','Wisbech','Cambridgeshire','UNITED KINGDOM','PE13 2UP','01945584112',NULL,NULL,NULL,'2012-02-24 04:55:00',0,NULL,3,1,3,1,'BJ01715603 ',NULL),(24602,8881330060292341,111,'伞式柔光箱80cm  8角  ',3,'AD1198',98.97,'hermeshine','thiagoliveira2011','thiagoliveira@terra.com.br','Thiago Oliveira de Oliveira','Avenida Eduardo Prado<br>1670 - Incoterm Indústria de Termômetros - MARKETING','Cavalhada','Porto Alegre  - Rio Grande do Sul','BRAZIL','91751-000','',NULL,NULL,NULL,'2012-02-24 05:11:32',0,NULL,3,1,3,1,'RA184524815CN ','Thiago Oliveira de Oliveira\rAvenida Eduardo Prado, 1670 - Incoterm Indústria de Termômetros - MARKETING\rCavalhada\rPorto Alegre  - Rio Grande do Sul\r91751-000\rBrazil\r 申报$18\r'),(24603,8881330065116596,111,' Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','philthistle','thistle@blueyonder.co.uk','philip sawford','3 west court<br>the thistle foundation','edinburgh','Midlothian','UNITED KINGDOM','eh16 4eb','01316614013',NULL,NULL,NULL,'2012-02-24 06:31:56',0,NULL,3,1,4,1,'YW867610963CN ','英标\r除了C以外再发\r1.6*2.1  黑色 \r没有拍卖信和付款信\r'),(24604,8881330065302948,111,' 1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.79,'hutongstore','philthistle','thistle@blueyonder.co.uk','philip sawford','3 west court<br>the thistle foundation<br>the thistle foundation','edinburgh','Midlothian','UNITED KINGDOM','eh16 4eb','01316614013',NULL,NULL,NULL,'2012-02-24 06:35:02',0,NULL,8,0,17,0,NULL,NULL),(24607,8881330066928968,111,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','ssg_rus','ssg_pbox@mail.ru','Sergey Samarskiy','Svobody, 26/1, kv. 2','Taganrog','Rostovskaya obl.','RUSSIAN  FEDERATION','347902','+79034356125',NULL,NULL,NULL,'2012-02-24 07:02:08',0,NULL,3,1,11,1,'BJ01715608 ','没有付款信和拍卖信 '),(24605,8881330065612194,111,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore',' a447623884','renhui3290229@gmail.com','hui ren','ROOM 1 HOUSE 5 PENROSE COURT<br>HIGHFIELD ROAD','egham','Surrey','UNITED KINGDOM','tw200ss','07721099038',NULL,NULL,NULL,'2012-02-24 06:40:12',0,NULL,3,1,11,1,'BJ01715614 ','没有拍卖信和付款信 '),(24606,802403690001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','rstedman644f','rstedman@pacific.net.sg','Robert  Stedman','Block 7 Kallang Place #07-08/09','default','','SINGAPORE','339153','6742-4101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 06:06:32',0,NULL,3,1,3,1,'RA184524912CN ','hermeshine\r称重量，算运费'),(24608,8881330067328655,111,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','7190lisa ','elbond01@yahoo.com','lisa bond','lisa bond','buna','TX','UNITED STATES','77612-4287','4092893519',NULL,NULL,NULL,'2012-02-24 07:08:48',0,NULL,3,1,3,1,'RA184524890CN ','没有付款信和拍卖信 '),(24609,8881330068624446,111,'斜臂 最上面配件',1,'',0,'hutongstore','carlos30358','c_costa_@msn.com','Carlos Costa','Rua Escolas Nº 2 Vivenda Costa<br>2680-321 Apelação','Lisboa','Lisboa','PORTUGAL','2680-321','+351 917613125',NULL,NULL,NULL,'2012-02-24 07:30:24',0,NULL,3,0,3,1,'RA184519740CN',NULL),(24610,933131110016,260660053809,'New 82mm 82 mm Adapter Ring for Cokin P series Sigma 24-70mm',1,'AA2222',1.6,'hutongstore','chrscb','chris.baltassis@gmail.com','Chris Baltassis','84 Chios street<br>Agia Paraskevi','Athens','Greece','GREECE','15343','6944 300 135','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 07:39:05',0,NULL,3,1,11,1,'BJ01715602 ','hutongstore'),(24611,846965742002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 07:39:36',0,NULL,3,1,17,0,NULL,'hermeshine'),(24612,802421354001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 07:39:37',0,NULL,3,1,17,0,NULL,'hermeshine'),(24613,846965743002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 07:39:38',0,NULL,3,1,17,0,NULL,'hermeshine'),(24614,802421356001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',2,'AB1201',34,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 07:39:40',0,NULL,3,1,17,0,NULL,'hermeshine'),(24615,802421353001,110790875316,'New Professional Portable Diffuser for SpeedLight sb900 sb700 580ex metz XL ',1,'AD1210',12.99,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 07:39:35',0,NULL,3,1,17,0,NULL,'hermeshine'),(24616,802421352001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 07:39:34',0,NULL,3,1,17,0,NULL,'hermeshine'),(24617,846965741002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 07:39:35',0,NULL,3,1,17,0,NULL,'hermeshine'),(24618,802421355001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','czechjewels','mcervenka@centrum.cz','Marek Cervenka','Rubesova 1285/16','Plzen','Czech Republic','CZECH REPUBLIC','32600','+420603729317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 07:39:39',0,NULL,3,1,5,1,'CP244439913CN ','hermeshine\r115w 5500k 灯泡  220v  2\r无牌方镜 渐变灰 （nd2）  1\r5灯头+60-90棚   1\r倒影板（白黑）  2\rlif通用柔光罩XL   1\r45w 5500k 灯泡 220v   2\r115w 5500k 灯泡  220v  4\r无牌方镜 渐变灰 （nd8）  1'),(24619,802422729001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','doomu','alkharch@gmail.com','Olexander Kharchenko','ulica Vishnyakovskaya 17, KVARTIRA 95','Kiev','','UKRAINE','02140','+380502189286','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 07:47:58',0,NULL,3,1,5,1,'CP244439958CN ','hermeshine\r黑加白'),(24620,846968587002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','npouesi','naipouesi@yahoo.com','Agaiotupu Pouesi','558 E Double St','Carson','CA','UNITED STATES','90745','(310) 347-5300','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 07:53:13',0,NULL,3,1,3,1,'RA184524886CN ','hermeshine'),(24621,808806943018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.86,'photographyacc','sbbs83','sbbsga@gmail.com','Saiful Sufri','Lot 77, Taman Seri Gaya<br>Jalan Maktab Gaya, Lorong Seladang','Kota Kinabalu','Sabah','MALAYSIA','88300','0168353536','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 08:09:53',0,NULL,3,1,11,1,'BJ01715605 ','photographyacc'),(24622,846973824002,120661195323,'Green-L 62mm Graduated Neutral Density ND Grey Filter',1,'AA3318',7.41,'hermeshine','jimble0328','jimblyg@yahoo.com','James Charlton','1623 S Atlantic St','Boise','ID','UNITED STATES','83705','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 08:17:22',0,NULL,3,1,1,1,'LK202687826CN ','hermeshine'),(24623,802431375001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','antonenkoanton','numis28@mail.ru','Anton Antonenko','Suzdalskaya str. 16-2-132','Moskow','','RUSSIAN FEDERATION','111673','89651842980','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 08:28:42',0,NULL,8,1,17,0,NULL,'hermeshine'),(24624,802431694001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','antonenkoanton','numis28@mail.ru','Anton Antonenko','Suzdalskaya str. 16-2-132','Moskow','','RUSSIAN FEDERATION','111673','89651842980','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 08:30:06',0,NULL,3,1,11,1,'BJ01715604 ','hermeshine\r无牌方镜 渐变灰 （nd8）   1\r无牌方镜 渐变灰 （nd2）   1'),(24625,952963308015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','josantonio1393','servitronic@ono.com','José Antonio Reguera Menéndez','Heliodoro A. Fernández, 6','Colindres','Cantabria','SPAIN','39750','607 20 02 27','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 08:35:58',0,NULL,3,1,3,1,'RA184525008CN ','hutongstore'),(24626,952969963015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','ninapts','jamyth@gmail.com','Nikolina Petolas','Maksimirska 105','Zagreb','Croatia','CROATIA','10000','00385989080982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 08:59:39',0,NULL,3,1,3,1,'RA184507361CN ','hutongstore'),(24627,933156146016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','rusty_lightning_photography','rusty.lightning@gmail.com','Matthew Manwaring','16 Rodney Cresent<br>Ford','Arundel','West Sussex','UNITED KINGDOM','BN18 0DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 09:09:46',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24628,630013058004,140649026335,'New 100% Cotton Photo photographya Vest for Sony Nikon Canon color: kaqi',1,'AA2123',32,'hermeshine','vickers6626','pvickers@tpg.com.au','paul vickers','7 christine avenue','berwick','Victoria','AUSTRALIA','3806','0397961250','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 09:22:15',0,NULL,3,1,17,0,NULL,'hermeshine\r'),(24629,846988590002,120592624747,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',103,'hermeshine','vickers6626','pvickers@tpg.com.au','paul vickers','7 christine avenue','berwick','Victoria','AUSTRALIA','3806','0397961250','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 09:22:14',0,NULL,3,1,4,1,'YW867611000CN\r ','hermeshine\r摄影背心 驼色厚 无字 大小无特别标注为 XL   1\r球台 伟峰 WF-717AH  1\r'),(24630,802445072001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ps203','kursk_video@mail.ru','Sergey Pronin','Orlovskaya d12 kv 245','Kursk','Kursk','RUSSIAN FEDERATION','305040','+7(951)3100687','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 09:29:21',0,NULL,3,1,3,1,'RA184525878CN ','hermeshine'),(24631,952980634015,250692236379,'Continuous Lighting System - light stand/bulb holder/um',1,'AKT009',55,'hutongstore','redroseyred','janelouiserose@aol.com','jane rose','5 great green<br>cockfield','bury st edmunds','Suffolk','UNITED KINGDOM','IP300HQ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-24 09:34:52',0,NULL,3,1,4,1,'YW867611022CN\r ','hutongstore\r英标'),(24632,933166009016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','oh1242','oliverholman@hotmail.com','Oliver Holman','Sjøstranda 69, leilighet B.89','Tromsø','','NORWAY','9006','4798823151','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 09:44:29',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24633,951828647015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','aris2010aris','arismart2@yahoo.gr','aris martakos','dragatsaniou 6A','Lamia','Fthiotida','GREECE','35100','(+30)6977993903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 11:11:08',0,NULL,3,1,3,1,'RA184507551CN ','hutongstore'),(24634,802470670001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','svnguyen69','svn2009@gmail.com','Sanh Nguyen','Suite 1138, 1 Queens Road','Melbourne','Victoria','AUSTRALIA','3004','0410409095','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 11:12:13',0,NULL,3,1,11,1,'、 ','hermeshine'),(24635,933213341016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','spielbergofhereford','neiloseman@googlemail.com','Neil Oseman','119 Widemarsh Street','Hereford','Herefordshire','UNITED KINGDOM','HR4 9EZ','01432353647','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-24 12:05:53',0,NULL,3,1,12,1,'3125968661','hutongstore\r英标'),(24636,802485070001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 12:06:12',0,NULL,3,1,17,0,NULL,'hermeshine'),(24637,847016550002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:06:14',0,NULL,3,1,17,0,NULL,'hermeshine'),(24638,802464982001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 12:06:13',0,NULL,3,1,17,0,NULL,'hermeshine'),(24639,847015961002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',25,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:06:12',0,NULL,3,1,17,0,NULL,'hermeshine'),(24640,802464795001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:06:13',0,NULL,3,1,4,1,'YW867611055CN\r ','hermeshine\r灯架  2m  1\r斜臂   1\r反光伞110cm   1\r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）  1      欧标\r灯架 84cm   1\r倒影板（白黑）  1\r闪光灯B座   2\r独脚架  伟峰 WT-1005  1'),(24641,802486060001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','wickermanakos1','wickermanakos@gmail.com','Kostas Petropoulos','mesologgiou 63b','Thessaloniki','Evosmos','GREECE','56224','+306942281980','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 12:10:18',0,NULL,3,1,3,1,'RA184507517CN ','hermeshine'),(24642,869376899017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',18,'photographyacc','bleu4363','wanfamily@internode.on.net','Betty Leung','455 Victoria Road','Malaga','Western Australia','AUSTRALIA','6090','0403327549','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 12:17:02',0,NULL,3,1,3,1,'RA184507640CN ','photographyacc'),(24643,847034396002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','avmoran','avmoran1@earthlink.net','Anita Moran','5351 Rocks Rd','Pylesville','MD','UNITED STATES','21132','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-24 12:18:19',0,NULL,3,1,1,1,'LK211137376CN  ','hermeshine'),(24644,953040416015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','audioxtra','nigeljopson@yahoo.com','N Jopson','2 Old Dene Cottages<br>Ranmore Common Road','Westhumble','Dorking','UNITED KINGDOM','RH5 6AZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 12:25:29',0,NULL,3,1,3,1,'RA184507534CN ','hutongstore'),(24645,847036241002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','serg140457','sergltd@list.ru','Sergey Gorban','Starokorsunskaya<br>85','Krasnodar','Krasnodarskii krai','RUSSIAN FEDERATION','350912','(861) 227-8429','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-24 12:25:38',0,NULL,3,0,3,1,'RA184508000CN ','hermeshine\rL 已入库'),(24646,869389025017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',3.5,'photographyacc','rosmizi','mohdrosmizi@yahoo.com','MOHD ROSMIZI ABD RAHMAN','8 Carter Street','Noble Park','Victoria','AUSTRALIA','3174','0411351974','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-24 13:17:54',0,NULL,3,1,11,1,'、 ','photographyacc'),(24647,847072537002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',16.4,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 14:17:59',0,NULL,3,1,17,0,NULL,'hermeshine'),(24648,953107325015,250804358083,'New 67mm Lenscap for Nikon Lens Snap-on 67  Front Cap',1,'AA1307',1.87,'hutongstore','batatarfc','batatarfc@ig.com.br','Ricardo F Coimbra','82, Cavendish Road','Colliers Wood','London','UNITED KINGDOM','SW19 2EU','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 14:59:53',0,NULL,3,1,2,1,'\\ ','hutongstore'),(24649,847098721002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','dberkovic','danijel.berkovic@gmail.com','Danijel Berkovic','Sokolgradska 53','Zagreb','','CROATIA','10000','+385 91 6500945','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 15:28:38',0,NULL,3,1,3,1,'RA184507295CN ','hermeshine'),(24650,933079774016,260660053846,'Photo Studio Background Support 2m×3m 7 x 10 ft + BAG',1,'AO0011',47.5,'hutongstore','superpuga','propuga@yandex.ru','Alexandr Volunkov','38, Proletarskaya str., app. 8','Kondopoga','Karelia','RUSSIAN FEDERATION','186225','(+7) 911-414-38-14','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 15:40:23',0,NULL,3,1,5,1,'CP244439649CN ','hutongstore'),(24651,802464131001,110422379787,'Aluminium Lightweight 71\" Camera Monopod 3-way head New',1,'AE1603',22,'hermeshine','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 15:51:41',0,NULL,3,1,17,0,NULL,'hermeshine'),(24652,953138409015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-02-24 16:06:33',0,NULL,3,1,12,1,'3126033735 ','hutongstore\r除了C以外再发\r灯架  2m  2\r欧标\r申报70'),(24653,953143566015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 16:14:07',0,NULL,3,1,3,1,'RA184507335CN ','hutongstore\r申报$14'),(24654,933340636016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','ellen01384','ellenbranter@hotmail.co.uk','Mr G. Branter','13 Malvern House<br>Pickersleigh close','Halesowen','West Midlands','UNITED KINGDOM','B63 4TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 16:59:55',0,NULL,3,1,17,0,NULL,'hutongstore'),(24655,933347282016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','ellen01384','ellenbranter@hotmail.co.uk','Mr G. Branter','13 Malvern House<br>Pickersleigh close','Halesowen','West Midlands','UNITED KINGDOM','B63 4TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 16:59:54',0,NULL,3,1,2,1,NULL,'hutongstore\r麂皮  2\r'),(24656,869531854017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','fiav07','fievel61@hotmail.com','Jacques Viel','1805, chemin de la Réserve','Chicoutimi','QC','CANADA','G7J0C9','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 18:22:57',0,NULL,3,1,11,1,'、 ','photographyacc'),(24657,869527391017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.9,'photographyacc','rydelko','rydelko@yahoo.ca','Karl RYDLO','Apt.#404-3097 Lincoln Avenue','Coquitlam','BC','CANADA','V3B0E3','(604) 942-4723','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-24 18:25:46',0,NULL,3,1,11,1,'、 ','photographyacc'),(24658,953256183015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','dianenik1012','dianenik@gmail.com','Diane Nikolic','14,<br>Ferdinand Calleja Street,','Mosta','','MALTA','MST3753','0035699456922','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 19:25:55',0,NULL,3,1,5,1,'CP2444439635CN ','hutongstore\r英标'),(24659,802666527001,110716976862,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','udiam12','udiam12@hotmail.com','UDI AMSELLEM','Mekor Haim 24-7','Jerusalem','Israel','ISRAEL','93465','97226737792','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 19:39:41',0,NULL,3,1,11,1,'、 ','hermeshine'),(24660,933466303016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','vasspiou','vaspiou@gmail.com','VASSILIS BERTOS','STEFANOU KOUMANOUDI 27','ATHENS','','GREECE','11474','+306934708373','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 20:12:34',0,NULL,3,1,3,1,'RA184507375CN ','hutongstore'),(24661,802684598001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','ronkobi2012','ronkobi4@gmail.com','ron kobi','Sderot binyamin 58,(apartment 6)','netanya','-Select-','ISRAEL','42314',' 0524555335','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-24 20:14:28',0,NULL,3,1,3,1,'RA184507392CN ','hermeshine'),(24662,953297530015,250958162625,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',22,'hutongstore','itaniaestudi','iania47@hotmail.com','iolanda andres corretge','c_ puigllançada, 6 1r<br>passeig Pere III, 83 1-3','manresa','Cataluña','SPAIN','08242','938732157','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 20:23:36',0,NULL,3,1,3,1,'RA184507415CN ','hutongstore'),(24663,953355221015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',4,'AC2402',48.4,'hutongstore','rokfeller','vikey133@gmail.com','Mikhail Papulyan','Lublinskaya 159-39','Moscow','RU','RUSSIAN FEDERATION','109341','+7 9261014855','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-24 21:59:59',0,NULL,3,1,3,1,'RA184507477CN ','hutongstore\rCP244596193CN'),(24664,933541222016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','syl_shek','sylviashek@msn.com','Sylvia shek','11/5 Southhouse Brae','edinburgh','Edinburgh (City of)','UNITED KINGDOM','eh17 8dg','01312583598','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-24 22:18:59',0,NULL,3,1,11,1,'、 ','hutongstore'),(24665,847295130002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','castro1681969','dcarrerascastro@yahoo.com','CASTRO CARRERAS','6703 nw 7th st<br>sdq 8145','miami','FL','UNITED STATES','33126-6007','(809) 246-6787','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-24 22:29:17',0,NULL,3,1,3,1,'RA184507287CN ','hermeshine'),(24666,846786265002,120566694497,'2 x 4 SOCKET W/ 24\"X24\" SOFTBOX PHOTO VIDEO LIGHT HEAD',1,'AKT040',74.9,'hermeshine','sakostudio','farzanehmusictv@gmail.com','Farzaneh Lindquist','6006 San Fernando Rd<br>Ste A','Glendale','CA','UNITED STATES','91202-2775','(818) 206-8816','NoPaymentFailure','CheckoutComplete','Other','2012-02-24 23:43:56',0,NULL,3,1,4,1,'YW867611173CN ','hermeshine\r美标'),(24667,953410613015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',2,'AE3401',32,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 00:03:14',0,NULL,3,1,17,0,NULL,'hutongstore'),(24668,869714346017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.99,'photographyacc','123sell','ak73@onthenet.com.au','Alan King','72 Prospect Crt','Robina','Queensland','AUSTRALIA','4226','0755787669','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 00:49:54',0,NULL,3,1,2,1,'30123174900 ','photographyacc'),(24669,802794839001,110489672383,'NEW 77mm Snap-on Front Lens Cap for Canon 77 Lenscap',2,'AA1304',5.2,'hermeshine','demchinsk','demchinsky@hotmail.com','Steve Demchinsky','c/o Charter Keck Cramer<br>Level 1, 620 Church Street','Richmond','Victoria','AUSTRALIA','3121','0394255170','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 01:11:09',0,NULL,3,1,2,1,'30123177766 ','hermeshine'),(24670,953434812015,250599923179,'New 72mm 72 Ring adapter and Holder for Cokin P Series ',1,'AKT023',3.12,'hutongstore','stevetiles70','stevetiles2004@yahoo.co.uk','stephen allen-marley','15 First Row','ashington','Northumberland','UNITED KINGDOM','NE638ND','01670816695','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 01:12:08',0,NULL,3,1,2,1,'30123178466 ','hutongstore'),(24671,953456919015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','carolinabastias','carolina.bastias.fotos@gmail.com','Carolina Bastias','tomas gutierrez 5601<br>villa el almendral Penalolen','Santiago','Santiago','CHILE','7930126','09 82616239','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 02:20:45',0,NULL,3,1,17,0,NULL,'hutongstore'),(24672,953458622015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','carolinabastias','carolina.bastias.fotos@gmail.com','Carolina Bastias','tomas gutierrez 5601<br>villa el almendral Penalolen','Santiago','Santiago','CHILE','7930126','09 82616239','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 02:26:15',0,NULL,3,1,3,1,'RA184507429CN ','hutongstore\r灯架  2m 1\r闪光灯云台(配合灯架）  1\r伞式柔光箱 80cm 8角    1\r灯架包薄  1'),(24673,802847102001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 04:51:36',0,NULL,3,1,3,1,'RA184507485CN ','hermeshine'),(24674,869791251017,270748624857,'New Photo Light Kit for Flash Umbrella D Mount set ',2,'AKT052',85.6,'photographyacc','fortunatehcf','fortunate.chauraya@anglocoal.com.au','Fortunate Chauraya','2 Michael Drive','Biloela','Queensland','AUSTRALIA','4715','0447532738','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 05:57:31',0,NULL,3,1,4,1,'YW867611033CN\r ','photographyacc\r2套2云柔'),(24675,809277569018,280683075819,'Stereo Microphone for DC DV Camcorder 60D 5D II 7D 550D',1,'AA1215',42.99,'photographyacc','pygmydragon','eugeniegoodyer@gmail.com','Eugenie Goodyer','1 Pibrac Av','Warrawee','New South Wales','AUSTRALIA','2074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 07:22:15',0,NULL,8,1,17,0,NULL,'photographyacc'),(24676,869806804017,270742401961,'New IR Wireless Remote Control for Canon 550D 7D 500D',1,'AA2202',3.5,'photographyacc','pygmydragon','eugeniegoodyer@gmail.com','Eugenie Goodyer','1 Pibrac Av','Warrawee','New South Wales','AUSTRALIA','2074','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 07:22:16',0,NULL,3,1,3,1,'RA184507914CN ','photographyacc\r麦克风  1\r爵影红外 canon   1'),(24677,847403389002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',79.98,'hermeshine','bombardier2003','benedict-thomas.sau@hec.ca','Benedict Thomas Sau','5211 Philippe Lalonde #7','Montreal','QC','CANADA','H4C 0B3','(514) 781-8867','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 07:07:41',0,NULL,3,1,5,1,'CP244439621CN ','hermeshine'),(24678,847437451002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','natali_photo_design','ntlplv1@gmail.com','Nataliya Pylayeva','Sanedrin<br>47 / 30','Beer-Sheva','Negev','ISRAEL','84593','0546476020','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 08:11:40',0,NULL,3,0,3,1,'RA184507826CN ','hermeshine\r1.6*3  黑色'),(24679,847445950002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','texas_tony33','s-shit@inbox.ru','Vladyslav Yatsun','Kyivska, 12 (Rivne-27)<br>PO Box 23','Rivne','','UKRAINE','33027','380630763628','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 08:55:40',0,NULL,3,1,11,1,'、 ','hermeshine'),(24680,933749327016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','kum2345','kum234@mail.ru','Yury Lutkovskiy','Nahimova  11-13','Volhov','Leningradskaya oblast`','RUSSIAN FEDERATION','187401','+79112379333','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 09:35:28',0,NULL,3,1,11,1,'、 ','hutongstore'),(24681,802906511001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','chingaik','yc_aik@yahoo.com','ChingAik Yeoh','12, Tingkat Bukit Kecil 4<br>Taman Sri Nibong','Bayan Lepas','Penang','MALAYSIA','11900','0124553151','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-25 09:47:03',0,NULL,3,1,3,1,'RA184507874CN ','hermeshine'),(24682,847469107002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','contra7ivo_pt','contra7ivo@hotmail.com','Ivo Moreira','Travessa Doutor Américo Jazelino Dias da Costa, 17<br>Nº 17','Fânzeres - Gondomar','Porto/Gondomar/Fânzeres','PORTUGAL','4510-551','00351967752233','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 10:19:08',0,NULL,3,1,3,1,'RA184507260CN ','hermeshine'),(24683,802929938001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','ali_suttondept','ali@bohemian.plus.com','Alastair Sutton','8 Northridge<br>Northiam','Rye','East Sussex','UNITED KINGDOM','TN31 6PG','01797252201','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 11:06:35',0,NULL,3,1,11,1,'、 ','hermeshine'),(24684,869883227017,270751512053,'YongNuo 3m Off Camera FLASH sync Cord for Nikon - i TTL',1,'AB3320',28.99,'photographyacc','marlabe','helmutk@westnet.com.au','H . Kummer','69 Old Marlo Road','Marlo','Victoria','AUSTRALIA','3888','0429800846','NoPaymentFailure','CheckoutComplete','AU_SmallParcelWithTracking','2012-02-25 11:53:25',0,NULL,3,1,3,1,'RA184507738CN ','photographyacc'),(24685,802958023001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','valerybuchko1984','valerybuchko2@gmail.com','Valery Buchko','10 district 1A - 10','Balkhash','Karagandinskaya obl','KAZAKHSTAN','100300','(701) 727 - 4947','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 12:35:43',0,NULL,3,1,17,0,NULL,'hermeshine'),(24686,802958024001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','valerybuchko1984','valerybuchko2@gmail.com','Valery Buchko','10 district 1A - 10','Balkhash','Karagandinskaya obl','KAZAKHSTAN','100300','(701) 727 - 4947','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 12:35:44',0,NULL,3,1,11,1,'、 ','hermeshine\r小号灰卡  1\r铝合金灯座（N）   1'),(24687,933820046016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','kenjiemazzami','ezrihayat@rocketmail.com','Ezri Hayat','42 gainsborough street','Salford','Greater Manchester','UNITED KINGDOM','m7 4an','07423153242','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 12:45:37',0,NULL,3,1,2,1,'30123181535 ','hutongstore'),(24688,953654093015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',49.98,'hutongstore','twin2devine','brendandevine@hotmail.com','Brendan Devine','The Doctors Laboratory<br>Michigan Hs. Michigan Ave','Salford Quays Manchester','Lancashire','UNITED KINGDOM','M50 2GY','01613327181','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 13:06:30',0,NULL,3,1,4,1,'YW867611070CN\r ','hutongstore'),(24689,802981927001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','stylegadget2012','admin@stylegadget.ru','Aleksey Karandasov','ulica Kosygina, dom 9, kv 19','Moscow','Moscow','RUSSIAN FEDERATION','119334',' 79067043840','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 13:44:36',0,NULL,3,1,5,1,'CP244439618CN\r ','hermeshine'),(24690,809396561018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',18,'photographyacc','koh_desmond','lhkoh@yahoo.com','Lian Hau Koh','13 Drummer Street','Harrison','Australian Capital Territory','AUSTRALIA','2914','0421726870','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 13:51:05',0,NULL,3,1,3,1,'RA184507741CN ','photographyacc'),(24691,847539050002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','m.mathavan','manicks@manicksfamily.com','Manicks Mathavan','17 Kylie Tennant St','Franklin','Australian Capital Territory','AUSTRALIA','2913','0402463419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 13:53:58',0,NULL,3,1,3,1,'RA184507675CN ','hermeshine'),(24692,803045345001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','nusho4ka','betula13@yandex.ru','Elena Tyurina','Tsimlyanskaya 2-48','Voronezh','','RUSSIAN FEDERATION','394014','8-9507534561','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-25 16:16:22',0,NULL,8,1,17,0,NULL,'hermeshine'),(24693,847604098002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','nusho4ka','betula13@yandex.ru','Elena Tyurina','Tsimlyanskaya 2-48','Voronezh','','RUSSIAN FEDERATION','394014','8-9507534561','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 16:23:51',0,NULL,3,1,3,1,'RA184507707CN ','hermeshine\r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）  1  欧标\r镜头筒 小号  1\r镜头筒 中号   1\r镜头筒 大号   1\r镜头筒 xl 大号  1'),(24694,803064669001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','a.wider','andwider@gmail.com','Andrzej Widerkiewicz','Maciaszka 32a','Bydgoszcz','','POLAND','85-366','603 948016','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-25 16:55:27',0,NULL,3,1,3,1,'RA184507790CN ','hermeshine'),(24695,847630234002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',59.98,'hermeshine','mike4711_0815','michael.lehdorfer@utanet.at','Michael Lehdorfer','Gemeindeweg 13A/15','Gerasdorf bei Wien','','AUSTRIA','2201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 17:16:51',0,NULL,8,1,17,0,NULL,'hermeshine'),(24696,803076617001,110468046436,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',1,'AKT013',25.8,'hermeshine','mike4711_0815','michael.lehdorfer@utanet.at','Michael Lehdorfer','Gemeindeweg 13A/15','Gerasdorf bei Wien','','AUSTRIA','2201','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 17:19:12',0,NULL,3,1,3,1,'RA184525665CN\r','hermeshine\r斜臂   2\r永诺 CTR-301P 触发器  1\r永诺 CTR-301P 接受器  1'),(24697,953804464015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','revexodus','jaanusehte@gmail.com','Jaanus Ehte','Õnne 38-4','Tartu','Tartumaa','ESTONIA','50106','+37255663210','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 17:36:10',0,NULL,3,1,11,1,'、 ','hutongstore'),(24698,847652333002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','jankop2012','pavel.janko@fancon.cz','Pavel Janko','Dukelska 12','Brno','','CZECH REPUBLIC','61400',' 420606733611','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 17:58:26',0,NULL,3,1,17,0,NULL,'hermeshine'),(24699,847652954002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 18:00:38',0,NULL,3,1,3,1,'RA184507755CN ','hermeshine\r申报gift低值   '),(24700,803103821001,110807100036,'Promotion ! NEW 3pcs Square ND2+ND4+ND8 Neutral Density Filter Kit for Cokin P',1,'AKT096',13.88,'hermeshine','maplestrat33','peter@leelopezphoto.com','Peter Woodward','148 Zifful Ct','Houma','LA','UNITED STATES','70364-3520','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 18:09:23',0,NULL,3,1,1,1,'LK211140786CN  ','hermeshine'),(24701,803115537001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','jose_prestes','jbpze@hotmail.com','Jose Batista Bueno Prestes','rs 239<br>n° 1200','novo Hamburgo','Rio grande sul','BRAZIL','93352000','55 51 93282484','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-25 18:30:53',0,NULL,3,1,3,1,'RA184591316CN ','hermeshine\r欧标\r以收到运费，发货\r'),(24702,847679765002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','rv78blue','qualifoodfast@yahoo.com','Melvin Gaither','948 Market Promenade Ave','Lake Mary','FL','UNITED STATES','32746-4793','','NoPaymentFailure','CheckoutComplete','Other','2012-02-25 18:45:49',0,NULL,3,0,1,1,'LK211107811CN ','hermeshine\r3XL 已入库'),(24703,803129406001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','kelween','feverish85@mail.ru','Igor Lyalkin','30 Let Pobedy 132,  7<br>30 Let Pobedy, dom 132, kvartira 7','Tyumen','RU','RUSSIAN FEDERATION','625028','(905) 858-5141','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 19:00:48',0,NULL,3,1,3,1,'RA184507446CN ','hermeshine'),(24704,803135915001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','heve1','hventura@yahoo.com','Heriberto Ventura','Gonzalo Fernandez de Oviedo 2726<br>Jardines de la Paz','Guadalajara','Jalisco','MEXICO','44860','33341220','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 19:05:36',0,NULL,3,1,3,1,'RA184507401CN ','hermeshine'),(24705,847703813002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','solomonet','films.pro@walla.com','Rotem Solomon','Hamizmor  3<br>M.B 5452','Pardes Hanna-Karkur','Israel','ISRAEL','37510','972-54-6808912','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 19:27:49',0,NULL,3,1,3,1,'RA184507432CN \rRA184507976CN','hermeshine\r分开发\r算一下运费'),(24706,934058718016,260660053809,'New 82mm 82 mm Adapter Ring for Cokin P series Sigma 24-70mm',1,'AA2222',1.6,'hutongstore','seddon4050','rob@robertwilkinson.co.uk','Rob Wilkinson','12 Spinnaker House<br>Lock Approach','Port Solent','Hampshire','UNITED KINGDOM','PO6 4UY','07836546556','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 19:30:02',0,NULL,3,1,2,1,'30123182121 ','hutongstore'),(24707,847721512002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','18chaos','jbrewley@gmail.com','Jason Brewley','Estate Thomas 9234','St. Thomas','VI','UNITED STATES','00802','(340) 998-9999','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-02-25 19:59:10',0,NULL,3,1,4,1,'YW867611011CN\r ','hermeshine\rJason Brewley\rEstate Thomas 9234\rSt. Thomas, VI 00802\rUnited States\r燕文不到，3.6该走EMS外地\rEE651628184CN\r\r'),(24708,953911956015,250599983185,'New Neoprene Reversible Cover for Canon 5D II 7D',1,'AC1304',5.5,'hutongstore','elghoumari','nour@photonour.com','Nour El Ghoumari','65,Sugden Road','Worthing','West Sussex','UNITED KINGDOM','BN112JG','07766906006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 20:09:47',0,NULL,3,1,11,1,'、 ','hutongstore'),(24709,803179443001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','424robert','bobmauldin@bobmauldin.com','Robert Mauldin','12412 Cimarron Drive','Tyler','TX','UNITED STATES','75709','(903) 292-2129','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-25 20:22:43',0,NULL,3,1,21,1,'RA184507698CN ','hermeshine\r美标\r利润少\rSAL挂号便宜8块钱\r'),(24710,934111631016,260901272233,'New 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',2.5,'hutongstore','jehannus','jens.hannus@surfnet.fi','Jens-Johan Hannus','Itäinenpitkäkatu 25 aB 30','Turku','TURKU','FINLAND','20700','0503393046','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 20:45:47',0,NULL,3,1,11,1,'、 ','hutongstore'),(24711,803193077001,110445705855,'Adjustable Neoprene Padded Camera Neck Strap for Pentax',1,'AB1405',5.49,'hermeshine','jankop2012','pavel.janko@fancon.cz','Vitezslav Hanak','Obla 33','Brno','','CZECH REPUBLIC','634 00','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 20:52:41',0,NULL,3,1,11,1,'、 ','hermeshine\rlenspen  1\r气吹 + 布  1\r肩带 pentax  1'),(24712,847751179002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','hennerdk','kontakt@henrikmoller.dk','henrik møller','Hadbjergvej 112','Hadsten','','DENMARK','8370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 21:00:19',0,NULL,3,1,11,1,'、 ','hermeshine'),(24713,953956442015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','pierre167','otmarp@xs4all.nl','Otmar Permentier','Prinsegracht 48H','Den Haag','','NETHERLANDS','2512GA','06-44320016','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 21:10:46',0,NULL,3,1,3,1,'RA184507724CN ','hutongstore'),(24714,953960722015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','sorin.cristea','sorin@inet.hr','Sorin Cristea','Ul.Sv.Roka 54A','Osijek','','CROATIA','31000','+385959063237','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-25 21:18:05',0,NULL,3,1,11,1,'、 ','hutongstore'),(24715,847758466002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','korr5505','orr500@msn.com','Kenneth Orr','20925 Jenkins St NE','East Bethel','MN','UNITED STATES','55011-9743','(763) 413-2515','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-25 21:18:45',0,NULL,3,0,1,1,'LK211126413CN  ','hermeshine\r1.6*3  黑色'),(24716,803229457001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','dvladi5','dvladi5@yahoo.com','Daniel Vladimirsky','4320 Sepulveda Blvd','Culver City','CA','UNITED STATES','90230','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 22:02:40',0,NULL,3,1,1,1,'LK211145267CN  ','hermeshine'),(24717,847785969002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','djonesimage','djones8793@optonline.net','Debra Jones','829 Prospect Ave','Keyport','NJ','UNITED STATES','07735-5434','(732) 970-6432','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-25 22:03:47',0,NULL,3,1,3,1,'RA184507596CN ','hermeshine'),(24718,870203584017,270747481572,'New Neoprene Neck Shoulder Strap for Pentax SLR camera',1,'AB1405',5.08,'photographyacc','errolkphoto','ebax@tpg.com.au','errol bax','Shop 36 quick as a flash<br>Gladstone Central, Dawson Highway','Gladstone','Queensland','AUSTRALIA','4680','0749729576','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-25 22:15:39',0,NULL,3,1,11,1,'、 ','photographyacc'),(24719,847768238002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','alas8578','asierlh@yahoo.es','Aitor Las Hayas','C/ Juntas Generales nº 55 4Izq','Vitoria','País Vasco','SPAIN','01010','945254205','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 21:27:59',0,NULL,3,1,11,1,'、 ','hermeshine'),(24720,953993916015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','miggy_619','orlytantoco@yahoo.com','Orlando Tantoco','9 Knevett Close','Colchester','Essex','UNITED KINGDOM','CO4 5HQ','07834235207','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 22:15:14',0,NULL,3,1,3,1,'RA184507344CN ','hutongstore'),(24721,803260944001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','3801adrian','ackrem@yahoo.com.au','a krempin','52 the ridgeway','bolton point','New South Wales','AUSTRALIA','2283','0249595586','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 23:19:43',0,NULL,3,1,11,1,'、 ','hermeshine'),(24722,954037153015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:46:39',0,NULL,3,1,17,0,NULL,'hutongstore'),(24723,934213029016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:49:18',0,NULL,3,1,17,0,NULL,'hutongstore\r'),(24724,954039464015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:50:21',0,NULL,3,1,17,0,NULL,'hutongstore'),(24725,954039821015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','arsenalfan_2000','arsenalfan_2000@hotmail.co.uk','Philip J Vernon','67 Keyham Lane West','Leicester','Leicestershire','UNITED KINGDOM','LE5 1RS','01162200715','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-25 23:51:05',0,NULL,3,1,3,1,'RA184507772CN \rRA184507769CN','hutongstore\r反光板 80cm 2合1     1\r反光板  80cm 5合1    1\r伞式柔光箱 60×90cm   1\r伞式柔光箱 80cm 8角    1\r\r'),(24726,847828810002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','jeyrun','slavaguzenko@yahoo.com','Slava Guzenko','27 Hillgrove Cres','Berwick','Victoria','AUSTRALIA','3806','0397021997','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-25 23:51:52',0,NULL,3,1,11,1,'、 ','hermeshine'),(24727,870259501017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',1,'AA3301',3.2,'photographyacc','kvadratura','ivelinakirilovabg@gmail.com','Ivelina Andreeva','Zahari Stoqnov 25, et.3, ap.6','Dobrich','Dobrich','BULGARIA','9300','+3590888340522','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 00:37:13',0,NULL,3,1,11,1,'、 ','photographyacc'),(24728,847855451002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','wendtah','wendtah@msn.com','Aaron Wendt','7905 Volk Dr','Dayton','OH','UNITED STATES','45415-2241','(937) 898-3680','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 01:14:23',0,NULL,3,1,3,1,'RA184507582CN ','hermeshine'),(24729,847883094002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','adrenalin086','xoaz122@hotmail.com','Jason Tam','3370 East 29th Ave','Vancouver','BC','CANADA','V5R1W8','(604) 783-7969','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 02:47:05',0,NULL,3,1,3,1,'RA184507300CN ','hermeshine'),(24730,8881330226162788,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail ',1,'AKT052',42.99,'aliexpress','1006974427','tcortelacci@hotmail.com','Tania Regina Cortelacci Marchezoni','Rua Rui Barbosa, 451 Apt 401','Maringa','Parana','BRAZIL','87020090','+55 044 33057861',NULL,NULL,NULL,'2012-02-26 03:16:02',0,NULL,3,1,3,1,'RA184507565CN ',NULL),(24731,954114398015,250958162625,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',22,'hutongstore','justy_west','west_boy_46@hotmail.com','Justin Caruana','Our Lady of Ta\' Pinu<br>Frenc tal-Gharb Str.','Gharb','Gozo','MALTA','GRB 1202','(356) 7928 4601','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 03:21:30',0,NULL,3,1,3,1,'RA184507548CN ','hutongstore'),(24732,8881330226824413,111,'Free shipping & Tracking # - Pro Spanner Wrench Set 2 for repair tool lens openning ',1,'AA2401',33.99,'aliexpress','1006960325 ','kdbarth@gmx.de','Klaus-Dieter Barth','Bahnhofstr. 29','Friedrichroda','Thueringen','GERMANY','99894','+0049 3623 303030',NULL,NULL,NULL,'2012-02-26 03:27:04',0,NULL,3,1,3,1,'RA184507619CN ',NULL),(24733,8881330226929844,111,'Photo Studio Background Support (7ft x 7ft) + Free Backdrop - Wholesale/ Retail',1,'AO0009',69.99,'aliexpress','1006963088 ','e.koc@hotmail.se','Ergun Koc','Almvagen 18 B','Kristianstad','Sweden','SWEDEN','29141','+0046 076 0347159',NULL,NULL,NULL,'2012-02-26 03:28:49',0,NULL,3,1,4,1,'YW867611044CN\r ','+白布 '),(24734,8881330229267285,111,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','grindkt88','grindkt88@yahoo.com','Michael Fessenden','2215 E Bramble Ave','Mesa','AZ ','UNITED STATES','85204','',NULL,NULL,NULL,'2012-02-26 04:07:47',0,NULL,3,1,1,1,'LK211109171CN ','hermeshine\r有拍卖信和付款信，\r系统里没有 '),(24735,8881330229458035,111,'New 4 Sockets with 20\"X28\" Softbox Photo Video Light',2,'AD1176',75.98,'hermeshine','melate8','tonefotos@hotmail.com','Maria Antonieta Cevallos','Obregon 405 pte','Navojoa','Sonora ','MEXICO','85830','',NULL,NULL,NULL,'2012-02-26 04:10:58',0,NULL,3,1,6,1,'EE651291547CN ','需要重量算一下怎么发合适\r系统里没有单子\r邮件里有拍卖信和付款信 '),(24736,803348574001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','makukori','stmach-pp--with-ganesh@iris.eonet.ne.jp','Kiyokazu Tokuda','2-11-25 SUGA','TONDABAYASHISHI','Osaka','JAPAN','5840062','09056457202','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 04:30:17',0,NULL,3,1,3,1,'RA184507809CN ','hermeshine'),(24737,803364352001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',1,'AE2201',37.98,'hermeshine','ibuyusedgear','rogerjohansen@mac.com','Roger Johansen','106 Parkview Ave','Weehawken','NJ','UNITED STATES','07086-6819','(201) 920-9026','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 05:47:05',0,NULL,3,1,3,1,'RA184507494CN\r ','hermeshine\r美标'),(24738,809799018018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','chrisiey7463','chrisiey@hotmail.com','Chris Caldwell','16 Carramar Close','Brandy Hill','New South Wales','AUSTRALIA','2324','0423285883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 06:12:08',0,NULL,3,0,11,1,'、 ','photographyacc\r1.6*2.1  白色'),(24739,847935581002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','amlalways','ams3837@yahoo.com','Aaron Lingar','2671 w midway ave','Post Falls','ID','UNITED STATES','83854-4493','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-26 06:39:47',0,NULL,3,0,1,1,'LK211142257CN ','hermeshine\r1.6*3 绿色'),(24740,803378692001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','rainedman2000','rainedman2000@yahoo.com','Willy Cao','15205 Lamella Ct','Chesterfield','MO','UNITED STATES','63017-2483','(314) 239-8440','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-26 07:09:53',0,NULL,3,1,1,1,'LK211110651CN  ','hermeshine'),(24741,843340558002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','ezolos880816','ezolos@mail.ru','Алёна Сёмина','Чернореченская 49-36','Самара','','RUSSIAN FEDERATION','443096','+79277031225','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 08:14:24',0,NULL,3,1,3,1,'RA184507636CN ','hermeshine'),(24742,954209309015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','geddeholm','michael.stendahl@fibo.varnamo.net','Michael Stendahl','Valdemarsgatan 8','Värnamo','','SWEDEN','33140','+46 (0)73 995 1687','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-26 09:07:11',0,NULL,3,1,3,1,'RA184507667CN ','hutongstore'),(24743,934401758016,260768455478,'New 52mm Lenscap for Nikon Lens Snap-on 52  Front Cap',1,'AA1305',1.87,'hutongstore','floumakis','floumakis@gmail.com','Faidon Loumakis','Fluent Interaction<br>17G Clerkenwell Road','City of London','London','UNITED KINGDOM','EC1M 5RD','07889764958','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 09:39:56',0,NULL,3,1,11,1,'、 ','hutongstore'),(24744,803419724001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','gsarsa','gsarsa@gmail.com','Consultores MTT- Gonzalo Sarsa','C/ San Lorenzo, 30, Of. A','Zaragoza','Aragón','SPAIN','50001','976231000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 09:37:04',0,NULL,3,1,11,1,'、 ','hermeshine'),(24745,954243737015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','ealpozo','apozomar@gmail.com','Antonio Luis Pozo Marín','Avd José Antonio, 16','Tíjola (Almería)','Andalucía Ceuta y Melilla','SPAIN','04880','649971655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 10:16:15',0,NULL,3,1,3,1,'RA184507327CN ','hutongstore'),(24746,870424484017,270747044190,'New 62mm Snap-on Front Lens Cap for Nikon 62 mm lenscap',1,'AA1306',2.5,'photographyacc','joeg2996','jgoozeff@bigpond.net.au','Joe Goozeff','17 Varna St','CLOVELLY','New South Wales','AUSTRALIA','2031','0410654844','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 10:16:54',0,NULL,3,1,11,1,'、 ','photographyacc'),(24747,954253995015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','diy_tony','a.pennington@ntlworld.com','Arthur  Pennington','81A Ampthill Road','Shefford','Bedfordshire','UNITED KINGDOM','SG175AZ','01462621916','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 10:39:26',0,NULL,3,0,3,1,'RA184507786CN ','hutongstore\rXL  已入库'),(24748,848022708002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',4,'AD1169',27.52,'hermeshine','hulder1','stephenhull@hotmail.com','Stephen Hull','256 Serpells Road','Templestowe','Victoria','AUSTRALIA','3106','0398421029','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 11:17:29',0,NULL,3,1,11,1,'、 ','hermeshine'),(24749,848025560002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','luiguisan','luis.osendi@gmail.com','Sandra Rodriguez Alcazar','C/San Nicolás de Bari, 2. 3ºB','Paracuellos de Jarama','Madrid','SPAIN','28860','666608930','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 11:24:42',0,NULL,3,1,3,1,'RA184507622CN ','hermeshine'),(24750,954285459015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','nativenoiseza','nativenoise@gmail.com','Bevan Godden','94 Murray street','Kokstad','KZN','SOUTH AFRICA','4700','+27742922298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 11:33:46',0,NULL,3,1,12,1,'3126045602\r ','hutongstore\r反光板 80cm 2合1  1\r3*6 白色和黑色布\r欧标\r泡重24.3\r'),(24751,954285462015,250631211627,'32\" 2-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3302',8,'hutongstore','nativenoiseza','nativenoise@gmail.com','Bevan Godden','94 Murray street','Kokstad','KZN','SOUTH AFRICA','4700','+27742922298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 11:33:47',0,NULL,3,1,17,0,'3126045602 ','hutongstore'),(24752,803478902001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 12:02:05',0,NULL,3,1,17,0,NULL,'hermeshine'),(24753,848043219002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',1,'AD1169',6.88,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 12:05:46',0,NULL,3,1,3,1,'RA184507525CN ','hermeshine\r反光板支架  1\r沙袋（普通）   1'),(24754,848046812002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','exhumer2012','exhumer@yandex.ru','Sergey Neputaev','Solnechnaya, 15-27','Saransk','Mordovia','RUSSIAN FEDERATION','430017','9272760797','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 12:13:23',0,NULL,3,1,17,0,NULL,'hermeshine'),(24755,848046813002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','exhumer2012','exhumer@yandex.ru','Sergey Neputaev','Solnechnaya, 15-27','Saransk','Mordovia','RUSSIAN FEDERATION','430017','9272760797','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 12:13:24',0,NULL,3,1,3,1,'RA184507684CN ','hermeshine\r反光板 60cm 2合1    1\r反光板 100*150 40*60 5合1    1'),(24756,848062039002,120693172459,'Photo  Background Support 2 x 2m (7×7 ft) + Backdrop',1,'AO0010',70,'hermeshine','lelik35','y_alexei@mail.ru','Alexey Yarkovoy','Michurinskiy prospekt, No.27, Bldg.1, Apt.64','Moscow','','RUSSIAN FEDERATION','119607','7(9030612-4357','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 12:48:20',0,NULL,3,1,5,1,'CP244439604CN\r ','hermeshine'),(24757,803489737001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','doronmdk','doron@mdk.co.il','Doron Kilstein','8 Haneve\'em str.','Haifa','Haifa','ISRAEL','33501','+97248665447','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 13:05:59',0,NULL,3,1,11,1,' 、','hermeshine'),(24758,848105243002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','worleybird98','worleybird98@hotmail.com','Janis A. Worley','5623 Williamsburg Cir','Hudson','OH','UNITED STATES','44236','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 14:18:22',0,NULL,3,1,1,1,'LK211132541CN  ','hermeshine'),(24759,934568090016,260808977562,'Portable 60cm 24\" Soft Box Softbox for Flash Speedlight',1,'AB3329',30.99,'hutongstore','lookedvicspb','looked@mail.ru','Victor Kolomiets','Ammermana 31-15','Kronstadt','Saint-Petersburg','RUSSIAN FEDERATION','197762','(905) 2680724','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 14:40:30',0,NULL,3,1,3,1,'RA184507962CN ','hutongstore'),(24760,953651992015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','ramilx4','x4studio@bk.ru','Рамиль Ахметов','Красная позиция, 2а, 239','Казань','Татарстан','RUSSIAN FEDERATION','420061','+79872224935','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 14:57:43',0,NULL,3,1,3,1,'RA184507715CN ','hutongstore\r欧标'),(24761,954411067015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','tencho_79','tencho@abv.bg','Tencho Baharov','59B HEATH ROAD','HOUNSLOW','Middlesex','UNITED KINGDOM','TW3 2NP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 15:03:00',0,NULL,3,1,3,1,'RA184507928CN ','hutongstore\r英标'),(24762,630858854004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','alesshans','yi2han@hotmail.com','Yih Han Tan','492A-3-17,<br>JALAN AIR ITAM','AIR ITAM','PENANG','MALAYSIA','11400','0174011007','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 15:54:11',0,NULL,3,1,2,1,'30123181701 ','hermeshine'),(24763,803603876001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','billarstudio','billarstudio@yahoo.com','JESUS H. GALLEGOS','CERRADA DE NICOLAS BRAVO #2 CASA 24<br>COL. AMPLIACION TEPEPAN','MEXICO D.F','DISTRITO FEDERAL','MEXICO','16010','52155-37336099','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 16:04:25',0,NULL,3,0,3,1,'RA184507891CN ','hermeshine\rXL  已入库'),(24764,848168459002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','webdivers1996','webdivers1996@hotmail.com','Valerio Tripodi','Holvenstraat 166','Overpelt','','BELGIUM','3900','(011)533797','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 16:08:56',0,NULL,3,0,3,1,'RA184507888CN ','hermeshine\rL 已入库'),(24765,803618962001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','davestpro','davestcorp@gmail.com','Alexander Dolgin','Metallurgov 49A-43','Tula','','RUSSIAN FEDERATION','300027','+7 (953) 422-3000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 16:25:50',0,NULL,3,1,3,1,'RA184507503CN ','hermeshine\r4节'),(24766,870636442017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','aldoscic','aldosc@go.net.mt','Aldo Scicluna','89 Claire E. Engel Street','St Julian\'s','','MALTA','STJ 1814','+356 21382654','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-26 16:44:55',0,NULL,3,1,11,1,'、 ','photographyacc'),(24767,803639328001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',19.99,'hermeshine','925coin0clj','vasilverbelle@earthlink.net','Ann Cooper','PO Box 190','Port Haywood','VA','UNITED STATES','23138-0190','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 16:53:29',0,NULL,3,1,1,1,'LK211153657CN ','hermeshine'),(24768,848231331002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','knesandahl','knesan@frisurf.no','Knut Erik Sandahl','Bjoernemyrveien 13','Oppegaard','Oppegaard','NORWAY','NO-1415','(47) 91647672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 17:30:59',0,NULL,8,1,17,0,NULL,'hermeshine'),(24769,803678813001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','knesandahl','knesan@frisurf.no','Knut Erik Sandahl','Bjoernemyrveien 13','Oppegaard','Oppegaard','NORWAY','NO-1415','(47) 91647672','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 17:41:58',0,NULL,3,1,3,1,'RA184525674CN\r ','hermeshine\r斜臂   1\r反光板支架  1\r看一下超重了吗'),(24770,803685151001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','candr2004','cwphotography75@gmail.com','Christie Williams','744 Chatsworth Dr','Newport News','VA','UNITED STATES','23601-1455','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-02-26 17:52:09',0,NULL,3,1,4,1,'YW867611066CN\r ','hermeshine'),(24771,803759381001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',2,'AC2401',33.98,'hermeshine','liveinstylerus','agapovstudio@gmail.com','Alisa Vorobyeva','Planernaya 45-1-286','Saint-petersburg','','RUSSIAN FEDERATION','197373','89213885670','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 19:04:07',0,NULL,3,1,3,1,'RA184507993CN ','hermeshine'),(24772,954663035015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','cathbellamy','catherinebellamy@hotmail.com','Catherine Bellamy','76 Bushmead Avenure<br>Kingskerswell','Newton Abbot','Devon','UNITED KINGDOM','TQ125EP','01803873053','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 19:11:53',0,NULL,3,1,11,1,'、 ','hutongstore'),(24773,848335883002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','helgelutsk','oleg@chernenko.info','Oleg Chernenko','Gornaya<br>2/27','Lutsk','Volyn','UKRAINE','43001','+380673327612','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 19:16:44',0,NULL,3,1,17,0,NULL,'hermeshine'),(24774,803776783001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','juvenal_70','juvenalpinto_70@hotmail.com','Juvenal Silva Pinto','Rua Dr. Pr. António joaquim Ferreira da Silva, Bloco A, 1 Esq.','Oliveira de Azemeis','Cucujães','PORTUGAL','3720 - 767','912713707','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 19:21:06',0,NULL,3,1,11,1,'、 ','hermeshine'),(24775,954682976015,250600501508,'Continuous Lighting System soft box photography studio ',1,'AKT016',57.9,'hutongstore','wolfr5','wolfr@yandex.ru','Владимир Неверовский','Карла Либкнехта д. 4/176 кв. 23','Калуга','','RUSSIAN FEDERATION','248021','9109137406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 19:36:51',0,NULL,3,1,5,1,'CP244439595CN\r ','hutongstore\r欧标'),(24776,848372446002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','helgelutsk','oleg@chernenko.info','Oleg Chernenko','Gornaya<br>2/27','Lutsk','Volyn','UKRAINE','43001','+380673327612','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-26 19:54:57',0,NULL,3,1,5,1,'CP244439578CN\r ','hermeshine\r115w 5500k 灯泡  220v  4\r5灯头+60-90棚   1\r澳转欧标'),(24777,954173209015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','kaire154','tuust@tuust.ee','Kaire Undrits','Praakli<br>Komsi küla','Puka vald','Valgamaa','ESTONIA','67205','37256616169','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 20:08:34',0,NULL,3,1,11,1,'、 ','hutongstore'),(24778,803821700001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','mpak-666','mpak-service@ya.ru','Evgeniy Moiseenko','Jeleznodorojnikov st. 22-138','Krasnoyarsk','Krasnoyarskii krai','RUSSIAN FEDERATION','660099','89048931398','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 20:10:06',0,NULL,3,1,11,1,'、 ','hermeshine'),(24779,954741396015,250971425921,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.9,'hutongstore','hogbina','anthony@zerosandones.co.uk','Anthony Hogbin c/o Hosting UK','Unit 24 - Ffordd Richard Davies<br>St Asaph Business Park','St Asaph','Denbighshire','UNITED KINGDOM','LL17 0LJ','07803124621','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-26 20:12:59',0,NULL,3,1,17,0,NULL,'hutongstore'),(24780,934914744016,260933198603,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'hutongstore','hogbina','anthony@zerosandones.co.uk','Anthony Hogbin c/o Hosting UK','Unit 24 - Ffordd Richard Davies<br>St Asaph Business Park','St Asaph','Denbighshire','UNITED KINGDOM','LL17 0LJ','07803124621','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-02-26 20:13:00',0,NULL,3,1,11,1,'、 ','hutongstore\r无牌方镜 渐变灰 （nd4）   1\r无牌方镜 渐变灰 （nd8）   1'),(24781,954764962015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','ghost_yratof','yratof@gmail.com','Andrew Smith','17 Sandhurst Avenue','Mansfield','Nottinghamshire','UNITED KINGDOM','NG18 4BS','07955066651','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-26 20:34:48',0,NULL,3,1,3,1,'RA184507273CN ','hutongstore'),(24782,848420984002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','niltonovaes1','niltonovaes@bol.com.br','nilton novaes','rua tavares coutinho 1671','fortaleza','fortaleza','BRAZIL','60160120','5585 99741438','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 20:53:25',0,NULL,3,1,5,1,'CP244439581CN\r ','hermeshine'),(24783,848434154002,120526192258,'NEW 67mm Snap-on Front Lens Cap for Canon 67 Lenscap',1,'AA1302',2.6,'hermeshine','ncmasra','ncmsra@gmail.com','Hikmet Gürüz','Mavişehir mah. 2040 sk. no:104 Ege Park AVM Karşıyaka<br>Starbucks Coffee','İzmir','','TURKEY','35590','+902323244131','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-26 21:09:28',0,NULL,3,1,11,1,'、 ','hermeshine'),(24784,954837111015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','nonoyeye2001','nonoyeye2001@yahoo.es','juan antonio campos ochoa','costa rica 7 blq-4 2ºA','RIO SAN PEDRO(PUERTO REAL)CADIZ','Andalucía Ceuta Y Melilla','SPAIN','11519','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-26 21:56:29',0,NULL,3,1,11,1,'、 ','hutongstore'),(24785,848478467002,120752561050,'Genuine Lenspen lens cleaning CANON NIKON SONY LENS ',1,'AA1310',5.49,'hermeshine','koconut86','koconut@gmail.com','Michael Kochanek','129 W Fayette St<br>Apt 209','Syracuse','NY','UNITED STATES','13202-1383','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-26 22:20:28',0,NULL,3,1,1,1,'LK211106569CN ','hermeshine'),(24786,803933818001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','balbra018','punk.static007@gmail.com','Frank Baltodano','8335 SW 107 avenue apartment H miami florida 33173','miami','FL','UNITED STATES','33173','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 23:02:19',0,NULL,3,1,1,1,'LK211126268CN ','hermeshine'),(24787,935053809016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','banzai_dk','ebay@banzai.dk','Laust Nielsen','Stuhrsvej 36','Skagen','','DENMARK','9990','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-26 23:07:04',0,NULL,3,1,11,1,'、 ','hutongstore'),(24788,870982463017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'photographyacc','nattyg89','nat_d_brat@hotmail.com','Natalie Gardner','11 Easton Avenue','Sylvania','New South Wales','AUSTRALIA','2224','0295761039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 23:46:41',0,NULL,3,1,17,0,NULL,'photographyacc'),(24789,810398773018,280805178524,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.9,'photographyacc','nattyg89','nat_d_brat@hotmail.com','Natalie Gardner','11 Easton Avenue','Sylvania','New South Wales','AUSTRALIA','2224','0295761039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 23:46:42',0,NULL,3,1,17,0,NULL,'photographyacc'),(24790,801373911001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','sxynickle84','cnlesher06@pldi.net','Nicole Lesher','PO Box 313','Crescent','OK','UNITED STATES','73028-0313','(405) 969-3048','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-26 23:50:33',0,NULL,3,0,1,1,'LK211108984CN','hermeshine\r1.6*2.1  黑色'),(24791,870982319017,270891544454,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.9,'photographyacc','nattyg89','nat_d_brat@hotmail.com','Natalie Gardner','11 Easton Avenue','Sylvania','New South Wales','AUSTRALIA','2224','0295761039','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-26 23:51:19',0,NULL,3,1,11,1,'、 ','photographyacc\r无牌方镜 渐变灰 （nd8）   1\r无牌方镜 渐变灰 （nd4）    1\r无牌方镜 渐变灰 （nd2）    1'),(24792,848522955002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','art-latinamerican','eduardocastrejon@prodigy.net.mx','Eduardo Castrejon','del mar #221<br>mozimba','acapulco','Guerrero','MEXICO','39460','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 00:10:31',0,NULL,3,1,11,1,'、 ','hermeshine'),(24793,848529010002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','wickidwombat','dan_wilk@hotmail.com','Daniel Wilkinson','9  Scarlet  Cl','Tapping','Western Australia','AUSTRALIA','6065','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 00:12:53',0,NULL,3,1,11,1,'、 ','hermeshine'),(24794,848528618002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',53.98,'hermeshine','rmcaudio1','rstore@me.com','Rodrigo Martínez','ibsen 6445 departamento 24<br>comuna: Las Condes','Santiago','Región metropolitana','CHILE','7550000','56 99170124','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 00:18:15',0,NULL,3,1,3,1,'RA184507653CN ','hermeshine\r欧标'),(24795,848545679002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','cedrixe','drixe_16@msn.com','cedric azens','les chateliers<br>23 route du val de charente','roullet st estephe','Poitou-Charentes','FRANCE','16440','0615214206','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 00:55:05',0,NULL,3,1,11,1,'、 ','hermeshine'),(24796,810431572018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-27 01:11:08',0,NULL,3,1,3,1,'RA184507313CN ','photographyacc'),(24797,848558000002,120785831796,'New Camera Case Shoulder Bag PU Leather for Nikon D90 D700 D5100 D7000 Strong',1,'AD1200',55,'hermeshine','shiby_87','trash_hot_dolls@hotmail.com','adam shiberras','4 bingera st','gladstone','Queensland','AUSTRALIA','4680','0432230082','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 01:26:14',0,NULL,3,1,3,1,'RA184507980CN ','hermeshine'),(24798,8881330306985221,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail ',1,'AA1310',6.99,'aliexpress','1006997175','nozgul@mail.ru','Vodvud Juriy','Pushkina 17-10','Novokuznetsk','Kemerovskaya obl','RUSSIAN FEDERATION','654013','+7 960 9056000',NULL,NULL,NULL,'2012-02-27 01:43:05',0,NULL,3,1,3,1,'RA184506220CN ','速卖通 '),(24799,8881330307131624,111,'QR Quick Release Plate Tripod Head For 717 EI-717A - Wholesale/ Retail ',1,'AB1204',13.99,'aliexpress','1006998822',' bobbyminder1@bellsouth.net','robert minder','518 lockner rd','columbia','South Carolina','UNITED STATES','29212','+1 803 7312722',NULL,NULL,NULL,'2012-02-27 01:45:31',0,NULL,3,1,1,1,'LK089258221CN  ','速卖通 '),(24800,8881330308597728,111,'50cmx70cm 的柔光箱 (配4灯头）',1,'',0,'hermeshine','coorykoray','korayturkay@gmail.com','Koray Turkay','kurucesme mah. sakarya cad no:46<br>Osmangazi','bursa','bursa','TURKEY','16050','+902242236064',NULL,NULL,NULL,'2012-02-27 02:09:57',0,NULL,3,0,11,1,'、 ','没有4灯头，只是柔光箱 \r已入库'),(24801,8881330311790625,111,'柔光伞110cm ',1,'AD1125',0,'photographyacc','mikcak','mikcak@email.cz','Mikulas Petrik','Na Radouci 1134','Mlada Boleslav','','CZECH REPUBLIC','29301','',NULL,NULL,NULL,'2012-02-27 03:03:10',0,NULL,3,1,3,1,'RA184507579CN ',NULL),(24802,804034635001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','cscot2u','owner@kelowna-website-design.com','Chris Scott','1332 Alder Ct.','Kelowna','BC','CANADA','V1Y 3P9','(250) 762-9132','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 03:17:06',0,NULL,3,1,11,1,'、 ','hermeshine'),(24803,8881330313363880,111,'1600W 套装',1,'AKT039',280,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-02-27 03:29:23',0,NULL,3,1,12,1,'3125968672 ','灯架  2m   2 \r柔光箱50-70cm  四灯头  2\r45w 5500k 灯泡 110v    10\r灯架包   1\r魔术手臂11寸  1'),(24804,848611335002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','bankie_a','b_a.thalas@hotmail.com','Siruth Aurchaikarn','1008/55-58 Soi Predeepanomyong 44 Sukumvit 71 Road<br>Khlongtun Wattana','default','BA','THAILAND','10110','(+66)847711132','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 03:41:43',0,NULL,3,1,11,1,'、 ','hermeshine'),(24805,848632115002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','vkichenko','orielsexi@gmail.com','Kichenko Vladimir','Olega Koshevogo 9-64','Khabarovsk','Khabarovsk / Territory / 27','RUSSIAN FEDERATION','680007','962-150-2020','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 04:54:56',0,NULL,3,1,11,1,'、 ','hermeshine'),(24806,804063374001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','exhumer2012','exhumer@yandex.ru','Sergey Neputaev','Solnechnaya, 15-27','Saransk','Mordovia','RUSSIAN FEDERATION','430017','9272760797','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 04:59:21',0,NULL,3,1,3,1,'RA184507358CN ','hermeshine'),(24807,955041689015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',2,'AD1129',16,'hutongstore','alexpotapov_tlt','bob008@list.ru','Aleksej Potapov','Larina street, 106<br>0','Togliatti','Samara region','RUSSIAN FEDERATION','445007','(903) 331 - 7772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 05:16:38',0,NULL,3,1,11,1,'、 ','hutongstore'),(24808,804066794001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','adelaida2501','sov1987.87@mail.ru','Ольга суслина','бульвар Тинчурина д.1 кв.10','Набережные Челны','Россия','RUSSIAN FEDERATION','423802','8917-925-07-53','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 05:16:51',0,NULL,3,1,11,1,'、 ','hermeshine'),(24809,955041971015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','rjazzjim','rjazzjim@aol.com','James William Roach','5625 Calle Vista Alegre','Yorba Linda','CA','UNITED STATES','92887-2466','(714) 779-2178','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 05:18:45',0,NULL,3,0,1,1,'LK211794559CN ','hutongstore\rXXL  已入库'),(24810,846494374002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','comer203','jgcomer1@msn.com','john comer','1001 Smoke Tree Ln','Virginia Beach','VA','UNITED STATES','23452','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-27 05:19:25',0,NULL,3,1,1,1,'LK211822396CN ','hermeshine'),(24811,8881330321078594,111,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gsilva451 ','gsilva45@gmail.com','Geraldo Silva','168 SE 1st St<br>Suite 904','Miami','FL','UNITED STATES','33131','',NULL,NULL,NULL,'2012-02-27 05:37:58',0,NULL,3,1,1,1,'LK211111881CN ','M  已入库 '),(24812,955059719015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','bisseryo','bisser_yordanov@mail.bg','Bisser Yordanov','Lyulin 10, bl 133, ent1, fl 5, apt 18','Sofia','Sofia','BULGARIA','1335','+359898776059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 06:31:55',0,NULL,3,1,3,1,'RA184507463CN ','hutongstore'),(24813,8881330324317902,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail ',1,'AKT052',42.99,'aliexpress','1007012229','volgoaks@mail.ru','Andrew Bourdiokov','N.Otradu st. 6 - 192','Volgograd','Volgogradskay obl.','RUSSIAN FEDERATION','400121','89023136308',NULL,NULL,NULL,'2012-02-27 06:31:57',0,NULL,3,1,3,1,'RA184525612CN\r ','2云柔\r速卖通 '),(24814,848653545002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','bume003','gregpullen@playbillvenues.com.au','Greg Pullen','Playbill Venues, Building 16,<br>Fox Studios Australia, Lang Road','Moore Park','New South Wales','AUSTRALIA','2021','61299215330','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 06:42:33',0,NULL,3,1,11,1,'、 ','hermeshine'),(24815,871051620017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1302',9.8,'photographyacc','murrami_jagman','jagmanis@hotmail.com','John Barton','44 Judges Gardens','Leda','Western Australia','AUSTRALIA','6170','0427411350','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-27 06:46:40',0,NULL,3,1,11,1,'、 ','photographyacc\r澳标'),(24816,955076399015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','bpenny92','b.penny92@gmail.com','Andrew Pennycuick','9 northbow crt<br>Tallebudgera','Gold Coast','Queensland','AUSTRALIA','4228','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 07:39:02',0,NULL,3,1,3,1,'RA184506088CN ','hutongstore'),(24817,848665337002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',3,'AD1186',89.97,'hermeshine','avzaid','avzaid@gmail.com','Awni Hafedh','Abu Dhabi','Abu Dhabi','Abh Dhabi','UNITED ARAB EMIRATES','55417','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 07:39:52',0,NULL,3,1,3,1,'RA184506091CN ','hermeshine'),(24818,848670831002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','vadimnikolaev','vadimbralukas@gmail.com','Vadim Nikolaev','st.I.Chernyh, 97/4, 49','Tomsk','','RUSSIAN FEDERATION','634062','3822-673306','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-27 08:16:29',0,NULL,3,1,3,1,'RA184506105CN\r ','hermeshine'),(24819,804104707001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','birdjouterie','fernandezrosa32@gmail.com','Rosa Fernández','Colegio de Gestores<br>Pl. Urquinaona 6, 6º','barcelona','Cataluña','SPAIN','08010','933170686','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 08:30:35',0,NULL,3,1,11,1,'.. ','hermeshine'),(24820,804105575001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','albcam22','albcam22@maltanet.net','Carmen Vella','\'Paulmar\' House<br>Triq Salvinu Vella','Mellieha','Mellieha','MALTA','MLH 1142','+356 21520856','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 08:35:42',0,NULL,3,1,11,1,'.... ','hermeshine'),(24821,848677901002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','alevaleva','eva.maria.asensio@hotmail.es','Eva Asensio Morales','Villa de Marin 10 - 9º A','Madrid','Madrid','SPAIN','28029','630048997','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-27 08:38:42',0,NULL,3,1,3,1,'RA184506012CN ','hermeshine'),(24822,804106798001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.99,'hermeshine','durlano','zdurlanov@hotmail.com','Zarko Durlanov','Stiv Naumov 20a','Bitola','','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','7000','+38971242160','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 08:42:45',0,NULL,3,1,11,1,'... ','hermeshine'),(24823,848685744002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','serena1980ro','phooosonic@yahoo.com','elena ciobanu','No 6 Ion Budai Deleanu Str','bucharest','','ROMANIA','040192','00403357146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:10:45',0,NULL,3,1,17,0,NULL,'hermeshine'),(24824,848685745002,120633469024,'Photo Studio Light Stand Heavy Duty Clamp Copper head ',1,'AE3102',7.89,'hermeshine','serena1980ro','phooosonic@yahoo.com','elena ciobanu','No 6 Ion Budai Deleanu Str','bucharest','','ROMANIA','040192','00403357146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:10:47',0,NULL,3,1,17,0,NULL,'hermeshine'),(24825,804113590001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',2,'AE3103',19.6,'hermeshine','serena1980ro','phooosonic@yahoo.com','elena ciobanu','No 6 Ion Budai Deleanu Str','bucharest','','ROMANIA','040192','00403357146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:10:47',0,NULL,3,1,17,0,NULL,'hermeshine'),(24826,848685746002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','serena1980ro','phooosonic@yahoo.com','elena ciobanu','No 6 Ion Budai Deleanu Str','bucharest','','ROMANIA','040192','00403357146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:10:48',0,NULL,3,1,17,0,NULL,'hermeshine'),(24827,804113589001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',1,'AD1167',16,'hermeshine','serena1980ro','phooosonic@yahoo.com','elena ciobanu','No 6 Ion Budai Deleanu Str','bucharest','','ROMANIA','040192','00403357146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 09:10:46',0,NULL,3,1,3,1,'RA184506030CN ','hermeshine\rCANON 镜头盖  58mm  1\r大力夹  1\r大力夹云台  2\rc型大力夹  1\r铝合金灯座（N）   1'),(24828,848709793002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','kuvshcinca','liliya_smetanina@mail.ru','Lilija Smetanina','ul. Dekabristov, dom 4, kv. 73','Gaj','Orenburgskaja obl','RUSSIAN FEDERATION','462635','8(35362)35208','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 10:41:02',0,NULL,3,1,3,1,'RA184506057CN\r ','hermeshine'),(24829,848711035002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',2,'AD1183',185.98,'hermeshine','kuvshcinca','liliya_smetanina@mail.ru','Lilija Smetanina','ul. Dekabristov, dom 4, kv. 73','Gaj','Orenburgskaja obl','RUSSIAN FEDERATION','462635','8(35362)35208','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 10:45:04',0,NULL,3,1,5,1,'CP244439683CN ','hermeshine\r2.4x3m背景架+ 蓝色布  2套\r麂皮  1\r放10个夹子'),(24830,935301908016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','saivonga','dave.crystalstudios@gmail.com','DAVID FRENCH','66 TALBOT ROAD','ISLEWORTH','Middlesex','UNITED KINGDOM','TW7 7HF','07955267412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 10:46:10',0,NULL,3,1,11,1,'.... ','hutongstore'),(24831,804140267001,110658437998,'Remote Shutter Release Cord for Nikon D70s D80 RE-G',2,'AA2221',7.96,'hermeshine','communications_tech','dennis.zanon@victrack.com.au','Dennis Zanon','PO Box 244','Niddrie','Victoria','AUSTRALIA','3042','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 10:52:43',0,NULL,3,1,11,1,'... ','hermeshine'),(24832,804140785001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','mikitee7','mikitee2@yahoo.com','Liz Mikitenko','450 Queensberry St','North Melbourne','Victoria','AUSTRALIA','3051','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 10:54:55',0,NULL,3,1,11,1,'... ','hermeshine'),(24833,848721296002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','rpejkovic','renato.pejkovic@zg.t-com.hr','Renato Pejkovic','Novacka 55','Zagreb','','CROATIA','10040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 11:22:53',0,NULL,3,1,3,1,'RA184506074CN ','hermeshine'),(24834,8881330342245653,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag ',1,'AD1183',100,'aliexpress','Денис Михайлов ','dens96@yandex.ru','Aleksandr Sokolov','Ulitsa Chernova 4-67','Vorkuta','KOMI ','RUSSIA','169900','',NULL,NULL,NULL,'2012-02-27 11:30:45',0,NULL,3,1,5,1,'CP244439670CN ','+1.6m X 4m 白色布'),(24835,631266882004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',2,'AD1219',7,'hermeshine','dgshalonin','info@dime-ltd.com','Dmitry Shalonin','Br. Kashirinykh street, 87-A, 318','Chelyabinsk','Chelyabinsk','RUSSIAN FEDERATION','454016','+79068901900','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 11:54:13',0,NULL,3,1,11,1,'. ','hermeshine'),(24836,935328480016,260901272233,'New 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1202',5,'hutongstore','nutmini13','nuttaphongj.ssi@gmail.com','Nuttaphong Jongsurasitthiwat','Sahaviriya Steel Industries UK Limited.<br>Steel house','Redcar','Cleveland','UNITED KINGDOM','TS10 5QW','07523094801','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 12:00:14',0,NULL,3,1,11,1,'.. ','hutongstore'),(24837,954700625015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','peteyxo','jay_bonapartez@hotmail.com','Guilliano Arduin','Kranenbroekhof 10','Zaandam','','NETHERLANDS','1507 KK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 13:13:18',0,NULL,3,1,4,1,'YW867611162CN ','hutongstore\r欧标'),(24838,801928992001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','setis7771','87017933983@mail.ru','Druzhinin Alexandr','Kutusov str. 32 k.91','Pavlodar','Pavlodarskaya oblast','KAZAKHSTAN','140003','(701)523-5368','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 13:29:10',0,NULL,3,1,17,0,NULL,'hermeshine'),(24839,935369697016,260880822091,'5 outputs light head 60x90 Softbox Continuous lighting kit equals 2000W output',1,'AKT090',150,'hutongstore','dostorreschatun','ignaciotorresalonso@gmail.com','Ignacio Torres Alonso','c/Campaspero,7','Olombrada','Castilla y León','SPAIN','40220','652515819','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 13:42:15',0,NULL,3,1,4,1,'YW867611151CN ','hutongstore\r欧标'),(24840,847159095002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','setis7771','87017933983@mail.ru','Druzhinin Alexandr','Kutusov str. 32 k.91','Pavlodar','Pavlodarskaya oblast','KAZAKHSTAN','140003','(701)523-5368','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 13:29:08',0,NULL,3,1,3,1,'RA184506065CN ','hermeshine\r眼罩 450D/500D  1\r斜臂   1'),(24841,804207016001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','kuvshcinca','liliya_smetanina@mail.ru','Lilija Smetanina','ul. Dekabristov, dom 4, kv. 73','Gaj','Orenburgskaja obl','RUSSIAN FEDERATION','462635','8(35362)35208','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 14:27:43',0,NULL,3,1,17,0,NULL,'hermeshine'),(24842,955232054015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','skyblue742','mb88@hotmail.co.uk','Mandeep Bharaj','48 Erith Road','Belvedere','Kent','UNITED KINGDOM','DA17 6EY','07806414261','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 14:41:53',0,NULL,3,1,11,1,'.. ','hutongstore'),(24843,848788834002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','auihar2009','auihar@gmail.com','IHAR AUSIYEVICH','Pritytskogo str. 112<br>kvartira 397','MINSK','','BELARUS','220017','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 14:48:01',0,NULL,3,1,11,1,'... ','hermeshine'),(24844,804223566001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','duvidf2011','duvidf@live.com','David Feldmar','Kibutz Kissufim','Kissufim','DN negev','ISRAEL','85130',' 872524562031','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 15:11:47',0,NULL,3,1,3,1,'RA184506026CN ','hermeshine'),(24845,848800895002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','drdrddds','drdillarddds@sbcglobal.net','Dan Dillard','710 Elk Rdg','Fairview','TX','UNITED STATES','75069-8747','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-27 15:21:07',0,NULL,3,1,1,1,'LK211806597CN ','hermeshine'),(24846,955267883015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','screwdriver2220','j.jacks@hotmail.com','JEFFERY JACKS','27 WESTCOUNTRY CLOSE<br>WESTON MILL','PLYMOUTH','Devon','UNITED KINGDOM','PL2 2BJ','01752366377','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 15:54:48',0,NULL,3,1,2,1,'. ','hutongstore'),(24847,804244155001,110417007819,'New EyeCup for Canon Ef EOS 40D, 5D, 5D Mark-II',2,'AA1202',4.96,'hermeshine','seyzmo','fedor.bauer@vbleasing.hr','Fedor Jan Bauer','Marjanovicev prilaz 9','Zagreb','','CROATIA','10020','+385 1 98 9806 229','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 16:03:55',0,NULL,3,1,11,1,'\r\r\r\r... ','hermeshine'),(24848,955280299015,250918925611,'New Pro Photo Vest 100% Cotton for Nikon Fans D40 D60 D80 D5100 D7000 D700',1,'AA2101',25,'hutongstore','nadd5676','n.addison2@ntlworld.com','NICK ADDISON','MIDLAND PIG PRODUCERS<br>MERE ROAD, BRANSTON','LINCOLN','Lincolnshire','UNITED KINGDOM','LN42JD','01522826839','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 16:17:21',0,NULL,3,1,3,1,'RA184525325CN ','hutongstore\rM 已入库\r'),(24849,955285012015,250690846438,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',135,'hutongstore','thepcpoet','pcpoet@obheal.ie','Paul Casey','Apt 3 - 5 Smithgrove Terrace<br>Middle Glanmire Rd','Cork','Cork','IRELAND','default','0857126299','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 16:25:46',0,NULL,3,1,4,1,'YW867611140CN ','hutongstore\r英标\r除了C以外再发\r1.6*3  蓝色布'),(24850,935448339016,260660053782,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',12,'hutongstore','thepcpoet','pcpoet@obheal.ie','Paul Casey','Apt 3 - 5 Smithgrove Terrace<br>Middle Glanmire Rd','Cork','Cork','IRELAND','default','0857126299','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 16:25:46',0,NULL,3,1,17,0,NULL,'hutongstore'),(24851,804264144001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','sram6430','rnramales@yahoo.com','ronald ramales','1337 Pine St','port huron','MI','UNITED STATES','48060-5141','(810) 987-5062','NoPaymentFailure','CheckoutComplete','Other','2012-02-27 16:50:27',0,NULL,3,0,1,1,'LK211778587CN ','hermeshine\rXL 已入库'),(24852,848845971002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','byolgecti','b_yolgecti@yahoo.com.tr','BURCU BORAHAN','HAMIYET YUCESES SOK YUCESES APT 6-14<br>SASKINBAKKAL KADIKOY','ISTANBUL','TURKEY','TURKEY','34734','00905354422211','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 17:04:47',0,NULL,3,1,3,1,'RA184506159CN ','hermeshine'),(24853,848851926002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','asharygin','andrew.sharygin@gmail.com','Andrew Sharygin','Krasniy sezd, 2A-14','Yaroslavl','','RUSSIAN FEDERATION','150003','+7(910)9690010','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 17:17:41',0,NULL,3,1,11,1,'... ','hermeshine'),(24854,955378794015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','ay03zde','mark_vickers@blueyonder.co.uk','mark vickers','5 Heather Croft road','Wickford','Essex','UNITED KINGDOM','SS118YA','01268560496','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 18:51:31',0,NULL,3,1,3,1,'RA184506145CN ','hutongstore'),(24855,848910480002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',5,'AA1305',13,'hermeshine','vfm11','vfm2011@gmail.com','Elizaveta Zarokili','Golubinskaya 8 - 301','Volgograd','','RUSSIAN FEDERATION','4000131','+79050630726','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 19:03:00',0,NULL,3,1,3,1,'RA184506255CN ','hermeshine'),(24856,810794449018,280696878124,'100% Cotton Photo Vest for Sony Nikon Canon Light tan',1,'AA2123',28.49,'photographyacc','cokelabtech','c.edmondson@fsmail.net','Colin Edmondson','44 Castlevue Park','Moira','Armagh','UNITED KINGDOM','BT67 0LN','02892610673','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 19:03:50',0,NULL,3,0,3,1,'RA184506247CN ','photographyacc\r3XL  已入库'),(24857,810795069018,280714978182,'Dual-Layer Soft Reflective Umbrella Studio 110cm 43\"',1,'AD1157',29.9,'photographyacc','ralphm64','ralph.mills@vodamail.co.za','Ralph Mills','PO Box 53657<br>Wierda Park','Centurion','','SOUTH AFRICA','0149','+27 82 905 4363','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-27 19:06:00',0,NULL,3,1,11,1,'... ','photographyacc'),(24858,935564750016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','nituzu','gtarland@gmail.com','Mountouris Gerasimos','Kifisias 74','Kalamaria','Thessaloniki','GREECE','55134','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 19:22:03',0,NULL,3,1,11,1,'.. ','hutongstore'),(24859,935569225016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','agge81','mattias.agerberg@gmail.com','Mattias Agerberg','Myrholen 53','Mockfjärd','Dalarna','SWEDEN','78542','0707950950','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-27 19:27:30',0,NULL,3,1,3,1,'RA184506193CN\r ','hutongstore'),(24860,804379303001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',59.98,'hermeshine','igorbomi','igorpaladi@gmail.com','Igor Paladi','Soseaua Sorocii 32/50<br>Gudanov 32/50','Drochia','Drochia','MOLDOVA, REPUBLIC OF','MD-5202','+37368268068','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 20:15:52',0,NULL,3,1,3,1,'RA184525759CN ','hermeshine\r看一下超重吗\r称一下重量    算一下运费'),(24861,804440447001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','sixties-and-seventies','adnan_pamukcu@hotmail.com','Adnan Pamukçu','Caferaga Mah. Yaver Bey Sok. No. 2/2<br>Moda-Kadiköy','Istanbul','-','TURKEY','34710','+90 0216 4186956','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:06:52',0,NULL,3,1,3,1,'RA184506043CN\r ','hermeshine'),(24862,955536306015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','halmo82','shredmaster@azet.sk','Martin Halmo','Cajkovskeho 9','Nitra','','SLOVAK REPUBLIC','94911','+421908545869','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 22:18:37',0,NULL,3,1,3,1,'RA184506131CN ','hutongstore'),(24863,804453456001,110529627295,'Light Soft Box for Studio Strobes 70cmx50cm E27 Socket',1,'AE2401',32,'hermeshine','monsieurmegalo','vik77@free.fr','Haumesser Victor','2 Rue du Parchemin','Strasbourg','Alsace','FRANCE','67000','0648824011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:34:52',0,NULL,3,1,17,0,NULL,'hermeshine'),(24864,804453455001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','monsieurmegalo','vik77@free.fr','Haumesser Victor','2 Rue du Parchemin','Strasbourg','Alsace','FRANCE','67000','0648824011','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-27 22:34:51',0,NULL,3,1,3,1,'RA184506176CN ','hermeshine\r柔光箱 50-70cm 单灯头  1\r灯架  2m  1\r欧标'),(24865,935726270016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','saxamadmac','mickclitheroe@yahoo.co.uk','michael clitheroe','107 slater lane','leyland','Lancashire','UNITED KINGDOM','pr267se','07973134977','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-27 23:26:10',0,NULL,3,1,2,1,'fh ','hutongstore'),(24866,955578411015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','eamonn1234','edwardcampion@gmail.com','Edward Campion','Central Vehicle Office<br>c/o Revenue Commissioners','Rosslare Harbour Co Wexford','','IRELAND','xxx','0863064622','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-27 23:46:03',0,NULL,3,1,11,1,'. ','hutongstore'),(24867,871563388017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',2,'AE3301',29.6,'photographyacc','denn199','jill1927@internode.on.net','Charles Heathcote','136 harrington road<br>Dennington','Warrnambool','Victoria','AUSTRALIA','3280','0355625784','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-27 23:53:59',0,NULL,3,1,3,1,'RA184506128CN ','photographyacc'),(24868,955586794015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','domtomazo','thomasohlsson84@hotmail.com','Thomas Ohlsson','Strandpromenaden 8','Lomma','Skane','SWEDEN','23439','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 00:06:11',0,NULL,3,1,11,1,'.. ','hutongstore'),(24869,849072834002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5.2,'hermeshine','demchinsk','demchinsky@hotmail.com','Steve Demchinsky','c/o Charter Keck Cramer<br>Level 1, 620 Church Street','Richmond','Victoria','AUSTRALIA','3121','0394255170','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 00:35:23',0,NULL,3,1,2,1,'fh ','hermeshine'),(24870,804494920001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','gonzalo11646','shomar@sunflower.com','Gonzalo Romero Jr.','2443 Missouri St','Lawrence','KS','UNITED STATES','66046','(785) 749-3188','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 00:36:54',0,NULL,3,1,1,1,'LK211837078CN ','hermeshine'),(24871,849076139002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 00:47:22',0,NULL,3,1,3,1,'RA184506162CN\r ','hermeshine\r110V\r申报低值'),(24872,849068421002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','edwardskitty2010','leanneklami@rocketmail.com','Leanne Klami','326 Jones Kelley Rd','Travelers Rest','SC','UNITED STATES','29690-9263','(864) 640-9752','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 00:44:17',0,NULL,3,1,3,1,'RA184506114CN ','hermeshine'),(24873,804515415001,110422380084,'Aluminium Lightweight 68\" Camera Monopod BALL HEAD New',1,'AE1604',23,'hermeshine','vitorseagull','vitor.seagull@gmail.com','Luiz Vitor Vieira','Rua Novo Cruzeiro n °46 apto 301<br>Vila Valqueire','Rio de Janeiro','Rio de Janeiro','BRAZIL','21330-240','5521-246-40753 ','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 01:45:16',0,NULL,3,1,3,1,'RA184506202CN ','hermeshine'),(24874,849103771002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','guilhermenico','guinico@gmail.com','Guilherme Gustav Stolzel Amaral  TV USP','Al. Dr. Octávio Pinheiro Brisolla, 9-75,TVUSP vila universitária','Bauru','Sp','BRAZIL','17012-901','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 02:15:57',0,NULL,3,1,3,1,'RA184506180CN ','hermeshine'),(24875,849110318002,120752153194,'Photo Studio Background Support Carrying Carry Bag',3,'AD1129',29.7,'hermeshine','vicferber','vifebe@hotmail.com','Victor Fernandez','ave 19 num 310','Cordoba','Veracruz','MEXICO','94580','2711220135','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 02:32:21',0,NULL,3,1,17,0,NULL,'hermeshine'),(24876,849110319002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',3,'AB3329',146.97,'hermeshine','vicferber','vifebe@hotmail.com','Victor Fernandez','ave 19 num 310','Cordoba','Veracruz','MEXICO','94580','2711220135','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 02:32:22',0,NULL,3,1,3,1,'RA184525745CN\r ','hermeshine\r灯架包薄   3\r闪光的柔光箱   60cm  3\r称一下重量\r分开发\rRA184525728CN\rRA184525731CN\r'),(24877,804531317001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',6.21,'hermeshine','dalito71','dalito71@gmail.com','pedro cabrera','watt 5769','cordoba','cordoba','ARGENTINA','5020','0351-4979512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 02:38:05',0,NULL,3,1,11,1,'... ','hermeshine'),(24878,811000372018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','andywilliam7','andrewwilliams7@y7mail.com','andrew williams','1 jaye street','edge hill cairns','Queensland','AUSTRALIA','4870','0408546238','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 02:46:45',0,NULL,3,0,11,1,'.. ','photographyacc\r1.6*2.1  黑色'),(24879,8881330399785199,111,'橡胶遮光罩 58mm',1,'AB1303',0,'hermeshine','blenheimgal','dscottwells@hotmail.com','Mr David Wells','78 Coldstream Close<br>Cinnamon Brow','Warrington','Cheshire','UNITED KINGDOM','WA2 0LL','',NULL,NULL,NULL,'2012-02-28 03:29:45',0,NULL,3,1,3,1,'RA184519753CN ','RA184519753CN \r这个有单号 '),(24880,849130167002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','euseermide','szaszi-laci@hotmail.com','tomi varga','52 church road, bellbowrie','brisbane','Queensland','AUSTRALIA','4070','0732025919','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 03:38:46',0,NULL,3,1,11,1,'.. ','hermeshine'),(24881,804558734001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','feez170109','nafeez_farouk@hotmail.com','Mohammed Farouk-Yusuf','679  Beenleigh  Rd<br>Brisbane Diagnostics','Sunnybank','Queensland','AUSTRALIA','4109','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 04:17:09',0,NULL,3,1,11,1,'... ','hermeshine'),(24882,955685793015,250692236438,'Digital SLR Camera Rain cover D300S D700 D90 550D 7D 5D',1,'AA3101',7.99,'hutongstore','grannydondon','nandondon@live.com.au','Donna Bremer','5 Tamarind Pl','Barrack Heights','New South Wales','AUSTRALIA','2528','0423362037','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 04:37:01',0,NULL,3,1,11,1,'... ','hutongstore'),(24883,8881330405853925,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail',1,'AA1310',6.99,'aliexpress','1007003146','sovgvd@gmail.com','Marina Devyatkina','dom 9, kvartira 6 Kurchatova','Dubna','Moskovskaya oblast','RUSSIAN FEDERATION','141980','+7 903 5369923',NULL,NULL,NULL,'2012-02-28 05:10:53',0,NULL,3,1,3,1,'RA184525643CN\r ','速卖通 '),(24884,811043107018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.99,'photographyacc','madmickey_1','sam@sam-burke.com','Sam Burke','C/O Caxton St Catering<br>20-22 Prospect St','Fortitude Valley','Queensland','AUSTRALIA','4006','0438727733','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-28 05:22:58',0,NULL,3,1,11,1,'... ','photographyacc'),(24885,804577833001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','mattlainhart2012','mattlainhart@gmail.com','Matthew Lainhart','355 N 7th St<br>Apt 406','Sierra Vista','AZ','UNITED STATES','85635-1666','(520) 255-4148','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-28 05:51:39',0,NULL,3,1,1,1,'LK211787473CN ','hermeshine'),(24886,8881330412205041,111,'New Collapsible 190cm * 140cm backdrop background light green & blue - Wholesale/ Retail',1,'AC3304',54.99,'aliexpress','1007035506 ','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 06:56:45',0,NULL,3,1,3,1,'RA184525135CN\r ','速卖通 '),(24887,8881330412525242,111,'Free shipping & Tracking # - New 400w Studio Mini Flash Kit 200w strobe+ Soft box + 2m Stand - Whole/Retail ',1,'AKT080',268.99,'aliexpress','1007035505 ','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 07:02:05',0,NULL,3,1,6,1,'EE651291533CN ','除了C以外再发\r反光板支架 5\r闪光灯D座   7\r永诺 SF18- CANON 2\r灯架  2m   3\r'),(24888,8881330412619738,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail ',1,'AKT056',50,'aliexpress','1007035504','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 07:03:39',0,NULL,8,1,17,0,NULL,NULL),(24889,8881330413475148,111,'Free shipping & Tracking # - YN Flash Battery Pack SF-18 for Canon Flash 580EXII CP-E4 - Wholesale/Retail ',2,'AB3307',99.98,'aliexpress','1007035503 ','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 07:17:55',0,NULL,8,1,17,0,NULL,NULL),(24890,8881330413530963,111,'Swivel Flash Mount Umbrella Bracket for Light Stand D - Wholesale/ Retail ',7,'AD1122',97.93,'aliexpress','1007035502','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 07:18:50',0,NULL,8,1,17,0,NULL,NULL),(24891,8881330413590956,111,'Pro Photo Studio Reflector Holding Arm 0.66-1.5m - Wholesale/ Retail ',2,'AE2501',51.98,'aliexpress','1007035501 ','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-28 07:19:50',0,NULL,8,1,17,0,NULL,NULL),(24892,955446583015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',34.99,'hutongstore','cherrymosh','sehrish01@hotmail.com','Sehrish Amir','2/4 lake boga ave','deer park','Victoria','AUSTRALIA','3023','0383485165','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 07:28:23',0,NULL,3,1,3,1,'RA184525586CN\r ','hutongstore\r灯架  2m  1\r伞式柔光箱 80cm 8角   1\r已入库'),(24893,804598964001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','$1mp1','tilakaweera@yahoo.com.au','T W','PO Box 2181','Homebush West','New South Wales','AUSTRALIA','2140','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 07:46:06',0,NULL,3,1,3,1,'RA184525569CN\r ','hermeshine\r澳标'),(24895,849184672002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','samzynikon','samzy75@yahoo.com','samir misira','aleja lipa 15','Sarajevo','Kanton Sarajevo','BOSNIA AND HERZEGOVINA','71000','(387)61 712-616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:21:40',0,NULL,3,1,3,1,'RA184525572CN\r ','hermeshine\r欧标'),(24894,8881330417148608,111,'1.6m x 4m 黑色布',1,'',16.5,'hermeshine','eshop_masenka','miroslavhorak.nb@seznam.cz','Lucie Horakova','Jiriho Wolkera 1888','Nymburk','ČR','CZECH REPUBLIC','28802','+420608140139',NULL,NULL,NULL,'2012-02-28 08:19:08',0,NULL,3,0,3,1,'RA184525626CN\r ','另外再放其他颜色布的小块样品 '),(24896,804380771001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','arthur.docx','arthur.doc@bk.ru','Arthur Mkrtchyan','Erebuni str. 32, apt, 85','Yerevan','','ARMENIA','0020','37499012721','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:37:17',0,NULL,3,1,5,1,'CP244439887CN ','hermeshine\r欧标'),(24897,849193408002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','asibit','asibit@zahav.net.il','Asi Bitton','Hayasmin 14','Ganot Hadar','Israel','ISRAEL','42930','972548008456','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:37:21',0,NULL,3,1,3,1,'RA184525705CN\r ','hermeshine\r欧标'),(24898,849194214002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','cps2006lk','cps2005lk@gmail.com','Chaminda Peiris Sooriyapperuma','No 23/1,Lional Jayasinghe rd,<br>Panagoda,','Homagama','Western','SRI LANKA','10200','+94773559469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:42:07',0,NULL,3,1,17,0,NULL,'hermeshine'),(24899,849194117002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','cps2006lk','cps2005lk@gmail.com','Chaminda Peiris Sooriyapperuma','No 23/1,Lional Jayasinghe rd,<br>Panagoda,','Homagama','Western','SRI LANKA','10200','+94773559469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 08:47:14',0,NULL,3,1,3,1,'RA184525630CN\r ','hermeshine\r伞式柔光箱 60×90cm   1\r沙袋（普通）   2'),(24900,935910126016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','baby.cara','henry.mccluskey@yahoo.co.uk','henry mccluskey','81 central avenue','southport','Merseyside','UNITED KINGDOM','pr83eq','01704575225','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 09:17:18',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24901,8881330421107390,111,'斜臂最上面配件  60闪光柔光箱包',1,'',0,'photographyacc','analiavc70','analia2@bigpond.com','Analia Cahill','14 Carlton Crescent','Kogarah Bay','New South Wales','AUSTRALIA','2217','0295464738',NULL,NULL,NULL,'2012-02-28 09:25:07',0,NULL,3,0,3,1,'RA184519665CN ',NULL),(24902,804623082001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','alpinesman','alpinesman@hotmail.com','jean-françois fouquart','batiment B - appart 204<br>2 Rue Colette','toulouse','Midi-Pyrénées','FRANCE','31200','06.81.18.81.01','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 09:34:44',0,NULL,3,1,3,1,'RA184525590CN\r ','hermeshine\rM 已入库'),(24903,955765231015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',10.6,'hutongstore','svetek2002','svetek2002@gmail.com','Ekaterina Svetlova','Novopeschanaya 3-40','Moscow','Russia','RUSSIAN FEDERATION','125057','+79152324041','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 09:39:09',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24904,849211465002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',2,'AB3327',79.98,'hermeshine','raymon.koko','raymonq@gmail.com','ramon portales auñon','luz casanova, 24-11','valencia','Valencia','SPAIN','46009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 09:54:23',0,NULL,3,1,17,1,'YW867611210CN\r ','hermeshine'),(24905,804627907001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','raymon.koko','raymonq@gmail.com','ramon portales auñon','luz casanova, 24-11','valencia','Valencia','SPAIN','46009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 09:54:24',0,NULL,3,1,17,1,'YW867611210CN\r ','hermeshine'),(24906,804627786001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','raymon.koko','raymonq@gmail.com','ramon portales auñon','luz casanova, 24-11','valencia','Valencia','SPAIN','46009','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 09:54:25',0,NULL,3,1,17,1,'YW867611210CN\r ','hermeshine'),(24907,849211926002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','stgeorgedragons','polyview@hotmail.com','Paul Au-Yeung','15 Tracey Avenue','Carlingford','New South Wales','AUSTRALIA','2118','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 09:55:23',0,NULL,3,1,11,1,'、 ','hermeshine\r退一半钱'),(24908,935921525016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','raymon.koko','raymonq@gmail.com','ramon portales auñon','luz casanova, 24-11','valencia','Valencia','SPAIN','46009','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 09:56:03',0,NULL,3,1,4,1,'YW867611210CN\r ','hutongstore\r闪光的柔光箱   40cm  2\r反光板支架  1\r斜臂的夹子（单轮）   1\r反光板  80cm 5合1  1\r是不同店的。hermeshine里面也扫个单号'),(24909,955777430015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','zed_the_pirate','s@birlet.com','Sebastian Birlet','64 Avondale Cres.<br>Enfield','London','Middlesex','UNITED KINGDOM','EN3 7SA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 10:14:54',0,NULL,3,1,3,1,'RA184525691CN\r ','hutongstore'),(24910,849218162002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','danmvieira','danilo@danilovieira.com.br','Danilo Vieira','Rua Quinze de Novembro, 3511 - Apto. 93<br>Centro','São José do Rio Preto','São Paulo','BRAZIL','15015-110','+55 17 9107-6690','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 10:19:44',0,NULL,3,1,3,1,'RA184525657CN\r ','hermeshine'),(24911,849220494002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','megatirta','megatirta@yahoo.com','Rendy Anom M. Sugiono','Duri I No.9 Blok B4<br>Komplek Ruko Lina Indah','Jakarta','DKI','INDONESIA','10140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 10:31:12',0,NULL,3,1,3,1,'RA184525453CN ','hermeshine'),(24912,849235031002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','mannek72','manne.koponen@saunalahti.fi','Manne Koponen','Talvionkuja 3','Tuusula','','FINLAND','04300','0408697206','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 11:21:24',0,NULL,3,1,3,1,'RA184525382CN ','hermeshine'),(24913,849236315002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','sofia052011','mysteryka88@gmail.com','Alexandr Voronov','Oktyabrskaya,74 kv3','Budennovsk','Stavropolskiy kray','RUSSIAN FEDERATION','356806','+7-906-470-19-98','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 11:24:54',0,NULL,3,1,3,1,'RA184525379CN ','hermeshine'),(24914,955803456015,250692238780,'New Desktop Photography light Stand 10-15\" Tall',1,'AKT010',20.9,'hutongstore','choxter79','darko79@gmail.com','Darko Kostic','Vrbanska 12 A','Maribor','','SLOVENIA','2000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 11:33:11',0,NULL,3,1,3,1,'RA184525436CN ','hutongstore\r欧标\r不要申报gift'),(24915,955805619015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 11:43:52',0,NULL,3,1,17,1,'CP244439860CN\r ','hutongstore'),(24916,811139157018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','malfac','mfackender@spotlightonasia.com','Malcolm Fackender','31 Kapooka Avenue','Dapto','New South Wales','AUSTRALIA','2530','0242616210','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-02-28 11:55:15',0,NULL,3,1,4,1,'YW867611206CN\r ','photographyacc'),(24917,804673855001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','jukkos','mail@jukkakoskinen.com','Jukka Koskinen','Pajatie 59','KOTKA','','FINLAND','48600','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 12:44:57',0,NULL,3,1,3,1,'RA184525396CN ','hermeshine'),(24918,849260921002,120661195166,'Green-L 58mm Graduated Neutral Density ND Grey Filter',1,'AA3317',5.95,'hermeshine','leadhead7457','hankins.mike.1@gmail.com','Michael Hankins','7457 S Jackson St','Centennial','CO','UNITED STATES','80122','(303) 221-2611','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 12:51:16',0,NULL,3,1,1,1,'LK212632929CN ','hermeshine'),(24919,801941663001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','photonastya','nastya1991-17@mail.ru','Анастасия Шведкова','ул. Ново кузнечная, д.5','Оренбург','','RUSSIAN FEDERATION','460037','(987)8530609','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 13:34:17',0,NULL,3,1,11,1,'、 ','hermeshine'),(24920,811183402018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','timstable','timballic@gmail.com','Timothy Ball',' Mellings Farm,<br>Benson Lane, Catforth,','Preston,','Lancashire','UNITED KINGDOM','PR40HY','01772691612','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-28 14:05:02',0,NULL,3,1,11,1,'、 ','photographyacc'),(24921,802795662001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','mdmbc','mikemacwillie@gmail.com','Michael MacWillie','23226 121A Ave','Maple Ridge','BC','CANADA','V2X 0X1','(604) 220-0407','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 14:27:57',0,NULL,3,1,11,1,'、 ','hermeshine'),(24922,804709760001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','ketvui','dusun_chong@yahoo.com','Ket Vui Dusun chong','Semi D Lot 50 Taman Utama Jln Utara<br>Lorong Utama 5','Sandakan','Sabah','MALAYSIA','90000','0128183348','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 14:34:02',0,NULL,3,1,11,1,'、 ','hermeshine'),(24923,849302321002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','136443676','mazafak2000@mail.ru','Vitaliy Zhiltsov','senukova 33 kvartira 85','Ukhta','Komi Republic','RUSSIAN FEDERATION','169300','+79091207611','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 14:54:47',0,NULL,3,1,17,1,'CP244439842CN  ','hermeshine'),(24924,804715179001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','136443676','mazafak2000@mail.ru','Vitaliy Zhiltsov','senukova 33 kvartira 85','Ukhta','Komi Republic','RUSSIAN FEDERATION','169300','+79091207611','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 14:51:10',0,NULL,3,1,5,1,'CP244439842CN ','hermeshine\r伞式柔光箱 80cm 8角    1\r灯架  2m  1\r斜臂   1'),(24925,936058049016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','fotopomohnikartem','fotopomohnik@mail.ru','Artem Zabolotskikh','Kluchevoy poselok 41-57','Izhevsk','Udmurtia','RUSSIAN FEDERATION','426063','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 15:35:09',0,NULL,3,1,5,1,'CP244439839CN ','hutongstore\r欧标\r等普通灯架包吧 '),(24926,849318980002,120565576687,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.99,'hermeshine','aqauriusart','yan@yangrin.com','Yan Grin','Avraam Sofer 10/2<br>Rova Yud','Ashdod','','ISRAEL','77467','(518) 289-4146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:36:45',0,NULL,3,1,11,1,'、 ','hermeshine'),(24927,849322974002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','micdub819','mic-dub@hotmail.com','michael dubuc','1580 rue evangeline app. 308','sherbrooke','QC','CANADA','j1h 6b3','(819) 575-1507','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 15:46:47',0,NULL,3,1,3,1,'RA184525405CN ','hermeshine'),(24928,955934453015,250871285429,'10pcs color filters ring holder box for cokin p series',1,'AKT082',28.5,'hutongstore','kindozhang','kindozhang@yahoo.com','Kindo Zhang','Graha Family K-19','Surabaya','East Java','INDONESIA','60228','+62 818 529 618','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 16:26:26',0,NULL,3,1,3,1,'RA184525263CN ','hutongstore\r申报25\r环换成49mm的'),(24929,955958481015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 17:09:53',0,NULL,3,1,17,0,'RA184525317CN ','hutongstore'),(24930,955961155015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 17:20:39',0,NULL,3,1,3,1,'RA184525317CN ','hutongstore\r伞式柔光箱 60×90cm   1\r灯架  2m  1'),(24931,804789966001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','elfabricio','fab418@gmail.com','Fabrice Tremblay','560 Léon','St-Honoré','QC','CANADA','G0V 1L0','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 18:01:55',0,NULL,3,1,11,1,'、 ','hermeshine'),(24932,956011512015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','photodepiction','eventdepiction@gmail.com','Spencer William','Jackdaw Studio<br>Unit D, The Paintworks, Bath Road','Bristol','Bristol','UNITED KINGDOM','BS4 3EH','07527229334','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 18:33:37',0,NULL,3,1,3,1,'RA184525555CN ','hutongstore'),(24933,849399898002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','ilovejeanny','alex@xclass-web.de','Manuela Hantke','Steinlache 5','Woerth','','GERMANY','76744','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-28 18:32:55',0,NULL,3,0,3,1,'RA184525467CN ','hermeshine\rXL 已入库'),(24934,804847055001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','zykarussian','df_lsd@mail.ru','Dmitry Romantsov','ul. Kooperativnaya 28','s. Petrovskoye','Tambovskaya oblast','RUSSIAN FEDERATION','393070','+74754423122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:38:59',0,NULL,3,1,3,1,'RA184525475CN ','hermeshine'),(24935,804838038001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','davidovsv','davidovsv@yandex.ru','Stanislav Davydov','Matrosa Zheleznyaka 23-11','Saint-Petersburg','Russia','RUSSIAN FEDERATION','197343','79213565681','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:22:55',0,NULL,3,1,5,1,'CP244439873CN  ','hermeshine\r除了C以外再发\r倒影板（白黑）  1 \r1.6*2.1  黑加灰\rC里面布1.6*2.1白色\r欧标'),(24936,804838037001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',2,'AO0006',21.98,'hermeshine','davidovsv','davidovsv@yandex.ru','Stanislav Davydov','Matrosa Zheleznyaka 23-11','Saint-Petersburg','Russia','RUSSIAN FEDERATION','197343','79213565681','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:22:54',0,NULL,3,0,17,0,'CP244439873CN  ','hermeshine\r'),(24937,804839001001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','davidovsv','davidovsv@yandex.ru','Stanislav Davydov','Matrosa Zheleznyaka 23-11','Saint-Petersburg','Russia','RUSSIAN FEDERATION','197343','79213565681','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 19:25:10',0,NULL,3,1,17,0,'CP244439873CN ','hermeshine'),(24938,956079226015,250692236133,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',22,'hutongstore','comred','arr70@list.ru','Aleksey Kalashnikov','Degtyrnay str, 20','Penza','Penza','RUSSIAN FEDERATION','440023','(927)2898945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 20:06:19',0,NULL,3,1,3,1,'RA184525484CN ','hutongstore'),(24939,849454243002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','syrrus-ru','syrrus@yandex.ru','Ruslan Syroegin','ul.Safonova, dom 25, kv 44','Severomorsk','Murmanskay','RUSSIAN FEDERATION','184604',' 89212722388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 20:11:25',0,NULL,3,1,3,1,'RA184525498CN ','hermeshine'),(24940,872013255017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.8,'photographyacc','joni01_es','jcagrafica@yahoo.es','JUAN CARLOS ANDRES','Montecelo Bajo, 43.','VIGO','VIGO','SPAIN','36207','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-28 20:36:03',0,NULL,3,1,11,1,'、 ','photographyacc'),(24941,956157323015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-28 21:56:03',0,NULL,3,1,5,1,'CP244439860CN\r ','hutongstore\r4灯头 灯头 孔   2\r50cmx70cm 的柔光箱 (配4灯头）   2\r放4个欧标头给他'),(24942,849515582002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','ashdot','ashdot@ashdot.co.il','Izhar Ashdot','Yosef Nassi 12','Tel Aviv','xx','ISRAEL','65236','+972-3-5253392','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-28 22:02:22',0,NULL,3,1,11,1,'、 ','hermeshine\r欧标'),(24943,936306184016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','janosser','tim_janos@hotmail.com','Tim Janos','38 Whitefriars','Oswestry','Shropshire','UNITED KINGDOM','SY11 2LN','(078) 159-9737 ext.: 9','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 22:04:31',0,NULL,3,1,11,1,'、\r ','hutongstore'),(24944,804947933001,110717761104,'New 77mm Fader ND Neutral Density filter ND2 to ND400',1,'AD1143',36.99,'hermeshine','ansel1946','wlimhof@aol.com','William Imhof','3000 Middleton Way Ct','Hendersonville','NC','UNITED STATES','28791-1844','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-28 22:46:41',0,NULL,3,1,17,0,'LK213329609CN\r ','hermeshine'),(24945,804947934001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','ansel1946','wlimhof@aol.com','William Imhof','3000 Middleton Way Ct','Hendersonville','NC','UNITED STATES','28791-1844','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-28 22:46:42',0,NULL,3,1,1,1,'LK213329609CN\r ','hermeshine\r可调ND镜 77mm   1\r绿叶 渐变镜 77mm  1'),(24946,956200657015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','nonusaequilibrium','david.herod@btinternet.com','David Herod','Codemasters Software Co. Ltd<br>Codemasters Campus, Stoneythorpe','Southam','Warwickshire','UNITED KINGDOM','CV47 2DL','07815913702','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-28 23:16:46',0,NULL,3,1,3,1,'RA184525365CN ','hutongstore'),(24947,936355324016,260814162311,'MBL-306 Complete Tripod Kit Travel  Canon Nikon Sony',1,'AD1132',40,'hutongstore','mkurzum1','mkurzum@gmail.com','Manuel Kurzum','109 rue des berges','Vaudreuil','QC','CANADA','J7V 9X3','(514) 909-9120','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-02-28 23:39:47',0,NULL,3,1,3,1,'RA184525507CN ','hutongstore\r发燕文还是挂号'),(24948,956217625015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','munchkin03','amyangel03@hotmail.com','Amy Nolan','4 The Haywain <br>Stanway','Colchester','Essex','UNITED KINGDOM','CO3 0YG','07512822405','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-28 23:56:17',0,NULL,3,1,4,1,'YW867611195CN\r ','hutongstore\r黑加白'),(24949,804978853001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','the_boldens','boldenk@bgnet.bgsu.edu','Krystal Bolden','2042 Dragon Trl','New Braunfels','TX','UNITED STATES','78130','(937) 321-8075','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-29 00:30:33',0,NULL,3,1,1,1,'LK212631469CN ','hermeshine\r110v  '),(24950,849578461002,120443020790,'Neoprene Protector Camera Cover Case for Canon Nikon L',6,'AC1302',45,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 00:38:49',0,NULL,3,1,3,1,'RA184525419CN ','hermeshine\r申报gift低值   '),(24951,811487511018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','mjameson2011','mjameson08@hotmail.com','Teegan Daniels','684 Mulquineys Road Braunstone','Grafton','New South Wales','AUSTRALIA','2460','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 00:40:38',0,NULL,3,0,11,1,'、 ','photographyacc\r1.6*2.1  黑色'),(24952,804985848001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','omarrebe71','omitorres50@gmail.com','Omar Torres','2081 Sunchine Blvd apto B','Naples','FL','UNITED STATES','34116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 00:56:51',0,NULL,3,0,1,1,'LK212602405CN ','hermeshine\r1.6*2.1  黑色'),(24953,849586143002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','4escapade','luizajeff@comcast.net','Jeffrey Trahan','5605 137th Place SE','Everett','WA','UNITED STATES','98208','','PayPalPaymentInProcess','CheckoutComplete','StandardShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,5,0,18,0,NULL,'hermeshine\r电子账单'),(24954,8881330482847512,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail ',1,'AKT056',50,'aliexpress','1007038861','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-29 02:34:07',0,NULL,8,1,17,0,NULL,NULL),(24955,8881330482902645,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail ',1,'AKT056',50,'aliexpress','1007038880 ','marcelokorea@hotmail.com','Marcelo Sigecazu','Akeno-cho 1-25-3 Akeno- jutaku 5 -102','Toyokawa-shi','Aichi-ken','JAPAN','441 2346','+57 090 66461910',NULL,NULL,NULL,'2012-02-29 02:35:02',0,NULL,8,1,17,0,NULL,NULL),(24956,8881330483472093,111,'Free shipping & Tracking # - New Green.L Premium Quality 55mm CPL Filter FOR Canon Nikon',1,'AA3309',7.49,'aliexpress','1007039751','123@hotmail.com','EVGENIYA Petrushova','Bumazhnaya st., 1, 10','Saint-Petersburg ','','RUSSIAN FEDERATION','190020','+7 812 7862656',NULL,NULL,NULL,'2012-02-29 02:44:32',0,NULL,3,1,17,0,'RA184525060CN\r ',NULL),(24957,8881330483805930,111,'Free shipping & Tracking # - New Neoprene Camera Cover Case for Nikon dslr & semi slr (S) ',1,'AC2302',6.69,'aliexpress','1007039751','123@hotmail.com','EVGENIYA Petrushova','Bumazhnaya st., 1, 10','Saint-Petersburg ','','RUSSIAN FEDERATION','190020','+7 812 7862656',NULL,NULL,NULL,'2012-02-29 02:50:05',0,NULL,3,1,3,1,'RA184525060CN\r ','绿叶 CPL  55mm  1 \r小号内胆包 Nikon  1\r速卖通'),(24958,849603522002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','nathaniel21223','uniquephotoman@gmail.com','Nathaniel Isaac','208 S Pulaski St<br>Ste 4E','Baltimore','MD','UNITED STATES','21223-2952','(443) 642-8944','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 03:10:56',0,NULL,3,1,17,0,'RA184525538CN ','hermeshine'),(24959,849626683002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','nathaniel21223','uniquephotoman@gmail.com','Nathaniel Isaac','208 S Pulaski St<br>Ste 4E','Baltimore','MD','UNITED STATES','21223-2952','(443) 642-8944','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 03:12:28',0,NULL,3,1,3,1,'RA184525538CN ','hermeshine\r伞式柔光箱 80cm 8角    2'),(24960,8881330485755603,111,'New Camera Tripod Fancier FT-6662A with 6160H Ball head - Wholesale/ Retail [AE1503] ',1,'AE1503',72.99,'aliexpress','1007052838','dionisio.merola@inwind.it','merola dionisio','Via Trento , 255 ','Villalba di Guidonia','Roma','ITALY','00012','+0039 338 4929151',NULL,NULL,NULL,'2012-02-29 03:22:35',0,NULL,3,1,4,1,'YW867611302CN ','速卖通 '),(24961,8881330485888746,111,'Aluminium UltraLightweight 71\" Camera Monopod with 3way-head - Wholesale/ Retail [AE1603]',1,'AE1603',30.99,'aliexpress','1007042794 ','raffitahmizian@yahoo.com','Raffi Tahmizian','11635 apt 6 rue lavigne ','Montreal','Quebec','CANADA','H4J1X4','+1 514 6991141',NULL,NULL,NULL,'2012-02-29 03:24:48',0,NULL,3,1,3,1,'RA184525144CN\r ',NULL),(24962,849641041002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',4,'AE3104',38.72,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 04:04:45',0,NULL,3,1,3,1,'RA184525524CN ','hermeshine'),(25036,8881330573648617,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail [AKT056]',1,'AKT056',50,'aliexpress','1007063285','msatelevision@yahoo.fr','noyelle yann','9bis rue de st remy','jouy','france','FRANCE','28300','0659898802',NULL,NULL,NULL,'2012-03-01 03:47:28',0,NULL,3,1,3,1,'RA184523735CN ','速卖通 '),(24963,849653078002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','videoaleks12','videoaleks@rambler.ru','Aleksey Tumakin','Deputatskaya 5-5','Volgograd','Volgograd','RUSSIAN FEDERATION','400123','+7-905-397-98-10','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-29 04:54:43',0,NULL,3,1,3,1,'RA184525515CN ','hermeshine\r澳转欧标'),(24964,811559954018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',2,'AKT007',36,'photographyacc','slashxor24','mattbairdsteele@gmail.com','Matt Baird','6 Minnamurra Rd','Gorokan','New South Wales','AUSTRALIA','2263','0413413226','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 05:01:55',0,NULL,3,1,17,0,'RA184525609CN ','photographyacc'),(24965,872207054017,270748169404,'New Lamp Bulb Holder E27 Socket Light Umbrella Bracket',4,'AE1302',39.2,'photographyacc','slashxor24','mattbairdsteele@gmail.com','Matt Baird','6 Minnamurra Rd','Gorokan','New South Wales','AUSTRALIA','2263','0413413226','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 05:01:56',0,NULL,3,1,3,1,'RA184525609CN ','photographyacc\r45w 5500k 灯泡 220v   2\r单灯头   4\r澳标'),(24966,805055899001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','threadbarely','aceo_by_deb@live.com.au','Deborah Bostock','302 Torquay Terrace<br>Torquay','Hervey Bay','Queensland','AUSTRALIA','4655','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 05:09:08',0,NULL,3,1,11,1,'、 ','hermeshine'),(24967,8881330496585890,111,'x2 115W 220V 5500K Studio Light Bulb Daylight with E27 Socket [AKT049]',1,'AKT049',30.99,'aliexpress','1007058827','sertes@mail.ru','Sergey Teslya','Beskudnikovsky bulvar, d. 22, kv. 272','Moscow','Moscow','RUSSIAN FEDERATION','127474','+7 910 4848316',NULL,NULL,NULL,'2012-02-29 06:23:05',0,NULL,3,1,3,1,'RA184523599CN ',NULL),(24968,8881330496695625,111,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket - Wholesale/ Retail [AE1301]',1,'AE1301',18.99,'aliexpress','1007058826','sertes@mail.ru','Sergey Teslya','Beskudnikovsky bulvar, d. 22, kv. 272','Moscow','Moscow','RUSSIAN FEDERATION','127474','+7 910 4848316',NULL,NULL,NULL,'2012-02-29 06:24:55',0,NULL,8,1,17,0,NULL,NULL),(24969,8881330496752664,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail [AKT052]',1,'AKT052',42.99,'aliexpress','1007058825 ','sertes@mail.ru','Sergey Teslya','Beskudnikovsky bulvar, d. 22, kv. 272','Moscow','Moscow','RUSSIAN FEDERATION','127474','+7 910 4848316',NULL,NULL,NULL,'2012-02-29 06:25:52',0,NULL,3,1,3,1,'RA184523608CN ','115w 5500k 灯泡  220v  2 \r双灯头   1\r灯架  2m  1\r闪光灯云台(配合灯架）  1\r柔光伞  1\r欧标\r速卖通\r灯泡单发'),(24970,849673169002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','8668825','gboven72@cableone.net','Penny Boven','5858 Boven Ln','Boise','ID','UNITED STATES','83716-8808','(208) 331-1140','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-29 06:39:18',0,NULL,3,1,1,1,'LK212735455CN ','hermeshine'),(24971,805080970001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','doka27','ziniukas22@gmail.com','Donatas Kairys','Justiniskiu 115-37','Vilnius','','LITHUANIA','05245','865292119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 07:24:47',0,NULL,3,0,11,1,'、 ','hermeshine'),(24972,8881330503812689,111,'灯架底座',1,'',0,'hutongstore','matiaspeterpan','matilike@hotmail.com','matias diaz','ctra hardu nº3 p 2 1ºd urb nuevo real','melila','Andalucía Ceuta y Melilla','SPAIN','52006','647660958',NULL,NULL,NULL,'2012-02-29 08:23:32',0,NULL,3,0,3,1,'RA184525334CN ',NULL),(24973,8881330504870499,111,'斜臂的夹子  单轮',1,'',0,'hermeshine','monokia79','monokia@gmail.com','Mónika Sáfár, Attila Monoki','2. street Kelemen László<br>building 4.  2./11.','Budapest','Budapest','HUNGARY','1026','+36304006392',NULL,NULL,NULL,'2012-02-29 08:41:10',0,NULL,3,0,3,1,'RA184507857CN',NULL),(24974,8881330506175369,111,'伞式柔光箱 80cm 8角   柔光布',1,'',0,'hermeshine','deymosd','gordan.gledec@fer.hr','Gordan Gledec','Vladimira Ruzdjaka 9','Zagreb','Croatia','CROATIA','HR10000','+385992513689',NULL,NULL,NULL,'2012-02-29 09:02:55',0,NULL,3,0,3,1,'RA184525351CN ',NULL),(24975,956391781015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','coneil1979','christopheroneil@hotmail.co.uk','Christopher O\'Neil','Number 1 Waterfront Ave','Edinburgh','MLT','UNITED KINGDOM','EH5 1SG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 09:10:00',0,NULL,3,0,3,1,'RA184525277CN ','hutongstore\r3XL 已入库'),(24976,8881330509081188,111,'摄影背心 黑色厚 sony 3XL',1,'',0,'hermeshine','marxvideo','marxvideo@aol.com','Russell S. Kern','729 Crown Ridge Dr','Colorado Springs','CO','UNITED STATES','80904','',NULL,NULL,NULL,'2012-02-29 09:51:21',0,NULL,3,0,3,1,'RA184525100CN\r ','3XL 已入库 '),(24977,936549772016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',2,'AD1182',92,'hutongstore','cyclingplanetearth','nirroj@gmail.com','Jorrin Peereboom','13 Cooper Works<br>19-23 Sternhall Lane','London','London','UNITED KINGDOM','SE15 4NQ','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-02-29 10:01:54',0,NULL,3,1,4,1,'YW867611221CN\r ','hutongstore'),(24978,872290135017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',3,'AD1168',45,'photographyacc','bdaf6887','bdafonseca@otop-interactive.com','Bruno Da Fonseca','Otop Interactive<br>15 place Henri Neveu','Colombes','Île-de-France','FRANCE','92700','06.70.71.56.39','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-02-29 10:39:14',0,NULL,3,1,11,1,'\\ ','photographyacc'),(24979,849739636002,120813021178,'New 24\"x35\"/60x90cm Softbox Universal Mount Metal for strobe 2  layer diffuser',1,'AD1140',39.9,'hermeshine','sidney2001andy','patystefas@yahoo.com.au','vu truong','41 cambridge ave','bankstown','New South Wales','AUSTRALIA','2200','020412210158','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-29 11:21:04',0,NULL,3,1,3,1,'RA184525113CN\r ','hermeshine'),(24980,805143536001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','ilf105998','ilanfain1@gmail.com','Ilan Fain','Nativ Hen str.<br>35/32','Haifa','','ISRAEL','32688','97248235155','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-29 11:44:45',0,NULL,3,1,3,1,'RA184525127CN\r ','hermeshine\r分开发  \rRA184525095CN\r'),(24981,805068882001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',150.57,'hermeshine','djmatzek','djmatzek@t-online.de','Matthias Kahrs','Huxfelder Damm 7','Grasberg','','GERMANY','28879','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 12:06:33',0,NULL,3,1,3,1,'RA184523846CN\r ','hermeshine\rc里面的接口环换成62cm的\r除了c里面的再发\r72cm接口环    1\rcanon老款背心3xl    1\r广角托架     1\r天涯方形滤镜CPL   1\r永诺 MC-C1      1\r已入库'),(24982,805147946001,110451012922,'Adjustable Padded Camera Neck shoulder Strap for Canon',1,'AB1404',5.9,'hermeshine','sprut81','pashaspage1@mail.ru','Pavel Vlasov','per. Stroiteley, 22','Tiraspol','','MOLDOVA, REPUBLIC OF','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 12:06:38',0,NULL,3,1,17,0,'RA184525201CN\r ','hermeshine'),(24983,849750024002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',2,'AB2301',16.4,'hermeshine','sprut81','pashaspage1@mail.ru','Pavel Vlasov','per. Stroiteley, 22','Tiraspol','','MOLDOVA, REPUBLIC OF','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 12:06:39',0,NULL,3,1,17,0,'RA184525201CN\r ','hermeshine'),(24984,849750402002,120601700681,'Rain Cover Dust Protector 4 Canon 500D 1000D 7D 5D 50D',1,'AA3101',16.99,'hermeshine','sprut81','pashaspage1@mail.ru','Pavel Vlasov','per. Stroiteley, 22','Tiraspol','','MOLDOVA, REPUBLIC OF','3300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 12:06:39',0,NULL,3,1,3,1,'RA184525201CN\r ','hermeshine\r肩带 canon    1\r闪光灯B座     2\r防雨罩    1'),(24985,936594781016,260894475632,'43\" Dual double layer reflective and translucent soft  umbrella 110cm',1,'AD1157',18,'hutongstore','giotis_ant','giotis_ant@msn.com','Panagiotis  Antoniadis','Karpathou 6','Drama','Drama','GREECE','66100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 12:09:16',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24986,956464091015,250627959211,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',1,'AC2302',4.2,'hutongstore','mergle77','edith.rogers@ntlworld.com','edith england-elbro','40 Mafeking Road','Cardiff','Cardiff','UNITED KINGDOM','CF235DQ','029220213280','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 12:33:13',0,NULL,3,1,11,1,'\\ ','hutongstore'),(24987,849763034002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','chiefnars74','w.vivas@yahoo.com.au','Wendelle Vivas','44 KILGARIFF CRESCENT<br>SADADEEN','Alice Springs','Northern Territory','AUSTRALIA','0870','0889522927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 12:50:36',0,NULL,3,1,4,1,'YW867611243CN\r ','hermeshine\r2单反  1澳标\r2B柔  1'),(24988,849769079002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','andyfx883','iter103@hotmail.com','Andrew Lam','11 Ewart Street<br>Paddington','Brisbane','Queensland','AUSTRALIA','4064','61421452363','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 13:00:29',0,NULL,3,1,11,1,NULL,'hermeshine'),(24989,956490386015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',12.1,'hutongstore','mavdbtva','t_vanaubel@hotmail.com','Thierry VAN AUBEL','avenue J.S. Bach 18 bte 15','BRUXELLES','','BELGIUM','B-1083','475248903','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 13:35:09',0,NULL,3,1,11,1,' \\','hutongstore'),(24990,849769789002,120758263555,'Camera protector case bag f Nikon D40 D60 D3000 D3100 S',1,'AD1171',7.99,'hermeshine','fcespedes2011','fcespedes@geocom.cl','Felipe Cespedes','Julio Prado 1590 Departamento 1102<br>Providencia','Santiago','Region Metropolitana','CHILE','7501469','024803634','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 13:02:45',0,NULL,3,1,11,1,NULL,'hermeshine'),(24991,849802473002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','peterthim','peter.thim@devnet.fi','Peter Thim','Niemenkatu 77','Lahti','Etela-Suomi','FINLAND','15240',' 358408411216','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 14:39:42',0,NULL,3,1,4,1,'YW867611254CN\r ','hermeshine\r除了c里面的再发\r肥皂盒 柔光罩  430EX    4'),(24992,805199926001,110502941736,'NEW Flash Diffuser for Canon 430EX / 430EXII',4,'AB3331',10.4,'hermeshine','peterthim','peter.thim@devnet.fi','Peter Thim','Niemenkatu 77','Lahti','Etela-Suomi','FINLAND','15240',' 358408411216','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 14:39:43',0,NULL,3,1,17,1,'YW867611254CN\r ','hermeshine'),(24993,956525878015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','el1ude','eyesonly@gmail.com','Cliff Donaldson','21 Cromwells Highway','Lisburn','Down','UNITED KINGDOM','BT27 5DH','07759253331','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 14:54:32',0,NULL,3,1,3,1,'RA184525158CN\r ','hutongstore'),(24994,805207776001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 15:02:37',0,NULL,5,0,18,0,NULL,'hermeshine\r需要加$9运费\r先别包\r已发信'),(24995,956548937015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','oinkely','oinkely11@gmail.com','Eoin Kelly','35 The Bentley','Kilcoole','Co Wicklow','IRELAND','default','0879893904','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 15:42:41',0,NULL,3,1,3,1,'RA184525192CN\r ','hutongstore'),(24996,849830315002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','andyisdead','andyisdead.81@gmail.com','Andrea Cosentino','Cà Marco','Lopagno','','SWITZERLAND','6956','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 15:58:33',0,NULL,3,1,3,1,'RA184525189CN\r ','hermeshine'),(24997,956556847015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','thomaslafar','juliengrano@googlemail.com','Mr Alban Giannelli','1 rue du temps','Istres','Provence-Alpes-Côte d\'Azur','FRANCE','13800','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 15:59:57',0,NULL,3,1,3,1,'RA184525175CN\r ','hutongstore'),(24998,956554629015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','r.whiteley12012','r.whiteley1@ntlworld.com','Ronald Whiteley','26, Troutbeck Close','Runcorn','Cheshire','UNITED KINGDOM','WA7 3JG','441928772799','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 16:01:02',0,NULL,3,0,3,1,'RA184525161CN\r ','hutongstore\rXL 已入库'),(24999,805239095001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','zordak33','karl@zordak.fr','FRANCE TELECOM -> Karl COSSE','23 rue Thomas Edison','PESSAC','Aquitaine','FRANCE','33608','0633598852','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-02-29 16:25:59',0,NULL,3,1,4,1,'YW867611265CN\r ','hermeshine'),(25000,936709520016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','combu81','cjscerri@hotmail.com','Clint Scerri Harkins','4, Daisy Court<br>Guze Ellul Street','G\'Mangia','','MALTA','','+35627016942','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 16:31:04',0,NULL,3,1,3,1,'RA184525250CN\r ','hutongstore'),(25001,805277975001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','filiplucin','filip@filiplucin.com','Filip Lucin','Dr. I. Novaka 20/1','Cakovec','Medjimurje','CROATIA','40000','0913902166','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 17:53:31',0,NULL,3,1,17,0,NULL,'hermeshine'),(25002,849882904002,120626873273,'New wide angle holder for Cokin P series filter',2,'AA2216',7.98,'hermeshine','filiplucin','filip@filiplucin.com','Filip Lucin','Dr. I. Novaka 20/1','Cakovec','Medjimurje','CROATIA','40000','0913902166','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 17:53:31',0,NULL,3,1,11,1,'\\ ','hermeshine\r方形滤镜接口环 52mm    1\r方镜广角托架（ 一槽）  2'),(25003,936773651016,260901272225,'New Camera protector case Neoprene bag for Nikon D200 D300s D700 XL',1,'AD1174',7.8,'hutongstore','instantkarmagreen','smirnov@live.co.uk','Denis Smirnov','2 Anita Croft','Birmingham','West Midlands','UNITED KINGDOM','B23 7NU','07708220706','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 18:17:58',0,NULL,3,1,11,1,NULL,'hutongstore'),(25004,849873270002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:20:30',0,NULL,3,1,17,0,'RA184525246CN\r ','hermeshine'),(25005,805271320001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:20:29',0,NULL,3,1,17,0,'RA184525246CN\r ','hermeshine'),(25006,849900022002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','amamedov75','veg_ua@yahoo.com','Azer Mamedov','31 Shelbourne Dr','Woodbridge','ON','CANADA','L4H 0K6','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:26:57',0,NULL,3,1,11,1,NULL,'hermeshine'),(25007,849900255002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','zgaxhwhgwia','igor.fil@softrating.com.ua','igor fil','Geroyev Stalingrada 24a, 73','Kiev','','UKRAINE','04210','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:35:14',0,NULL,3,1,11,1,NULL,'hermeshine'),(25008,805271104001,110524443704,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',30.99,'hermeshine','jordano-jordano2000','jordano2000@mail.ru','Leonid Anfimov','ul. Velizhskaya d.10 kv.101','Ivanovo','','RUSSIAN FEDERATION','153022','+7-910-994-10-80','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 18:20:29',0,NULL,3,1,3,1,'RA184525246CN\r ','hermeshine\r圆形柔光棚 50cm   1\r圆形柔光棚 40cm    1\r圆形柔光棚 60cm    1'),(25009,804236318001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',1,'AA1314',2.99,'hermeshine','drummerbabe505','kneadwork@gmail.com','Jennifer Gignac','130 Lake Spring Loop','Mooresville','NC','UNITED STATES','28117-3500','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-29 20:11:26',0,NULL,3,1,1,1,'LK213301628CN\r ','hermeshine'),(25010,956733707015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',1.6,'hutongstore','eyne2004','eyne2004@yahoo.ie','michael nolan','eyne','portlaoise','Laois','IRELAND','default','0868518577','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-02-29 20:27:04',0,NULL,3,1,11,1,NULL,'hutongstore'),(25011,956744155015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',6.9,'hutongstore','william10terry','t_bewsey@sky.com','terry bewsey','36 lee way<br>glashougton','castleford','West Yorkshire','UNITED KINGDOM','wf10 4tq','01977513405','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-02-29 20:40:33',0,NULL,3,1,11,1,NULL,'hutongstore\r英标'),(25012,849985673002,120343552392,'67mm 67 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1305',3.79,'hermeshine','tanyakenapa','prima.studio@gmail.com','Susanto Gunawan','Toko SINAR INDAH<br>Jl. Muslimin Ismail No. 9','Singkawang','Kalimantan Barat','INDONESIA','79111','6285245350009','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:54:03',0,NULL,3,1,17,0,'RA184523727CN ','hermeshine'),(25013,805379227001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','tanyakenapa','prima.studio@gmail.com','Susanto Gunawan','Toko SINAR INDAH<br>Jl. Muslimin Ismail No. 9','Singkawang','Kalimantan Barat','INDONESIA','79111','6285245350009','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:54:04',0,NULL,3,1,17,0,'RA184523727CN ','hermeshine'),(25014,849985674002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','tanyakenapa','prima.studio@gmail.com','Susanto Gunawan','Toko SINAR INDAH<br>Jl. Muslimin Ismail No. 9','Singkawang','Kalimantan Barat','INDONESIA','79111','6285245350009','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 20:54:04',0,NULL,3,1,3,1,'RA184523727CN ','hermeshine\r橡胶遮光罩 52mm  2\r橡胶遮光罩 67mm   2\r橡胶遮光罩 58mm   3\r橡胶遮光罩 77mm    3\r已付其他橡胶罩钱\r'),(25015,805379071001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','jzyjohn1','jzhaoyu@yahoo.com','Zhaoyu Jiao','1056 E Elm St','Tucson','AZ','UNITED STATES','85719-4109','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-02-29 21:03:43',0,NULL,3,1,1,1,'LK213339345CN\r ','hermeshine'),(25016,849995948002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','paswordiztok','iztok_rant@t-2.net','Iztok Rant','Zariška ulica 6','Kranj','','SLOVENIA','4000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 21:13:04',0,NULL,3,0,3,1,'RA184525011CN\r ','hermeshine\r1.6*3  黑色'),(25017,632180801004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','macroar','arman.abovian@gmail.com','Ruben Gazaryan','709 N Dorset Ave<br>Apt C10','Ventnor city','NJ','UNITED STATES','08406-1369','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-02-29 21:41:31',0,NULL,3,1,1,1,'LK213264545CN\r ','hermeshine'),(25018,805422232001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','july.sun777','suomalainen10@gmail.com','Julia Hannikainen','Pihkalankatu 7 a 4','Turku','','FINLAND','20610','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 22:20:20',0,NULL,3,1,4,1,'YW867611276CN\r ','hermeshine\r欧标'),(25019,872633100017,270751947565,'Camera Remote Shutter Release Cord RS-C1 Canon 550D 60D',1,'AA3210',3.99,'photographyacc','cz8015','gungartan@tpg.com.au','Bruce Wingrove','27 Macken St','OATLEY','New South Wales','AUSTRALIA','2223','0295805316','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 22:41:57',0,NULL,3,1,11,1,NULL,'photographyacc'),(25020,872640396017,270819643515,'New 100% Authentic / Official Nikon Baseball Cap Hat D3s D700 D90 D80 ',1,'AD1190',16,'photographyacc','jly288','jmly@optusnet.com.au','John Ly','20 Dunscombe Ave<br>Glen Waverley','Melbourne','Victoria','AUSTRALIA','3150','0392586111','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-02-29 22:59:10',0,NULL,3,1,11,1,NULL,'photographyacc'),(25021,805449305001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','rosie_n_aaron','ll_amaya_ll6@bigpond.com','Rosemary Anderson','2/58 Wigg St','Wodonga','Victoria','AUSTRALIA','3690','0260561630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 23:30:59',0,NULL,3,1,17,0,NULL,'hermeshine'),(25022,850056386002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','rosie_n_aaron','ll_amaya_ll6@bigpond.com','Rosemary Anderson','2/58 Wigg St','Wodonga','Victoria','AUSTRALIA','3690','0260561630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 23:31:00',0,NULL,3,1,17,0,NULL,'hermeshine'),(25023,632214670004,140679559505,'Promotion ! NEW Square Gradual Graduated Brown Color Filter for Cokin P Series',1,'AD1227',3.5,'hermeshine','rosie_n_aaron','ll_amaya_ll6@bigpond.com','Rosemary Anderson','2/58 Wigg St','Wodonga','Victoria','AUSTRALIA','3690','0260561630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 23:30:58',0,NULL,3,1,11,1,NULL,'hermeshine\r6片装的滤镜袋  1\r无牌方镜 渐变蓝    1\r无牌方镜 渐变棕    1'),(25024,805456700001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','samemory','linhrom@gmail.com','Hai Linh Truong','17-19 Collins St (crn William st)','Alexandria, Sydney','New South Wales','AUSTRALIA','2015','0410944945','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-02-29 23:53:20',0,NULL,3,1,3,1,'RA184525232CN\r ','hermeshine'),(25025,850100730002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','acayoung01','acayoung@iinet.net.au','Alex Young','63 Dickson Pl','Warriewood','New South Wales','AUSTRALIA','2102','0411267433','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 01:47:36',0,NULL,3,0,3,1,'RA184525025CN\r ','hermeshine\r1.6*3灰色背景布   1'),(25026,850101962002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',1,'AA1303',2.6,'hermeshine','gregsull101','gregsull53@yahoo.com','gregory o sullivan','1325 Monad Ter','US','FL','UNITED STATES','33139-3719','(714) 916-3959','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 01:51:53',0,NULL,3,1,1,1,'LK213284964CN\r ','hermeshine'),(25027,956908449015,250692239361,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',58,'hutongstore','a_pneia','xingoffdays@gmail.com','Vanessa Prates','Rª do Moinho, Lt 598<br>Bº da Fraternidade, S. João da Talha','Lisboa','PA','PORTUGAL','2695-602','919121900','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 02:17:30',0,NULL,3,1,4,1,'YW867611232CN\r ','hutongstore\r欧标'),(25028,805502532001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','jelf6012','jamalelfirikh@hotmail.com','jamal elfirikh','35 valonia drive<br>house 35  valonia drive','brampton','ON','CANADA','L6V4J2','(416) 809-3174','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-01 02:32:57',0,NULL,3,0,3,1,'RA184525229CN\r ','hermeshine\r2XL 已入库'),(25029,8881330569205403,111,'Neoprene Protector Camera Cover Case for Canon Nikon L',1,'AC1302',7.5,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','',NULL,NULL,NULL,'2012-03-01 02:33:25',0,NULL,3,1,17,0,NULL,NULL),(25030,8881330569312825,111,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','solsuny','solsuny@gmail.com','Soledad Ruiz y Blanco','Monroe 4050 1º B','Ciudad de Buenos Aires','Ciudad de Buenos Aires','ARGENTINA','1430','',NULL,NULL,NULL,'2012-03-01 02:35:12',0,NULL,3,1,11,1,NULL,'大号内胆包 无字  1 \r中号内胆包 无字  1\r系统漏单，有邮件'),(25031,8881330569501884,111,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',3.34,'hermeshine','oketanioketani ','t_oketani@msn.com','Takahiro Oketani','Kitasuna 2-11-9 305','Koto-ku','Tokyo-to','JAPAN','136-0073','',NULL,NULL,NULL,'2012-03-01 02:38:21',0,NULL,3,1,11,1,NULL,'系统漏单，有邮件 '),(25032,8881330569670921,111,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','coolheure1','aitzgorri@gmail.com','Diego Pobes','C/ Clara Campoamor 10 7º a','Vitoria-gasteiz','País Vasco','SPAIN','01015','',NULL,NULL,NULL,'2012-03-01 02:41:10',0,NULL,3,1,3,1,'RA184525215CN\r ','系统漏单，有邮件 '),(25033,8881330569769786,111,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','mininuno ','alexfloresphotographe@gmail.com','Alexandro Flores','77 grand rue','Strasbourg','Alsace ','FRANCE','67000 ','',NULL,NULL,NULL,'2012-03-01 02:42:49',0,NULL,3,1,3,1,'RA184525303CN\r ','系统漏单，有邮件 '),(25034,936873319016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','trainingsoft','trainingsoft@aol.com','Mansour Akbari','Digital Print<br>219 Bow Road','London','Bow','UNITED KINGDOM','E3 2SJ','07934004000','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-01 02:52:21',0,NULL,3,1,3,1,'RA184525294CN\r ','hutongstore'),(25035,850121552002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','patana0722','patrick@europhotography.com.au','Patrick Georgiou','10 Cumberland Crest','Thomastown','Victoria','AUSTRALIA','3074','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 02:54:46',0,NULL,3,1,11,1,'\\ ','hermeshine'),(25037,8881330573757931,111,'Free shipping & Tracking # - New Portable 40cm 16\"x16\" Soft Box Softbox for Flash - Whole/Retail AB3327',1,'AB3327',39.99,'aliexpress','1007064020','dimbas@gmail.com','Dmitry Khodak','Rublevskoe sh.18-1-55','Moscow','RU','RUSSIAN FEDERATION','121615','+7 903 6179223',NULL,NULL,NULL,'2012-03-01 03:49:17',0,NULL,3,1,3,1,'RA184523744CN ','速卖通 '),(25038,8881330575211206,111,'摄影背心 Canon  老款 ',1,'',0,'hutongstore','bilalshah1','bilalshah1@aol.com','Bilal Shah','45 Tildsley Street','Bolton','Lancashire','UNITED KINGDOM','BL3 6PN','07833946045',NULL,NULL,NULL,'2012-03-01 04:13:31',0,NULL,3,0,3,1,'RA184504966CN\r ','M  已入库 \r'),(25039,8881330575839482,111,'45w 5500k 灯泡 220v',2,'',0,'hutongstore','invictus*2010','lorna.rodgers@flanagan-flooring.com','Jenna Jordan','Millpond Business Park<br>Belfast Road','Saintfield','Down','UNITED KINGDOM','BT24 7NL','02897510932',NULL,NULL,NULL,'2012-03-01 04:23:59',0,NULL,3,0,3,1,'RA184525285CN\r ','已入库 '),(25040,8881330577348466,111,'爵影红外 canon 电池',1,'',0,'hermeshine','iso9020','kaliko81@hotmail.com','Christian Lavoie','672<br>Chenier','Sherbrooke','QC','CANADA','J1N 2B2','(819) 820-7173',NULL,NULL,NULL,'2012-03-01 04:49:08',0,NULL,3,0,3,1,'RA184507830CN\r ',NULL),(25041,956959839015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','samemory','linhrom@gmail.com','Hai Linh Truong','17-19 Collins St (crn William st)','Alexandria, Sydney','New South Wales','AUSTRALIA','2015','0410944945','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 04:56:03',0,NULL,3,1,3,1,'RA184507843CN\r ','hutongstore'),(25042,850164676002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','rainedman2000','rainedman2000@yahoo.com','Willy Cao','15205 Lamella Ct','Chesterfield','MO','UNITED STATES','63017-2483','(314) 239-8440','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-01 06:02:22',0,NULL,3,1,1,1,'LK213417422CN\r ','hermeshine'),(25043,850167858002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',119.98,'hermeshine','psae3966','jarhead89x@gmail.com','Paul Saechao','7338 Hayward Dr','Sacramento','CA','UNITED STATES','95828-3810','','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-01 06:18:45',0,NULL,3,1,4,1,'YW867611291CN ','hermeshine\r澳转美标'),(25044,632299659004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','lansbricae','lansbricae@gmail.com','luis eduardo leclere rodriguez','C/ LONDRES, Nº 7 - PORTAL H - 1º A','SANTIAGO DE COMPOSTELA','Galicia','SPAIN','15707','657253030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 06:59:13',0,NULL,3,1,11,1,NULL,'hermeshine'),(25045,850175483002,120752153194,'Photo Studio Background Support Carrying Carry Bag',2,'AD1129',19.8,'hermeshine','thepraetorianone','thebobooo@gmail.com','Sergey Smolyaninov','pr. Svobodniy 28-12','Krasnoyarsk','','RUSSIAN FEDERATION','660018','+7(963)1919341','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 07:00:50',0,NULL,3,1,17,0,NULL,'hermeshine'),(25046,805562044001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','thepraetorianone','thebobooo@gmail.com','Sergey Smolyaninov','pr. Svobodniy 28-12','Krasnoyarsk','','RUSSIAN FEDERATION','660018','+7(963)1919341','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 07:00:54',0,NULL,3,1,11,1,'','hermeshine\r灯架包薄    2\r牛津布大包    1'),(25047,805566113001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','stagnant_vagrant','wongja+ebay@gmail.com','Jason Wong','#605 1053 10th St. SW','Calgary','AB','CANADA','T2R1S6','(403) 297-3040','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 07:24:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(25048,956997942015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','tanus69blue','ask4it2@yahoo.co.uk','Denise Mercer','Deltarail<br>Unit 3 Victoria Way Pride Park','Derby','Derbyshire','UNITED KINGDOM','DE24 8AN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-01 07:35:31',0,NULL,3,1,3,1,'RA184525087CN\r ','hutongstore'),(25049,805568905001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','alex_iepuras87','alex_iepuras@mail.ru','Palii Denis','str. Alba Iulia 184 ap.145','Chisinau','Rep of Moldova','MOLDOVA, REPUBLIC OF','MD-2071','068344418','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-01 07:39:07',0,NULL,3,1,5,1,'CP244439697CN ','hermeshine\r黑加白'),(25050,8881330589858047,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',2,'AB3329',97.98,'aliexpress','1007082944 ','cjcool@yandex.ru','Alexandr Kardakov','Halturina 33-55','Kemerovo','Kemerovskaya','RUSSIAN FEDERATION','650068','+7 905 9003884',NULL,NULL,NULL,'2012-03-01 08:17:38',0,NULL,3,1,5,1,'CP246990117CN\r ','速卖通 '),(25051,805580176001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',2,'AE1401',71.98,'hermeshine','xc6.tiger','yonex@ua.fm','ILYA GELFER','Plehanov street,16/44','DNEPROPETROVSK','','UKRAINE','49000','+380562340647','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-01 08:32:26',0,NULL,3,1,5,1,'CP244397064CN ','hermeshine'),(25052,937151115016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','mipentertainment','mipproduction@hotmail.com','IVANDRO PEREIRA','Flat 204, 87 Axe Street<br>Barking','Essex','Essex','UNITED KINGDOM','IG11 7FS','07901333684','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-01 08:41:30',0,NULL,3,1,12,1,'3126012293\r ','hutongstore\r英标\r泡重  9.6'),(25053,812156395018,280675565620,'Twin Lamp Bulb Holder E27 Socket Light Umbrella Bracket',1,'AE1301',15.8,'photographyacc','hungarianarchery','pp@hungarianarchery.com','Istvan Tomasovszki, Szalai Eva','Eksterberg 45.','Bruxelles','','BELGIUM','1932','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-01 10:34:18',0,NULL,3,1,11,1,NULL,'photographyacc\r欧标'),(25054,872831957017,270819648126,'New Profession​al Tripod Ball Head Camera Ballhead KS-0  + Quick Release Plate',1,'AD1186',32,'photographyacc','hungarianarchery','pp@hungarianarchery.com','Istvan Tomasovszki, Szalai Eva','Eksterberg 45.','Bruxelles','','BELGIUM','1932','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-01 10:41:23',0,NULL,3,1,17,0,'RA184528962CN\r ','photographyacc'),(25055,872835125017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','hungarianarchery','pp@hungarianarchery.com','Istvan Tomasovszki, Szalai Eva','Eksterberg 45.','Bruxelles','','BELGIUM','1932','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-01 10:52:44',0,NULL,3,1,3,1,'RA184528962CN\r ','photographyacc\rks-0 II （绿盒）  1\r柔光伞110cm   1'),(25056,850249012002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','vicentenoca','vicentemassaro@hotmail.com','Vicente de Paulo Massaro','Rua 3, 870','Orlândia','São Paulo','BRAZIL','14620-000','551638260665','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 12:17:04',0,NULL,3,1,3,1,'RA184523758CN ','hermeshine'),(25057,805635187001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','sintang','sintangman@yahoo.com','Andi Herwiandy','Komp. Vijaya Kusuma Blok B14 No.11<br>Cipadung, Cibiru','Bandung','Jawa Barat','INDONESIA','40614','+62818615478','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 12:20:56',0,NULL,3,1,11,1,NULL,'hermeshine\r+62818615478'),(25058,805650248001,110760260099,'11\" Articulating Magic Arm For LCD Monitor / LED light / DSLR Registered Airmail',1,'AD1195',29,'hermeshine','chamelet','fchamelet@gmail.com','Fernando Chamelet','Av. Sabiá, 699 apto 71','São Paulo','São Paulo','BRAZIL','04515001','55 11 76970882','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 13:08:20',0,NULL,3,1,3,1,'RA184523673CN ','hermeshine'),(25059,805654886001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','dararada','sashacammedia@gmail.com','Aleksandr Muravyev','Lysogorskaya 9','Tambov','','RUSSIAN FEDERATION','392018','89106537837','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 13:24:37',0,NULL,3,1,3,1,'RA184523687CN ','hermeshine'),(25060,805690891001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','zykarussian','df_lsd@mail.ru','Dmitry Romantsov','ul. Kooperativnaya 28','s. Petrovskoye','Tambovskaya oblast','RUSSIAN FEDERATION','393070','+74754423122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 15:13:08',0,NULL,3,1,11,1,NULL,'hermeshine'),(25061,957176432015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','stefane7606','stephane_rouen@hotmail.com','Derambure Stefane','10 rue de Guyenne','Saint Etienne du Rouvray','Haute-Normandie','FRANCE','76800','06.82.76.80.33','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 15:53:04',0,NULL,3,1,3,1,'RA184523700CN ','hutongstore'),(25062,804791402001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',195,'hermeshine','tanb0017','philips170t@yahoo.com','BENG KEAT TAN','BLK 414 PANDAN GARDEN<br>#06-144','SINGAPORE','SINGAPORE','SINGAPORE','600414','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 16:20:48',0,NULL,3,1,9,1,'10423112030200001 ','hermeshine\r英标'),(25063,937355167016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','razoreye76','razor@getmail.no','Tom Andre Haug','Ravnkollbakken 81','oslo','','NORWAY','0971','+4747810318','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 17:22:54',0,NULL,3,1,11,1,NULL,'hutongstore'),(25064,805761223001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','luchochm','luischm@gmail.com','Luis Chigne','Jr. Manuel Segura 720 - Lince','Lima','Lima','PERU','LIMA 14','+51992728758','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-01 18:07:16',0,NULL,3,1,5,1,'CP244439710CN\r ','hermeshine\r黑加白'),(25065,850400444002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','romanklykov','roman.klykov@gmail.com','Roman Klykov','per. Stolyarnyi 13','Miass','Chelyabynskaya','RUSSIAN FEDERATION','456303','9630783126','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 18:47:30',0,NULL,3,1,3,1,'RA184523639CN ','hermeshine'),(25066,805795905001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','williamskjelmose','mirefugio@ya.com','William Skjelmose','C / Del Drago 12','Alicante','Comunidad Valenciana','SPAIN','03699','965668732','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 19:14:08',0,NULL,3,1,3,1,'RA184523642CN ','hermeshine'),(25067,957337305015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','mrcloneme','hellan22@hotmail.com','Helena Antonsson','Norströmsväg 13','Stockholm','Trångsund','SWEDEN','14260','+46707663677','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-01 20:09:45',0,NULL,3,1,3,1,'RA184523656CN ','hutongstore'),(25068,805839406001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',2,'AE2201',75.96,'hermeshine','countryboyrecords','countryboyrecords@yahoo.com','Carlos Orr','1 Miller Pond Rd<br>Rice Creek Subdivision Hwy 21','Port Wentworth','GA','UNITED STATES','31407-6044','(912) 660-6244','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-01 20:29:12',0,NULL,3,1,4,1,'YW867611324CN\r ','hermeshine\r美标'),(25069,873124257017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','cbenci','christianbenci@gmail.com','Christian Benci','97 Rennie Street','Lara','Victoria','AUSTRALIA','3212','0352828549','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-01 21:29:09',0,NULL,3,1,3,1,'RA184523660CN ','photographyacc'),(25070,805875410001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','artbabelon','babelonartbabelon@gmail.com','Albert Babelyan','Sundukyan str. 17/43','Yerevan','','ARMENIA','0012','37410263664','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 21:37:35',0,NULL,3,1,11,1,NULL,'hermeshine'),(25071,632529299004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','karinolen2010','karinolen@hotmail.com','karin molok','Tehase tee 3-6','Raasiku','Harjumaa','ESTONIA','75203','37258509409','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 21:38:21',0,NULL,3,1,11,1,NULL,'hermeshine'),(25072,805897560001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','weddingfilms','joel@weddingfilms.com','Joel R. Peregrine','4932 N Newhall St','Whitefish Bay','WI','UNITED STATES','53217-6048','(414) 964-9414','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-01 22:25:03',0,NULL,3,1,1,1,'LK213841305CN ','hermeshine'),(25073,805921502001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','csarpasan','cemsarpasan@yahoo.com','Arzu Denli Sarpasan','Tatlisu Mahallesi. Tezcan cad.<br>Polat Hill Town Sitesi 1 NO:44 B Blok D:1 serifali umraniye','istanbul','TURKEY, TR','TURKEY','34774','902163610764','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 23:31:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(25074,865431106017,270759686194,'1000W Photo Studio Soft Box Continuous Lighting  Kit ',1,'AKT017',120,'photographyacc','lisem44','lise.m.cooney@gmail.com','Elise Cooney','26 Castleton Rd','Herne Hill','Victoria','AUSTRALIA','3218','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-01 23:39:26',0,NULL,3,0,4,1,'YW867610930CN  ','photographyacc'),(25075,850549067002,120762404074,'600w Photography Lighting Kit 45w bulbs 110cm umbrella',1,'AKT078',90,'hermeshine','melissamajesty9','melissamajesty@hotmail.com','Melissa Stojanovska','16 Raydon Crt<br>Deer Park','Melbourne','Victoria','AUSTRALIA','3023','0392660913','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-01 23:50:54',0,NULL,3,1,4,1,'YW867611313CN\r ','hermeshine\r澳标'),(25076,956187454015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','paularoris','panakita@msn.com','ana paula roris dominguez','calle manuel rodriguez 69 1a','porriño','Galicia','SPAIN','36400','653994000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 00:20:38',0,NULL,3,1,3,1,'RA184523568CN ','hutongstore'),(25077,850561634002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','khananan','khananan_ph@hotmail.com','Khananan Phongphanit','6/53<br>Forsyth street','Kingsford','New South Wales','AUSTRALIA','2032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 00:31:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(25078,812511918018,280739900925,'New Quality Heavy Universal wheel Light Stand Grip Clamp Boom ',1,'AD1180',14.9,'photographyacc','kronosgalicia','kronosvega@hotmail.com','Beatriz Irigoyen Pampin','C/Real 195 Bajo Cosquillas','Ferrol - A coruña','Galicia','SPAIN','15402','652408632','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 00:31:49',0,NULL,3,1,11,1,NULL,'photographyacc'),(25079,805939614001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','raysebas','raynikon@gmail.com','RAIMUNDO SEBASTIAN HIDALGO','C/. Pablo Neruda, 13, 6º- B','ZARAGOZA','Aragón','SPAIN','50018','669425036','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 00:39:19',0,NULL,3,1,11,1,NULL,'hermeshine'),(25080,937618748016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','paradoxodarap','roadmaniacs@hotmail.com','Sami Feili','Lekstraat 25','Arnhem','','NETHERLANDS','6826 AG','026 3884771','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 00:55:22',0,NULL,3,1,11,1,NULL,'hutongstore'),(25081,632582744004,140649026335,'New 100% Cotton Photo photographya Vest for Sony Nikon Canon color: kaqi',1,'AA2123',32,'hermeshine','zee03nt','zeeimages@gmail.com','Barry Zee','Idsworth House','Waterlooville','Hampshire','UNITED KINGDOM','PO8 0AW','02392412224','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 01:01:50',0,NULL,3,0,3,1,'RA184523571CN ','hermeshine\r2XL  已入库'),(25082,873221717017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','3805sue','robertson.ps@bigpond.com','Sue Robertson','65A Georges River Cres<br>Oyster Bay','Sydney','New South Wales','AUSTRALIA','2225','0295894753','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 01:37:20',0,NULL,3,1,3,1,'RA184523585CN ','photographyacc'),(25083,8881330654348916,111,'Black/Whilte Reflection board 20X30cm Reflection effect - Wholesale/ Retail [AB1201]',1,'AB1201',15.99,'aliexpress','1007099974 ','chrigu_1988@hotmail.com','Christoph Mueller','Alpenblickstrasse 37','Zollikofen','Schweiz','SWITZERLAND','3052','+0041 079 7260285',NULL,NULL,NULL,'2012-03-02 02:12:28',0,NULL,3,1,3,1,'RA184523829CN\r ','速卖通 '),(25084,811571948018,280683865341,'New Lambency Flash Diffuser for Canon 420EX 430EX P2',1,'AB3308',18,'photographyacc','king_kong_shopper','paul_vasquez23@yahoo.com','paul vasquez','2/11 curzon st','ryde','New South Wales','AUSTRALIA','2112','0413037776','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 02:37:47',0,NULL,3,1,3,1,'RA184523611CN ','photographyacc'),(25085,850599937002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 02:41:57',0,NULL,5,0,18,0,NULL,'hermeshine\r需要加$8运费\r发信了'),(25086,850601941002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 02:47:30',0,NULL,3,1,3,1,'RA184523625CN ','hermeshine'),(25087,805611038001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','77madeline','wayneandmargi@yahoo.com.au','Margaret OConnor','PO Box 5034','Cobargo','New South Wales','AUSTRALIA','2550','0427030131','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 03:00:48',0,NULL,3,1,11,1,NULL,'hermeshine'),(25088,805992314001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','sidvic27','sidnei27@gmail.com','SIDNEI VICENTE','QN 1, Conjunto 18, casa 6 - Riacho Fundo 1','Brasília','Distrito Federal','BRAZIL','71805118','55 61 33996557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 03:37:06',0,NULL,8,1,17,0,'RA184519705CN  ','hermeshine'),(25089,850616641002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','sidvic27','sidnei27@gmail.com','SIDNEI VICENTE','QN 1, Conjunto 18, casa 6 - Riacho Fundo 1','Brasília','Distrito Federal','BRAZIL','71805118','55 61 33996557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 03:37:07',0,NULL,3,1,3,1,'RA184519705CN ','hermeshine\r大力夹云台  1\r斜臂   1\r加$8运费\r已付款\rRA184519705CN \r'),(25090,805993369001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',16.99,'hermeshine','shoppbrx','vendascomph@yahoo.com.br','wagner andrade','Dr. muricy 839  ap 154','curitiba','parana','BRAZIL','80020040','4185024177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 03:43:19',0,NULL,3,1,11,1,NULL,'hermeshine'),(25091,850619296002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','brokerpaket','abrorpay@gmail.com','Tira Arafa','Jalan Pulau Badas blok C13 No. 8<br>Komplek AL Jatimakmur, Pondok Gede','Bekasi','Jawa Barat','INDONESIA','17413','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 03:50:23',0,NULL,3,1,11,1,NULL,'hermeshine'),(25092,8881330663875355,111,'EW-73B',1,'AA3408',0,'hermeshine','2011akam','akamspog@yahoo.com','Akam Pertamawan','Jl. Melati Bintang no.1<br>Bukit Palem','Cilegon','Banten','INDONESIA','42434','+62818376666',NULL,NULL,NULL,'2012-03-02 04:51:15',0,NULL,3,1,3,1,'RA184523713CN ',NULL),(25093,806015612001,110533631327,'Padded Camera Neck shoulder Strap for Canon 550D 7D',1,'AB1404',5.49,'hermeshine','lxwall','lxwall97@aol.com','Alejandro Muro','150 Baywood Rd','El Paso','TX','UNITED STATES','79915-3626','(915) 309-8379','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-02 05:21:50',0,NULL,3,1,1,1,'LK214247296CN ','hermeshine'),(25094,8881330670861540,111,'1600W 套装',1,'AKT039',214,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-03-02 06:47:41',0,NULL,3,1,12,1,'3125979581 ','110V \r换成50-70 柔光箱\r泡重8.5 '),(25095,937727793016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','mar-ada','martin-adamec@post.cz','Martin Adamec','Babakova 2200','Praha 4','','CZECH REPUBLIC','14800','+420776623270','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 06:54:06',0,NULL,3,1,11,1,NULL,'hutongstore'),(25096,812617548018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','nazwun','razak.naz@gmail.com','Naeem Razak','13 Cable Close','Seville Grove','Western Australia','AUSTRALIA','6112','0893997162','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 07:33:19',0,NULL,3,1,3,1,'RA184523801CN ','photographyacc'),(25097,850667691002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','olegrakul','orakul99@gmail.com','Oleg Rakul','Kurkinskoe shosse, 22 - 181','Khimki','Moscow region','RUSSIAN FEDERATION','141407','+79154392676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 07:38:53',0,NULL,3,1,17,0,'RA184523792CN ','hermeshine'),(25098,806042148001,110531023268,'JJC Leather Hand Strap Grip HS-3A D80 D90 40D',1,'AB1410',11.99,'hermeshine','olegrakul','orakul99@gmail.com','Oleg Rakul','Kurkinskoe shosse, 22 - 181','Khimki','Moscow region','RUSSIAN FEDERATION','141407','+79154392676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 07:38:54',0,NULL,3,1,3,1,'RA184523792CN ','hermeshine\r闪光的柔光箱   40cm  1\rJJC 腕带  JJC-3A  1'),(25099,873326592017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.99,'photographyacc','jtrent123','jaytrent@live.com.au','Jay Trent','123 Old Bells Line of Rd','Kurrajong','New South Wales','AUSTRALIA','2758','0423041377','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-02 08:33:15',0,NULL,3,1,11,1,'BJ01713727\r ','photographyacc'),(25100,806054127001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','hpis40','hidegpista@gmail.com','Istvan Hideg','Fügefa utca 144.','Érd','','HUNGARY','2030','+36304837138','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:33:31',0,NULL,3,1,11,1,'BJ01713725\r ','hermeshine'),(25101,957628622015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 08:34:43',0,NULL,3,0,3,1,'RA184504997CN\r ','hutongstore\r摄影背心 Canon  老款  3XL 已入库'),(25102,8881330677348764,111,'58mm 58 Rubber 3in1 Collapsible Lens Hood Canon Nikon',1,'AB1303',3.34,'hermeshine','thaobruce','thao_b16@hotmail.com','Bruce Thao','2652 Monterey Street','Chico','CA ','UNITED STATES','95973','',NULL,NULL,NULL,'2012-03-02 08:35:48',0,NULL,3,0,1,1,'LK214378067CN\r ',NULL),(25103,806056054001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','lopos17','ricardo@serradolopo.com.br','Ricardo Rodrigues','Rua Tiradentes 296','Extrema','Minas Gerais','BRAZIL','37640 000',' 553534353357','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:43:28',0,NULL,3,0,3,1,'RA184505003CN\r ','hermeshine\r4节'),(25104,850683258002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',79.98,'hermeshine','allamdvd','ali.mahfoodh@yahoo.com','ALI AL-MAHFOODH','P.O.Box 9787','DAMMAM','','SAUDI ARABIA','31423','(966) 544-4886 ext.: 76','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 08:46:18',0,NULL,3,1,8,1,'CP244439745CN\r ','hermeshine'),(25105,850700260002,120601699780,'NeopreneCamera Cover Case for Canon Nikon Medium Size',1,'AC1301',6.24,'hermeshine','pelle4an','per-soder@telia.com','Per Söder','Bergsgatan 23<br>Bergsgatan 23','Emmaboda','Emmaboda','SWEDEN','S-36133','+46 70 28 29 890','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 09:59:36',0,NULL,3,1,17,1,'BJ01713724\r ','hermeshine'),(25106,806075699001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','pelle4an','per-soder@telia.com','Per Söder','Bergsgatan 23<br>Bergsgatan 23','Emmaboda','Emmaboda','SWEDEN','S-36133','+46 70 28 29 890','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 10:04:11',0,NULL,3,1,11,1,'BJ01713724\r ','hermeshine\r中号内胆包 无字  1\r小号内胆包 无字  1'),(25107,850704811002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','crocket2david','david2681@hotmail.fr','david daime','5 ramsay court','red cliffs','Victoria','AUSTRALIA','3496','0488406778','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 10:20:32',0,NULL,3,0,3,1,'RA184504952CN\r ','hermeshine'),(25108,850710257002,120621948143,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',37.15,'hermeshine','yunkaolesya','lesya@leusphoto.ru','Viktor Talankin','Novoe Devyatkino, d.55, kv.91<br>79522672611','der.Novoe Devyatkino','Leningradskaya','RUSSIAN FEDERATION','188661','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 10:37:14',0,NULL,3,1,3,1,'RA184504569CN\r ','hermeshine\r欧标'),(25109,850711910002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','alexshebanov2012','alexshebanov@yandex.ru','Alexandr Shebanov','Baraeva 12, 20','Astana','','KAZAKHSTAN','010000',' 87771073013','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 10:43:24',0,NULL,3,1,17,0,'RA184523832CN\r ','hermeshine'),(25110,850722225002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','vodibike','rsinapse@hotmail.com','RAPHAEL SOUZA DUARTE','RUA FREI CANECA 183<br>183 CURIANGO','CURVELO','MINAS GERAIS','BRAZIL','35790000','3197936561','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 11:22:19',0,NULL,3,1,3,1,'RA184597044CN','hermeshine\r重新发，换个单号'),(25111,937812462016,260675928373,'New Camera bag topload D3 for Canon 550D 500D',1,'AO0034',5.8,'hutongstore','tinatommo','tinatommo@aol.com','Tina Tomlinson','5 Saltburn Grove','GRIMSBY','Lincolnshire','UNITED KINGDOM','DN32 9TE','01472356587','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 11:33:15',0,NULL,3,1,11,1,NULL,'hutongstore'),(25112,957689027015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','paulocajuru','paulomarcioalves@gmail.com','Paulo Márcio de S. Alves','251, Alfredo Mattar<br>B. Adelino Mano','Carmo do Cajuru','Minas Gerais','BRAZIL','35510-000','553732441476','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 11:37:12',0,NULL,3,1,3,1,'RA184504475CN\r ','hutongstore'),(25113,937820901016,260933199108,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.9,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-02 12:03:12',0,NULL,3,1,17,0,NULL,'hutongstore'),(25114,937820535016,260660054471,'TianYa Gradual Gray Plexigl Filter replaces for Cokin P',1,'AA2322',4.65,'hutongstore','zecrich67','zecrichardson@hotmail.co.uk','Zechariah Richardson','69, Queen Elizabeth Chase','Rochford','Essex','UNITED KINGDOM','SS4 1JJ','01702544947','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 12:03:13',0,NULL,3,1,11,1,NULL,'hutongstore\r无牌方镜 渐变灰 （nd2）  1\r天涯方形滤镜  渐变灰   1'),(25115,850747503002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','la_compagnie_des_skawas','anamnesis.spirit@live.fr','Julien Sanchez','12 rue laurencin','Lyon','Rhône-Alpes','FRANCE','69002','0625630875','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 12:49:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(25116,937842509016,260660051940,'New 52mm 52 Ring adapter and Holder for Cokin P Series',1,'AKT018',3.12,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','','IRELAND','default','0879290583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 12:55:51',0,NULL,3,1,17,0,NULL,'hutongstore'),(25117,957720319015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','pcooley63','pcooley@eircom.net','Paul Cooley','Culleen<br>Kilmaley','Co. Clare','','IRELAND','default','0879290583','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 12:57:28',0,NULL,3,1,11,1,NULL,'hutongstore\r方形滤镜接口环 52mm  1\r方镜普通托架（三槽）   1\r橡胶遮光罩 52mm  1'),(25118,850774111002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','samzynikon','samzy75@yahoo.com','samir misira','aleja lipa 15','Sarajevo','Kanton Sarajevo','BOSNIA AND HERZEGOVINA','71000','(387)61 712-616','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 14:09:33',0,NULL,3,1,3,1,'RA184504586CN\r ','hermeshine'),(25119,850774761002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','alexshebanov2012','alexshebanov@yandex.ru','Alexandr Shebanov','Baraeva 12, 20','Astana','','KAZAKHSTAN','010000',' 87771073013','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 14:11:46',0,NULL,3,1,3,1,'RA184523832CN\r ','hermeshine\r闪光的柔光箱   60cm  1\r爵影碗罩P4   1'),(25120,957780527015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','wing-commander-03','kinwingwu@aol.com','Mr  Wu','Flat 27<br>Connaught Gardens','78 Alexandra Road','West Midlands','UNITED KINGDOM','B5 7NH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 15:16:34',0,NULL,0,0,3,1,NULL,'hutongstore\r发信问大小'),(25121,937908189016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','skytech88','sparxx88@sky.com','mark driver','9 wilton avenue','chapel st leonards','Lincolnshire','UNITED KINGDOM','pe24 5sg','01754873635','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 15:27:43',0,NULL,3,1,3,1,'RA184504626CN\r ','hutongstore\r2单反  1'),(25122,806177325001,110414377211,'New Graduated Gray Filter & Ring & Holder Saving $1.5',1,'AKT028',10.99,'hermeshine','2010bobesponja','beamarteche@hotmail.com','Beatriz Martínez Echeandía','C/Escritorio Nº1 2ºC','Alcalá de Henares','Madrid','SPAIN','28801','649553707','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 15:40:18',0,NULL,3,1,2,1,'30124085810\r ','hermeshine'),(25123,848411863002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','belued_123','dianejohnson57@gmail.com','Dianne Johnson','46 Goldsmith Road','Spearwood','Western Australia','AUSTRALIA','6163','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 15:47:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(25124,937934365016,260660053049,'New Hairlight  photostudio boom arm and Light stand',1,'AKT030',32,'hutongstore','revelation4','g.symes09@btinternet.com','Graham Symes','17 The Weind<br>Theydon Bois','Essex','ENGLAND','UNITED KINGDOM','CM167HP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-02 16:21:14',0,NULL,3,1,3,1,'RA184504612CN\r ','hutongstore'),(25125,957826296015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ten_quintas','goncalo.quintino@gmail.com','Gonçalo Quintino','Rua José Farinha, n.º 38, 7.º B','Lisboa','Lisboa','PORTUGAL','1500-700','+351934257482','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 16:43:36',0,NULL,3,1,11,1,NULL,'hutongstore'),(25126,849586143002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','4escapade','luizajeff@comcast.net','Jeffrey Trahan','5605 137th Place SE','Everett','WA','UNITED STATES','98208','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-02 17:33:05',0,NULL,3,1,3,1,'RA184504705CN\r ','hermeshine'),(25127,850847655002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','alonetix','alonet@yandex.ru','Vadim Borisov','Pershutova str. 35/1-14','Kovrov','Vladimirskaya obl','RUSSIAN FEDERATION','601902','+79101747441','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 17:14:31',0,NULL,3,1,3,1,'RA184504484CN\r ','hermeshine'),(25128,850872536002,120461006671,'Digital SLR Camera Raincover rain cover for Nikon Canon',1,'AA3101',16.99,'hermeshine','gerasim111','serdukov@list.ru','Roman Serdyukov','Shipilovskaya street, house 41, apartment 158','Moscow','Russia','RUSSIAN FEDERATION','115573','(495)3952172','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 18:11:12',0,NULL,3,1,17,0,'RA184523903CN\r ','hermeshine'),(25129,806245146001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','gerasim111','serdukov@list.ru','Roman Serdyukov','Shipilovskaya street, house 41, apartment 158','Moscow','Russia','RUSSIAN FEDERATION','115573','(495)3952172','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 18:12:30',0,NULL,3,1,3,1,'RA184523903CN\r ','hermeshine\r防雨罩  1\r永诺 Canon ttl线  3m  1'),(25130,806254015001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0039761411264','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 18:35:11',0,NULL,3,1,5,1,'CP246990125CN\r ','hermeshine\r申报$23'),(25131,957893070015,250600478659,'Camcorder cameras tripod hand free shoulder support pad',1,'AE1401',21.9,'hutongstore','mikhail_brekhov','mbrekhov@gmail.com','Mikhail Brekhov','bul. Profsouzov 10 kv.84','Volgskiy','VOLGOGRADSKAY OBL','RUSSIAN FEDERATION','404102','78443384620','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 18:38:19',0,NULL,3,1,3,1,'RA184504745CN\r ','hutongstore'),(25132,806275480001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','prettyjen178','prettyjen178mo@yahoo.com','Lawrence Punsalan','6111 Skaha Crescent','Richmond','BC','CANADA','V7C2R3','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 19:11:33',0,NULL,3,1,11,1,NULL,'hermeshine'),(25133,873584778017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'photographyacc','wufflydog','gary.gasson@btinternet.com','Gary   Gasson','325 Harold Road','Hastings','East Sussex','UNITED KINGDOM','TN355NE','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 19:31:43',0,NULL,3,1,11,1,NULL,'photographyacc'),(25134,850920470002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','rivalwon','ben@liamstheman.com','Ben Glasstetter','33733 Bowie Dr','Mission','BC','CANADA','V2V7S3','(604) 331-2823','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 19:40:06',0,NULL,3,1,3,1,'RA184504630CN\r ','hermeshine'),(25135,806299750001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','helgelutsk','oleg@chernenko.info','Oleg Chernenko','Gornaya<br>2/27','Lutsk','Volyn','UKRAINE','43001','+380673327612','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 19:56:23',0,NULL,3,1,5,1,'CP246990134CN\r ','hermeshine\r欧标'),(25136,850935052002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','stinehorsey','stinebe88@hotmail.com','Stine Eidem','Lodevegen 27','Nærbø','','NORWAY','4365','004797125579','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 20:08:41',0,NULL,3,1,11,1,'、 ','hermeshine'),(25137,812892118018,280667405538,'24\" 60CM 2IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3303',8.5,'photographyacc','jonvdveen','jon_tlw_84@yahoo.ca','Jonathan Vander Veen','1446 Highwood Blvd','Devon','AB','CANADA','T9G 2E8','(780) 934-2474','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 19:47:18',0,NULL,3,1,11,1,NULL,'photographyacc'),(25138,850949518002,120560330004,'64pcs LED Light Flash Camcorder/Camera Photo Light ',1,'AB3317',36.99,'hermeshine','jkchan-2007','j.kchan3@hotmail.com','james chan','1780 stravinski','brossard','QC','CANADA','j4x2j7','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 20:36:19',0,NULL,3,1,3,1,'RA184523982CN\r ','hermeshine'),(25139,938100877016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','browne6175','danielbrowneava@yahoo.co.uk','daniel browne','40 greenway<br>greasby','wirral','Merseyside','UNITED KINGDOM','ch49 2nw','01516770152','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-02 20:54:53',0,NULL,3,1,4,1,'YW867611431CN ','hutongstore\r英标'),(25140,938120065016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',5,'AD1181',64.95,'hutongstore','dreamideal','francesca_scerri@hotmail.com','Francesca Scerri','22 \'Bouquet\'<br>Mose Gatt street','B\'kara','B\'kara','MALTA','BKR 4092','+35679261978','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-02 21:23:38',0,NULL,3,1,3,1,'RA184523815CN\r ','hutongstore'),(25141,957991830015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','alex_enzo','enzo_y2k@yahoo.com','Alexandru Nica','Str.Primaverii nr.5, bl P11, sc F,ap 9','Botosani','Romania','ROMANIA','710114','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-02 21:24:17',0,NULL,3,1,5,1,'CP244439754CN ','hutongstore\r欧标'),(25142,806376693001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','skittyann','bartissa@yandex.ru','Ann Sidelnikova','Budapeshtskaya st, 66-1-224','Saint-Petersburg','','RUSSIAN FEDERATION','192286','(911)127-4114','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 22:38:38',0,NULL,3,1,11,1,NULL,'hermeshine'),(25143,958047303015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','onkenw','gauvreau01@yahoo.ca','Robert Gauvreau','445 rue Deshaies','Trois-Rivières','QC','CANADA','g9a 5p2','(819) 244-1948','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-02 22:41:39',0,NULL,3,1,3,1,'RA184523885CN\r ','hutongstore'),(25144,812993413018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.43,'photographyacc','lightdeva86','lorrainebrowne12@gmail.com','Lorraine Browne','Apt 126, The Neptune,<br>Harty\'s Quay, Rochestown','Co. Cork','Cork','IRELAND','25','0879607047','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-02 23:17:36',0,NULL,3,1,11,1,NULL,'photographyacc'),(25145,806394825001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','ilya79','ilyapetrenko@yahoo.com','ilya petrenko','hanegev str 2/5','nahariya','','ISRAEL','22222','0544494807','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-02 23:28:40',0,NULL,3,1,3,1,'RA184523894CN\r\r ','hermeshine\r放四个欧标'),(25146,806394824001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','ilya79','ilyapetrenko@yahoo.com','ilya petrenko','hanegev str 2/5','nahariya','','ISRAEL','22222','0544494807','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-02 23:28:39',0,NULL,3,1,3,1,'RA184504714CN\r ','hermeshine'),(25147,958077624015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','7wister76','fredrick@my.com.mt','Frederick Muscat','89, Margerita<br>Sir Harry Luke Str.,','Mgarr','Malta','MALTA','MGR1505','+356 99283264','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-02 23:49:21',0,NULL,3,1,3,1,'RA184504728CN\r ','hutongstore'),(25148,806408080001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','pegasusphil','philweight@gofast.co.uk','Philip Weight','420 Maurer Court<br>John Harrison Way','London','London','UNITED KINGDOM','SE10 0SW','07920015238','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 00:11:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(25149,806407273001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','almablanca70','obelesarosaeugenio@yahoo.es','Maria Obelesa Rosa Eugenio','Jose Hernandez Almeida,56','Arrecife - Lanzarote (Las Palmas)','Canarias','SPAIN','35500','627550503','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 00:11:58',0,NULL,3,1,3,1,'RA184504643CN\r ','hermeshine'),(25150,873733691017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',5.08,'photographyacc','ninja_mike_strikes','achieve1@bigpond.net.au','Mike Palmer','P.O. Box 7322','Beaumaris','Victoria','AUSTRALIA','3193','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 00:56:35',0,NULL,3,1,2,1,'30124074540\r ','photographyacc'),(25151,813030680018,280683358148,'Swivel Flash Mount Umbrella Bracket for Light Stand D',1,'AD1122',15.8,'photographyacc','covert-tiger','kabs03@gmail.com','Barbara Anne  Bailey','8 Dutton Dr','Para Hills','South Australia','AUSTRALIA','5096','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 01:13:05',0,NULL,3,1,11,1,NULL,'photographyacc'),(25152,938223816016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.12,'hutongstore','inflames_georgi','freefall_kramz@yahoo.co.uk','Georgi Georgiev','9 Ashfield Road  <br>Ealing','London','London','UNITED KINGDOM','W3 7JE','07853899828','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 01:20:25',0,NULL,3,1,11,1,NULL,'hutongstore'),(25153,806426898001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','noomphoto','noomphoto072@gmail.com','Ekachai Kumfang','21910 44th Ave W','Mountlake Terrace','WA','UNITED STATES','98043-3614','(425) 622-8932','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 01:26:06',0,NULL,3,1,1,1,'LK220371553CN ','hermeshine'),(25154,806431789001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','wlgoode863','wlgoode@gmail.com','Wendell Goode','8958 S Six Shooter Canyon Rd<br>Spc 66','Globe','AZ','UNITED STATES','85501-4084','(928) 793-3935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 01:38:14',0,NULL,3,1,17,0,'LK220368894CN ','hermeshine'),(25155,632937717004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','wlgoode863','wlgoode@gmail.com','Wendell Goode','8958 S Six Shooter Canyon Rd<br>Spc 66','Globe','AZ','UNITED STATES','85501-4084','(928) 793-3935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 01:38:15',0,NULL,3,1,17,0,'LK220368894CN ','hermeshine'),(25156,806419765001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','wlgoode863','wlgoode@gmail.com','Wendell Goode','8958 S Six Shooter Canyon Rd<br>Spc 66','Globe','AZ','UNITED STATES','85501-4084','(928) 793-3935','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 01:38:16',0,NULL,3,1,1,1,'LK220368894CN ','hermeshine\r无牌方镜 渐变灰 （nd2）  1\r无牌方镜 渐变灰 （nd4）   1\r无牌方镜 渐变灰 （nd8）   1'),(25157,806435172001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','darkwarchief','rorymallett@hotmail.com','Rory Mallett','10710 110TH ST<br>APT 208','Edmonton','AB','CANADA','T5H 3E1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 01:51:53',0,NULL,3,1,3,1,'RA184504731CN ','hermeshine'),(25158,813080859018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',55,'photographyacc','glossfox','louise.a.francis@gmail.com','Louise Francis','101 Gold Street','Collingwood','Victoria','AUSTRALIA','3066','0403922040','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 04:34:32',0,NULL,3,1,4,1,'YW867611442CN ','photographyacc'),(25159,806474358001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','wildhogrunner','txbulldog1@gmail.com','David Caraway','3711 Roylene Ct','Dickinson','TX','UNITED STATES','77539-6412','(832) 495-9978','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-03 04:38:55',0,NULL,3,1,4,1,'YW870146822CN ','hermeshine'),(25160,813087636018,280721288180,'New 10pcs Landscape Filter Adapter & Holder for Cokin P',1,'AKT082',51.5,'photographyacc','mar$hallr','marshall.rainbow@gmail.com','Marshall Rainbow','Suite W2C1,75-85 O\'Riordan St<br>Sydney Corporate Park','Alexandria','New South Wales','AUSTRALIA','2015','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 05:07:20',0,NULL,3,1,3,1,'RA184523925CN\r ','photographyacc\r环换成77mm 环'),(25161,958184197015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','nerkaren','nerkaren85@mail.ru','Karen Nersisyan','app.- 3, 11, Baghyan backstr.','Yerevan','Nor Nork','ARMENIA','0056','37494113015','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-03 05:38:21',0,NULL,3,1,5,1,'CP246990240CN\r ','hutongstore'),(25162,806483707001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','yuhjeng','ftsrecording@gmail.com','Eugene Chen','7460 Warren Pkwy<br>Oracle Ste 300','Frisco','TX','UNITED STATES','75034-4169','(972) 334-9373','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 05:21:49',0,NULL,3,1,1,1,'LK220381312CN ','hermeshine'),(25163,938302892016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','willough83','davidjenkins1973@bigpond.com','David Jenkins','6 Daly Boulevard','Highton','Victoria','AUSTRALIA','3216','0352444478','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-03 06:04:29',0,NULL,3,1,3,1,'RA184504657CN\r ','hutongstore'),(25164,958185995015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','blakey_614','blakey614@aol.com','steve blake','12 newall road','andover','Hampshire','UNITED KINGDOM','SP11 8HP','07748841975','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 06:19:45',0,NULL,3,1,3,1,'RA184504847CN\r ','hutongstore'),(25165,806500963001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',3,'AD1167',48,'hermeshine','5978michael','vurck7@aol.com','MICHAEL VURCKIO','22 Piersoll Rd','old bridge','NJ','UNITED STATES','08857-1537','(917) 912-2498','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-03 06:57:35',0,NULL,3,1,1,1,'LK220367134CN ','hermeshine'),(25166,806502851001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',2,'AE2501',59.98,'hermeshine','neguadastyle','ns_pictures@hotmail.fr','GUERRIER JEAN-FRANKY','41 avenue Georges Clemenceau<br>bat B1','MONTPELLIER','Languedoc-Roussillon','FRANCE','34000','0672657529','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 07:08:02',0,NULL,3,1,3,1,'RA184504762CN\r ','hermeshine'),(25167,851132864002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','telaketju','lasse.kaukonen@nesteoil.com','lasse kaukonen','trumpettitie 13 H 17','helsinki','uusimaa','FINLAND','00420','0408673856','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 07:08:41',0,NULL,3,1,17,0,NULL,'hermeshine'),(25168,851135953002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','svetoslavplace','svetoslav.krastev@gmail.com','Svetoslav Krastev','Bratya Miladinovi, bl. 1B, vh.A, et.7, ap. 19','Burgas','','BULGARIA','8000','+359895744030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 07:10:56',0,NULL,3,1,3,1,'RA184519617CN ','hermeshine'),(25169,851142683002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','diegog.858','diegodomain@msn.com','Diego Gomez','12675 Danielson Ct<br>Ste 402','Poway','CA','UNITED STATES','92064-6835','(858) 335-2540','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-03 07:40:34',0,NULL,3,1,1,1,'LK220367995CN ','hermeshine'),(25170,851152163002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','urosm1234','umlakar@teleing.com','Uros Mlakar','Dornava 82','Dornava','','SLOVENIA','2252','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 08:24:36',0,NULL,3,1,3,1,'RA184504793CN\r ','hermeshine'),(25171,851153520002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','vik_bik','vikbik1977@gmail.com','Viktor Bogdanov','Vanco Mickov 57','Skopje','MACEDONIA','MACEDONIA (REP. OF) (FORMER YOGOSLAVIA)','1000','072243122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 08:29:56',0,NULL,3,1,3,1,'RA184504802CN\r ','hermeshine'),(25172,958227073015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','giorgos_v','vlageorg@gmail.com','GEORGIOS VLACHOS','1 TSELIOU STREET','THESSALONIKI','THESSALONIKI','GREECE','54352','(30)2310951780','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 08:31:23',0,NULL,3,1,11,1,'\r ','hutongstore'),(25173,958229569015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','preben-a','rojser@email.dk','preben nielsen','kettrupvej 3','fjerritslev','','DENMARK','9690','96507006','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 08:39:46',0,NULL,3,1,3,1,'RA184504541CN\r ','hutongstore'),(25174,8881330764696561,111,'Studio Background Support 7x7 ft + 2 (White and Black) Backdrops + Free Carry bag - Wholesale/ Retail [AKT015]',1,'AKT015',74.99,'aliexpress','1007108146','wrost69@rambler.ru','Viktor Prikhodko','Kommunisticheskii st. 30/2 - ap.27','Rostov-na-Dony','Rostov region','RUSSIAN FEDERATION','344091','+7863 221 4563214',NULL,NULL,NULL,'2012-03-03 08:51:36',0,NULL,3,1,5,1,'CP244439768CN ','黑加白\r速卖通 '),(25175,8881330764813945,111,'x2 115W 220V 5500K Studio Light Bulb Daylight with E27 Socket [AKT049]',1,'AKT049',30.99,'aliexpress','1007115385 ','mosaique@mosadax.fr','ph thevenon - MOSAIQUE','18 rue neuve','dax','landes','FRANCE','40100','+033 0973842113',NULL,NULL,NULL,'2012-03-03 08:53:33',0,NULL,3,1,3,1,'RA184504609CN\r ','速卖通'),(25176,8881330764925233,111,'Free shipping & Tracking # - New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount - Wholesale/Retail AE2203',1,'AE2203',22.99,'aliexpress','1007125665 ','mma.icms@gmail.com','Marcelo Mancano Aro','Superquadra 11 Quadra 08 Casa 18 - Centro','Cidade Ocidental','Goias','BRAZIL','72880000','+55 61 36251361',NULL,NULL,NULL,'2012-03-03 08:55:25',0,NULL,3,1,17,0,'RA184523877CN\r ','速卖通'),(25177,8881330765058345,111,'Free shipping & Tracking # - Universal Barn Door with Honeycomb Grid + 4 Color Gels - AD1166',1,'AD1166',24.99,'aliexpress','1007125664 ','mma.icms@gmail.com','Marcelo Mancano Aro','Superquadra 11 Quadra 08 Casa 18 - Centro','Cidade Ocidental','Goias','BRAZIL','72880000','+55 61 36251361',NULL,NULL,NULL,'2012-03-03 08:57:38',0,NULL,3,1,3,1,'RA184523877CN\r ','50-70柔光棚 通用塑料卡口  1\r蜂窝   1\r速卖通'),(25178,938361969016,260661735026,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',29,'hutongstore','gillian101273','joedyingham@hotmail.co.uk','gillian tams','41 garth 25','newcastle upon tyne','Tyne and Wear','UNITED KINGDOM','ne12 6dw','07791092460','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 09:38:17',0,NULL,3,1,3,1,'RA184504691CN\r ','hutongstore'),(25179,938365080016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','123cathw','cath.walker@optusnet.com.au','Cath Walker','5 Sutton St','Balmain','New South Wales','AUSTRALIA','2041','0421053408','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 09:48:23',0,NULL,3,1,2,1,'30124084922\r ','hutongstore'),(25180,813129724018,280680854426,'YongNuo WR159  Wireless Remote Control for Canon 60D 7D',1,'AD1120',18,'photographyacc','xenonive','thebigphil_100@hotmail.com','Phil Rowell','The Gilberd School<br>Brinkley Lane','Colchester','Brinkley Lane','UNITED KINGDOM','co4 9pu','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 10:51:56',0,NULL,3,1,11,1,NULL,'photographyacc'),(25181,958289417015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','torbeng2007','torben@glarbo.dk','Torben Glarbo','Gadevangen 9','Kongens Lyngby','','DENMARK','2800','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 11:16:34',0,NULL,3,1,4,1,'YW867611420CN ','hutongstore'),(25182,872627144017,270745063943,'New Green.L Premium Quality 52mm UV Filter Canon Nikon ',2,'AA3301',6.4,'photographyacc','flyingkroeger','christina.soongkroeger@gmail.com','Christina Soong-Kroeger','3 Allerdice Court','West Lakes','South Australia','AUSTRALIA','5021','0882421246','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-03 11:18:12',0,NULL,3,1,11,1,'','photographyacc'),(25183,806570033001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','morleyvon','morley@vonsternberg.com','Morley von Sternberg','18 Grove Hill','London','London','UNITED KINGDOM','E18 2JG','02089895704','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 11:20:18',0,NULL,3,1,11,1,NULL,'hermeshine'),(25184,958294152015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','snapit101','stuartmcloughlin@btinternet.com','Stuart McLoughlin','209 Kingstown Road','Carlisle','Cumbria','UNITED KINGDOM','CA3 0BB','01228535944','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-03 11:30:45',0,NULL,3,1,3,1,'RA184523850CN\r ','hutongstore'),(25185,806595357001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','vyroy','jorge_411@msn.com','Jorge Tortosa Gassó','C/Molí 54','La Font de la Figuera','Comunidad Valenciana','SPAIN','46630','660760419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 12:36:41',0,NULL,3,1,17,0,'RA184504855CN\r ','hermeshine'),(25186,958326668015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','arabadzhiev2010','nikilondon@mail.bg','nikolay arabadzhiev','1 more london place','london','London','UNITED KINGDOM','se1 2af','07876443673','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 12:50:38',0,NULL,3,1,11,1,NULL,'hutongstore'),(25187,813218075018,280785873784,'New Camera Lens Spanner Wrench 2 tip Repair Repairing Open Tool Stainless Steel',1,'AD1207',43,'photographyacc','cahallsworth','charles.hallsworth@abitas.com','Charles Hallsworth','Studio 6, St. Michaels Studios<br>St. Michaels Lane','Bridport','Dorset','UNITED KINGDOM','DT6 3RR','07768476603','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 13:17:27',0,NULL,3,1,3,1,'RA184523761CN\r ','photographyacc'),(25188,958349565015,250599384153,'72mm 72 Haze UV Filter For Canon SONY Pentax Nikon New',1,'AA3306',2.9,'hutongstore','whyte9530','anneandbobby1952@blueyonder.co.uk','robert whyte','15 lindams','uddingston  glasgow','South Lanarkshire','UNITED KINGDOM','g717jj','01698330435','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 13:36:45',0,NULL,3,1,11,1,NULL,'hutongstore'),(25189,938459638016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','ariel520alan','alanwaller2@sky.com','ALAN WALLER','4 THORNHOLME DRIVE<br>BOTTESFORD','SCUNTHORPE','Lincolnshire','UNITED KINGDOM','DN163Pq','01724348216','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 13:39:08',0,NULL,3,1,3,1,'RA184504688CN\r ','hutongstore'),(25190,958358347015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','gaz.ti.bmw','gary.lowder@sky.com','G Lowder','19 Ainsdale Close<br>Scale Hall','lancaster','lancs','UNITED KINGDOM','LA1 2 SF','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-03 13:53:31',0,NULL,3,1,4,1,'YW867611416CN ','hutongstore\r黑加白'),(25191,938472300016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',105,'hutongstore','zaven.grigoryan','zaveng@gmail.com','Tigran Manukyan','Armen Tigranyan 5-108','Yerevan','Yerevan','ARMENIA','0037','+37495395525','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 14:06:09',0,NULL,3,1,5,1,'CP244439771CN ','hutongstore\r除了C以外还有\rWT600  1\r欧标'),(25192,958369428015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','seun.is','seun.ismail@gmail.com','Seun Ismail','97 bond street','Chelmsford','Essex','UNITED KINGDOM','Cm11gd','07775039128','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 14:18:11',0,NULL,3,1,3,1,'RA184504524CN\r ','hutongstore'),(25193,938484450016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','mr_crabtree','nixhome@hotmail.com','Nicholas Moore','35 Bolingbroke Grove','London','Greater London','UNITED KINGDOM','SW11 6EJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 14:28:50',0,NULL,3,1,11,1,NULL,'hutongstore'),(25194,851292754002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT052',85.98,'hermeshine','ninoft','neket@yandex.ru','Nikita Kobets','Narodnaya Street, house 32, appartment 101','Nizhniy Novgorod','RU','RUSSIAN FEDERATION','603074','89506000857','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-03 15:18:26',0,NULL,3,1,5,1,'CP246990148CN\r ','hermeshine\r2云柔  2套'),(25195,813289531018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.99,'photographyacc','studio_fred','fred.egea@free.fr','Egea Fred','6 allee Bourvil<br>appt 23','CRETEIL','Ile-de-France','FRANCE','94000','0650469711','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 15:43:09',0,NULL,3,1,11,1,NULL,'photographyacc'),(25196,633123536004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','telaketju','lasse.kaukonen@nesteoil.com','lasse kaukonen','trumpettitie 13 H 17','helsinki','uusimaa','FINLAND','00420','0408673856','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 16:23:43',0,NULL,3,1,11,1,NULL,'hermeshine\r方形滤镜接口环 72mm  1\r方镜普通托架（三槽）  1\r无牌方镜 渐变灰 （nd4）   1'),(25197,851329288002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','fabritsv','fabrits@bezeqint.net','Victor Fabrits','Ben Eliezer Aryeh 86/30','Jerusalem','','ISRAEL','93826','(972)52-3553321','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 16:33:11',0,NULL,3,1,11,1,NULL,'hermeshine'),(25198,806695339001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','malsm61','tatsyzran@yandex.ru','Сергей Малов','п.Варламово, ул.Южная 1-32','Сызранский район','Самарская область','RUSSIAN FEDERATION','446073','+7(927)6106440','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-03 16:35:56',0,NULL,3,0,3,1,'RA184523775CN\r ','hermeshine\r2XL 已入库'),(25199,806697607001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','beladob','beladobsai@hotmail.com','Bela Dobsai','63-3380 Ypres Ave.','Windsor','ON','CANADA','N8W 5G9','(519) 566-6045','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-03 16:43:20',0,NULL,3,1,3,1,'RA184504674CN\r ','hermeshine'),(25200,851364371002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','tlgdnr','dnrtlg@hotmail.com','tolga doner','Teleferik Mahahllesi Metin Oktay Sokak. Mizan Sitesi C blok<br>no:15/2 Daire 2','izmir balcova','izmir','TURKEY','35330','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 17:38:29',0,NULL,3,1,11,1,NULL,'hermeshine\r欧标'),(25201,851370281002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','tbb100','bobo100@mail.ru','Boris Trapeznikov','Deputatskaja build. 60, flat 192','Novosibirsk','Novosibirsk','RUSSIAN FEDERATION','630099','+79139257106','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 17:46:54',0,NULL,3,1,11,1,NULL,'hermeshine'),(25202,806738315001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','capgal6ahd','capgal@uol.com.br','galdino neto','rua cap otávio machado 860','sao paulo','sao paulo','BRAZIL','04718-001','2392377','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 18:03:41',0,NULL,3,1,3,1,'RA184523789CN\r ','hermeshine'),(25203,851452972002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-03 20:09:48',0,NULL,3,1,3,1,'RA184504498CN\r ','hermeshine\r申报$32'),(25204,938720609016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','bazilkat','chas.knight@virgin.net','Chas Knight','34 City Court<br>15 Lower Canal Walk','Southampton','Hampshire','UNITED KINGDOM','SO14 3HL','07803172296','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 20:28:42',0,NULL,3,1,11,1,NULL,'hutongstore'),(25205,938724022016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.2,'hutongstore','giljoska','giljoska@gmail.com','Gil Josquin','Rua Alzira Cortes 50 / apt 601<br>Botafogo','Rio de Janeiro','Rio de Janeiro','BRAZIL','22260-050','5521-22868936','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-03 20:32:12',0,NULL,3,1,11,1,NULL,'hutongstore'),(25206,806857563001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','aleksaskvedoras','aleksas.k@mail.ru','Aleksas Kvedoras','Karaliauciaus 15-79','Vilnius','Vilnius','LITHUANIA','LT-06200','37060638119','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 21:22:28',0,NULL,3,1,11,1,NULL,'hermeshine'),(25207,958661772015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','radoslaw3736','radziu77@o2.pl','Radoslaw Romanczukiewicz','19 Grange Gardens<br>Rusthall','Tunbridge Wells','Kent','UNITED KINGDOM','tn4 8qd','07851606237','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-03 21:26:20',0,NULL,3,1,3,1,'RA184528959CN\r ','hutongstore'),(25208,851505995002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','dimkin_lv','dimundo@inbox.lv','Dmitry Munda','Parka 8-22','Olaine','','LATVIA','LV2114','+371 29184754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 21:44:47',0,NULL,3,1,17,0,NULL,'hermeshine'),(25209,806867982001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','dimkin_lv','dimundo@inbox.lv','Dmitry Munda','Parka 8-22','Olaine','','LATVIA','LV2114','+371 29184754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 21:44:48',0,NULL,3,1,17,0,NULL,'hermeshine'),(25210,806868085001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.5,'hermeshine','dimkin_lv','dimundo@inbox.lv','Dmitry Munda','Parka 8-22','Olaine','','LATVIA','LV2114','+371 29184754','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 21:44:48',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变蓝   1\r无牌方镜 渐变灰 （nd8）  1\r无牌方镜 渐变橙   1'),(25211,813509032018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','ripson76','ripe@ripestudio.com','Pawel Nowakowski','184 Winchmore Hill Road','London','London','UNITED KINGDOM','N21 1QP','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 22:07:07',0,NULL,3,1,11,1,NULL,'photographyacc'),(25212,813511719018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',7.2,'photographyacc','erwinfeindt','21640@gmx.de','Lothar Duve c/o Mitec','Finnländische Str. 12','Berlin','','GERMANY','10439','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-03 22:13:51',0,NULL,3,1,2,1,'30124083555\r ','photographyacc'),(25213,851528873002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','syrrus-ru','syrrus@yandex.ru','Ruslan Syroegin','ul.Safonova, dom 25, kv 44','Severomorsk','Murmanskay','RUSSIAN FEDERATION','184604',' 89212722388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:35:36',0,NULL,3,1,17,1,'CP244439799CN ','hermeshine'),(25214,958708088015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','birodani82','b.d4n1el@gmail.com','Daniel Biro','27 Hazelwood Road<br>Walthamstow','London','London','UNITED KINGDOM','E17 7AJ','447581440190','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-03 22:43:35',0,NULL,3,1,11,1,NULL,'hutongstore'),(25215,806894519001,110471803400,'YONGNUO 8ft E-TTL(II) Off-Camera Flash Sync Cord Canon',1,'AB3325',25.99,'hermeshine','syrrus-ru','syrrus@yandex.ru','Ruslan Syroegin','ul.Safonova, dom 25, kv 44','Severomorsk','Murmanskay','RUSSIAN FEDERATION','184604',' 89212722388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:43:45',0,NULL,3,1,17,1,'CP244439799CN ','hermeshine'),(25216,851535492002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','syrrus-ru','syrrus@yandex.ru','Ruslan Syroegin','ul.Safonova, dom 25, kv 44','Severomorsk','Murmanskay','RUSSIAN FEDERATION','184604',' 89212722388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:48:27',0,NULL,3,1,17,1,'CP244439799CN ','hermeshine'),(25217,806548871001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','ds2009js','dsantosuosso@gmail.com','Daniel Santossuoso','2 Macdonald Place','Spence','Australian Capital Territory','AUSTRALIA','2615','0262580278','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:49:46',0,NULL,3,1,17,0,NULL,'hermeshine'),(25218,806548773001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','ds2009js','dsantosuosso@gmail.com','Daniel Santossuoso','2 Macdonald Place','Spence','Australian Capital Territory','AUSTRALIA','2615','0262580278','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:51:04',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变灰 （nd8） 1\r无牌方镜 渐变灰 （nd2）  1'),(25219,851540429002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',3.98,'hermeshine','syrrus-ru','syrrus@yandex.ru','Ruslan Syroegin','ul.Safonova, dom 25, kv 44','Severomorsk','Murmanskay','RUSSIAN FEDERATION','184604',' 89212722388','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-03 22:59:17',0,NULL,3,1,5,1,'CP244439799CN  ','hermeshine\r2B 柔  1\r永诺 Canon ttl线  3m  1\r闪光的柔光箱   60cm  1\r普通有线快门线C3  1'),(25220,806905830001,110320736686,'62mm 62 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1304',3.79,'hermeshine','inokashira','olsen_808@yahoo.com','Robert Olsen','5080 Likini St<br>Ph 113','Honolulu','HI','UNITED STATES','96818-2383','(808) 392-1429','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-03 23:13:12',0,NULL,3,1,1,1,'LK220411076CN ','hermeshine'),(25221,806914580001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','13jakeh13','jakehbree13@gmail.com','Jakeh Landrum','2870 N Towne Ave<br>Apt 99','Pomona','CA','UNITED STATES','91767-2066','(909) 936-4464','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-03 23:35:47',0,NULL,3,1,1,1,'LK220365853CN ','hermeshine'),(25222,851573958002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',3,'AD1169',20.64,'hermeshine','sp-michael2009','michael@soundpartner.dk','michael jensen','nedertoften 39 2 th','vanløse','dk','DENMARK','2720','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 00:32:18',0,NULL,3,1,11,1,NULL,'hermeshine'),(25223,938867674016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','pedromaher','pfm31048@bigpond.com','PETER F MAHER','68 COLCHES STREET','CASINO','New South Wales','AUSTRALIA','2470','61266625670','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 01:08:24',0,NULL,3,0,3,1,'RA184504507CN\r ','hutongstore\r2XL 已入库'),(25224,938796839016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',2,'AD1182',92,'hutongstore','zimsus','zimo@o2.pl','Stanislaw Zimoglad','20B Boghall Cottages','Bray','Wicklow','IRELAND','default','0851475059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 01:27:15',0,NULL,3,1,4,1,'YW867611405CN ','hutongstore'),(25225,851607746002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','gerardofegan','uv_run@hotmail.com','Gerard Egan','21 Blythe Close','Kaleen','Australian Capital Territory','AUSTRALIA','2617','0438121100','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-04 02:24:01',0,NULL,3,1,3,1,'RA184523863CN\r ','hermeshine\rM 已入库'),(25226,633321341004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','yuanseng','ho.yuanseng@gmail.com','Yuan Seng Ho','Blk 110 Spottiswoode Park Road<br>#21-93','default','','SINGAPORE','081110','9817 6284','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 02:25:04',0,NULL,3,1,2,1,'30124083721\r ','hermeshine'),(25227,806975521001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','vyroy','jorge_411@msn.com','Jorge Tortosa Gassó','C/Molí 54','La Font de la Figuera','Comunidad Valenciana','SPAIN','46630','660760419','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 03:03:10',0,NULL,3,1,3,1,'RA184504855CN\r ','hermeshine\r3m 横杆（通用4节）   1\r反光板支架  1'),(25228,806985446001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','hanserpanser','hansbakken@live.no','Hans-Even Bakken','prost Hallings vei 16','Oslo','Oslo','NORWAY','0666','+4746675578','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 03:39:45',0,NULL,3,1,3,1,'RA184504820CN\r ','hermeshine'),(25229,958837342015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 04:29:11',0,NULL,3,1,17,1,'CP244439808CN  ','hutongstore'),(25230,958837341015,250610487679,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',12.99,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 04:29:10',0,NULL,3,1,17,1,'CP244439808CN ','hutongstore'),(25231,958837345015,250599949620,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',16,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 04:29:14',0,NULL,3,1,17,1,'CP244439808CN ','hutongstore'),(25232,958837344015,250848949434,'600w lighting kit with 3mx6m backdrop & 2mx3m support ',1,'AKT037',134,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-04 04:29:13',0,NULL,3,1,5,1,'CP244439808CN  ','hutongstore\r除了C以外再发   欧标\r倒影板（白黑） 1\r圆形柔光棚 40cm  1\r天涯方形滤镜  ND2  1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  ND8    1\r方形滤镜接口环 67mm  1\r方镜普通托架（三槽）   1\r110cm 两用伞   1\r无牌方镜 渐变蓝   1\r无牌方镜 渐变橙    1\r无牌方镜 渐变灰 （nd4）   1\r3片装的滤镜袋  1\r气吹 + 布  1\r普通有线快门线S1  1\r1.6*3  灰色加黑色布'),(25233,813643084018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','mangoman666','rgyeo@hotmail.com','linda yeo co/nulab professional','8-12 venture way','breaside','victoria','AUSTRALIA','3195','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 05:21:44',0,NULL,3,1,3,1,'RA184504816CN\r ','photographyacc'),(25234,870251893017,270794122739,'New Large Heavy Duty Sand Bag Weight 2 x 23.5 x 26 cm  ',3,'AD1168',45,'photographyacc','clarkmarg2131','marg@festival-photo.com.au','Marg Roche','241 Wright street','Adelaide','South Australia','AUSTRALIA','5000','0422385717','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 05:32:07',0,NULL,3,1,11,1,NULL,'photographyacc'),(25235,807011339001,110469599833,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',9.99,'hermeshine','nardoo72','dnardoo@optusnet.com.au','David Nardoo','173 Pinncale Drive','Townsville,Condon','Queensland','AUSTRALIA','4815','0747736598','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 05:35:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(25236,851658981002,120539339978,'New 67mm ring adapter replacement for cokin P series',1,'AA2212',2.18,'hermeshine','zoed00','zoedwyer@hotmail.com','Zoe Dwyer','4/101 Hardgrave Road<br>West End','Brisbane','Queensland','AUSTRALIA','4101','0405973568','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 05:52:32',0,NULL,3,1,2,1,'30124082332\r ','hermeshine'),(25237,938977342016,260894475632,'43\" Dual double layer reflective and translucent soft  umbrella 110cm',1,'AD1157',18,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 07:17:21',0,NULL,3,1,17,1,'CP244439808CN ','hutongstore'),(25238,958879965015,250971426000,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',9.99,'hutongstore','ruteryak','zloysansey@yandex.ru','Alexandr Paliy','Lenina14 - 10','Yakutsk','Sakha Republic','RUSSIAN FEDERATION','677000','+79248770088','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 07:17:22',0,NULL,3,1,17,1,'CP244439808CN ','hutongstore\r'),(25239,874412923017,270778045389,'TianYa Color Filter Box Set 10 Pcs for Cokin P Series',1,'AKT006',65,'photographyacc','mbur1534','traceyburgess1@bigpond.com','mark burgess','8 birch dr','Bungendore','New South Wales','AUSTRALIA','2621','0262380402','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-04 07:49:54',0,NULL,3,1,3,1,'RA184523965CN\r ','photographyacc'),(25240,813682381018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','h1000barn','wayne.barnett.synergy@hotmail.com','wayne barnett','3 michel rd','scarborough','Queensland','AUSTRALIA','4020','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-03-04 08:15:07',0,NULL,3,1,4,1,'YW867611394CN ','photographyacc'),(25241,851725892002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+62-21-92659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 09:56:23',0,NULL,3,1,2,1,'30124083323\r ','hermeshine'),(25242,807088831001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','al6000','alex.esselin@free.fr','Alex ESSELIN','1 rue des violettes','Illkirch','Alsace','FRANCE','67400','+33369067578','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 10:14:42',0,NULL,3,1,3,1,'RA184504515CN\r ','hermeshine'),(25243,851769860002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','dipayanjana','jana@cmc-concrete.com','DIPAYAN JANA','4727 State Route 30<br>Cmc, Inc., Berkshire Center, St 104.','GREENSBURG','PA','UNITED STATES','15601-7270','(724) 261-1914','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-04 11:37:06',0,NULL,3,1,3,1,'RA184504833CN\r ','hermeshine'),(25244,959009737015,250600524739,'Shutter Release Remote Cord Canon 5D Mark II 40D RS-80',1,'AA3211',2.52,'hutongstore','ebalvsk','ebay@gal.sk','Jozef Gál','Hronske Klacany c.493','Hronske Klacany ','okres Levice','SLOVAK REPUBLIC','93529','036-6331000','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 11:50:19',0,NULL,3,1,11,1,NULL,'hutongstore'),(25245,813780944018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','northernheritage','orders@northern-heritage.co.uk','Chris    Hartnell','Unit 7/8 New Kennels<br>Blagdon Estate','Seaton Burn','Northumberland','UNITED KINGDOM','NE13 6DB','01670789940','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 12:01:00',0,NULL,3,1,11,1,NULL,'photographyacc'),(25246,807141726001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','gits4130','stigbilde@gmail.com','Stig Bilde','Neapelvej 10','Copenhagen S','','DENMARK','2300','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 12:10:43',0,NULL,3,1,3,1,'RA184504555CN\r ','hermeshine'),(25247,813801980018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','sethlehoff','seth@seth.co.uk','Seth Ward','45 Victoria Road<br>Sutton Coldfield','Birmingham','West Midlands','UNITED KINGDOM','B72 1SY','07800581420','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 12:49:43',0,NULL,3,1,11,1,NULL,'photographyacc'),(25248,874566458017,270758473357,'Photo Studio translucent white umbrella soft 110cm/43\" ',1,'AD1125',12.5,'photographyacc','hatititi','i.hatvani@hotmail.com','ifj. Hatvani Istvan','Alispan utca 70','Erd','Erd','HUNGARY','2030','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-04 13:26:34',0,NULL,3,1,17,0,'RA184523917CN\r ','photographyacc'),(25249,959092117015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','mattysfx','mattysfx@hotmail.co.uk','Matthew Richards','3 Botsford Road<br>Wimbledon','London','London','UNITED KINGDOM','SW20 9NP','02085424002','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 13:59:32',0,NULL,3,1,11,1,' ','hutongstore'),(25250,939200167016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','josephsghendo','jsghendo@gmail.com','Joseph Sghendo','41, Triq il-Prinjoli','Santa Lucia','','MALTA','SLC1302','+356 79538786','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 14:22:55',0,NULL,3,1,11,1,NULL,'hutongstore'),(25251,807236728001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','coreycheshire','coreycheshire@sympatico.ca','Corey M.J.P. Cheshire','5418 Valley Way','Niagara Falls','ON','CANADA','L2E1X6','(905) 371-6259','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:06:30',0,NULL,3,1,17,0,'RA184504759CN\r ','hermeshine'),(25252,807247586001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','perm346587','346587@gmail.com','Georgii Kostin Георгий  Костин','st Milchakova 28-94 Мильчакова','28-94erm 28-94','Russia Perm Kray','RUSSIAN FEDERATION','614094','+7(922)242-50-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:25:10',0,NULL,3,0,17,0,'RA184523996CN  ','hermeshine'),(25253,807249191001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','perm346587','346587@gmail.com','Georgii Kostin Георгий  Костин','st Milchakova 28-94 Мильчакова','28-94erm 28-94','Russia Perm Kray','RUSSIAN FEDERATION','614094','+7(922)242-50-10','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:27:44',0,NULL,3,0,3,1,'RA184523996CN ','hermeshine\r1.6*2.1  黑色  2'),(25254,8881330874923765,111,'1500w Continuous Light Kit softbox Boom Arm Hairlight - Wholesale / Retail',1,'AKT066',187.99,'hermeshine','Irina ','mopsirmile@gmail.com','Irina Miluykova','Brusilova str<br>bild 27-3 ap107','Moskow','Russia ','RUSSIA','117 148','',NULL,NULL,NULL,'2012-03-04 15:28:43',0,NULL,3,1,5,1,'CP246990222CN','除了C里面的以外再发\r2.4x3m背景架+1.6*2.1 白布+灯架包   1\r灯架  2m   2 \r柔光箱 60-60cm  四灯头  2\r45w 5500k 灯泡 220v  8\r灯架包     1\r1.6*3  黑色，蓝色，橙色布\r红边套装包    1\r\r欧标\r\r'),(25255,939261716016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',2,'AE3103',15.8,'hutongstore','hatititi','i.hatvani@hotmail.com','ifj. Hatvani Istvan','Alispan utca 70','Erd','Erd','HUNGARY','2030','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-04 15:42:17',0,NULL,3,1,3,1,'RA184523917CN\r ','hutongstore\r柔光伞110cm   1\r大力夹云台  2'),(25256,8881330876353141,111,'115W 110V 灯泡',4,'AKT069',0,'hermeshine','princessvideo','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Yabuku No. 4 Col. Jardines del Ajusco','México','Distrito Federal','MEXICO','14200','',NULL,NULL,NULL,'2012-03-04 15:52:33',0,NULL,3,1,3,1,'RA184504419CN\r ',NULL),(25257,851915414002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',2,'AD1190',33,'hermeshine','andrey1957','samposhel@yandex.ru','Andrey Fedorov','Fedora Poletaeva 4 korp. 1 ap.127<br>Федора Полетаева д.4 кор.1 кв.127','Moscow','Москва','RUSSIAN FEDERATION','109457','+79037100366','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 15:59:59',0,NULL,3,1,11,1,NULL,'hermeshine'),(25258,807279702001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','coreycheshire','coreycheshire@sympatico.ca','Corey M.J.P. Cheshire','5418 Valley Way','Niagara Falls','ON','CANADA','L2E1X6','(905) 371-6259','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 16:11:43',0,NULL,3,1,3,1,'RA184504759CN\r ','hermeshine\r柔光箱 50-70cm 单灯头   1\r3m 横杆（通用4节）   1\r美标'),(25259,959228760015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','ikhaa','ikhaa@mail.dk','Ikhaa Al-Saadoun','Store Tingbakke 187','Vodskov','Denmark','DENMARK','9310','004561719829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 16:49:27',0,NULL,3,1,11,1,NULL,'hutongstore'),(25260,939351327016,260856847288,'Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate for Benro/Manfrotto',1,'AD1187',25,'hutongstore','algebra1984','sunnylunan@btinternet.com','Mr David Charlton','Tynedale,  Home Farm<br>Ecclesgreig,  St. Cyrus','Near Montrose','Angus','UNITED KINGDOM','DD10 0DP','01674850010','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-04 17:16:54',0,NULL,3,1,3,1,'RA184523951CN\r ','hutongstore'),(25261,807357076001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',18.99,'hermeshine','shopper12312','pei_1236@hotmail.com','kanny Thompson','260 Sackville Dr. SW','Calgary','AB','CANADA','T2W 0W6','(587) 215-6567','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 17:52:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(25262,939512197016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','andreychernov','andreychernov66@gmail.com','Андрей Чернов','Аксайская,д.42,кв.15','Краснодар','Краснодарский край','RUSSIAN FEDERATION','350072','89189300530','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 19:20:15',0,NULL,3,1,11,1,NULL,'hutongstore'),(25263,852127790002,120502180275,'Neoprene Protector Camera Cover for Canon 500D 40D M',1,'AC2305',6.24,'hermeshine','edutoury','tourybai@hotmail.com','eduardo touriñan pena','juan astray 26','Baio (Zas)','La Coruna','SPAIN','15150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 19:39:03',0,NULL,3,1,2,1,'30124083953\r ','hermeshine'),(25264,807508059001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','oliverolanovic','oliver.olanovic@yahoo.com','oliver olanovic','slavonska 102','slavonski brod','','CROATIA','385','0959052813','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 20:09:17',0,NULL,3,1,3,1,'RA184504780CN\r ','hermeshine'),(25265,852168620002,120752161238,'4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1202',4,'hermeshine','sebas1430','sebas_girard@hotmail.com','Sebastien Girard','1255 St-Denis<br>App 2','Sorel-Tracy','QC','CANADA','J3R 2A7','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 20:18:36',0,NULL,3,1,2,1,'30124077955\r ','hermeshine'),(25266,807555729001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','svetik100500','serchbanner@gmail.com','Светлана Князева','ул.Интернатская 3, кв.57','Мичуринск','Тамбовская обл','RUSSIAN FEDERATION','393764','(47545)23913','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 21:03:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(25267,807580985001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','mikhailkitashkin','mkitashkin@gmail.com','Mikhail Kitashkin','Souzniy prospekt 24, kv 254','Moscow','','RUSSIAN FEDERATION','111396','+79262575217','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-04 21:37:08',0,NULL,3,1,17,1,'CP244439811CN ','hermeshine'),(25268,807581741001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','mikhailkitashkin','mkitashkin@gmail.com','Mikhail Kitashkin','Souzniy prospekt 24, kv 254','Moscow','','RUSSIAN FEDERATION','111396','+79262575217','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-04 21:38:05',0,NULL,3,1,5,1,'CP244439811CN  ','hermeshine\r4灯头 灯头 孔   1\r50cmx70cm 的柔光箱 (配4灯头）   1    欧标\r灯架  2m   1\r斜臂    1'),(25269,939672436016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','nickjlt','bozza_the_spider@hotmail.com','Nick Toogood','20 Hydrangea Close<br>St Peter\'s','Worcester','Worcestershire','UNITED KINGDOM','WR5 3SR','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 21:40:53',0,NULL,3,1,11,1,NULL,'hutongstore'),(25270,958358558015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','geezermarshy','stevenrobertmarsh@hotmail.co.uk','Steven Marsh','36 Mulberry Avenue','Stubbington','Hampshire','UNITED KINGDOM','po142sn','01329667671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-04 22:04:19',0,NULL,3,1,3,1,'RA184504776CN\r ','hutongstore'),(25271,959607102015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 22:14:01',0,NULL,3,1,17,0,'YW870146844CN\r ','hutongstore'),(25272,959606737015,250692239129,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',19,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 22:14:01',0,NULL,3,1,17,0,'YW870146844CN\r ','hutongstore'),(25273,806901655001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:16:43',0,NULL,3,1,17,0,'3126025055  ','hermeshine'),(25274,852151602002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:16:44',0,NULL,3,1,17,0,'3126025055  ','hermeshine'),(25275,851540886002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-04 22:16:44',0,NULL,3,1,17,0,'3126025055  ','hermeshine'),(25276,807142076001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:16:45',0,NULL,3,1,17,0,'3126025055  ','hermeshine'),(25277,806901580001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:16:46',0,NULL,3,1,17,0,'3126025055  ','hermeshine'),(25278,806901608001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','saud-p','saud.dp@gmail.com','Saud Helayel','7724 - shgra street - alshifa<br>Tel: 00966500051020','Riyadh','Riyadh','SAUDI ARABIA','14721-3103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 22:16:46',0,NULL,3,1,12,1,'3126025055 ','hermeshine\r除了C以外再发\r灯架  2m  12\r斜臂    2\r柔光箱 60-60cm  四灯头  2\r柔光箱 50-70cm 单灯头   10\r115w 5500k 灯泡  220v  8\r45w 5500k 灯泡 220v   8\r灯架包    5\r欧标\r实重30\r泡重38\r补发一块白色背景布的单号\rRA184528287CN'),(25279,959617258015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 22:23:54',0,NULL,3,1,3,1,'RA184523979CN\r ','hutongstore\r欧标'),(25280,959628140015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','pedrosalet','pedrofcy@hotmail.com','Pedro Francisco Candela Yago','Esteban Diaz nº20 piso 1º','Yecla','Murcia','SPAIN','30510','680412199','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 22:37:52',0,NULL,3,1,3,1,'RA184504904CN\r ','hutongstore'),(25281,939723821016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','manuelo1602','manuelo.siatothro@gmail.com','Marjorie Le Roux','2D Avenue des Hélianthes','La Baule','Pays de la Loire','FRANCE','44500','0646773608','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-04 22:56:03',0,NULL,3,1,3,1,'RA184504665CN\r ','hutongstore'),(25282,852279301002,120783196902,'New 4pcs Soft Neoprene Lens Pouch Case Bag S  M  L  XL',1,'AKT086',14.99,'hermeshine','humshkin','hbande6@gmail.com','Humphrey Bande','His People Church<br>Cnr Solly Smidt and Joe Hattingh','N1 City','Western Cape','SOUTH AFRICA','7463','+27723267299','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-04 23:00:28',0,NULL,8,1,17,0,NULL,'hermeshine'),(25283,852279302002,120568071909,'1000W Pro Photo Studio Soft Box Continuous Light Kit ',1,'AKT017',128,'hermeshine','humshkin','hbande6@gmail.com','Humphrey Bande','His People Church<br>Cnr Solly Smidt and Joe Hattingh','N1 City','Western Cape','SOUTH AFRICA','7463','+27723267299','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-04 23:00:29',0,NULL,3,1,3,1,'RA184528477CN ','hermeshine\r除了C以外还有\r镜头筒 小号，中号，大号，XL大号各一个\r分开三个小包试试\rRA184528494CN\rRA184528485CN'),(25284,959682563015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',22,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-05 00:21:53',0,NULL,3,1,4,1,'YW870146844CN\r ','hutongstore\r一转四 灯头  1\r柔光箱 50-70cm 单灯头  1\r115w 5500k 灯泡  220v  2\r欧标\r再补个50-70cm 单灯头'),(25285,807672515001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',18.99,'hermeshine','eliem2008','mene_menelaou@yahoo.gr','Menelaos Menelaou','3, Synergasias Str.,','Lakatamia','Nicosia','CYPRUS','2324','0035799487054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 00:59:02',0,NULL,3,1,11,1,NULL,'hermeshine'),(25286,806994887001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','jmalcon','jmalcon@hotmail.com','Jose Manuel Alconchel Ortega','Avd. Abona esquina el sauzal edf romansil 1 Bajo C','SAN ISIDRO, GRANADILLA DE ABONA','Canarias','SPAIN','38611','637055180','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 01:06:38',0,NULL,3,1,2,1,'30124086834\r ','hermeshine'),(25287,807662572001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',2,'AD1184',67.98,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 01:18:52',0,NULL,3,1,17,1,'CP244439825CN ','hermeshine'),(25288,807661541001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',4,'AE1302',38,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 01:18:52',0,NULL,3,1,17,1,'CP244439825CN  ','hermeshine'),(25289,852278641002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',59.98,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 01:18:54',0,NULL,3,1,5,1,'CP244439825CN  ','hermeshine\r3m 横杆（通用4节）   2\r单灯头   4\r斜臂   2\r欧标'),(25290,959715823015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','zabiyaka01','nikitabar@yandex.ru','Nikita Karpov','proezd Shockalskogo, 21,9','Moscow','Moscow','RUSSIAN FEDERATION','127221','8-903-581-23-00','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 01:32:33',0,NULL,3,1,3,1,'RA184504572CN\r ','hutongstore'),(25291,807689628001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','smile2bond','shjjang01@hanmail.net','Sang Hoon Bahn','Yuljeon-dong, Jangan-gu, Suwon-si, Gyeonggi-do, Korea<br>408-20 202ho','Suwon','N/A','KOREA,REPUBLIC OF','440-827','82-10-3055-9951','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-05 01:42:30',0,NULL,3,1,3,1,'RA184523934CN\r ','hermeshine'),(25292,852350345002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','jameekorn','jameekorn13@yahoo.com','Jameekorn Boonsri','Thai Tavern Restaurant<br>4011 Unit E Norbeck Rd.','Rockville','MD','UNITED STATES','20853','(301) 924-1592','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-05 02:02:26',0,NULL,3,1,4,1,'YW867611335CN ','hermeshine'),(25293,807704331001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','jessicataylor-davis','jessicataylor-davisphotography@hotmail.com','jessica taylor-davis','1127 Holly River Rd','Webster Springs','WV','UNITED STATES','26288-8590','(304) 644-1251','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-05 02:20:25',0,NULL,3,1,4,1,'YW867611346CN ','hermeshine\r美标\r110V灯泡'),(25294,8881330915742038,111,'Free shipping & Tracking # - New Mini IR Wireless Remote Control for Nikon D80 D5000 D90 - AD1116',1,'AD1116',5.99,'aliexpress','1007132252','123@hotmail.com','Roberto Martins','Rua Sebastiao de Moraes 329','Sao Carlos','Sao Paulo','BRAZIL','13562030','+55 16 97132622',NULL,NULL,NULL,'2012-03-05 02:49:02',0,NULL,3,1,3,1,'RA184528260CN\r ','速卖通 \rmini 红外没有了，\r的是爵影红外'),(25295,8881330915849877,111,'Free shipping & Tracking # - New Studio Lighting Kit Stands Large Carry Carrying Bag - AD1181',1,'AD1181',19.99,'aliexpress','1007147310','grishkadv@mail.ru','Grigory Dupanov','Lenina38-31','Klintsy','Brynskaya','RUSSIAN FEDERATION','243140','8-903-86-903-86',NULL,NULL,NULL,'2012-03-05 02:50:49',0,NULL,3,1,3,1,'RA184528021CN ','速卖通 '),(25296,8881330916073668,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',2,'AB3329',97.98,'aliexpress','1007082944 ','cjcool@yandex.ru','Alexandr Kardakov','Halturina 33-55','Kemerovo','Kemerovskaya','RUSSIAN FEDERATION','650068','+7 905 9003884',NULL,NULL,NULL,'2012-03-05 02:54:33',0,NULL,3,1,5,1,'CP246990205CN ','速卖通\r单号1007160374 '),(25297,807728891001,110529196640,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60',4,'AC2302',24.84,'hermeshine','gorrionsudaca','juanotesone@gmail.com','Juan Tesone','Av. Libertador 886<br>Piso 8 Dto E','Vicente Lopez','Buenos Aires','ARGENTINA','1638','(5411) 4718 3175','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 03:21:50',0,NULL,3,1,11,1,NULL,'hermeshine'),(25298,8881330918600308,111,'新款内胆包 XL  Canon  ',1,'AD1214',0,'hermeshine','marisc2009','maris_c@inbox.lv','Maris Cirulis','Jaunlepiki','Launkalnes pag.','Smiltenes nov','LATVIA','LV4729','37129184900',NULL,NULL,NULL,'2012-03-05 03:36:40',0,NULL,3,1,3,1,'RA184523948CN\r ',NULL),(25299,959795252015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',1,'AB3330',1.58,'hutongstore','ibclee','ibclee88@hotmail.com','boon chuan lee','unit 3 castle street, glenvale , ballyragget,<br>co. kilkenny.','ballyragget','Kilkenny','IRELAND','default','0870993211','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 04:36:50',0,NULL,3,1,11,1,NULL,'hutongstore'),(25300,852412438002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','thomas.pyle2012','thomas.pyle@ymail.com','Thomas pyle','1321 Hunt St','Richmond','IN','UNITED STATES','47374-1820','(765) 993-2500','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-05 04:59:40',0,NULL,3,1,1,1,'LK220386748CN ','hermeshine'),(25301,959805733015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','sampsaj','sampsa@patagonia.fi','Sampsa Jyrkynen','Niittaajankatu 6 B 16','HELSINKI','','FINLAND','00810','358445768976','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 05:12:46',0,NULL,3,1,11,1,NULL,'hutongstore'),(25302,633914720004,140642546050,'New Swivel Flash Mount Umbrella Bracket for studio  Light Stand D',1,'AD1122',13.8,'hermeshine','jepmad04','jeppe@pharmaceuter.dk','Jeppe Madsen','Tyttebærkvisten 2','Middelfart','','DENMARK','5500','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 06:30:54',0,NULL,3,1,11,1,NULL,'hermeshine'),(25303,807779133001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','chamira34m','chamiram@suntel.lk','Chamira Morawaka','15<br>Silva Lane','Rajagiriya','Western Province','SRI LANKA','10100','009477229971','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 06:52:12',0,NULL,3,1,11,1,NULL,'hermeshine'),(25304,807779545001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',4,'AO0006',43.96,'hermeshine','kgup5132','krishnak@sfu.ca','krishna krishna','404, 9009 cornerstone mews','burnaby','BC','CANADA','v5a0b9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 06:56:00',0,NULL,3,0,3,1,'RA184524002CN ','hermeshine\r1.6*2.1 粉，黄，蓝，黑'),(25305,807779946001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','jonikk83lev','jennifer180883@gmail.com','EVGENYA MEDVEDEVA','Строителей , д17, кв 154','Ярославль','Ярославский','RUSSIAN FEDERATION','150064','9051330571','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 06:56:05',0,NULL,3,1,3,1,'RA184504590CN\r ','hermeshine'),(25306,875224032017,270748191358,'3-in-1 Cleaning Kit-Lenspen /Rubber Air Blower/Cloth',1,'AKT067',10.44,'photographyacc','taufikrisnandar1975','taufikrisnandar@yahoo.co.id','Taufik Risnandar','Griya Japan Raya, Jl. Pacuan Kuda OO-12 RT 05 RW 12 Japan, Sooko<br>Mojokerto','Mojokerto','JB','INDONESIA','61361','628123230742','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-05 07:20:20',0,NULL,3,1,11,1,NULL,'photographyacc'),(25307,807793470001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','digital_art_01','manuelcab94112@hotmail.com','manuel caballero','1261 Pine Creek way apt H','concord','CA','UNITED STATES','94520','','NoPaymentFailure','CheckoutComplete','Other','2012-03-05 08:00:05',0,NULL,3,0,1,1,'LK226589783CN ','hermeshine\rL 已入库'),(25308,814457554018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',46.54,'photographyacc','itsokwithme','james.b.mcculloch@gmail.com','James McCulloch','15 Bonnyvale Rd','Ocean Grove','Victoria','AUSTRALIA','3226','0413220370','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-05 07:28:18',0,NULL,3,1,3,1,'RA184528035CN ','photographyacc'),(25309,875239163017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.4,'photographyacc','falcon0433','aaronbentley13@hotmail.com','aaron bentley','74 faith street','dimboola','Victoria','AUSTRALIA','3414','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-05 08:16:21',0,NULL,3,1,11,1,NULL,'photographyacc'),(25310,959855153015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',1,'AO0018',38,'hutongstore','nativenoiseza','nativenoise@gmail.com','Bevan Godden','94 Murray street','Kokstad','KZN','SOUTH AFRICA','4700','+27742922298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 08:46:07',0,NULL,3,0,17,0,'3126045602 ','hutongstore'),(25311,959850977015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',1,'AO0018',38,'hutongstore','nativenoiseza','nativenoise@gmail.com','Bevan Godden','94 Murray street','Kokstad','KZN','SOUTH AFRICA','4700','+27742922298','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 08:46:08',0,NULL,3,0,17,0,'3126045602 ','hutongstore'),(25516,961829190015,250599317634,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',2,'AE3401',31.98,'hutongstore','bo280349','guyogco@hotmail.com','Bo Rasmussen','Uhlendorffs Allé 10','Rørvig','standard','DENMARK','4581','(045) 31195517','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 10:17:55',0,NULL,3,1,17,0,'YW870146962CN\r ','hutongstore'),(25312,852474358002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','vigo_tolubizer','tolubizer@gmail.com','Viktor Tolubaew','103/144, ul.Lizjukova','Voronezh','RU','RUSSIAN FEDERATION','394088','+7-920-211-8898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 09:42:53',0,NULL,3,1,17,0,'RA184528049CN  ','hermeshine'),(25313,807819222001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','vigo_tolubizer','tolubizer@gmail.com','Viktor Tolubaew','103/144, ul.Lizjukova','Voronezh','RU','RUSSIAN FEDERATION','394088','+7-920-211-8898','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 09:42:53',0,NULL,3,0,17,0,'RA184528049CN  ','hermeshine\r'),(25315,852481123002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1307',3.79,'hermeshine','mxswa','miata@arach.net.au','D.T.','5 Lockett Crest','Winthrop','Western Australia','AUSTRALIA','6150','61413939007','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 10:12:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(25314,807819221001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','vigo_tolubizer','tolubizer@gmail.com','Viktor Tolubaew','103/144, ul.Lizjukova','Voronezh','RU','RUSSIAN FEDERATION','394088','+7-920-211-8898','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-05 09:42:52',0,NULL,3,1,3,1,'RA184528049CN ','hermeshine\rlenspen  1\r气吹 + 布  1\r1.6*2.1 黑色布   1\r肩架   1'),(25316,807678766001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',36.36,'hermeshine','sunnywidesky','dcerlat@gmail.com','Dorel Cerlat','Ion Ganea 29<br>ap. 2','Chisinau','','MOLDOVA, REPUBLIC OF','MD2009','37369571609','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 10:16:19',0,NULL,8,1,17,0,NULL,'hermeshine\r'),(25317,8881330943498389,111,'Promotion ! NEW Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','sunnywidesky','dcerlat@gmail.com','Dorel Cerlat','Ion Ganea 29<br>ap. 2','Chisinau','','MOLDOVA, REPUBLIC OF','MD2009','37369571609',NULL,NULL,NULL,'2012-03-05 10:31:38',0,NULL,8,1,17,0,NULL,NULL),(25318,8881330943545220,111,'New 3 filters TianYa brand & Ring adapter holder for Cokin System P Series',1,'AKT071',25,'hermeshine','sunnywidesky','dcerlat@gmail.com','Dorel Cerlat','Ion Ganea 29<br>ap. 2','Chisinau','','MOLDOVA, REPUBLIC OF','MD2009','37369571609',NULL,NULL,NULL,'2012-03-05 10:32:25',0,NULL,8,1,17,0,NULL,NULL),(25319,8881330943593204,111,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','sunnywidesky','dcerlat@gmail.com','Dorel Cerlat','Ion Ganea 29<br>ap. 2','Chisinau','','MOLDOVA, REPUBLIC OF','MD2009','37369571609',NULL,NULL,NULL,'2012-03-05 10:33:13',0,NULL,8,1,17,0,NULL,' '),(25320,8881330943640292,111,'New 49mm ring adapter replacement for cokin P series',1,'AA2207',2.18,'hermeshine','sunnywidesky','dcerlat@gmail.com','Dorel Cerlat','Ion Ganea 29<br>ap. 2','Chisinau','','MOLDOVA, REPUBLIC OF','MD2009','37369571609',NULL,NULL,NULL,'2012-03-05 10:34:00',0,NULL,5,1,18,1,'RA184519696CN ','方形滤镜接口环 55mm  1 \r无牌方镜 ND8   1\r方镜普通托架（三槽）  1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  渐变蓝  1\r天涯方形滤镜  渐变灰  1\r方形滤镜接口环 72mm   1\r无牌方镜 渐变灰 （nd8）   1\r方形滤镜接口环 49mm  1'),(25321,959903386015,250933223732,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT075',188,'hutongstore','australia*','office77@tpg.com.au','Tony Monteleone','4 Alder Close','Jerrabomberra','New South Wales','AUSTRALIA','2619','0421406480','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 10:51:54',0,NULL,3,1,4,1,'YW870146833CN ','hutongstore\r澳标'),(25322,959906184015,250600488479,'New Hairlight  photostudio boom arm and Light stand ',1,'AKT030',32.8,'hutongstore','spbserge','agold78@gmail.com','Shcherbenok Sergey','Leninskii pr. h.109 ap.310','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','198207','(812) 3687365','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 11:18:25',0,NULL,3,1,3,1,'RA184528097CN ','hutongstore'),(25323,807849869001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','brownp1965','panthonybrown@yahoo.com','Peter Brown','P.O. Box 59','Spanish Town','St Catherine','JAMAICA','33126','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 11:32:47',0,NULL,3,1,5,1,'CP246990196CN ','hermeshine\r灯泡是110v的  美标'),(25324,814518616018,280670191243,'Green.L Premium Quality 77mm CPL Circular Polarizer New',1,'AA3314',6.84,'photographyacc','konzertorganist','konzertorganist@web.de','Christian Naumann','Sebastian-Bauer-Straße 28','München','','GERMANY','81737','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-05 12:12:36',0,NULL,3,1,2,1,'30124227475\r ','photographyacc'),(25325,959948260015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 12:46:24',0,NULL,3,1,3,1,'RA184528083CN ','hutongstore\r申报$21'),(25326,959947417015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 12:46:25',0,NULL,3,1,3,1,'RA184528070CN ','hutongstore\r申报$21\r\r'),(25327,851282271002,120813657815,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton ',1,'AA2111',54,'hermeshine','dknoguz35','info@gwc-int.com','oguz dikbakan','1775/5 sok no:12 d:11<br>Nergiz Karsiyaka','izmir','tr','TURKEY','35540','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-05 12:12:50',0,NULL,3,1,3,1,'RA184528106CN ','hermeshine\rL 已入库'),(25328,940044285016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',2,'AA1312',2.4,'hutongstore','huck200770','huckgraham@hotmail.co.uk','gary graham','10 d mourneview park','lisburn','Antrim','UNITED KINGDOM','bt28 2uq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 13:26:23',0,NULL,3,1,11,1,NULL,'hutongstore'),(25329,959970008015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.48,'hutongstore','purpleelise1','elisej1@msn.com','Elise Lapwood','52 South Primrose Hill','Chelmsford','Essex','UNITED KINGDOM','CM1 2RG','01245631279','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 13:35:02',0,NULL,3,1,11,1,NULL,'hutongstore'),(25330,814574570018,280670189892,'Green.L Premium Quality 67mm CPL Circular Polarizer New',1,'AA3312',6.27,'photographyacc','vervi32','jacques.baikry@skynet.be','Jacques BAIKRY','Place Général Jacques 32','Verviers','','BELGIUM','4800','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-05 14:01:41',0,NULL,3,1,11,1,NULL,'photographyacc'),(25331,940066675016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','molotok.ru','digishop@mail.ru','Vladimir Sapozjnikov','ul. Zelenaya, d.55, kv.11','Novotroitzk','','RUSSIAN FEDERATION','462351','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-05 14:21:28',0,NULL,3,1,3,1,'RA184528066CN ','hutongstore\r新地址\rVladimir Sapozjnikov\rul. Zelenaya, d.55, kv.11\rNovotroitzk \rOrenburgskaya obl.\r462351\rRussian Federation\r'),(25332,807907610001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','ace_','ace_@gmx.de','Enno Endlicher','Leichtensternstr. 23','Köln','','GERMANY','50937','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 14:28:23',0,NULL,3,1,2,1,'30124225795\r ','hermeshine'),(25333,959996675015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','timmyboy999','timsaxton@onetel.com','Tim Saxton','26a Mount Road','Stone','Staffordshire','UNITED KINGDOM','ST158LJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 14:33:54',0,NULL,3,1,11,1,NULL,'hutongstore'),(25334,959968228015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','jotatetxu','jotatetxu@hotmail.com','juan pedro bote','grupo san juan de dios nº 19 -2º izq.','santurtzi','País Vasco','SPAIN','48980','622781100','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 15:02:41',0,NULL,3,1,2,1,'30124222192\r ','hutongstore'),(25335,807952816001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','abz-1234','abe-83@hotmail.com','Eldin Abazovic','Samira Catovica 25','Ilidža','Sarajevo','BOSNIA AND HERZEGOVINA','71210','0038761843174','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 16:26:13',0,NULL,3,1,3,1,'RA184528018CN ','hermeshine'),(25336,875421640017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','qkevin*','qkevinto@live.com','Kevin To','1 Crabb Pl','Cabramatta','New South Wales','AUSTRALIA','2166','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-05 16:47:21',0,NULL,3,1,2,1,'30124228050\r ','photographyacc'),(25337,807972145001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',3,'AE3401',77.97,'hermeshine','crycatliu','zhangx29@gmail.com','Xiaoli Zhang','35 Charles St W Apt 1114 Buzz 95','Toronto','ON','CANADA','M4Y1R6','(647) 724-0342','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 17:06:50',0,NULL,3,1,5,1,'CP246990182CN ','hermeshine'),(25338,852616388002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','kostelin','kostelin69@yahoo.es','Oier Elorriaga Intxausti','Bº Mendieta  nº67, 1º izda','Ajangiz','País Vasco','SPAIN','48320','699611322','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 16:43:11',0,NULL,3,1,11,1,' ','hermeshine\r'),(25339,852642733002,120752324312,'Protect Soft Camera Bag Case Skin Cover Canon EOS 7D',1,'AD1115',11.99,'hermeshine','kristendahm','kristen.vicelli@comcast.net','Kristen Dahm','1400 Fox Sedge Trl','Woodstock','IL','UNITED STATES','60098-9210','(630) 605-2678','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-05 17:38:34',0,NULL,3,1,1,1,'LK227130574CN ','hermeshine'),(25340,852665860002,120751757613,'New Pro Photo Vest for all DSLR fans Mesh-line Size: L',1,'AA1217',27,'hermeshine','andersuw','anders.westholm@statsvet.uu.se','Anders Westholm','Flogstavägen 154','Uppsala','','SWEDEN','75272','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 18:22:23',0,NULL,3,1,3,1,'RA184528242CN ','hermeshine\rL 已入库'),(25341,808038076001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','izofluran','assuta@mail.ru','Evgeny Bendersky','Golomb 39/1','Haifa','','ISRAEL','33394','9720525610396','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-05 19:06:03',0,NULL,3,1,3,1,'RA184528168CN ','hermeshine\r分开发\rRA184528273CN'),(25342,852694371002,120753012046,'Brand New Official Original Nikon Photo Vest for D300 D90 D700 D80 Size M ',1,'AD1159',42,'hermeshine','gavin95','vwright5006@gmail.com','Vincent Wright','5006 S Links Cir','Suffolk','VA','UNITED STATES','23435-2640','(908) 764-2007','NoPaymentFailure','CheckoutComplete','Other','2012-03-05 19:09:54',0,NULL,3,1,1,1,'LK227124579CN ','hermeshine\rM 已入库'),(25343,940239573016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','albert.pavel','albert.pavel@bohexistuje.eu','Pavel Albert','Vansovej 11','Zvolen','Slovakia','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 19:11:56',0,NULL,3,1,17,0,'RA184528052CN ','hutongstore'),(25344,940242794016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','albert.pavel','albert.pavel@bohexistuje.eu','Pavel Albert','Vansovej 11','Zvolen','Slovakia','SLOVAK REPUBLIC','96001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 19:15:52',0,NULL,3,1,3,1,'RA184528052CN ','hutongstore\r反光板支架  1\r反光板  80cm 5合1  1'),(25345,808077546001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',18.99,'hermeshine','marcelalb','jean-marie.fontaine@aviation-civile.gouv.fr','Jean-Marie Fontaine','157 Lotissement de la Farguette','NAILLOUX','Toulouse','FRANCE','31560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-05 20:08:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(25346,960248265015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','vsbabakhan','vbabakhan@gmail.com','VSEVOLOD BABAKHANOV','Dzerginskogo 15-26','Kokoshkino','Moscow Region','RUSSIAN FEDERATION','143390','903-001-4217','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 20:54:34',0,NULL,3,1,5,1,'CP246990179CN ','hutongstore\r斜臂   1\r背景架2mx2m  + 3个夹子  1\r1.6*2.1  黑加白'),(25347,960256175015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','vsbabakhan','vbabakhan@gmail.com','VSEVOLOD BABAKHANOV','Dzerginskogo 15-26','Kokoshkino','Moscow Region','RUSSIAN FEDERATION','143390','903-001-4217','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 21:04:26',0,NULL,3,1,17,1,'CP246990179CN ','hutongstore'),(25348,940326388016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','koshtrik','koschernov8@yandex.ru','Konstantin Chernov','Voronezh city, Kopernika street 65','Voronezh','','RUSSIAN FEDERATION','394071','79290092400','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-05 21:07:43',0,NULL,3,1,3,1,'RA184528300CN ','hutongstore'),(25349,960285040015,250709193068,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',38.99,'hutongstore','neelen2010','neelenpatten@yahoo.com','Neelen Patten','6, Saranvilla Road<br>Belle-Etoile','Coromandel','Plaine Wilhem','MAURITIUS','09','2302334059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 21:46:12',0,NULL,3,1,8,1,'CP246990219CN\r ','hutongstore\r需要加$14 运费\r已付钱'),(25350,960293334015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','kenisared1','ken.surgenor@yahoo.co.uk','kenneth surgenor','6 hanwood avenue,  dundonald','belfast','Antrim','UNITED KINGDOM','bt16 1xn','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-05 22:01:00',0,NULL,3,1,3,1,'RA184528211CN\r ','hutongstore'),(25351,808146527001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','maciek_pl','maciek_pc@op.pl','Radzimirski Maciej','Zablocinska 8/11<br>Zablocinska 8/11','Warsaw','mazowieckie','POLAND','01-697','503895739','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 22:16:02',0,NULL,3,1,11,1,NULL,'hermeshine'),(25352,960311660015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','kritikos13','kritikobazelos@gmail.com','nektarios fotinakis','goudouras sitia ','sitia','creta','GREECE','72059','0302843052084','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-05 22:30:49',0,NULL,3,1,4,1,'YW870146800CN ','hutongstore'),(25353,960319814015,250619381872,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',24.99,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-05 22:43:29',0,NULL,3,1,3,1,'RA184528225CN ','hutongstore'),(25354,960339272015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','kebaborre','kebaborre@hotmail.com','Oscar Gustafsson','Västmannagatan 33','Stockholm','','SWEDEN','11325','+46708195771','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-05 23:24:54',0,NULL,3,1,3,1,'RA184528239CN ','hutongstore'),(25355,960355510015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','gizmogadgetfanboy','sales@sublime-products.com','Amin Motin','10 Buckthorne Court','Wakefield','West Yorkshire','UNITED KINGDOM','WF3 2DD','01924871995','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 00:03:16',0,NULL,3,1,3,1,'RA184528256CN ','hutongstore'),(25356,808185453001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','leoniephoto','leoniephoto@gmail.com','Leonie Roy','5055 Marie-Guyart','Trois-Rivieres','QC','CANADA','G8Y 7E6','(819) 668-5555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 00:03:39',0,NULL,3,1,17,0,'RA184528171CN ','hermeshine'),(25357,852842875002,120568574354,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',8.79,'hermeshine','leoniephoto','leoniephoto@gmail.com','Leonie Roy','5055 Marie-Guyart','Trois-Rivieres','QC','CANADA','G8Y 7E6','(819) 668-5555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 00:03:41',0,NULL,3,1,3,1,'RA184528171CN ','hermeshine\r反光板支架  1\r反光板 60cm 2合1  1'),(25358,852855389002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','drgueh2009','drgueh@comcast.net','david  r. gueh','522 Foster St<br>Unit A','philadelphia','PA','UNITED STATES','19116','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 00:53:20',0,NULL,3,1,3,1,'RA184528185CN ','hermeshine'),(25359,808197669001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','greekrossiya','greek64@yandex.ru','Андрей Лукьянченко','ул. Шелехова, дом 15, кв. 3','Елизово','','RUSSIAN FEDERATION','684005','+7 914 6243571','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 01:05:18',0,NULL,3,1,5,1,'CP246990151CN ','hermeshine\r黑加白'),(25360,852874899002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','petitessoeurs06','marlene_b13@hotmail.com','Nicole Braquet','Lotissement les Templiers<br>1625 route de Nice','Aspremont','Provence-Alpes-Côte d\'Azur','FRANCE','06790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 01:41:36',0,NULL,3,1,3,1,'RA184528199CN ','hermeshine\r欧标'),(25361,940463922016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',2,'AA1310',7.56,'hutongstore','mandos_bs','bserem@gmail.com','VASILIOS SEREMETIS','ANAPAYSEOS 5','RIO','AXAIAS','GREECE','26504','(+30)6997047042','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 01:51:41',0,NULL,3,1,11,1,NULL,'hutongstore'),(25362,852881183002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 02:01:18',0,NULL,3,1,3,1,'RA184528208CN ','hermeshine\r110V'),(25363,8881330999701602,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail [AKT056]',1,'AKT056',50,'aliexpress','1007167712 ','doctor-kucherov@yandex.ru','Valery Kucherow','polini-osipenko 16, kv 5','Volgograd','Volgograd','RUSSIAN FEDERATION','400081','79173386525',NULL,NULL,NULL,'2012-03-06 02:08:21',0,NULL,3,1,3,1,'RA184528450CN ','速卖通'),(25364,8881331000555841,111,'mptbranco@gmail.com',1,'AD1198',32.99,'hermeshine','marcosptbranco ','mptbranco@gmail.com','marcos paulo teixeira branco','estrada do cafundá, 1757 - bloco 10, apartamento 202','rio de janeiro  - rio de janeiro','rio de janeiro  - rio de janeiro','BRAZIL','22725030','',NULL,NULL,NULL,'2012-03-06 02:22:35',0,NULL,8,1,17,0,NULL,''),(25365,8881331000622648,111,'New Hairlight Heavy Duty photostudio boom arm',1,'AE1301',29.99,'hermeshine','marcosptbranco ','mptbranco@gmail.com','marcos paulo teixeira branco','estrada do cafundá, 1757 - bloco 10, apartamento 202','rio de janeiro  - rio de janeiro','rio de janeiro  - rio de janeiro','BRAZIL','22725030','',NULL,NULL,NULL,'2012-03-06 02:23:42',0,NULL,4,0,3,0,NULL,'斜臂   1\r伞式柔光箱 80cm 8角    1\r需要加$8运费，已发信'),(25366,852900821002,120593061649,'New Pro Photo Vest for all DSLR fans Mesh-line Size: XL',1,'AA1102',27,'hermeshine','davesitemsnewandused','cuscunad@gmail.com','Dave Cuscuna','51 Hunting St','Malden','MA','UNITED STATES','02148-4513','(781) 888-4054','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 03:03:16',0,NULL,3,1,1,1,'LK227097153CN ','hermeshine\rXL 已入库'),(25367,960431008015,250600509488,'Camera Body and Rear Lens Cap for NIKON - NEW',1,'AA1314',2.2,'hutongstore','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 03:19:29',0,NULL,3,1,17,0,'RA184528123CN ','hutongstore'),(25368,940496857016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 03:19:29',0,NULL,3,0,3,1,'RA184528123CN ','hutongstore\r机身盖/镜头后盖  Nikon  1\r摄影背心 黑色厚 无字3XL  1\r已入库'),(25369,8881331004919863,111,'NIKON 镜头盖 62mm',1,'AA1306',0,'hermeshine','shs-records1','shs-records@yandex.ru','Mihail Shahov','Srednya 11 kv 3','Vologda','Vologodskaya oblast','RUSSIAN FEDERATION','160002','',NULL,NULL,NULL,'2012-03-06 03:35:19',0,NULL,3,1,3,1,'RA184528137CN ',NULL),(25370,852914670002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','namra_48','nonoy_adr@yahoo.com','ARMAN D. RAVENA','117-E. Reyes Ave.','Estancia, Iloilo','','PHILIPPINES','5017','0333970618','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 03:46:05',0,NULL,3,1,3,1,'RA184528145CN ','hermeshine\r澳转美标'),(25371,875747533017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.38,'photographyacc','lennyau','len.willemsen46@bigpond.com','Len Willemsen','P O Box 10071','PINES FOREST','Victoria','AUSTRALIA','3200','0413741444','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-06 04:07:43',0,NULL,3,1,2,1,'30124228024\r ','photographyacc'),(25372,8881331008785850,111,'方镜普通托架（三槽）',1,'',0,'hermeshine','3801adrian','ackrem@yahoo.com.au','a krempin','52 the ridgeway','bolton point','New South Wales','AUSTRALIA','2283','0249595586',NULL,NULL,NULL,'2012-03-06 04:39:45',0,NULL,3,0,3,1,'RA184528154CN ',NULL),(25373,852936380002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','jualkegua','jeffereymin@yahoo.com','Harianto Djong','7839 Jellico Ave','Northridge','CA','UNITED STATES','91325-4336','(818) 428-8119','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 05:16:26',0,NULL,3,1,3,1,'RA184528295CN ','hermeshine'),(25374,940538770016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','eph.k','ephemeral.k@gmail.com','Kam See Hoon','17 Kovan Road #06-08','default','','SINGAPORE','548190','(65) 63843882','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 05:41:44',0,NULL,3,1,11,1,NULL,'hutongstore'),(25375,852943027002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',5,'AA1205',11,'hermeshine','dppphoto','dppphotography@me.com','Tighes Hill Photography','2/25 Kings Rd','Tighes Hill','New South Wales','AUSTRALIA','2297','0411772677','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 05:48:55',0,NULL,3,1,3,1,'RA184528358CN\r ','hermeshine'),(25376,8881331015083143,111,'伞式柔光箱 80cm 8角 ',1,'',0,'hutongstore','cherrymosh','sehrish01@hotmail.com','Sehrish Amir','2/4 lake boga ave','deer park','Victoria','AUSTRALIA','3023','0383485165',NULL,NULL,NULL,'2012-03-06 06:24:43',0,NULL,5,0,18,0,NULL,NULL),(25377,808296306001,110532007068,'67mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1307',2.6,'hermeshine','mscortes','meagancortes@yahoo.com','Meagan Cortes','2842 Renee Dr','West Palm Beach','FL','UNITED STATES','33409-5133','(561) 667-8584','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 07:20:06',0,NULL,3,1,1,1,'LK227273520CN ','hermeshine'),(25378,808305474001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','jgardiazabal','jose@gardiazabal.com','Jose Francisco Gardiazabal Schilling','Georgenstr. 109','München','','GERMANY','80798','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 08:03:24',0,NULL,3,1,3,1,'RA184528344CN\r ','hermeshine'),(25379,875807799017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',28.49,'photographyacc','rabie-photography','crash_30@hotmail.com','Rabie Al-Buraiky','P.O.Box: 105898<br>Auckland City Postshop','Auckland','Auckland','NEW ZEALAND','1143','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-06 08:46:32',0,NULL,3,1,3,1,'RA184528335CN\r ','photographyacc'),(25380,808322216001,110407021410,'For Canon 70-300mm 70-300 DO IS ET-65B Lens Hood New',1,'AA3402',10.2,'hermeshine','teefer75','trent.steer@rockingham.wa.gov.au','Trent Steer','11 Vila Do Porto Crescent','Secret Harbour','Western Australia','AUSTRALIA','6173','0895280382','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 09:15:48',0,NULL,3,1,11,1,NULL,'hermeshine'),(25381,940597302016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','reni_ni','renini@gmail.com','Nadia Steenhouwer','Blancefloerstraat 6','Rotterdam','','NETHERLANDS','3077LR','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 09:23:35',0,NULL,3,1,11,1,NULL,'hutongstore'),(25382,852991744002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',3,'AA3408',29.97,'hermeshine','beagledenis','rodesia@q-net.net.au','denis taylor','7 dower st','mandurah','Western Australia','AUSTRALIA','6210','0895354638','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 09:32:07',0,NULL,3,1,3,1,'RA184528463CN ','hermeshine\r发四个'),(25383,808332148001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','torgash2000','tezikovka2000@yahoo.com','Mikhail Niyzov','10250 62nd Rd<br>Apt 3E','Forest Hills','NY','UNITED STATES','11375-1011','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-06 09:55:28',0,NULL,3,1,3,1,'RA184528548CN ','hermeshine'),(25384,958926311015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','dscdsc123','david@synthservice.com','David Croft','Unit 1<br>30 Gorst Road','London','London','UNITED KINGDOM','NW10 6LE','07854283949','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 10:01:26',0,NULL,3,1,11,1,NULL,'hutongstore'),(25385,852962790002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','mrflan999','qatarsky@hotmail.com','Hamad Abdulla','P.O. Box 8278','Doha','QATAR','QATAR','974','9745834308','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:31:54',0,NULL,3,1,8,1,'CP246990298CN\r ','hermeshine\r按运费算的航空大包可以到'),(25386,853002790002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','karmannghia1961','a.chetcuti@hotmail.com','Albert Chetcuti','11/37-39 Lane Street','Wentworthville','New South Wales','AUSTRALIA','2145','0298453028','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:15:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(25387,808342436001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','elena230464orlova','elenaorlova@yahoo.it','Elena Orlova','Háberg3','Reykjavik','','ICELAND','111','+35482319 36','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:35:09',0,NULL,3,1,11,1,NULL,'hermeshine'),(25388,853011755002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','paleaeroplane','paleaeroplane@yahoo.com.au','Mathew Joshua','4 LANJAK PLACE','TANAH MERAH','Queensland','AUSTRALIA','4128','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 10:46:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(25389,960567742015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','goldenflameneil','topsy19@sky.com','neil turvill','22.dinham court<br>     dinham road','      new milton','Hampshire','UNITED KINGDOM','bh25 5xr','01425638712','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 11:01:32',0,NULL,3,1,3,1,'RA184528551CN ','hutongstore'),(25390,853021886002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 11:24:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(25391,853025705002,120762404074,'600w Photography Lighting Kit 45w bulbs 110cm umbrella',1,'AKT078',90,'hermeshine','jinordnes','sendron@gmail.com','Jon Inge Nordnes','Kjellengveien 18','Tonsberg','Vestfold','NORWAY','3125','4791783359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 11:39:56',0,NULL,3,1,5,1,'CP246990253CN\r ','hermeshine\r申报$30  \r欧标'),(25392,808374954001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','eugenybanin','john_jester@mail.ru','Evgeny Banin','Chertygasheva 131-119','Abakan','Khakassia','RUSSIAN FEDERATION','655017','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 12:32:41',0,NULL,3,1,5,1,'CP246990267CN\r ','hermeshine\r黑加白'),(25393,808375262001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','wisky_studio','wisky@wisky.ru','Andrey Guryanov','Melnikova 20/1 - ap.12','Kirov','','RUSSIAN FEDERATION','610006','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 12:35:17',0,NULL,3,1,11,1,NULL,'hermeshine'),(25394,807978704001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',39.99,'hermeshine','nailuj33','jmiguezb@hotmail.com','Julian Miguez','Evaristo Lillo 29 Dpto 177','Santiago','Las Condes','CHILE','7580123','(569) 824-2719','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 12:48:55',0,NULL,3,1,3,1,'RA184528534CN ','hermeshine\r58-58mm 双阳环  1\r老款佳能M  1\r已入库'),(25395,853048615002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','menquian','o_galan@terra.es','Maria Osuna Galán','C/ Hermanos Machado, 4-1º Izq.','Puerto Rosario (Las Palmas)','Canarias','SPAIN','35600','677730318','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 12:56:48',0,NULL,3,1,3,1,'RA184528525CN ','hermeshine'),(25396,960621860015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','don_marx','marx37@gmx.at','Markus Rubasch','Semmelweisstraße 60','Linz','','AUSTRIA','4020','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 13:22:58',0,NULL,3,1,3,1,'RA184528517CN ','hutongstore'),(25397,940691383016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','jjkkjack','jackwalker12@hotmail.co.uk','Gary Walker','24 Barnard Close<br>Gorleston','Great Yarmouth','Norfolk, England','UNITED KINGDOM','NR31 7RN','0796350332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 13:49:37',0,NULL,3,1,3,1,'RA184528605CN ','hutongstore'),(25398,815116271018,280689694480,'New Continuous Lighting System umbrella with bulbs',1,'AKT068',109.5,'photographyacc','lalani_bay','lalani.ekanayake@gmail.com','Lalani Ekanayake','143, Vihara Mawatha<br>Mulgampola','Kandy','','SRI LANKA','20000','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-06 14:32:34',0,NULL,3,1,8,1,'CP246990236CN\r ','photographyacc\r按运费算航空大包到\r欧标和英标都给放上'),(25399,853091201002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','jm1258','jmichaelanderson5@hotmail.com','JERRY MICHAEL ANDERSON','PO Box 104<br>Brookside Village Otsego Bottom Road','mullens','WV','UNITED STATES','25882-0104','','NoPaymentFailure','CheckoutComplete','Other','2012-03-06 15:00:28',0,NULL,3,0,1,1,'LK227984961CN ','hermeshine\r3XL 已入库'),(25400,808426752001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','eladher81','eladher@gmail.com','elad herskovici','volfson 16/6','nahariyya','nahariyya','ISRAEL','22400','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 15:10:44',0,NULL,3,1,11,1,NULL,'hermeshine'),(25401,808443707001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','malsm61','tatsyzran@yandex.ru','Сергей Малов','п.Варламово, ул.Южная 1-32','Сызранский район','Самарская область','RUSSIAN FEDERATION','446073','+7(927)6106440','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 15:53:55',0,NULL,3,1,3,1,'RA184528653CN ','hermeshine'),(25402,808480513001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','gonzalez664','gonzalez664@hotmail.com','Jose Manuel Gonzalez Sanchez','Miguel de Unamuno nº63 apt 403','Nueva Andalucia Marbella','Málaga','SPAIN','29660','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 17:18:53',0,NULL,3,1,3,1,'RA184528327CN ','hermeshine'),(25403,808493000001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','kverna1987','kverna@gmail.com','Anders Kverneng','Holmestrandsveien 22','Drammen','Buskerud','NORWAY','3041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 17:44:32',0,NULL,3,1,3,1,'RA184528640CN ','hermeshine'),(25404,960755952015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','szofo72','traveler72@freemail.hu','Ferenc Szarvas','Böszörményi út 180.','Debrecen','','HUNGARY','4032','0036302808606','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 17:50:49',0,NULL,3,1,5,1,'CP246990284CN\r ','hutongstore\r+1.6*2.1 白色布\r申报gift'),(25405,960769372015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','viggoness','ness.viggo@gmail.com','Viggo Næss','Åråsveien. 14<br>Apartment number 207','Kjeller','','NORWAY','2007','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 18:12:49',0,NULL,3,1,3,1,'RA184528636CN ','hutongstore'),(25406,940859945016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','dkjellgr','dave@djswedish.com','David Kjellgren','5 Harrisons Rise, waddon','Croydon','London','UNITED KINGDOM','CR04LL','07956191143','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 19:05:00',0,NULL,3,1,3,1,'RA184528375CN ','hutongstore'),(25407,808543899001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','marekic','mbaksa@gmail.com','Mario Baksa','R. Boskovica 7A<br>Selnik','Ludbreg','CROATIA','CROATIA','42230','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-06 19:19:01',0,NULL,3,1,3,1,'RA184528389CN ','hermeshine\r欧标'),(25408,940891110016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','para0033','gerard@dzpictures.co.uk','Gerard Farrell','11a Wykeham Road','Farnham','Surrey','UNITED KINGDOM','GU9 7JR','07831396923','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-06 19:47:01',0,NULL,3,1,4,1,'YW870146866CN\r ','hutongstore'),(25409,960853593015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','la-malle-aux-tresors0609','la-malle-aux-tresors@hotmail.fr','kétline Schmitt','144 Rue des cordeliers','Moyenneville','Picardie','FRANCE','60190','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 20:06:23',0,NULL,3,1,3,1,'RA184528392CN ','hutongstore'),(25410,938616138016,260768455534,'New 58mm Lenscap for Canon Lens Snap-on 58  Front Cap',1,'AA1301',1.87,'hutongstore','jon.wide.73','jon.wide@gmail.com','Jon Wide','Nygatan 53','Norrköping','Östergötland','SWEDEN','60234','0046733525977','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 20:06:40',0,NULL,3,1,11,1,NULL,'hutongstore'),(25411,940928947016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','benzle81','benny.mansfield@googlemail.com','Benny Mansfield','Fir Tree Barn, Crownland Rd<br>Walsham-Le-Willows','Bury St. Edmunds','Suffolk','UNITED KINGDOM','IP31 3BX','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 20:37:00',0,NULL,3,1,11,1,NULL,'hutongstore\r接口环换成67mm 的\r已入库'),(25412,853262128002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','mtjd1998','mtjd1998@yahoo.com','Marvin Singletary Jr','1007 Eastwood Dr','Wingate','NC','UNITED STATES','28174-7202','(704) 233-9172','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-06 20:43:46',0,NULL,3,1,1,1,'LK227970931CN ','hermeshine'),(25413,960891806015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','minmyatwin0208','minmyatwin@yahoo.com','M Myat','32 Bridges Court<br>Beldam Way','Hounslow','Middlesex','UNITED KINGDOM','TW3 3FR','07904070760','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 20:57:22',0,NULL,3,1,11,1,NULL,'hutongstore'),(25414,853282646002,120539720851,'New Professional Hot Shoe hotshoe Cover Cap for Sony ',1,'AA1205',2.2,'hermeshine','lynyrdpb','peebooo@mac.com','Pierre BOUSSAC','Chez Marie Laure ABAD<br>Le Château','Pont en Royans','Rhône-Alpes','FRANCE','38680','0628237770','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 21:18:55',0,NULL,3,1,11,1,NULL,'hermeshine'),(25415,960915425015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','digimist','richard.digimist@gmail.com','Richard Clark','54 Beaufoy Terrace','Dover','Kent','UNITED KINGDOM','CT17 0HS','01304332095','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 21:29:09',0,NULL,3,1,3,1,'RA184528401CN ','hutongstore'),(25416,815344817018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','blez7','sgreffe@gmail.com','Steven Greffe','458 Tallebudgera Creek RD','Tallebudgera','Queensland','AUSTRALIA','4228','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-06 21:48:50',0,NULL,3,1,11,1,NULL,'photographyacc'),(25417,960586314015,250621654557,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box',1,'AC2403',20,'hutongstore','aussieitgirl','jongpilee@hotmail.com','Jongpil Lee','27 Tagell Road','Heathmont','Victoria','AUSTRALIA','3135','0413102614','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 22:36:42',0,NULL,3,1,17,1,'YW870146855CN\r ','hutongstore'),(25418,939003165016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','aussieitgirl','jongpilee@hotmail.com','Jongpil Lee','27 Tagell Road','Heathmont','Victoria','AUSTRALIA','3135','0413102614','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 22:39:16',0,NULL,3,1,4,1,'YW870146855CN\r ','hutongstore\r圆形柔光棚 60cm  1\r灯架  2m  1\r斜臂   1\r闪光的柔光箱   60cm  1'),(25419,941020717016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','lewin5829','m5astt@yahoo.co.uk','michael lewin','38 vernon drive Harefield','uxbridge','Middlesex','UNITED KINGDOM','ub9 6eg','01895824500','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-06 23:09:58',0,NULL,3,1,11,1,NULL,'hutongstore'),(25420,960980688015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','16046941','yur9516@yandex.ru','Юрий Поляков','ул.Bar-ilan д.38 кв.3','Bat-Yam','','ISRAEL','59589','0528391763','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-06 23:28:05',0,NULL,3,1,11,1,NULL,'hutongstore'),(25421,808676164001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','katherinepklyce','kklyce@katherinepklyce.biz','Katherine Klyce','140 W 124th ST<br>Apt 9B','New York','NY','UNITED STATES','10027-4973','(212) 222-3825','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-06 23:54:28',0,NULL,3,1,3,1,'RA184528313CN ','hermeshine'),(25422,853337793002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',2,'AD1186',59.98,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-06 23:26:27',0,NULL,3,1,3,1,'RA184528905CN\r ','hermeshine'),(25423,808686188001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','lambdajax','lambda@laposte.net','pascal fradet','12, rue de Belgrade','Grenoble','Rhône-Alpes','FRANCE','38000','0476501022','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 00:23:57',0,NULL,3,1,3,1,'RA184528582CN ','hermeshine'),(25424,853369600002,120753012100,'New Official Original Nikon Photo Vest D300 D90 Size L ',1,'AD1160',42,'hermeshine','fujite43','renokar@cgocable.ca','Renaud Guerin','64a Jean-Talon','Salaberry de Valleyfield','QC','CANADA','J6S 3H7','(450) 371-4234','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 01:01:56',0,NULL,3,1,17,0,'RA184528596CN ','hermeshine'),(25425,808697983001,110718665736,'Official Original Nikon Photo Vest D300 D90 Size XL ',1,'AD1161',42,'hermeshine','fujite43','renokar@cgocable.ca','Renaud Guerin','64a Jean-Talon','Salaberry de Valleyfield','QC','CANADA','J6S 3H7','(450) 371-4234','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 01:05:28',0,NULL,3,1,3,1,'RA184528596CN ','hermeshine\rnikon 原厂摄影背心 网眼 L  1\rnikon 原厂摄影背心 网眼 XL  1'),(25426,808698378001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','tirednthirstee','beatbox818@hotmail.com','Daniel Cristerna','13020 Kagel Canyon St','Pacoima','CA','UNITED STATES','91331-3216','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-07 01:07:38',0,NULL,3,1,1,1,'LK227989204CN ','hermeshine'),(25427,8881331085652698,111,'Free shipping & tracing # - Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs - Wholesale/ Retail AE2201',2,'AE2201',69.98,'aliexpress','1007207057','kinopravda2010@gmail.com','Alexey Yakovlev','ul. Frunze 93-138','Ekaterinburg ','Sverdlovskaya oblast','RUSSIAN FEDERATION','620144','79222091518',NULL,NULL,NULL,'2012-03-07 02:00:52',0,NULL,3,1,5,1,'CP246990341CN\r ','速卖通\r欧标 '),(25428,808724349001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','samal9497','sam-al@sympatico.ca','Claude Deschenes','27 Meunier','Saint-Constant','QC','CANADA','J5A 1R3','(450) 632-3537','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 02:36:10',0,NULL,3,1,11,1,NULL,'hermeshine'),(25429,853409617002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','toxified_blood','egtparas@gmail.com','Edgar Paras','5/20 Gordon Street<br>Milton','Brisbane','Queensland','AUSTRALIA','4064','0416049761','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 03:04:05',0,NULL,3,1,3,1,'RA184528361CN ','hermeshine\r放fragile 标签'),(25430,629098663003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','for_travel','okislinger@hotmail.com','oscar kislinger','Jiron Apurimac 626, Apartado 23','cajamarca','CAJAMARCA','PERU','cajamarca','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 03:22:48',0,NULL,3,1,5,1,'CP246990275CN\r ','hermeshine'),(25431,876284128017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',4.83,'photographyacc','twoblockssouth','anada_shorti@hotmail.com','Aaron Balido','7 Mabuhay Grove<br>Mount Druit','Sydney','New South Wales','AUSTRALIA','2770','0415929248','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 03:27:44',0,NULL,3,1,11,1,NULL,'photographyacc'),(25432,876306414017,270748624133,'New Photo Studio Light Stand Umbrella Bulb Socket Set ',1,'AKT061',37.05,'photographyacc','pangitpete','peterbirtles@yahoo.com.au','Peter Birtles','3 Weigall Street','Barraba','New South Wales','AUSTRALIA','2347','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 04:48:21',0,NULL,3,1,3,1,'RA184528579CN ','photographyacc\r2单反  1   澳标'),(25433,853440462002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','mers124','romchyk1984@mail.ru','Roman','9755 89th Ave N','Maple Grove','MN','UNITED STATES','55369-4038','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 04:59:40',0,NULL,3,1,3,1,'RA184528622CN ','hermeshine'),(25434,808763397001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','trieudungchi','tcdungcm@gmail.com','Trieu Chi Dung','Marikoji Kaikan, #404<br>6-2 Yoshida izumidono-cho, Sakyo-ku','Kyoto','Kyoto','JAPAN','606-8301','(81) 80 3845 9607','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 05:08:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(25435,808771179001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','tahls13','tahlia_russell13@hotmail.com','Tahlia Russell','2/63<br>Armagh street','Perth','Western Australia','AUSTRALIA','6100','0415091313','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 05:50:10',0,NULL,3,1,3,1,'RA184528565CN ','hermeshine'),(25436,808787680001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','rexxluna','rexluna@gmail.com','sean fau-burnitz','531 1/2 N Serrano Ave','Los Angeles','CA','UNITED STATES','90004-2765','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 07:15:21',0,NULL,3,1,1,1,'LK228121401CN ','hermeshine'),(25437,808791319001,110417004756,'Nikon-52mm Macro Reverse Adapter Ring For D40 D80 D300',1,'AA1210',3.58,'hermeshine','pjlinvestigations','peterlynch@pjlinvestigations.com.au','Peter Lynch','20 Cromwell St','Adelong','New South Wales','AUSTRALIA','2729','0417260650','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 07:33:00',0,NULL,3,1,11,1,NULL,'hermeshine'),(25438,8881331106028665,111,'New Photo Studio Background Support 3m x 2.4m +Free Backdrop(1.6m X 4m backdrop) + Free Carry bag - Wholesale/ Retail AD1183',1,'AD1183',100,'aliexpress','Jouko Hokajärvi','jouko.hokajarvi@gmail.com','Jouko Hokajärvi','Kuuselantie 5','Kempele ','','FINLAND','90450','',NULL,NULL,NULL,'2012-03-07 07:40:28',0,NULL,3,1,4,1,'YW870146914CN\r ','C里面布换成1.6m X 4m 白色 \r确认一下地址，先不要打单子\r速卖通线下交易，发货后通过tradermannager告诉客户单号.在buyer分组里\rJouko Hokajarvi \rKuuselantie 5 \r90450 Kempele \rFinland\r地址没错\r\r'),(25439,808792811001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','sandro8686','ninelandrusco@gmail.com','Kirilici Roman','1Mai 7A/64 str.','Balti','MDA','MOLDOVA, REPUBLIC OF','3129','0000000','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 07:42:07',0,NULL,3,1,5,1,'CP246990307CN\r ','hermeshine\r黑加白'),(25440,815548176018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','akin7416','angel_hellraiser@live.com','Adrianne king','11/15 bourke street','waterford west','Queensland','AUSTRALIA','4133','0415366659','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 09:28:41',0,NULL,3,1,11,1,NULL,'photographyacc\r白色'),(25441,876373373017,270767170462,'100% Cotton Photo Vest for Sony a200 a300 a700 a900user',1,'AA2113',28.49,'photographyacc','mgeezerbloke','mgeezerbloke@aol.com','MARTYN GARDNER','32 BEVERLY WAY','RAMSGATE','Kent','UNITED KINGDOM','CT126DN','01843596103','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 09:34:19',0,NULL,3,0,3,1,'RA184528812CN\r ','photographyacc\r3XL 已入库'),(25442,853501425002,120767298141,'16chan Wireless Remote Control Cord for Nikon D90 D7000',1,'AD1178',18.5,'hermeshine','marluck','marekl@konceptcorp.com','Marek Luckos','705 Western St','Hoffman Estates','IL','UNITED STATES','60169-3026','(847) 809-5214','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 09:39:08',0,NULL,3,1,1,1,'LK228609097CN\r ','hermeshine'),(25443,852238745002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','thebestoldthings','yuriy8754@gmail.com','Yurij Gupalo','Naukova st. 12/26','Lviv','UA','UKRAINE','79053','38-063-688-0-886','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 09:42:08',0,NULL,3,1,11,1,NULL,'hermeshine'),(25444,876383181017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','mikisings','erinlsmith87@gmail.com','Erin Smith','13 Sand Street','Kingscliff','New South Wales','AUSTRALIA','2487','0427374617','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 10:10:39',0,NULL,3,1,11,1,NULL,'photographyacc'),(25445,815574691018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','so-good-goods','ebaykaew@gmail.com','Sukaew Sirithong','841/9 Phrannok Rd., Banchanglor<br>Bangkoknoi','default','BA','THAILAND','10700','66817706838','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 11:00:32',0,NULL,3,1,11,1,NULL,'photographyacc'),(25446,961208417015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','pawnster413','omid@massali.net','Omid Massali','Övre Slottsgatan 11A<br>Övre Slotts','Uppsala','Uppland','SWEDEN','75312','0736546522','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 11:07:17',0,NULL,3,1,3,1,'RA184528928CN ','hutongstore'),(25447,808853511001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 11:38:34',0,NULL,8,1,17,0,NULL,'hermeshine'),(25448,808853236001,110790875316,'New Professional Portable Diffuser for SpeedLight sb900 sb700 580ex metz XL ',1,'AD1210',12.99,'hermeshine','tomis.ales','tomis.ales@azet.sk','Ales Tomis','Holubyho 351/25','Stara Tura','','SLOVAK REPUBLIC','91601','421327763072','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 11:38:35',0,NULL,3,1,3,1,'RA184528826CN\r ','hermeshine\r反光板支架的夹子（双轮）   1\rlif通用柔光罩XL     1'),(25449,853462072002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',3,'AO0005',54,'hermeshine','i.salomandra','skiffin@mail.ru','Вячеслав Давыденко','ул. Вербная д.8 кв.114','Красноярск','','RUSSIAN FEDERATION','660041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 11:40:38',0,NULL,3,1,3,1,'RA184528830CN\r ','hermeshine\r1.6x3m    3\r1 - White\r1 - Blue\r1 - Gray'),(25450,941262037016,260933198603,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'hutongstore','labgeardog','kaporeagebora@googlemail.com','M Roberts','35 Main Road<br>Hambleton','Selby','North Yorkshire','UNITED KINGDOM','YO8 9HW','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-07 11:31:26',0,NULL,3,1,11,1,NULL,'hutongstore'),(25451,853350020002,120526192319,'NEW 72mm Snap-on Front Lens Cap for Canon 72 Lenscap',2,'AA1303',5.2,'hermeshine','babulisan','ibirinc1@seiris.de','Seiris GmbH','Wiesenstrasse 51','Düsseldorf','','GERMANY','40549','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 12:02:31',0,NULL,3,0,17,0,NULL,'hermeshine'),(25452,876423444017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',17.1,'photographyacc','gavinkelly68brisbane','gavin@brisbanekellys.com','Emma Kelly','4 Yaringa street','Manly West','Queensland','AUSTRALIA','4179','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 12:14:03',0,NULL,3,1,3,1,'RA184528843CN\r ','photographyacc'),(25453,815598367018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',28.49,'photographyacc','dakotadc3','dakotahallett@mail.com','Dakota Hallett','15 Greenvale Close','Smithfield','Queensland','AUSTRALIA','4878','0740383345','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 12:23:48',0,NULL,3,1,3,1,'RA184528857CN\r ','photographyacc\rXL'),(25454,961245262015,250610576198,'Photo Studio Background Support (2m×2m)+ Free Backdrop',1,'AO0009',39.9,'hutongstore','greendale9061','lui_kate@hotmail.com','Kate Lui (Chi Yip Ltd)','Treasure House, Greenside Way<br>Middleton','Manchester','Lancashire','UNITED KINGDOM','M24 1SW','07818898898','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-07 12:41:14',0,NULL,3,1,17,0,'YW870146936CN\r ','hutongstore'),(25455,941288708016,260833542494,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',120,'hutongstore','greendale9061','lui_kate@hotmail.com','Kate Lui (Chi Yip Ltd)','Treasure House, Greenside Way<br>Middleton','Manchester','Lancashire','UNITED KINGDOM','M24 1SW','07818898898','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-07 12:41:15',0,NULL,3,1,4,1,'YW870146936CN\r ','hutongstore\rc以外再发：\r背景架2mx2m  + 3个夹子   1\r白布\r泡重11.8  实重9.7'),(25456,876205324017,270748932729,'New Eyepiece EyeCup for Canon EB 5DII 50D 40D 60D 7D',1,'AA1202',2.76,'photographyacc','babulisan','ibirinc1@seiris.de','Seiris GmbH','Wiesenstrasse 51','Düsseldorf','','GERMANY','40549','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-07 12:18:02',0,NULL,3,0,11,1,NULL,'photographyacc\rCANON 镜头盖  72mm   2\r眼罩 40D/50D     1'),(25457,853564840002,120539340436,'New 77mm ring adapter replacement for cokin P series',10,'AA2214',21.8,'hermeshine','ex_focus','behnk@omnipress.de','Behnk / Zimmermann','Bebelstrasse 94','Stuttgart','','GERMANY','70193','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 13:17:15',0,NULL,3,1,3,1,'RA184528769CN\r ','hermeshine'),(25458,853577550002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',5,'AA2322',36,'hermeshine','todsapon','suwapanont@hotmail.com','Todsapon Suwapanont','555/104 Thongpracha condo<br>Prachauthid road.  Samsennork','Huaykwang','Bangkok','THAILAND','10310','+66 81 7386004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 13:52:44',0,NULL,3,1,3,1,'RA184528772CN\r ','hermeshine'),(25459,808897559001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','cscot2u','owner@kelowna-website-design.com','Chris Scott','1332 Alder Ct.','Kelowna','BC','CANADA','V1Y 3P9','(250) 762-9132','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 13:55:46',0,NULL,3,1,3,1,'RA184528786CN\r ','hermeshine'),(25460,815645767018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',4.08,'photographyacc','elizjad77','nika7@live.com.au',' Nicole Ashton','13 Bendee Dr','Atwell','Western Australia','AUSTRALIA','6164','0422484386','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-07 14:29:24',0,NULL,3,1,11,1,NULL,'photographyacc'),(25461,808912485001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','albertang2010','amktang238@aol.com','Albert Tang','68 Nob Hill Dr','ELMSFORD','NY','UNITED STATES','10523','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 14:37:44',0,NULL,3,1,1,1,'LK228604545CN\r ','hermeshine'),(25462,853597006002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','tseworldtreasures','marinezinck@aol.com','Tye Zinck','76 Melanson Lane','Brookside','NS','CANADA','B3T 2K9','(902) 850-2854','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 14:46:57',0,NULL,3,0,3,1,'RA184528790CN\r ','hermeshine\r白色'),(25463,957381340015,250692236407,'Continuous Lighting System soft box photography studio',1,'AKT016',70.99,'hutongstore','elskanbaby','heather@elskanbaby.com','Heather Sosbee','678 Sabrina Ter','Ramona','CA','UNITED STATES','92065-2345','(760) 788-0204','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 15:29:06',0,NULL,3,1,5,1,'CP244455519CN\r ','hutongstore\rc以外再加 45w 灯泡  （220v）   2\r英标\r新地址： \rHeather\rSosbee\rHoltagerdi 62\rKopavogur, NA \r200\rIceland'),(25464,961335037015,250939066207,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm Strong',1,'AD1163',18,'hutongstore','sexybear01','adele.rudland@hotmail.co.uk','ADELE RUDLAND','11 PLOVER GARDENS<br>CROSSGATES','SCARBOROUGH','North Yorkshire','UNITED KINGDOM','YO12 4TS','01723862461','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 15:57:27',0,NULL,3,1,3,1,'RA184528675CN\r ','hutongstore'),(25465,961342773015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','jfvision2012','jfvision@hotmail.co.uk','Joaquim Fortunato','Banister House','London','London','UNITED KINGDOM','E9 6BN','02085334635','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 16:11:08',0,NULL,3,0,11,1,NULL,'hutongstore'),(25466,634789750004,140679559505,'Promotion ! NEW Square Gradual Graduated Brown Color Filter for Cokin P Series',1,'AD1227',3.5,'hermeshine','reem8928','maryam8928@yahoo.com','Maryam Abubaker','AlZahara','Ajman','','UNITED ARAB EMIRATES','26626','00971506311033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:12:15',0,NULL,3,1,17,0,NULL,'hermeshine'),(25467,853659810002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','reem8928','maryam8928@yahoo.com','Maryam Abubaker','AlZahara','Ajman','','UNITED ARAB EMIRATES','26626','00971506311033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:12:16',0,NULL,3,1,17,0,NULL,'hermeshine'),(25468,853656222002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','reem8928','maryam8928@yahoo.com','Maryam Abubaker','AlZahara','Ajman','','UNITED ARAB EMIRATES','26626','00971506311033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:12:16',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变棕     1\rNIKON 镜头盖 52mm  1\r绿叶 UV  52mm   1'),(25469,808980391001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','reem8928','maryam8928@yahoo.com','Maryam Abubaker','AlZahara','Ajman','','UNITED ARAB EMIRATES','26626','00971506311033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 17:22:55',0,NULL,3,1,3,1,'RA184528809CN\r ','hermeshine\r\r150-200cm 5in1 反光板    1'),(25470,853654700002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',2,'AA2106',72,'hermeshine','almozel','wencheo@online.no','wenche elita øverland','kyvannsveien 17','trondheim','','NORWAY','7025','(47)93411284','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 17:25:58',0,NULL,3,0,3,1,'RA184528715CN\r ','hermeshine\rXL  已入库'),(25471,853660360002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','lancewants','lancefreelance2@peoplepc.com','anthony moreland','505 Columbus Ave<br>Apt 4A','new york','NY','UNITED STATES','10024-4485','(212) 580-8091','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-07 17:56:46',0,NULL,3,1,1,1,'LK228553058CN\r ','hermeshine'),(25472,961438480015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','the-milster','millerg@blueyonder.co.uk','gary miller','59 stanley gardens','paignton','Devon','UNITED KINGDOM','tq33nx','01803528511','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 18:46:34',0,NULL,3,1,11,1,NULL,'hutongstore'),(25473,941503431016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',3,'AA1302',5.61,'hutongstore','grendelsmum','pdonovan@gofree.indigo.ie','Patrick O Donovan','17, O Connell Avenue<br>Turners Cross','Cork','','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 19:23:22',0,NULL,3,1,11,1,NULL,'hutongstore'),(25474,961453366015,250599421078,'58mm Snap-on Front Cap for Canon 58mm Filters Lens New',2,'AA1301',3.76,'hutongstore','minniemalky','minniemalky@hotmail.com','Geraldine Malcolm','4 Weaver Place, Gardenhall','East Kilbride','Glasgow (City of)','UNITED KINGDOM','G758SH','01355239365','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 19:08:31',0,NULL,3,1,11,1,NULL,'hutongstore'),(25475,961498983015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','genady7337','cerberus@dva.lv','Genadijs Storozenko','A.Biezina 3 - 66','Riga','','LATVIA','LV-1029','+37129745343','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 20:06:11',0,NULL,3,1,11,1,NULL,'hutongstore'),(25476,941536809016,260810137161,'New Flash Shoe Holder Swivel Bracket Umbrella Mount',1,'AD1122',6.5,'hutongstore','nymandribe','nymand91@hotmail.com','Thomas Nielsen','Kollegiebakken 1, 209','Kgs. Lyngby','','DENMARK','2800','+4561689159','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 20:08:11',0,NULL,3,1,11,1,NULL,'hutongstore'),(25477,961506553015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','kompanii','egon.hirvesoo@mail.ee','Egon Hirvesoo','Redise 8-6','Saue vald','','ESTONIA','76401','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 20:18:57',0,NULL,3,1,11,1,NULL,'hutongstore'),(25478,853762913002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','billts1','bthorns@stny.rr.com',' Bill Thorn','42 lakin ave','Jamestown','NY','UNITED STATES','14701','(716) 664-0013','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-07 20:22:07',0,NULL,3,1,1,1,'LK228600190CN\r ','hermeshine'),(25479,961515417015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',22,'hutongstore','andreiestonian67','webfile@hot.ee','Andrei Naleikin','Tallinna mnt. 25-15','Narva','','ESTONIA','20303','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-07 20:27:35',0,NULL,3,1,3,1,'RA184528724CN\r ','hutongstore'),(25480,961549221015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','keep1250','derickgray54@gmail.com','Derick Gray','13 Lochview<br>Ardpeaton, Cove','Helensburgh','Argyll & Bute','UNITED KINGDOM','G84 0PF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-07 21:15:57',0,NULL,3,1,11,1,NULL,'hutongstore'),(25481,961573925015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','razoreye76','razor@getmail.no','Tom Andre Haug','Ravnkollbakken 81','oslo','','NORWAY','0971','+4747810318','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 21:49:22',0,NULL,3,1,5,1,'CP246990315CN\r ','hutongstore\r欧标'),(25482,809109584001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18.99,'hermeshine','mbmoh93160','mbmoh93@gmail.com','Mohamed Bouchadekh','2, place Eugène Thomas','NOISY LE GRAND','Ile-de-France','FRANCE','93160','0615090560','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 21:15:32',0,NULL,3,1,3,1,'RA184528738CN\r ','hermeshine'),(25483,853807692002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','salmanz100','sjaved@orcon.net.nz','Salman Javed','22A Kowhatu Road<br>One Tree Hill','Auckland','Auckland','NEW ZEALAND','1061','64210506526','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 21:52:16',0,NULL,3,1,11,1,NULL,'hermeshine'),(25484,961590382015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','ealpozo','apozomar@gmail.com','Antonio Luis Pozo Marín','Avd José Antonio, 16','Tíjola (Almería)','Andalucía Ceuta y Melilla','SPAIN','04880','649971655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-07 22:17:07',0,NULL,3,1,3,1,'RA184528741CN\r ','hutongstore'),(25485,853826003002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',1,'AD1125',12.99,'hermeshine','euseermide','szaszi-laci@hotmail.com','tomi varga','52 church road, bellbowrie','brisbane','Queensland','AUSTRALIA','4070','0732025919','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-07 22:18:18',0,NULL,3,1,11,1,NULL,'hermeshine'),(25486,809140690001,110807100036,'Promotion ! NEW 3pcs Square ND2+ND4+ND8 Neutral Density Filter Kit for Cokin P',1,'AKT096',13.88,'hermeshine','jonlak','jonlar@shaw.ca','John L. Clarke','P.O. Box 10128<br>5025 Mein Road','108 Mile Ranch','BC','CANADA','V0K 2Z0','(250) 791-9284','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 22:22:12',0,NULL,3,1,11,1,NULL,'hermeshine'),(25487,808724148001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',6,'AE1302',57,'hermeshine','melate8','tonefotos@hotmail.com','Laura Zepeda','Jesus Salido 101 nte<br>entre Obregon y Morelos','Navojoa','Sonora','MEXICO','85830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 22:40:48',0,NULL,3,1,3,1,'RA184528755CN\r ','hermeshine\r客户要单号'),(25488,809150252001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','carlosjimenezzapata','carlos_jimenez_zapata@hotmail.com','CARLOS JIMENEZ ZAPATA','C/ GRANADO, 2 PORTAL 6 - 1ºC','DOS HERMANAS','Andalucía Ceuta y Melilla','SPAIN','41701','655086199','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-07 22:41:47',0,NULL,3,1,3,1,'RA184528667CN\r ','hermeshine'),(25489,853867395002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','rd6lv','ua6lpo@rambler.ru','Andrey Maksimenkov','3/18, ul. Tekstilnaya','Shakhty','Rostovskaya obl','RUSSIAN FEDERATION','346527','7 903 4318129','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 00:16:51',0,NULL,3,1,3,1,'RA184528993CN\r ','hermeshine'),(25490,853872667002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',25,'hermeshine','vfm2012vfm','valerio.vfm@gmail.com','Valério Fábio Moreira','Rua José Neves Cyprestes, 195 - ap. 102 - Jardim da Penha','Vitória','Espírito Santo','BRAZIL','29060-300',' 2732256408','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 00:30:36',0,NULL,3,1,3,1,'RA184528891CN\r ','hermeshine'),(25491,809185912001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',8,'AC1301',49.92,'hermeshine','patzillmann','patriciazillmann@gmail.com','Patricia Zillmann','Rua Doutor Catrambi, 219','Rio de Janeiro','Rio de Janeiro','BRAZIL','20531005','552122687693','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 00:34:48',0,NULL,3,1,3,1,'RA184528980CN\r ','hermeshine'),(25492,809186503001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',8,'AC1301',49.92,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 00:37:44',0,NULL,3,1,3,1,'RA184528945CN\r ','hermeshine'),(25493,961665913015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 01:12:56',0,NULL,3,1,17,0,'CP246990324CN\r ','hutongstore'),(25494,961665405015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 01:11:39',0,NULL,3,1,5,1,'CP246990324CN\r ','hutongstore\r4灯头 灯头 孔     2\r50cmx70cm 的柔光箱 (配4灯头）    2\r欧标'),(25495,941704053016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','sukidog086','fiatritmo@yahoo.ie','colm coogan','67 kilgarron park<br>enniskerry','enniskerry','Wicklow','IRELAND','01','0868478291','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-08 01:33:34',0,NULL,3,1,17,0,'YW870146903CN\r ','hutongstore'),(25496,941705494016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','sukidog086','fiatritmo@yahoo.ie','colm coogan','67 kilgarron park<br>enniskerry','enniskerry','Wicklow','IRELAND','01','0868478291','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-08 01:39:18',0,NULL,3,1,17,0,'YW870146903CN\r ','hutongstore'),(25497,961683075015,250604460502,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',18,'hutongstore','sukidog086','fiatritmo@yahoo.ie','colm coogan','67 kilgarron park<br>enniskerry','enniskerry','Wicklow','IRELAND','01','0868478291','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 02:01:56',0,NULL,3,1,17,0,'YW870146903CN ','hutongstore\r\r'),(25498,961685608015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',16,'hutongstore','sukidog086','fiatritmo@yahoo.ie','colm coogan','67 kilgarron park<br>enniskerry','enniskerry','Wicklow','IRELAND','01','0868478291','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 02:08:24',0,NULL,3,1,4,1,'YW870146903CN ','hutongstore\r2单反  英标   2   \r柔光箱 50-70cm 单灯头   1\r灯架  2m    1\r\r'),(25499,853918128002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','afcbts','surachet_safc@hotmail.com','surachet saroj','100/986 Soi.Subboonchai 18 ,Srinakarin rd. Bangmuang ,','Muang','Samutparkan','THAILAND','10270','+668-9699-6701','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 02:53:12',0,NULL,3,1,11,1,NULL,'hermeshine'),(25500,8881331176379435,111,'Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite ',1,'AD1198',32.99,'hermeshine','thiagoliveira2011','thiagoliveira@terra.com.br','Daiana Garibaldi da Rocha','Rua Professor Joaquim Felizardo, nº 40<br>CEP 91770-370','Porto Alegre City - Rio Grande do Sul','Bairro Espírito Santo','BRAZIL','91751-000','',NULL,NULL,NULL,'2012-03-08 03:12:59',0,NULL,3,1,3,1,'RA184528976CN\r ','新地址：\rDaiana Garibaldi da Rocha\rRua Professor Joaquim Felizardo, nº 40\rCEP 91770-370\rBairro Espírito Santo\rPorto Alegre City - Rio Grande do Sul\rBrazil \r申报 gift  $18'),(25501,8881331176710836,111,'1.6x2m  背景布  黑色',1,'',0,'hermeshine','tanb0017','philips170t@yahoo.com','BENG KEAT TAN','BLK 414 PANDAN GARDEN<br>#06-144<br>CEP 91770-370','SINGAPORE','SINGAPORE','SINGAPORE','600414','',NULL,NULL,NULL,'2012-03-08 03:18:30',0,NULL,3,0,3,1,'RA184528931CN\r ',NULL),(25502,8881331177839288,111,'2b柔',2,'AKT014',0,'hermeshine','radoslav007','radojanic@gmail.com','Radoslav Janic','Hodoninska 15','Holic Holic 908 51','','SLOVAKIA','','',NULL,NULL,NULL,'2012-03-08 03:37:19',0,NULL,3,1,5,1,'CP246990338CN\r ',NULL),(25503,853932316002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','noyz!','sagittareanspell@hotmail.com','noel zaragoza','3450 W Belmont ave<br>Fl 2','chicago','IL','UNITED STATES','60618-5409','(224) 201-1117','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 03:39:58',0,NULL,3,1,3,1,'RA184528888CN\r ','hermeshine'),(25504,941752307016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','akoryagin','koryaginag@mail.ru','Anton Koryagin','Amurskaya st. 5 ap. 96','Vladivostok','Primorsky region','RUSSIAN FEDERATION','690000',' 89247399399','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 03:52:38',0,NULL,3,1,11,1,NULL,'hutongstore'),(25505,876847927017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',190,'photographyacc','andyb2001au','acommon@y7mail.com','Andrea L Common','17 Corfu Pass','Port Kennedy','Western Australia','AUSTRALIA','6172','0895246669','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-08 04:27:34',0,NULL,3,1,4,1,'YW870146925CN\r ','photographyacc\r布换成白色的，澳标'),(25506,853959039002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','rosie_n_aaron','ll_amaya_ll6@bigpond.com','Rosemary Anderson','2/58 Wigg St','Wodonga','Victoria','AUSTRALIA','3690','0260561630','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 05:36:46',0,NULL,3,1,11,1,NULL,'hermeshine'),(25507,809265204001,110615440719,'Photo Spring Cushioned tripod Light Stand 7‘/ 210cm x 1',1,'AE3403',37.95,'hermeshine','majormfrf','shtuchkaz@yandex.ru','Andrey Shtuchka','Yangelya st. 6/74','Baykonur','RU','RUSSIAN FEDERATION','468320','73362270348','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 05:41:17',0,NULL,3,1,3,1,'RA184528874CN\r ','hermeshine'),(25508,853968183002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','batuevkv','uuitwer@mail.ru','Константин Батуев','пр-т Ленина дом 46 кв. 50','Нытва','Пермский край','RUSSIAN FEDERATION','617001','+79519412333','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-08 06:26:37',0,NULL,3,1,3,1,'RA184528865CN\r ','hermeshine'),(25509,941804170016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','depzy123','depzy@hotmail.co.uk','Despina Chroussis','49 Durnsford Road<br>Bounds Green','London','London','UNITED KINGDOM','N11 2EP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 07:16:41',0,NULL,3,0,11,1,NULL,'hutongstore'),(25510,635014847004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','kulis112','jkusy@seznam.cz','Jan Kusý','Prokopa Holého 440','Trutnov','Královehradecký','CZECH REPUBLIC','54101','776069305','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 07:29:27',0,NULL,3,1,17,0,NULL,'hermeshine'),(25511,809285978001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','kulis112','jkusy@seznam.cz','Jan Kusý','Prokopa Holého 440','Trutnov','Královehradecký','CZECH REPUBLIC','54101','776069305','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 07:29:30',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变灰 （nd4）    1\r无牌方镜 渐变灰 （nd8）  1'),(25512,961778164015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','oty1972','otti72@yahoo.com','Otilia Sepulveda Sepulveda','8 Imperial Arcade','Huddersfield','West Yorkshire','UNITED KINGDOM','HD1 2BR','07904335205','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 07:30:43',0,NULL,3,1,11,1,' ','hutongstore'),(25513,809292158001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','aa2209','arielamir@yahoo.com','Amir Ariel','9th Begin St.','Givat Shmuel','','ISRAEL','54421','+972-54-227 1403','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 07:58:18',0,NULL,3,1,3,1,'RA184529000CN\r ','hermeshine'),(25514,853998135002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','vangcheenou1991','cvang1991@gmail.com','Cheenou Vang','1333 F St','Eureka','CA','UNITED STATES','95501-2321','(707) 601-7506','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 08:48:51',0,NULL,3,1,3,1,'RA184528914CN\r ','hermeshine'),(25515,816075053018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',96.9,'photographyacc','jamzdabrainz','jamie@atwebdesign.com.au','Jamie Sotiroski','Unit 12/89 Gow Street','Padstow, Sydney,','New South Wales','AUSTRALIA','2211','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 09:40:18',0,NULL,3,1,4,1,'YW870146940CN ','photographyacc'),(25517,961829191015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',2,'AD1176',47,'hutongstore','bo280349','guyogco@hotmail.com','Bo Rasmussen','Uhlendorffs Allé 10','Rørvig','standard','DENMARK','4581','(045) 31195517','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 10:17:56',0,NULL,3,1,4,1,'YW870146962CN\r ','hutongstore\r灯架  2m       2\r4灯头 灯头 孔     2    欧标\r50cmx70cm 的柔光箱 (配4灯头）    2'),(25518,809326796001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','waseem1239','waseemqatar@hotmail.com','Waseem Bashar AL Khudr','Alsadd<br>Mobile +97455551239','Doha','Doha','QATAR','92303','+97455551239','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-08 10:21:34',0,NULL,3,1,8,1,'CP246990369CN\r ','hermeshine\r白+黑\r\r告我一下最终重量\r3.3\r\r\r'),(25519,941861961016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','corneliu-mihael','corneliu.ionescu@yahoo.com','Corneliu-Mihael Ionescu','Sos. Pantelimon 309, Bl. 8, Sc. E, Ap. 181','Bucharest','Bucharest','ROMANIA','021621','+40722581237','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 10:32:54',0,NULL,3,1,11,1,NULL,'hutongstore'),(25520,635046541004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','doortjha','doortjhu_lovezz@hotmail.com','Dorinda van der Jagt','Buitenweg 21','Krimpen aan de Lek','','NETHERLANDS','2931AC','0031624468252','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 10:37:27',0,NULL,3,1,11,1,NULL,'hermeshine'),(25521,941865178016,260660052222,'New 67mm 67 Ring adapter and Holder for Cokin P Series',1,'AKT022',3.12,'hutongstore','tedmoat','tedmoat@hotmail.co.uk','TED MOAT','22, THE NESS','DOLLAR','Clackmannan','UNITED KINGDOM','FK14 7EB','01259743335','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 10:42:12',0,NULL,3,1,2,1,NULL,'hutongstore'),(25522,961840230015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','linas565','linas@paintbaleris.lt','Linas NAVARDAUSKAS','TAIKOS pr. 84-54','Kaunas','LITHUANIA','LITHUANIA','LT51275','37068723366','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 10:50:10',0,NULL,3,1,11,1,NULL,'hutongstore \r欧标'),(25523,809342605001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',10,'AC2301',62.1,'hermeshine','mariomarques.com.br','mariobrrj@gmail.com','Mario Marques Netto','Rua Marechal Aguiar, 96<br>Benfica','Rio De Janeiro','Rio de Janeiro','BRAZIL','20920280','552138901273','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 11:25:20',0,NULL,3,1,3,1,'RA184522085CN\r ','hermeshine'),(25524,854045937002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',3,'AE2203',74.4,'hermeshine','1965stanleycup','darocque@gmail.com','Daniel Rocque','1846, ch. Lamoureux','St-Faustin/Lac-Carré','QC','CANADA','J0T 1J2','(819) 429-6859','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 11:55:14',0,NULL,3,1,3,1,'RA184522094CN\r ','hermeshine'),(25525,816111017018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',4.83,'photographyacc','lenehma','mahieu.helen@gmail.com','Helen Mahieu','1/29 Panorama Street','Clayton','Victoria','AUSTRALIA','3168','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 11:56:57',0,NULL,3,1,11,1,NULL,'photographyacc'),(25526,809367584001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','cppproject','drew@oakbox.co.uk','Andrew Dunk','15 Norton Road','Reading','Berkshire','UNITED KINGDOM','RG1 3QH','01189663287','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 12:46:46',0,NULL,3,1,11,1,NULL,'hermeshine'),(25527,961882758015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','caroline2592','carolineamanda2592@hotmail.com','Caroline Hamilton','Agent Design<br>91 - 93 Great Union Road, St. Helier','Jersey','Channel Islands','JE','JE2 3WA','07797826518','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 12:51:47',0,NULL,3,1,5,1,'CP246990355CN\r ','hutongstore\r白 黑\r\r'),(25528,854062685002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','yamatama266','famous_sas266@hotmail.com','William De la Cruz','6 Alts Del Este','Humacao','PR','UNITED STATES','00791-4718','(787) 222-4111','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-08 12:53:35',0,NULL,3,1,3,1,'RA184522103CN\r ','hermeshine'),(25529,854070516002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','mikemorenophotoman','mike_moreno_thebest@hotmail.com','Miguel Angel Moreno Correro','C/Trainera Ubanización Montesol<br>Nº67','Algeciras','Andalucía Ceuta y Melilla','SPAIN','11207','626695418','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:15:44',0,NULL,3,1,3,1,'RA184522015CN\r ','hermeshine'),(25530,809378842001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-507254189','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:22:56',0,NULL,3,1,3,1,'RA184522029CN\r ','hermeshine'),(25531,809384835001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.5,'hermeshine','radovicsmilan1982','radovicsmilan@gmail.com','Milán Radovics','Deák Ferenc u. 14.','Csongrád','Csongrád','HUNGARY','6640','+36703396832','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:39:50',0,NULL,3,1,11,1,NULL,'hermeshine'),(25532,809386626001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1203',10,'hermeshine','juca*2009','jpavelak@me.com','Juarez Pavelak','Rua Alegrete, 21<br>Bairro Laranjeiras','Rio de Janeiro','RJ','BRAZIL','22240-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 13:46:16',0,NULL,3,1,3,0,'RA184522205CN\r  ','hermeshine'),(25533,961908767015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','kronosgalicia','kronosvega@hotmail.com','Beatriz Irigoyen Pampin','C/Real 195 Bajo Cosquillas','Ferrol - A coruña','Galicia','SPAIN','15402','652408632','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 13:54:58',0,NULL,3,1,3,1,'RA184522032CN\r ','hutongstore'),(25534,809392678001,110417005141,'Canon-52mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1207',3.58,'hermeshine','juca*2009','jpavelak@me.com','Juarez Pavelak','Rua Alegrete, 21<br>Bairro Laranjeiras','Rio de Janeiro','RJ','BRAZIL','22240-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:04:28',0,NULL,3,1,17,0,'RA184522205CN\r  ','hermeshine\r'),(25535,854081404002,120642517387,'Tungsten bulb 800W for redhead light  X 5 3200K 110V',1,'AKT058',29.99,'hermeshine','joao_guarapari','srjoao@terra.com.br','Nathalie Pinto de Oliveira','Rua 20 de Janeiro, nº 170, casa 02<br>Itapebussu','Guarapari','ESPÍRITO SANTO','BRAZIL','29210-140','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:10:19',0,NULL,3,1,3,1,'RA184522046CN\r ','hermeshine'),(25536,809396522001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','juca*2009','jpavelak@me.com','Juarez Pavelak','Rua Alegrete, 21<br>Bairro Laranjeiras','Rio de Janeiro','RJ','BRAZIL','22240-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:15:28',0,NULL,3,1,17,0,'RA184522205CN\r  ','hermeshine'),(25537,854090007002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',37.89,'hermeshine','hemi.i','hemi_i@live.com','Ibrahim AL-Shehri','P.O BOX 10053<br>HADEED COMPANY','jubail','jubail','SAUDI ARABIA','31961','+966544803385','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-08 14:20:54',0,NULL,3,1,3,1,'RA184522050CN\r ','hermeshine'),(25538,854096038002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','emuexport81','gavinhughes@iinet.net.au','gavin hughes','33 jacobsen way<br>thornlie','perth','Western Australia','AUSTRALIA','6108','0894932070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 14:33:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(25539,941960800016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','throkkas','trokkas@hotmail.com','Theodoros Rokkas','Kremou 93','Kallithea','Athens','GREECE','17676','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-08 14:48:59',0,NULL,3,1,3,1,'RA184522077CN\r ','hutongstore'),(25540,816178128018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',46.54,'photographyacc','spudhead1982','webmaster@fullyautomotive.com','Ryan Annear','11 Excalibur Circle Camillo','Perth','Western Australia','AUSTRALIA','6111','0478192564','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 15:07:47',0,NULL,3,1,17,0,'YW870146973CN ','photographyacc'),(25541,961945608015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','lordbazis','boldizsar@diffikult.com','Lukács Boldizsár','István király útja 25','Edelény','BAZ','HUNGARY','3780','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 15:16:36',0,NULL,3,1,3,1,'RA184522196CN\r ','hutongstore'),(25542,816182324018,280683074172,'24\" / 60cm Easy Fold Flash Speedlight Softbox soft box',1,'AB3329',46.54,'photographyacc','spudhead1982','webmaster@fullyautomotive.com','Ryan Annear','11 Excalibur Circle Camillo','Perth','Western Australia','AUSTRALIA','6111','0478192564','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-08 15:18:45',0,NULL,3,1,4,1,'YW870146973CN\r ','photographyacc\r闪光的柔光箱   60cm    2'),(25543,809432014001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','midnightmask','miss.pitcher@live.ca','Leanne Pitcher','10 Boggan\'s Lane','Conception Bay South','NL','CANADA','A1W 5V4','(709) 690-2776','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 15:54:49',0,NULL,3,1,11,1,NULL,'hermeshine\r黑\r'),(25544,854131216002,120694617297,' IR Remote Control for Canon 7D/550D/450D/500D  ',1,'AA2202',3.5,'hermeshine','juca*2009','jpavelak@me.com','Juarez Pavelak','Rua Alegrete, 21<br>Bairro Laranjeiras','Rio de Janeiro','RJ','BRAZIL','22240-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 16:05:53',0,NULL,3,1,3,1,'RA184522205CN\r ','hermeshine\r6片装的滤镜袋   2\rcanon 反接环  58mm     1\rcanon 反接环  52mm      1\r爵影红外 canon     1'),(25545,807954731001,110446312770,'Hand Free Shoulder Pad Support 4 Camcorder Video Camera',1,'AE1401',35.99,'hermeshine','homepon22','homepon@bk.ru','Nikita Mineev','Altaiskaya,74-51','Rubtsovsk','Altaiskiy region','RUSSIAN FEDERATION','658218','9132527033','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-08 16:32:28',0,NULL,3,1,3,1,'RA184522117CN\r ','hermeshine'),(25546,854176082002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',1,'AD1402',8.9,'hermeshine','anttiturunen','turunen.antti.johannes@gmail.com','Antti Turunen','Kirkkokatu 10 C 27','Savonlinna','','FINLAND','57100',' 0443270793','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 17:47:22',0,NULL,3,1,17,0,'YW870146984CN\r ','hermeshine'),(25547,809481802001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','anttiturunen','turunen.antti.johannes@gmail.com','Antti Turunen','Kirkkokatu 10 C 27','Savonlinna','','FINLAND','57100',' 0443270793','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-08 17:47:23',0,NULL,3,1,4,1,'YW870146984CN ','hermeshine\r柔光伞    1\r灯架  2m    2'),(25548,962063348015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','13nguoa','bbal_sayers@hotmail.co.uk','Michael Sayers','Hunters Moon, Nicker Hill,','Keyworth','Nottinghamshire','UNITED KINGDOM','NG125ED','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 18:48:12',0,NULL,3,1,3,1,'RA184522134CN\r ','hutongstore'),(25549,942103442016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','areus101','trytoremembermyemail@gmail.com','Arkadiusz Kmera','115 Millbrook<br>JFK Parade','Sligo','Sligo','IRELAND','default','0868062447','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 19:07:40',0,NULL,3,1,3,1,'RA184522125CN\r ','hutongstore'),(25550,816309794018,280678917520,'Neoprene Camera Cover Case for small dslr & semi slr S',1,'AC2301',5.6,'photographyacc','buzabenedek','benedek.buza@gmail.com','Bence Buza','Attila ut 47.','Budapest','Budapest','HUNGARY','1013','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-08 19:40:27',0,NULL,3,1,11,1,' ','photographyacc'),(25551,962106445015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','isadsa3','haugls@yahoo.com','silje Haugland','reknes<br>5986','hosteland','','NORWAY','5986','90206428','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 19:48:12',0,NULL,3,1,3,1,'RA184522148CN\r ','hutongstore'),(25552,809548201001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','checkcheck542354','check12341234@gmail.com','Evgeny Anikeev','Lesnaya 5, 49','Fryazino','Moscow Oblast','RUSSIAN FEDERATION','141195','+79629797035','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 19:51:26',0,NULL,3,1,17,1,'CP246990372CN\r ','hermeshine'),(25553,809547699001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','checkcheck542354','check12341234@gmail.com','Evgeny Anikeev','Lesnaya 5, 49','Fryazino','Moscow Oblast','RUSSIAN FEDERATION','141195','+79629797035','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 19:51:27',0,NULL,3,1,5,1,'CP246990372CN\r ','hermeshine\r灯架  2m    2'),(25554,962120076015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',2,'AD1126',15.2,'hutongstore','alimar7068','alimar7068@aol.com','Alastair Mann','146 SHERBROOKE ROAD<br>ROSYTH','DUNFERMLINE','Fife','UNITED KINGDOM','KY11 2YX','01383850412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 20:05:45',0,NULL,3,1,3,0,'RA184522151CN\r ','hutongstore'),(25555,962120078015,250846947101,'43\" 110cm Studio Flash Translucent soft White Umbrella',2,'AD1125',15.8,'hutongstore','alimar7068','alimar7068@aol.com','Alastair Mann','146 SHERBROOKE ROAD<br>ROSYTH','DUNFERMLINE','Fife','UNITED KINGDOM','KY11 2YX','01383850412','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 20:05:46',0,NULL,3,1,3,1,'RA184522151CN\r ','hutongstore\r反光伞110cm     2\r柔光伞110cm     2'),(25556,809572259001,110790903696,'New Neoprene Soft Camera Cover Canon EOS 450D with kit lenses 18-55mm 50mm',1,'AD1213',7.99,'hermeshine','kiki_kopjar','ktb_net@yahoo.com','Kristina Kristek-Kopjar','Poljačka 65','Zagreb-Susedgrad','Croatia','CROATIA','10090','+385959099101','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 20:31:58',0,NULL,3,1,11,1,NULL,'hermeshine'),(25557,962148251015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',2,'AA3405',11.6,'hutongstore','m.flanders0771','m.flanders@sky.com','martin flanders','3<br>broomy close','birmingham','West Midlands','UNITED KINGDOM','b346ep','07717767515','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-08 20:44:53',0,NULL,3,1,11,1,NULL,'hutongstore'),(25558,854288597002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','ppa80pavel','pplotnikov@gmail.com','pavel plotnikov','souznyi prospect<br>dom 13k2 kv. 147','moscow','','RUSSIAN FEDERATION','111396','+7 926 2347825','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 21:14:14',0,NULL,3,1,3,1,'RA184522063CN\r ','hermeshine'),(25559,962172392015,250845736756,'New Light Stand / Umbrella Carry Soft Case Bag - Nylon',1,'AD1129',8,'hutongstore','371ember','vpelns@gmail.com','Valters Pelns','Jūrmalas iela 8 -1','Liepāja','Latvia','LATVIA','LV-3401','(371) 26755220','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 21:17:31',0,NULL,3,1,11,1,NULL,'hutongstore'),(25560,809604297001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','rosemarie_gala','rosemarie.b.gala@gmail.com','Rosemarie Gala','C/O Michelle Gala Office #21-22 Bldg 947<br>Road 3620 Blk 436 Seef District','Manama','bahrain','BAHRAIN','21379','0097339724486','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-08 21:30:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(25561,962189939015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','eduardomorais','eduardomorais2@gmail.com','Eduardo Morais','R. Cabeço do Alqueve, 34<br>Cordovão - Eiras','Coimbra','Portugal','PORTUGAL','3020-164','918816688','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-08 21:43:30',0,NULL,3,1,11,1,NULL,'hutongstore'),(25562,816410212018,280696383922,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',57,'photographyacc','madridencorto08','madridencorto@hotmail.com','Christian García Martínez','C/ Butrón 29 1º D','Madrid','Madrid','SPAIN','28022','657757714','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-08 22:40:49',0,NULL,3,1,17,0,'YW870146995CN\r ','photographyacc'),(25563,877267990017,270855429606,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',294.5,'photographyacc','madridencorto08','madridencorto@hotmail.com','Christian García Martínez','C/ Butrón 29 1º D','Madrid','Madrid','SPAIN','28022','657757714','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-08 22:40:50',0,NULL,3,1,4,1,'YW870146995CN ','photographyacc\rc以外再加上：  欧标\r115w 5500k 灯泡  220v    4'),(25564,809662622001,110417005426,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',3.58,'hermeshine','carri56','carpe33@hotmail.com','francisco javier carrion peral','C/Natividad Morales Muñoz, 63','SAN JOSE DE LA RINCONADA','Andalucía Ceuta y Melilla','SPAIN','41300','608336999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 00:05:39',0,NULL,3,1,11,1,NULL,'hermeshine'),(25565,962279577015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','knag20','knag20@hotmail.com','Ruben Monteiro','UNIT 1, DEBEN MILL BUSINESS CENTER, MELTON APROACH','WOODBRIDGE, IPSWICH','Suffolk','UNITED KINGDOM','IP121BL','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 00:58:15',0,NULL,3,1,11,1,NULL,'hutongstore'),(25566,8881331255127673,111,'灯架底座+斜臂头螺丝+英标头一个',1,'',0,'hutongstore','spielbergofhereford','neiloseman@googlemail.com','Neil Oseman','119 Widemarsh Street','Hereford','Herefordshire','UNITED KINGDOM','HR4 9EZ','01432353647',NULL,NULL,NULL,'2012-03-09 01:05:27',0,NULL,3,0,3,1,'RA184522307CN ',NULL),(25567,854386186002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','moniqueb_123','brewster_monique@yahoo.com','Monique Brewster','14811 235th St','Rosedale','NY','UNITED STATES','11422-3294','','PayPalPaymentInProcess','CheckoutComplete','ShippingMethodStandard','0000-00-00 00:00:00',0,NULL,5,0,18,0,'LK229516286CN\r ','hermeshine'),(25568,877329235017,270747043947,'New 52mm Snap-on Front Lens Cap for Nikon 52  lenscap',1,'AA1305',2.38,'photographyacc','vardaro_studio','vardaro@riverland.net.au','Vardaro Studio','26 Kay Ave','Berri','South Australia','AUSTRALIA','5333','0885823111','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 01:41:32',0,NULL,3,1,2,1,NULL,'photographyacc'),(25569,816473443018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','yialeloglou','johnmandy@ozemail.com.au','John Yialeloglou','54 Church St','Yass','New South Wales','AUSTRALIA','2582','0262262981','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 01:56:48',0,NULL,3,1,11,1,NULL,'photographyacc'),(25570,629765336003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','razaloba','conjuntodisjunto@gmail.com','Juan Muñoz','Reina Victoria 66','Madrid','Madrid','SPAIN','28003','627590266','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 01:26:13',0,NULL,3,1,4,1,'YW870147006CN\r ','hermeshine'),(25571,8881331261006695,111,'38cm灯架最上面的螺丝',1,'',0,'hermeshine','pauljavor','attila@hujman.hu','Attila Hujman','Frankenburg út 14','Sopron','Hungary','HUNGARY','9400',' 06205332292',NULL,NULL,NULL,'2012-03-09 02:43:26',0,NULL,3,0,3,1,'RA184522219CN ',NULL),(25572,809736095001,110498795544,'New soft box photography studio lighting Set',1,'AKT016',97,'hermeshine','paige.lathan','bragginbratsphotography@yahoo.com','Paige Lathan','681 W McClellan St','Ponchatoula','LA','UNITED STATES','70454-3854','(985) 351-3511','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-09 04:26:51',0,NULL,3,1,4,1,'YW870147010CN\r ','hermeshine'),(25573,854448919002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','vickbasra','viganecanada@yahoo.ca','vigane aghavart','270 palmdale dr apt 407','scarborough','ON','CANADA','m1t3n8','(416) 885-8050','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 05:31:45',0,NULL,3,1,3,1,'RA184522222CN\r ','hermeshine'),(25574,854454046002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','goddealnow','gustavougarte@comcast.net','gustavo','2306 newcastle dr','Garland','TX','UNITED STATES','75041-1315','(214) 403-0280','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-09 05:57:13',0,NULL,3,1,3,1,'RA184522236CN\r ','hermeshine'),(25575,809756611001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','salljh09','salljh@hotmail.com','Susannah Hodson','Australian Embassy<br>Rue Guimard 6','Brussels','','BELGIUM','1040','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 06:08:10',0,NULL,3,1,11,1,NULL,'hermeshine'),(25576,8881331274613585,111,'New pro 10 x 20 ft 3m x 6m backdrop system and continous lighting kit 1000W',1,'AKT050',0,'hutongstore','esseonline','serena.saunders@neonerve.com','serena saunders','17 hallett road','dunmow Essex cm63fl','','UNITED KINGDOM','','',NULL,NULL,NULL,'2012-03-09 06:30:13',0,NULL,3,1,4,1,'YW870147021CN\r ','布是白色的\r英标 '),(25577,8881331275477898,111,'2m灯架',1,'AE3401',0,'photographyacc','glossfox','louise.a.francis@gmail.com','Louise Francis','PO Box 8122<br>Monash University','Clayton Victoria 3800','Victoria','AUSTRALIA','3800','',NULL,NULL,NULL,'2012-03-09 06:44:37',0,NULL,3,1,3,1,'RA184522240CN\r ',NULL),(25578,8881331275582270,111,'New Camera Tripod Fancier FT-6662A with 6160H FT-686',1,'AE1503',0,'photographyacc',' likclikc  ','likc@yahoo.com','Lukas Korinek','23 Laurence Road','Walliston Western','','AUSTRALIA ','6076','',NULL,NULL,NULL,'2012-03-09 06:46:22',0,NULL,3,1,4,1,'YW870147032CN\r ',NULL),(25579,8881331275725629,111,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',0,'hermeshine','colinds888','clind20@bigpond.net.au','Colin Lindsay','323 Philp Avenue<br>Frenchville','Rockhampton','Queensland','AUSTRALIA','4701','0749282862',NULL,NULL,NULL,'2012-03-09 06:48:45',0,NULL,3,1,3,1,'RA184522253CN\r ',NULL),(25580,8881331276007390,111,'Free shipping & Tracking # - New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount - Wholesale/Retail AE2203',1,'AE2203',22.99,'aliexpress','Dieter Bruns',' dieter.bruns@gmail.com','Dieter Gustavo Brun','Rua Barao do Rio Branco, 760, Apto 702, Bairro Centro<br>Santa Catarina, Brazil','Jaragua do Sul','Santa Catarina','BRAZIL','89251400','+55 47 34654800',NULL,NULL,NULL,'2012-03-09 06:53:27',0,NULL,3,1,3,1,'RA184522179CN\r ',NULL),(25581,8881331276113521,111,'Free shipping & Tracking # - New Pro wide angle holder for Cokin P series Filters - AA2216',1,'AA2216',5.99,'aliexpress','Auster F',' toyoki@ca2.so-net.ne.jp','Toyoki Bamba','3-20-2-205 Nogata, Nakano-ku','Tokyo','','JAPAN','165-0027','+81 03 53438674',NULL,NULL,NULL,'2012-03-09 06:55:13',0,NULL,8,1,17,0,NULL,NULL),(25582,8881331276152369,111,'6 pcs Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs - Wholesale/ Retail [AKT081]',1,'AKT081',27.83,'aliexpress','Auster F',' toyoki@ca2.so-net.ne.jp','Toyoki Bamba','3-20-2-205 Nogata, Nakano-ku','Tokyo','','JAPAN','165-0027','+81 03 53438674',NULL,NULL,NULL,'2012-03-09 06:55:13',0,NULL,3,1,3,1,'RA184522182CN\r ','c以外再发：\r方镜广角托架（ 一槽）   1 '),(25583,8881331276455660,111,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',0,'hermeshine',' tobiahdavis  ','tdavis@teknik.com.au','Toby Davis','15 Galvin Street','South Launceston Tasmania','','AUSTRALIA','7249','',NULL,NULL,NULL,'2012-03-09 07:00:55',0,NULL,7,0,18,0,NULL,NULL),(25584,809221184001,110566020073,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',2.18,'hermeshine','tobiahdavis','tdavis@teknik.com.au','Toby Davis','115 Galvin Street','South Launceston','Tasmania','AUSTRALIA','7249','61427813339','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 06:47:19',0,NULL,3,1,2,1,NULL,'hermeshine'),(25585,816554258018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',19,'photographyacc','8hany','hany@milano.net.au','Makram Mahrous','138 Addison Road','Marrickville','New South Wales','AUSTRALIA','2204','0408888804','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-09 07:41:32',0,NULL,3,1,11,1,NULL,'photographyacc'),(25586,942441339016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','greatwhite90125','john@theharrises.co.uk','John Harris','The Manor House, Market St','Tunstead','Norfolk','UNITED KINGDOM','NR12 8AH','01603737509','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 08:58:09',0,NULL,3,1,11,1,NULL,'hutongstore'),(25587,854494982002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ojisan333','arcoiris@bigpond.net.au','MASUMI TAKAHASHI','28/110 CRIMEA ROAD','MARSFIELD','New South Wales','AUSTRALIA','2122','0298685264','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 09:18:08',0,NULL,3,1,11,1,NULL,'hermeshine'),(25588,854495278002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','ilbeastli','be.ast@mail.ru','Dmitry Severinov','Rodimceva Street 4 - 53','Orenburg','Orenburg','RUSSIAN FEDERATION','460052','89225434313','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 09:19:10',0,NULL,3,1,3,1,'RA184522298CN ','hermeshine'),(25589,962437229015,250854521184,'MANUAL WALL SUPPORT EXPANSION 3x ROLLER BACKGROUND',1,'AD1147',67,'hutongstore','amed3862','anabume@yahoo.es','Ana Medeiros','calle Via de los Poblados 1. Parque Alvento. C. Bajo A. VERIFONE','Madrid','Madrid','SPAIN','28033','653021406','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 09:51:14',0,NULL,3,1,4,1,'YW870147065CN\r\r ','hutongstore'),(25590,942467709016,260901272264,'New Tungsten bulb 800W for redhead light X 1 3200K 220V',2,'AO0015',9,'hutongstore','sinvision_multimedia_solutions','info@sinvision.co.uk','David Sinclair','8 Namur road<br>South Wigston','Leicester','Leicestershire','UNITED KINGDOM','LE18 4UJ','01162775482','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 10:19:43',0,NULL,3,1,11,1,NULL,'hutongstore'),(25591,962448480015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','mmakjp','philip.kamm@blueyonder.co.uk','Philip Kamm','The John of Gaunt School<br>Wingfield Road','Trowbridge','Wiltshire','UNITED KINGDOM','BA14 9EH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 10:22:19',0,NULL,3,1,3,1,'RA184590341CN\r ','hutongstore'),(25592,809814989001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','egorsilenthorror','silenthorrorspirit@gmail.com','Egor Filippov','Sharapovskaya ulica, dom 2 korpus 3, kvartira 53','Mytischi','Moskovskaya oblast\'','RUSSIAN FEDERATION','141002','+7-903-677-75-21','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 10:32:05',0,NULL,3,1,3,1,'RA184522369CN\r ','hermeshine'),(25593,808450042001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','malsm61','tatsyzran@yandex.ru','Сергей Малов','п.Варламово, ул.Южная 1-32','Сызранский район','Самарская область','RUSSIAN FEDERATION','446073','+7 927 6106440','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 10:49:37',0,NULL,3,1,11,1,NULL,'hermeshine'),(25594,854518413002,120813022039,'Super clamp all metal 15kg capacity for flash, backdrop',4,'AD1177',140,'hermeshine','goretsky75','k812@yandex.ru','Kirill Goretskiy','Kirochnaya street,11 apt 39','St-Petersburg','','RUSSIAN FEDERATION','191014','(921)939-2370','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 10:50:56',0,NULL,3,1,5,1,'CP246990409CN ','hermeshine'),(25595,962462457015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','fandressouza2011','fandressouza@gmail.com','felipe souza alarcon','sobo cafe-pearse dart station, westland row','dublin 2','Dublin','IRELAND','default','858208369','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 11:02:34',0,NULL,3,1,3,1,'RA184522355CN\r ','hutongstore'),(25596,942485178016,260901272211,'New Camera protector case Neoprene bag for Nikon D90 D7000 D80 L',1,'AD1173',6.5,'hutongstore','taqtaq007','t_taqtaq@yahoo.com','Tareq Taqtaq','Transworld Tower<br>P O Box 47 c/o HRR21','Doha','Doha','QATAR','+97455515385','+97455515385','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 11:15:37',0,NULL,3,1,11,1,NULL,'hutongstore'),(25597,962489504015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ruta6809','anastazija882@hotmail.com','Ruta Mackelaite','22 Wells Court<br>Cambridge avenue','London','London','UNITED KINGDOM','NW6 5TH','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 12:19:01',0,NULL,3,1,3,1,'RA184522275CN\r ','hutongstore'),(25598,942509111016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','iban979','ibanma79@hotmail.com','Iban Andueza Manrique','Bikuña Enea Enparantza 8 - 1º A','Legazpi','País Vasco','SPAIN','20230','646366027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 12:24:44',0,NULL,8,1,17,0,NULL,'hutongstore'),(25599,962492170015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','iban979','ibanma79@hotmail.com','Iban Andueza Manrique','Bikuña Enea Enparantza 8 - 1º A','Legazpi','País Vasco','SPAIN','20230','646366027','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 12:26:11',0,NULL,3,1,3,1,'RA184522443CN\r ','hutongstore\r摄影背心 黑色厚 无字  XL  1\r新款内胆包 大号 canon logo  1\r'),(25600,854568939002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','a_photo','armeniagold@hotmail.com','Misak Nalbandyan','Batikyan 93a','Yerevan','Malatya-sebastya','ARMENIA','0032','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 13:42:21',0,NULL,3,1,11,1,NULL,'hermeshine'),(25601,962526918015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',1,'AA2212',1.6,'hutongstore','sexgodsid','suditha@uk.bynx.com','Mr. S K Atureliya','Bynx Europe Ltd.<br>34 Wellesbourne House Business Centre, Walton Road','Wellesbourne','Warwickshire','UNITED KINGDOM','CV35 9JB','01789471600','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 13:51:01',0,NULL,3,1,11,1,NULL,'hutongstore'),(25602,962529356015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','antalszilagyi','szilagyiantal79@gmail.com','Antal Szilágyi','Lovohaz u 28','Budapest','','HUNGARY','1024','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-09 14:01:07',0,NULL,3,1,5,1,'CP246990426CN ','hutongstore\r欧标'),(25603,854574514002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 14:04:09',0,NULL,3,1,17,0,'CP246990443CN  ','hermeshine'),(25604,809892042001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','juca*2009','jpavelak@me.com','Juarez Pavelak','Rua Alegrete, 21<br>Bairro Laranjeiras','Rio de Janeiro','RJ','BRAZIL','22240-130','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 14:40:55',0,NULL,3,1,3,1,'RA184590179CN\r ','hermeshine\r已发信需要加$8运费\r已发账单，付款后发货\r已付款\r'),(25605,962560607015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',1.6,'hutongstore','alex50h','alex50h@yahoo.co.uk','ALEX HENDRY','74 SOUTH SCOTT STREET<br>BAILLIESTON','GLASGOW','LANARKSHIRE','UNITED KINGDOM','G69 7DE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 15:04:32',0,NULL,3,1,11,1,NULL,'hutongstore'),(25606,809910813001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',3,'AD1180',41.7,'hermeshine','amnon064','amnon64@gmail.com','Amnon Ziv','Doar Na Chalutza','Kibutz Mashabe Sade','','ISRAEL','85510','972-507254189','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 15:31:14',0,NULL,3,1,3,1,'RA184522409CN\r ','hermeshine'),(25607,854610457002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 15:32:45',0,NULL,3,1,17,0,'CP246990443CN  ','hermeshine'),(25608,854610319002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 15:32:46',0,NULL,3,1,5,1,'CP246990443CN ','hermeshine\r闪光的柔光箱   60cm  1\rks-0 II （绿盒）  2\r称一下重量。超过2kg.就发SAL\r不超过就要算运费'),(25609,962574739015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','canastahotel','stay@canastahotel.com','Doug Smith','Canasta Hotel<br>288 North Promenade','Blackpool','Lancashire','UNITED KINGDOM','FY1 2EY','01253290501','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 15:34:15',0,NULL,3,1,3,1,'RA184522284CN\r ','hutongstore'),(25610,854616042002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','vickbasra','viganecanada@yahoo.ca','vigane aghavart','270 palmdale dr apt 407','scarborough','ON','CANADA','m1t3n8','(416) 885-8050','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-09 15:47:12',0,NULL,3,1,3,1,'RA184522315CN\r ','hermeshine'),(25611,854658275002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',31.34,'hermeshine','fwdracer','henryquan@rogers.com','Henry Quan','40 Flushing Ave','Woodbridge','ON','CANADA','L4L 8H9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 17:25:50',0,NULL,3,1,3,1,'RA184522474CN\r ','hermeshine'),(25612,942659224016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','123xat','patrick.fleming@mac.com','Patrick Fleming','7A The Terrace<br>Barnes','London','London','UNITED KINGDOM','SW130NP','07775981671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 17:42:02',0,NULL,3,1,11,1,NULL,'hutongstore'),(25613,809969733001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','blondie401','makelley316@aol.com','Jan Kelley','7630 Sleepy Summit Ln','Fairview','TN','UNITED STATES','37062-8349','(615) 799-2458','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-09 17:45:55',0,NULL,3,1,1,1,'LK231079071CN ','hermeshine'),(25614,962649519015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','mipentertainment','mipproduction@hotmail.com','IVANDRO PEREIRA','Flat 204, 87 Axe Street<br>Barking','Essex','Essex','UNITED KINGDOM','IG11 7FS','07901333684','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-09 17:50:51',0,NULL,3,1,11,1,NULL,'hutongstore'),(25615,854701141002,120531387355,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',15.69,'hermeshine','vitalija2','vitalija219@gmail.com','Vitalija Pabilioniene','Reipslagergata 17','Kristiansund N','Møre og Romsdal','NORWAY','6514','92506070','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 18:53:57',0,NULL,3,1,11,1,NULL,'hermeshine\r欧标'),(25616,809838442001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','johandelos','johandemarle@gmail.com','Johan Demarle','7 chemin du prat-long bat B Appt 46','Toulouse','Midi-Pyrénées','FRANCE','31200','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-09 19:22:25',0,NULL,3,1,3,1,'RA184522488CN\r ','hermeshine\rM 已入库'),(25617,854721312002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','datlant','asier_gm@yahoo.es','Asier Galea','C/ General Arteche 1 4ºC','San Sebastián','País Vasco','SPAIN','20002','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 19:33:55',0,NULL,3,1,3,1,'RA184522491CN\r ','hermeshine'),(25618,854734753002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',2,'AKT014',79.98,'hermeshine','kverna1987','kverna@gmail.com','Anders Kverneng','Holmestrandsveien 22','Drammen','Buskerud','NORWAY','3041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 19:57:49',0,NULL,3,1,5,1,'CP246990457CN ','hermeshine'),(25619,854797594002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','monteforyou','monteymarea@terra.es','Juan Manuel Lores Sanchez','avenida pipaces 38','San Isidro','Andalucía Ceuta y Melilla','SPAIN','04117','653985305','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 22:13:31',0,NULL,3,1,11,1,NULL,'hermeshine'),(25620,810107104001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',3,'AD1225',10.5,'hermeshine','acoelho73','acoelhocoelho@gmail.com','António Coelho','Praceta Doutor Egas Moniz N 189 4 Esq','Ovar','Valega','PORTUGAL','3880 682','962387300','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 22:21:59',0,NULL,3,1,11,1,NULL,'hermeshine'),(25621,630067746003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','bamrudj','jan.erik@bamrud.no','Jan Erik Bamrud','Drammen postterminal, Teknisk avd.<br>Ingv. Ludvigsensgate 21','Drammen','N/A','NORWAY','3007','+47 99251450','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 23:02:29',0,NULL,3,1,5,1,'CP246990474CN ','hermeshine'),(25622,810124878001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','leifertsan','roger.leifert@freenet.de','Roger Leifert','Hans-Böckler-Allee 87','Aachen','','GERMANY','52074','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-09 23:10:57',0,NULL,3,1,3,1,'RA184522430CN\r ','hermeshine'),(25623,854826484002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 23:30:51',0,NULL,3,1,3,0,'RA184522412CN\r ','hermeshine'),(25624,810132317001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','vidz_formers','multicare.enterprise@gmail.com','NUNKOO Gopal','Ave, Belle Isle Bambous','Bambous Medine','','MAURITIUS','230','7508622','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-09 23:35:03',0,NULL,3,1,3,1,'RA184522505CN\r ','hermeshine\r英标'),(25625,877819698017,270860550846,'Promotion！New EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.4,'photographyacc','antxonperdido','1tu@hotmail.es','JOSE MIGUEL  MORAL RUEDA','CL. DUQUES DE NAJERA, 39-6 DCHA.','LOGROÑO','La Rioja','SPAIN','26002','941205357','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-10 00:06:41',0,NULL,3,1,11,1,NULL,'photographyacc'),(25626,877820785017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',17.1,'photographyacc','hulahoopkids','tambrown77@bigpond.com','Tammy  Brown','11 Hewitt St','Colac','Victoria','AUSTRALIA','3250','0401518033','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 00:10:01',0,NULL,3,1,3,1,'RA184590845CN\r ','photographyacc'),(25627,810135880001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','alainice06','gromalain@yahoo.fr','gromy alain','hopital ste marguerite centre hyperbare<br>270 boulevard ste marguerite','MARSEILLE','Provence-Alpes-Côte d\'Azur','FRANCE','13009','0660892365','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-09 23:45:42',0,NULL,3,1,3,1,'RA184522412CN\r ','hermeshine\r斜臂   1\r反光板 110cm 5合1  1'),(25628,854294810002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',3,'AD1198',98.97,'hermeshine','melate8','tonefotos@hotmail.com','Susana Alvarez','Rincon 204<br>entre Matamoros y Morelos','Navojoa','Sonora','MEXICO','85830','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 01:46:36',0,NULL,3,1,3,1,'RA184522823CN\r ','hermeshine\r'),(25629,854865912002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','rossperchulo','r-malysh@ukr.net','Rostyslav Malysh','8161 Enger Ln<br>Apt 2','River Grove','IL','UNITED STATES','60171-3336','(773) 543-1258','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 01:54:38',0,NULL,3,1,17,0,'LK231060282CN ','hermeshine'),(25630,810170311001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','rossperchulo','r-malysh@ukr.net','Rostyslav Malysh','8161 Enger Ln<br>Apt 2','River Grove','IL','UNITED STATES','60171-3336','(773) 543-1258','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 01:56:51',0,NULL,3,1,1,1,'LK231060282CN ','hermeshine\r无牌方镜 渐变日落   1\r无牌方镜 渐变灰 （nd8）  1'),(25631,810179627001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','portugalmade','jcadima@sapo.pt','José Cadima','Rua Dr. Alberto Cunha Rocha Saraiva, Nº 1','Trancoso','','PORTUGAL','6420-194','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 02:35:47',0,NULL,3,1,3,1,'RA184522426CN\r ','hermeshine\rM 已入库\r\r'),(25632,810180461001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','marekic','mbaksa@gmail.com','Mario Baksa','R. Boskovica 7A<br>Selnik','Ludbreg','CROATIA','CROATIA','42230','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 02:38:18',0,NULL,3,1,11,1,NULL,'hermeshine'),(25633,816979470018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.08,'photographyacc','2010blackvelvet','fslappe2002@hotmail.com','Francis Lappe','PO Box 543','Banora Point','New South Wales','AUSTRALIA','2486','0755248836','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 02:38:01',0,NULL,3,1,11,1,NULL,'photographyacc'),(25634,817050325018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','brentm84','b.munro@ecu.edu.au','Brent Munro','31 San Teodoro Avenue','SINAGRA','Western Australia','AUSTRALIA','6065','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 08:03:48',0,NULL,3,1,11,1,NULL,'photographyacc'),(25635,810274759001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','emmalee106','emmamin206@hotmail.com','Emma Jones','44 Close Tyn Y Coed<br>Sarn','Bridgend','Bridgend','UNITED KINGDOM','CF32 9PQ','07949870359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 09:48:43',0,NULL,3,1,11,1,NULL,'hermeshine'),(25636,810278180001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','mr-gorilla','mark_e_pooo@yahoo.com.au','mark cooper','DKX1 CAD Group, North Wing - Nissan Technical Centre (Europe) Ltd<br>Cranfield Technology Park., Moulsoe Road','Bedford','Bedfordshire','UNITED KINGDOM','MK43 0DB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 09:55:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(25637,817087481018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','chrisiey7463','chrisiey@hotmail.com','Chris Caldwell','16 Carramar Close','Brandy Hill','New South Wales','AUSTRALIA','2324','0423285883','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 10:17:44',0,NULL,3,0,11,1,NULL,'photographyacc\r1.6*2.1  黑色'),(25638,963053535015,250692241207,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',22,'hutongstore','stevekz234','contact@socialimpactmedia.com','Stephen Kelly','3 Clayton Street','Peakhurst','New South Wales','AUSTRALIA','2210','0295343319','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-10 10:31:05',0,NULL,3,1,3,1,'RA184522457CN\r ','hutongstore'),(25639,855016389002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','anramsu','antti@yyterinpoppoo.com','Antti Ramstedt','Kanttorintie 10','Pori','Oletus','FINLAND','28840','+358 407302286 ','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 12:07:32',0,NULL,3,1,3,0,'RA184522514CN\r ','hermeshine'),(25640,810319440001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','anramsu','antti@yyterinpoppoo.com','Antti Ramstedt','Kanttorintie 10','Pori','Oletus','FINLAND','28840','+358 407302286 ','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 12:07:33',0,NULL,3,1,3,0,'RA184522514CN\r ','hermeshine'),(25641,810319441001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',3,'AE3103',29.4,'hermeshine','anramsu','antti@yyterinpoppoo.com','Antti Ramstedt','Kanttorintie 10','Pori','Oletus','FINLAND','28840','+358 407302286 ','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 12:07:34',0,NULL,3,1,3,1,'RA184522514CN\r ','hermeshine\r爵影碗罩P4  1\r1.6*2.1  黑色  1\r大力夹云台  3'),(25642,817163583018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',4,'AD1169',24.32,'photographyacc','papounetdaddy','peoocreation@gmail.com','VALENTIN DELUY','16 montee de la glaciere','Salon-de-Provence','Provence-Alpes-Côte d\'Azur','FRANCE','13300','06.70.94.79.90.','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-10 13:51:34',0,NULL,3,1,11,1,NULL,'photographyacc'),(25643,963159717015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',3,'AD1199',56.7,'hutongstore','hollandermarc','hollandermarc@hotmail.com','Marc Hollander','Schumannlaan 141','Zwolle','','NETHERLANDS','8031 EZ','+31641752388','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 14:33:57',0,NULL,3,1,3,1,'RA184522528CN\r ','hutongstore'),(25644,963166178015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','vondeyen','vondeyen@post8.tele.dk','Jan von Deyen','Engvej 25','Nyköbing F','','DENMARK','DK4800','54822030','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 14:46:41',0,NULL,3,1,11,1,NULL,'hutongstore'),(25645,817193360018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',3,'AD1137',85.47,'photographyacc','not-humdrum','not-humdrum@hotmail.de','Not-Humdrum D.Sign UGhb c/o Michael Nörling','Haubahn 20','Wuppertal','','GERMANY','42119','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-10 15:02:17',0,NULL,3,0,4,1,'YW870147124CN ','photographyacc\r3XL 3个\r已入库'),(25646,963180211015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','dumpman1','dumpman1@hotmail.co.uk','Chris Bedford','Adelphi Group<br>Olympus House, Mill Green Road','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 1XQ','01444472324','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 15:13:32',0,NULL,3,1,11,1,NULL,'hutongstore'),(25647,810408009001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','shinzai','salomaoshinzai@yahoo.com.br','Salomão Shinzai','Rua Antônio Parreiras casa 105','Niterói','Rio de Janeiro','BRAZIL','24210-320','36175621','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 15:57:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(25648,810400732001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',3,'AO0006',32.97,'hermeshine','portalafurtuna','amafiaboy@hotmail.com','giovanni neroni','alte bernstrasse 198','steffisburg bern','','SWITZERLAND','3613','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 15:40:20',0,NULL,3,0,3,1,'RA184522465CN\r ','hermeshine\r1.6*2.1 黑色，绿色，蓝色'),(25649,963218088015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','jarza_s','jsavijarvi@gmail.com','Jari Savijärvi','Varvikontie 17','JÄMSÄ','','FINLAND','42100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 16:17:58',0,NULL,3,1,3,1,'RA184522531CN\r ','hutongstore'),(25650,943227473016,260768455940,'New 67mm Lenscap for Canon Lens Snap-on 67  Front Cap',1,'AA1302',1.87,'hutongstore','malone788','malone788@aol.com','Steven Smith','18 Shilton Road','Carterton','Oxfordshire','UNITED KINGDOM','OX18 1EH','01993842612','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 16:26:13',0,NULL,3,1,11,1,NULL,'hutongstore'),(25651,963229345015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','hollie696_88','hollie696@hotmail.com','hollie lee','8 milton close','dover','Kent','UNITED KINGDOM','CT16 2BG','01304822193','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-10 16:36:31',0,NULL,3,1,4,1,'YW870147076CN ','hutongstore\r黑加白'),(25652,810467644001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',35.99,'hermeshine','vsamson-2012','vsamsonoff.vs@gmail.com','v samson','Vatutina (Ватутина)','Moscow','','RUSSIAN FEDERATION','12135',' 11111111111111','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 17:51:14',0,NULL,3,1,17,0,'CP246990488CN  ','hermeshine'),(25653,810467646001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','vsamson-2012','vsamsonoff.vs@gmail.com','v samson','Vatutina (Ватутина)','Moscow','','RUSSIAN FEDERATION','12135',' 11111111111111','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 17:51:15',0,NULL,3,1,17,0,'CP246990488CN  ','hermeshine'),(25654,855163907002,120461606047,'New 64\" Pro metal Tripod FT-6662A with Ballhead Bag',1,'AE1601',61,'hermeshine','vsamson-2012','vsamsonoff.vs@gmail.com','v samson','Vatutina (Ватутина)','Moscow','','RUSSIAN FEDERATION','12135',' 11111111111111','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 17:51:13',0,NULL,3,1,5,1,'CP246990488CN ','hermeshine\r2.5m高灯架  1\r4灯头 灯头 孔  1    欧标\r50cmx70cm 的柔光箱 (配4灯头）  1\r三脚架  伟峰 WF-6662A  1\r\r'),(25655,878189227017,270747070236,'New Neoprene Neck Shoulder Strap for Canon SLR camera',1,'AB1404',4.83,'photographyacc','knirob6086','kni.rob@bigpond.com','Rob Knight','42/25 Coopers Road','Willowbank','Queensland','AUSTRALIA','4306','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-10 18:12:25',0,NULL,3,1,11,1,NULL,'photographyacc'),(25656,810479819001,110734602062,'Promotion！EW-78D Lens Hood for Canon EF-S 18-200mm ',1,'AA3405',9.99,'hermeshine','mpin4741','mpineau1963@gmail.com','Michel Pineau','349 Tadoussac','Otterburn Park','QC','CANADA','j3h5n4','(514) 291-6781','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 18:12:49',0,NULL,3,1,11,1,NULL,'hermeshine'),(25657,943313972016,260660055377,'40\'\'x 60\'\' Collapsible 5-in-1 Photo Reflector Oval Disc',1,'AC3201',26.5,'hutongstore','metos-75','metos00@gmail.com','SAROS - Aymeric LE BRETON','6 rue de la Tremoille','Paris','Ile-de-France','FRANCE','75008','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 18:37:42',0,NULL,3,1,3,1,'RA184522602CN\r ','hutongstore'),(25658,878183122017,270753487143,'New Camera Body and Rear Lens Cap for Nikon D80 D40 D90',1,'AA1314',2.84,'photographyacc','shetata','tanashet@gmail.com','Tatiana Shevtsova','Titova street 30 - 64','Volgograd','Volgogradskay oblast','RUSSIAN FEDERATION','400123','8442718931','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-10 18:10:00',0,NULL,3,1,11,1,NULL,'photographyacc'),(25659,810499913001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','aaclub9824','aac1986@gmail.com','ANGUS YUEN','9824 Rathburn Drive','Burnaby','BC','CANADA','V3J 7L1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 18:50:21',0,NULL,3,1,3,1,'RA184590355CN\r ','hermeshine'),(25660,855196780002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','namelessamy','emailamy@myway.com','Amy Wonch','2300 W County Road 38 E<br>Lot 45','Fort Collins','CO','UNITED STATES','80526-6458','(970) 372-2149','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 18:50:32',0,NULL,3,1,1,1,'LK231096450CN ','hermeshine'),(25661,943349393016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','moooman777','madmooo@optusnet.com.au','Martin  Muirhead','68 Vincennes<br>Avenue','Tregear','New South Wales','AUSTRALIA','2770','0288071139','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-10 19:23:45',0,NULL,3,1,11,1,NULL,'hutongstore'),(25662,855224976002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:15',0,NULL,3,1,3,0,'RA184522545CN ','hermeshine'),(25663,855224978002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',37.89,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 19:41:15',0,NULL,3,1,3,0,'RA184522545CN ','hermeshine'),(25664,855224980002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:16',0,NULL,3,1,17,0,'CP246990505CN   ','hermeshine'),(25665,810529693001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 19:41:18',0,NULL,3,1,17,0,'CP246990465CN  ','hermeshine'),(25666,855224983002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:18',0,NULL,3,1,3,1,'RA184522545CN\r ','hermeshine\r闪光灯B座   1\r反光板 100*150 40*60 5合1  1\r灯架包厚   1\r申报commercial sample $30'),(25667,808390637001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:20',0,NULL,3,1,17,0,'CP246990465CN ','hermeshine'),(25668,855229853002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','kazladoeff','lissitsian@gmail.com','Alexander Lissits','59-3420 Vialoux Drive','Winnipeg','MB','CANADA','R3R0A4','(204) 417-5469','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:49:01',0,NULL,3,1,3,1,'RA184522559CN\r ','hermeshine'),(25669,810529695001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',2,'AD1217',71.98,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:19',0,NULL,3,1,5,1,'CP246990505CN ','hermeshine\r反光伞110cm   1\r2.5m高灯架  2\r\r申报commercial sample $30'),(25670,810545219001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',3,'AE3401',77.97,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:08:05',0,NULL,3,1,17,0,'CP246990491CN  ','hermeshine'),(25671,855240185002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:08:08',0,NULL,3,1,17,0,'CP246990491CN  ','hermeshine'),(25672,855240186002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','qurlson','qurlsoni@gmail.com','ILYA Parubenko','Volgogradsky prospekt d.68/2 kv.51','Moskow','','RUSSIAN FEDERATION','109462','(495)1774487','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:08:09',0,NULL,3,1,5,1,'CP246990491CN ','hermeshine\r灯架  2m   3\r伞式柔光箱 80cm 8角     1\r85cm 两用伞   1'),(25673,855241729002,120526192014,'NEW 77mm Snap-on Front Lens Cap for Nikon 77 Lenscap',1,'AA1309',2.6,'hermeshine','erik_efv','erik@u2us.nl','Erik de Vries','Stellingmolenstraat 56','Culemborg','','NETHERLANDS','4105 XG','+31345512489','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 20:09:47',0,NULL,3,1,11,1,NULL,'hermeshine'),(25674,855224981002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','andreasmsx','andreas.saxegaard@gmail.com','Andreas Saxegaard','Øyjordsveien 11, leil. 508','BERGEN','','NORWAY','5038','004798846145','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 19:41:17',0,NULL,3,1,5,1,'CP246990465CN ','hermeshine\r斜臂   1\r灯架  2m  2\r反光板支架  1\r申报commercial sample $30'),(25675,943413412016,260692183564,'Neoprene Protector Camera Cover Case for SLR semi slr S',1,'AC2301',4.2,'hutongstore','looby*','dark_dave25@yahoo.co.uk','David Smith','SATRA<br>Telford Way Ind. Estate','Kettering','Northamptonshire','UNITED KINGDOM','NN16 8SD','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 20:54:51',0,NULL,3,1,11,1,NULL,'hutongstore'),(25676,963415878015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','dil6969','ian.laycock@btinternet.com','DI  Laycock','4 Delamere Close','Accrington','Lancashire','UNITED KINGDOM','BB55DW','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-10 21:02:37',0,NULL,3,1,3,1,'RA184522633CN\r ','hutongstore\r澳转英标'),(25677,635951056004,140679559505,'Promotion ! NEW Square Gradual Graduated Brown Color Filter for Cokin P Series',1,'AD1227',3.5,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:46',0,NULL,8,1,17,0,NULL,'hermeshine'),(25678,855291925002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:47',0,NULL,8,1,17,0,NULL,'hermeshine'),(25679,635949616004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:47',0,NULL,8,1,17,0,NULL,'hermeshine'),(25680,855289933002,120448639014,'72mm 72 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT023',4.1,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:49',0,NULL,8,1,17,0,NULL,'hermeshine'),(25681,810595519001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:50',0,NULL,8,1,17,0,NULL,'hermeshine'),(25682,855290719002,120500417697,'72mm CPL Circular Polarizing Filter 72 CPL Green.L ',1,'AA3313',6.6,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:50',0,NULL,8,1,17,0,NULL,'hermeshine'),(25683,810595428001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','p_priesnitz','ppriesnitz@email.cz','Pavel Priesnitz','Jasanova 20','Brno','','CZECH REPUBLIC','63700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 21:56:51',0,NULL,3,1,3,1,'RA184522845CN\r ','hermeshine\r无牌方镜 渐变棕   1\r无牌方镜 渐变日落   1\r无牌方镜 渐变灰 （nd4）1\r方形滤镜接口环 72mm   1\r方镜普通托架（三槽）  1\r无牌方镜 渐变灰 （nd2）  1\r绿叶 CPL 72mm  1\r无牌方镜 渐变灰 （nd8）  1'),(25684,855111802002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','bombon-456','jrm@foxvalley.net','Ricardo Mancha','164 DIVISION ST<br>Ste 101','ELGIN','IL','UNITED STATES','60120-5532','(847) 931-5225','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-10 22:01:50',0,NULL,3,1,3,1,'RA184522647CN\r ','hermeshine'),(25685,810637154001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',29.99,'hermeshine','auraibis','audrius.raibis@gmail.com','Audrius Raibis','Taikos pr. 65-89','Kaunas','','LITHUANIA','50436','+37065559265','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 23:25:49',0,NULL,3,1,3,1,'RA184522562CN\r ','hermeshine'),(25686,810643154001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','trevor_qld','trevorcook1@bigpond.com.au','Trevor Cook','10 Flametree st<br>Bridgeman Downs','Brisbane','Queensland','AUSTRALIA','4035','0738630167','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-10 23:42:48',0,NULL,3,0,3,1,'RA184522655CN\r ','\rhermeshine\r3XL 已入库'),(25687,810645488001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','laurence108','laurence108@hotmail.com','Laurence Castle','4/1 Maud street','Hazelwood Park','South Australia','AUSTRALIA','5066','0466422015','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-10 23:50:00',0,NULL,3,1,3,1,'RA184522576CN\r ','hermeshine'),(25688,855346515002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',3,'AB3329',146.97,'hermeshine','vicferber','vifebe@hotmail.com','Victor Fernandez','ave 19 num 310','Cordoba','Veracruz','MEXICO','94580','2711220135','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 00:04:17',0,NULL,5,0,18,0,NULL,'hermeshine\r分开发也不是太合适\r发信加$9运费，付款后分开发'),(25689,855348984002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',31.34,'hermeshine','donaldejose','djose1@comcast.net','Donald E Jose','108 Tramore Cir','Malvern','PA','UNITED STATES','19355-3182','(610) 889-5675','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 00:11:36',0,NULL,3,1,3,1,'RA184522580CN\r ','hermeshine'),(25690,855361450002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',62.68,'hermeshine','xtremeelement','xtremeelement@msn.com','Brandon Downhour','1609 Tattenham Way','Orlando','FL','UNITED STATES','32837-6513','(407) 859-3452','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-11 00:52:12',0,NULL,3,1,3,1,'RA184522593CN\r ','hermeshine'),(25691,963545797015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.45,'hutongstore','sguzak','guzak@azet.sk','Stanislav Guzak','Cernysevskeho 23','Bratislava','','SLOVAK REPUBLIC','85101','00421904190343','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 01:34:12',0,NULL,3,1,11,1,NULL,'hutongstore'),(25692,855375338002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','z3zo11','safethadzimusic@gmail.com','Safet Hadzimusic','Očaktanum 26','Sarajevo','Sarajevo','BOSNIA AND HERZEGOVINA','71000','+38761709988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 01:40:42',0,NULL,3,1,3,0,'RA184522749CN\r ','hermeshine'),(25693,810684766001,110499652261,'New Umbrella in Silver 85cm / 33.5\"',1,'AD1401',9,'hermeshine','z3zo11','safethadzimusic@gmail.com','Safet Hadzimusic','Očaktanum 26','Sarajevo','Sarajevo','BOSNIA AND HERZEGOVINA','71000','+38761709988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 02:03:20',0,NULL,3,1,3,1,'RA184522749CN\r ','hermeshine\r斜臂   1\r反光伞  1'),(25694,810686714001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','explosiu','kort89700@gmail.com','Wilson Apaestegui','Nonbe 1-1-12<br>Ozakizen haitsu 2-C','Suzuka','Mie','JAPAN','5130024','08069183108','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 02:13:49',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(25695,943559998016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','ibrartariq','ibrar_tariq@yahoo.com','Ibrar Tariq','4 Blenheim Road','LONDON','London','UNITED KINGDOM','E15 1UF','07773080686','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 02:19:35',0,NULL,3,1,11,1,NULL,'hutongstore'),(25696,855389416002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ddre9415','ardentmill@bigpond.com','D Drew','Ardent Mill  po box 62<br>720 Elliott Way','Tumbarumba','New South Wales','AUSTRALIA','2653','0448667883','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 02:27:01',0,NULL,3,1,11,1,NULL,'hermeshine'),(25697,963566532015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','oehlersklaus','klaus@oehlers.dk','Klaus Øhlers','granvej 34','Espergærde','Dk','DENMARK','3060','+4529724555','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-11 02:32:12',0,NULL,3,1,3,1,'RA184522752CN\r ','hutongstore'),(25698,878463605017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',190,'photographyacc','03.robert34','chris34.1994@hotmail.com','Robert Di Blasi ','1 Gala Place <br>Keilor Downs','Melbourne ','Victoria','AUSTRALIA','3038','0393665135','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-11 05:14:10',0,NULL,3,1,4,1,'YW870147161CN\r ','photographyacc\r澳标'),(25699,810735109001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','amallbaby','andrene_lowe24@yahoo.com','Andrene Lowe','Lot 174 WoodStock Housing Scheme','Buff Bay','Portland','JAMAICA','1876','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 05:31:37',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  白色  1'),(25700,963639842015,250692239066,'New Hot Shoe Cover for Nikon Fuji Canon Pentax OLYMPUS',1,'AA1204',1.5,'hutongstore','arturocarras','arturo.carrasco@gmail.com','Arturo Carrasco Ruiz','C/ Antonio Diaz Canabate, 26','Azuqueca de Henares-Guadalajara','Castilla-La Mancha','SPAIN','19200','605091872','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 06:58:35',0,NULL,3,1,11,1,NULL,'hutongstore'),(25701,878486925017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.14,'photographyacc','arturocarras','arturo.carrasco@gmail.com','Arturo Carrasco Ruiz','C/ Antonio Diaz Canabate, 26','Azuqueca de Henares-Guadalajara','Castilla-La Mancha','SPAIN','19200','605091872','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-11 07:03:26',0,NULL,3,1,11,1,NULL,'photographyacc'),(25702,855455419002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','rsviktorich','rodik62@yandex.ru','Sergey Rodionov','Lunacharskogo 62-2-306','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','194354','+79219143944','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 07:24:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(25703,810765230001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','sveen14','asveen72@hotmail.com','Andre Sveen','Glimmerveien 5','Oslo','oslo','NORWAY','1155','46966100','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 07:57:53',0,NULL,3,1,11,1,NULL,'hermeshine'),(25704,810767556001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','jd-muchmores','juliandyer@live.com','Julian Dyer','2 Muchmores Cottage<br>Blake End Road, Great Saling','Braintree','Essex','UNITED KINGDOM','CM7 5DS','01376349054','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 08:06:58',0,NULL,3,1,11,1,NULL,'hermeshine'),(25705,810808955001,110604497800,'New Multi Purpose Heavy  Spring  Clamp with Ball head',1,'AE3103',9.8,'hermeshine','ajvek2012','ivranjic@gmail.com','Ivica Vranjic','B.A.Krcelica 19','Zapresic','','CROATIA','10290',' 0038598735030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 10:04:59',0,NULL,3,1,11,1,NULL,'hermeshine'),(25706,810819167001,110731646314,'New 200w Photo Studio Mini Flash Kit + Soft Box + Stand',1,'AKT085',108,'hermeshine','sm_grey','sm.grey@mail.ru','Sergei Mityukov','Kirova, 26A, 50','Smolensk','Smolensk region','RUSSIAN FEDERATION','214004','89051616999','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 10:27:28',0,NULL,3,1,5,1,'CP246990430CN ','hermeshine\r欧标'),(25707,960644770015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','lenny.brans','len_3000@hotmail.com','Lenny Brans','Arthur Goemaerelei 48 Bus 5','Antwerpen','','BELGIUM','2018','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 10:27:47',0,NULL,3,1,11,1,NULL,'hutongstore');
INSERT INTO `hmsh_ebay_transaction` VALUES (25708,963741650015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','o_watkinson','o_watkinson@hotmail.com','Oliver Watkinson','7 Linden Court<br>Holyoake Road','Headington','Oxford','UNITED KINGDOM','OX3 8AS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 10:58:11',0,NULL,3,1,11,1,NULL,'hutongstore'),(25709,810832695001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ystive2','ystive@walla.co.il','Stanislav Yelisevich','Ha-Noter str\' 34A/3','Haifa','Kiriat Haim','ISRAEL','26307','972522799878','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 11:00:20',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(25710,943739375016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','reenadk','reenakisun@shaw.ca','Reena Kisun','412-1230 East 8th Avenue','Vancouver','BC','CANADA','V5T1V2','(604) 879-1300','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 11:02:29',0,NULL,3,1,3,1,'RA184522664CN\r ','hutongstore'),(25711,855534414002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','valerybuchko1984','valerybuchko2@gmail.com','Valery Buchko','10 district 1A - 10','Balkhash','Karagandinskaya obl','KAZAKHSTAN','100300','(701) 727 - 4947','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 11:07:06',0,NULL,3,1,17,0,'CP246990386CN  ','hermeshine'),(25712,810836909001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','valerybuchko1984','valerybuchko2@gmail.com','Valery Buchko','10 district 1A - 10','Balkhash','Karagandinskaya obl','KAZAKHSTAN','100300','(701) 727 - 4947','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-11 11:07:07',0,NULL,3,1,8,1,'CP246990386CN ','hermeshine\r伞式柔光箱 80cm 8角     1\r灯架  2m  1\r斜臂   1'),(25713,963760004015,250621654248,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',14.99,'hutongstore','moonmen51','moonmen@op.pl','Szymon Wnetrzak','glebemount 17','wicklow town','WICKLOW CO','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 11:32:03',0,NULL,3,1,3,0,'RA184522616CN\r ','hutongstore'),(25714,963765054015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','moonmen51','moonmen@op.pl','Szymon Wnetrzak','glebemount 17','wicklow town','WICKLOW CO','IRELAND','default','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-11 11:41:29',0,NULL,3,1,3,1,'RA184522616CN\r ','hutongstore\r圆形柔光棚 50cm  1\r115w 5500k 灯泡  220v  4'),(25715,810805160001,110533632067,'New Diffuser for external flash sb800 sb700 580ex metz',1,'AB3314',6.9,'hermeshine','missmellanie83','mellsemail2008-home@yahoo.com.au','Mellanie Satie','26A PURVES WAY','HAYNES','Western Australia','AUSTRALIA','6112','0424182830','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 11:53:06',0,NULL,3,1,11,1,NULL,'hermeshine'),(25716,855554906002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','janmoehler','jan.moehler@t-online.de','Jan-Marc Möhler','Robert-Koch-Str. 68','Eningen','','GERMANY','72800','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-11 11:55:52',0,NULL,3,0,3,1,'RA184522678CN\r ','hermeshine\rXL  已入库'),(25717,810857448001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','ghoostt','anndrius@gmail.com','Andrius Ribinskas','J.Basanavičiaus 12','Varėna','','LITHUANIA','65217','+37062112860','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 12:29:42',0,NULL,3,1,11,1,NULL,'hermeshine'),(25718,855587136002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','evenaug','even.augdal@gmail.com','Even Sverdrup Augdal','Kirkeveien 145','Oslo','Oslo','NORWAY','0361','99159607','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 13:07:25',0,NULL,3,1,3,1,'RA184522681CN\r ','hermeshine\r申报$25'),(25719,810895973001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','ergonaut','erg@pisem.net','Ivan Balakaev','str.Capitan Burkov\'s 11/18-6','Murmansk','','RUSSIAN FEDERATION','183025','+7-902-281-97-25','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 13:16:18',0,NULL,3,1,5,1,'CP246990412CN ','hermeshine'),(25720,855592939002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','majormfrf','shtuchkaz@yandex.ru','Andrey Shtuchka','Yangelya st., 6/74','Baykonur','KZ','KAZAKHSTAN','468320','7(33622)70348','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 13:21:25',0,NULL,3,1,8,1,'CP246990562CN\r ','hermeshine\r白色布\r欧标'),(25721,855614020002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','sirvit','sirvitforum@rambler.ru','Buranov Vitaliy','Zorge st. 90 flat 256','Novosibirsk','','RUSSIAN FEDERATION','630106','79137059295','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 14:02:08',0,NULL,3,1,11,1,NULL,'hermeshine'),(25722,855634860002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','mattysek1','martas44@gmail.com','Martina Crlová','1.máje 1023','Zlín 4','Czech Republic','CZECH REPUBLIC','76302','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 14:43:49',0,NULL,3,1,11,1,NULL,'hermeshine'),(25723,855657515002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','jfsehan','jfsehan@wanadoo.fr','Sehan Jean-Francois','5 route des Magriaux','La groutte','Centre','FRANCE','18200','0248962176','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 15:22:20',0,NULL,3,1,11,1,NULL,'hermeshine'),(25724,811006213001,110734435190,'Full ND + Gradual ND Filter Kit for Cokin P Series 6pcs',1,'AKT081',27.2,'hermeshine','donhil1234','chrishantha@msn.com','Valentyna Dzyubenko','Loeschniggasse 1/4/9','Wien','','AUSTRIA','1220','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-11 16:27:24',0,NULL,3,1,3,1,'RA184522695CN\r ','hermeshine'),(25725,811039690001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','chema1024','chema1024@hotmail.com','Chema Perez','Apartado 397','Villagarcia de Arosa','Galicia','SPAIN','36600','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-11 17:10:28',0,NULL,3,1,3,1,'RA184522704CN\r ','hermeshine'),(25726,855736196002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','tuzemec9','samosa1@mail.ru','Andrey Samokhvalov','Rostovka 9 - 67','Omsk','','RUSSIAN FEDERATION','644527','9136004476','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:14:39',0,NULL,3,1,11,1,NULL,'hermeshine'),(25727,943985625016,260894475364,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',9.8,'hutongstore','michael_hanson','eileenanneronan@gmail.com','Michael Hanson','6 Netherwood Road','London','London','UNITED KINGDOM','W14 0BJ','02076026347','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 17:05:18',0,NULL,3,1,11,1,NULL,'hutongstore'),(25728,855753098002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',6,'AA3301',19.5,'hermeshine','dentaire09','mendibule27@hotmail.com','Paul Corbeil','249, Rang 2','Trois-Rives','QC','CANADA','G0X2C0','(819) 601-2914','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:34:32',0,NULL,3,1,3,1,'RA184522620CN\r ','hermeshine'),(25729,855755323002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',31.34,'hermeshine','forken242','romanantunes@gmail.com','Roman Antunes','Av. Santa Fe 4990 1 i','Buenos Aires','Buenos Aires','ARGENTINA','C1425BHY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:38:35',0,NULL,3,1,3,0,'RA184522797CN\r ','hermeshine'),(25730,811068793001,110502915971,'New 55mm ring adapter replacement for cokin P series',1,'AA2209',2.18,'hermeshine','forken242','romanantunes@gmail.com','Roman Antunes','Av. Santa Fe 4990 1 i','Buenos Aires','Buenos Aires','ARGENTINA','C1425BHY','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 17:43:40',0,NULL,3,1,3,1,'RA184522797CN\r ','hermeshine\r伞式柔光箱 60×90cm   1\r方形滤镜接口环 55mm  1'),(25731,963913662015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','peteyxo','jay_bonapartez@hotmail.com','Guilliano Arduin','Kranenbroekhof 10','Zaandam','','NETHERLANDS','1507 KK','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 18:26:01',0,NULL,3,1,11,1,NULL,'hutongstore'),(25732,811151148001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',6.21,'hermeshine','sambarhunt','scottsambar@hotmail.com','Scott Wilson','16 kingfisher drive','wodonga','Victoria','AUSTRALIA','3690','0417475889','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 19:03:49',0,NULL,3,1,11,1,NULL,'hermeshine'),(25733,944246806016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','yveskwijibo74','yveskwijibo@gmail.com','dantinne yves','rue des noyers 7','liege','','BELGIUM','4000','32499133829','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 20:37:18',0,NULL,3,1,11,1,NULL,'hutongstore'),(25734,964272903015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','tommybank','tommydevine@blueyonder.co.uk','Thomas Devine','3 Butterwick Drive<br>Croxteth Park','Liverpool','Merseyside','UNITED KINGDOM','L12 0JQ','01515473430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 20:50:45',0,NULL,3,1,11,1,NULL,'hutongstore'),(25735,811269238001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','mozesart-il','mozesart@gmail.com','moshe nachumovich','Rabi Akiva 31','Pardess Hanna','Pardess Hanna','ISRAEL','37041',' 972525275511','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 21:07:14',0,NULL,3,1,3,1,'RA184522783CN\r ','hermeshine'),(25736,855999202002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','juankaneda','juanpfailde@gmail.com','Juan Pablo Failde','Pasaje Aguaribay 6724','Buenos Aires','Buenos Aires','ARGENTINA','1407','01146412949','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:07:30',0,NULL,3,1,3,0,'RA184522806CN\r ','hermeshine'),(25737,811311274001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',15.9,'hermeshine','juankaneda','juanpfailde@gmail.com','Juan Pablo Failde','Pasaje Aguaribay 6724','Buenos Aires','Buenos Aires','ARGENTINA','1407','01146412949','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:10:39',0,NULL,3,1,3,1,'RA184522806CN\r ','hermeshine\r斜臂  1\r反光板支架的夹子（双轮）   1'),(25738,811319546001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:25:12',0,NULL,3,1,17,0,'RA184590267CN ','hermeshine'),(25739,811317554001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:25:12',0,NULL,3,1,3,1,'RA184590267CN\r\r ','hermeshine\r3m 横杆（通用4节）   2\r'),(25740,856014436002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','victorvicente86','victorvice86@gmail.com','Victor Teixeira Vicente','Avenida Doutor Epitácio Pessoa<br>n°587 apto.83','Santos','São Paulo - SP','BRAZIL','11030-601','(13) 9783-7684','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:43:28',0,NULL,3,1,11,1,NULL,'hermeshine'),(25741,811003782001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',8.99,'hermeshine','hannaan09','hanna_aa_n@hotmail.com','Hanna Aarnes Nisja','Thomas Angells gate 20<br>c/o rom 312','Trondheim','NC','NORWAY','7011','91535242','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 22:57:37',0,NULL,3,1,11,1,NULL,'hermeshine'),(25742,964383295015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','nidge001','nigel.p@ntlworld.com','Nigel Penn','52 Intake Lane<br>Ossett','Wakefield','West Yorkshire','UNITED KINGDOM','WF5 0RG','07842055276','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 23:19:19',0,NULL,3,1,3,1,'RA184590275CN\r ','hutongstore'),(25743,964390302015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','benjamminmagic','zitouniatis@gmail.com','Dimos Dimitrios Zitouniatis','patron 3-5','Athens','Kolonos','GREECE','10444','0030 211 0114647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-11 23:33:36',0,NULL,3,1,3,1,'RA184522718CN\r ','hutongstore'),(25744,964389302015,250599423735,'67mm Snap-on Front Cap for Nikon 67mm Filters Lens New',1,'AA1307',1.88,'hutongstore','alwyng','a.griffith@talktalk.net','Alwyn Griffith','16 Broad Meadows','Sunderland','Tyne and Wear','UNITED KINGDOM','SR2 7NG','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-11 23:35:59',0,NULL,3,1,11,1,NULL,'hutongstore'),(25745,856046461002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','oddhoi54','ohoi@live.no','Odd Arne Høiby','Rabben 6','Lillehammer','Lillehammer','NORWAY','2611','41266535','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-11 23:48:52',0,NULL,3,1,5,0,'CP246990545CN\r ','hermeshine\r申报$30'),(25746,811360542001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','petitessoeurs06','marlene_b13@hotmail.com','Nicole Braquet','Lotissement les Templiers<br>1625 route de Nice','Aspremont','Provence-Alpes-Côte d\'Azur','FRANCE','06790','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 00:01:48',0,NULL,3,1,3,1,'RA184522721CN\r ','hermeshine'),(26030,857707773002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','coolmiss','aldegonde@gmail.com','Aldegonde Le Compte','rue petite coyarde 6 (or 8 if absent)','Mont Saint Andre (Ramillies)','','BELGIUM','1367','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:46:03',0,NULL,3,1,17,0,'RA184590837CN\r ','hermeshine'),(25747,811408388001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','maruko321','akan@ucla.edu','Andrew Kan','1800 Oak St<br>Unit 317','Torrance','CA','UNITED STATES','90501-3363','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-12 02:02:52',0,NULL,3,1,1,1,'LK231064372CN ','hermeshine'),(25772,8881331535447851,111,'1.6*2.1  红色背景布',1,'',0,'hermeshine','kozovod2010','kozovod@yandex.ru','Sergij Serik','st. Ladychuka, 125','Kherson','UA','UKRAINE','73008','+380509689884',NULL,NULL,NULL,'2012-03-12 06:57:27',0,NULL,3,0,3,1,'RA184522341CN\r\r ',' '),(25748,8881331518428106,111,'无牌方镜 渐变灰 （nd4） ',3,'AD1219',0,'hermeshine','fodi64','fojola@digikabel.hu','Fodor Jozsef','Tulipan u. 1. II/8.','Bekescsaba','','HUNGARY','5600','',NULL,NULL,NULL,'2012-03-12 02:13:48',0,NULL,3,1,3,1,'RA184522735CN\r ',NULL),(25749,818261815018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',4,'AD1169',25.6,'photographyacc','simondomares','caternorth@gmail.com','Craig Mc Donald','PO Box 71<br>James Cook University','Douglas','Queensland','AUSTRALIA','4811','0437774852','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 02:40:50',0,NULL,3,1,11,1,NULL,'photographyacc'),(25750,879212231017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','clowee007','tahleejade@bigpond.com','craig lewin','10 Ritche Road','Silverdale','New South Wales','AUSTRALIA','2752','0247740661','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 02:58:26',0,NULL,3,1,11,1,NULL,'photographyacc'),(25751,8881331521501138,111,'New Photo Studio Light Stand Umbrella Flash B-Mount set -Wholesale/ Retail [AKT014]',1,'AKT014',42.99,'aliexpress','1007285910 ','ddad@mail.ru','Dmitry Dobrokhvalov','Sovetskaya 60-14','Tver','Tverskaya','RUSSIAN FEDERATION','170100','+7 910 9358723',NULL,NULL,NULL,'2012-03-12 03:05:01',0,NULL,3,1,3,1,'RA184522386CN\r ',NULL),(25752,811433116001,110505570380,'Neoprene Lens Pouch bag Case 9.5cmx23cm 80-200 70-200',1,'AC1204',7.2,'hermeshine','selketh01','blade@telecable.es','Israel García Fernandez','c/ Pedro Pablo Nº2 5º Izq','Gijon','Asturias','SPAIN','33209','985093719','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:05:44',0,NULL,3,1,11,1,NULL,'hermeshine'),(25753,8881331521597600,111,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand - Wholesale/ Retail [AKT056]',1,'AKT056',50,'aliexpress','1007288111','wrost69@rambler.ru','Viktor Prikhodko','Kommunisticheskii st. 30/2 - ap.27','Rostov-na-Dony','Rostov region','RUSSIAN FEDERATION','344091','+7863 221 4563214',NULL,NULL,NULL,'2012-03-12 03:06:37',0,NULL,3,1,17,0,'CP246990390N ',NULL),(25754,8881331521732335,111,'Photo Studio Background Support Carrying Carry Bag - Wholesale/ Retail [AD1129]',1,'AD1129',8.99,'aliexpress','1007288112','wrost69@rambler.ru','Viktor Prikhodko','Kommunisticheskii st. 30/2 - ap.27','Rostov-na-Dony','Rostov region','RUSSIAN FEDERATION','344091','+7863 221 4563214',NULL,NULL,NULL,'2012-03-12 03:08:52',0,NULL,3,1,17,0,'CP246990390N ',''),(25755,8881331521841200,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail [AKT052]',1,'AKT052',42.99,'aliexpress','1007288110','wrost69@rambler.ru','Viktor Prikhodko','Kommunisticheskii st. 30/2 - ap.27','Rostov-na-Dony','Rostov region','RUSSIAN FEDERATION','344091','+7863 221 4563214',NULL,NULL,NULL,'2012-03-12 03:10:41',0,NULL,3,1,5,1,'CP246990390CN ','反光板支架  1 \r灯架  2m  1\r灯架包薄   1 \r2云柔    1'),(25756,8881331521986223,111,'Free shipping & Tracking # - 55mm 55 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon - AB1302',1,'AB1302',5.09,'aliexpress','1007307489','aligator147@mail.ru','Nik On','ul. Esenina 14/2 -293','Saint-Peterburg','Saint-Peterburg','RUSSIAN FEDERATION','194354','9650820924',NULL,NULL,NULL,'2012-03-12 03:13:06',0,NULL,3,1,3,1,'RA184522372CN\r ',NULL),(25757,8881331522080344,111,'Free shipping & Tracking # - New Pro 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND Filters of Cokin P Series - AE1202',2,'AE1202',10.78,'aliexpress','1007333363','jana_navarro@itelefonica.com.br','Janaina Navarro','Rua Israel Vieira Ferreira, 705 Bairro Presidente Medici','Itu','Sao Paulo','BRAZIL','13310-090','+055 011 81123399',NULL,NULL,NULL,'2012-03-12 03:14:40',0,NULL,3,1,3,1,'RA184522908CN\r ','速卖通'),(25758,854979318002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','dm-pal','dmpal@yandex.ru','Dmitriy Palyanov','Zavodskaya, 24a-55','Kondopoga','Karelia','RUSSIAN FEDERATION','186225','79214501223','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:28:17',0,NULL,3,0,3,1,'RA184522390CN\r ','hermeshine\r1.6*3  灰色'),(25759,856137386002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','scipio47','esfordham47@hotmail.com','ERIC FORDHAM','34 Brookview Dr','VERNON','CT','UNITED STATES','06066','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-12 03:37:36',0,NULL,3,1,1,1,'LK231376295CN ','hermeshine'),(25771,810178370001,110292526188,'10pcs Color Filter Box Ring & Holder for Cokin P series',1,'AKT006',61.5,'hermeshine','uyeyeauu','baebprasert@gmail.com','Mr. Kiattikun Baebprasert','Norton Rose (Thailand) Limited, 14th Floor, Sindhorn Tower 2,<br>130-132, Wireless Road, Lumpini, Pathumwan','Bangkok','','THAILAND','10330','+6622058510','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 06:52:33',0,NULL,3,1,3,1,'RA184522766CN\r ','hermeshine\r换成77mm 的接口环'),(25760,811447442001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ainsivalavie2011','vivelesavoir@gmail.com','Francis Dumais','195 rue Saint-Pierre','St-Jean-sur-Richelieu','QC','CANADA','J3B 5W5','(438) 238-3077','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:49:50',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(25761,856143458002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:01',0,NULL,3,1,17,0,'EE651291581CN ','hermeshine'),(25762,856143459002,120550522816,'New Timer Remote Control For Nikon MC-DC2 D90 D5000',1,'AA3220',45.9,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:02',0,NULL,3,1,17,0,'EE651291581CN  ','hermeshine'),(25763,811449308001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:03',0,NULL,3,0,17,0,'EE651291581CN  ','hermeshine'),(25764,811449309001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:04',0,NULL,3,1,17,0,'EE651291581CN ','hermeshine'),(25765,811449310001,110724664256,'New High quality heavy duty sand bag Shipped Empty',1,'AD1168',15,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:06',0,NULL,3,1,17,0,'EE651291581CN  ','hermeshine'),(25766,811449311001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','embroiderysecret','postmaster_maribelajarsulam@ymail.com','SYAHIDA RAMLI','NO 23 A, JALAN BBP1, TAMAN BATU BERENDAM PUTRA','BATU BERENDAM','MELAKA','MALAYSIA','75350','013-9854461','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 03:57:07',0,NULL,3,1,6,1,'EE651291581CN ','hermeshine\r单灯头  1   英标\r永诺 MC-N3  1\r1.6*2.1  黑色  1\r反光板支架   1\r沙袋（大）   1\r倒影板（白黑）  1'),(25767,856144692002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','principiodeljuego','nahuelsrnec@gmail.com','Nahuel Srnec','Pareja 2986','Capital Federal','Buenos Aires','ARGENTINA','1419','54 011 6979 1584','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 04:02:37',0,NULL,3,1,3,1,'RA184522267CN\r ','hermeshine'),(25768,856153636002,120526182972,'NEW 52mm Snap-on Front Lens Cap for Nikon 52 Lenscap',1,'AA1305',2.6,'hermeshine','andrew8t7','andrew8t7@yahoo.com','Andrew Nguyen','2375 Lass Dr','Santa Clara','CA','UNITED STATES','95054-1371','(408) 326-9549','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 04:37:41',0,NULL,3,1,1,1,'LK231463349CN ','hermeshine'),(25769,811474423001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','mirakoolz','mirakoolz@hotmail.com','Chi Vo','30 payton street','Canley Vale','New South Wales','AUSTRALIA','2166','0297249025','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 06:01:09',0,NULL,3,1,3,1,'RA184522324CN\r ','hermeshine'),(25770,856172104002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','sydneyfcchick12','sydneyfcchick@yahoo.com.au','Kristy Beck','56 Leumeah Rd','Leumeah','New South Wales','AUSTRALIA','2560','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 06:17:28',0,NULL,3,1,3,1,'RA184522338CN\r ','hermeshine'),(25773,811495120001,110744433768,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',18.5,'hermeshine','grandmax-kz','photographer.maxim@mail.ru','Mihail (father) or Elena (mother) or Maxim','Ainabulak-4 .173 .30','Almaty','','KAZAKHSTAN','050014','87051230505','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 07:48:41',0,NULL,3,1,11,1,NULL,'hermeshine'),(25774,856190333002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',37.89,'hermeshine','sabrinasaelle','saelle@gmail.com','Sabrina Wong','47 Vincent Street','Nedlands','Western Australia','AUSTRALIA','6009','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-12 07:49:30',0,NULL,3,1,3,1,'RA184522770CN\r ','hermeshine'),(25775,8881331538571850,111,'柔光伞',1,'',0,'hutongstore','twin2devine','brendandevine@hotmail.com','Brendan Devine','The Doctors Laboratory<br>Michigan Hs. Michigan Ave','Salford Quays Manchester','Lancashire','UNITED KINGDOM','M50 2GY','01613327181',NULL,NULL,NULL,'2012-03-12 07:49:31',0,NULL,3,0,3,1,'RA184590307CN\r ',NULL),(25776,856197264002,120649097131,'Collapsible 4.6\' x 5.7\' 190x140 cm backdrop green/blue',1,'AC3304',58,'hermeshine','ragdoll_matte','mona@pihl.nu','Mona Pihl','Nyvångsvägen 27','Helsingborg','','SWEDEN','25374','+4642165802','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 08:21:19',0,NULL,3,1,3,1,'RA184522854CN\r ','hermeshine'),(25777,811522268001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0039761411264','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 09:39:58',0,NULL,3,1,3,1,'RA184522837CN\r ','hermeshine'),(25778,811532679001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','jolitakey','jolita.kimsaite@gmail.com','Jolita Kimsait','Paupio 11-1','Vilnius','','LITHUANIA','01201','+37080079881','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 10:16:03',0,NULL,3,1,11,1,NULL,'hermeshine\r欧标'),(25779,856227070002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',2,'AE2203',49.6,'hermeshine','ferzonecomputer','ferzonecomputer@yahoo.com','Jose Enrique Ferrer','284 Cape Sable Dr','Naples','FL','UNITED STATES','34104-4119','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 10:18:23',0,NULL,3,1,3,1,'RA184522899CN\r ','hermeshine'),(25780,879333875017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.06,'photographyacc','arkan3223','sales.innovision@hotmail.com','Aleksandar Matic','69 Vella crescent, Blacktown','Sydney','New South Wales','AUSTRALIA','2148','0298316730','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,5,1,2,1,'30125123210\r ','photographyacc'),(25781,811546202001,110728100681,'1500w Continuous Light Kit softbox Boom Arm Hairlight',1,'AKT066',199,'hermeshine','legtaproche','y.derbre@rochefeuille.net','lycee rochefeuille','route de caen','mayenne','Pays de la Loire','FRANCE','53100','0243041173','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 11:09:00',0,NULL,3,1,12,1,'3126109276\r ','hermeshine\r欧标\r实重7.1kg\r泡重9.2kg'),(25782,811551221001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','chekmag','gaysin@gmail.com','Dinar Gaysin','Kopyilova 78-105','Krasnoyarsk','Krasnoyarskiy kray','RUSSIAN FEDERATION','660001','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 11:19:38',0,NULL,3,1,5,1,'CP246990531CN ','hermeshine'),(25783,964648385015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','akhtar191','raheel191@hotmail.com','Raheel Akhtar','Flat 1<br>16 Golsmid Road','Reading','Berkshire','UNITED KINGDOM','rg1 7jz','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 11:33:56',0,NULL,3,1,11,1,NULL,'hutongstore'),(25784,818398898018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',71.39,'photographyacc','jonotto7','jon.otto@hotmail.com','Jonathan Otto','16 Frith Ave','Normanhurst','New South Wales','AUSTRALIA','2076','0405205509','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-12 11:48:12',0,NULL,3,1,3,1,'RA184522885CN\r ','photographyacc'),(25785,810665413001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',2,'AB1204',34,'hermeshine','oshead087','oshead@gmail.com','David O\'Shea','27 Lanesborough Crescent<br>Finglas','Dublin','Dublin','IRELAND','D11','0852722474','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-12 12:07:58',0,NULL,3,1,17,0,'RA184522871CN\r ','hermeshine'),(25786,811565701001,110528829526,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',17,'hermeshine','oshead087','oshead@gmail.com','David O\'Shea','27 Lanesborough Crescent<br>Finglas','Dublin','Dublin','IRELAND','D11','0852722474','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-12 12:07:58',0,NULL,3,1,3,1,'RA184522871CN\r ','hermeshine\r伟峰 717 快装板  3\r'),(25787,944635081016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','turbodiz','b-kleven@live.no','Bjørn Kleven','Bjørnebærveien 7','Levanger','Nord Trøndelag','NORWAY','7600','92841890','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 12:11:50',0,NULL,3,1,11,1,NULL,'hutongstore'),(25788,879383343017,270744171861,'52mm Ring Adapter and Filter Holder for Cokin P Series ',1,'AKT018',3.98,'photographyacc','vitmatos','hazard0@msn.com','Vitor Matos','Rua Hermes Inacio, 122, S<br>Azurem','Guimaraes','','PORTUGAL','4800-273','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 13:15:54',0,NULL,3,1,17,0,'RA184590032CN ','photographyacc'),(25789,818430337018,280805178508,'Promotion ! NEW Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.7,'photographyacc','vitmatos','hazard0@msn.com','Vitor Matos','Rua Hermes Inacio, 122, S<br>Azurem','Guimaraes','','PORTUGAL','4800-273','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 13:15:55',0,NULL,3,1,17,0,'RA184590032CN ','photographyacc'),(25790,879383464017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.7,'photographyacc','vitmatos','hazard0@msn.com','Vitor Matos','Rua Hermes Inacio, 122, S<br>Azurem','Guimaraes','','PORTUGAL','4800-273','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 13:15:55',0,NULL,3,1,3,1,'RA184590032CN ','photographyacc\r方形滤镜接口环 52mm  1\r方镜普通托架（三槽）  1\r无牌方镜 ND8   1\r无牌方镜 渐变灰 （nd8）   1\r无牌方镜 渐变灰 （nd4）   1\r无牌方镜 渐变灰 （nd2）   1'),(25791,944663459016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',105,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:22',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25792,964692306015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:23',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25793,964686660015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:24',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25794,944666131016,260808986339,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',18,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:24',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25795,964687569015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:26',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25796,944666451016,260894475364,'Universal two-wheel Light Stand Double Dual Grip Clamp',1,'AD1179',9.8,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:27',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25797,964691125015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',1,'AKT007',12.99,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 13:44:28',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25798,944665832016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-12 13:44:28',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25799,944667785016,260814129933,'Metal Flash Holder w/ Ball Head &Spring Clamp Clip 2.2\"',1,'AE3103',7.9,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-12 13:44:25',0,NULL,3,1,12,1,'3126028146 ','hutongstore\r灯架  2m  2\r柔光箱 60-60cm  四灯头   2\r45w 5500k 灯泡 220v   14\r灯架包    1\r反光伞110cm   1\r一转四 灯头   1\r灯架包厚    1\r背景架2mx2m  + 3个夹子  1\r1.6*2.1 黑加白背景布\r反光板支架的夹子（双轮）  1\r牛津布大包   1\r大力夹云台  1\r欧标\r实重11.3kg.\r泡重14.7kg\r\r'),(25800,818440351018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',94.05,'photographyacc','uninspired42','angusvonsanchez@gmail.com','Michael Waghorn','The Church<br>15 Saunders St','Coburg','Victoria','AUSTRALIA','3058','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-03-12 14:33:24',0,NULL,3,1,4,1,'YW870147150CN ','photographyacc'),(25801,811616025001,110445641416,'New 3 filters & Ring set for Cokin System P Series',1,'AKT026',25,'hermeshine','kverna1987','kverna@gmail.com','Anders Kverneng','Holmestrandsveien 22','Drammen','Buskerud','NORWAY','3041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:33:29',0,NULL,3,1,17,0,'RA184522987CN\r ','hermeshine'),(25802,856310934002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','kverna1987','kverna@gmail.com','Anders Kverneng','Holmestrandsveien 22','Drammen','Buskerud','NORWAY','3041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:33:30',0,NULL,3,1,17,0,'RA184522987CN\r ','hermeshine'),(25803,636687011004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',1,'AD1223',3.5,'hermeshine','kverna1987','kverna@gmail.com','Anders Kverneng','Holmestrandsveien 22','Drammen','Buskerud','NORWAY','3041','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:33:30',0,NULL,3,1,3,1,'RA184522987CN\r ','hermeshine\r天涯方形滤镜  ND2  1\r天涯方形滤镜  ND4   1\r天涯方形滤镜  ND8     1\r方形滤镜接口环 77mm  1\r方镜普通托架（三槽）  1\r圆形柔光棚 50cm   1\r无牌方镜 ND8    1'),(25804,856296440002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 13:59:51',0,NULL,3,1,3,1,'RA184522960CN\r ','hermeshine'),(25805,856227195002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',8,'AO0005',181,'hermeshine','vetals777','vitaliy.nechiporenko@gmail.com','Vitaliy Nechiporenko','pereulok SHTABNOY 6,<br>kvartira 220,','Dnepropetrovsk','','UKRAINE','49049','+38(067)563-60-64','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:36:33',0,NULL,3,0,5,0,'CP246990528CN ','hermeshine\r1.6*3  粉  1\r红 色   1\r橙色     1\r棕色     1\r白色     2\r黑色     2\r摄影背心 canon 老款 3XL  1\r已入库\r\r'),(25806,818465260018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','treehousecz','jantegze@gmail.com','Jan Tegze','Koterova 1','Brno','','CZECH REPUBLIC','61300','0042777805221','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 14:46:08',0,NULL,3,1,11,1,NULL,'photographyacc'),(25807,856306005002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','thore-no','thore@fotoforalle.no','Thore Johannessen','Sprintveien 13a','Sandefjord','','NORWAY','3223',' 91668602','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 14:48:39',0,NULL,3,1,3,1,'RA184522956CN\r ','hermeshine'),(25808,811626335001,110468046436,'Wireless Flash Trigger set CTR-301 P CTR-301P w/PC Sync',1,'AKT013',25.8,'hermeshine','sneuf','sneuf85@hotmail.fr','stéphanie deldicque','23/25 apt 33 residence triannon<br>rue nicolas leblanc','lille','Nord-Pas-de-Calais','FRANCE','59000','0677908843','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 15:02:28',0,NULL,3,1,3,1,'RA184522942CN\r ','hermeshine'),(25809,856339388002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','edutoury','tourybai@hotmail.com','eduardo touriñan pena','moncho reboiras n 7, 1<br>o burgo','culleredo(a coruña)','Galicia','SPAIN','15670','652853517','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 15:46:32',0,NULL,3,1,17,0,'YW870147146CN  ','hermeshine'),(25810,811639336001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','edutoury','tourybai@hotmail.com','eduardo touriñan pena','moncho reboiras n 7, 1<br>o burgo','culleredo(a coruña)','Galicia','SPAIN','15670','652853517','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 15:46:32',0,NULL,3,1,4,1,'YW870147146CN ','hermeshine\r三脚架 伟峰 WF-6663A   1\r2B 柔   1'),(25811,811651197001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','jbr920','jbr920@aol.com','Joseph W Britt','379 Misty Dr','Pleasant View','TN','UNITED STATES','37146-7155','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 16:01:56',0,NULL,3,1,1,1,'LK231930430CN\r ','hermeshine'),(25812,811710242001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','2010maristela','maristelacruz2010@gmail.com','Maristela Cruz','70 Port Ave<br># 72','Elizabeth','NJ','UNITED STATES','07206-2069','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-12 18:06:08',0,NULL,3,1,1,1,'LK231949626CN\r ','hermeshine'),(25813,818561189018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',28.49,'photographyacc','janmoehler','jan.moehler@t-online.de','Jan-Marc Möhler','Robert-Koch-Str. 68','Eningen','','GERMANY','72800','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-12 18:08:07',0,NULL,3,1,3,1,'RA184522810CN\r ','photographyacc\rXL 已入库'),(25814,856411735002,120642593354,'New Portable 40cm 16\"x16\" Soft Box Softbox for Flash ',1,'AB3327',39.99,'hermeshine','yuriynayman','naymanyuriy@gmail.com','Yuriy Nayman','ul. Partizanskaya d.118A','Miass','Chelyabinskaya oblast','RUSSIAN FEDERATION','456300','89514413020','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 18:15:31',0,NULL,3,1,3,1,'RA184522925CN\r ','hermeshine'),(25815,964868086015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','illuminatijs','joesant@melita.com','Joseph Sant','Illuminati<br>1, Triq Guzeppi Xuereb ix-Xudi','Swatar','Birkirkara','MALTA','BKR 4133','+356 9924 6757','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 18:34:24',0,NULL,3,1,11,1,NULL,'hutongstore'),(25816,811730282001,110580765121,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',224,'hermeshine','danoveolsen1965','post@nettkompis.no','Dan Ove Olsen','Postboks 5','Grua','NORWAY','NORWAY','2717','92065988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 18:39:41',0,NULL,3,1,5,1,'CP246990559CN\r ','hermeshine\r欧标'),(25817,964889266015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','cornmer','ben.bask@gmail.com','Sergei Bender','81 Cornmow Drive','London','London','UNITED KINGDOM','NW10 1BB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 19:00:05',0,NULL,3,1,2,1,'30125127686\r ','hutongstore'),(25818,811775318001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','raferto','raferto@lleida.org','Rafa Fernandez Torres','Josep Maria de Sagarra, 47 1º 3ª','Granollers','Cataluña','SPAIN','08402','652840199','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-12 19:50:36',0,NULL,5,1,4,1,'YW870147172CN\r ','hermeshine\r已发货'),(25819,811788794001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','a_doreanmode','a_lydian@aol.jp','Akihiro Yokoo','180-1,Konemoto','Matsudo-shi','Chiba','JAPAN','2710073','81-47-368-8669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 20:10:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(25820,944916880016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','jimmcguc','jim@mcguckin.eu','Jim McGuckin','Paradise  Park View Drive<br>Markyate','St Albans','Herts','UNITED KINGDOM','AL3 8PE','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 20:10:59',0,NULL,3,1,11,1,NULL,'hutongstore'),(25821,964951557015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','malikrk','rakesh.malik1@gmail.com','Rakesh Malik','57 Sherbourne Avenue<br>Bradley Stoke','Bristol','Gloucestershire','UNITED KINGDOM','BS32 8BB','01179692241','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 20:12:32',0,NULL,3,1,3,1,'RA184522939CN\r ','hutongstore'),(25822,811794811001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','luchochm','luischm@gmail.com','Katty Alarcón Juñuruco','Calle Trapiche Mz. I4 LT 2 Urb. Portada del Sol - La Molina','Lima','Lima','PERU','LIMA 12','+51 997233286','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 20:20:26',0,NULL,3,1,5,1,'CP246990514CN ','hermeshine'),(25823,856545734002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','samastudio','asdbh@hotmail.com','Ali Ismaeel','Building 2062, Road 153, Tubli 701','Isa Town','Middle Province','BAHRAIN','701','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 21:56:02',0,NULL,3,1,11,1,NULL,'hermeshine\r英标'),(25824,856565153002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','jtarcisio1978','jtarcisio@hotmail.com','Tarcísio Joaquim de Araújo Filho','Rua Francisco Serrador, 90 apto. 403<br>Centro','Rio de Janeiro','RJ','BRAZIL','20031-060','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-12 22:38:11',0,NULL,5,0,18,0,NULL,'hermeshine\r需要加$10运费\r发信了'),(25825,965061020015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','freda4971','freda.hannar@ntlworld.com','Freda Hannar','18, Reynolds Avenue<br>Columbia','Washington','Tyne and Wear','UNITED KINGDOM','ne38 7eq','01914177571','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-12 22:48:06',0,NULL,3,1,2,1,'30125135751\r ','hutongstore'),(25826,811882595001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','e.ismen','ebru_ismen@hotmail.com','EBRU İŞMEN','AKBANK TAS AKDENIZ CADDESI SUBESI AKDENİZ CADDESI NO:101A<br>FATIH','ISTANBUL','ISTANBUL','TURKEY','34091','5352198903','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-12 23:18:08',0,NULL,3,1,11,1,NULL,'hermeshine'),(25827,945040078016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','kvdparadise','kathyvido@gmail.com','Kathy Do','7301 Southwind Dr','Biloxi','MS','UNITED STATES','39532-5709','(832) 277-2002','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-12 23:28:59',0,NULL,3,1,1,1,'LK231934706CN\r ','hutongstore'),(25828,811914173001,110596691926,'New Small Camera bag lens case  D2 for Canon 500D 450D',1,'AO0033',6.99,'hermeshine','cystokids','cystokid@charter.net','Bryan Shumaker','289 Bluewater Trl','Boyne City','MI','UNITED STATES','49712-8816','(231) 582-5554','NoPaymentFailure','CheckoutComplete','Other','2012-03-13 00:58:52',0,NULL,5,0,18,0,NULL,'hermeshine\r已经发信了，看是否退款'),(25896,8881331626934259,111,'Free shipping & Tracking # - New 77mm ring adapter + Filter Holder for cokin P series - AKT024',1,'AKT024',5.19,'aliexpress','1007342823','serg8899@gmail.com','sergey kalabun','Bryanceva 22 kv 28','Saint Petersburg','Russia','RUSSIAN FEDERATION','195297','+7 911 1902923',NULL,NULL,NULL,'2012-03-13 08:22:14',0,NULL,3,1,3,1,'RA184590240CN\r ','速卖通'),(25829,811930565001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','art000sienna','sluga@spin.net.au','Charles Sluga','PO Box 128','Yackandandah','Victoria','AUSTRALIA','3749','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 01:53:51',0,NULL,3,1,3,1,'RA184522973CN\r ','hermeshine'),(25830,818798635018,280678256629,'4 pockets filter case pouch wallet 25mm-77mm ',1,'AE1202',4.66,'photographyacc','lexie13marion','tandm.robertson@bigpond.com','Marion Robertson','267 West Gawler Road','Ulverstone','Tasmania','AUSTRALIA','7315','0364251618','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 02:02:03',0,NULL,3,1,2,1,'30125126253\r ','photographyacc'),(25831,0,110837413750,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 02:20:32',0,NULL,5,0,18,0,NULL,'hermeshine'),(25832,0,110837409312,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.67,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:33',0,NULL,5,0,18,0,NULL,'hermeshine'),(25833,0,110837409072,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.26,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:33',0,NULL,5,0,18,0,NULL,'hermeshine'),(25834,0,110837409349,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.33,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:34',0,NULL,5,0,18,0,NULL,'hermeshine'),(25835,0,110837409365,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.26,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:35',0,NULL,5,0,18,0,NULL,'hermeshine'),(25836,0,110837409215,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.04,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:35',0,NULL,5,0,18,0,NULL,'hermeshine'),(25837,0,140717951541,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:36',0,NULL,5,0,18,0,NULL,'hermeshine'),(25838,0,110837409281,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:37',0,NULL,5,0,18,0,NULL,'hermeshine'),(25839,0,110837409591,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',0.55,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:20:36',0,NULL,5,0,18,0,NULL,'hermeshine'),(25840,0,140717951440,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:49:59',0,NULL,5,0,18,0,NULL,'hermeshine'),(25841,0,140717951211,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',0.01,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:50:00',0,NULL,5,0,18,0,NULL,'hermeshine'),(25842,0,140717951253,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.36,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:50:00',0,NULL,5,0,18,0,NULL,'hermeshine'),(25843,0,140717951374,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:50:01',0,NULL,5,0,18,0,NULL,'hermeshine'),(25844,0,120872383948,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',34.41,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 02:56:19',0,NULL,5,0,18,0,NULL,'hermeshine'),(25845,0,110837413371,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',45.06,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:04:47',0,NULL,5,0,18,0,NULL,'hermeshine'),(25846,0,120872382481,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',60.08,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:05:06',0,NULL,5,0,18,0,NULL,'hermeshine'),(25847,0,110837411886,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',64.12,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:05:13',0,NULL,5,0,18,0,NULL,'hermeshine'),(25848,0,140717952000,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',6.8,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:17:33',0,NULL,5,0,18,0,NULL,'hermeshine'),(25849,0,140717950215,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',43.01,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:21:42',0,NULL,5,0,18,0,NULL,'hermeshine'),(25850,0,140717952247,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',0.06,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:06',0,NULL,5,0,18,0,NULL,'hermeshine'),(25851,0,140717951700,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:07',0,NULL,5,0,18,0,NULL,'hermeshine'),(25852,0,140717951267,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.36,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:39:07',0,NULL,5,0,18,0,NULL,'hermeshine'),(25853,0,140717951715,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.3,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:08',0,NULL,5,0,18,0,NULL,'hermeshine'),(25854,0,140717951731,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.11,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:08',0,NULL,5,0,18,0,NULL,'hermeshine'),(25855,0,140717951274,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:39:09',0,NULL,5,0,18,0,NULL,'hermeshine'),(25856,0,140717951930,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.3,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:09',0,NULL,5,0,18,0,NULL,'hermeshine'),(25857,0,140717951850,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.11,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:39:10',0,NULL,5,0,18,0,NULL,'hermeshine'),(25858,0,140717951525,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:39:10',0,NULL,5,0,18,0,NULL,'hermeshine'),(25859,0,110837409269,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',44.64,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:23:50',0,NULL,5,0,18,0,NULL,'hermeshine'),(25860,0,140717951989,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.62,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:39',0,NULL,5,0,18,0,NULL,'hermeshine'),(25861,0,140717951800,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:40',0,NULL,5,0,18,0,NULL,'hermeshine'),(25862,0,140717951340,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:41:41',0,NULL,5,0,18,0,NULL,'hermeshine'),(25863,0,140717951834,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.3,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:41',0,NULL,5,0,18,0,NULL,'hermeshine'),(25864,0,140717951858,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.11,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:42',0,NULL,5,0,18,0,NULL,'hermeshine'),(25865,0,140717951412,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:41:42',0,NULL,5,0,18,0,NULL,'hermeshine'),(25866,0,140717951973,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.61,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:43',0,NULL,5,0,18,0,NULL,'hermeshine'),(25867,0,140717951912,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:41:43',0,NULL,5,0,18,0,NULL,'hermeshine'),(25868,0,140717951573,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:41:44',0,NULL,5,0,18,0,NULL,'hermeshine'),(25869,0,140717951956,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',1.3,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:44:19',0,NULL,5,0,18,0,NULL,'hermeshine'),(25870,0,140717951632,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.36,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:44:19',0,NULL,5,0,18,0,NULL,'hermeshine'),(25871,0,140717951194,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',0.06,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:44:20',0,NULL,5,0,18,0,NULL,'hermeshine'),(25872,0,140717951639,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:44:21',0,NULL,5,0,18,0,NULL,'hermeshine'),(25873,0,140717951735,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.75,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:44:21',0,NULL,5,0,18,0,NULL,'hermeshine'),(25874,0,140717951478,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',5,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:44:22',0,NULL,5,0,18,0,NULL,'hermeshine'),(25875,0,140717951888,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.06,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:44:22',0,NULL,5,0,18,0,NULL,'hermeshine'),(25876,0,140717951748,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:44:23',0,NULL,5,0,18,0,NULL,'hermeshine'),(25877,0,140717951605,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.45,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:44:23',0,NULL,5,0,18,0,NULL,'hermeshine'),(25878,0,140717951927,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.6,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:46:55',0,NULL,5,0,18,0,NULL,'hermeshine'),(25879,0,140717951512,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.75,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:46:56',0,NULL,5,0,18,0,NULL,'hermeshine'),(25880,0,140717951207,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',0.01,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:46:56',0,NULL,5,0,18,0,NULL,'hermeshine'),(25881,0,140717951759,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',1.51,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:47:06',0,NULL,5,0,18,0,NULL,'hermeshine'),(25882,0,140717951613,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',0.45,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:47:06',0,NULL,5,0,18,0,NULL,'hermeshine'),(25883,0,140717951506,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:47:07',0,NULL,5,0,18,0,NULL,'hermeshine'),(25884,0,140717951529,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',3.25,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:47:07',0,NULL,5,0,18,0,NULL,'hermeshine'),(25885,0,140717951922,'New Professional Hot Shoe hotshoe Cover Cap for Sony',1,'AA1205',0.4,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 03:49:09',0,NULL,5,0,18,0,NULL,'hermeshine'),(25886,0,140717951533,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.36,'hermeshine','kookieamyamy','kookieamy@gmail.com','amy amy','2300 Tryon Rd','Raleigh','NC','UNITED STATES','27603-3037','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 03:49:10',0,NULL,5,0,18,0,NULL,'hermeshine'),(25887,818836725018,280675004468,'Collapsibl​e 4.6\' x 5.7\' 190x140cm backdrop Blue/Green',1,'AC3304',58.9,'photographyacc','japasei','janpaulseifert@gmail.com','Jan Paul Seifert','5/52  High  St','Toowong','Queensland','AUSTRALIA','4066','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-13 04:19:56',0,NULL,3,1,3,1,'RA184590050CN ','photographyacc'),(25888,818838110018,280666893047,'New Green.L 72mm  Gradual Grey ND4 Filter 2-Stop 72 mm',1,'AA3320',6.84,'photographyacc','waiming2010','chauwaiming@yahoo.com.hk','Wai Ming Chau','2/8 Ashbolt Crescent<br>Lutana','Hobart','Tasmania','AUSTRALIA','7009','0413971880','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 04:23:26',0,NULL,3,1,2,1,'30125135530\r ','photographyacc'),(25889,856674433002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','bbsource','blackbeansource@gmail.com','Ken Yeo','1 Commonwealth Lane<br>#01-05 One Commonwealth Building','default','','SINGAPORE','149544','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 04:30:17',0,NULL,8,1,17,0,'','hermeshine\r'),(25890,965190023015,250692237751,'Neoprene Protector Camera Cover Case 4 Nikon D40 D60 S',1,'AC2302',4.2,'hutongstore','delux1321','delugianthomas@hotmail.fr','thomas delugian','clive steps,king charles street','london','London','UNITED KINGDOM','SW1A 2AQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 04:18:30',0,NULL,3,1,11,1,NULL,'hutongstore'),(25891,965191892015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','bbsource','blackbeansource@gmail.com','Ken Yeo','1 Commonwealth Lane<br>#01-05 One Commonwealth Building','default','','SINGAPORE','149544','','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-03-13 04:28:21',0,NULL,3,1,6,1,'EE667257954CN\r ','hutongstore\r除了C以外再发\r3m 横杆（通用4节）   1\r背景布 3x6 绿色  1\r灯架  2m  4\r柔光箱 50-70cm 单灯头  2\r115w 5500k 灯泡  220v  2\r灯架包    1\r英标\r灯架包薄   1\r实重20.8kg\r泡重25.5kg\r'),(26029,812964091001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','szbognar','sysco@gtwo.hu','Szilard Bognar','Jozsef Attila u. 59.','Abda','Gyor-Moson-Sopron','HUNGARY','9151',' 0036703181494','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:22:59',0,NULL,3,1,3,1,'RA184590559CN\r ','hermeshine'),(25892,818851985018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',33.25,'photographyacc','elkington02','elkington@downunderhub.com','Kylie Kassel','19 Palmer Rd','Elizabeth Park','South Australia','AUSTRALIA','5113','0882552570','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 05:35:54',0,NULL,3,1,3,1,'RA184522995CN ','photographyacc\rKylie Kassel\r19 Palmer Rd, Elizabeth Park \rSA 5113\rAUSTRALIA\r0882552570'),(25893,965220562015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','d-sign75','yk75@live.be','Yves Knockaert','Torhoutsesteenweg 450 b2','Oostende','','BELGIUM','8400','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 06:35:33',0,NULL,3,1,3,1,'RA184523007CN ','hutongstore'),(25894,964689131015,250692241543,'45W 5400-5500K Studio Light Bulb x2 Daylight E27 Socket',2,'AKT007',25.98,'hutongstore','stylianosd','info@dedeletakis.gr','Dedeletakis Stelios','DANTI 4','HERAKLION','CRETE','GREECE','71409','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 06:44:31',0,NULL,3,1,17,0,'3126028146  ','hutongstore'),(25895,856700756002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','hong2101-2101','hong2101@hotmail.com','Thitiphan Pakseesuwan','99/294 Soi B13 THE URBANA<br>T.Tasala','A.Muang','Chiang Mai','THAILAND','50000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 06:53:41',0,NULL,3,1,11,1,NULL,'hermeshine'),(25897,8881331627048855,111,'Free shipping & Tracking # - Photo Studio Light Kit Boom Arm Stand Tripod no bulb - Wholesale/Retail AKT003',1,'AKT003',74.99,'aliexpress','1007343248','yourfotoshop@mail.ru','Roman Korshynoff','city. Yaroslavl strit. Bolshaya Oktyaborskaya d. 126B kv.19','Yaroslavl','Russia','RUSSIAN FEDERATION','150001','+7 920 1407828',NULL,NULL,NULL,'2012-03-13 08:24:08',0,NULL,3,1,5,1,'CP246990616CN\r ','欧标\r速卖通'),(25898,879152715017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',11.7,'photographyacc','greatapoc','petenewsome@gmail.com','Peter Newsome','Soul Communications<br>Level 2 11-17 Mosbri Cr','Newcastle','New South Wales','AUSTRALIA','2300','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 08:29:23',0,NULL,3,1,11,1,NULL,'photographyacc\r无牌方镜 渐变灰 （nd8）  1\r无牌方镜 渐变灰 （nd2）   1\r无牌方镜 渐变灰 （nd4）    1\r已入库'),(25899,965262503015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','dutch_dan','daniel_freese@hotmail.com','Daniel Freese','50 Hunt Avenue','Netley Abbey','Hampshire','UNITED KINGDOM','SO315BE','02380452436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 09:14:40',0,NULL,3,1,3,1,'RA184522911CN ','hutongstore'),(25900,8881331630783316,111,'伞式柔光箱 60×90cm ',1,'AD1199',0,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','+79233486117',NULL,NULL,NULL,'2012-03-13 09:26:23',0,NULL,3,1,3,1,'RA184590046CN ',NULL),(25901,818430345018,280805178524,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.7,'photographyacc','vitmatos','hazard0@msn.com','Vitor Matos','Rua Hermes Inacio, 122, S<br>Azurem','Guimaraes','','PORTUGAL','4800-273','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 09:42:12',0,NULL,3,1,17,0,'RA184590032CN ','photographyacc'),(25902,879383501017,270891544454,'Promotion!NEW Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.7,'photographyacc','vitmatos','hazard0@msn.com','Vitor Matos','Rua Hermes Inacio, 122, S<br>Azurem','Guimaraes','','PORTUGAL','4800-273','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 09:42:12',0,NULL,3,1,17,0,'RA184590032CN ','photographyacc'),(25903,856733552002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','zexzus','zexz@xairo.com','Dmitri Mosco','sos. Muncesti 176, ap 90','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','2002','+373 68636301','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 09:25:49',0,NULL,3,1,3,1,'RA184590165CN\r ','hermeshine'),(25904,965299555015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','gizmo_le_hobbit','loic.r.francois@wanadoo.fr','Loic Francois','11 Allée de l\'Europe, Appartement 311','Chantilly','Picardie','FRANCE','60500','0615467167','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 11:01:48',0,NULL,3,1,3,1,'RA184590973CN ','hutongstore'),(25905,812058833001,110535742580,'43\" 110CM 5 IN 1 Collapsible Multi Disc Light Reflector',1,'AC3401',25.67,'hermeshine','hayalet5','byumitsiz@gmail.com','umit sener','kredi yurtlar kurumu','bilecik','merkez','TURKEY','11100',' 5318388313','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 11:18:20',0,NULL,3,1,3,1,'RA184590236CN\r ','hermeshine'),(25906,965301714015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','tsgfarnetti','tfarnetti@gmail.com','TSGFarnetti','Unit A4 Arena Business Centre<br>71 Ashfield Rd','London','London','UNITED KINGDOM','N4 1FF','07714025006','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 11:09:28',0,NULL,3,1,3,1,'RA184590222CN\r ','hutongstore'),(25907,818944305018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','husaynmohammadi9','husaynmohammadi@gmail.com','Husayn Mohammadi','82 Luttrell Street,','Richmond','New South Wales','AUSTRALIA','2753','0410977992','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 11:53:39',0,NULL,3,1,2,1,'30125292676\r ','photographyacc'),(25908,854099660002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','mariam-ch-25','mariam_ch_ik@yahoo.com','Narek Harutyunyan','15 Soghomon Tarontsi Street, apartment 30','Yerevan','Yerevan','ARMENIA','0055','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 12:06:48',0,NULL,3,1,3,1,'RA184590219CN\r ','hermeshine'),(25909,856784443002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 12:30:37',0,NULL,3,1,3,1,'RA184591293CN ','hermeshine'),(25910,816075485018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.18,'photographyacc','pedrojrmartins','pedro_jr_martins@yahoo.com','Maria Helena Rodrigues Martins','Rua Grao Vasco<br>N 5 1ºDt','Sacavem','Portugal','PORTUGAL','2685-062','351917926120','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 13:28:10',0,NULL,3,1,17,0,NULL,'photographyacc'),(25911,814176711018,280678255974,'3 pockets filter case pouch wallet 25mm-82mm Cokin P',1,'AE1201',4.4,'photographyacc','pedrojrmartins','pedro_jr_martins@yahoo.com','Maria Helena Rodrigues Martins','Rua Grao Vasco<br>N 5 1ºDt','Sacavem','Portugal','PORTUGAL','2685-062','351917926120','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 13:29:37',0,NULL,3,1,11,1,NULL,'photographyacc\r3片装的滤镜袋   2'),(25912,879962347017,270751511608,'YongNuo 1m Off Camera FLASH sync Cord for CANON E-TTL',1,'AB3321',16.14,'photographyacc','swobbles','hoppet@tpg.com.au','Peter Hopkins','101 Lakeview Road','Wangi Wangi','New South Wales','AUSTRALIA','2267','0249752446','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-13 13:49:40',0,NULL,3,1,11,1,NULL,'photographyacc'),(25913,945329879016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',5.6,'hutongstore','kerrywithay','cheryljanesmith@yahoo.co.uk','Kerry Smith','South studio<br>The clock tower, the galleries','Brentwood','England','UNITED KINGDOM','CM14 5GF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 14:14:01',0,NULL,3,1,11,1,NULL,'hutongstore'),(25914,812120373001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',3,'AD1184',101.97,'hermeshine','angeltoncp1','angeltonalencar@gmail.com','Angelton Freire de Alencar','CaixaPostal 42<br>Centro','Cuiaba','Mato Grosso','BRAZIL','78005-970','6599496565','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:30:36',0,NULL,5,1,5,1,'CP246990620CN\r ','hermeshine\r2.65kg \r已发货..................'),(25915,812120963001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','hevgenii','onetoo2006@ya.ru','Евгений Хайкара','ул.Победы, 42-70','Осинники','Кемеровская область','RUSSIAN FEDERATION','652800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:33:37',0,NULL,3,1,17,0,'RA184590253CN\r ','hermeshine'),(25916,812121123001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','hevgenii','onetoo2006@ya.ru','Евгений Хайкара','ул.Победы, 42-70','Осинники','Кемеровская область','RUSSIAN FEDERATION','652800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:33:38',0,NULL,3,1,3,1,'RA184590253CN\r ','hermeshine\r灯架  2m  1\r单灯头  1\r欧标'),(25917,854386186002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','moniqueb_123','brewster_monique@yahoo.com','Monique Brewster','14811 235th St','Rosedale','NY','UNITED STATES','11422-3294','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-13 14:45:12',0,NULL,3,1,1,1,'LK229516286CN ','hermeshine'),(25918,856836420002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','ijulskoe','nik.oralow@mail.ru','Nikita Oralov','ul. Pesochnaya 14-70','Udmurtiya','','RUSSIAN FEDERATION','426069','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-13 14:57:20',0,NULL,3,1,3,1,'RA184590063CN\r ','hermeshine\r2云柔  1'),(25919,856835437002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','y*stacy','sandzusan@mail.ru','Yerakhtina Anastassiya','37/2 Alikhanov street  apt 27','Karaganda','Karagandinskaya','KAZAKHSTAN','100027','87014963234','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 14:57:24',0,NULL,3,1,3,1,'RA184590151CN\r ','hermeshine'),(25920,819020482018,280719725855,'New Sand Bag Weight portable for boom arm tripod black',1,'AD1169',6.08,'photographyacc','animotto','ottomogren@gmail.com','Otto Mogren','Västgötagatan 22<br>c/o Zhang','Stockholm','','SWEDEN','118 27','46736133384','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 15:30:25',0,NULL,3,1,11,1,NULL,'photographyacc'),(25921,637076606004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','okjuytr','essayasse@yahoo.com','Hinh Tran','591 Dundas Street West','Toronto','ON','CANADA','M5T1H6','(647) 892-2460','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 16:14:29',0,NULL,3,1,11,1,NULL,'hermeshine'),(25922,810651930001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',1,'AB1302',62.13,'hermeshine','catpcat','povolalex@yahoo.ca','Tatiana Povolotcaia','3460 Keele str #309','Toronto','ON','CANADA','M3j1L9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 16:27:09',0,NULL,3,1,3,1,'RA184590148CN\r ','hermeshine\r橡胶遮光罩 55mm  1\r大力夹云台    1\r闪光的柔光箱   60cm   1\r已入库'),(25923,965447482015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','millsy747','mr.paulmills@gmail.com','Paul Mills','30 North Dell<br>Springfield','Chelmsford','Essex','UNITED KINGDOM','CM1 6UP','07920789520','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 16:41:20',0,NULL,3,1,3,1,'RA184590134CN\r ','hutongstore\r澳转英标'),(25924,945412004016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','bryncoch50','eddiemail@talk21.com','Wayne Edwards','50 Bryncoch','Llanelli','Carmarthenshire','UNITED KINGDOM','SA14 8RH','01554741167','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 17:06:00',0,NULL,3,1,3,1,'RA184590117CN\r ','hutongstore'),(25925,965477521015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','webb.bid','iamstevewebb@hotmail.co.uk','Solaris health Att: steven webb','34<br>the quadrant','richmond upon thames','London','UNITED KINGDOM','TW9 1DN','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 17:34:37',0,NULL,3,1,2,1,'30125282806\r ','hutongstore'),(25926,945434082016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',14.99,'hutongstore','ninapts','jamyth@gmail.com','Nikolina Petolas','Maksimirska 105','Zagreb','Croatia','CROATIA','10000','00385989080982','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 17:49:42',0,NULL,3,1,3,1,'RA184590205CN\r ','hutongstore'),(25927,965494232015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 18:03:08',0,NULL,3,1,11,1,NULL,'hutongstore'),(25928,812232384001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','pelisaara','apelisaar@yahoo.com','Ago Pelisaar','Saha 46-9','Tallinn','','ESTONIA','10921','+37256654822','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 18:52:47',0,NULL,3,1,11,1,NULL,'hermeshine'),(25929,965546920015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','trampstarshane','shaneleach1970@yahoo.co.uk','shane leach','2 lambourn road<br>rose hill','oxford','Oxfordshire','UNITED KINGDOM','ox44gn','01865433525','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 19:18:33',0,NULL,3,1,2,1,'30125286881\r ','hutongstore'),(25930,965553496015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dutch_dan','daniel_freese@hotmail.com','Daniel Freese','50 Hunt Avenue','Netley Abbey','Hampshire','UNITED KINGDOM','SO315BE','02380452436','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 19:24:58',0,NULL,3,1,3,1,'RA184590196CN\r ','hutongstore'),(25931,856969523002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',41.5,'hermeshine','fotofilia','sngfotografia@gmail.com','María Teresa Godoy León','El Coigüe 3720, Vitacura','Santiago','Metropolitana','CHILE','7630493','5668499240','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 19:42:23',0,NULL,3,1,3,1,'RA184590182CN\r ','hermeshine'),(25932,945521533016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','kacperfrank','asiek.cieslik@interia.pl','Zbigniew Grzeda','38 West Parade','Spalding','Lincolnshire','UNITED KINGDOM','pe11 1hd','07742831578','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-13 19:54:34',0,NULL,3,1,3,1,'RA184590338CN\r ','hutongstore'),(25933,965616601015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','ridabu','bjorn@reklamare.no','Bjorn Linderud','Sagengvegen 26','Ridabu','','NORWAY','N-2322','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 20:47:49',0,NULL,3,1,3,1,'RA184590015CN\r ','hutongstore\r申报10英镑'),(25934,857017504002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','liberts28','acfellowship@sbcglobal.net','Rebecca Basden','816 E Oakwood Ave','Altus','OK','UNITED STATES','73521-3528','(580) 477-4190','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-13 21:00:45',0,NULL,3,1,1,1,'LK232860253CN ','hermeshine'),(25935,819213341018,280683075819,'Stereo Microphone for DC DV Camcorder 60D 5D II 7D 550D',1,'AA1215',40.84,'photographyacc','kurtgriesbach','kurt_griesbach@hotmail.com','kurt  griesbach','bahnhofstr.5','dahlewitz','','GERMANY','15827','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-13 21:35:15',0,NULL,3,1,3,1,'RA184590103CN\r ','photographyacc'),(25936,812321265001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','toughxmix','hrenbuben@gmail.com','Andrey Chernyshov','Novoperedelkinskaya st. 12-1-186','Moscow','','RUSSIAN FEDERATION','119633','9262252027','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 21:36:51',0,NULL,3,1,11,1,NULL,'hermeshine'),(25937,812328883001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','junglistic_maxim','ebay_junglistic@mail.ru','Mogildea Maxim','A. Xenopol 11','Chisinau','','MOLDOVA, REPUBLIC OF','MD-2051','+37379844160','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 21:46:28',0,NULL,3,1,3,1,'RA184590029CN\r ','hermeshine\r新地址\rMogildea Maxim \rChisinau, str. A.Xenopol, 11 MD-2051, \rMOLDOVA \r+37379844160 '),(25938,945632262016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','robk2250','robkane50@hotmail.com','Robert Kane','22 Atalanta Terrace<br>Pye Nest','Halifax','West Yorkshire','UNITED KINGDOM','HX2 7HL','01422342010','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 22:45:22',0,NULL,3,1,2,1,'30125290285\r ','hutongstore'),(25939,965692114015,250892628465,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',21.2,'hutongstore','karrod1958','karenrodham@hotmail.com','Karen Rodham','1 Rowan Road','Stockton-on-Tees','Cleveland','UNITED KINGDOM','TS19 0EZ','07851298058','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-13 22:55:32',0,NULL,3,1,3,1,'RA184590324CN\r ','hutongstore'),(25940,965698766015,250938521804,'New Photo Studio Light Stand with 80cm Octagon Umbrella Softbox Flash Mount set',1,'AKT092',41,'hutongstore','noxpax89','noel.pace@hotmail.com','Andrea Sacco Baldacchino','187 St Margaret Street','Siggiewi','','MALTA','SGW 1016','(00356) 99211138','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-13 23:04:57',0,NULL,3,1,3,1,'RA184590094CN\r ','hutongstore'),(25941,819255011018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',94.05,'photographyacc','shadow0450','naomi-woodbury@hotmail.com','Naomi Barnes','101 po box','Coornabong','New South Wales','AUSTRALIA','2265','','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-03-13 23:05:02',0,NULL,3,1,4,1,'YW870147194CN\r ','photographyacc\rNaomi Barnes\r176 Bridge street Morisset \rNSW 2264\rAUSTRALIA\r'),(25942,810198096001,110542112392,'4 IN 1 LAMP SOCKET ADAPTER CONVERT 1 BUBL TO 4 BULBS',3,'AE3301',47.94,'hermeshine','melate8','tonefotos@hotmail.com','Las Lomas','Otero 111-A<br>Entre Obregon e Hidalgo','Navojoa','Sonora','MEXICO','85830','(642)422-8909','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-13 23:21:44',0,NULL,3,1,3,1,'RA184590085CN\r ','hermeshine\r'),(25943,965726068015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.12,'hutongstore','dghagi3816','dghagi@yahoo.com','Dragan Dejanovic','Jovana Hadzivasiljevica 41','Vranje','','SERBIA','17500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 00:11:16',0,NULL,3,1,17,0,'RA184590125CN\r ','hutongstore'),(25944,965726069015,250692238242,'New 67mm Ring adapter for Cokin P Series Filter Holder',2,'AA2212',3.2,'hutongstore','dghagi3816','dghagi@yahoo.com','Dragan Dejanovic','Jovana Hadzivasiljevica 41','Vranje','','SERBIA','17500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 00:11:16',0,NULL,3,1,17,0,'RA184590125CN\r ','hutongstore'),(25945,965726070015,250692237962,'New 52mm Ring adapter for Cokin P Series Filter Holder',1,'AA2208',1.6,'hutongstore','dghagi3816','dghagi@yahoo.com','Dragan Dejanovic','Jovana Hadzivasiljevica 41','Vranje','','SERBIA','17500','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 00:11:17',0,NULL,3,1,3,1,'RA184590125CN\r ','hutongstore\r方形滤镜接口环 77mm 1\r方镜普通托架（三槽）   1\r方形滤镜接口环 67mm   2\r方形滤镜接口环 52mm   1'),(25946,812382665001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','ettetca902','wuzzy69@gmail.com','michael ettinger','27 joyce ave','halifax','NS','CANADA','b3p1w7','(902) 443-2196','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 00:15:24',0,NULL,3,1,5,1,'CP246990602CN\r ','hermeshine'),(25947,880269994017,270891544153,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.7,'photographyacc','intracom-auctions','alda.curtis@gmail.com','Alda Curtis','36 Anne William Drive','West Pennant Hills','New South Wales','AUSTRALIA','2125','0431600560','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 00:28:12',0,NULL,3,1,2,1,'30125292724\r ','photographyacc'),(25948,812388066001,110417006174,'Male to Male 52mm-58mm Macro Reverse Ring reversing',1,'AA1212',2.99,'hermeshine','j_santana','smokada@gmail.com','Joao Santana','Rua de Baixo 17<br>Graveto','2425-610','Monte Redondo','PORTUGAL','LRA','00351918446366','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 00:35:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(25949,880282452017,270759128117,'ManBily MBL-306 Travel Tripod Kit Canon Nikon Sony',1,'AD1132',61.75,'photographyacc','dtasker','dtasker@netspace.net.au','D Tasker','342 Marriot Street<br>PO Box 155','Westbury','Tasmania','AUSTRALIA','7303','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-14 00:55:24',0,NULL,3,1,4,1,'YW870147183CN\r ','photographyacc\r地址 \rD Tasker\r342 Marriot Street\rWestbury Tasmania 7303\rAUSTRALIA'),(25950,819299418018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','goy02','anwarsako@gmail.com','anwar raphael','17/26 Mckinley drive','melbourne / roxburgh park','Victoria','AUSTRALIA','3064','0431296595','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 01:18:01',0,NULL,3,0,11,1,NULL,'photographyacc\r1.6*2.1  白色'),(25951,8881331690375628,111,'Photo Studio Background Support (7ft x 7ft) + Free Backdrop - Wholesale/ Retail [AO0009]',1,'AO0009',69.99,'aliexpress','1007364906','ostyak@gmail.com','Ivan Permyakov','8-9 Shneider St.','Berezovo','KHMAO-Ugra','RUSSIAN FEDERATION','628140','+7 34674 23321',NULL,NULL,NULL,'2012-03-14 01:59:35',0,NULL,3,1,5,1,'CP246990593CN\r ','+1.6*2.1白色布\r速卖通'),(25952,812417928001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','rmcaudio1','rstore@me.com','Rodrigo Martínez','ibsen 6445 departamento 24<br>comuna: Las Condes','Santiago','Región metropolitana','CHILE','7550000','56 99170124','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 02:13:15',0,NULL,3,1,5,1,'CP246990580CN\r ','hermeshine\r欧标'),(25953,880320684017,270758683063,'New Photo Studio Background Support Stand Carry Bag',1,'AD1129',9.31,'photographyacc','pangitpete','peterbirtles@yahoo.com.au','Peter Birtles','3 Weigall Street','Barraba','New South Wales','AUSTRALIA','2347','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 02:52:56',0,NULL,3,1,11,1,NULL,'photographyacc'),(25954,637280980004,140628962835,'New Arrival Fancier Professional Tripod WT-6714 with Damped Pan Head  w/ Case',1,'AD1196',65,'hermeshine','anviddivna','mama_en_casa@hotmail.com','Divna Razmilic Contreras','Sazie 2032<br>departamento 504','Santiago','','CHILE','8370095','61-248128','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 03:42:39',0,NULL,3,1,5,1,'CP246990576CN\r ','hermeshine'),(25955,812443104001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','clewis0013','cvd13@hotmail.com','216Chris Lewis','3045 Monticello Blvd','Cleveland','OH','UNITED STATES','44118-1250','(330) 846-1313','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-14 03:51:28',0,NULL,3,1,3,1,'RA184590077CN\r ','hermeshine'),(26018,8881331776075537,111,'Free shipping & Tracking # - New Sand Bag Weight portable equipment Shipped Empty - AD1169',2,'AD1169',13.98,'aliexpress','1007388357',' tobias.laudert@googlemail.com','Tobias Laudert','Wolkenburg 48','Wuppertal','NRW','GERMANY','42119','+0049 178 5312733',NULL,NULL,NULL,'2012-03-15 01:47:55',0,NULL,3,1,3,1,'RA184590562CN\r ','速卖通 '),(26026,966468611015,250662317207,'Studio Light 2300W Continuous Lighting Kit Set',1,'AKT041',110,'hutongstore','mortenhjemmen','mhjemmen@online.no','Morten Hjemmen','Høievegen 87','Årnes','Akershus','NORWAY','2150','004794181021','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-15 07:02:52',0,NULL,3,1,5,1,'CP246990678CN\r ','hutongstore\r欧标\r灰色布'),(25956,812457350001,110569973202,'New  Non Woven Fabric Backdrop 1.6m x 3m(5.2x10 ft)',1,'AO0005',20.8,'hermeshine','alehandrobay','alehandromail@gmail.com','Alexander Terentyev','M-n Taugul - 1 (Dezhneva-Piatnickogo) phone: +7 (727) 302-3323<br>home 42 / 22','Almaty','Almaatinskaya oblast','KAZAKHSTAN','050042','+7 (777) 252-0300','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-14 05:01:30',0,NULL,3,0,3,1,'RA184590284CN\r ','hermeshine\r1.6*3  白色'),(25957,880374531017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.14,'photographyacc','vernegu','vernegu@optusnet.com.au','verne gu','1/26 Sefton RD','Thornleigh','New South Wales','AUSTRALIA','2120','0412524343','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-14 07:06:43',0,NULL,3,0,3,1,'RA184590298CN\r ','photographyacc\r1.6*3  白色'),(25958,8881331711467287,111,'10pcs Color Filter Box Ring & Holder for Cokin P series',2,'AKT066',166,'hermeshine','jafarq8','United States','Jafar Eslami','29 W. Pleasant St.','Hamilton','','NY ','13346','',NULL,NULL,NULL,'2012-03-14 07:51:07',0,NULL,5,0,18,0,NULL,'地址：\rJafar Eslami\r29 W. Pleasant St.\rHamilton, NY 13346\rUnited States '),(25959,8881331711605770,111,'10pcs Color Filter Box Ring & Holder for Cokin P series',2,'AKT006',166,'hermeshine','jafarq8','jmousawi@gmail.com','Jafar Eslami','29 W. Pleasant St.','Hamilton','NY','UNITED STATES','13346','',NULL,NULL,NULL,'2012-03-14 07:51:07',0,NULL,3,1,1,1,'LK108973521CN ','2套10片装滤镜\r其中一套是 58mm 环，\r一套是67mm环\r再加一个67mm 环\r永诺 MC-N3  1\r已入库\r'),(25960,8881331713847404,111,'Free shipping & Tracking # - IR Remote Control for Canon 7D/550D/450D/500D - AA2202',1,'AA2202',5.99,'aliexpress','1007367803','racer.mad@gmail.com','Panov Evgeniy','B.Pereyaslavskaya 6-39','Moscow','Moscow','RUSSIAN FEDERATION','129110','+8 926 5887899',NULL,NULL,NULL,'2012-03-14 08:30:47',0,NULL,3,1,3,1,'RA184590315CN\r ','速卖通'),(25961,8881331714130460,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',1,'AB3329',48.99,'aliexpress','1007384005','cjcool@yandex.ru','Alexandr Selunin','Sergeya Tulenina 8-49','Kemerovo','Kemerovskaya','RUSSIAN FEDERATION','650024','+7 913 1267964',NULL,NULL,NULL,'2012-03-14 08:35:30',0,NULL,3,1,17,0,'CP246990664CN\r ',NULL),(25962,8881331714203196,111,'Free shipping & Tracking # - New Portable 40cm 16\"x16\" Soft Box Softbox for Flash - Whole/Retail AB3327',1,'AB3327',39.99,'aliexpress','1007383826','cjcool@yandex.ru','Alexandr Selunin','Sergeya Tulenina 8-49','Kemerovo','Kemerovskaya','RUSSIAN FEDERATION','650024','+7 913 1267964',NULL,NULL,NULL,'2012-03-14 08:36:43',0,NULL,3,1,5,1,'CP246990664CN\r ','闪光的柔光箱   60cm  1 \r闪光的柔光箱   40cm    1\r速卖通'),(25963,965877172015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','palanchoke','nirdoshpalanchoke@yahoo.com','Nirdosh Palanchoke','Unit 1, 90 Samford Road','Alderley','Queensland','AUSTRALIA','4051','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 08:59:15',0,NULL,3,1,3,1,'RA184590390CN\r ','hutongstore'),(25964,857217552002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',3,'AD1169',20.64,'hermeshine','extracut','extracut@hotmail.com','Teerapaj jornvong','25 , Soi. Ngamwongwan 47 yak 20<br>Ngamwongwan Rd.,','Tongsonghong, Laksi','Bangkok','THAILAND','10210','+66834283383','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 08:42:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(25965,857231082002,120538959115,'NEW Flash Diffuser for Canon 580EX II',1,'AB3332',2.6,'hermeshine','drorartzi','drorartzi@gmail.com','Dror Artzi','default','Kibbutz Kfar Hanassi','','ISRAEL','12305','972528088775','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 09:37:51',0,NULL,3,1,17,0,NULL,'hermeshine'),(25966,857231083002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',3.98,'hermeshine','drorartzi','drorartzi@gmail.com','Dror Artzi','default','Kibbutz Kfar Hanassi','','ISRAEL','12305','972528088775','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 09:37:52',0,NULL,3,1,11,1,NULL,'hermeshine\r肥皂盒 柔光罩   580EX  1\r普通有线快门线C3  1'),(25967,945843553016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','biosbuster','ken.brown@petsday.co.uk','Ken Brown','7 Hillfield Drive','Skirlaugh','East Riding of Yorkshire','UNITED KINGDOM','HU11 5DQ','01964563452','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 10:14:16',0,NULL,3,1,11,1,NULL,'hutongstore'),(25968,857241668002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','pete322bikerallies','deadendpete@cableone.net','pete pierce','817 Crescent Dr','independence','KS','UNITED STATES','67301-2332','(620) 330-7537','NoPaymentFailure','CheckoutComplete','Other','2012-03-14 10:19:34',0,NULL,3,1,1,1,'LK233375593CN ','hermeshine\rXL  已入库'),(25969,857249210002,120601699920,'New 58mm ring adapter replacement for cokin P series',1,'AA2210',2.18,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 10:46:24',0,NULL,3,1,17,0,'RA184590386CN ','hermeshine'),(25970,857249212002,120539340154,'New 72mm ring adapter replacement for cokin P series',1,'AA2213',2.18,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 10:46:24',0,NULL,3,1,17,0,'RA184590386CN ','hermeshine'),(25971,812528886001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 10:46:25',0,NULL,3,1,17,0,'RA184590386CN ','hermeshine'),(25972,857249209002,120448641700,'52mm 52 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT018',4.1,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 10:46:23',0,NULL,3,1,17,0,'RA184590386CN ','hermeshine'),(25973,857254303002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',2,'AD1224',7,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 11:04:19',0,NULL,3,1,17,0,' RA184590386CN','hermeshine'),(25974,637347816004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',2,'AD1219',7,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 11:04:20',0,NULL,3,1,17,0,'RA184590386CN ','hermeshine'),(25975,812534038001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',2,'AD1218',7,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 11:04:21',0,NULL,3,1,17,0,' RA184590386CN','hermeshine'),(25976,965924599015,250939066117,'New JueYing Lambency Flash Bowl Diffuser for Canon 550EX 580EX(II) 550EX P4',1,'AB3312',11,'hutongstore','aco224','aco24@net.hr','Aleksandar Obranović','Cvjetna 26','Glogovac','Kop Bregi','CROATIA','48324','098545842','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 11:08:47',0,NULL,3,1,3,1,'RA184590854CN\r ','hutongstore'),(25977,812534035001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',2,'AD1220',7,'hermeshine','alexvasin','dark.finances@gmail.com','Alexandr Vasin','Svobody street 91-147','Moscow','Moscow','RUSSIAN FEDERATION','125481','+7-915-381-3249','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 11:04:20',0,NULL,3,1,3,1,'RA184590386CN\r ','hermeshine\r方形滤镜接口环 58mm  1\r方形滤镜接口环 72mm    1\r方形滤镜接口环 67mm   1\r方镜普通托架（三槽）   2\r方形滤镜接口环 52mm    1\r无牌方镜 渐变蓝    2\r无牌方镜 渐变灰 （nd4）    2\r无牌方镜 渐变灰 （nd2）   2\r无牌方镜 渐变灰 （nd8）   2'),(25978,0,110837413762,'New Professional Hot Shoe hotshoe Cover Cap Nikon Canon',1,'AA1204',0.06,'hermeshine','pr.ministr','slonyara23@mail.ru','Andrey Lyaubakh','Kalinina prospekt d. 3, kv. 56','Barnaul','Алтайский край','RUSSIAN FEDERATION','656002','923-795-06-62','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 11:22:41',0,NULL,3,1,11,1,NULL,'hermeshine'),(25979,812562885001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','macsoft3','mailprivado@netcabo.pt','Manuel  Macedo','LG CMDT AUGUSTO MADUREIRA<br>N-5, 4DTO','LISBOA','ALGES','PORTUGAL','1495-012','+351962541517','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 12:43:43',0,NULL,3,1,11,1,NULL,'hermeshine'),(25980,857286269002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','totorie','ccachy@gmail.com','Jack CHO','8  Kennedy  St<br>Unit 1','Glen Waverley','Victoria','AUSTRALIA','3150','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 12:52:18',0,NULL,3,1,11,1,NULL,'hermeshine'),(25981,812575982001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','dormevutlm','tmccabe2@columbus.rr.com','Theresa McCabe','5600 Deergrass Ct','Grove City','OH','UNITED STATES','43123-9276','(614) 560-3033','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 13:26:56',0,NULL,3,0,1,1,'LK233387574CN ','hermeshine\r1.6*2.1  黑色'),(25982,812275524001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1303',6.68,'hermeshine','chevy56591','chevybol@hotmail.com','Eusebio Parada Roda','Calle 27 de mayo 81<br>Zona Barrio Lindo','Santa Cruz de la Sierra','Santa Cruz','BOLIVIA','591','591-3-3323132','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 13:39:01',0,NULL,3,1,11,1,NULL,'hermeshine'),(25983,857305450002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','bausheff','bausheff@mail.ru','Andrey Baushev','Yamskaya, 76-155','Tyumen','Tyumenskaya oblast','RUSSIAN FEDERATION','625001','89222693946','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 13:48:44',0,NULL,3,1,11,1,NULL,'hermeshine'),(25984,965934370015,250599423416,'62mm Snap-on Front Cap for Nikon 62mm Filters Lens New',1,'AA1306',1.88,'hutongstore','kenjiemazzami','ezrihayat@rocketmail.com','Ezri Hayat','42 gainsborough street','Salford','Greater Manchester','UNITED KINGDOM','m7 4an','07423153242','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 13:55:06',0,NULL,3,1,11,1,NULL,'hutongstore'),(25985,965978554015,251017296011,'2 Umbrellas- 2m Light Stand- Flash/Umbrella mount bracket 4 Portable Speedlight',1,'AKT100',32,'hutongstore','del-off','tipa_ya@rambler.ru','Yuri Delov','Magistral\'niy proezd, 5A, 97','Kursk','','RUSSIAN FEDERATION','305025',' 123123123','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 13:26:40',0,NULL,3,1,3,1,'RA184590474CN\r ','hutongstore\r1.67kg'),(25986,966024084015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','molotok.ru','digishop@mail.ru','Alexsander Lubyshev','Izmailovskiy proezd, d.13, kv. 210','Moscow','','RUSSIAN FEDERATION','105122','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-14 15:08:26',0,NULL,3,1,5,1,'CP246990655CN ','hutongstore'),(25987,945970273016,260660055319,'32\" 5-in-1 Light Mulit Collapsible disc Reflector 80cm',1,'AC3301',9.78,'hutongstore','seffie44','serafina231001@yahoo.co.uk','carrie snowden','Flat 27 Woodgate Lodge<br>28-32 Belfast Road','Bangor','Down','UNITED KINGDOM','BT20 3GS','02891478560','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 15:31:54',0,NULL,3,1,17,0,'RA184590372CN ','hutongstore'),(25988,945970275016,260660052077,'New 58mm 58 Ring adapter and Holder for Cokin P Series',1,'AKT020',3.12,'hutongstore','seffie44','serafina231001@yahoo.co.uk','carrie snowden','Flat 27 Woodgate Lodge<br>28-32 Belfast Road','Bangor','Down','UNITED KINGDOM','BT20 3GS','02891478560','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 15:31:56',0,NULL,3,1,17,0,'RA184590372CN ','hutongstore'),(25989,966036638015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','seffie44','serafina231001@yahoo.co.uk','carrie snowden','Flat 27 Woodgate Lodge<br>28-32 Belfast Road','Bangor','Down','UNITED KINGDOM','BT20 3GS','02891478560','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 15:31:57',0,NULL,3,1,17,0,'RA184590372CN ','hutongstore'),(25990,966036639015,250606686008,'IR Wireless Remote Control for Nikon D90/D80/D60 ML-L3',1,'AA2201',2.75,'hutongstore','seffie44','serafina231001@yahoo.co.uk','carrie snowden','Flat 27 Woodgate Lodge<br>28-32 Belfast Road','Bangor','Down','UNITED KINGDOM','BT20 3GS','02891478560','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 15:31:57',0,NULL,3,1,17,0,'RA184590372CN ','hutongstore'),(25991,857308183002,120535045669,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT052',42.99,'hermeshine','shaydurov','n_shaydurov@mail.ru','Nikolay Shaydurov','Stavropolskaya str, 217/1, 47.','Krasnodar','','RUSSIAN FEDERATION','350058','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-14 15:43:08',0,NULL,3,1,3,1,'RA184590491CN\r ','hermeshine\r2云柔  1'),(25992,966036637015,250971426000,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',9.99,'hutongstore','seffie44','serafina231001@yahoo.co.uk','carrie snowden','Flat 27 Woodgate Lodge<br>28-32 Belfast Road','Bangor','Down','UNITED KINGDOM','BT20 3GS','02891478560','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-14 15:31:55',0,NULL,3,1,3,1,'RA184590372CN\r ','hutongstore\r无牌方镜 渐变蓝   1\r无牌方镜 渐变橙    1\r无牌方镜 渐变灰 （nd4）   1\r3片装的滤镜袋  1\r反光板  80cm 5合1  1\r方形滤镜接口环 58mm   1\r方镜普通托架（三槽）   1\r58-58mm 双阳环   1\r爵影红外 nikon  1'),(25993,966045630015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','barry4766','bj.chambers@ntlworld.com','B Chambers','17 Clayton<br>Orton Goldhay','Peterborough','Cambridgeshire','UNITED KINGDOM','PE2 5SB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 15:49:52',0,NULL,3,1,11,1,NULL,'hutongstore'),(25994,945991167016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','wasouski','muaythai500@hotmail.com','ruben torres isidro','c/antonio mendez nº3 3ºA','alcobendas','Madrid','SPAIN','28100','686170454','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 16:16:01',0,NULL,3,1,3,1,'RA184590369CN\r ','hutongstore'),(25995,966070371015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','rezframes','rezframes@gmail.com','Mojmir Pribis','Dicova 32','Piestany','Slovakia','SLOVAK REPUBLIC','92101','+421905741984','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 16:38:39',0,NULL,3,1,3,1,'RA184590457CN\r ','hutongstore\r澳转欧标'),(25996,966062184015,250692240030,'QR Quick Release Plate Video Tripod Head 717 EI-717A',1,'AB1204',12.99,'hutongstore','clyner123','hubieclyne@gmail.com','Mary Therese Clyne','Auburn Cottage,<br>Scarden, Strandhill Rd.','Sligo','Sligo','IRELAND','4','0863901698','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 16:23:06',0,NULL,3,1,11,1,NULL,'hutongstore'),(25997,812669804001,110723417494,'Universal Barn Door with Honeycomb Grid + 4 Color Gels',1,'AD1166',25.99,'hermeshine','denistenchi','tenchido@gmail.com','Denis Kriga','Orehovaya str.<br>house 9, flat 8','Kaliningrad','Kaliningrad','RUSSIAN FEDERATION','236039','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 17:38:13',0,NULL,3,1,3,1,'RA184590488CN\r ','hermeshine'),(25998,946049600016,260854010827,'New Official Canon Baseball Cap Hat EOS Rebel T1i 5D ii 7D SLR Black',1,'AD1189',11.9,'hutongstore','geoff_1975','geofcac@yahoo.com','Geoffrey Cachia','1.Vicpol<br>Tal-Mirakli Street,','Lija','','MALTA','Bzn10','7905 7988','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 18:04:01',0,NULL,3,1,11,1,NULL,'hutongstore'),(25999,966126779015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','jonsorsal','jonsorsal@yahoo.co.uk','jonathan salvador','53 herbert street','maindy','Cardiff','UNITED KINGDOM','cf14 3ap','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 18:16:08',0,NULL,3,1,11,1,NULL,'hutongstore'),(26000,857422096002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','idoelad1','idoelad@gmail.com','Ido Elad','Tel-chay 3','Jerusalem','','ISRAEL','92107','972-54-4302210','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 18:28:19',0,NULL,3,1,3,1,'RA184590443CN\r ','hermeshine'),(26001,966136753015,250662996740,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',12,'hutongstore','mikpz','mik.alo@hotmail.co.uk','michael allerton','top flat no 9 coulsons buildings<br>queen st','penzance','Cornwall','UNITED KINGDOM','tr184ds','07518681652','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 18:31:14',0,NULL,3,1,11,1,NULL,'hutongstore'),(26002,966175714015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','alexpotapov_tlt','bob008@list.ru','Aleksej Potapov','Larina street, 106<br>0','Togliatti','Samara region','RUSSIAN FEDERATION','445007','(903) 331 - 7772','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 19:31:41',0,NULL,3,1,5,1,'CP246990647CN ','hutongstore\r黑色和绿色背景布\r1.6*2.5m'),(26003,965860484015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','ocphotographyst','cdrsca@gmail.com','Igmar H. Rodas','3932 ESTRELLA CT','FORT WORTH','TX','UNITED STATES','76106-3261','(714) 760-2129','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 19:42:26',0,NULL,3,0,1,1,'LK233374417CN ','hutongstore\rL 已入库'),(26004,966192579015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','tommybank','tommydevine@blueyonder.co.uk','Thomas Devine','3 Butterwick Drive<br>Croxteth Park','Liverpool','Merseyside','UNITED KINGDOM','L12 0JQ','01515473430','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-14 19:47:06',0,NULL,3,1,11,1,NULL,'hutongstore'),(26005,812740111001,110532006949,'62mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1306',2.6,'hermeshine','iirt','auction@iirt.com','Amy Pichaikul','6901 Security Blvd<br>Luvyah Card 549','Windsor Mill','MD','UNITED STATES','21244-2412','(410) 265-5118','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 20:07:26',0,NULL,3,1,1,1,'LK233396077CN ','hermeshine'),(26006,637520826004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','shall0wgrave2011','shall0wgrave@sapo.pt','Vitor Dias','Zona Industrial Rua 13 s/n','Ponte De Sôr','','PORTUGAL','7400-207','938431407','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 20:41:57',0,NULL,3,1,11,1,NULL,'hermeshine'),(26007,946165866016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','m0rris0n01','aflour@portugalmail.pt','Artur Loureiro','Rua Damião de Gois 162 2ºDt<br>Cividade','Braga','Norte','PORTUGAL','4700','253 217035','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-14 20:48:54',0,NULL,3,1,11,1,NULL,'hutongstore'),(26008,812786668001,110468057118,'Gray card for White balance exposure flash meter 18%(S)',1,'AA2217',8.99,'hermeshine','ravi736','ravijag78@gmail.com','Mahend Jagmohansingh','Riverside Street','St Julien Village','Union Flacq','MAURITIUS','4188059','+2307513584','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 21:14:55',0,NULL,3,1,11,1,NULL,'hermeshine'),(26009,812784732001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','cookie9840','pjlsml@insightbb.com','Paul Lorenz','9840 Spring Gate Dr','Louisville','KY','UNITED STATES','40241-6117','(502) 618-3837','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-14 21:28:17',0,NULL,3,1,3,1,'RA184590430CN\r ','hermeshine\r美标'),(26010,966291197015,250846948112,'New 43\" 110cm Studio Flash White Reflective Umbrella',1,'AD1126',7.6,'hutongstore','mikl53','miklnolan@eircom.net','michael nolan','53 briarwood lawn, mulhuddart','dublin','leinster','IRELAND','15','018216063','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-14 22:07:43',0,NULL,3,1,11,1,NULL,'hutongstore'),(26011,857562323002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','ciafquito','andres@ciaf-quito.com','Andres Bahamonde','Alianza Francesa<br>Av. Eloy Alfaro N32-468 y Rusia','Quito','','ECUADOR','00000','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 22:55:31',0,NULL,3,1,3,1,'RA184590426CN\r','hermeshine'),(26012,812842818001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',2,'AD1181',39.8,'hermeshine','william44290','william.rosenthal@yahoo.fr','William Rosenthal','9 rue henry fournis','Guémené penfao','Pays de la Loire','FRANCE','44290','0240792863','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-14 23:29:43',0,NULL,3,1,3,1,'RA184590409CN\r ','hermeshine'),(26013,812850375001,110597206838,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',60,'hermeshine','staib3840','gstax@staibtax.com.au','John Staib','Staib Accounting & Tax<br>19 William Street','Beaudesert','Queensland','AUSTRALIA','4285','61755413055','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-14 23:54:57',0,NULL,3,1,4,1,'YW870147220CN ','hermeshine'),(26014,857580120002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','amandag23','amandag1223@gmail.com','amanda  garcia','16 hounslow rd','SHIRLEY','NY','UNITED STATES','11967-2514','(631) 395-2419','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-14 23:46:13',0,NULL,3,1,3,1,'RA184590412CN\r ','hermeshine'),(26015,812860507001,110606819595,'Tungsten bulb 800W for redhead light  X 1 3200K 220V',1,'AO0015',7.9,'hermeshine','ramitetro','rami.tetro@gmail.com','Rami Tetro','Amnon 12','Ashkelon','','ISRAEL','78671','97250226635','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 00:29:57',0,NULL,3,1,11,1,NULL,'hermeshine'),(26016,946277882016,260660053809,'New 82mm 82 mm Adapter Ring for Cokin P series Sigma 24-70mm',1,'AA2222',1.6,'hutongstore','jetta_pt','guy@oplan.cc','Luis Antunes','Rua Amigos do Huambo, 26 - 2ºesq.<br>Apartado 312','Caldas da Rainha','','PORTUGAL','2500-126','968453812','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 00:30:16',0,NULL,3,1,11,1,NULL,'hutongstore'),(26017,857613430002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',3,'AD1199',98.97,'hermeshine','nebojsam2005','neb.mila@gmail.com','Nebojsa Milasinovic','34 Drinkwater Cresent, West Sunshine','Melbourne','Victoria','AUSTRALIA','3020','0355545555','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 01:33:49',0,NULL,3,1,3,1,'RA184590505CN\r ','hermeshine'),(26019,8881331776194263,111,'Free shipping & Tracking # - New 77mm Fader ND Neutral Density filter ND2 to ND400 - AD1143',1,'AD1143',32.99,'aliexpress','1007389682','vincenzocamiolo@tiscali.it','vincenzo camiolo','via col garlanda 65','erto e casso','pn','ITALY','33080','+0039 338 3387121',NULL,NULL,NULL,'2012-03-15 01:49:54',0,NULL,3,1,3,1,'RA184590655CN\r ','速卖通 '),(26020,8881331778584632,111,'三脚架 伟峰 EI-717  155配件',1,'',0,'hutongstore','konruludmila','kon-ru@yandex.ru','Lydmila Tolstova','Army 60, house 25 apartment 58','Voronezh','Voronezh region','RUSSIAN FEDERATION','394077','79102479231',NULL,NULL,NULL,'2012-03-15 02:29:44',0,NULL,3,0,3,1,'RA184590465CN\r ',NULL),(26021,819849098018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',66.5,'photographyacc','telephoto2003','turnerww@hotmail.com','Wayne Turner','Flat 2 / 9 Greta Street<br>South Hill','Oamaru','Otago','NEW ZEALAND','9400','027 4347974','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 03:11:41',0,NULL,8,1,17,0,NULL,'photographyacc'),(26022,819853269018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',2,'AD1179',28.48,'photographyacc','telephoto2003','turnerww@hotmail.com','Wayne Turner','Flat 2 / 9 Greta Street<br>South Hill','Oamaru','Otago','NEW ZEALAND','9400','027 4347974','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 03:19:22',0,NULL,3,1,6,1,'EE667257945CN ','photographyacc\r反光板支架  2\r反光板支架的夹子（双轮）   2'),(26023,857654259002,120817998195,'New Mini IR Wireless Remote Control for Olympus E520E E420',1,'AD1119',3.3,'hermeshine','trent_mclennan','hellrad@hotmail.com','Trent McLennan','130 boynton st','balranald','New South Wales','AUSTRALIA','2715','0350200512','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 04:03:13',0,NULL,3,1,11,1,NULL,'hermeshine'),(26024,812919202001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',2,'AE3401',51.98,'hermeshine','jurgend71','jurgen_degrande@telenet.be','Jurgen Degrande','Gentweg 36','Zedelgem','','BELGIUM','8210','0478560642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 04:06:22',0,NULL,3,1,4,1,'YW870147231CN ','hermeshine'),(26025,819868075018,280667309453,'QR Quick Release Plate Tripod Head For Fancier FT-6662A',1,'AB1202',6.63,'photographyacc','ajalr','alan.bromley@bigpond.com','Joanne Bromley','22 Carey Crt','Sunbury','Victoria','AUSTRALIA','3429','0397446704','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 04:22:38',0,NULL,3,1,11,1,NULL,'photographyacc'),(26027,857685706002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','seremell','seremela@mail.ru','Александр Игнатьев','Ремизова, 21,18','Санкт-Петербруг','Россия','RUSSIAN FEDERATION','196650','8-921-599-79-51','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 07:22:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(26028,946392905016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','sai_cat','saikit.to@gmail.com','Sai To','57 Merrifield Circle<br>Leeming','Perth','Western Australia','AUSTRALIA','6149','0402821835','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-15 07:25:08',0,NULL,3,1,11,1,NULL,'hutongstore'),(26031,857705987002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','coolmiss','aldegonde@gmail.com','Aldegonde Le Compte','rue petite coyarde 6 (or 8 if absent)','Mont Saint Andre (Ramillies)','','BELGIUM','1367','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 08:46:04',0,NULL,3,1,3,1,'RA184590837CN\r ','hermeshine\r防寒罩  1\r伞式柔光箱 60×90cm   2'),(26032,819440117018,280666887507,'New Green.L 52mm  Gradual Grey ND4 Filter 2-Stop 52 mm',1,'AA3315',5.89,'photographyacc','fillmoren','nomes.14@hotmail.com','Naomi Fillmore','4 Lawrence St','Mooloolaba','Queensland','AUSTRALIA','4557','0422926085','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 09:19:20',0,NULL,3,1,11,1,NULL,'photographyacc'),(26033,8881331804713837,111,'60闪光柔光箱',6,'AB3329',279,'hutongstore','belogor83','akoshechkin@gmail.com','Ludmila Chernikova','Generala Simonyaka dom11 kv29','Sankt-Peterburg ','','RUSSIAN FEDERATION','198261','',NULL,NULL,NULL,'2012-03-15 09:45:13',0,NULL,3,1,5,1,'CP246990681CN\r ',NULL),(26034,819940000018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',36.1,'photographyacc','rayw007','nojoke00@hotmail.com','Ray Warren','Apt. 3407<br>380 Little Lonsdale St','Melbourne','Victoria','AUSTRALIA','3000','0390176801','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 10:06:32',0,NULL,3,1,3,1,'RA184590531CN\r ','photographyacc'),(26035,942424215016,260635341118,'Pro Photo Studio Reflector Holder hold Arm 0.66m - 1.5m',1,'AE2501',22,'hutongstore','geezermarshy','stevenrobertmarsh@hotmail.co.uk','Steven Marsh','36 Mulberry Avenue','Stubbington','Hampshire','UNITED KINGDOM','po142sn','01329667671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 10:07:12',0,NULL,3,1,3,1,'RA184590528CN\r ','hutongstore'),(26036,812999840001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','jamus1402','msberns@gmail.com','shahar livny','Halon 5 appartment 1','Gedera','','ISRAEL','70700','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 10:49:37',0,NULL,3,1,3,1,'RA184590514CN\r ','hermeshine'),(26037,857739334002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','melanitta1','melanitta@yandex.ru','Lidziya Puchkova','Street Knorina, the house 4, apartment 15','Minsk','','BELARUS','220049','+375447440755','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 10:51:09',0,NULL,3,1,3,1,'RA184590602CN\r ','hermeshine'),(26038,857748430002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','edd1899','vaulet@hotmail.fr','VAULET EDDY','37 Rue de la Liberté \"Le Square Pasteur\"<br>Boîte N° 21 App 113 Etg 2','Villejuif','Ile-de-France','FRANCE','94800','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 11:25:07',0,NULL,3,1,11,1,NULL,'hermeshine'),(26039,813012278001,110717444953,'New Collapsible 4.6\' x 6.4\' 190x140 cm backdrop background color White',1,'AD1206',42,'hermeshine','minnie_005','minnie005@hotmail.co.uk','Mohini Mistry','49 Stanhope Street','Leicester','Leicestershire','UNITED KINGDOM','LE5 5EW','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 11:40:31',0,NULL,3,1,3,1,'RA184590593CN\r ','hermeshine'),(26040,857752739002,120841734374,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',13.88,'hermeshine','loyed.francis','loyed_francies@email.com','Loyed Francis','Old Passport Road','Abu Dhabi','Abu Dhabi','UNITED ARAB EMIRATES','2254','00971508158094','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 11:41:16',0,NULL,3,1,11,1,NULL,'hermeshine'),(26041,813016763001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','avonjai','avoniee01@hotmail.com','avon young','315 Stevens Cir<br>Apt 3C','aberdeen','MD','UNITED STATES','21001-2700','(951) 544-4196','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 11:53:31',0,NULL,3,1,3,1,'RA184590580CN\r ','hermeshine\r美国的必须有单号'),(26042,857757019002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','tempus.brazil','tiagodebrino@gmail.com','Tiago Ricardo De Brino','Rua Mario de Andrade 808','Ribeirao Preto','Sao Paulo','BRAZIL','14030-340','551681158707','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 11:56:04',0,NULL,3,1,3,1,'RA184590576CN\r ','hermeshine\r要挂号，发账单，已付款'),(26043,819975748018,280740686285,'New 100% Authentic / Official Canon Baseball Cap Hat 5D mark II 7D 60D 40D EOS',1,'AD1189',19,'photographyacc','tlc286','tlconstable@bigpond.com','Tracey Constable','75  Nanbaree  Dr','Bray Park','Queensland','AUSTRALIA','4500','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 12:11:41',0,NULL,3,1,11,1,NULL,'photographyacc'),(26044,966566232015,250948075013,'Brand New Lens Repair Tool Stainless Steel Spanner Wrench with swap-able tips',2,'AD1207',50,'hutongstore','hidefaerialsurveying','elaine.southward@hidefsurveying.co.uk','Elaine  Southward','Phoenix Court<br>Earl Street','Cleator Moor','Cumbria','UNITED KINGDOM','CA25 5AU','01946814463','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 12:22:00',0,NULL,3,1,3,1,'RA184590735CN\r ','hutongstore'),(26045,813028416001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','lifeaxe_products','sales@lifeaxe.com','Allan  Rhodes','36 Brymore Close<br>Prestbury','Cheltenham','Gloucestershire','UNITED KINGDOM','GL52 3DY','01242231096','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-15 12:35:21',0,NULL,5,0,18,0,NULL,'hermeshine\rL 已入库\r客户要取消，已退款'),(26046,813029822001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',1,'AA2114',32,'hermeshine','mcneice2006','wamcneice@hotmail.com','William McNeice','51 main street','Parkside','SK','CANADA','s0j2a0','(306) 747-2868','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-15 12:40:12',0,NULL,3,1,3,1,'RA184590721CN\r ','hermeshine\rXL 已入库'),(26047,946502657016,260894475033,'PRO LED 312 Panel Camera & Camcorde​r Light,3200-5600k 312AS for 5D2 7D 60D',1,'AD1149',139,'hutongstore','devitaitp','devitait@gmail.com','D T Peters','3 Adamson Gardens<br>Didsbury','Manchester','Greater Manchester','UNITED KINGDOM','M20 2TQ','01614341258','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-15 13:10:35',0,NULL,3,1,4,1,'YW870147275CN\r ','hutongstore'),(26048,637720864004,140642545867,'New 28\"x40\"/ 70x100cm Softbox Metal Universal Mount for strobe 2 layers diffuser',1,'AD1141',57,'hermeshine','startrekereduardo','trianguel@gmail.com','EDUARDO GRAFFIGNA','JUAN BAUTISTA ALBERDI<br>64 A PB','BUENOS AIRES','CIUDAD AUTONOMA DE BUENOS AIRES','ARGENTINA','1424','49227532','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 13:13:31',0,NULL,3,1,3,1,'RA184590718CN ','hermeshine'),(26049,813049120001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',2,'AD1180',27.8,'hermeshine','dublin_harbour','chalmers@eircom.net','Joe Chalmers','10 brookfield Green<br>KCR','DUBLIN','Dublin','IRELAND','12','014928328','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 13:52:35',0,NULL,3,1,17,0,'RA184590797CN ','hermeshine'),(26050,813052286001,110422375449,'Aluminium Lightweight 71\" Camera Monopod with 3way-head',1,'AE1603',35.9,'hermeshine','dublin_harbour','chalmers@eircom.net','Joe Chalmers','10 brookfield Green<br>KCR','DUBLIN','Dublin','IRELAND','12','014928328','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 13:52:36',0,NULL,3,0,3,1,'RA184590797CN ','hermeshine\r斜臂的夹子（单轮）   2\r独脚架  伟峰 WT-1005  1'),(26051,966613974015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','leejbarker1982','ljb82@me.com','Lee Barker','31 Boxtree Avenue','Hucknall','Nottinghamshire','UNITED KINGDOM','NG156UT','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-15 14:11:33',0,NULL,3,1,3,1,'RA184591364CN\r ','hutongstore'),(26052,857801776002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',2,'AE3101',59.98,'hermeshine','yekophotostudio','yeko@inbox.lv','Sergejs Rahunoks','maskavas 224-50','Riga','','LATVIA','LV-1019','+371 220-740-95','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 14:23:35',0,NULL,8,1,17,0,'CP246990695CN\r ','hermeshine'),(26053,966625763015,250599942518,'72mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1306',2.56,'hutongstore','daveshrive','daveshrive@aol.com','sharon shrive','the post room box. 46 - shrive<br>calle azorin 2 bajo','san miguel de salinas','alicante','SPAIN','03193','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 14:38:58',0,NULL,3,1,11,1,NULL,'hutongstore'),(26054,813068841001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','yekophotostudio','yeko@inbox.lv','Sergejs Rahunoks','maskavas 224-50','Riga','','LATVIA','LV-1019','+371 220-740-95','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 14:43:52',0,NULL,3,1,5,1,'CP246990695CN\r ','hermeshine\r斜臂   2\r斜臂的夹子（单轮）  1'),(26055,820033373018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',2,'AE2501',66.5,'photographyacc','jameswantsone','james.corker@team.telstra.com','James Corker','28 Melbourne Street','St James','Western Australia','AUSTRALIA','6102','0418635505','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 14:59:34',0,NULL,3,1,3,1,'RA184590806CN ','photographyacc'),(26056,966646888015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',5.6,'hutongstore','jwright1962','jwright6@virginmedia.com','mrs j wright','22 ash view<br>munsbrough','rotherham','South Yorkshire','UNITED KINGDOM','s61 4nl','01709210948','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 15:27:19',0,NULL,3,1,11,1,NULL,'hutongstore'),(26057,813083326001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','gfd628','mgroves912@yahoo.com','mike groves','310 york st','greenville','KY','UNITED STATES','42345-1342','(270) 543-7428','NoPaymentFailure','CheckoutComplete','Other','2012-03-15 15:27:35',0,NULL,3,0,1,1,'LK234093611CN ','hermeshine\r3XL 已入库'),(26058,966645564015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','dazzle-star','daz@3-daz.com','Darren Mallard','6 Grosvenor Court<br>Grosvenor Road','Hoylake','Merseyside','UNITED KINGDOM','CH472BJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-15 15:49:21',0,NULL,3,1,3,1,'RA184590752CN\r ','hutongstore'),(26059,857839766002,120752248934,'33\" double layers reflective and translucent umbrella',1,'AD1156',20.99,'hermeshine','sagistious','leibmans@gmail.com','Sagi Leibman','Hanagid 4','Ramat Gan','','ISRAEL','52473','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 16:05:41',0,NULL,3,1,11,1,NULL,'hermeshine'),(26060,857848742002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','fastjumpers','carlosmay@carlosmay.com.br','Carlos May','Rua Caetano Silveira de Matos, 2654','Palhoça','Santa Catarina','BRAZIL','88130-005','(048)32421183','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 16:36:25',0,NULL,3,1,3,1,'RA184590749CN\r ','hermeshine'),(26061,813104899001,110409525731,'Neoprene Protector Camera Cover Case for Canon Nikon M',1,'AC1301',6.24,'hermeshine','krisdelpen','krisnoel_p@yahoo.com','Kris Noel Penaroyo','P.O.BOX 48812, AL-Nasr Plaza Office Building No. 4,<br>Room 411, 4th Floor, 10th Street, Oud Metha Road,','Dubai','Dubai','UNITED ARAB EMIRATES','00971','0097155 5514978','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 17:12:07',0,NULL,3,1,11,1,NULL,'hermeshine'),(26062,857867220002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','wdschmidt','wdschmidt@mailexcite.com','William D. Schmidt','PO Box 1888','Farmington','NM','UNITED STATES','87499-1888','(505) 327-3432','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-15 17:12:35',0,NULL,3,1,1,1,'LK234126500CN ','hermeshine'),(26063,946664650016,260901272183,'New Camera protector case Neoprene bag for Nikon D40 D3000 D3100 50mm 18-55mm',1,'AD1171',5.2,'hutongstore','gonzalogallardorecuerda','gongalla@hotmail.com','gonzalo gallardo recuerda','c/ carboneros nº 2 , 4º','La Linea de la Concepcion','Andalucía Ceuta y Melilla','SPAIN','11300','654086392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 18:48:22',0,NULL,3,1,17,0,NULL,'hutongstore'),(26064,966758739015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','gonzalogallardorecuerda','gongalla@hotmail.com','gonzalo gallardo recuerda','c/ carboneros nº 2 , 4º','La Linea de la Concepcion','Andalucía Ceuta y Melilla','SPAIN','11300','654086392','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-15 18:50:05',0,NULL,3,1,11,1,NULL,'hutongstore\r新款内胆包 S  Nikon    1\r带水平仪 热靴保护盖  1'),(26065,813177799001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','rodsilvab','destrocaipora@gmail.com','Rodrigo da Silva Brasil','Av. São Francisco<br>98','Sorocaba','São Paulo','BRAZIL','18095-450','+55 15 91081272','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:09:54',0,NULL,3,1,11,1,NULL,'hermeshine'),(26066,813182877001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','knightwolf1986','keyckarp@hotmail.com','keith karpelenia','77 N Granada Cir','casa grande','AZ','UNITED STATES','85122-5707','(520) 705-2327','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-15 19:16:52',0,NULL,3,1,4,1,'YW870147253CN\r ','hermeshine'),(26067,813183688001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','yorkiemommy17','lauralbland@hotmail.com','Laura Bland','99 Maple Avenue','New Glasgow','NS','CANADA','B2H 2B5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:19:10',0,NULL,3,0,17,0,'RA184590664CN\r ','hermeshine'),(26068,813182121001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','yorkiemommy17','lauralbland@hotmail.com','Laura Bland','99 Maple Avenue','New Glasgow','NS','CANADA','B2H 2B5','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:19:11',0,NULL,3,0,3,1,'RA184590664CN\r ','hermeshine\r1.6*2.1  黑色  1\r1.6*2.1   白色   1'),(26069,966786713015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','calicojack.1209','robb-is@hotmail.com','robb dove','42, polgine lane<br>TROON','camborne','Cornwall','UNITED KINGDOM','tr149dy','01209717551','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-15 19:27:05',0,NULL,3,1,3,1,'RA184590633CN\r ','hutongstore'),(26070,857943035002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','coldlocoman','anderson_harlen@yahoo.com.br','Fernanda Mota','rua dos cravos,426<br>inacio barbosa','Aracaju','Sergipe','BRAZIL','49040-140','055 21 79 8139 7614','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 19:44:53',0,NULL,3,1,3,1,'RA184590620CN\r ','hermeshine'),(26071,813198335001,110578448527,'Pro Photo Vest for Nikon D60 D80 D90 D5000 D700 user',1,'AA2101',37,'hermeshine','johnkenny','0jlk00@gmail.com','John Kenny','12901 Vint Hill Rd','Nokesville','VA','UNITED STATES','20181-3622','','NoPaymentFailure','CheckoutComplete','Other','2012-03-15 19:45:49',0,NULL,3,0,1,1,'K234102313CN ','hermeshine\r3XL 已入库'),(26072,813220949001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','antoligau','antoligau@hotmail.com','Antonio Oliva Gaudens','Castell de Verdu, 6','LLEIDA','Cataluña','SPAIN','25198','639601621','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 20:25:28',0,NULL,3,1,3,1,'RA184590616CN\r ','hermeshine\r欧标'),(26073,813221022001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','wilsonfreitas10','wilsonantoniodefreitas@bol.com.br','Wilson Antônio de Freitas','Rua 98, nº 6<br>Bairro João XXIII','Timóteo','Minas Gerais','BRAZIL','35.180-364','(31)87183484','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 20:25:24',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(26074,813249786001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','iveta-mihaljevic','jos.jedan.jan.iveta@gmail.com','Jan Iveta','Baruna Trenka 7','Zagreb','Grad Zagreb','CROATIA','10000','00385914621142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:18:24',0,NULL,3,1,17,0,'CP246990718CN ','hermeshine'),(26075,813249787001,110569963962,'New thicken Non Woven Fabric Backdrop 3m x 3m(10x10 ft)',1,'AO0018',45,'hermeshine','iveta-mihaljevic','jos.jedan.jan.iveta@gmail.com','Jan Iveta','Baruna Trenka 7','Zagreb','Grad Zagreb','CROATIA','10000','00385914621142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:18:25',0,NULL,3,0,17,0,'CP246990718CN ','hermeshine'),(26076,813249788001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',2,'AD1217',65.98,'hermeshine','iveta-mihaljevic','jos.jedan.jan.iveta@gmail.com','Jan Iveta','Baruna Trenka 7','Zagreb','Grad Zagreb','CROATIA','10000','00385914621142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:18:25',0,NULL,3,1,17,0,'CP246990718CN ','hermeshine'),(26077,813249789001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',9.5,'hermeshine','iveta-mihaljevic','jos.jedan.jan.iveta@gmail.com','Jan Iveta','Baruna Trenka 7','Zagreb','Grad Zagreb','CROATIA','10000','00385914621142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 21:18:26',0,NULL,3,1,5,1,'CP246990718CN\r ','hermeshine\r3m 横杆（通用4节）   1\r背景布 3x3 白色  1\r2.5m高灯架   2\r单灯头   1\r欧标\r链接里说是3m X 3m 的，在确认一下'),(26078,858018747002,120489237091,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',3,'AE1302',28.5,'hermeshine','danielwhiteman','daniel_movies@yahoo.com','Marius Danut Duca','Vlad Judetu nr2, Bl. V 14 A, Sc.2, Etj.4, Ap.42, Sector 3','Bucuresti','RI','ROMANIA','031304','+40723.229.168.','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 22:04:18',0,NULL,3,1,3,1,'RA184590704CN\r ','hermeshine\r欧标'),(26079,813283920001,110571501527,'Photo Softbox Light Tent Cube Soft Box 16\" 40cm NEW',1,'AC2401',19.89,'hermeshine','lvsite','esrega@yahoo.com','Esther Reyes','Vizcaya 9-101','Mexico City','Mexico City','MEXICO','03740','5255 24545410','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 22:36:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(26080,966916150015,250849647070,'Video 2400w RedHead Continuous Lighting Kit 800w Expres',1,'AKT072',170,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_CollectInPersonInternational','2012-03-15 22:41:18',0,NULL,3,1,5,1,'CP236402369CN\r','hutongstore\r申报70\r泡重16.3\r改发sal吧，之前dhl的会退回来\r2584850914 \r'),(26081,820264955018,280696871259,'100% Cotton  Photo Vest for Canon 550D 40D 50D 5D2 user',1,'AD1134',28.49,'photographyacc','mgeezerbloke','mgeezerbloke@aol.com','MARTYN GARDNER','32 BEVERLY WAY','RAMSGATE','Kent','UNITED KINGDOM','CT126DN','01843596103','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-15 22:49:41',0,NULL,3,0,3,1,'RA184590695CN\r ','photographyacc\r3XL  已入库'),(26082,879333875017,270748173446,'4 in 1 Studio Daylight Bulb E27 Lamp Socket Adapter',1,'AE3301',14.06,'photographyacc','arkan3223','sales.innovision@hotmail.com','Aleksandar Matic','69 Vella crescent, Blacktown','Sydney','New South Wales','AUSTRALIA','2148','0298316730','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 23:15:15',0,NULL,3,0,2,0,NULL,'photographyacc'),(26083,813299336001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','cpulgar','cp.compra@gmail.com','Carlos Pulgar','Doctor Ramon Corvalan 32<br>Departamento 301','Santiago','Región Metropolitana','CHILE','8331088','+56998879957','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-15 23:20:28',0,NULL,3,1,5,1,'CP246990704CN\r ','hermeshine'),(26084,966935687015,250895543710,'Pro Camera Tripod Ball Head KS-0 II + Quick Release Plate for Benro/Manfrotto',1,'AD1186',18.99,'hutongstore','andyc_r','andy.carsonr@googlemail.com','Andy Carson-Rowland','13 Lucastes Lane','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 1LB','01444450597','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-15 23:21:07',0,NULL,1,1,3,1,'RA184595953CN\r ','hutongstore\r已发货'),(26085,820280212018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',8,'AA1312',10.88,'photographyacc','jackie01kerry','kerry.pete.nomads@gmail.com','kerry robinson','17 barracuda ct<br>palm beach','gold coast','Queensland','AUSTRALIA','4221','610755082088','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 23:30:20',0,NULL,3,1,17,0,'RA184590681CN\r ','photographyacc'),(26086,820279896018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','jackie01kerry','kerry.pete.nomads@gmail.com','kerry robinson','17 barracuda ct<br>palm beach','gold coast','Queensland','AUSTRALIA','4221','610755082088','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-15 23:30:20',0,NULL,3,1,3,1,'RA184590681CN\r ','photographyacc\r麂皮   9'),(26087,858066418002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','toquynh','quynhtoto@yahoo.com','Quynh To','317 Idaho Ln','Murphy','TX','UNITED STATES','75094-3692','(972) 804-2860','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-16 00:15:46',0,NULL,3,1,1,1,'LK234086584CN ','hermeshine'),(26088,820309242018,280666903675,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',96.9,'photographyacc','paul-beattie','usefullstuff@hotmail.com','Paul Beattie','18/76 Reserve Road','Artarmon','New South Wales','AUSTRALIA','2064','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 01:02:54',0,NULL,3,1,4,1,'YW870147264CN\r ','photographyacc'),(26089,8881331862814459,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',1,'AB3329',48.99,'aliexpress','1007419448','andreyvedernikov74@yandex.ru','ANDREY VEDERNIKOV','ul. Lenina, d. 7, kv. 33','g. Magnitogorsk','Chelyabinskaya obl.','RUSSIAN FEDERATION','455001','+8 909 0923250',NULL,NULL,NULL,'2012-03-16 01:53:34',0,NULL,3,1,3,1,'RA184591055CN ','速卖通 '),(26090,8881331863232786,111,'New Photo Studio Background Support 3m x 2.4m + Free Backdrop + Free Carry bag - Wholesale/ Retail AD1183',1,'AD1183',92.99,'aliexpress','1007420400','eiriksl@gmail.com','Eirik Lund','Sirivegen 1','Haugesund','Rogaland','NORWAY','5516','+47 91541241',NULL,NULL,NULL,'2012-03-16 02:00:32',0,NULL,3,1,17,0,'RA184591072CN  ',NULL),(26091,858097478002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','98ways','kemwest@yahoo.com','Kem West','11660 Goleta St','Sylmar','CA','UNITED STATES','91342-7235','(818) 470-5528','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 02:00:50',0,NULL,3,1,3,1,'RA184590678CN\r ','hermeshine'),(26092,8881331863305799,111,'Free shipping & Tracking # - Brand New DSLR Rig Shoulder Mount for DV Camera 90D D7000 5D Mark ii 7D - AD1188',1,'AD1188',72.99,'aliexpress','1007420399','eiriksl@gmail.com','Eirik Lund','Sirivegen 1','Haugesund','Rogaland','NORWAY','5516','+47 91541241',NULL,NULL,NULL,'2012-03-16 02:01:45',0,NULL,3,1,17,0,'CP236401880CN ',NULL),(26093,8881331863369664,111,'New Heavy Duty Professional Camera Video Tripod Dolly WT600 - Wholesale/ Retail [AO0027]',1,'AO0027',83.99,'aliexpress','1007420398','eiriksl@gmail.com','Eirik Lund','Sirivegen 1','Haugesund','Rogaland','NORWAY','5516','+47 91541241',NULL,NULL,NULL,'2012-03-16 02:02:49',0,NULL,3,1,5,1,'CP236401880CN\r ','速卖通\r2.4x3m背景架+ 白布   1 \rDSLR-Rig    1\rWT600  1\r'),(26094,967001533015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','seamustuberdy','nmdarcy@hotmail.co.uk','n darcy','24 letfern road<br>omagh','tyrone','Tyrone','UNITED KINGDOM','bt78 1rx','02882536372','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 02:16:19',0,NULL,3,1,3,1,'RA184590545CN\r ','hutongstore'),(26095,858108396002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','shutterbug5000','stevewhite16@live.com','STEVE WHITE','4960 E 43 Ave<br>C6','Anchorage','AK','UNITED STATES','99508','(210) 857-2400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-16 02:33:51',0,NULL,3,1,17,0,'LK234109104CN ','hermeshine'),(26096,813356066001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','shutterbug5000','stevewhite16@live.com','STEVE WHITE','4960 E 43 Ave<br>C6','Anchorage','AK','UNITED STATES','99508','(210) 857-2400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-16 02:33:52',0,NULL,3,1,17,0,'LK234109104CN ','hermeshine'),(26097,858108389002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','3903dede132','giancarlo.dos@terra.com.br','Giancarlo dos Santos Giannotta','Maria lucia Duarte, 111<br>Pirituba','São Paulo','São Paulo / Pirituba','BRAZIL','05172-000','+55  39036851','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 02:37:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(26098,813356068001,110566021571,'TianYa New Star 6 points filters for Cokin P Series',1,'AE2316',10.4,'hermeshine','shutterbug5000','stevewhite16@live.com','STEVE WHITE','4960 E 43 Ave<br>C6','Anchorage','AK','UNITED STATES','99508','(210) 857-2400','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-16 02:33:52',0,NULL,3,1,1,1,'LK234109104CN ','hermeshine\r防寒罩  1\r天涯方形滤镜系列  星光镜  star8  1\r天涯方形滤镜系列  星光镜  star6  1'),(26099,8881331866537890,111,'礼物',1,'',0,'hermeshine','segalu','lujiangang@gmail.com','Jiangang Lu','104 Maddry Ct','Chapel Hill','NC','UNITED STATES','27516-1171','',NULL,NULL,NULL,'2012-03-16 02:55:37',0,NULL,3,0,1,1,'LK045152978CN ',NULL),(26100,8881331868973785,111,'灯架包厚 ',1,'AD1128',0,'hermeshine','nagelm73','marcos.nagelstein@gmail.com','Marcos Nagelstein','Avenida Chuí nº 30, ap. 203<br>Cristal','Porto Alegre','Rio Grande do Sul','BRAZIL','90820-080','',NULL,NULL,NULL,'2012-03-16 03:36:13',0,NULL,3,1,3,1,'RA184590647CN\r ',NULL),(26101,8881331870803339,111,'红头灯网格',2,'',0,'hutongstore','ruperjm','rubenjim@gmail.com','La Fábrica de Experiencias S.L.','CIF ESB85793891<br>Castilla 44','Las Matas','Madrid','SPAIN','28290','918501136',NULL,NULL,NULL,'2012-03-16 04:06:43',0,NULL,3,0,3,1,'RA184590766CN\r ',NULL),(26102,813380391001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','studio1042012','studio104@mail.ru','ignat Drobintsev','ul.Shirotnaia 104 - 45','Tuymen','Tuymen obl','RUSSIAN FEDERATION','625051',' 89292694950','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 06:37:28',0,NULL,3,1,3,1,'RA184590783CN\r ','hermeshine'),(26103,858161739002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','mymiata389','jairomoreno389@yahoo.com','jairo moreno','706 E Springdale Ln','Grand Prairie','TX','UNITED STATES','75052-5352','(972) 815-9355','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 06:55:24',0,NULL,3,1,3,1,'RA184590770CN\r ','hermeshine'),(26104,820399359018,280805178524,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.7,'photographyacc','tianchilai','vincentkon90@gmail.com','Vincent Kon','Unilodge@Swinburne Place,711<br>24,wakefield street','hawthorn','Victoria','AUSTRALIA','3122','0450469822','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 07:43:14',0,NULL,3,1,11,1,NULL,'photographyacc'),(26105,858178786002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','baderhz','bader.alhuzaimy@gmail.com','BADER ALHUZAIMY','5170 Hudson Dr<br># 62089445 Ste I','Hudson','OH','UNITED STATES','44236-3797','','NoPaymentFailure','CheckoutComplete','Other','2012-03-16 08:23:18',0,NULL,3,0,1,0,'LK234374872CN ','hermeshine\rXL 已入库'),(26106,813424719001,110488084819,'Full Set 52mm-77mm 7 Adapter Ring+Cokin P Filter Holder',1,'AKT025',25.98,'hermeshine','studio1042012','studio104@mail.ru','ignat Drobintsev','ul.Shirotnaia 104 - 45','Tuymen','Tuymen obl','RUSSIAN FEDERATION','625051',' 89292694950','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 08:26:34',0,NULL,3,1,3,1,'RA184591452CN ','hermeshine'),(26107,946996917016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','angelmancy','angelosh@primehome.com','ANGELOS HADJIANTONI','Telemachou 1 Str','Nicosia','Kaimakli','CYPRUS','1026','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 08:37:33',0,NULL,3,1,11,1,NULL,'hutongstore'),(26108,967121226015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','jay.vg','jvg@hotmail.co.uk','J van Gellecum','1 Trusley Brook<br>Hilton','Derby','Derbyshire','UNITED KINGDOM','DE65 5LA','01283735569','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 09:46:24',0,NULL,3,1,11,1,NULL,'hutongstore'),(26109,858200660002,120618815334,'TianYa 52mm ND8 filter New 52 Neutral Density Grey NIB',1,'AA2308',5.7,'hermeshine','raihanneutralbay','neutral_space@yahoo.com','Raihan Chowdhury','22 Sixth Avenue','Campsie','New South Wales','AUSTRALIA','2194','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 09:53:13',0,NULL,3,1,11,1,NULL,'hermeshine'),(26110,947038360016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','picopooki','claire@spotlessmedia.com','Claire Batten','21 St Margarets Road<br>PLympton','Plymouth','Devon','UNITED KINGDOM','PL7 4RZ','07584044388','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-16 10:48:25',0,NULL,3,1,4,1,'YW870147382CN\r ','hutongstore\r英标\r3.22客户要换地址\r16 Litchaton Way Plympton Plymouth PL7 4RD '),(26111,858224208002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',4,'AKT055',252,'hermeshine','alexmarghi','almarghi@gmail.com','Alexandru Marghitan','Elena Caragiani 27 bl.12E ap.8','Bucharest','sect1','ROMANIA','014214','+40721828877','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:22:09',0,NULL,3,1,5,1,'CP236402355CN\r ','hermeshine'),(26112,813473676001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','sunfields2005','john.clare.uk@gmail.com','John Clare','Sunfields, Mill Farm<br>Riby Road','Stallingborough','Lincolnshire','UNITED KINGDOM','DN41 8BU','01469560663','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 11:39:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(26113,813479431001,110724664256,'New High quality heavy duty sand bag Shipped Empty',2,'AD1168',30,'hermeshine','hanserpanser','hansbakken@live.no','Hans-Even Bakken','prost Hallings vei 16','Oslo','Oslo','NORWAY','0666','+4746675578','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:59:49',0,NULL,3,1,11,1,NULL,'hermeshine'),(26114,858240040002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','frenkelamir','amir.frenkel@gmail.com','Amir Frenkel','5/6 Mivtza Danny st.','Rosh Haaiyn','','ISRAEL','48057','+972-54-4902527','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-16 12:17:36',0,NULL,5,0,18,0,NULL,'hermeshine'),(26115,858229664002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',65.98,'hermeshine','najort-perm','alexandr.abramenkov@gmail.com','Alexandr Abramenkov','M. Gorkogo str, 64/1-145','Perm','Permskiy Kray','RUSSIAN FEDERATION','614007','89519361012','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 11:44:48',0,NULL,3,1,3,1,'RA184591333CN ','hermeshine'),(26116,967201149015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','latin_javi1982','latin_javi82@hotmail.com','Francisco Javier  Domínguez García','Plaza Bornos Bloque 1, 2ºD','Jerez de la Frontera','Andalucía Ceuta y Melilla','SPAIN','11405','670753034','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 13:22:12',0,NULL,3,1,3,1,'RA184590908CN ','hutongstore'),(26117,858261089002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','magua1985','magu_@mail.ru','Ivanov Andrei','Pobedi street, 23-18','Seversk','Tomsk region','RUSSIAN FEDERATION','636013','8-923-428-7093','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 13:25:07',0,NULL,3,1,3,1,'RA184591015CN ','hermeshine'),(26118,819285165018,280777504738,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',31.34,'photographyacc','gotty_got','gauthier.havet@gmail.com','gauthier havet','02 rue de l\'infirmerie','Cassel','Nord-Pas-de-Calais','FRANCE','59670','0618484504','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 13:34:40',0,NULL,3,1,3,1,'RA184591174CN\r ','photographyacc'),(26119,858284061002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','cristianosoy','henryromero@cristianosoy.com','Henry Romero','1733 N.W. 79 Av. CPS 8990','Miami','FL','UNITED STATES','33126','(809) 729-2785','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-16 14:31:32',0,NULL,3,1,3,1,'RA184591347CN ','hermeshine'),(26120,967238106015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','geddeholm','michael.stendahl@fibo.varnamo.net','Michael Stendahl','Valdemarsgatan 8','Värnamo','','SWEDEN','33140','+46 (0)73 995 1687','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-16 14:48:06',0,NULL,3,1,3,1,'RA184591214CN\r ','hutongstore'),(26121,811063263001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','kristiskd86','kristinedownie@yahoo.com','kristina Downie','929 con.4walpole','jarvis','ON','CANADA','n0a1j0','(519) 587-5434','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 15:18:34',0,NULL,3,0,11,1,NULL,'hermeshine\r黑色'),(26122,881604642017,270750130487,'TianYa Circular Polarizing CPL filter 4 Cokin P Series',2,'AA2326',30.02,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 16:27:18',0,NULL,3,1,17,0,'RA184591188CN  ','photographyacc'),(26123,820562098018,280678260761,'TianYa Star 6 points  cross filter for Cokin P Series',2,'AE2316',24.52,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 16:27:20',0,NULL,3,1,17,0,'RA184591188CN  ','photographyacc'),(26124,881604418017,270750130191,'TianYa Star 8 points  cross filter for Cokin P Series',2,'AE2317',24.52,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 16:27:20',0,NULL,3,1,17,0,'RA184591188CN  ','photographyacc'),(26125,820561845018,280670224809,'New wide angle holder 1 slot for Cokin P series filter',5,'AA2216',23.75,'photographyacc','fa636739','fa636739@skynet.be','LAMY ALAIN','rue des Malheurs 18','HERON','','BELGIUM','4217','0479700743','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 16:27:21',0,NULL,3,1,3,1,'RA184591188CN ','photographyacc\r天涯方形滤镜系列  CPL    2\r方镜广角托架（ 一槽）      5\r天涯方形滤镜系列  星光镜  star6    2\r天涯方形滤镜系列  星光镜  star8    2\r\r\r'),(26126,858329404002,120632314062,'NEW Reflector Panel Backdrop Arm Grip Holder and Stand',1,'AKT056',54,'hermeshine','iveta-mihaljevic','jos.jedan.jan.iveta@gmail.com','Jan Iveta','Baruna Trenka 7','Zagreb','Grad Zagreb','CROATIA','10000','00385914621142','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 16:35:41',0,NULL,3,1,3,1,'RA184590987CN  ','hermeshine'),(26127,813585836001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','709jenniferjennifer','jennifer2645@hotmail.com','marie barnes','church road p.o.box 1268','bell island','NL','CANADA','A0A4H0','(709) 488-2079','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 17:14:11',0,NULL,3,1,11,1,NULL,'hermeshine\r黑色'),(26128,858347567002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','allboyssebastian','sebastianchiaradia@hotmail.com','sebastian chiaradia','marcos sastre 5012','CABA','Buenos Aires','ARGENTINA','1417','541146396260','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 17:18:23',0,NULL,3,1,11,1,NULL,'hermeshine\r'),(26129,813602538001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','carsparepartscs-us','carsparepartscs@gmail.com','Viktoria Pakaliavina','Surganova 3 - 27','Minsk','BY','BELARUS','220012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 17:52:55',0,NULL,3,1,17,0,'RA184590871CN  ','hermeshine'),(26130,858362715002,120500417644,'67mm CPL Circular Polarizing Filter 67 CPL Green.L ',1,'AA3312',6.5,'hermeshine','carsparepartscs-us','carsparepartscs@gmail.com','Viktoria Pakaliavina','Surganova 3 - 27','Minsk','BY','BELARUS','220012','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 17:52:57',0,NULL,3,1,3,1,'RA184590871CN ','hermeshine\r150-200cm 5in1 反光板     1\r绿叶 CPL  67mm    1'),(26131,947254667016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','christophe.anagno','christophe_anagno@yahoo.gr','Thanasis Kefalas','21, 25th Martiou street','Vyronas','','GREECE','16233','00306976658423','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 18:47:46',0,NULL,3,1,11,1,NULL,'hutongstore'),(26132,967379146015,250600492879,'Twin Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1301',9.9,'hutongstore','ealpozo','apozomar@gmail.com','Antonio Luis Pozo Marín','Avd José Antonio, 16','Tíjola (Almería)','Andalucía Ceuta y Melilla','SPAIN','04880','649971655','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 19:06:50',0,NULL,3,1,11,1,NULL,'hutongstore\r欧标'),(26133,858403085002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',1,'AE2202',26.99,'hermeshine','davidrw49','davidrw4911@yahoo.com','David Williams','8851 N Congress Ave<br>Apt 417','Kansas City','MO','UNITED STATES','64153-1883','(816) 225-3705','NoPaymentFailure','CheckoutComplete','Other','2012-03-16 19:17:17',0,NULL,3,1,3,1,'RA184591395CN\r ','hermeshine'),(26134,967413244015,250599969006,'New Heavy Duty Professional Camera Video Tripod Dolly',1,'AO0027',45,'hutongstore','retardedastronaut','joao.azlo@gmail.com','Joao Lourenco','Avenida António Coelho Moreira 391<br>Valadares, Vila Nova de Gaia','Porto','','PORTUGAL','4405-528','912477746','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-16 19:56:47',0,NULL,3,1,4,1,'YW870147312CN\r ','hutongstore'),(26135,858408340002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',2,'AC2402',41.5,'hermeshine','horriblegoat','tuomas.tuomala@pp.inet.fi','Tuomas Tuomala','Tanhuankatu 27 as 10','Tampere','','FINLAND','33560','+358405688364','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 19:28:05',0,NULL,3,1,3,1,'RA184591157CN ','hermeshine'),(26136,813674762001,110451008509,'58mm 58  Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1303',3.34,'hermeshine','blindcorsa','meister-mischa@gmx.de','Mischa Jäger','Am Wingertsberg 28','Kaiserslautern','','GERMANY','67659','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 20:17:55',0,NULL,3,1,11,1,NULL,'hermeshine'),(26137,967433953015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','vyroy','jorge_411@msn.com','Jorge Tortosa Gassó','C/Molí 54','La Font de la Figuera','Comunidad Valenciana','SPAIN','46630','660760419','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 20:30:20',0,NULL,3,1,3,1,'RA184591038CN \r','hutongstore'),(26138,820708771018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','bysquashy','damienleongby@gmail.com','Damien Leong','Level 6, Tower B, 799 Pacific Highway','Chatswood','New South Wales','AUSTRALIA','2067','0401141561','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-16 21:10:55',0,NULL,3,1,11,1,NULL,'photographyacc'),(26139,967461821015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','cajaibamarcos','cajaiba.marcos@gmail.com','Marcos Luis Cajaiba Do Prado','Av São João 822 Apt 103<br>Republica','São Paulo','SÃO PAULO','BRAZIL','01036-100','055-11-25523339','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-16 21:13:00',0,NULL,3,1,3,1,'RA184590899CN','hutongstore'),(26140,967465333015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','wne1978','walidnazih@hotmail.com','walid el sayed','12 Dao court<br>Dacre road','london','London','UNITED KINGDOM','e13 0pg','02084713995','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 21:17:15',0,NULL,3,1,3,1,'RA184591165CN ','hutongstore'),(26141,813703069001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',35.99,'hermeshine','jcarrio','julio.carrio@gmail.com','Julio Carrio','Av.Oswaldo Cruz, 90/711<br>Flamengo','Rio de Janeiro','RJ','BRAZIL','22250060','+55 21 8877-0029','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 21:17:26',0,NULL,3,1,3,1,'RA184590939CN ','hermeshine'),(26142,812834309001,110571985851,'Pro Photo Studio Lighting system Kit ',1,'AKT009',90,'hermeshine','aniapunx','blonde@buziaczek.pl','Anna Kmiecik','39 Rosan Glas<br>Rahoon','Galway','Galway','IRELAND','353','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-16 21:45:18',0,NULL,3,1,4,1,'YW870147301CN\r ','hermeshine\rc以外再发：\r115w 5500k 灯泡  220v   2'),(26143,858485426002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','aniapunx','blonde@buziaczek.pl','Anna Kmiecik','39 Rosan Glas<br>Rahoon','Galway','Galway','IRELAND','353','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-16 22:07:40',0,NULL,3,1,17,0,'YW870147301CN ','hermeshine'),(26144,855018745002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','bmsena','bmsena@yahoo.com.br','Bruno Sena','Rua Bambui 1165/301<br>Anchieta','Belo Horizonte','MG','BRAZIL','30310320','(554) 184-9917 ext.: 24','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 22:49:14',0,NULL,3,1,3,1,'RA184590925CN\r ','hermeshine'),(26145,967533096015,250851134597,'Collapsible 4.6.x6.4ft backdrop background green/blue',1,'AC3304',35.8,'hutongstore','gizmogadgetfanboy','sales@sublime-products.com','Amin Motin','10 Buckthorne Court','Wakefield','West Yorkshire','UNITED KINGDOM','WF3 2DD','01924871995','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-16 23:33:50',0,NULL,3,1,3,1,'RA184590911CN ','hutongstore'),(26146,813758204001,110502914189,'New 52mm ring adapter replacement for cokin P series',1,'AA2208',2.18,'hermeshine','janjerabek','honza.jerabek@email.cz','Jan Jerabek','ulice Horni 153','Haj ve Slezsku - Lhota','MORAVSKOSLEZSKY KRAJ','CZECH REPUBLIC','74792','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-16 23:45:47',0,NULL,3,1,11,1,NULL,'hermeshine'),(26147,820776619018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',94.05,'photographyacc','htareh','leeherath@yahoo.com','Lee Herath','1510/180<br>City Road','Southbank','Victoria','AUSTRALIA','3006','0419264888','NoPaymentFailure','CheckoutComplete','AU_ExpeditedDeliveryFromOutsideAU','2012-03-17 00:05:59',0,NULL,3,1,4,1,'YW870147323CN\r ','photographyacc'),(26148,813785272001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','babin247','babinart@yahoo.com','John Babin','10135 E Park Ave','Houma','LA','UNITED STATES','70363-3886','(985) 852-2040','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-17 01:26:32',0,NULL,3,1,3,1,'RA184591072CN ','hermeshine'),(26149,820801307018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',4.83,'photographyacc','tcampbell25','tessa.campbell1@det.nsw.edu.au','Tessa Campbell','3/59 Mildura St','Coffs Harbour','New South Wales','AUSTRALIA','2450','0403741365','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 01:31:49',0,NULL,3,1,11,1,NULL,'photographyacc'),(26150,947462580016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','susanc4659','rscurwood@hotmail.com','susan curwood','44 arena pde','officer','Victoria','AUSTRALIA','3809','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-17 01:41:12',0,NULL,3,1,3,1,'RA184590995CN ','hutongstore'),(26151,813807065001,110807100307,'Promotion!NEW  Square Graduated Gray ND2 Plexiglass Filter for Cokin P Series',1,'AD1218',3.5,'hermeshine','gregman420','gregpphoto@yahoo.com','gregory petliski','907 Woodbridge Commons Way','Iselin','NJ','UNITED STATES','08830-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 02:52:28',0,NULL,8,1,17,0,NULL,'hermeshine'),(26152,858575372002,120581548456,'115w x 2 Daylight bulb for Photography 5500K Light Bulb',1,'AKT049',30,'hermeshine','$1mp1','tilakaweera@yahoo.com.au','T W','PO Box 2181','Homebush West','New South Wales','AUSTRALIA','2140','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-17 03:15:36',0,NULL,3,1,3,1,'RA184591280CN ','hermeshine'),(26153,638286736004,140679559778,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.5,'hermeshine','gregman420','gregpphoto@yahoo.com','gregory petliski','907 Woodbridge Commons Way','Iselin','NJ','UNITED STATES','08830-3026','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 03:12:48',0,NULL,3,1,1,1,'LK235831857CN ','hermeshine\r无牌方镜 渐变灰 （nd2）    1\r无牌方镜 渐变灰 （nd4）   1'),(26154,967669170015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','antonisg123','xesemesa666@hotmail.com','Antonios Georgiou','P. Karolidou 30 Flat A52','Kaimakli','NICOSIA','CYPRUS','1020','0035799655586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 07:46:40',0,NULL,3,1,11,1,NULL,'hutongstore'),(26155,967677513015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','redlub','kbmanden@yahoo.dk','kjeld jensen','bispevangen 2','ballerup','','DENMARK','2750','+4550238682','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 08:16:12',0,NULL,3,1,11,1,NULL,'hutongstore'),(26156,858632735002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','kasakin11','kassakinm@gmail.com','Kasakin Marat','Truzhenikov street, d 9, kv 144','Novosibirsk','Novosibirskaya oblast\'','RUSSIAN FEDERATION','630058','89231196317','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 08:24:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(26157,820890957018,280674125220,'New Neoprene Neck Shoulder Strap for Sony SLR camera',1,'AB1406',4.83,'photographyacc','raycpt','rayt@y7mail.com','Raymond Theuma','17 Willunga Place','West Pennant Hills','New South Wales','AUSTRALIA','2125','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 08:34:47',0,NULL,3,1,11,1,NULL,'photographyacc'),(26158,820891296018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',33.25,'photographyacc','jsheenam','heenamkim@bigpond.com','Heenam Kim','61 Bestmann Road, East','Sandstone Point,','Queensland','AUSTRALIA','4511','0414934972','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 08:42:52',0,NULL,3,1,3,1,'RA184590868CN ','photographyacc'),(26159,813887846001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','caramba32130','laurent.veysset@wanadoo.fr','LaurentN VEYSSET','Soulès','SAMATA','Midi-Pyrénées','FRANCE','32130','0623682127','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 09:40:51',0,NULL,3,1,4,1,'YW870147371CN\r ','hermeshine'),(26160,813894279001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','vladimir_liquid','610727@mail.ru','Vladimir Kryshtalev','ul. Bystrinskaya 20/2 kv.1','Surgut','Khanty-Mansiyskiy avtonomniy okrug','RUSSIAN FEDERATION','628406','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 10:03:05',0,NULL,3,1,3,1,'RA184591024CN ','hermeshine'),(26161,858666776002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','hystericmint','viseu.c@gmail.com','Cristina Viseu','2735 Lake St','San Francisco','CA','UNITED STATES','94121-1047','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 10:35:45',0,NULL,3,1,3,1,'RA184591109CN ','hermeshine'),(26162,967734659015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',37.89,'hutongstore','vitaliy.sobolevskiy','sobolevskiy@gmail.com','Vitaliy Sobolevskiy','okruzhna, 38 ap 14','Lviv','','UKRAINE','79041','+380673533405','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 11:06:43',0,NULL,3,1,3,1,'RA184591143CN ','hutongstore\r转欧标头（大的）'),(26163,858682518002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','paulolagoaseca2010','paulolagoaseca@hotmail.com','paulo sergio muniz de lima','Rua João Francisco de Oliveira, 233<br>Rua  Edmundo Jerônimo do Nascimento, 109','Lagoa Seca','paraiba','BRAZIL','58117-000','83 3366-2074','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 11:30:15',0,NULL,3,1,5,1,'CP236402386CN\r ','hermeshine'),(26164,858684290002,120753012046,'Brand New Official Original Nikon Photo Vest for D300 D90 D700 D80 Size M ',1,'AD1159',42,'hermeshine','marisete10','marisetemuniz2010@hotmail.com','marisete muniz de lima','Rua João Francisco de Oliveira, 233<br>centro','Lagoa Seca','Paraíba','BRAZIL','58117-000','83 33661044','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-17 11:36:18',0,NULL,3,0,3,1,'RA184595729CN\r ','hermeshine\rL  已入库'),(26165,813925700001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','harleeandben','lil_perrin_91@hotmail.com','harlee perrin','19 diorite street','greenbushes','Western Australia','AUSTRALIA','6254','0400543803','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 11:51:35',0,NULL,3,0,11,1,NULL,'hermeshine\r黑色'),(26166,882023676017,270794124972,'Big Travel Bag for Photo Equipment w Padded Dividers',1,'AD1164',47.5,'photographyacc','broadproductions-store','jeremy@broadproductions.com.au','Jeremy I Broad','120 Dugandan St','Nerang','Queensland','AUSTRALIA','4211','0414522274','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 12:23:21',0,NULL,3,1,3,1,'RA184590810CN','photographyacc'),(26212,859301220002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','arthur15015','luis_arthur_15@yahoo.com.br','Luis Arthur Bitencourt','Rua Jose Bonifacio 1320','Sao Leopoldo','RS','BRAZIL','93010-180',' 555192114089','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 14:52:12',0,NULL,3,1,5,1,'CP236402372CN\r ','hermeshine'),(26167,813716006001,110733724232,'New quality Universal wheel Light Stand Grip Clamp',1,'AD1180',13.9,'hermeshine','oniksphoto','ebay@oniksseo.ru','Vladislav Patsevich','Verhnyaya hohlovka str., house 17, flat 59','Moscow','','RUSSIAN FEDERATION','109052','(916) 063-7923','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 12:50:25',0,NULL,3,1,11,1,NULL,'hermeshine'),(26168,813955346001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','mikenadershehadeh','mike.shehadeh@gmail.com','Mike Nader Shehadeh','Shnaler','Nazareth','','ISRAEL','P.O.B 6534','054-4640054','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 13:23:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(26169,813969294001,110489671829,'NEW 67mm Snap-on Front Lens Cap for Nikon 67 Lenscap',1,'AA1307',2.6,'hermeshine','theprofessional81','leon.ponjee@gmail.com','Leon Ponjee','Atalanta 15','Someren','','NETHERLANDS','5711 NH','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 14:00:56',0,NULL,3,1,11,1,NULL,'hermeshine'),(26170,858749729002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',1,'AA1301',2.6,'hermeshine','wefocus','imagemaker@riversidestudio.com','Riverside Studio Photography','7 Riverside Ln','Ellsworth','ME','UNITED STATES','04605-2616','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 14:44:44',0,NULL,3,1,1,1,'LK235810786CN ','hermeshine'),(26171,858748386002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','ural_photo','faketruth@yandex.ru','Azat Akhyarov','Postbox 85','Tuimazy','Bashkortostan','RUSSIAN FEDERATION','452754','+7 917 4965443','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-17 14:54:20',0,NULL,3,1,3,1,'RA184591112CN ','hermeshine\r澳转欧标'),(26172,967836367015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','folooop','foolop@gmail.com','Monika  bejtner','Carrero Juan Ramon 10 ,4b','madrid','Madrid','SPAIN','28025','603253654','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 14:58:31',0,NULL,3,1,3,1,'RA184591228CN ','hutongstore'),(26173,858764740002,120813021178,'New 24\"x35\"/60x90cm Softbox Universal Mount Metal for strobe 2  layer diffuser',1,'AD1140',39.9,'hermeshine','jonikk83lev','jennifer180883@gmail.com','EVGENYA MEDVEDEVA','Строителей , д17, кв 154','Ярославль','Ярославский','RUSSIAN FEDERATION','150064','9051330571','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-17 15:22:31',0,NULL,3,1,3,1,'RA184591041CN ','hermeshine'),(26174,967855275015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','jonathan849','pro.urena@gmail.com','Jonathan ureña','8532 NW 66th St.<br>AP-018075','Miami','FL','UNITED STATES','33166','829 845 1283','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 15:36:16',0,NULL,3,1,3,1,'RA184591007CN ','hutongstore'),(26175,967927221015,250600471643,'18% Gray card set 10x8\" 8x6\" for White balance exposure',1,'AA2218',7.48,'hutongstore','pavantt','pahan@e1.ru','Antropov Pavel Alekseevich','Sibirskaya d-3, kv-44','Kogalym HMAO','RUSSIAN FEDERATION','RUSSIAN FEDERATION','628485','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 17:36:03',0,NULL,3,1,11,1,NULL,'hutongstore'),(26176,858876289002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','withd70','ishoot4u@hotmail.com','Denise Whithorne','5416 W 65th Pl','Mission','KS','UNITED STATES','66202-4305','(913) 432-1090','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 19:06:26',0,NULL,3,1,3,1,'RA184590942CN ','hermeshine'),(26177,814113237001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',2,'AA1305',5.2,'hermeshine','svrcek','crsvrcek@sbcglobal.net','Charles Svrcek','3550 Hillcrest Dr<br>Apt 224','Waco','TX','UNITED STATES','76708','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 19:12:36',0,NULL,3,1,1,1,'LK235797988CN ','hermeshine'),(26178,947919490016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',3.6,'hutongstore','xasito','rodolaina@gmail.com','XAVIER SINFREU TORRES','CTRA.VILARS,XALET SINFREU','ESCALDES-ENGORDANY','ANDORRA','ANDORRA','AD700','376.323962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 20:17:49',0,NULL,3,1,17,0,'RA184595689CN ','hutongstore'),(26179,947911067016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','xasito','rodolaina@gmail.com','XAVIER SINFREU TORRES','CTRA.VILARS,XALET SINFREU','ESCALDES-ENGORDANY','ANDORRA','ANDORRA','AD700','376.323962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 20:17:50',0,NULL,3,0,17,0,'RA184595689CN ','hutongstore'),(26180,968023784015,250599965679,'Aluminium Ultra Lightweight 67\" Camera Monopod with cas',1,'AE1602',15,'hutongstore','xasito','rodolaina@gmail.com','XAVIER SINFREU TORRES','CTRA.VILARS,XALET SINFREU','ESCALDES-ENGORDANY','ANDORRA','ANDORRA','AD700','376.323962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 20:17:50',0,NULL,3,1,17,0,'RA184595689CN ','hutongstore'),(26181,947909142016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',5.5,'hutongstore','xasito','rodolaina@gmail.com','XAVIER SINFREU TORRES','CTRA.VILARS,XALET SINFREU','ESCALDES-ENGORDANY','ANDORRA','ANDORRA','AD700','376.323962','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 20:17:51',0,NULL,3,1,3,1,'RA184595689CN\r ','hutongstore\r麂皮  3\r摄影背心 黑色厚 无字  3XL  1\r独脚架  伟峰 WT-1003   1\r大号内胆包 无字  1\r已入库\r没有3ＸＬ的　　发的是２XL的  \r但是把标签剪掉了\r'),(26182,968052052015,250932121983,'16\" Photo Softbox Table Top Light Lighting Cube Kit',1,'AKT091',52,'hutongstore','ledon_racing_services','npodell81@hotmail.com','Nathan Odell','RLR Msport, Unit 2<br>Hall Moss Bus. Park, Bolton Road','DARWEN','Lancashire','UNITED KINGDOM','BB3 2TT','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 20:37:12',0,NULL,3,1,4,1,'YW870147360CN\r ','hutongstore\r英标'),(26183,968092271015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dkin8240','daisy_king@hotmail.co.uk','Daisy King','8 Ottway Walk<br>Welwyn','Hertfordshire','Herefordshire','UNITED KINGDOM','AL69AS','01438840152','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 21:41:39',0,NULL,3,1,3,1,'RA184591259CN ','hutongstore'),(26184,968096032015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','iorox10','io_tz@yahoo.gr','Roxani Konstantinidou','Aristotelous 28A','Thessaloniki','Macedonia','GREECE','55133','(2310) 448586','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-17 21:47:22',0,NULL,3,1,3,1,'RA184591302CN ','hutongstore'),(26185,858970448002,120813021502,'New Studio 1000W Continuous Lighting kit with 3x6m backdrop and support system G',1,'AKT063',214,'hermeshine','reelcrankyboruch','boruchlen@gmail.com','Bruce Len','Rechov Migdal 43','Katzrin','','ISRAEL','12900','(786) 338-9188','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 22:04:30',0,NULL,3,1,6,1,'EE667839141CN','hermeshine\r除了C以外还有\r倒影板（白黑） 1\r摄影背心 Canon  XL   1\r11kg\r15kg\r已经发了账单了，已付运费\r新地址：\rBruce Len\rRechov Hatzivonim 3\rKatzrin, Israel\r12900\r'),(26186,814201785001,110556868876,'Black/Whilte Reflection board 20X30cm Reflection effect',1,'AB1201',17,'hermeshine','reelcrankyboruch','boruchlen@gmail.com','Bruce Len','Rechov Migdal 43','Katzrin','','ISRAEL','12900','(786) 338-9188','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-17 22:04:31',0,NULL,3,1,17,0,'EE667839141CN\r','hermeshine\r'),(26187,858970447002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','reelcrankyboruch','boruchlen@gmail.com','Bruce Len','Rechov Migdal 43','Katzrin','','ISRAEL','12900','(786) 338-9188','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-17 22:04:30',0,NULL,3,0,17,0,'EE667839141CN','hermeshine'),(26188,882349090017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.65,'photographyacc','petej4130','petejaquesphoto@gmail.com','Pete Jaques','2 BANNERFIELD DRIVE','TOOWOOMBA','Queensland','AUSTRALIA','4350','0746135710','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-17 23:05:15',0,NULL,3,1,11,1,NULL,'photographyacc'),(26189,948014800016,260646700576,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',49.99,'hutongstore','manjarina123','idelamata@gmail.com','Inmaculada González de la Mata','Miguel de Unamuno 6, 2º P','Gijón','Asturias','SPAIN','33211','618832211','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-17 23:07:16',0,NULL,3,1,4,1,'YW870147356CN\r ','hutongstore'),(26190,858994807002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','pvir3180','pvirdi@gmail.com','Prem Virdi','16 Velie Dr','Moline','IL','UNITED STATES','61265-6120','(309) 912-4402','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-17 23:10:30',0,NULL,3,1,1,1,'LK235796165CN ','hermeshine'),(26191,968151155015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','jenny1846','jcheasman@hamptonbrook.com','J Cheasman','Towerfield<br>66 Derngate','Northampton','Northants','UNITED KINGDOM','NN1 1UH','07813841810','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-17 23:37:44',0,NULL,3,1,3,1,'RA184591435CN ','hutongstore'),(26192,968161999015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','electrostar_man','ebayshop72@googlemail.com','Michael Doughty','141 Hereson Rd','Ramsgate','Kent','UNITED KINGDOM','CT11 7EG','01843584127','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 00:05:56',0,NULL,3,1,11,1,NULL,'hutongstore'),(26193,821314877018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',28.49,'photographyacc','sos.bg','sos.bg.soft@gmail.com','Anton Ivanov','Trakia<br>Teofan Rainov 3','Plovdiv','Plovdiv','BULGARIA','4023','+359886446226','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 01:29:25',0,NULL,3,0,3,1,'RA184591262CN ','photographyacc\r3XL 已入库'),(26194,968196892015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','yvonnecarebear','paulandyvonne@aol.com','yvonne donaghy','30 drumceatt park','limavady','Londonderry','UNITED KINGDOM','BT499HE','02877762916','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 02:08:30',0,NULL,3,0,11,1,NULL,'hutongstore\r1.6*2.1  黑色'),(26195,882463309017,270855429482,'Background Support & 3m x 6m Green Screen with 800w Continuous  Lighting  Kit',1,'AKT037',190,'photographyacc','pari3a','biazar@optusnet.com.au','Parisa biazar','707/34 Alison Road','randwick','New South Wales','AUSTRALIA','2031','0413181944','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-18 05:55:26',0,NULL,3,1,4,1,'YW870147345CN\r ','photographyacc\r澳标'),(26196,859122512002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','carlos3bkrew','amhi2003@aol.com','carlos david castañeda castro','Ezequiel Chavez 45','Naucalpan','Estado de México','MEXICO','53100','(011) 5255-53730431','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 07:56:12',0,NULL,3,1,3,1,'RA184591069CN ','hermeshine'),(26197,821435709018,280739905769,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',33.24,'photographyacc','william44290','william.rosenthal@yahoo.fr','William Rosenthal','9 rue henry fournis','Guémené penfao','Pays de la Loire','FRANCE','44290','0240792863','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 09:40:00',0,NULL,3,1,3,1,'RA184591245CN ','photographyacc'),(26198,968338859015,251017296011,'2 Umbrellas- 2m Light Stand- Flash/Umbrella mount bracket 4 Portable Speedlight',1,'AKT100',32,'hutongstore','kimemma','anthony.elvy@sky.com','anthony elvy','39, Eridge gardens','crowborough','East Sussex','UNITED KINGDOM','tn6 2tb','07903529092','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 09:40:15',0,NULL,3,1,3,1,'RA184591276CN ','hutongstore'),(26199,968343458015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','mikegml','mike.lear@hotmail.co.uk','Mr M. Lear','296 St Albans Road','Watford','Hertfordshire','UNITED KINGDOM','WD24 6PE','01923233332','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 09:49:58',0,NULL,3,1,11,1,NULL,'hutongstore'),(26200,859162450002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','minavain','seppo.steen@dnainternet.net','Seppo Steen','Männistöntie 8 D 60','Pori','Satakunta','FINLAND','28120','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-18 09:56:12',0,NULL,3,0,3,1,'RA184591320CN ','hermeshine\r3XL  已入库'),(26201,859170777002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','rightwine7','rightwine@gmail.com','Ketut Adhi Apriana','Perumahan Puri Chandra Asri Blok G No.11<br>Batubulan-sukawati','Gianyar','BALI','INDONESIA','80582','6283119914285','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 10:25:00',0,NULL,3,1,3,1,'RA184591404CN\r ','hermeshine'),(26202,814404266001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','adrob1350','river@maltanet.net','Joseph Borda','\'Adrob\'<br>160 F. Buhagiar Str.','Birkirkara','Malta, Europe','MALTA','BKR 1157','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 10:27:36',0,NULL,3,1,11,1,NULL,'hermeshine'),(26203,859183582002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','jabibieh2','jabibieh@euskalnet.net','Fco. Javier Blanco Rodriguez','Estrada de Salcedillo,2  2º Izda','Trapagaran (Bizkaia)','País Vasco','SPAIN','48510','653015964','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 10:49:11',0,NULL,3,1,17,0,NULL,'hermeshine'),(26204,859183297002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','jabibieh2','jabibieh@euskalnet.net','Fco. Javier Blanco Rodriguez','Estrada de Salcedillo,2  2º Izda','Trapagaran (Bizkaia)','País Vasco','SPAIN','48510','653015964','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 10:49:12',0,NULL,3,1,11,1,' ','hermeshine\r方形滤镜接口环 77mm  2\r\r'),(26205,859187149002,120443003976,'New Graduated Gray Filter for Cokin P Series Tian Ya',1,'AA2322',7.2,'hermeshine','frostyweb','tony@frostyweb.co.uk','Anthony Frost','24 Lower Green Lane<br>Astley','Manchester','Gtr Manchester','UNITED KINGDOM','M29 7JE','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 10:55:22',0,NULL,3,1,11,1,NULL,'hermeshine'),(26206,821483700018,280670190865,'Green.L Premium Quality 72mm CPL Circular Polarizer New',1,'AA3313',6.84,'photographyacc','ggjone','graham.g.jones@gmail.com','Graham Jones','19 Blyde Street','Sinnamon Park','Queensland','AUSTRALIA','4073','0419721640','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 11:28:57',0,NULL,3,1,11,1,NULL,'photographyacc'),(26207,968408756015,250692238359,'New 77mm 77 Ring adapter and Holder for Cokin P Series',1,'AKT024',3.12,'hutongstore','tolpuddlemartyrs','norbut01@hotmail.com','Norman Butler','8 Thornlea Lodge, 24 Edge Lane<br>Chorlton','Manchester','Greater Manchester','UNITED KINGDOM','m21 9jf','01618620297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 11:52:26',0,NULL,3,1,17,0,NULL,'hutongstore'),(26208,968408755015,250599920440,'New 77mm Ring adapter for Cokin P Series Filter Holder',1,'AA2214',1.6,'hutongstore','tolpuddlemartyrs','norbut01@hotmail.com','Norman Butler','8 Thornlea Lodge, 24 Edge Lane<br>Chorlton','Manchester','Greater Manchester','UNITED KINGDOM','m21 9jf','01618620297','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 11:52:25',0,NULL,3,1,11,1,NULL,'hutongstore\r方形滤镜接口环 77mm  2\r方镜普通托架（三槽）  1'),(26209,821528676018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',5,'AA1312',6.8,'photographyacc','cyberdeveil','caolaurence@hotmail.com','zhen','14 baden powell drive','tarneit','Victoria','AUSTRALIA','3029','0422897774','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 13:04:07',0,NULL,3,1,3,1,'RA184591090CN\r ','photographyacc'),(26210,882628845017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.4,'photographyacc','anggaharimurti','angga.harimurti@yahoo.com','angga harimurti','PT Multimedia Nusantara The East Building 37 Floor Mega Kuningan Jakarta 12950','Jakarta','DKI Jakarta','INDONESIA','12950','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 13:13:30',0,NULL,3,1,11,1,NULL,'photographyacc'),(26211,8881332081047813,111,'NIKON 镜头盖 52mm',1,'',0,'hermeshine','verbatim10000','waiminwong@telus.net','Tyson Yong','8-9451 granville ave','richmond','BC','CANADA','v6y1p9','',NULL,NULL,NULL,'2012-03-18 14:30:47',0,NULL,3,1,11,1,NULL,'已入库 '),(26213,968522365015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',3.16,'hutongstore','majklem','majkl.em@gmail.com','Michal Marko','54A The Old High Street','Folkestone','Kent','UNITED KINGDOM','CT20 1RN','07871994951','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 14:57:34',0,NULL,3,1,11,1,NULL,'hutongstore'),(26214,859324998002,120651621406,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',24.8,'hermeshine','beengel','beengel@yahoo.com','Ben Engel','1018 4th ave SE','Rochester','MN','UNITED STATES','55904-5033','(507) 280-8349','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 15:32:50',0,NULL,3,1,3,1,'RA184591086CN ','hermeshine'),(26215,948454976016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','adamkertesz','adam.kertesz@yahoo.co.uk','Adam Kertesz','Flat1, 54 Old Christchurch Road','Bournemouth','Dorset','UNITED KINGDOM','BH1 1LL','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-18 16:12:34',0,NULL,3,1,4,1,'YW870147334CN\r ','hutongstore'),(26216,814576973001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','diks999','dikkks@mail.ru','Василий  Беличков','Успенского 31/3 -59','Омск','','RUSSIAN FEDERATION','644001','+79083110768','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 16:15:30',0,NULL,3,1,17,0,'CP236402409CN ','hermeshine'),(26217,859353499002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','diks999','dikkks@mail.ru','Василий  Беличков','Успенского 31/3 -59','Омск','','RUSSIAN FEDERATION','644001','+79083110768','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 16:15:31',0,NULL,3,1,5,1,'CP236402409CN\r ','hermeshine\r150-200cm 5in1 反光板   1\r反光板 100*150 40*60 5合1  1\r闪光的柔光箱   60cm   1'),(26218,859353500002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','diks999','dikkks@mail.ru','Василий  Беличков','Успенского 31/3 -59','Омск','','RUSSIAN FEDERATION','644001','+79083110768','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 16:15:32',0,NULL,3,1,17,0,'CP236402409CN ','hermeshine'),(26219,821662521018,280672075177,'NEW Photo Studio Soft Box Cube 40x40cm /16\'\' Light Tent',1,'AC2401',16.14,'photographyacc','livehappiness55','sirirattai@yahoo.com','Sirirat Mongkolpradit','88/421 Patcharaville2<br>Putthamonthon sai 4 road, Kratumlom,','Sampran,','Nakhon Prathom','THAILAND','73220','66816102189','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 16:45:48',0,NULL,3,1,11,1,NULL,'photographyacc'),(26220,968669179015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','121robbie','hkerrell@btinternet.com','helen kerrell','14 kennard terrace','crumlin','Caerphilly','UNITED KINGDOM','np11 3qf','07930454136','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-18 17:45:14',0,NULL,3,1,4,1,'YW870147404CN\r ','hutongstore\r黑加白'),(26221,814647506001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','ebft56','e.bienfait@laposte.net','eric BIENFAIT','32 rue lavoisier','ploemeur','Bretagne','FRANCE','56270','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 17:48:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(26222,859431144002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','mag42267-us','mag42267@yahoo.com','Miguel Gonzalez','3425 S 78th St','Tampa','FL','UNITED STATES','33619-6571','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 17:56:23',0,NULL,3,1,3,1,'RA184590956CN ','hermeshine'),(26223,859126960002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','vmv_martin','martin_vmv@yahoo.com','Martin Mkrtumyan','ul.Pobedy, d.38A, kv.10','Tolyatti','Samara Region','RUSSIAN FEDERATION','445009','+7(917)9669999','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 17:57:01',0,NULL,3,1,5,1,'CP236402390CN\r ','hermeshine'),(26224,882855798017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',2,'AA1301',4.76,'photographyacc','rudvput','rudvput@hetnet.nl','RJP van Putten','Zwedenburg 87','Den Haag','','NETHERLANDS','2591BB','(070) 3355517','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-18 18:22:37',0,NULL,3,1,11,1,NULL,'photographyacc'),(26225,814655326001,110724639436,'Flash Umbrella Holder Bracket Mount aluminum metal N',2,'AD1167',32,'hermeshine','rbeamon','dsmedia13@gmail.com','Rayshaun Beamon','303 Washington Rd','Murfreesboro','NC','UNITED STATES','27855-9366','(757) 354-6694','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-18 17:58:04',0,NULL,3,1,1,1,'LK235829867CN ','hermeshine'),(26226,968809697015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','tees_auctions','ebay@couriers24hr.co.uk','Andrew Hill','9 Rampside ave<br>Roseworth','Stockton on tees','Cleveland','UNITED KINGDOM','TS19 9HR','01642653671','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 19:32:08',0,NULL,3,1,11,1,NULL,'hutongstore'),(26227,859016388002,120604105951,'1600w Photo Studio Bulb Continuous Lighting Kit NEW',1,'AKT039',173,'hermeshine','andrewmitr','mitrandr@gmail.com','Andrew Mitrofanov','Starobitcevskaya str,11, 572','Moscow','RU','RUSSIAN FEDERATION','117628','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 19:38:01',0,NULL,3,1,5,1,'CP236402412CN\r ','hermeshine\r除了C以外再发\r斜臂   1\r欧标'),(26228,859016148002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',29.99,'hermeshine','andrewmitr','mitrandr@gmail.com','Andrew Mitrofanov','Starobitcevskaya str,11, 572','Moscow','RU','RUSSIAN FEDERATION','117628','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 19:38:02',0,NULL,3,1,17,0,'CP236402412CN ','hermeshine'),(26229,968846834015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',1,'AB1302',2.26,'hutongstore','ericopy','eric.lindstrom@swipnet.se','Eric Lindström','Oderup 9297','Hörby','','SWEDEN','24297','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 19:59:52',0,NULL,3,1,11,1,NULL,'hutongstore'),(26230,814849606001,110586609242,'NEW Photo Studio Reflector Holder holding Arm 0.66-1.5m',1,'AE2501',29.99,'hermeshine','nicstaveley2011','nicstaveley@gmail.com','Nic Staveley','2/37 Hepburn St<br>Freemans BAy','Auckland','Auckland','NEW ZEALAND','1011','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 21:21:46',0,NULL,3,1,3,1,'RA184591205CN\r ','hermeshine'),(26231,968908461015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 20:55:37',0,NULL,8,1,17,0,NULL,'hutongstore'),(26232,859638065002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','bookbird','grannymm@ymail.com','Melody Mallory','3960 Mid. Patton Pk. Rd.','Martinsville','IN','UNITED STATES','46151','','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-18 21:33:13',0,NULL,3,1,1,1,'LK235803391CN ','hermeshine'),(26233,968947275015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','ewel69','mrrrauuu@o2.pl','Ewelina Dobrosiewicz','58 Appleby Way','Lincoln','Lincolnshire','UNITED KINGDOM','LN6 0BU','07731393627','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 21:38:47',0,NULL,3,1,3,1,'RA184591378CN ','hutongstore'),(26234,968977052015,251017296011,'2 Umbrellas- 2m Light Stand- Flash/Umbrella mount bracket 4 Portable Speedlight',1,'AKT100',32,'hutongstore','sylwid21sylwia','sylwid21@hotmail.com','Sylwia Domagala','28(GF3) Albion Road','Edinburgh','Edinburgh (City of)','UNITED KINGDOM','EH7 5QJ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 22:18:55',0,NULL,3,1,3,1,'RA184591381CN\r ','hutongstore'),(26235,968983805015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',2,'AC3303',10.9,'hutongstore','bimantas','foto@regimantas.lt','Regimantas Zukauskas','Žirmūnų g. 1 - 25','Vilnius','','LITHUANIA','09101','(370) 61460081','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 22:32:28',0,NULL,3,1,11,1,NULL,'hutongstore'),(26236,883094423017,270753945526,'New Lambency Flash Diffuser for Canon 550EX 580EX II P4',1,'AB3312',17.1,'photographyacc','brightyellowpiglet','pennyroselewis@gmail.com','Penny Lewis','C/- Melton Community Health Centre<br>Cnr Yuille and High Street','Melton','Victoria','AUSTRALIA','3337','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-18 22:46:57',0,NULL,3,1,3,1,'RA184590960CN ','photographyacc'),(26237,948879972016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','mitch_uk','mitch_uk@email.com','Michael Payne','Flat 4, 11 Charlotte Street<br>Walworth house','Leamington Spa','Warwickshire','UNITED KINGDOM','CV31 3EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 23:16:56',0,NULL,3,1,11,0,NULL,'hutongstore'),(26238,948879924016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','mitch_uk','mitch_uk@email.com','Michael Payne','Flat 4, 11 Charlotte Street<br>Walworth house','Leamington Spa','Warwickshire','UNITED KINGDOM','CV31 3EB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 23:16:58',0,NULL,3,1,11,1,NULL,'hutongstore\r52-52mm 双阳环  1\r52-58mm 双阳环   1'),(26239,859694122002,120480575853,'72mm Rubber 3in1 Collapsible Lens Hood for Canon Nikon',1,'AB1306',3.79,'hermeshine','balenogsr0','leon.counsell@ntlworld.com','Leon Counsell','10 High Bank Gardens,Colton','Leeds','West Yorkshire','UNITED KINGDOM','LS159DD','01132647621','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-18 23:17:21',0,NULL,3,1,11,1,NULL,'hermeshine'),(26240,969012512015,250600493313,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',1,'AE1302',6.9,'hutongstore','zetra450','alcazaralfilms@yahoo.es','Rafael Alcázar González','Valtravieso, 10, 1º, C, Aravaca','MADRID','Madrid','SPAIN','28023','913574894','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-18 23:20:04',0,NULL,3,1,11,1,NULL,'hutongstore\r一转四 灯头  1\r单灯头   1\r欧标'),(26241,969015342015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','adplan00','pascalbob@gmail.com','Robert J McGee','224 Liverpool Road South','Maghull, Liverpool','Merseyside','UNITED KINGDOM','L31 7DH','07885460304','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 23:24:50',0,NULL,3,1,3,1,'RA184591126CN\r ','hutongstore'),(26242,969029259015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','charlietravers','charlie_travers@hotmail.com','Elouise Travers','14 Bingham Court<br>South Hill','St Helier','Channel Islands','UNITED KINGDOM','JE2 4UR','01534738731','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-18 23:52:21',0,NULL,3,1,11,1,NULL,'hutongstore'),(26243,883127359017,270862492371,'New Studio Lighting Kit Stands Large Carry Carrying Bag Material Oxford cloth',1,'AD1181',19,'photographyacc','blackbrentor','brentley70@hotmail.com','Brenton Lindley','24 Wunulla Street<br>Thorneside','Brisbane','Queensland','AUSTRALIA','4158','0458636127','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 00:01:46',0,NULL,3,1,11,1,NULL,'photographyacc'),(26244,859713962002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','pablo_nunez','mail@pablonunez.com','Pablo Nunez','Cnel. Bdier. Gra. Zapiola 2330 1st 9','Belgrano','CABA - Ciudad Autonoma de Buenos Aires','ARGENTINA','C1428CXJ','5411-4545-5571','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 00:08:32',0,NULL,3,1,3,1,'RA184591231CN ','hermeshine'),(26245,639112193004,140649026335,'New 100% Cotton Photo photographya Vest for Sony Nikon Canon color: kaqi',1,'AA2123',32,'hermeshine','12pilotes','lapprand@videotron.ca','Pierre Lapprand','29 rue Gabriel-Lacasse','Gatineau','QC','CANADA','J9A 1J8','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-19 00:27:29',0,NULL,3,0,3,1,'RA184591449CN ','hermeshine\r2XL 已入库'),(26246,822038742018,280676689103,'Photography Studio Reflector Disc holder Arm with Stand',1,'AKT056',52.75,'photographyacc','scully550','scully450@gmail.com','Dale Mawby','63 Crawford St<br>Mowbray','Launceston','Tasmania','AUSTRALIA','7248','0363265748','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 01:15:53',0,NULL,3,1,4,1,'YW870147393CN\r ','photographyacc'),(26247,859745695002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','kleines_fellbuendel','annerichard@gmx.de','Anne Richard','Kirchwiesenstr. 17','Roßdorf- Gundernhausen','','GERMANY','64380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 01:29:44',0,NULL,3,1,11,0,NULL,'hermeshine'),(26248,814961513001,110807100159,'Promotion ! NEW Square Gradual Graduated Orange Color Filter for Cokin P Series',1,'AD1225',3.5,'hermeshine','kleines_fellbuendel','annerichard@gmx.de','Anne Richard','Kirchwiesenstr. 17','Roßdorf- Gundernhausen','','GERMANY','64380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 01:31:20',0,NULL,3,1,11,0,NULL,'hermeshine'),(26249,8881332120696729,111,'Free shipping & Tracking # - Photo Video Light Stands Studio Photo Stand 6ft 200cm - Wholesale/ Retail AE3401',1,'AE3401',35.99,'aliexpress','1007441238','tekn.dan.eriksson@gmail.com','Dan Eriksson','Hagvagen 44','Stockholm','Upplands Vasby','SWEDEN','19440','+46 76 1453289',NULL,NULL,NULL,'2012-03-19 01:31:36',0,NULL,3,1,17,0,'YW870147426CN ',NULL),(26250,859745789002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','kleines_fellbuendel','annerichard@gmx.de','Anne Richard','Kirchwiesenstr. 17','Roßdorf- Gundernhausen','','GERMANY','64380','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 01:32:32',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变蓝   1\r无牌方镜 渐变橙    1\r无牌方镜 渐变日落   1'),(26251,8881332120800514,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',1,'AB3329',48.99,'aliexpress','1007441237','tekn.dan.eriksson@gmail.com','Dan Eriksson','Hagvagen 44','Stockholm','Upplands Vasby','SWEDEN','19440','+46 76 1453289',NULL,NULL,NULL,'2012-03-19 01:33:20',0,NULL,3,1,4,1,'YW870147426CN\r ','灯架  2m  1 \r闪光的柔光箱   60cm  1'),(26252,8881332120958128,111,'x5 Tungsten bulb 800W 220V 3200K for redhead light - Whole sale/ Retail [AKT059]',1,'AKT059',29.99,'aliexpress','1007460758',' blessingd8@gmail.com','blessing denuga','16 castle grange court clondalkin','dublin','dublin22','IRELAND','353','+00353 85 1038945',NULL,NULL,NULL,'2012-03-19 01:35:58',0,NULL,3,1,3,1,'RA184591355CN\r ','800w  220v 灯泡  5 '),(26253,814985602001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','elizavetash','shestakovaliza@gmail.com','Elizaveta Shestakova','Vyatskaya 59, flat 14','Rostov-on-Don','Rostov Region','RUSSIAN FEDERATION','344065','+79034057314','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 02:39:24',0,NULL,3,1,11,1,NULL,'hermeshine'),(26254,822071621018,280672077658,'NEW Photo Studio Soft Box Cube 60x60cm /24\'\' Light Tent',1,'AC2403',28.5,'photographyacc','micklepickle','micore770@gmail.com','Michael Orehek','Unit 15/7 Carrington Rd','Castle Hill','New South Wales','AUSTRALIA','2154','0296298656','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 02:48:09',0,NULL,3,1,3,1,'RA184591191CN\r ','photographyacc'),(26255,8881332128151214,111,'3m 横杆上的两个螺丝 ',1,'',0,'hermeshine','coreycheshire','coreycheshire@sympatico.ca','Corey M.J.P. Cheshire','5418 Valley Way','Niagara Falls','ON','CANADA','L2E1X6','(905) 371-6259',NULL,NULL,NULL,'2012-03-19 03:35:51',0,NULL,3,0,3,1,'RA184591421CN\r ',NULL),(26256,822090572018,280671650882,'New Phototography Studio Softbox Photo Boom Arm Sandbag',1,'AE3101',36.1,'photographyacc','cadbadhad','deadlydigby@bigpond.com','Lara Digby','5 Kilkenny Ct','North Rockhampton','Queensland','AUSTRALIA','4701','0749235014','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 03:51:17',0,NULL,3,1,3,1,'RA184591130CN ','photographyacc'),(26257,8881332130119810,111,'新式内胆包小号',1,'AC1305',0,'aliexpress','1006925416',' kyrf.pda@gmail.com','Igor Kyrf','Serafimy Deryabinoy street. d. 11, kv. 33','Ekaterinburg','Sverdlovsk Region','RUSSIAN FEDERATION','620102','+7 903 0793148',NULL,NULL,NULL,'2012-03-19 04:08:39',0,NULL,1,1,3,1,NULL,NULL),(26258,859801204002,120562972198,'100% Genuine Lenspen x 2 lens perfect cleaning tool ',1,'AKT051',11.5,'hermeshine','boyd3661','brelton@telus.net','Boyd Elton','6 Rodeo Way','Whitecourt','AB','CANADA','T7S 0B9','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 04:13:04',0,NULL,3,1,11,1,NULL,'hermeshine'),(26259,949007891016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','carito1992','pumaguerrero@gmail.com','Eluali Larbi','4 Lenham Av.<br>Saltdean','Brighton','East Sussex','UNITED KINGDOM','BN2 8AE','07701011636','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 04:15:10',0,NULL,3,1,11,1,NULL,'hutongstore'),(26260,969141908015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','lexusman_bern','bern_@hotmail.co.uk','Bernard Jones','61 Cedar rd','Dartford','Kent','UNITED KINGDOM','DA1 2RS','07704558212','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-19 04:15:57',0,NULL,3,1,3,1,'RA184591506CN ','hutongstore'),(26261,822092530018,280739899219,'New Heavy Universal two-wheel Light Stand Double Dual Grip Clamp Boom ',1,'AD1179',14.24,'photographyacc','eyecatching_software','eye2@dodo.com.au','peter king','po box 25','creswick','Victoria','AUSTRALIA','3363','0353458350','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 04:00:18',0,NULL,3,1,11,1,NULL,'photographyacc'),(26262,859808448002,120555973963,'Light Stand 80cm / 32\" for back light studio',1,'AE3501',22,'hermeshine','jryan06','jryan06@snet.net','John P. Ryan','172 Burke St','East Hartford','CT','UNITED STATES','06118','(860) 569-6685','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 04:48:32',0,NULL,3,1,3,1,'RA184595865CN\r ','hermeshine'),(26263,639174483004,140722305812,'2 Umbrellas 2m Light Stand  Flash/Umbrella mount bracket for Portable Speedlight',1,'AKT100',55,'hermeshine','leiramsiul','leiram.siul@hotmail.com','Luis Mariel T. Sendon','Block 4 Lot 8 South View Homes 1 Ext. 2','San Vicente','','PHILIPPINES','4023','028464179','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 04:52:21',0,NULL,3,1,3,1,'RA184591418CN ','hermeshine'),(26264,815023793001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','juxy_juice','juxy_juice@hotmail.com','Júlia Argentin','Rua Cinco de Julho, 375 Ap 1503<br>Icarai','Niteroi','RJ','BRAZIL','24220110','(552) 127-1081 ext.: 44','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 05:08:51',0,NULL,3,1,5,1,'CP236402426CN\r ','hermeshine\r欧标'),(26265,859816714002,120524521426,'Neoprene Protector Camera Cover for Canon Large  5DII ',1,'AC1304',5.99,'hermeshine','djcrystal2525','djcrystal@gmail.com','Ratirat  Boonrak','P.O. Box 4','Muang','Buriram','THAILAND','31000','0833774944','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 05:36:48',0,NULL,3,1,11,1,NULL,'hermeshine'),(26266,815030055001,110499652147,'Lamp Bulb Holder E27 Socket Flash Umbrella Bracket',2,'AE1302',19,'hermeshine','cliv7049','chadlively111@hotmail.com','chad lively','110-4316  139 avenue','edmonton','AB','CANADA','T5Y0L1','(780) 953-3682','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 05:45:20',0,NULL,3,1,17,0,'CP236401876CN\r ','hermeshine'),(26267,815030626001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','cliv7049','chadlively111@hotmail.com','chad lively','110-4316  139 avenue','edmonton','AB','CANADA','T5Y0L1','(780) 953-3682','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 05:48:14',0,NULL,3,1,3,1,'RA184590885CN ','hermeshine'),(26268,859819405002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','cliv7049','chadlively111@hotmail.com','chad lively','110-4316  139 avenue','edmonton','AB','CANADA','T5Y0L1','(780) 953-3682','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 05:52:21',0,NULL,3,1,5,1,'CP236401876CN ','hermeshine\r除了C以外再发\r单灯头  2\r美标'),(26269,8881332140293721,111,'New Photo Studio Background Backdrop Support Cross Bar 3m ',1,'AD1184',31,'photographyacc','pebblecaza69','kirkphotog@nelsonbay.com ','Kirk Maclean','2 / 10 Pebble Parade','FINGAL BAY','New South Wales','AUSTRALIA','2315','',NULL,NULL,NULL,'2012-03-19 06:58:13',0,NULL,3,1,3,1,'RA184591483CN  ',NULL),(26270,883256250017,270742025107,'32\" 80CM 5IN1 Collapsibl​e Multi Disc Light Reflector',1,'AC3301',14.11,'photographyacc','lisem44','lise.m.cooney@gmail.com','Elise Cooney','13 Mont Albert Rd','Drumcondra','Victoria','AUSTRALIA','3215','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 07:09:25',0,NULL,3,1,11,1,NULL,'photographyacc'),(26271,815048323001,110422375037,'Aluminium UltraLightweight 67\" Camera Monopod 1/4\"Mount',1,'AE1602',26,'hermeshine','alexshebanov2012','alexshebanov@yandex.ru','Alexandr Shebanov','Baraeva 12, 20','Astana','','KAZAKHSTAN','010000',' 87771073013','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 07:33:04',0,NULL,3,1,3,1,'RA184591497CN','hermeshine'),(26272,8881332145112809,111,'Background Support & 3m x 6m Green Screen Light Kit',1,'AKT037',259,'hermeshine','danoveolsen1965','+47 92065988','Dan Ove Olsen','Gruaenga 16','Grua','','NORWAY','2742','92065988',NULL,NULL,NULL,'2012-03-19 08:18:32',0,NULL,3,1,12,1,'2584820615 ','已付$35DHL运费 \r申报$224\r泡重14.1'),(26273,949064011016,260894475451,'New foto Studio 20\"x27\"/50x70cm Softbox Universal Mount',1,'AE2203',14.99,'hutongstore','winnieyem','jmbourgeot_pub@yahoo.fr','Jean-Matthieu Bourgeot','lot 1, 10 rue de Treoualen','SAINT RENAN','Bretagne','FRANCE','29290','02.98.05.39.07','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 08:21:50',0,NULL,3,1,3,1,'RA184595128CN\r ','hutongstore'),(26274,859860599002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','doctor.vital','dr.vital@safe-mail.net','Vitaliy Selivanov','ul. Dikopolceva d.36, kv.9','Komsomolsk-on-Amur','Khabarovsk Territory','RUSSIAN FEDERATION','681035','79098648762','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 09:14:06',0,NULL,3,1,17,0,'RA184595131CN ','hermeshine'),(26275,859860600002,120752222147,'43\" 110cm Studio Flash Translucent White soft Umbrella',2,'AD1125',29.98,'hermeshine','doctor.vital','dr.vital@safe-mail.net','Vitaliy Selivanov','ul. Dikopolceva d.36, kv.9','Komsomolsk-on-Amur','Khabarovsk Territory','RUSSIAN FEDERATION','681035','79098648762','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-19 09:14:06',0,NULL,3,1,3,1,'RA184595131CN ','hermeshine\r反光伞110cm   2\r柔光伞110cm   2'),(26276,969234154015,250599985129,'Small size Lens Pouch Case fit 50mm 1.8 18-55mm New',1,'AC1201',2.18,'hutongstore','voiceman1uk','paul_beckwith@btconnect.com','P. Beckwith','The Stables<br>Hunters Yard','Riseley','Bedfordshire','UNITED KINGDOM','Mk44 1EN','07786111579','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 10:05:24',0,NULL,3,1,11,1,NULL,'hutongstore'),(26277,822189774018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.36,'photographyacc','elijaali','nbaynes@live.com.au','narelle baynes','2 / 82 Raceview Ave','hendra','Queensland','AUSTRALIA','4011','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 11:01:21',0,NULL,3,1,17,0,NULL,'photographyacc'),(26278,822187561018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.44,'photographyacc','elijaali','nbaynes@live.com.au','narelle baynes','2 / 82 Raceview Ave','hendra','Queensland','AUSTRALIA','4011','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 10:55:03',0,NULL,3,0,11,1,NULL,'photographyacc\r麂皮  1\r1.6*2.1  蓝色'),(26279,949149319016,260901271990,'Male to Male 52mm-58mm Macro Reverse Ring reversing 52-58 adapter',1,'AA1212',1.9,'hutongstore','8rehsifgnik','markbeniams@btinternet.com','Mark Beniams','10 Neale Close<br>Wollaston','Wellingborough','Northamptonshire','UNITED KINGDOM','NN29 7UT','01933665254','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 12:20:37',0,NULL,3,1,2,1,NULL,'hutongstore'),(26280,859911804002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','sevan13hlam57','vyacheslav-stukalo@yandex.ru','Вячеслав Стукало','проспект Фрунзе дом 61, квартира 149','г. Ярославль','Ярославская область','RUSSIAN FEDERATION','150006','+79201261569','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 12:12:00',0,NULL,3,1,3,1,'RA184595145CN ','hermeshine'),(26281,969307070015,250692239924,'Photo Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',45,'hutongstore','lenzcape','davetaylor1964@hotmail.co.uk','DAVE TAYLOR','Security Gatehouse. BP Oil Hamble lane<br>Hamble le rice','Southampton','Hampshire','UNITED KINGDOM','SO31 4NR','07887530386','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-19 13:06:37',0,NULL,3,1,4,1,'YW867611475CN','hutongstore\r英标'),(26282,949119563016,260660053020,'New Graduated Gray Filter & Ring & Holder for Cokin P',1,'AKT028',7,'hutongstore','redactor.am','nesoma@mail.ru','Nerses Matinyan','Banaki str. 15, apt. 12','Vanadzor','Lori','ARMENIA','2001',' 37455451702','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 12:50:48',0,NULL,3,1,11,1,NULL,'hutongstore'),(26283,815148476001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','bimantas','foto@regimantas.lt','Regimantas Zukauskas','Žirmūnų g. 1 - 25','Vilnius','','LITHUANIA','09101','(370) 61460081','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 13:35:55',0,NULL,3,1,3,1,'RA184595159CN ','hermeshine'),(26284,822250692018,280714977904,'New Dual-Layer Soft Reflective Umbrella Studio 85cm 33\"',1,'AD1156',18.81,'photographyacc','megan3863','markmeg@iprimus.com.au','Megan Burnett','17 Mallard Street, Thornlie','Perth','Western Australia','AUSTRALIA','6108','0894594309','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 13:54:49',0,NULL,3,1,11,1,NULL,'photographyacc'),(26285,859956132002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','itsthisboy','ryan@ryancarterimages.com','Ryan Carter','57 Quailo Ave','Hallett Cove','South Australia','AUSTRALIA','5158','0883221195','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 14:17:42',0,NULL,3,1,3,1,'RA184595065CN ','hermeshine'),(26286,969351596015,250895544246,'New Pro Panoramic Gimbal Head Tripod Bracket Mount Cameras DSLR Good Quality',1,'AD1185',55,'hutongstore','teamworkskarting','mbryant@teamworkskarting.com','Michael Bryant','Teamworks Karting<br>202 Fazeley Street','Birmingham','West Midlands','UNITED KINGDOM','B5 5SE','08709003020','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-19 14:47:30',0,NULL,3,1,3,1,'RA184595074CN ','hutongstore'),(26287,949247192016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','norberterdei','norbert.erdei@gmail.com','Norbert Erdei','47. Szent István str.','Nyíregyháza','','HUNGARY','H-4400','(0036) 703 350 722','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-19 15:56:17',0,NULL,3,1,5,1,'CP243056166CN ','hutongstore\r欧标'),(26288,949255387016,260833938025,'Super clamp all metal 15kg capacity for flash, backdrop',1,'AD1177',17.9,'hutongstore','javitum','javitum@hotmail.com','Javier Madrazo Caballero','Plaza Juan Carlos I Nº7 1ºDcha','Santander','Cantabria','SPAIN','39008','609522034','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-19 16:13:21',0,NULL,3,1,3,1,'RA184595088CN\r ','hutongstore'),(26289,949282425016,260660050824,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',1,'AKT004',49.99,'hutongstore','luthfur0','lutrahman@talktalk.net','luthfur rahman','5 haslingden drive','bradford','West Yorkshire','UNITED KINGDOM','BD95HS','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-19 17:04:23',0,NULL,3,1,4,1,'YW867611534CN\r ','hutongstore\r除了C以外再发\r灯架  2m   2\r5灯头+60-90棚   2\r115w 5500k 灯泡 220v  10\r灯架包    1\r澳转英标'),(26290,949290555016,260933198603,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.9,'hutongstore','lucie.smahelova','cavalla@seznam.cz','Lucie Smahelova','4 Linnkeith House<br>Balmoral Road','Blairgowrie','Perthshire and Kinross','UNITED KINGDOM','PH10 7AH','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-19 17:16:20',0,NULL,3,1,2,1,NULL,'hutongstore'),(26291,969433802015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',4.6,'hutongstore','aroen83','reitsma_stephan@hotmail.com','Stephan Reitsma','Rollemastate 99','Leeuwarden','','NETHERLANDS','8925DC','+31618297163','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 17:17:27',0,NULL,3,1,11,1,NULL,'hutongstore'),(26292,639351951004,140722305812,'2 Umbrellas 2m Light Stand  Flash/Umbrella mount bracket for Portable Speedlight',1,'AKT100',55,'hermeshine','jimpawa86','jimpawa@gmail.com','Jimmie Sonelius','Hovslagargatan 40','Upplands väsby','Stockholm','SWEDEN','19431','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 18:15:04',0,NULL,3,1,3,1,'RA184595091CN ','hermeshine'),(26293,969474403015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','jasahchun','jason@jl-photo.net','Jason Lin','Blk 230 Ang Mo Kio Avenue 3 #04-1254','Ang Mo Kio','none','SINGAPORE','560230','97672503','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 18:21:24',0,NULL,3,1,6,1,'EE567025569CN ','hutongstore\r黑加白'),(26294,860048898002,120704726071,'Photo Light Head with Four E27(26) Socket Umbrella Hole',2,'AE2202',62.98,'hermeshine','rmcaudio1','rstore@me.com','Rodrigo Martínez','ibsen 6445 departamento 24<br>comuna: Las Condes','Santiago','Región metropolitana','CHILE','7550000','56 99170124','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 17:55:56',0,NULL,3,1,3,1,'RA184595012CN ','hermeshine\r欧标'),(26295,949345128016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','ingvar8807','hengill803@simnet.is','Sjofn Ingvarsdottir','Flat B<br>361 Regents Park Road','London','London','UNITED KINGDOM','N3 1DH',' 447411071841','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 18:42:32',0,NULL,3,1,3,1,'RA184595105CN ','hutongstore\r摄影背心 黑色厚 无字 大小无特别标注为XL'),(26296,815283212001,110533631091,'52mm 3-Stage Rubber Lens Hood for 18-55mm D40 D60',2,'AB1301',6.68,'hermeshine','johnboy2146','john.r.lechner@gmail.com','John Lechner','24 Bower Bird Cl','VACY','New South Wales','AUSTRALIA','2421','0249388427','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 18:50:06',0,NULL,3,1,11,1,NULL,'hermeshine'),(26297,860094884002,120633569372,'Continuous Light Redhead 800w with bulb Red Head Light',1,'AKT055',63,'hermeshine','jackmeck','berkkaleli@hotmail.com','Berk Kaleli','Zafer sokak zafer apartmani<br>numara 43 daire 2 nisantasi','istanbul','sisli','TURKEY','34000','+905327813357','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 19:16:50',0,NULL,3,1,17,0,'CP236401893CN  ','hermeshine'),(26298,815300155001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','bankofjones','srjones240@gmail.com','Spencer Jones','29401 PACIFIC HWY S<br>Apt D201','FEDERAL WAY','WA','UNITED STATES','98003-3880','(253) 802-6071','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-19 19:23:33',0,NULL,3,0,1,1,'LK236512625CN ','hermeshine\r1.6*2.1  绿色'),(26299,815306032001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','jackmeck','berkkaleli@hotmail.com','Berk Kaleli','Zafer sokak zafer apartmani<br>numara 43 daire 2 nisantasi','istanbul','sisli','TURKEY','34000','+905327813357','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 19:27:17',0,NULL,3,1,5,1,'CP236401893CN ','hermeshine\r800w红头灯     1\r800w  220v 灯泡  1\r灯架  2m   1\r欧标'),(26300,949404105016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','promoments','morneandnicola@gmail.com','Morne Olivier','P.O. Box 688','Uvongo','KZN','SOUTH AFRICA','4270','','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-19 19:56:14',0,NULL,3,1,11,1,NULL,'hutongstore'),(26301,969531265015,250599392855,'72mm CPL Circular Polarizing Filter 72 CPL Green.L New',1,'AA3313',4.22,'hutongstore','sergiov_don','sergio.vera@hotmail.com','Sergio Osvaldo Vera Donoso','Chiclana 10849 Villa Los Robles<br>La Pintana','Santiago','Santiago','CHILE','8820348','+5625412788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 19:32:02',0,NULL,3,1,17,0,NULL,'hutongstore'),(26302,860141221002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','junk_project','alpha18m@hotmail.com','Maarten Vaes','Meenselstraat 115','Binkom','','BELGIUM','3211','0472716591','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 20:32:37',0,NULL,3,1,11,1,NULL,'hermeshine'),(26303,969578482015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','gradwar','glenvideodagbok@hotmail.com','Gustav Aldin','Liljegatan 4D','Uppsala','Uppland','SWEDEN','75324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 20:32:46',0,NULL,3,1,17,0,'RA184595026CN ','hutongstore'),(26304,969577850015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','gradwar','glenvideodagbok@hotmail.com','Gustav Aldin','Liljegatan 4D','Uppsala','Uppland','SWEDEN','75324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 20:32:47',0,NULL,3,1,17,0,'RA184595026CN ','hutongstore'),(26305,969577569015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',1,'AB2301',5,'hutongstore','gradwar','glenvideodagbok@hotmail.com','Gustav Aldin','Liljegatan 4D','Uppsala','Uppland','SWEDEN','75324','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-19 20:32:49',0,NULL,3,1,3,1,'RA184595026CN ','hutongstore\r伞式柔光箱 60×90cm   1\r斜臂    1\r闪光灯B座    1'),(26306,969607127015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','varakon','damon_troughton@lineone.net','Damon Troughton','50 Mursley Court<br>Stony Stratford','Milton Keynes','Buckinghamshire','UNITED KINGDOM','MK11 1NS','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 21:08:26',0,NULL,5,0,18,0,NULL,'hutongstore\r客户要取消'),(26307,969621303015,250932214023,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',2,'AD1191',75.78,'hutongstore','freehand_ltd','matt.wright@freehand.co.uk','Matt Wright','Freehand Ltd, Building 52<br>Dunsfold Park','Cranleigh','Surrey','UNITED KINGDOM','GU6 8TB','01483200111','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-19 21:25:33',0,NULL,3,1,4,1,'YW867611486CN','hutongstore\r澳转英标'),(26308,860188633002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','criticalfx','simosenmarko@gmail.com','Marko Simonen','Ulappasaarentie 8 C 65','Helsinki','Uusimaa','FINLAND','00980','+358-45-6352688','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 21:54:09',0,NULL,3,1,11,1,NULL,'hermeshine'),(26309,860205264002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','marcusfluvius','kadoelen141@hotmail.com','Marc van Beek','Diamantring 150','Eindhoven','','NETHERLANDS','5629 GR','+31628536129','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 22:32:24',0,NULL,3,1,3,1,'RA184595030CN ','hermeshine'),(26310,883675538017,270742402877,'New IR Wireless Remote Control for Olympus E520E E420 ',1,'AA2204',3.32,'photographyacc','gnrichard','gnrichard@gmail.com','Nathaniel Richard Gollamandala','18 Emert St','Wentworthville','New South Wales','AUSTRALIA','2145','0061430140322','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-19 22:57:22',0,NULL,3,1,2,1,NULL,'photographyacc'),(26311,860216382002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','francisnzv','ventasfrancis@gmail.com','M. ANGELES LOMEÑA MONTES','SPITERI 16 4º E','MALAGA','Andalucía Ceuta y Melilla','SPAIN','29003','645179905','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 22:59:04',0,NULL,3,1,2,1,NULL,'hermeshine'),(26312,860219068002,120343558909,'Adjustable Neoprene Padded Camera Neck shoulder Strap',1,'AB1407',5.49,'hermeshine','inmovil70','julianrey@terra.es','Julián Rey Fernández','Union Fenosa - A Batundeira 2 -Velle-','Ourense','Galicia','SPAIN','32960','616482860','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-19 23:05:42',0,NULL,3,1,2,1,NULL,'hermeshine'),(26313,860266585002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','captbillod','billod01@comcast.net','William O\'Donnell','13756 Briargate Dr','Huntley','IL','UNITED STATES','60142','(847) 515-2825','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 01:25:39',0,NULL,3,1,3,1,'RA184595043CN\r ','hermeshine'),(26314,8881332207430201,111,'New Photo Studio Light Stand Umbrella Flash C Mount set - Wholesale/ Retail [AKT052]',1,'AKT052',42.99,'aliexpress','1007501965','mit00@yandex.ru','Dmitriy Belyaev','Malysheva 5-10','Moscow','Russia','RUSSIAN FEDERATION','109129','+495 916 1782638',NULL,NULL,NULL,'2012-03-20 01:37:10',0,NULL,3,1,3,1,'RA184595851CN\r ','速卖通\r2云柔   1 '),(26315,8881332207557634,111,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included Wholesale/ Retail [AC2402]',1,'AC2402',23.99,'aliexpress','1007505449','dgomail@terra.com.br','Diego Bormann','Primicias 312','sao paulo','sao paulo','BRAZIL','03406-100','+55 11 80687085',NULL,NULL,NULL,'2012-03-20 01:39:17',0,NULL,3,1,3,1,'RA184595763CN\r ','速卖通 '),(26316,815469666001,110625489425,'Green-L 77mm Graduated Neutral Density ND Grey Filter',1,'AA3321',8.47,'hermeshine','djgrrr','james@jamestilberg.com','James Tilberg','4100 Ponytrail Drive<br>Suite 903','Mississauga','ON','CANADA','L4W 2Y1','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 01:40:48',0,NULL,3,1,11,1,NULL,'hermeshine'),(26317,860279572002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','neal_hanley','neal_hanley@yahoo.com','NEAL HANLEY','712 CANYON VIEW DR','LANSING','KS','UNITED STATES','66043','','NoPaymentFailure','CheckoutComplete','Other','2012-03-20 02:04:15',0,NULL,3,0,1,1,'LK237068046CN ','hermeshine\r3XL 已入库'),(26318,969756394015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','bugsbunny74','craigandsuz@gmail.com','Craig Davidson','80 The Hollies<br>Quakers Yard','Treharris','Mid Glamorgan','UNITED KINGDOM','CF46 5PP','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-20 02:14:24',0,NULL,3,1,3,1,'RA184595057CN\r ','hutongstore'),(26319,8881332210957285,111,'60闪光柔光箱上的两个扣',1,'',0,'photographyacc','malfac','mfackender@spotlightonasia.com','Malcolm Fackender','31 Kapooka Avenue','Dapto','New South Wales','AUSTRALIA','2530','0242616210',NULL,NULL,NULL,'2012-03-20 02:35:57',0,NULL,3,0,3,1,'RA184595114CN\r ',NULL),(26320,969768688015,250939065597,'Male to Male 58mm-58mm Macro Reverse Ring reversing 58-58 adapter',1,'AA1213',1.9,'hutongstore','guss123077','guss28@hotmail.co.uk','simon sugden','59central avenue','shipley','West Yorkshire','UNITED KINGDOM','bd183rl','07725076669','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 03:12:27',0,NULL,3,1,2,1,NULL,'hutongstore'),(26321,815498195001,110414373102,'67mm 67 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT022',4.1,'hermeshine','raroman168','dcheng75385@roadrunner.com','david cheng','3332 millbury ave','baldwin park','CA','UNITED STATES','91706-5439','(626) 593-6136','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-20 03:21:55',0,NULL,3,1,17,0,'LK236735905CN ','hermeshine'),(26322,860301420002,120841734374,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',13.88,'hermeshine','raroman168','dcheng75385@roadrunner.com','david cheng','3332 millbury ave','baldwin park','CA','UNITED STATES','91706-5439','(626) 593-6136','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 03:21:56',0,NULL,3,1,17,0,'LK236735905CN ','hermeshine'),(26323,815498196001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.1,'hermeshine','raroman168','dcheng75385@roadrunner.com','david cheng','3332 millbury ave','baldwin park','CA','UNITED STATES','91706-5439','(626) 593-6136','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-20 03:21:57',0,NULL,3,1,1,1,'LK236735905CN ','hermeshine\r方形滤镜接口环 67mm  1\r方镜普通托架（三槽）  1\r无牌方镜 渐变蓝   1\r无牌方镜 渐变橙   1\r无牌方镜 渐变灰 （nd4）   1\r3片装的滤镜袋  1\r方形滤镜接口环 58mm  1\r方镜普通托架（三槽）  1'),(26324,969789662015,250746714122,'72mm Graduated Neutral Density Filter Gradual Grey 72',1,'AA3320',5.8,'hutongstore','sergiov_don','sergio.vera@hotmail.com','Sergio Osvaldo Vera Donoso','Chiclana 10849 Villa Los Robles<br>La Pintana','Santiago','Santiago','CHILE','8820348','+5625412788','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 04:02:51',0,NULL,3,1,11,1,NULL,'hutongstore\r绿叶 CPL 72mm  1\r绿叶 渐变镜 72mm  1'),(26325,860173818002,120593459021,'New Hairlight Heavy Duty photostudio boom arm ',1,'AE3101',37.99,'hermeshine','eutanasiabass','ivan.eutanasia@gmail.com','Ivan Baltazar','Calle Jose Molina Campos, 3184<br>Barrio Estación Argentina','Santa Cruz','Santa Cruz','BOLIVIA','2841','(591) 3 346 2030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:26:17',0,NULL,3,1,3,1,'RA184596004CN\r ','hermeshine'),(26326,860316309002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+62-21-92659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 04:36:10',0,NULL,3,1,11,1,NULL,'hermeshine'),(26327,860326341002,120778209565,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',16.5,'hermeshine','liberty_gaming','libertygaming@gmail.com','Kiran Bedi','251 Maltby Road E','Guelph','ON','CANADA','N1L1K5','(514) 426-5149','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 05:33:36',0,NULL,3,1,11,1,NULL,'hermeshine'),(26328,860328920002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','svyaznoi777','jon-vor@mail.ru','Evgeny Vorobyev','st. Matrosova, dom. 11, kv. 8','Krasnoyarsk','RU','RUSSIAN FEDERATION','660064','+79233486117','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 06:15:06',0,NULL,3,1,3,1,'RA184595936CN\r ','hermeshine'),(26336,860391822002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','oleg-oo8','x008am71rus@narod.ru','Oleg Kharitonov','12 Gaydar\'s street','Aleksin','Tula Region / Aleksinsky district','RUSSIAN FEDERATION','301360','+79156953233','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 10:39:03',0,NULL,3,1,11,1,NULL,'hermeshine'),(26329,969832311015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','freelancer4224','ianyoung2@me.com','Ian Young','Fire Station<br>New Hythe Lane','Larkfield','Kent','UNITED KINGDOM','ME20 6PP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 07:19:49',0,NULL,3,1,3,1,'RA184595919CN\r ','hutongstore'),(26330,949692871016,260814129443,'Pole Clamp 1/4\" Thread for Flash Continuous Lamp Clip C',1,'AE3104',6.6,'hutongstore','technic1','tecnik2002@yahoo.com','Gil Palen','PO Box 16501','Sugar Land','TX','UNITED STATES','77496-6501','(832) 928-0775','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-20 08:11:27',0,NULL,3,1,11,1,NULL,'hutongstore'),(26331,883832701017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',28.49,'photographyacc','tbird_1306','m.turner1306@gmail.com','Matt Turner','23 - 27 Maike Drive<br>Urraween','Hervey Bay','Queensland','AUSTRALIA','4655','0403586109','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 08:34:36',0,NULL,3,1,3,1,'RA184595984CN\r ','photographyacc'),(26332,969856013015,250932248731,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light',1,'AKT069',42,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-20 08:45:25',0,NULL,3,1,3,1,'RA184595975CN\r ','hutongstore\r申报GBP19'),(26333,969878226015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','eirerun','danielle_lorenzi@hotmail.com','Danielle Lorenzi','35, sruthan Mhuirlinne<br>Ballybane','Galway','','IRELAND','','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 09:54:11',0,NULL,3,1,4,1,'YW867611560CN\r\r ','hutongstore\r黑加白'),(26334,811304872001,110526979454,'New Camera Body & Lens Rear Cap For Nikon D3 D300 D60 ',3,'AA1314',8.97,'hermeshine','eastcoast_t902','tzilkowsky@gmail.com','Tania Zilkowsky','7 David Allen Drive','East Lawrencetown','NS','CANADA','B2Z 1N8','(902) 482-2481','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 09:56:11',0,NULL,3,1,11,1,NULL,'hermeshine'),(26335,8881332237399274,111,'80cm 8角柔光布',1,'',0,'hermeshine','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0039761411264',NULL,NULL,NULL,'2012-03-20 09:56:39',0,NULL,3,0,3,1,'RA184595746CN\r',''),(26337,860398045002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','whealers','whealers@aol.com','Gary Jackson','188 Church St','Doylestown','OH','UNITED STATES','44230-1403','(330) 289-2215','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 11:04:23',0,NULL,3,1,3,1,'RA184595785CN\r ','hermeshine'),(26338,969916586015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','lahy18','nik.lahajnar@gmail.com','Nik Lahajnar','Triglavska cesta 35','Mojstrana','','SLOVENIA','4281','07035954714','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 11:41:30',0,NULL,3,0,11,1,NULL,'hutongstore\r1.6*2.1  黑色'),(26339,949769269016,260901272233,'New 4 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',3,'AE1202',7.5,'hutongstore','shippy_56','rowaldigital@gmail.com','Allan Rowe','Hudsons Penrith<br>Coreen ave','Penrith','New South Wales','AUSTRALIA','2747','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 11:50:10',0,NULL,3,1,11,1,NULL,'hutongstore'),(26340,815632603001,110611086536,'Neoprene  Camera Cover Case for dslr & semi slr small',1,'AC2301',5.69,'hermeshine','ejrastik','d.a.polishchuk@gmail.com','Dmitriy Polishchuk','127/55, pr. Kommunisticheskiy','Seversk','Tomsk region','RUSSIAN FEDERATION','636037','7-952-8066669','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 13:17:55',0,NULL,3,1,11,1,NULL,'hermeshine'),(26341,969964723015,250846990874,'New Flash Shoe Holder Swivel Bracket Umbrella Mount B',5,'AB2301',25,'hutongstore','kooregani89','nazziir@hotmail.com','Nazir Kooregani','poppelvägen 1','Vänersborg','Vänersborg','SWEDEN','46251','0046700372273','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 13:39:47',0,NULL,3,1,3,1,'RA184595777CN\r ','hutongstore'),(26342,815644077001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','lazy-goose','lazy-goose@hotmail.com','Anthony Gates','4 George Street','Tanunda','South Australia','AUSTRALIA','5352','0885631562','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 13:54:42',0,NULL,3,1,11,1,NULL,'hermeshine'),(26343,969984524015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','rguindi','raul_fv@hotmail.com','Raul Ferrero Vicente','Avenida De Valladolid<br>Nº3, Blq 2, P-1, 2ºD','Zamora','Castilla y León','SPAIN','49022','607307943','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 14:25:20',0,NULL,3,1,4,1,'YW867611545CN\r ','hutongstore\r黑加白'),(26344,949835600016,260901272035,'New HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm HB7',1,'AA1216',8.8,'hutongstore','j0kyno','josoares@yahoo.com','João Soares','Rua Coutinho de Azevedo nº 294, 1º Andar','Porto','Porto','PORTUGAL','4000-188','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-20 14:35:47',0,NULL,3,1,11,1,NULL,'hutongstore'),(26345,860474906002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','sys4uu','audiopia@naver.com','Jaekon Lee','108-808 Dongsuwon LG Village, Mangpo-Dong, Yeongtong-Gu','Suwon-Si','Gyeonggi-Do','KOREA,REPUBLIC OF','443-706','(010)273-7870','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:02:43',0,NULL,3,1,17,0,NULL,'hermeshine'),(26346,815668042001,110566021586,'TianYa New Star 8 points filters for Cokin P Series',1,'AE2317',10.4,'hermeshine','sys4uu','audiopia@naver.com','Jaekon Lee','108-808 Dongsuwon LG Village, Mangpo-Dong, Yeongtong-Gu','Suwon-Si','Gyeonggi-Do','KOREA,REPUBLIC OF','443-706','(010)273-7870','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:02:44',0,NULL,3,1,17,0,NULL,'hermeshine'),(26347,860474907002,120626873273,'New wide angle holder for Cokin P series filter',1,'AA2216',3.99,'hermeshine','sys4uu','audiopia@naver.com','Jaekon Lee','108-808 Dongsuwon LG Village, Mangpo-Dong, Yeongtong-Gu','Suwon-Si','Gyeonggi-Do','KOREA,REPUBLIC OF','443-706','(010)273-7870','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:02:44',0,NULL,3,1,11,1,NULL,'hermeshine\r无牌方镜 渐变日落   1\r天涯方形滤镜系列  星光镜  \rstar8  1\r方镜广角托架（ 一槽）  1'),(26348,815675389001,110533631929,'New Light Soft Box x 1 for Studio Strobes 70cm x 50cm',1,'AE2401',34,'hermeshine','elephant_2012','dirnens@gmail.com','Uldis Dirnens','38 Priory Road','London','London','UNITED KINGDOM','NW6 4SJ','07405450547','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:23:56',0,NULL,3,1,3,1,'RA184595794CN\r ','hermeshine\r英标'),(26349,970017410015,250636783550,'New PhotoStudio Continuous Light Kit Soft Box Softbox',1,'AKT016',54,'hutongstore','soundzshop','thesoundshop@live.co.uk','alan scott','31<br>upperby court','carlisle','Cumbria','UNITED KINGDOM','ca24jw','01228549501','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-20 15:45:04',0,NULL,3,1,4,1,'YW867611512CN\r ','hutongstore\r英标'),(26350,815680025001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','shooter163yuriy','yuriytymchenko@mail.ru','Yuriy Tymchenko','Pobedy, 4B-28','Samara','Samarkaya','RUSSIAN FEDERATION','443083','89083926059','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 15:53:33',0,NULL,3,1,5,1,'CP236401916CN\r ','hermeshine'),(26351,860534832002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','housesales11','veronicayepiz@gmail.com','veronica yepiz','5928 amick st','north las vegas','NV','UNITED STATES','89081-6437','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-20 17:34:05',0,NULL,3,1,3,1,'RA184595750CN\r ','hermeshine'),(26352,860538329002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','kalinovskydmitry','kadmy@yandex.ru','Dmitry Kalinovsky','ul.Kizhevatova, d.66, kv.92','Minsk','','BELARUS','220024','80172124265','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 17:41:04',0,NULL,3,1,17,0,'RA184595715CN ','hermeshine'),(26353,815730810001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','kalinovskydmitry','kadmy@yandex.ru','Dmitry Kalinovsky','ul.Kizhevatova, d.66, kv.92','Minsk','','BELARUS','220024','80172124265','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 17:41:05',0,NULL,3,1,3,1,'RA184595715CN\r ','hermeshine\r伞式柔光箱 80cm 8角    1\r3m 横杆（通用4节）   1\r申报$40'),(26354,970096515015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','s.kavir','sohrabkavir@gmail.com','Sohrab Kavir','130 Booth Road','london','London','UNITED KINGDOM','NW9 5JY','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 18:33:15',0,NULL,3,1,4,1,'YW867611571CN\r ','hutongstore\r英标\r除了C以外还有\r3m X 6m 白色和黑色布'),(26355,860564007002,120439974540,'Promotion！EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',9.99,'hermeshine','meseyo','conchijuanlf@wanadoo.es','VIDAL PASCUAL, CONCHI','C/ SUBIDA AL CABEZO Nº 10','CASTELSERAS','Aragón','SPAIN','44630','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 18:41:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(26356,815776286001,110566891585,'Photo Studio Background Support 2m x 3m (7×10 ft) BAG',1,'AO0011',79.99,'hermeshine','sagistious','leibmans@gmail.com','Sagi Leibman','Hanagid 4','Ramat Gan','','ISRAEL','52473','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-20 19:11:14',0,NULL,3,1,3,1,'RA184595817CN\r ','hermeshine\r分开发\rRA184595803CN\r'),(26357,950003331016,260901272191,'New Camera protector case Neoprene bag for Nikon D5000 D5100 D90 D80 M',1,'AD1172',4.6,'hutongstore','8165davidf','david.fielderah@btinternet.com','david fielder','abenhall house<br>abenhall road','mitcheldean','Gloucestershire','UNITED KINGDOM','gl17 0dt','07733257464','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 19:39:40',0,NULL,3,1,11,1,NULL,'hutongstore'),(26358,970207406015,250599342200,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1201',2.95,'hutongstore','peter_butt','peterbutterworth@mac.com','Peter Butterworth','1 The Avenue<br>Seedfield','Bury','Greater Manchester','UNITED KINGDOM','BL9 5DQ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 20:38:22',0,NULL,3,1,11,1,NULL,'hutongstore'),(26359,822974077018,280687909093,'1.6m x 2.1m Background Backdrop Photography  Non-Woven',1,'AO0005',10.99,'photographyacc','natjfm','andpigsmightfly@msn.com','Natalie Furner','88 Single st','Werris Creek','New South Wales','AUSTRALIA','2341','0427789966','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-20 20:47:56',0,NULL,3,0,11,1,NULL,'photographyacc\r1.6*2.1  粉色'),(26360,860654801002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','ain-tova','davidstein48@gmail.com','David Stein','Metula 5','Ramat Gan','','ISRAEL','52273','054-979-2771','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 21:16:39',0,NULL,3,1,3,1,'RA184595825CN\r ','hermeshine'),(26361,815849477001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',78,'hermeshine','xarumunguru','gzegoz@bk.ru','Gzegoz Sakel','18 Limassol Road ','Dereham','Norfolk','UNITED KINGDOM','NR19 1XR','00792412696','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 21:23:55',0,NULL,3,1,3,1,'RA184595834CN\r ','hermeshine'),(26362,970246565015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','louthy123','garrylouth@tiscali.co.uk','gary louth','1 parkdale ave , Audenshaw','manchester','lancashire','UNITED KINGDOM','M345LW','01613207078','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 21:33:16',0,NULL,3,1,17,0,'RA184595940CN ','hutongstore'),(26363,970246567015,250971425921,'Promotion !NEW Square Graduated Gray ND4 Plexiglass Filter for Cokin P Series',1,'AD1219',3.9,'hutongstore','louthy123','garrylouth@tiscali.co.uk','gary louth','1 parkdale ave , Audenshaw','manchester','lancashire','UNITED KINGDOM','M345LW','01613207078','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-20 21:33:17',0,NULL,3,1,3,1,'RA184595940CN\r ','hutongstore\r伞式柔光箱 80cm 8角    1\r无牌方镜 渐变灰 （nd4）  1'),(26364,860705357002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','fotama','ntamas@pannongsm.hu','Nagy Tamás','Ferenczy Ida u. 5. 1./5.','Kecskemét','','HUNGARY','6000','36304636974','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-20 23:19:55',0,NULL,3,1,3,1,'RA184595879CN\r ','hermeshine'),(26365,970305638015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','thegouster','thegouster@ntlworld.com','Rick Stanton','20 Tilstock Ave<br>New Ferry','Wirral','Cheshire','UNITED KINGDOM','CH62 1EL','07971974649','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-20 23:32:43',0,NULL,3,1,3,1,'RA184595882CN\r ','hutongstore'),(26366,823120865018,280666888704,'New Green.L 58mm  Gradual Grey ND4 Filter 2-Stop 58 mm',1,'AA3317',6.6,'photographyacc','collh','garthcoll78@iinet.net.au','Colleen Henderson','14 Emblem Street<br>Jamboree Heights','Brisbane','Queensland','AUSTRALIA','4074','0432339839','PayPalPaymentInProcess','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','0000-00-00 00:00:00',0,NULL,3,1,11,1,NULL,'photographyacc'),(26367,860782643002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','svetoslavplace','svetoslav.krastev@gmail.com','Svetoslav Krastev','Bratya Miladinovi, bl. 1B, vh.A, et.7, ap. 19','Burgas','','BULGARIA','8000','+359895744030','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 03:47:26',0,NULL,3,1,3,1,'RA184595692CN ','hermeshine'),(26368,860780314002,120503658828,'New translucent white umbrella soft 85cm / 33.5\"',2,'AD1402',17.8,'hermeshine','newtonbr','newtonnogueira@gmail.com','NEWTON NOGUEIRA DA SILVA','RUA JOÃO BATISTA D\'ELIA, 1270<br>PARQUE PROGRESSO','FRANCA','SÃO PAULO','BRAZIL','14403-102','551681249004','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 03:35:54',0,NULL,3,0,11,1,NULL,'hermeshine'),(26369,884301020017,270748932879,' Eyepiece Eyecup EF For Canon EOS 550D 450D 400D 350D',1,'AA1201',2.9,'photographyacc','johan.larson','johan.larson@jcu.edu.au','Johan Larson','4 Amos Close','Redlynch Valley','Queensland','AUSTRALIA','4870','0740421641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 03:57:16',0,NULL,3,1,17,0,'RA184595896CN ','photographyacc'),(26370,884301384017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','johan.larson','johan.larson@jcu.edu.au','Johan Larson','4 Amos Close','Redlynch Valley','Queensland','AUSTRALIA','4870','0740421641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 03:58:27',0,NULL,3,1,17,0,'RA184595896CN ','photographyacc'),(26371,884301747017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',2,'AA1310',11.9,'photographyacc','johan.larson','johan.larson@jcu.edu.au','Johan Larson','4 Amos Close','Redlynch Valley','Queensland','AUSTRALIA','4870','0740421641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 03:59:51',0,NULL,3,1,17,0,'RA184595896CN ','photographyacc'),(26372,884302087017,270862544761,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',29.99,'photographyacc','johan.larson','johan.larson@jcu.edu.au','Johan Larson','4 Amos Close','Redlynch Valley','Queensland','AUSTRALIA','4870','0740421641','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 04:01:22',0,NULL,3,1,3,1,'RA184595896CN\r ','photographyacc\r眼罩 450D/500D   1\r带水平仪 热靴保护盖  1\rlenspen  2\r伞式柔光箱 60×90cm   1'),(26373,860787395002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','darkaindragoon','pkfk@hotmail.com','Vincent Milum Jr','3599 Fawcett Ave','Tacoma','WA','UNITED STATES','98418-6841','(530) 746-8695','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 04:10:39',0,NULL,3,1,3,1,'RA184595905CN\r ','hermeshine'),(26374,823129138018,280667385648,'New Collapsibl​e 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',38,'photographyacc','pattyjae','pat_bits@hotmail.com','Patrick Jaeger','32a Saunders Bay Rd','Caringbah','New South Wales','AUSTRALIA','2229','0295273815','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 04:15:34',0,NULL,3,1,3,1,'RA184595848CN\r ','photographyacc'),(26375,970403544015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','marcspinolla2010','marcspin@starmedia.com','José Marcos de Freitas Spínola','Rua Alagoas<br>1475-A','Avaré','São Paulo','BRAZIL','18700-010','14-88063590','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 04:24:28',0,NULL,3,1,5,1,'CP236401978CN\r ','hutongstore\r欧标\r110V 灯泡'),(26376,8881332306650287,111,'800W 220V *10',1,'',0,'aliexpress','paul486 ','sales@hypop.com.au','Paul Romero','31/70 Holbeche Road','Arndell Park','NSW','AUSTRALIA','2148','+611300449767',NULL,NULL,NULL,'2012-03-21 05:10:50',0,NULL,3,0,3,1,'RA184595732CN\r ','Paypal（sales@hypop.com）直接付款 \r一共是10个 \r已入库'),(26377,8881332311477711,111,'三脚架 伟峰 WF-6663A  中轴',1,'',0,'hermeshine','systemop63','oac1.6@mail.ru','Petr Grachev','Taskentskaya street 132-24','Samara','Samara','RUSSIAN FEDERATION','443095','+7 906 3451006',NULL,NULL,NULL,'2012-03-21 06:31:17',0,NULL,3,0,3,1,'RA184595675CN\r ',NULL),(26378,884333850017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',1,'AO0005',16.99,'photographyacc','n1buyer1001','khanhhungvn1001@gmail.com','Harry DK','2/2 Glenbrook Ave','Clayton','Victoria','AUSTRALIA','3168','0395628000','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 06:50:23',0,NULL,3,0,3,1,'RA184595661CN\r ','photographyacc\r1.6*3  白色'),(26379,8881332317023144,111,'45w 5500k 灯泡 220v',2,'AKT007',0,'hutongstore','diixiirkazan','diixiir@gmail.com','Dmitri Kochnev','Cheluskina street, house (dom) 60, flat (kvartira) 13','Kazan','Tatarstan','RUSSIAN FEDERATION','420037','89625603803',NULL,NULL,NULL,'2012-03-21 08:03:43',0,NULL,3,0,3,1,'RA184595701CN ','已入库 \r没发'),(26380,860830513002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',2,'AA1216',27,'hermeshine','ivan_ns2','norman.setiawan@gmail.com','Norman Setiawan','Atrium Setiabudi, PT Bakrie Telecom Tbk,   Lt. 8 Suite 802<br>Jl. HR. Rasuna Said Kav. 62','South Jakarta','DKI JAKARTA','INDONESIA','12920','+62-21-92659421','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 08:09:47',0,NULL,3,1,11,1,NULL,'hermeshine'),(26381,8881332317908773,111,'Black/Whilte Reflection board 20X30cm Reflection effect - Wholesale/ Retail [AB1201]',1,'AB1201',15.99,'aliexpress','1007526913','magali.besson@monsacadeco.com','Besson Magali','27 ALLEE FLEURIE','LIVRON SUR DROME','RHONE ALPES DROME','FRANCE','26250','+33 0610885925',NULL,NULL,NULL,'2012-03-21 08:18:28',0,NULL,3,1,17,0,'RA184595508CN\r ','速卖通 '),(26382,8881332318023184,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included - Wholesale/ Retail [AC2403]',1,'AC2403',33.99,'aliexpress','1007526912','magali.besson@monsacadeco.com','Besson Magali','27 ALLEE FLEURIE','LIVRON SUR DROME','RHONE ALPES DROME','FRANCE','26250','+33 0610885925',NULL,NULL,NULL,'2012-03-21 08:20:23',0,NULL,3,1,3,1,'RA184595508CN\r ','速卖通\r倒影板（白黑）  1 \r圆形柔光棚 60cm  1'),(26383,950295499016,260624539451,'Photo Studio Continuous Light Kit 23\' SoftBox 4 output ',1,'AKT039',105,'hutongstore','crinaromania001','mamazmeilor@yahoo.com','Crina Prida','Str. Slanic 3/7<br>Cluj','Cluj Napoca','','ROMANIA','400413','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 08:41:23',0,NULL,3,1,5,1,'CP236401964CN\r ','hutongstore\r欧标\r220V'),(26384,8881332321022859,111,'两个欧标',1,'',0,'hutongstore','garyshark024','gary.h024@gmail.com','Gergely Horváth','Kertvaros street 59.','Budapest','','HUNGARY','1028','',NULL,NULL,NULL,'2012-03-21 09:10:22',0,NULL,5,0,18,0,NULL,NULL),(26385,970477802015,250599940143,'52mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1301',2.15,'hutongstore','norman970_0','montyhighst@aol.com','Norman Hutchinson','56,High Street, Coldstream','Berwickshire','Borders','UNITED KINGDOM','TD124DH','01890883782','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 09:22:24',0,NULL,3,1,11,1,NULL,'hutongstore'),(26386,816037180001,110566018189,'55mm 3-Stage Rubber Lens Hood for A700 A100 Sony',3,'AB1302',10.02,'hermeshine','olea_matis','victormatisiuc@gmail.com','Victor Matisiuc','Mircea cel Batrin 4 ap. 133','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','MD-2044','+373 69596649','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 09:32:04',0,NULL,3,1,17,0,'RA184595613CN ','hermeshine'),(26387,8881332322995677,111,'2个150W灯泡',1,'',0,'hutongstore','ilhadastartarugas','ilhatartarugas@gmail.com','Ilha das Tartarugas','Av Infante D Henrique 94 apt 208','Junqueiro','Lisboa','PORTUGAL','2775-000','',NULL,NULL,NULL,'2012-03-21 09:43:15',0,NULL,3,0,3,1,'RA184595635CN ',NULL),(26388,860853000002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','levens74','madewithlovecards@googlemail.com','Meghan Levens','214 Bath Road','Reading','Berkshire','UNITED KINGDOM','RG30 2HN','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 09:45:38',0,NULL,3,1,3,1,'RA184595627CN ','hermeshine'),(26389,860856363002,120486048110,'77mm 77 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',2,'AB1307',7.58,'hermeshine','olea_matis','victormatisiuc@gmail.com','Victor Matisiuc','Mircea cel Batrin 4 ap. 133','Chisinau','Moldova','MOLDOVA, REPUBLIC OF','MD-2044','+373 69596649','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 09:56:24',0,NULL,3,1,3,1,'RA184595613CN','hermeshine\r橡胶遮光罩 55mm  3\r橡胶遮光罩 77mm  2'),(26390,970490130015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','mansell77','mansell77@msn.com','Stephen  Mansell','Gnoll House, 32 Gnoll Road, Godrergraig','Ystalyfera','Swansea','UNITED KINGDOM','SA9 2PA','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 09:58:05',0,NULL,3,1,11,1,NULL,'hutongstore'),(26391,823220087018,280696873208,'100% Cotton Photo Vest for Nikon D90 D80 D300 D700 user',1,'AD1137',29.99,'photographyacc','prettydamhot','sixpack@netspace.net.au','Rosemary Rowe','108 Leven Street','Ulverstone','Tasmania','AUSTRALIA','7315','0364252232','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 11:00:29',0,NULL,3,1,3,1,'RA184595410CN\r ','photographyacc\rXL  已入库'),(26392,970523342015,250643703886,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0005',7.99,'hutongstore','brendan0676','b_morgan@mail2expert.com','Joanne Skillen','6 Earl Close','Belfast','Antrim','UNITED KINGDOM','bt151df','02895810223','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 11:30:35',0,NULL,3,0,11,1,NULL,'hutongstore\r1.6*2.1  黑色'),(26393,823231934018,280680882557,'Dslr Remote Shutter Release Cord RS-N1 Nikon D300s D700',1,'AA3207',3.99,'photographyacc','nvy825','philip.natividad@gmail.com','Philip Natividad','Ground Floor / 185 Rosslyn Street','West Melbourne','Victoria','AUSTRALIA','3003','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 11:40:28',0,NULL,3,1,17,0,NULL,'photographyacc'),(26394,884411737017,270748975676,'Hot Shoe Spirit Level Cover Protector For Canon Nikon',1,'AA1206',2.9,'photographyacc','nvy825','philip.natividad@gmail.com','Philip Natividad','Ground Floor / 185 Rosslyn Street','West Melbourne','Victoria','AUSTRALIA','3003','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 11:40:29',0,NULL,3,1,11,1,NULL,'photographyacc\r普通有线快门线N1  1\r带水平仪 热靴保护盖   1'),(26395,970536901015,250678485928,'New thicken Non Woven Fabric Backdrop 3m x 6m(10x20ft)',2,'AO0018',76,'hutongstore','s.kavir','sohrabkavir@gmail.com','sohrab kavir','10 cave road','Richmond','Surrey','UNITED KINGDOM','tw107tz','02084399098','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-21 12:12:05',0,NULL,8,1,17,0,NULL,'hutongstore'),(26396,814965289001,110807099913,'Promotion ! NEW  Square Neutral Density full ND4 Grey Filter for Cokin P Series',5,'AD1222',17.5,'hermeshine','u458297','erwin_ricerra@yahoo.com','ERWIN ROY RICERRA','153 scout gandia st.<br>brgy sacred heart, kamuning','Quezon City','PHILIPPINES','PHILIPPINES','1103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 12:29:43',0,NULL,3,1,17,0,'RA184595423CN\r ','hermeshine'),(26397,639132988004,140679559196,'Promotion ! NEW  Square Neutral Density full ND8 Grey Filter for Cokin P Series',5,'AD1223',17.5,'hermeshine','u458297','erwin_ricerra@yahoo.com','ERWIN ROY RICERRA','153 scout gandia st.<br>brgy sacred heart, kamuning','Quezon City','PHILIPPINES','PHILIPPINES','1103','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 12:29:43',0,NULL,3,1,3,1,'RA184595423CN\r ','hermeshine\r无牌方镜 ND4   5\r无牌方镜 ND8    5'),(26398,816101124001,110560006022,'1200W Continuous Lighting Kit backdrop support softbox',1,'AKT005',185,'hermeshine','8809josv','jonatan@legstale.se','Jonatan Svensson','Rogalandsgata 74 lgh 207','Haugesund','Rogaland','NORWAY','5522','96758925','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 13:17:44',0,NULL,3,1,5,1,'CP236402001CN\r ','hermeshine\r欧标'),(26399,950401244016,260901272211,'New Camera protector case Neoprene bag for Nikon D90 D7000 D80 L',1,'AD1173',6.5,'hutongstore','bluerustytiger','russellpmurphy4@bigpond.com','Russell Murphy','8/59 Cureton Avenue','MILDURA','Victoria','AUSTRALIA','3500','0350235541','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 13:32:33',0,NULL,3,1,11,1,NULL,'hutongstore'),(26400,823272574018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39.99,'photographyacc','339514884','kamikazi@inbox.ru','Andrey Pirinov','yl. Nekrasova d.11','Voronezh','Voronezh','RUSSIAN FEDERATION','394071','+79081349541','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-21 13:39:49',0,NULL,3,1,3,1,'RA184595437CN\r ','photographyacc'),(26401,970578359015,250599936751,'3 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',2,'AE1201',5.96,'hutongstore','clare1584','claresarahuk@yahoo.co.uk','clare bishop','1 sandy lane<br>bushbury','Wolverhampton','West Midlands','UNITED KINGDOM','wv109de','01922440565','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 13:47:59',0,NULL,3,1,11,1,NULL,'hutongstore'),(26402,859940338002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',2,'AB3329',97.98,'hermeshine','serj161189','serj1989@mail.ru','Gerashchenko Sergey Mihaylovich','Ulica. Stadionnaya, dom 7/1, kv.54','UFA','Bashkortostan','RUSSIAN FEDERATION','450069','+79876237676','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 13:52:19',0,NULL,3,1,5,1,'CP236401995CN\r ','hermeshine'),(26403,884382405017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.9,'photographyacc','b.harding','beharding@optusnet.com.au','Brett Harding','3 Matthew Close<br>St Ives','Sydney','New South Wales','AUSTRALIA','2075','0415658871','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-21 14:03:37',0,NULL,3,1,11,1,NULL,'photographyacc'),(26404,860932865002,120757472199,'1500w Studio Bulb Continuous Lighting Kit 3x6m backdrop',1,'AKT074',310,'hermeshine','danoveolsen1965','post@nettkompis.no','Dan Ove Olsen','Postboks 5','Grua','NORWAY','NORWAY','2717','92065988','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 14:08:55',0,NULL,3,1,12,1,'3125999601 ','hermeshine\r欧标\r客户要发DHL，还没付款\r新地址\rDan Ove Olsen\rGruaenga 16\r2742 GRUA\rNORWAY\r已付运费\r申报$310\r泡重16.8kg\r实重12.1kg'),(26405,860937045002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ezitox','ezitox@gmail.com','Ezequiel González Herrera','Calle Dr. Allart. nº 16, 3E','Santa Cruz de Tenerife','Canarias','SPAIN','38003','639308446','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-21 14:25:49',0,NULL,3,1,3,1,'RA184595445CN\r ','hermeshine'),(26406,816127884001,110464642429,'Male to Male 58mm-58mm Macro Reverse Ring reversing',1,'AA1213',2.99,'hermeshine','hai66609','hai666_83@hotmail.com','Kee Ching Hai','Blk733 Jurong West St73 #11-22','default','','SINGAPORE','640733','92470006','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 14:35:41',0,NULL,3,1,11,1,NULL,'hermeshine'),(26407,970608121015,250746713585,'58mm Graduated Neutral Density Filter Gradual Grey 58',1,'AA3317',4.8,'hutongstore','trllth08','trllth@yahoo.com','Christine Oeurn AMS','OC03K Orwell Close<br>University of East Anglia','Norwich','Norfolk','UNITED KINGDOM','NR47TJ','(075) 916-8272 ext.: 3','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 14:58:00',0,NULL,3,1,11,1,NULL,'hutongstore'),(26408,950445005016,260919755943,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',3,'AA1312',3.6,'hutongstore','eduardocoradi','marianapintescu@yahoo.co.uk','eduardo  coradi','144b<br>colney hatch lane','london','London','UNITED KINGDOM','n10 1er','07551880972','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 15:12:32',0,NULL,3,1,11,1,NULL,'hutongstore'),(26409,970621315015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','pusllab','martino62@tiscali.co.uk','martin harding','100 cavendish road<br>patchway','bristol','Avon','UNITED KINGDOM','bs345hh','07976551230','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 15:26:56',0,NULL,3,0,3,1,'RA184595454CN\r ','hutongstore\r3XL  已入库'),(26410,860959360002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','omar98ls1','omarrakeen@hotmail.com','Omar Rakeen','Sanaiya road','al ain','','UNITED ARAB EMIRATES','16847','00971503379452','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 15:27:19',0,NULL,3,1,3,1,'RA184595321CN\r ','hermeshine\r新地址\rOmar Rakeen \rAhmed Al Ain City 16847 \rUnited Arab Emirates.'),(26411,860965566002,120813020985,'New 115w x 4 Daylight Bulb for Photograph​y 5500K Light 220v 110v',1,'AKT069',57.99,'hermeshine','horst9480','horst.idler@alcatel.de','Horst Idler','Korntaler Str.96','Stuttgart','','GERMANY','70439','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-21 15:45:14',0,NULL,3,1,3,1,'RA184595366CN\r ','hermeshine'),(26412,640029158004,140722305812,'2 Umbrellas 2m Light Stand  Flash/Umbrella mount bracket for Portable Speedlight',1,'AKT100',55,'hermeshine','laura3720','lolly690@hotmail.com','Richard Davies','C/Belgica, 18<br>Villa Violet, Mojacar Playa','Mojacar','Andalucía Ceuta y Melilla','SPAIN','04638','663006390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 17:24:45',0,NULL,3,1,3,1,'RA184595370CN\r ','hermeshine'),(26413,970690780015,250732315196,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',24.99,'hutongstore','martin14noble','martin@massivearts.co.uk','Martin Smith','13 Longden Gardens','Shrewsbury','Shropshire','UNITED KINGDOM','SY3 7EG','01743241202','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 17:38:43',0,NULL,3,1,3,1,'RA184595560CN\r ','hutongstore'),(26414,861016806002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','martingrieco','martinx1977@gmail.com','Martin grieco','gorlero y calle 30, local 002 Edificio Santos Dumont. Aerolíneas<br>punta del este','maldonado','maldonado','URUGUAY','20100','598 99216035','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 17:44:57',0,NULL,3,0,3,1,'RA184595539CN\r ','hermeshine\r1.6*3  绿色'),(26415,816217052001,110532006804,'52mm Lens lenscap for Nikon D40 D60 D80 D90 D200 D300s',1,'AA1305',2.6,'hermeshine','allen198939','sunjian198939@gmail.com','Allen Sun','228 Jennings Rd','Fairfield','CT','UNITED STATES','06825-4731','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 18:21:48',0,NULL,3,1,1,1,'LK238225940CN ','hermeshine'),(26416,861068628002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','old_grimm_guy','rjohnso1@elp.rr.com','Roy Johnson c/o SAIC','7400 Viscount Blvd<br>Ste 220','El Paso','TX','UNITED STATES','79925-4851','(915) 449-4863','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 19:22:04',0,NULL,3,1,17,0,'LK238212495CN ','hermeshine'),(26417,861069777002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','old_grimm_guy','rjohnso1@elp.rr.com','Roy Johnson c/o SAIC','7400 Viscount Blvd<br>Ste 220','El Paso','TX','UNITED STATES','79925-4851','(915) 449-4863','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-21 19:24:23',0,NULL,3,1,1,1,'LK238212495CN ','hermeshine\r无牌方镜 渐变日落   1\r无牌方镜 渐变蓝    1'),(26418,816255237001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','andyvanddetta','andyvandetta@hotmail.com','AbdulRedha Ahmed','C/o Natalie Hollyman HR Manager Alghanim Industries<br>Ext 3204 PF12920 P O Box 223 Safat 13003','Kuwait','','KUWAIT','965','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-21 19:32:14',0,NULL,3,1,3,1,'RA184595542CN\r ','hermeshine\rXL 已入库'),(26419,970777712015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','pantaleofragale','leofragale@yahoo.co.uk','Mr Leo Fragale','The Orchards<br>22 Coalbeach Lane','Surfleet','Lincolnshire','UNITED KINGDOM','pe11 4de','01775680799','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-21 19:43:58',0,NULL,3,1,3,1,'RA184595556CN\r ','hutongstore'),(26420,950612897016,260660056652,'New Padded shoulder Neck Strap for Canon 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','vitoriasetubal','candeias_marco@hotmail.com','Marco Candeias','Praceta Pêro Vaz de Caminha<br>Nº 1 - 1º A','2900-798 SETÚBAL','SETÚBAL','PORTUGAL','2900-798','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-21 19:55:50',0,NULL,3,1,11,1,NULL,'hutongstore'),(26421,816305771001,110417007509,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',2.48,'hermeshine','revoltex_idrak','revoltex@gmail.com','Emil Ismailov','Kara Karaev ave. 114, apt. 48','Baku','','AZERBAIJAN','AZ1119','+99412 3743138','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:01:32',0,NULL,3,1,11,1,NULL,'hermeshine'),(26422,816257788001,110529627228,'Pro Spanner Wrench Set 2 for repair tool lens openning',1,'AA2401',33.5,'hermeshine','shawnmuntz','danbookem@hotmail.com','Shawn Randall','601 Grey Street','Regina','SK','CANADA','S4T5G4','(306) 775-3354','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-21 21:07:57',0,NULL,3,1,3,1,'RA184595352CN\r ','hermeshine'),(26423,861135950002,120705757607,'52mm 52 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3301',3.25,'hermeshine','metekatirci','mete@hobbytime.com.tr','METE KATRCI','Hilal Mah.716 sok<br>No 5-A Cankaya','ANKARA','','TURKEY','06550','+90 312 438 40 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:21:12',0,NULL,3,1,17,0,'RA184595264CN ','hermeshine'),(26424,816317155001,110532006793,'52mm CPL Circular Polarizing Filter 52 CPL Green.L ',1,'AA3308',5.95,'hermeshine','metekatirci','mete@hobbytime.com.tr','METE KATRCI','Hilal Mah.716 sok<br>No 5-A Cankaya','ANKARA','','TURKEY','06550','+90 312 438 40 31','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:21:13',0,NULL,3,1,3,1,'RA184595264CN ','hermeshine\r绿叶 UV  52mm  1\r绿叶 CPL  52mm  1\r客户要挂号，已付款'),(26425,970849598015,250971426000,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',9.99,'hutongstore','arys2008','ryszardzeglen@op.pl','Ryszard Zeglen','89 Jumples Court<br>Mixenden','Halifax','West Yorkshire','UNITED KINGDOM','HX2 8NT','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-21 21:23:27',0,NULL,3,1,11,1,NULL,'hutongstore'),(26426,861145767002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',2,'AD1198',65.98,'hermeshine','colibrigirl71','gauchon.celine@wanadoo.fr','Céline GAUCHON','12 impasse Jacquart','Gergy','Bourgogne','FRANCE','71590','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 21:42:07',0,NULL,3,1,3,1,'RA184595468CN\r ','hermeshine'),(26427,861155147002,120501738235,'Flash Shoe/Umbrella Holder Bracket Mount Light Stand B',1,'AB2301',8.2,'hermeshine','lazm27619006','mala.maja@hotmail.com','Marija Lazarevic','2320 rue ward app.205','saint-laurent','QC','CANADA','H4M 2V5','(438) 380-9065','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-21 22:07:29',0,NULL,3,1,11,1,NULL,'hermeshine'),(26428,861158920002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','dcov9879','d.coviensky@rogers.com','David Coviensky','1236 Eldorado Ave','Oshawa','ON','CANADA','L1K 1G2','(905) 240-4663','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-21 22:12:44',0,NULL,3,0,3,1,'RA184595471CN\r ','hermeshine\r2XL 已入库'),(26429,944492348016,260814597510,'New Photo Studio Light Stand Umbrella Bulb Socket Set',1,'AKT061',22.99,'hutongstore','missjshopaholic87','missj.shopaholic@gmail.com','Jessica Melliza','102/55 Victoria Harbour','Docklands','Victoria','AUSTRALIA','3008','','PayPalPaymentInProcess','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','0000-00-00 00:00:00',0,NULL,4,1,3,0,NULL,'hutongstore\r电子账单'),(26430,970911677015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','shus9559','shotbyshahed@gmail.com','Shahed Hussain','37 Gowland Avenue<br>Fenham','Newcastle Upon Tyne','Tyne and Wear','UNITED KINGDOM','NE4 9NE','07854850157','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-21 23:22:04',0,NULL,3,1,3,1,'RA184595485CN\r ','hutongstore'),(26431,970916271015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','phill1928','phillip.g.davies@sky.com','Phillip Davies','9 Morien Crescent','Pontypridd','Rhondda Cynon Taff','UNITED KINGDOM','CF37 5RB','07788967206','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-21 23:32:39',0,NULL,3,1,3,1,'RA184595499CN\r ','hutongstore'),(26432,823563854018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.43,'photographyacc','muffyjon','muffyjon@hotmail.com','John Lubajo','1/71 Corbel Street<br>Shelley','Perth','Western Australia','AUSTRALIA','6148','61424191016','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 00:01:50',0,NULL,3,1,11,1,NULL,'photographyacc'),(26433,861207077002,120535023292,'New Rainproof & Warm Protector D300s D700 D90 550D 7D',1,'AA3102',19.99,'hermeshine','jerchan1962','jdconstructionjd4@gmail.com','John Dallaire','931 11eme Ave','Fabreville,Laval','QC','CANADA','h7r 4m8','(514) 212-0291','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 00:27:26',0,NULL,3,1,11,1,NULL,'hermeshine'),(26434,861213566002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','christiancameras','lovechoirmusic@hotmail.com','Christian Franco','Palacios Del Prado, Calle Pacifico , Casa I-103<br>Palacios Del Prado , Calle Pacifico . Casa I-103','Juana Diaz','PR','PUERTO RICO','00795','787-709-5247','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 00:48:09',0,NULL,3,1,3,1,'RA184595383CN\r ','hermeshine'),(26435,8881332378597813,111,'80cm 8 角柔光布',1,'',0,'hermeshine','wmphotostudio','wagnermenezesfotografo@gmail.com','Wagner Tadeu Menezes','Rua: Demétrio Ghirardello, 249<br>Jardim Las Vegas','Santo andré','São Paulo','BRAZIL','09182-520','0551149723715',NULL,NULL,NULL,'2012-03-22 01:09:57',0,NULL,3,0,3,1,'RA184595573CN\r ',NULL),(26436,8881332378741662,111,'canon 反接环  58mm ',1,'AA1208',0,'hermeshine','csigabiiiga','sunshine_@freemail.hu','Gabriella Olláry','Galagonyás út 2.','Esztergom','Komarom-Esztergom megye','HUNGARY','2500','+36202521512',NULL,NULL,NULL,'2012-03-22 01:12:21',0,NULL,3,1,3,1,'RA184595587CN\r ',NULL),(26437,816400246001,110320736776,'52mm 52 Rubber 3in1 Collapsible Lens Hood  Canon Nikon',1,'AB1301',3.34,'hermeshine','menelaossynthesis','sykovelis@gmail.com','Menelaos Sykovelis','Kavasila 8','Ioannina','','GREECE','45444','+306936210210','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 01:12:50',0,NULL,3,1,11,1,NULL,'hermeshine'),(26438,816401028001,110733723623,'Universal two-wheel Light Stand Double Dual Grip Clamp',3,'AD1179',47.7,'hermeshine','rene_chile','rgalleguillosz@gmail.com','RENE GALLEGUILLOS','PRIMERA TRANVERSAL 5875. DEPTO 1006. SAN MIGUEL','SANTIAGO','SANTIAGO','CHILE','8920575','62476032','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 01:17:46',0,NULL,3,1,3,1,'RA184595658CN\r ','hermeshine'),(26439,8881332380899446,111,'canon 单肩包 A1 ',1,'AO0029',0,'aliexpress','1006882732','huynht02@hotmail.com','Tony','10 Timbercrest Road, Thornlie','Perth','Western Australia','AUSTRALIA','6108','+61 08 93490893',NULL,NULL,NULL,'2012-03-22 01:48:19',0,NULL,3,1,3,1,'RA184595644CN ','先给个单号 \rRA184595644CN'),(26440,861233957002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',46.99,'hermeshine','reynaldolouise2012','reynaldolouise@gmail.com','reynaldo louise','Pedro Saenz de zumaran 5140','montevideo','montevideo','URUGUAY','12100','094121265','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 01:55:39',0,NULL,4,1,3,0,NULL,'hermeshine\r客户已经付过$7运费，\r但是还需要再加$6。\r已发信\r'),(26441,8881332381368789,111,'Photo Studio Light Stand Heavy Duty Clamp Copper head - Wholesale/ Retail [AE3102]',1,'AE3102',9.99,'aliexpress','1007553410','kagerasimov@gmail.com','Konstantin Gerasimov','Lackova 4/1 81','Zhukovsky','Moscow region','RUSSIAN FEDERATION','140188','+7 498 4803321',NULL,NULL,NULL,'2012-03-22 01:56:08',0,NULL,3,1,17,0,'RA184596018CN\r ',NULL),(26442,8881332381421643,111,'C Clip Clamp Holder Mount for Studio Backdrop Camera - Wholesale/ Retail [AE3104]',1,'AC3104',13.99,'aliexpress','1007553409','kagerasimov@gmail.com','Konstantin Gerasimov','Lackova 4/1 81','Zhukovsky','Moscow region','RUSSIAN FEDERATION','140188','+7 498 4803321',NULL,NULL,NULL,'2012-03-22 01:57:01',0,NULL,3,1,17,0,'RA184596018CN\r ',NULL),(26443,8881332381482067,111,'New Hairlight photostudio boom arm without stand - Wholesale/ Retail [AE3101]',1,'AE3101',36.99,'aliexpress','1007553408','kagerasimov@gmail.com','Konstantin Gerasimov','Lackova 4/1 81','Zhukovsky','Moscow region','RUSSIAN FEDERATION','140188','+7 498 4803321',NULL,NULL,NULL,'2012-03-22 01:58:02',0,NULL,3,1,3,1,'RA184596018CN\r ','速卖通\r大力夹  1 \r斜臂   1\rc型夹   1'),(26444,8881332381687180,111,'24\" 60 x 60cm Photo Studio Shooting Tent Light Cube Box - 4 backgrounds included - Wholesale/ Retail [AC2403]',1,'AC2403',33.99,'aliexpress','1007559287','123hotmail.com','Ariba Nizametdinova','Lavochkina 34 kv.36','Moscow','Russian Federation','RUSSIAN FEDERATION','125581','+7926 211 7045',NULL,NULL,NULL,'2012-03-22 02:01:27',0,NULL,3,1,17,0,'RA184596154CN\r ',NULL),(26445,8881332381738116,111,'Black/Whilte Reflection board 20X30cm Reflection effect - Wholesale/ Retail [AB1201]',1,'AB1201',15.99,'aliexpress','1007559286','123hotmail.com','Ariba Nizametdinova','Lavochkina 34 kv.36','Moscow','Russian Federation','RUSSIAN FEDERATION','125581','+7926 211 7045',NULL,NULL,NULL,'2012-03-22 02:02:18',0,NULL,3,1,3,1,'RA184596154CN\r ','速卖通\r圆形柔光棚 60cm   1 \r倒影板（白黑）  1'),(26446,861241710002,120784883541,'New Studio Photo Video Continuous lighting 5 E27 Sockets Head with 60x90 Softbox',1,'AD1191',59.99,'hermeshine','prayz2jzus','portraitcreations@live.com','brad reynolds','RR 2 Box 146','tower hill','IL','UNITED STATES','62571-9654','(217) 565-2470','NoPaymentFailure','CheckoutComplete','EconomyShippingFromOutsideUS','2012-03-22 02:21:10',0,NULL,3,1,3,1,'RA184595595CN\r ','hermeshine\r澳转美标'),(26447,884804862017,270759690263,'New Foto Studio Light Kit Boom Arm Stand Tripod no bulb',1,'AKT003',68,'photographyacc','kiahstephens09','halonp@hotmail.com','kiah stephens','5 little brunswick st','Orange','New South Wales','AUSTRALIA','2800','','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-22 02:44:53',0,NULL,3,1,4,1,'YW867611582CN\r ','photographyacc\r澳标'),(26448,8881332385565669,111,'2个单灯头，一个灯架，两个反光伞',1,'',0,'hutongstore','sukidog086','fiatritmo@yahoo.ie','colm coogan','67 kilgarron park<br>enniskerry','enniskerry','Wicklow','IRELAND','01','0868478291',NULL,NULL,NULL,'2012-03-22 03:06:05',0,NULL,3,0,3,1,'RA184595600CN\r ','已入库 '),(26449,861256158002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','criszudo','dominguescristian@me.com','Cristian Domingues','Rua Marcondesia 114, Casa 07<br>114 casa 07','Sao Paulo','SP','BRAZIL','04645-040','011 93027683','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 03:14:45',0,NULL,3,1,17,0,'RA184595525CN\r ','hermeshine'),(26450,861255592002,120824638021,'Brand New Lens Repair Tool Stainless Steel Spanner Wrench with swap-able tips',1,'AD1207',40,'hermeshine','4912djg','dgillespie@shawcable.com','Derek Gillespie','4912 Dalham Cres NW','Calgary','AB','CANADA','T3A 1L7','(403) 618-7450','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-22 03:15:47',0,NULL,3,1,3,1,'RA184595511CN\r ','hermeshine'),(26451,861264308002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','criszudo','dominguescristian@me.com','Cristian Domingues','Rua Marcondesia 114, Casa 07<br>114 casa 07','Sao Paulo','SP','BRAZIL','04645-040','011 93027683','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 03:51:04',0,NULL,3,1,3,1,'RA184595525CN\r ','hermeshine\r伞式柔光箱 60×90cm   1\r伞式柔光箱 80cm 8角    1'),(26452,816462162001,110571618476,'Light Soft Box for Studio Strobes 60cm x 60cm 4 outputs',2,'AE2201',75.96,'hermeshine','pan_eng','pan_eng@hotmail.com','Panya Jampatong','69/22 Soi Pradiphat15 Pradiphat Road<br>Samsennai','Phayathai','Bangkok','THAILAND','10400','01-8244584','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 05:54:06',0,NULL,3,1,6,1,'EE667839138CN\r ','hermeshine\r英标'),(26453,861028483002,120508253684,'YONGNUO 8ft I-TTL Off-Camera Flash Sync Cord for Nikon',1,'AB3320',25.99,'hermeshine','michaelf2940','mikefalzon@hotmail.com','Michael Falzon','Id-Dwejra<br>Palm Street','Tarxien','','MALTA','TXN 2245','+35621660834','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 05:54:19',0,NULL,3,1,3,1,'RA184595397CN\r ','hermeshine'),(26454,861288691002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',32.99,'hermeshine','onarom23','dalemorano@hotmail.com','Dale Morano','5260 Goldmar Dr','Irondale','AL','UNITED STATES','35210','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 06:14:12',0,NULL,3,1,3,1,'RA184595406CN\r ','hermeshine'),(26455,8881332396894498,111,'1.6*3  白色布 ，一个灯架底座',1,'',0,'photographyacc','andyb2001au','acommon@y7mail.com','Andrea L Common','17 Corfu Pass','Port Kennedy','Western Australia','AUSTRALIA','6172','0895246669',NULL,NULL,NULL,'2012-03-22 06:14:54',0,NULL,3,0,3,1,'RA184595318CN\r ',NULL),(26456,8881332397370304,111,'Free shipping & Tracking # - New Portable 60cm 24\"x24\" Soft Box Softbox for Flash - Whole/Retail AB3329',1,'AB3329',48.99,'aliexpress','1007548559 ','cjcool@yandex.ru','Alexandr Kardakov','Halturina 33-55','Kemerovo','Kemerovskaya','RUSSIAN FEDERATION','650068','+7 905 9003884',NULL,NULL,NULL,'2012-03-22 06:22:50',0,NULL,3,1,3,1,'RA184596021CN\r ','速卖通 '),(26457,8881332397510434,111,'CAPA Double Quick Neck Shoulder Strap - Whole sale / Retail [AD1111]',1,'AD1111',33.99,'aliexpress','1007568242',' julieslavin@gmail.com','julie slavin','29 david street','Old Bar','New South Wales','AUSTRALIA','2430','+61 02 65536626',NULL,NULL,NULL,'2012-03-22 06:25:10',0,NULL,3,1,3,1,'RA184596199CN\r ','速卖通 '),(26458,816469392001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','sticksea','sticksea@hotmail.com','Eduardo Palomares','1075 Adams Ave','El Centro','CA','UNITED STATES','92243-2005','(760) 455-1808','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-22 06:39:28',0,NULL,3,1,1,1,'LK238438851CN\r ','hermeshine'),(26459,861291470002,120642594210,'New Portable 60cm 24\"x24\" Soft Box Softbox for Flash ',1,'AB3329',48.99,'hermeshine','k-l-e-c-h','klech@mail.ru','Sergey Krasnikov','Shelgunova st. 27 app. 16','St. Petersburg','RU','RUSSIAN FEDERATION','192174','79219779151','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 06:39:49',0,NULL,3,1,3,1,'RA184595335CN\r ','hermeshine'),(26460,971046102015,250846996647,'Pro Video Camera Tripod Action EI-717AH Fluid Drag Head',1,'AE2101',64.9,'hutongstore','vbigdan_99','vladimir.bigdan@gmail.com','Vladimir Bigdan','52 Mark Lane','Kangaroo Point','Queensland','AUSTRALIA','4169','0733930439','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 06:58:14',0,NULL,1,1,4,1,'YW867611615CN\r ','hutongstore'),(26461,861298300002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','xtremeelement','xtremeelement@msn.com','Brandon Downhour','1609 Tattenham Way','Orlando','FL','UNITED STATES','32837-6513','(407) 859-3452','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 07:10:04',0,NULL,3,1,3,1,'RA184595349CN\r ','hermeshine'),(26462,8881332401590385,111,'15个灯架',1,'',0,'hutongstore','sorimp','leif@sorvikimport.com','Sorvik Import','Bremsnes<br>Røsand','Averoy','Averoy','NORWAY','6530','04771511684',NULL,NULL,NULL,'2012-03-22 07:33:10',0,NULL,3,0,5,1,'CP236402015CN\r ','已入库 \r申报$42'),(26463,816480609001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','severinkaradzhov12','cccp0887@gmail.com','severin karadzhov','61A block, floor 5, apt.511 Studentski grad distr.','Sofia','Bulgaria/Sofia/Sofia','BULGARIA','1700','0883453927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 07:39:02',0,NULL,3,1,17,0,NULL,'hermeshine'),(26464,816480734001,110717757923,'6 Pockets Black Filter Wallet Case Fits UV CPL MCUV ND',1,'AE1203',5,'hermeshine','rkucinskis2296','rkucinskis@gmail.com','Rolands Kucinskis','Rīgas iela 28-2','Daugavpils','Daugavpils','LATVIA','LV-5400','+37126173390','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 07:40:23',0,NULL,3,1,11,1,NULL,'hermeshine'),(26465,816481186001,110591560364,'New 82mm ring adapter replacement for cokin P series',1,'AA2222',2.18,'hermeshine','severinkaradzhov12','cccp0887@gmail.com','severin karadzhov','61A block, floor 5, apt.511 Studentski grad distr.','Sofia','Bulgaria/Sofia/Sofia','BULGARIA','1700','0883453927','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 07:41:47',0,NULL,1,1,11,1,NULL,'hermeshine\r无牌方镜 渐变灰 （nd8）  1\r方形滤镜接口环 82mm  1'),(26466,861317000002,120448755595,'Remote Cord Shutter Release for Canon EOS = RS-80N',1,'AA3211',3.98,'hermeshine','rianzawhk','leovisser70@gmail.com','Leo Visser','PO Box 24369<br>Windhoek','Windhoek','Namibia','NAMIBIA','9000','00264812226162','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 08:41:53',0,NULL,3,1,11,1,NULL,'hermeshine'),(26467,8881332406025667,111,'New 100% Genuine Lenspen LP-1 Lens Cleaning Pen Brush - Wholesale/ Retail [AA1310]',1,'AA1310',6.99,'aliexpress','1007570507 ','norbulus@inbox.ru','Igor Dresvyannikov','Sovetskay st, d 22a kv 101','Izhevsk','Russia','RUSSIAN FEDERATION','426076','+7 3412 636477',NULL,NULL,NULL,'2012-03-22 08:47:05',0,NULL,3,1,3,1,'RA184596171CN ','速卖通 '),(26468,884882681017,270860550772,'New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',9.9,'photographyacc','kevlozza','kevlaur1@optusnet.com.au','Kevin Russell','11 Blyton Crescent','Sunbury','Victoria','AUSTRALIA','3429','0397446140','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 08:48:02',0,NULL,3,1,11,1,NULL,'photographyacc'),(26469,950908481016,260711705712,'77mm Graduated Neutral Density Filter Gradual Grey 77',1,'AA3321',5.8,'hutongstore','cornmer','ben.bask@gmail.com','Sergei Bender','81 Cornmow Drive','London','London','UNITED KINGDOM','NW10 1BB','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 09:12:17',0,NULL,3,1,11,1,NULL,'hutongstore'),(26470,884897558017,270747041767,'New 58mm Snap-on Front Lens Cap for Canon 58mm lenscap',1,'AA1301',2.5,'photographyacc','lennyau','len.willemsen46@bigpond.com','Len Willemsen','P O Box 10071','PINES FOREST','Victoria','AUSTRALIA','3200','61413741444','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 09:42:18',0,NULL,3,1,11,1,NULL,'photographyacc'),(26471,860789810002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',3,'AD1224',10.5,'hermeshine','orag_999','orag999@gmail.com','Mr_Panuwat  Jormputsa','55 M.8 Tambon Rangkayai','Phimai','Nakhon Ratchasima','THAILAND','30110','089-2804352','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 09:52:21',0,NULL,3,1,11,1,NULL,'hermeshine'),(26472,861342693002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','magal_2007','magal53@hotmail.com','Antonio Magalhaes','Rua do Centro 75','São Mamede de Infesta','São Mamede de Infesta','PORTUGAL','4465-071','351914958784','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 10:29:13',0,NULL,3,0,3,1,'RA184596137CN\r ','hermeshine\r1.6*3  蓝色'),(26473,861341542002,120639724081,'Continuous Lighting kit Red head 800w with bulb+stand ',1,'AKT060',110,'hermeshine','meurice2755','burnhippieburn@gmail.com','Meurice Gautier','14 rue Neuve','Gruson','Nord-Pas-de-Calais','FRANCE','59152','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 10:30:38',0,NULL,3,1,4,1,'YW867611626CN\r ','hermeshine\r欧标'),(26474,816520378001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','ad**ad','donwillcomputers@gmail.com','Bill Onibokun','10441 118th St','SOUTH RICHMOND HILL','NY','UNITED STATES','11419-2705','(718) 704-4921','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-22 10:35:38',0,NULL,3,1,1,1,'LK238953585CN ','hermeshine\rSouth Richmond Hill, (Queens), New York\r(718)704-4921'),(26475,823732164018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',74.99,'photographyacc','jonotto7','jon.otto@hotmail.com','Jonathan Otto','16 Frith Ave','Normanhurst','New South Wales','AUSTRALIA','2076','0405205509','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 11:32:28',0,NULL,3,1,3,1,'RA184595193CN\r ','photographyacc'),(26476,816536233001,110489283203,'New Hairlight Heavy Duty photostudio boom arm and stand',1,'AKT030',52.99,'hermeshine','vahanpas','audiophile666@gmail.com','Pasi Vähänen','Ilvesjärväenkuja 5 B 11','Hämeenlinna','Kanta-Häme','FINLAND','13500','+358445278861','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-22 11:35:19',0,NULL,3,1,3,1,'RA184595180CN\r ','hermeshine'),(26477,971133880015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',2,'AE3301',15.6,'hutongstore','will_mcd03','will_mcd03@hotmail.com','w mdonald','16<br>pannier mews','bideford','Devon','UNITED KINGDOM','ex39 2dt','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 11:46:36',0,NULL,3,1,11,1,NULL,'hutongstore'),(26478,861367893002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',3,'AD1169',20.64,'hermeshine','thelastdrive','gavalasg73@yahoo.gr','George Gavalas','Panepistimiou Kritis 9','Rethymno','','GREECE','74100','00302831020818','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 12:03:50',0,NULL,3,1,11,1,NULL,'hermeshine'),(26479,816555410001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','ee0ne','0nly@bk.ru','Marek Miglinski','Kirsipuu pst. 47','Maardu','Harjumaa','ESTONIA','74117','(372) 535 50000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 12:43:53',0,NULL,1,1,11,1,NULL,'hermeshine'),(26480,816567717001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','homezd8000','andrew_tihi@yahoo.com','Tihi Andrei','Calle Belice , Nr  1','Roquetas de Mar','Andalucía Ceuta y Melilla','SPAIN','04740','642878685','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 13:22:49',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(26481,971182107015,250939065731,'Brand New Original Nikon Photo Vest for D60 D80 D90 D5000 D700 100% Cotton',1,'AA2111',29.9,'hutongstore','juandediosjuande45','juandediosortizbea@hotmail.com','Juan de Dios Ortiz Bea','Avda. Cno. de las Cruces Nº 11   1º Izquierda','JAEN','Andalucía Ceuta y Melilla','SPAIN','23003','676130803','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 13:52:05',0,NULL,3,0,3,1,'RA184596145CN\r ','hutongstore\r2XL  \r库里没找到2XL '),(26482,971196524015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','treasmem','temp2@treasmemphotography.com','Chris Mitchell','47 Yarana St','FTG','Victoria','AUSTRALIA','3156','0397580501','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 14:27:48',0,NULL,3,1,3,1,'RA184596035CN\r ','hutongstore'),(26483,860403999002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','bayoto','oto@esquinadelmundo.com','jesus perez marabel','C Tardio 12 3','Badajoz','Extremadura','SPAIN','06001','629964135','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 15:14:14',0,NULL,3,1,3,1,'RA184595233CN\r ','hermeshine'),(26484,816612598001,110419742832,'Green.L 77mm Neutral Density ND8 Filter ND 8 77',1,'AE2314',0,'hermeshine','manray75shaul','shaulelal@gmail.com','shaul hengaly','doar na emek sorek','kibutz hulda','','ISRAEL','76842','','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,3,1,3,1,'RA184595247CN\r ','hermeshine\r绿叶 ND8  77mm  1\r绿叶77MM ND4    1\r3m通用横杆（4节）  1\r已入库'),(26485,861449582002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','slavjan2','zlobin@mail.ru','Vyacheslav Zlobin','Teatralnaya, 3a - 42','Novosibirsk','','RUSSIAN FEDERATION','630084','8-913-94-99-888','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 16:17:24',0,NULL,3,1,3,1,'RA184596052CN\r ','hermeshine'),(26486,861455488002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 16:38:11',0,NULL,3,1,3,1,'RA184596097CN\r ','hermeshine'),(26487,951086327016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','rossistrading','rossistravelling@yahoo.com','Ross Alexander','20 Laburnum Close','Bridgwater','Somerset','UNITED KINGDOM','TA6 4EN','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-22 16:51:11',0,NULL,3,1,3,1,'RA184596106CN\r ','hutongstore'),(26488,885045858017,270748971843,'New 52mm Macro Reverse Adapter Ring for Canon EF Mount',1,'AA1207',4.85,'photographyacc','henry.tan','henfry83@hotmail.com','Henry Tan','55  Belmore  Bend','Aubin Grove','Western Australia','AUSTRALIA','6164','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-22 16:53:22',0,NULL,3,1,11,1,NULL,'photographyacc'),(26489,971305975015,250939065664,'New HD DV Stereo Microphone for Canon 7D 60D 5D II 550D',1,'AA1215',22,'hutongstore','dustymck','dustymck@yahoo.com','Jonathan McKeon','515 Nottingham Ct','Alpharetta','GA','UNITED STATES','30005-4494','(404) 432-2567','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 18:19:13',0,NULL,3,1,1,1,'LK238943101CN ','hutongstore'),(26490,816678725001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',25.99,'hermeshine','dima2714-il','dima2714@gmail.com','dmitry dobrodiy','harav levi 27/14','bat yam','','ISRAEL','59621',' 0545841612','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 18:26:24',0,NULL,3,1,3,1,'RA184595255CN\r ','hermeshine'),(26491,861507266002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','tmgerhard','toddgerhard@yahoo.com','todd gerhard','135 n 7th st','olean','NY','UNITED STATES','14760-2309','(716) 244-1354','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-22 18:32:29',0,NULL,3,1,3,1,'RA184595162CN\r ','hermeshine'),(26492,816687149001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','amir.elti','amir.eltahan@gmail.com','Amir Eltahan','Miryam 6','Ramat Gan','','ISRAEL','52470','0545984557','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 18:42:58',0,NULL,3,0,11,1,NULL,'hermeshine\r1.6*2.1  黑色'),(26493,816692172001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','sztufi','sz_gery@yahoo.com','Sztuchlak Gergo','str:Louis Pasteur<br>nr: 42/A ap:14','Oradea','Bihor','ROMANIA','410154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 18:53:36',0,NULL,3,1,11,1,NULL,'hermeshine'),(26494,971353489015,250692241732,'New 55mm 3-Stage Rubber Lens Hood for Sony DT18-55mm ',2,'AB1302',4.52,'hutongstore','10.pops','cawthorne53@sky.com','Paul Cawthorne','7 Ambleside Gardens<br>Gunthorpe','Peterborough','Cambridgeshire','UNITED KINGDOM','PE4 7ZY','01733322677','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-22 19:19:05',0,NULL,3,1,11,1,NULL,'hutongstore'),(26495,861530069002,120526192167,'NEW 58mm Snap-on Front Lens Cap for Canon 58 Lenscap',3,'AA1301',7.8,'hermeshine','hgordondavisiv','gordondavis4@gmail.com','Henry G. Davis IV','307A Nan St','Valdosta','GA','UNITED STATES','31601-5137','(229) 300-6291','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-22 19:16:33',0,NULL,3,1,1,1,'LK238961286CN ','hermeshine'),(26496,861556127002,120772022113,'Boom Arm+Stand+Softbox kit for SpeedLight ex580 sb900',1,'AKT084',98,'hermeshine','ripp7938','rushlakeripp@hotmail.com','Lisa Ripp','49629 Alpine Ave N','Stanchfield','MN','UNITED STATES','55080-5214','(320) 266-6097','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-22 20:04:47',0,NULL,3,1,4,1,'YW867611630CN\r ','hermeshine'),(26497,634449382003,130494875280,'Manual Background Support System-3-ROLLER WALL-MOUNTED',1,'AD1147',112,'hermeshine','losmaniac1','martin.overaa@gmail.com','Martin Overaa','Furulia 17<br>8050 Tverlandet','Bodø','Nordland','NORWAY','8050','(47) 97645146','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 20:18:07',0,NULL,3,1,5,1,'CP236402032CN\r ','hermeshine'),(26498,816761413001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','wriv8112','w_rivera2007@yahoo.com','Wigberto Rivera','PO Box 230','Bajadero','PR','UNITED STATES','00616-0230','(787) 380-0904','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-22 21:01:35',0,NULL,3,1,1,1,'LK238974112CN ','hermeshine'),(26499,951248792016,260850296358,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\" 150cm x 200 cm',1,'AD1182',46,'hutongstore','claudelee1','claudesadik@gmail.com','Claude Lee Sadik','44 Hathersage Road<br>Victoria Point Block 3 Flat 90A','Manchester','Greater Manchester','UNITED KINGDOM','M130EH',' 07549526566','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-22 21:05:18',0,NULL,3,1,3,1,'RA184595202CN\r ','hutongstore'),(26500,816769694001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','christoffertalvis','christoffer.talvis@hotmail.com','Christoffer Talvis','Frejgatan 3C','Katrineholm','Södermanland','SWEDEN','64137','+46707716191','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-22 21:17:23',0,NULL,3,1,11,1,NULL,'hermeshine'),(26501,969935885015,250600317133,'NEW Flash Diffuser for Nikon SB-800 SB800 YN460 YN465',2,'AB3330',23.16,'hutongstore','xxwannabexx','grandy90@web.de','Thomas Stibenz','Lorettostraße 31','Freiburg','','GERMANY','79100','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-22 21:43:46',0,NULL,3,1,3,1,'RA184595176CN\r ','hutongstore\r肥皂盒 柔光罩   sb800 sb600  2\r伞式柔光箱 80cm 8角    1\r已入库'),(26502,861669604002,120536801441,'JueYing Lambency Flash Diffuser for 580EX(II) 550EX P4',1,'AB3312',18,'hermeshine','11dreis','detalhesdenise@gmail.com','Denise de Carvalho Reis','Av. Prof. Alfredo Balena,<br>189 sala: 1006','Belo Horizonte','Minas Gerais','BRAZIL','30130-100','55-031-8492-3389','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-23 00:45:20',0,NULL,3,1,3,1,'RA184595278CN\r ','hermeshine'),(26503,816846254001,110454033229,'Light Stand 2m / 6\'56\" for photo studio lighting ×2',1,'AKT031',50,'hermeshine','northern_aqs','lawrence@northernaqs.com','Lawrence Fisker','5-190 Minet\'s Point Road<br>#375','Barrie','ON','CANADA','L4N8J8','(705) 241-6940','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-23 00:57:22',0,NULL,3,1,5,1,'CP236402029CN\r ','hermeshine'),(26504,861677947002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','haiqi','haiqi@protyle.com','Haiqi Fu','2117 Palomar Trace Dr','Lexington','KY','UNITED STATES','40513-1120','(859) 219-1176','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 01:11:06',0,NULL,3,1,3,1,'RA184595220CN\r ','hermeshine'),(26505,971545443015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',132,'hutongstore','trie8176','sylmarill@hotmail.com','Tim Riedel','346 St Johns Rd','Toronto','ON','CANADA','M6S2K4','(647) 884-0025','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 01:15:44',0,NULL,3,1,5,1,'CP236402046CN\r ','hutongstore'),(26506,8881332465981665,111,'闪光灯B座',1,'',0,'hermeshine','allamdvd','ali.mahfoodh@yahoo.com','ALI AL-MAHFOODH','P.O.Box 9787','DAMMAM','','SAUDI ARABIA','31423','(966) 544-4886 ext.: 76',NULL,NULL,NULL,'2012-03-23 01:26:21',0,NULL,3,0,3,1,'RA184595281CN\r ','已入库 '),(26507,971543361015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',18.9,'hutongstore','ravivstein','mike1111114@walla.com','Raviv Stein','Haalon<br>mailbox 121','Ramat-Yishay','Emek-Izrael','ISRAEL','30095','(972) 523822235','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 01:09:35',0,NULL,3,1,3,1,'RA184595216CN\r ','hutongstore'),(26508,824075976018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39.99,'photographyacc','bobbychang83','robin.sang@hotmail.com','Robin Sang','152 Paine Street, Maroubra','Sydney','New South Wales','AUSTRALIA','2035','61415645919','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 01:28:53',0,NULL,3,1,3,1,'RA184595304CN\r ','photographyacc'),(26509,8881332470457454,111,'无牌渐变日落',1,'AD1226',0,'hermeshine','namelessamy','emailamy@myway.com','Amy Wonch','2300 W County Road 38 E<br>Lot 45','Fort Collins','CO','UNITED STATES','80526-6458','(970) 372-2149',NULL,NULL,NULL,'2012-03-23 02:40:57',0,NULL,3,1,1,1,'LK239207412CN ','上次发成渐变蓝了，这次别再错了 '),(26510,8881332470554653,111,'中号内胆包  无字',1,'',0,'hutongstore','oh1242','oliverholman@hotmail.com','Oliver Holman','Sjøstranda 69, leilighet B.89','Tromsø','','NORWAY','9006','4798823151',NULL,NULL,NULL,'2012-03-23 02:42:34',0,NULL,3,0,3,1,'RA184595295CN\r ','已入库 '),(26511,8881332473713324,111,'Free shipping & Tracking # - New Green.L Premium Quality 52mm CPL Filter FOR Canon Nikon - AA3308',1,'AA3308',7.49,'aliexpress','1007578398','123@hotmail.com','EVGENIYA Petrushova','Bumazhnaya st., 1, 10','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','190020','+7 812 7862656',NULL,NULL,NULL,'2012-03-23 03:35:13',0,NULL,8,1,17,0,NULL,''),(26512,8881332473781101,111,'Free shipping & Tracking # - New Neoprene Protector Camera Cover Case for Canon Nikon (M) - AC1301',1,'AC1301',7.19,'aliexpress','1007578399','123@hotmail.com','EVGENIYA Petrushova','Bumazhnaya st., 1, 10','Saint-Petersburg','Saint-Petersburg','RUSSIAN FEDERATION','190020','+7 812 7862656',NULL,NULL,NULL,'2012-03-23 03:36:21',0,NULL,0,1,3,0,NULL,'速卖通\r绿叶 CPL  52mm  1 \r中号内胆包 无字  1'),(26513,8881332473898548,111,'Free shipping & Tracking # - New Pro wide angle holder for Cokin P series Filters - AA2216',1,'AA2216',5.99,'aliexpress','1007576055 ',' toyoki@ca2.so-net.ne.jp','Toyoki Bamba','3-20-2-205 Nogata, Nakano-ku','Tokyo','','JAPAN','165-0027','+81 03 53438674',NULL,NULL,NULL,'2012-03-23 03:38:18',0,NULL,0,1,3,0,NULL,'速卖通 '),(26514,861725254002,120778184557,'New Photo Studio Background Support 3m x 2.4m Free Backdrop Free Carry bag',1,'AD1183',92.99,'hermeshine','oneblood1','oneblood@live.com.ar','alejandro aboy','La Blanqueada 3540','Avellaneda','Buenos Aires','ARGENTINA','1872','0054 11 43530201','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 04:21:36',0,NULL,3,1,5,1,'CP236402050CN\r ','hermeshine'),(26515,861726261002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','iamaman2012','iamaman@yandex.ru','vadim vadim','ak. bakuleva, 559','mosscow','_UAES_NULL_','RUSSIAN FEDERATION','117513',' 89263409000','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 04:24:33',0,NULL,3,1,11,1,NULL,'hermeshine'),(26516,861727405002,120595953748,'Pro FANCIER FT-6662A Tripod NEW with Ball head bag',1,'AE1601',59.9,'hermeshine','ropanes','ropanes@hotmail.com','Rodrigo Cuello Méndez','Carretera General S/N 1º izquierda','Panes','Asturias','SPAIN','33570','645031307','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-23 04:31:15',0,NULL,3,1,3,1,'RA184596083CN\r ','hermeshine'),(26517,8881332477107512,111,'Foto Studio Light Kit Boom Arm Stand Tripod w 115w bulb',2,'AKT004',192,'hermeshine','Xavier Hernandez','princess@princessvideo.com.mx','Fco Xavier Hernández Gtz','Calle Jardines # 4 Yabuku Ajusco<br>Mexico Federal District ','Delegation Tlalpan Federal Distrito Federal ','Mexico City.','MEXICO.','14200','(52 55) 56 45 39 74',NULL,NULL,NULL,'2012-03-23 04:31:47',0,NULL,3,1,12,1,'2584824756 ','注意是2套\r110V\r泡重7.4  实重6.1'),(26518,951430500016,260660055035,'10pcs TianYa Color Filter Box Ring & Holder for Cokin P',1,'AKT006',32,'hutongstore','zaidi24','zaidi@uniten.edu.my','Mohamad Zaidi Bahauddin','BW-6-C28, College of Information Technology<br>Universiti Tenaga Nasional, Jalan IKRAM-UNITEN','Kajang','Selangor Darul Ehsan','MALAYSIA','43000','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 05:20:03',0,NULL,3,1,3,1,'RA184596110CN ','hutongstore\r换成77mm 环\r一槽托架 '),(26519,951432221016,260901271975,'Male to Male 52mm-52mm Macro Reverse Ring reversing 52-52 adapter',1,'AA1211',1.9,'hutongstore','betspan','nigelsg@hotmail.co.uk','Nigel Greenway','20 Morley Street<br>Parkgate','Rotherham','South Yorkshire','UNITED KINGDOM','S62 6AP','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 05:23:19',0,NULL,3,1,11,1,NULL,'hutongstore'),(26520,816907087001,110797478393,'NEW Photo Video Light Stands Studio Stand 8ft 2.5m',1,'AD1217',32.99,'hermeshine','ivan_com','boxing2000@mail.ru','Иван Сафронов','Красный проспект 181, 246<br>Red prospekt 181, 246','Novosibirsk','НСО','RUSSIAN FEDERATION','630123','+79137514863','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 05:28:13',0,NULL,3,1,3,1,'RA184596123CN\r ','hermeshine'),(26521,824134936018,280739907456,'New Lighting kit Studio 2m  light stand Boom Arm 60cm Softbox For Speedlight ',1,'AKT084',99,'photographyacc','akjijioeh','ebay@anthony-tran.com','Anthony Tran','3611 Page Rd','Morrisville','NC','UNITED STATES','27560-9407','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-23 05:49:16',0,NULL,3,1,4,1,'YW867611641CN\r ','photographyacc'),(26522,816916050001,110502563007,'16\" 40 x 40cm Photo Studio Shooting Tent Light Cube Box',1,'AC2401',18.99,'hermeshine','shoppbrx','vendascomph@yahoo.com.br','wagner andrade','Dr. muricy 839  ap 154','curitiba','parana','BRAZIL','80020040','4185024177','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 06:26:34',0,NULL,3,1,11,1,NULL,'hermeshine'),(26523,951445895016,260854011321,'New Official Nikon Baseball Cap Hat D700 D3s D90 D7000 SLR Black',1,'AD1190',10.9,'hutongstore','willielawrence','willielawrence@hotmail.com','William LAWRENCE','C/O Mrs P Dedynski<br>2 Church Street','South Witham','Lincolnshire','UNITED KINGDOM','NG33 5PJ','','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-23 06:29:26',0,NULL,3,1,11,1,NULL,'hutongstore'),(26524,8881332484624434,111,'1.6*3  黑色布',1,'',0,'aliexpress','Jouko Hokajärvi','jouko.hokajarvi@gmail.com','Jouko Hokajärvi','Kuuselantie 5<br>Mexico Federal District ','Kempele ','','FINLAND','90450','',NULL,NULL,NULL,'2012-03-23 06:37:04',0,NULL,3,0,3,1,'RA184596208CN\r ','速卖通\r再发几个夹子\r上次2.4m  X 3m 背景架里面忘发夹子了 '),(26525,816918000001,110618903935,'Pro Photo Vest Black for Canon 500D 550D 7D 60D  user',1,'AA2115',32,'hermeshine','philu_ga','philubonmat@yahoo.com.vn','Tuan Phi Lu','1602 ESQUIRE PL','NORCROSS','GA','UNITED STATES','30093-1325','(770) 934-8777','NoPaymentFailure','CheckoutComplete','Other','2012-03-23 06:38:34',0,NULL,3,1,1,1,'LK239202769CN ','hermeshine\rXL 已入库'),(26526,824148849018,280793648042,'New Chammy Chamois Leather Lens Cleaning Cloth/ Lens cleaner',1,'AA1312',1.43,'photographyacc','dx_hhh_hbk','goku_arucard_hhh@live.com.au','sam selby','17 Matthew flinders avenue','Endeavour hills','Victoria','AUSTRALIA','3802','0432385012','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 07:06:25',0,NULL,3,1,11,1,NULL,'photographyacc'),(26527,861760497002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','drefus_be','stephanev0000@hotmail.fr','VANDEKERKHOVE STEPHANE','29/2 rue de tourcoing','MOUSCRON','','BELGIUM','7700','056480514','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 07:48:06',0,NULL,3,0,3,1,'RA184596185CN ','hermeshine\r1.6*3  黑色'),(26528,824162832018,280672125890,'White Black Acrylic photograph reflection board 20x30cm',1,'AB1201',18,'photographyacc','chrisandcav','easybeads@dodo.com.au','Easy Beads','70 Anglesey Street','Seymour','Victoria','AUSTRALIA','3660','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 08:11:43',0,NULL,3,1,11,1,NULL,'photographyacc'),(26529,951486469016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','diamondgirlcat','j.timpson@sky.com','Jonathan Timpson','18 Poplar Road','Leatherhead','Surrey','UNITED KINGDOM','KT228sq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 09:02:32',0,NULL,3,1,11,1,NULL,'hutongstore'),(26530,816951304001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','devilenya','mark-hinnawi@hotmail.com','Hinnawi Mark','219 De He Rd. 2F','Yung Ho City','','TAIWAN','23445','(886) 2 29270923','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 09:19:20',0,NULL,3,1,11,1,NULL,'hermeshine'),(26531,8881332494527797,111,'Free shipping & Tracking # - 62mm 62 Rubber 3in1 3-stage Collapsible Lens Hood for Canon Nikon - AB1304',2,'AB1304',10.98,'aliexpress','1007595578','refuge@yandex.ru','Anton Kobelev','Mira Str 115-127','Perm','Permsky Krai','RUSSIAN FEDERATION','614065','+7 902 4736267',NULL,NULL,NULL,'2012-03-23 09:22:07',0,NULL,0,1,3,0,NULL,'速卖通 '),(26532,971682862015,250607331372,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',132,'hutongstore','mishell32','ya.mishell@yandex.ru','Mishell Antonow','per. Elektrovoznyy, 6','Bryansk','Bryanskaya oblast','RUSSIAN FEDERATION','241039','+79192961532','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 09:37:15',0,NULL,0,1,5,0,NULL,'hutongstore'),(26533,951496438016,260662592614,'Background Support & 10m x 20m Green Screen Light Kit ',1,'AKT063',132,'hutongstore','krivami1','krivami@yahoo.com','Ami Krivulin','Givati 8','Rishon Le-Zion','','ISRAEL','75350','97239502893','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-23 09:37:27',0,NULL,4,1,6,0,NULL,'hutongstore\r需要加GBP24运费'),(26534,971692905015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','drkaktusss','drkaktusss-biz@ya.ru','Sergiy Bilyy','Vecherni Bulvar, 18-223','Krivoy Rog','Dnepropetrovskaya oblast','UKRAINE','50076','+ 380564014005','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 10:15:31',0,NULL,0,1,5,0,NULL,'hutongstore\r白 + 黑'),(26535,816973794001,110469599873,'Photo Video Light Stands Studio Photo Stand 7ft 200cm',1,'AE3401',25,'hermeshine','steffieheart','stefjuh1990@gmail.com','Stefanie Hodnik','Schouw 4866','LELYSTAD','','NETHERLANDS','8232BC','0655176433','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-23 10:48:00',0,NULL,0,1,11,0,NULL,'hermeshine'),(26536,817014766001,110534356031,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',46.34,'hermeshine','bardurbardur','bardurthomassen@hotmail.com','Bardur Thomassen','Rasmusargøta 10','Midvagur','Faroe Island','DENMARK','0370','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 13:10:26',0,NULL,0,1,3,0,NULL,'hermeshine\r单灯头  欧标   2\r45w 220v  灯泡   2\r广角托架    1\r77mm 接口环   1\r82mm 接口环   1\r\r已入库\r\r\r'),(26537,860583448002,120646868073,'Neoprene Camera Cover Case 4 Canon Dslr 450D &semi slr ',8,'AC2303',45.52,'hermeshine','edc-01e','bc-nc39@nifty.com','Akira Nakano','311 Aza-higashimyoudenchi, Rokugouhigashine,','Misato-chou, Senboku-gun,','Akita','JAPAN','019-1403','090-4425-5200','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 13:21:57',0,NULL,0,1,3,0,NULL,'hermeshine'),(26538,816898542001,110717934289,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',7.99,'hermeshine','armjanka','arevik.am@mail.ru','Arevik Kobelyan','Varshavyan 21','Yerevan','Yerevan','ARMENIA','0037','+374-55-377-167','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 14:15:18',0,NULL,0,1,11,0,NULL,'hermeshine'),(26539,640652606004,140727519721,'LensPen Mini Pro II Lens Pen Camera Cleaning Kit Safe for all lenses and filters',1,'AD1229',5.5,'hermeshine','mikey7901','mikeym@bell.net','Mike Miller','12200 boul de Pierrefonds<br>228','Pierrefonds','QC','CANADA','H9A 2X7','(514) 542-1558','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 14:27:49',0,NULL,0,1,11,0,NULL,'hermeshine'),(26540,971203189015,250637927048,'New Hairlight photostudio boom arm 75-135cm',2,'AE3101',37.98,'hutongstore','mickeymac10','michealmackin@hotmail.com','Micheal mackin','15 Clos Cormac<br>Saltown','Dundalk','Louth','IRELAND','default','0868329849','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 14:52:06',0,NULL,0,1,3,0,NULL,'hutongstore'),(26541,861866492002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','phikshun75','phikshun@hotmail.com','BOBBIE HEFNER','10536 Bear Creek Trl','Keller','TX','UNITED STATES','76244-6517','','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 14:18:40',0,NULL,0,1,3,0,NULL,'hermeshine'),(26542,817072590001,110456422601,'Circular Polarizing C-PL CPL Filters for Cokin P Series',1,'AA2326',10.8,'hermeshine','andysimpy','andy@as-photography.co.uk','Andy Warner-Simpson','63 Dorchester Avenue<br>Bletchley','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk36pq','01908632962','NoPaymentFailure','CheckoutComplete','UK_OtherCourier','2012-03-23 16:00:32',0,NULL,8,1,17,0,NULL,'hermeshine'),(26543,971835695015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','andysimpy','andy@as-photography.co.uk','Andy Warner-Simpson','63 Dorchester Avenue<br>Bletchley','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk36pq','01908632962','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-23 16:00:34',0,NULL,0,1,3,0,NULL,'hutongstore\rc以外再加上：\r天涯方形滤镜系列  CPL     1 \r斜臂     1  '),(26544,971848440015,250600489459,'New Hairlight photostudio boom arm ',1,'AE3101',18.9,'hutongstore','andysimpy','andy@as-photography.co.uk','Andy Warner-Simpson','63 Dorchester Avenue<br>Bletchley','Milton Keynes','Buckinghamshire','UNITED KINGDOM','mk36pq','01908632962','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 16:30:24',0,NULL,8,1,17,0,NULL,'hutongstore\r'),(26545,861913749002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',2,'AD1169',13.76,'hermeshine','dorushiva42','dorushiva@gmail.com','dorus oerlemans','Ohmstraat 12-3','AMSTERDAM','','NETHERLANDS','1098 ST','+31645460952','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 16:31:07',0,NULL,0,1,2,0,NULL,'hermeshine'),(26546,640683994004,140727554688,'New Soft Camera Bag Case Cover Canon 5D Mark II + 24-105mm XL',1,'AD1237',8,'hermeshine','leonyleony','leony_levandoski@hotmail.com','lucimara levandoski','aos 05 bl c ap 402<br>octogonal','brasilia','Distrito Federal','BRAZIL','70660053','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 16:33:33',0,NULL,8,1,17,0,NULL,'hermeshine'),(26547,817081657001,110777890336,'Pro Photo Vest Black Nikon Canon Sony Olympus Pentax',2,'AA2114',64,'hermeshine','leonyleony','leony_levandoski@hotmail.com','lucimara levandoski','aos 05 bl c ap 402<br>octogonal','brasilia','Distrito Federal','BRAZIL','70660053','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-23 16:33:34',0,NULL,0,1,3,0,NULL,'hermeshine\r加大内胆包 canon    1\r摄影背心 黑色厚 无字 XL    2'),(26548,951661361016,260660053205,'New Neoprene Reversible Bag Cover for Large-DSLR  L',1,'AC1302',3.9,'hutongstore','icantfindmyipod','luke.adrian@gmail.com','Luke Tanchua','23 Westerway Terrace','North Lake','Western Australia','AUSTRALIA','6163','0893138886','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 16:36:35',0,NULL,0,1,11,0,NULL,'hutongstore'),(26549,971871338015,250600507164,'Hot Shoe Spirit Level Cover Protector for Canon Nikon',1,'AA1206',2.9,'hutongstore','chrisafonso2131','chrisafonso21@gmail.com','Joseph Christophe Beites Afonso','Rua Edmundo Bettencourt, 41','Funchal','Madeira','PORTUGAL','9020-215','(351)963469764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 17:12:06',0,NULL,8,1,17,0,NULL,'hutongstore'),(26550,951679887016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',2.9,'hutongstore','chrisafonso2131','chrisafonso21@gmail.com','Joseph Christophe Beites Afonso','Rua Edmundo Bettencourt, 41','Funchal','Madeira','PORTUGAL','9020-215','(351)963469764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 17:12:07',0,NULL,8,1,17,0,NULL,'hutongstore'),(26551,951679889016,260660052718,'Original LP-1 Lenspen Lens Dust Cleaning Pen +Brush New',1,'AA1310',3.78,'hutongstore','chrisafonso2131','chrisafonso21@gmail.com','Joseph Christophe Beites Afonso','Rua Edmundo Bettencourt, 41','Funchal','Madeira','PORTUGAL','9020-215','(351)963469764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 17:12:08',0,NULL,8,1,17,0,NULL,'hutongstore'),(26552,951664582016,260660052888,'New EyeCup for Canon Ef EOS 500D 1000D 450D 400D 350D',1,'AA1201',1.85,'hutongstore','chrisafonso2131','chrisafonso21@gmail.com','Joseph Christophe Beites Afonso','Rua Edmundo Bettencourt, 41','Funchal','Madeira','PORTUGAL','9020-215','(351)963469764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 17:12:09',0,NULL,8,1,17,0,NULL,'hutongstore'),(26553,861921588002,120705839885,'HB-7 Petal Crown Flower Lens Hood For Nikon AF 80-200mm',1,'AA1216',13.5,'hermeshine','shellest1982','animal1982@bk.ru','Андрей Малтапар','Maloyaroslavetskaya<br>10-115','Kaluga','Central','RUSSIAN FEDERATION','248012','79208710033','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 17:16:09',0,NULL,0,1,11,0,NULL,'hermeshine'),(26554,971871337015,250692236354,'Canon-58mm Macro Reverse Adapter Ring For 40D 450D 500D',1,'AA1208',2.79,'hutongstore','chrisafonso2131','chrisafonso21@gmail.com','Joseph Christophe Beites Afonso','Rua Edmundo Bettencourt, 41','Funchal','Madeira','PORTUGAL','9020-215','(351)963469764','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 17:12:05',0,NULL,0,1,3,0,NULL,'hutongstore\r带水平仪 热靴保护盖    1\r气吹 + 布    1\rlenspen      1\r眼罩 450D/500D    1\rcanon 反接环  58mm     1'),(26555,971888476015,250939065869,'Promotion！New EW-78D Lens Hood for Canon EF-S 18-200mm 28-200mm ew78d flocking',1,'AA3405',5.8,'hutongstore','saralut','sara8900@hotmail.com','Sara Lutfullah','87 The Ridgway<br>Sutton','Surrey','Surrey','UNITED KINGDOM','SM2 5JU','02086421240','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 17:45:03',0,NULL,0,1,11,0,NULL,'hutongstore'),(26556,971900851015,250599414645,'Green.L 77mm 77 Neutral Density ND8 Filter ND 8 New',1,'AE2314',4.55,'hutongstore','sarabasas','sarabasas@yahoo.com','Sarunas Nariunas','Nemuno 10-7','Kaunas','Rokai','LITHUANIA','46159','868480277','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 18:08:10',0,NULL,0,1,11,0,NULL,'hutongstore'),(26557,971923998015,250941734273,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',2,'AD1199',37.8,'hutongstore','jurgitukas2009','jnikontaite@gmail.com','Jurgita Sakalauskiene','558B London road','Isleworth','London','UNITED KINGDOM','TW7 4EP','07895436021','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 18:45:43',0,NULL,0,1,3,0,NULL,'hutongstore'),(26558,861981557002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','pregieleo','pregiep@gmail.com','Pregie Leocadio','10325 97th st<br>apt 1','ozone park','NY','UNITED STATES','11417','','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-23 19:08:11',0,NULL,0,1,1,0,NULL,'hermeshine\r1.6x3m 白色'),(26559,817163008001,110414373712,'58mm 58 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT020',4.1,'hermeshine','stinkypete140','thewells.p@gmail.com','peter wells','14 fairview close<br>llansamlet','swansea','south wales','UNITED KINGDOM','sa7 9se','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 19:29:53',0,NULL,0,1,17,0,NULL,'hermeshine'),(26560,861995036002,120440123234,'62mm 62 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3304',3.99,'hermeshine','stinkypete140','thewells.p@gmail.com','peter wells','14 fairview close<br>llansamlet','swansea','south wales','UNITED KINGDOM','sa7 9se','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 19:35:55',0,NULL,0,1,17,0,NULL,'hermeshine'),(26561,817166750001,110566020073,'New 62mm ring adapter replacement for cokin P series',1,'AA2211',2.18,'hermeshine','stinkypete140','thewells.p@gmail.com','peter wells','14 fairview close<br>llansamlet','swansea','south wales','UNITED KINGDOM','sa7 9se','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 19:37:05',0,NULL,0,1,17,0,NULL,'hermeshine'),(26562,817163826001,110807100036,'Promotion ! NEW 3pcs Square ND2+ND4+ND8 Neutral Density Filter Kit for Cokin P',1,'AKT096',13.88,'hermeshine','stinkypete140','thewells.p@gmail.com','peter wells','14 fairview close<br>llansamlet','swansea','south wales','UNITED KINGDOM','sa7 9se','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 19:31:12',0,NULL,0,1,3,0,NULL,'hermeshine\r无牌方镜 ND2    1\r无牌方镜 ND4    1\r无牌方镜 ND8    1\r3片装的滤镜袋    1\r方形滤镜接口环 58mm     1\r方镜普通托架（三槽）      1\r绿叶 UV  62mm     1\r方形滤镜接口环 62mm    1'),(26563,861994077002,120621947187,'New Photo Studio Light Stand Umbrella Flash Mount set',1,'AKT014',39.99,'hermeshine','rio1parrot','baarn31@frontier.com','Barbara Allen','PO Box 232<br>401 Western Avenue','De Land','IL','UNITED STATES','61839-0232','(217) 664-3675','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 19:48:52',0,NULL,0,1,3,0,NULL,'hermeshine'),(26564,951800112016,260838264614,'New Large High quality heavy duty sand bag Empty',2,'AD1168',17.98,'hutongstore','jammas21','jammas@virginmedia.com','Robert Nightengale','41 Longhill Road','Catford','London','UNITED KINGDOM','SE6 1TZ','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 20:33:18',0,NULL,0,1,11,0,NULL,'hutongstore'),(26565,971996945015,250611204939,'Adjustable Padded shoulder Neck Strap for 500D 5DII 40D',1,'AB1404',2.99,'hutongstore','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 20:36:39',0,NULL,8,0,17,0,NULL,'hutongstore'),(26566,971996947015,250599421678,'72mm Snap-on Front Cap for Canon 72mm Filters Lens New',1,'AA1303',1.88,'hutongstore','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 20:36:40',0,NULL,8,1,17,0,NULL,'hutongstore'),(26567,971996950015,250599421415,'67mm Snap-on Front Cap for Canon 67mm Filters Lens New',1,'AA1302',1.88,'hutongstore','buzzer_72','jussi.manne@gmail.com','Jussi Manne','Heporinne 2 D 61','Vantaa','','FINLAND','01200','+358400438669','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 20:36:40',0,NULL,0,1,11,0,NULL,'hutongstore\r肩带 canon     1\rCANON 镜头盖  72mm     1\rCANON 镜头盖  67mm     1'),(26568,971997142015,250932213985,'New 1500w Studio Continuous Lighting Kit with background support & 3x6m backdrop',1,'AKT074',188,'hutongstore','dsureshkumar1998','dsuresh@hotmail.no','MAHESAKUMAR ARAMPU','ARNEFJELLBUS VEG 4E','TRONDHEIM','Norway','NORWAY','7033','004793412516','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 20:44:11',0,NULL,0,1,5,0,NULL,'hutongstore\r欧标'),(26569,862033621002,120640057121,'C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',9.68,'hermeshine','slidersez','slidersez@sbcglobal.net','Dave Meinerz','4602 S 113th St','greenfield','WI','UNITED STATES','53228-2527','(414) 425-8791','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-23 20:50:38',0,NULL,0,1,1,0,NULL,'hermeshine'),(26570,862049719002,120539340436,'New 77mm ring adapter replacement for cokin P series',1,'AA2214',2.18,'hermeshine','frangam','pacoleo@wanadoo.es','FRANCISCO GAMEZ GORDILLO','C/ LACARA  Nº5','PUEBLONUEVO DEL GUADIANA','Extremadura','SPAIN','06184','625430031','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 21:26:46',0,NULL,0,1,2,0,NULL,'hermeshine'),(26571,862051666002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','stormshdw9','stormshdw9@aol.com','Geoffrey Sykes','1114 S Cloverdale Ave','Los Angeles','CA','UNITED STATES','90019-6741','(805) 258-2290','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-23 21:30:36',0,NULL,0,1,3,0,NULL,'hermeshine'),(26572,862058761002,120561563990,'20\" 50 x 50cm Photo Studio Shooting Tent Light Cube Box',1,'AC2402',20.75,'hermeshine','jorgekiro','jorge.kiro@gmail.com','Jorge Quiroga Jimenez','Av Patrimonio Humanidad 8-2 Bajo C','Avila','Avila','SPAIN','05004','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 21:47:26',0,NULL,0,1,11,0,NULL,'hermeshine'),(26573,972041323015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','dbroom71','debroom@msn.com','David Broom','3 Ditton Way','Ipswich','Suffolk','UNITED KINGDOM','IP3 8GL','07872075209','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 21:54:04',0,NULL,0,1,3,0,NULL,'hutongstore'),(26574,817237851001,110566020462,'New Camera Tripod Fancier FT-6663A with 3-way head Bag',1,'AE1502',79.96,'hermeshine','birukovdenis','den57labs@gmail.com','Denis Birukov','Bessonovskiy raion, selo Grabovo, ulica Sovetskaya, dom184','Penzenskaya oblast\'','','RUSSIAN FEDERATION','442770','+7937-402-22-90','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 22:14:57',0,NULL,0,1,5,0,NULL,'hermeshine'),(26575,824489235018,280676697832,' C Clip Clamp Holder Mount for Studio Backdrop Camera',1,'AE3104',8.99,'photographyacc','06marshy','marshman@internode.on.net','john marshman','364 Carrington St','Adelaide','South Australia','AUSTRALIA','5000','0882325858','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-23 22:34:18',0,NULL,0,1,11,0,NULL,'photographyacc'),(26576,862087284002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','sakkater09','sak_kater@yahoo.gr','Pagonas Athanasios','137 A/K MMP','Litohoro Pierias','','GREECE','60200','6944905449','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-23 23:05:21',0,NULL,0,1,3,0,NULL,'hermeshine'),(26577,972075656015,250635199732,'52mm Macro Reverse Adapter Ring For Pentax K110D K-M KM',1,'AA1209',2.79,'hutongstore','wallybollox123','john58827@googlemail.com','jj erwin','28 camphill','newtownbutler','Fermanagh','UNITED KINGDOM','bt928ew','02867738198','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 23:05:26',0,NULL,0,1,2,0,NULL,'hutongstore'),(26578,972088496015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','benjamminmagic','zitouniatis@gmail.com','Dimos Dimitrios Zitouniatis','patron 3-5','Athens','Kolonos','GREECE','10444','0030 211 0114647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 23:36:55',0,NULL,8,1,17,0,NULL,'hutongstore'),(26579,972088498015,250932214167,'New 4 X E27 Sockets head with 20\"X28\"  50cmx70cm Softbox Photo Video Light',1,'AD1176',23.5,'hutongstore','benjamminmagic','zitouniatis@gmail.com','Dimos Dimitrios Zitouniatis','patron 3-5','Athens','Kolonos','GREECE','10444','0030 211 0114647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 23:36:56',0,NULL,8,1,17,0,NULL,'hutongstore'),(26580,972088499015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','benjamminmagic','zitouniatis@gmail.com','Dimos Dimitrios Zitouniatis','patron 3-5','Athens','Kolonos','GREECE','10444','0030 211 0114647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 23:36:57',0,NULL,8,1,17,0,NULL,'hutongstore'),(26581,972091545015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',4.6,'hutongstore','kirbrot','kirbrot@manx.net','James Kirby','23 Brecken Bank<br>Tromode Woods','Braddan','Isle of Man','UNITED KINGDOM','IM4 4TS','01624677544','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-23 23:46:05',0,NULL,0,1,11,0,NULL,'hutongstore'),(26582,951893485016,260660052597,'New Air Dust Blower Cleaner Pump and Cloth',1,'AA1311',2.9,'hutongstore','benjamminmagic','zitouniatis@gmail.com','Dimos Dimitrios Zitouniatis','patron 3-5','Athens','Kolonos','GREECE','10444','0030 211 0114647','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-23 23:36:54',0,NULL,0,1,3,0,NULL,'hutongstore\r气吹 + 布    1\r一转四 灯头     1\r4灯头 灯头 孔    1   欧标\r50cmx70cm 的柔光箱 (配4灯头）    1\r伞式柔光箱 80cm 8角     1'),(26583,972107574015,250971426000,'Promotion!NEW 3pcs Graduated Blue Grey(ND4) Orange Filter Kit for Cokin P Series',1,'AKT098',9.99,'hutongstore','trinitykate2005','modityx@yahoo.co.uk','andrew jubb','12 crags road<br>denaby main ','doncaster','South Yorkshire','UNITED KINGDOM','dn124ee','01709860554','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-24 00:31:50',0,NULL,0,1,17,0,NULL,'hutongstore'),(26584,972111201015,250939066315,'New Six Filters and six pockets filter case Kit for Cokin P Series 6pcs',1,'AKT081',16.6,'hutongstore','trinitykate2005','modityx@yahoo.co.uk','andrew jubb','12 crags road<br>denaby main ','doncaster','South Yorkshire','UNITED KINGDOM','dn124ee','01709860554','NoPaymentFailure','CheckoutComplete','UK_StandardShippingFromOutside','2012-03-24 00:42:51',0,NULL,0,1,3,0,NULL,'hutongstore\rc以外再加：\r无牌方镜 渐变蓝    1\r无牌方镜 渐变橙    1\r无牌方镜 渐变灰 （nd4）    1\r3片装的滤镜袋     1'),(26585,817303077001,110550760975,'Studio Background Support 7x7 ft White Black Backdrops',1,'AKT015',78.9,'hermeshine','staceymarie54','staceymarie54@yahoo.com','stacey cygan','601D Johnson Ave','clinton','WI','UNITED STATES','53525-9002','(608) 371-4640','NoPaymentFailure','CheckoutComplete','ExpeditedShippingFromOutsideUS','2012-03-24 02:02:05',0,NULL,0,1,4,0,NULL,'hermeshine\r白 + 黑'),(26586,824557130018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39.99,'photographyacc','drmithun','drmithoon@gmail.com','MITHUN RAJSHEKAR','14/8,Murray Avenue<br>mosman park','PERTH','Western Australia','AUSTRALIA','6012','0423689655','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 02:33:44',0,NULL,0,1,3,0,NULL,'photographyacc'),(26587,951958042016,260850329566,'New kit for Speedlight Boom Arm+Stand+​Softbox for SpeedLight ex580 sb900 sb700',1,'AKT084',59.9,'hutongstore','maccardin','marcdarkin@gmail.com','Manuel Fernández González','Brion, 2 - 3º','Santiago de Compostela','Galicia','SPAIN','15702','981940643','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 03:00:28',0,NULL,0,1,4,0,NULL,'hutongstore\r换2m弹簧灯架吧\r留一下最终的重量'),(26588,817318008001,110545632084,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',2,'AE2501',70.98,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:08:45',0,NULL,8,1,17,0,NULL,'hermeshine'),(26589,862152249002,120758743629,'New Sand Bag Weight portable equipment Shipped Empty',6,'AD1169',41.28,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:18:25',0,NULL,8,1,17,0,NULL,'hermeshine'),(26590,862154442002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',2,'AD1126',25,'hermeshine','emersoncgarcia','emerson.calvente@gmail.com','Emerson Garcia','Rua Claudino Pinto, 100 - Bloco 02 - Ap. 134','Sao Paulo','SP','BRAZIL','03040-040',' 551164731359','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 03:29:12',0,NULL,0,1,3,0,NULL,'hermeshine\r反光板支架    2\r沙袋（普通）    6\r反光伞110cm    2\r五灯头上的小螺丝 （邮件里有图）   1\r申报： Silver Light Umbrellas\r$38.9'),(26591,817346830001,110407144175,'67mm 67 Haze UV Filter For Canon SONY Pentax Nikon',1,'AA3305',11.23,'hermeshine','rosfan.hashim','rosfan@streamyx.com','Rosfan Hashim','35, JLN P11 B1/3<br>PRESINT 11','PUTRAJAYA','WP','MALAYSIA','62300','013-3428183','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 06:02:16',0,NULL,0,1,11,0,NULL,'hermeshine\r绿叶 UV  67mm   1\r绿叶 UV  72mm   1\r40D 眼罩     1\r'),(26592,817363603001,110724157545,'Camera protector case bag for Nikon D90 D7000 D80 L',1,'AD1173',11.9,'hermeshine','frs9008','sotfran@yahoo.com','Frank Scheets','8 Birchwood Dr','Short Hills','NJ','UNITED STATES','07078-3311','(973) 223-6027','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-24 07:28:26',0,NULL,0,1,1,0,NULL,'hermeshine'),(26593,972235717015,250607841646,'New Camera bag fit 1 dslr and 2-3 lenses upto 80-200mm',1,'AD1101',18,'hutongstore','2012anubhavmittal333','anubhavmittal333@yahoo.ca','anubhav mittal','212, bst white field dr n.e','calgary','AB','CANADA','t1y5j2','(403) 990-8987','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-24 08:41:00',0,NULL,0,1,3,0,NULL,'hutongstore'),(26594,862212459002,120752154008,'New Light Stand / Tripod Carry Soft Case Bag Thick Pad',1,'AD1128',22.9,'hermeshine','eyne2004','eyne2004@yahoo.ie','michael nolan','eyne','portlaoise','Laois','IRELAND','default','0868518577','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 08:42:30',0,NULL,0,1,3,0,NULL,'hermeshine'),(26595,952042087016,260901272211,'New Camera protector case Neoprene bag for Nikon D90 D7000 D80 L',1,'AD1173',6.5,'hutongstore','087fire7777','liesma42@inbox.lv','Viesturs Jekabsons','68 Dun Na Hinse,<br>Lahinch Road','Ennis','Clare','IRELAND','default','0872571908','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 08:51:50',0,NULL,0,1,11,0,NULL,'hutongstore'),(26596,952053446016,260844640278,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',12.99,'hutongstore','rsg7500','stuartgreen@planet.nl','STUART GREEN','APPLECROFT<br>LIMERS LANE','NORTHAM','Devon','UNITED KINGDOM','EX39 2RG','01237476486','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 09:25:27',0,NULL,0,1,11,0,NULL,'hutongstore'),(26597,817403602001,110741142180,'New Photography Huge Collapsible 5-in-1 Reflector 60“ x 80\"  150cm x 200 cm',1,'AD1182',139.79,'hermeshine','makeup-fx','lars@makeup-fx.com','Lars Carlsson','Nedre Linnarhultsvagen 18','Angered','','SWEDEN','42455','+46 (70) 7340122','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 10:11:32',0,NULL,0,1,4,0,NULL,'hermeshine\r新款15kg大力夹     2\r新款大力夹（手柄）  2\r反光板支架      1\r72mm 橡胶罩    1\r大沙袋    3\r150-200cm 5in1 反光板    1\r150-200cm 蓝绿背景板   1\r已入库\r'),(26598,972266854015,250937870392,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',20,'hutongstore','palamuda387','palamuda@hotmail.com','Vladimir Cubak','Avde Jabucice 12','Sarajevo','','BOSNIA AND HERZEGOVINA','71000','0039761411264','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 10:17:10',0,NULL,0,1,3,0,NULL,'hutongstore\r申报 $14\r仔细检查别少了柔光布'),(26599,862239898002,120595540056,'Non Woven Fabric Backdrop 3m long 1.6m width 5.2x9.8 ft',1,'AO0005',18,'hermeshine','jessychou2010','jessica_tetrault_69@hotmail.com','Jessica Tétrault','3827# A Hochelaga','Montréal','QC','CANADA','H1w 1j5','(514) 255-7303','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 10:26:35',0,NULL,0,0,3,0,NULL,'hermeshine\r黑色'),(26600,972282724015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','matroberts1979','mathewroberts@gmail.com','Mathew Roberts','22 The Square','Alveston','Bristol','UNITED KINGDOM','BS35 3PE','07817170707','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 10:57:38',0,NULL,0,1,3,0,NULL,'hutongstore'),(26601,817416639001,110533632347,'Super heavy clamp photography all metal capacity15kg',2,'AD1148',0,'hermeshine','makeup-fx','lars@makeup-fx.com','Lars Carlsson','Nedre Linnarhultsvagen 18','Angered','','SWEDEN','42455','+46 (70) 7340122','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,0,1,17,0,NULL,'hermeshine\r'),(26602,817423136001,110566020766,'New Lens Cleaning Cloth for Canon Nikon Pentax Sony',1,'AA1312',1.5,'hermeshine','papayoulele_fr','jbcantournet@hotmail.com','Jean-Bernard Cantournet','41 Route de Salèse<br>Le Boréon','Saint Martin Vésubie','Provence-Alpes-Côte d\'Azur','FRANCE','06450','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 11:22:04',0,NULL,0,1,2,0,NULL,'hermeshine'),(26603,972357851015,250692240473,'Studio Background Support 7\'x7\' + White Black Backdrops',1,'AKT015',46,'hutongstore','bazanmo','barry.johnson15@btopenworld.com','JOANNE JOHNSON','HIGH GABLES UPPERTHORPE ROAD<br>WESTWOODSIDE','DONCASTER','South Yorkshire','UNITED KINGDOM','DN9 2AQ','','NoPaymentFailure','CheckoutComplete','UK_ExpeditedShippingFromOutside','2012-03-24 14:02:51',0,NULL,0,1,4,0,NULL,'hutongstore\r白+ 黑'),(26604,861383160002,120565909440,'Extra Handle / Arm Weifeng Video Tripod Head 717 717A',1,'AE2102',25,'hermeshine','gfj22','fotografik@aon.at','Karin Christine Jagoutz','Grenzweg 43','Klagenfurt-Wölfnitz','','AUSTRIA','9061','','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-24 14:09:26',0,NULL,0,1,3,0,NULL,'hermeshine'),(26605,972382084015,251017296011,'2 Umbrellas- 2m Light Stand- Flash/Umbrella mount bracket 4 Portable Speedlight',1,'AKT100',32,'hutongstore','minaya76','jcgrandecasas@gmail.com','Juan Carlos Grande Casas','C/ Carros, 8, bajo','Minaya (Albacete)','Castilla-La Mancha','SPAIN','02620','653879071','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 14:55:48',0,NULL,0,1,3,0,NULL,'hutongstore'),(26606,862327500002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','diretordecriacao','daniel@danielalexandre.com.br','Daniel Alexandre Gaertner','Rio Grande do Norte street, number 131','Joinville','Santa Catarina','BRAZIL','89203-440','+55 47 34552642','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 15:01:53',0,NULL,0,1,3,0,NULL,'hermeshine'),(26607,972389554015,250948075013,'Brand New Lens Repair Tool Stainless Steel Spanner Wrench with swap-able tips',1,'AD1207',25,'hutongstore','matmaxgeds','matt@mattgeddes.co.uk','Matthew Geddes','45 Chelmer Road','Homerton','London','UNITED KINGDOM','E9 6AY','07747182612','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 15:13:00',0,NULL,0,1,3,0,NULL,'hutongstore'),(26608,817498638001,110541376393,'1.6m(5.2ft)×2.1m(7ft) Non Woven Fabric Backdrop Black',1,'AO0006',10.99,'hermeshine','ehgioes','ehgioes@gmail.com','Edward Joyce','CDr.Maranon 60','Coin,','Malaga','SPAIN','29100','646689701','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 15:13:36',0,NULL,0,0,2,0,NULL,'hermeshine\r1.6*2.1  黑色'),(26609,816558390001,110464642326,'Male to Male 52mm-52mm Macro Reverse Ring reversing',1,'AA1211',2.99,'hermeshine','sztufi','sz_gery@yahoo.com','Sztuchlak Gergo','str:Louis Pasteur<br>nr: 42/A ap:14','Oradea','Bihor','ROMANIA','410154','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 16:14:05',0,NULL,0,1,11,0,NULL,'hermeshine'),(26610,862398135002,120780386021,'New Pro Camera Tripod Ball Head KS-0 + Quick Release Plate for Benro/Manfrotto',1,'AD1186',29.99,'hermeshine','lexmon7','amulea@suddenlink.net','Alex Mulea','5233 Raphael Dr','Alexandria','LA','UNITED STATES','71303-2465','(318) 445-2008','NoPaymentFailure','CheckoutComplete','StandardShippingFromOutsideUS','2012-03-24 17:43:03',0,NULL,0,1,1,0,NULL,'hermeshine'),(26611,817566881001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',2,'AD1176',168.97,'hermeshine','alehandrobay','alehandromail@gmail.com','Alexander Terentyev','M-n Taugul - 1 (Dezhneva-Piatnickogo) phone: +7 (727) 302-3323<br>home 42 / 22','Almaty','Almaatinskaya oblast','KAZAKHSTAN','050042','+7 (777) 252-0300','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 17:53:01',0,NULL,4,1,8,0,NULL,'hermeshine\r2.4m X 3m 背景架+白布\r------这个产品减库要注意！\r4灯头 灯头 孔   2\r50cmx70cm 的柔光箱 (配4灯头）  2\r可能还有其他东西\r\r'),(26612,972489096015,250599942327,'67mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1305',2.45,'hutongstore','tharootas101','kashifrashid@ntlworld.com','Kashif Rashid','33 Mexborough Street','Leeds','West Yorkshire','UNITED KINGDOM','ls7 3eq','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 18:05:30',0,NULL,0,1,2,0,NULL,'hutongstore'),(26613,972506075015,250950973412,'Soft Camera Bag Case Cover Canon EOS 550D with 18-200mm',1,'AD1162',4.6,'hutongstore','anya79','ancorason@yahoo.com','Anna Clark','33 Cross Street','Fraserburgh','Aberdeenshire','UNITED KINGDOM','ab439eq','07724508829','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 18:32:08',0,NULL,0,1,11,0,NULL,'hutongstore'),(26614,862448531002,120813697903,'New Photo Photography Vest for Sony A230,A200,A330,​A350,A380 user 100% Cotton',1,'AA2113',33,'hermeshine','tuffguy63','tuffguy863@yahoo.de','William Hubers','600 Hickory Ridge Cir<br>Apt 4','Hopkinsville','KY','UNITED STATES','42240-3868','','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-24 19:18:35',0,NULL,0,1,1,0,NULL,'hermeshine\rXL 已入库'),(26615,824876234018,280666785906,'45W 5500K Studio Light Bulb x2 Daylight with E27 Socket',1,'AKT007',18,'photographyacc','hinggink','kisslips@gmx.net','Andreas Hartwig','Angerstraße 8','Thum','','GERMANY','09419','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-24 19:24:24',0,NULL,0,1,11,0,NULL,'photographyacc'),(26616,862463227002,120582354064,'New Collapsible 5-in-1 Reflector 40\"x60\" 100cm x150cm',1,'AC3201',39.88,'hermeshine','abolfaine','bolfaine@gmail.com','Alexey Bolfaine','Rua Inhambu, 964 Ap 121','Sao Paulo','Sao Paulo','BRAZIL','04520-013','551180803429','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-24 19:44:52',0,NULL,4,1,3,0,NULL,'hermeshine\r需要加$6运费，已发信'),(26617,972558052015,250804357708,'New 62mm Lenscap for Nikon Lens Snap-on 62  Front Cap',2,'AA1306',3.74,'hutongstore','smor9769','sandemorrison@talktalk.net','Stanley Morrison','32 Brierbush Road<br>Macmerry','Tranent','East Lothian','UNITED KINGDOM','eh33 1pr','01875611767','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 19:45:52',0,NULL,0,1,2,0,NULL,'hutongstore'),(26618,862443679002,120613894945,'Pro Photo Vest for Canon 450D 500D 40D 30D 50D 5D2 user',1,'AA2106',37,'hermeshine','boldonacne','tony@boldonautocentre.com','tony anderson','3 rosedale terrace<br>newbottle','houghton le spring','Tyne and Wear','UNITED KINGDOM','dh44hq','07751782812','NoPaymentFailure','CheckoutComplete','OtherInternational','2012-03-24 19:13:58',0,NULL,0,0,3,0,NULL,'hermeshine\r3XL 已入库'),(26619,886159661017,270748460971,'New 100% Genuine Lenspen Lens Cleaning Pen LP-1 tool',1,'AA1310',5.95,'photographyacc','kozhakovy','yuri.kozhakov@gmail.com','Yuri Kozhakov','Gara-Garayev st.94 apt.72','Baku','Nizami district','AZERBAIJAN','AZ1096','994502109951','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-24 20:00:27',0,NULL,0,1,11,0,NULL,'photographyacc'),(26620,972573829015,250637927048,'New Hairlight photostudio boom arm 75-135cm',1,'AE3101',18.99,'hutongstore','attam125','attardmartin@onvol.net','Martin Attard','Block 5, Door 2, Flat 6, Bini tal-Gvern<br>Triq ix-Xatt','Gzira','','MALTA','GZR 1025','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 20:07:41',0,NULL,0,1,3,0,NULL,'hutongstore'),(26621,817642989001,110744400547,'New Photo Studio 3m Cross Bar for Background Backdrop Support Load Weight 3kg',1,'AD1184',33.99,'hermeshine','rali4680','mzirk7887@hotmail.com','Rafail Alishayev','72-07 166 st','fresh meadows','NY','UNITED STATES','11365','(718) 591-0123','NoPaymentFailure','CheckoutComplete','ShippingMethodStandard','2012-03-24 20:12:23',0,NULL,0,1,3,0,NULL,'hermeshine'),(26622,952379890016,260901272052,'New Pro Photo Vest Black Nikon Canon Sony Olympus Pentax 100% COTTON',1,'AA2114',18,'hutongstore','jrnyfan_uk','supermariovill@yahoo.co.uk','Mario Villanueva',' 51 Ryecroft','Haywards Heath','West Sussex','UNITED KINGDOM','RH16 4NW','01444443106','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 20:29:13',0,NULL,0,1,3,0,NULL,'hutongstore\rXL 已入库'),(26623,817653466001,110807099824,'NEW Square Gradual Graduated Gray ND8 Plexiglass Filter for Cokin P Series',1,'AD1220',3.5,'hermeshine','jenspettrus','kklemet@yahoo.no','Knut Klemetsen','Tomtegt 25','Skien','Telemark','NORWAY','3714','+4790913991','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 20:34:19',0,NULL,8,1,17,0,NULL,'hermeshine'),(26624,972602254015,250946129951,'New Pro Photo Vest 100% Cotton for Canon Fans 450D 500D 40D 30D 50D 5DII 7D',1,'AA2106',25,'hutongstore','batetosho','tl@radio1.bg','Todor Lichev','7,Yantra St.','Plovdiv','','BULGARIA','4000','+359888452818','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-24 20:52:22',0,NULL,0,0,3,0,NULL,'hutongstore\r3XL 已入库'),(26625,824930500018,280671650022,'New Photography Studio Light Reflector Disc holder Arm',1,'AE2501',35,'photographyacc','great_sell3r','j_j_moreno@hotmail.com','Juan Jose Moreno Casado','C/ Caracas 17-19','Barcelona','na','SPAIN','08030','','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-24 20:58:12',0,NULL,0,1,3,0,NULL,'photographyacc'),(26626,862506168002,120816624311,'New Professional 60cm x 90cm Umbrella Softbox soft box Reflector Speedlight',1,'AD1199',31.34,'hermeshine','jenspettrus','kklemet@yahoo.no','Knut Klemetsen','Tomtegt 25','Skien','Telemark','NORWAY','3714','+4790913991','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 21:08:11',0,NULL,0,1,3,0,NULL,'hermeshine\r无牌方镜 渐变灰 （nd8）   1\r伞式柔光箱 60×90cm   1'),(26627,817672314001,110417009256,'NIB TianYa 77mm ND8 filter New 77 Neutral Density Grey',2,'AA2314',14.8,'hermeshine','klaasjan1986','kjschraa@gmail.com','Klaas Jan Schraa','Slingerbeek 21','ZWARTSLUIS','','NETHERLANDS','8064JE','+31610657474','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-24 21:13:15',0,NULL,0,1,2,0,NULL,'hermeshine'),(26628,952433897016,260901272183,'New Camera protector case Neoprene bag for Nikon D40 D3000 D3100 50mm 18-55mm',1,'AD1171',4.6,'hutongstore','susankidston','susan.kidston@sky.com','Susan Kidston','64 Stenhouse Avenue','Edinburgh','Midlothian','UNITED KINGDOM','EH11 3DF','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 21:52:16',0,NULL,0,1,11,0,NULL,'hutongstore'),(26629,886258576017,270757793519,'1.6m x 3m Background Backdrop Photography  Non-Woven',3,'AO0005',50.97,'photographyacc','shaunaandclayton','shauna20@bigpond.com','SHAUNA OAKLEY','24 Euro Blvd','KARRATHA','Western Australia','AUSTRALIA','6714','0891441921','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-24 23:24:08',0,NULL,0,0,3,0,NULL,'photographyacc\r1.6*3  灰色，粉色，蓝色'),(26630,972690837015,250599941476,'58mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1303',2.26,'hutongstore','lg11uk','l.h.gilbert@soton.ac.uk','Lester Gilbert','28 Mallard Gardens<br>Hedge End','Southampton','Hampshire','UNITED KINGDOM','SO30 2XJ','01489789619','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 23:38:51',0,NULL,8,1,17,0,NULL,'hutongstore'),(26631,972691223015,250599941685,'62mm 3-Stage Rubber Lens Hood for Nikon Canon Pentax OM',1,'AB1304',2.48,'hutongstore','lg11uk','l.h.gilbert@soton.ac.uk','Lester Gilbert','28 Mallard Gardens<br>Hedge End','Southampton','Hampshire','UNITED KINGDOM','SO30 2XJ','01489789619','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-24 23:39:46',0,NULL,0,1,11,0,NULL,'hutongstore\r橡胶遮光罩 58mm  1\r橡胶遮光罩 62mm  1'),(26632,952490658016,260814151115,'Collapsible 4.6.x6.4ft backdrop background black/white',1,'AA1218',35.8,'hutongstore','shankillandy','sales@shankillnews.com','Andrew Crawford','89 Ainsworth Drive','Belfast','Antrim','UNITED KINGDOM','bt133el','077701234567','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 00:02:00',0,NULL,0,1,3,0,NULL,'hutongstore'),(26633,817758842001,110724628512,'Big Travel Bag for Photo Equipment w Padded Dividers ',1,'AD1164',39.9,'hermeshine','johnyboy20100','johnybigoude@hotmail.com','Jean Vincent','1522 St-Louis App.3','Sherbrooke','QC','CANADA','J1H4P6','(819) 820-4704','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 01:27:25',0,NULL,0,1,3,0,NULL,'hermeshine'),(26634,862620100002,120578650981,'3-in-1 Cleaning Kit - Lenspen  Rubber Air Blower Cloth',1,'AKT067',9.9,'hermeshine','ron9906','ronfran@gmail.com','Ron Francis','164 Blackdome Cr.','Ottawa','ON','CANADA','K2T 1A7','(613) 270-9942','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 02:56:53',0,NULL,0,1,11,0,NULL,'hermeshine'),(26635,825062910018,280666981533,'New Photo Light Stand Soft Umbrella Flash Mount B set',1,'AKT014',39.99,'photographyacc','elliott1976','huttenrauch@optusnet.com.au','Claus Huttenrauch','47 Parkes Street','Manly Vale','New South Wales','AUSTRALIA','2093','','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 03:39:05',0,NULL,0,1,3,0,NULL,'photographyacc'),(26636,862639486002,120616936813,'Pro Video Tripod Fluid Pan Head EI717 717 EI-717 Bowl',1,'AO0001',190,'hermeshine','invisionstudio','complex-2003@yandex.ru','Sergey Titov','ul. Belgorodskaya. 10/12-8','Kursk','','RUSSIAN FEDERATION','305018','+79038769272','NoPaymentFailure','CheckoutComplete','AU_StandardInternational','2012-03-25 04:33:29',0,NULL,0,1,5,0,NULL,'hermeshine'),(26637,817827232001,110732073648,'New 4 Sockets with  20\"X28\" Softbox Photo Video Light',1,'AD1176',37.99,'hermeshine','seenicks2011','faiannarbor@gmail.com','Cliff Nixon','2383 Twin Lakes Dr<br>apt TA','Ypsilanti','MI','UNITED STATES','48197-1479','(734) 340-7313','PayPalPaymentInProcess','CheckoutComplete','EconomyShippingFromOutsideUS','0000-00-00 00:00:00',0,NULL,4,1,3,0,NULL,'hermeshine\r美标\r电子账单'),(26638,825109556018,280740692008,'New Profession​al  DSLR Rig VCR Shoulder Mount  for Camera DV Camcorder',1,'AD1188',74.99,'photographyacc','samuelwilson19','sam_campbell38@hotmail.com','Samuel Wilson','3/134 ramsgate Ave bondi beach','Sydney','New South Wales','AUSTRALIA','2026','0417793343','NoPaymentFailure','CheckoutComplete','AU_EconomyDeliveryFromOutsideAU','2012-03-25 07:33:38',0,NULL,0,1,3,0,NULL,'photographyacc'),(26639,972862512015,250600315434,'Flash Softbox Diffuser for internal flash for D500 D90',1,'AB3304',5.8,'hutongstore','coudysk','coudysk@gmail.com','Radoslav Chovan','1. poschodie vlavo, kancelarie Slovnaft<br>Zavodska cesta 2945/38','Zilina','','SLOVAK REPUBLIC','01001','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 09:07:08',0,NULL,0,1,11,0,NULL,'hutongstore'),(26640,952658205016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','luddeese','luddese@hotmail.com','LADISLAU SOLYOM','LAERKV.49','NAETTRABY','CO','SWEDEN','37024','','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 09:10:45',0,NULL,0,1,11,0,NULL,'hutongstore'),(26641,817880034001,110465846912,'Photo Video Light Stands Studio Photo Stand 6ft 200cm',1,'AE3401',0,'hermeshine','gardeobskure','vneeizer@gmail.com','Vyacheslav Neizer','Gogol str. 46/2 67','Karaganda','Karagandinskaya oblast','KAZAKHSTAN','100017','8(721)2511908','NoPaymentFailure','CheckoutIncomplete','StandardInternational','0000-00-00 00:00:00',0,NULL,0,1,8,0,NULL,'hermeshine\r闪光灯B座   2\r80cm 5in1    1\r灯架  2m  2\r柔光伞   1\r反光伞  1\r灯架包薄    1\r已入库\r客户要发EMS 称重量，\r算一下运费'),(26642,972905735015,250692237534,'Light Stands 2m /6\'56\" for photo studio lighting  NEW',1,'AE3401',18,'hutongstore','goldenbu','etirgus@gmail.com','Aigars Reinholds','Viduscels - 10','Ventspils','','LATVIA','LV 3601','29177548','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 10:37:22',0,NULL,0,1,11,0,NULL,'hutongstore'),(26643,817897119001,110414372016,'77mm 77 Ring Adapter & Filter Holder for Cokin P Series',1,'AKT024',4.1,'hermeshine','avner50k','avnyhil@yahoo.com','hillel avny','gazit 01','gazit','yzrael','ISRAEL','19340','04-6768572','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 10:45:09',0,NULL,0,1,11,0,NULL,'hermeshine'),(26644,825195413018,280689696782,'Photo Studio Light Kit Boom Arm Stand Tripod /115w bulb',1,'AKT004',78,'photographyacc','scorpus057','scorpus57@gmail.com','Tim Schiesser','3 Gamston Court','Highton','Victoria','AUSTRALIA','3216','0430377928','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-25 11:37:20',0,NULL,0,1,4,0,NULL,'photographyacc\r澳标'),(26645,8881332678932408,111,'3m 横杆',1,'',23.2,'hermeshine','thiagoliveira2011','thiagoliveira@terra.com.br','Daiana Garibaldi da Rocha','Rua Professor Joaquim Felizardo, nº 40<br>CEP 91770-370','Porto Alegre City - Rio Grande do Sul','Bairro Espírito Santo','BRAZIL','91751-000','',NULL,NULL,NULL,'2012-03-25 12:35:32',0,NULL,0,0,3,0,NULL,'4节\r申报低值 '),(26646,825223563018,280666853922,'Studio Background Support 7x7 ft with White Backdrops ',1,'AO0010',64,'photographyacc','joen97','andbaek@tpg.com.au','Seaung-Hun (Andrew) Baek','Unit 174/107 Pacific Hwy','Hornsby','New South Wales','AUSTRALIA','2077','61466405075','NoPaymentFailure','CheckoutComplete','AU_StandardDeliveryFromOutsideAU','2012-03-25 12:41:47',0,NULL,0,1,4,0,NULL,'photographyacc\r黑加白'),(26647,8881332679650061,111,'Highly recommended! - Free shipping & Tracking # - Pro Camera Tripod Ball Head KS-0 III + Quick Release Plate - AD1187',1,'AD1187',35.99,'aliexpress','1007605520 ','qqs644md@solid.ocn.ne.jp','Takashi Kitabatake','akatutumi4-19-8 bonelfakatutumi#111','setagaya','tokyo','JAPAN','1560044','+090 4433 6408',NULL,NULL,NULL,'2012-03-25 12:47:30',0,NULL,4,1,3,0,NULL,'速卖通 '),(26648,8881332680791360,111,'3m横杆螺丝',1,'',0,'hutongstore','australia*','office77@tpg.com.au','Tony Monteleone','4 Alder Close','Jerrabomberra','New South Wales','AUSTRALIA','2619','0421406480',NULL,NULL,NULL,'2012-03-25 13:06:31',0,NULL,0,0,3,0,NULL,'灯架包薄  1\r3个澳标，3个夹子 \rthe screws, peg and AU plug adapter and umbrella bag \r是这些东西吗？\r'),(26649,973010718015,250619383224,'NEW Pro Photo Studio Reflector Holding Arm 0.66m - 1.5m',1,'AE2501',18.99,'hutongstore','biohazardaj','anyeloj@hotmail.com','Anyelo Jiménez Boguier','Carretera General del Sur Nro. 59 2º Apto. 8<br>San Miguel de Abona','Santa Cruz de Tenerife','Canarias','SPAIN','38620','609166224','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 14:00:36',0,NULL,0,0,0,0,NULL,'hutongstore'),(26650,818002457001,110447980462,'BRAND NEW EW-73B Lens Hood for Canon EF-S 17-85mm EW73B',1,'AA3408',8,'hermeshine','arik2005','arikgulenko@yahoo.co.uk','Atrhur Hulenko','114 Rusheeney court','Clonsilla','Dublin','IRELAND','D15','018129986','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 14:58:42',0,NULL,0,0,0,0,NULL,'hermeshine'),(26651,862850347002,120841734282,'Promotion ! NEW Square Gradual Graduated Sunset Color Filter for Cokin P Series',1,'AD1226',3.5,'hermeshine','prrrum','dunieskicorzo@yahoo.com','Dunieski Corzo','11400 Whistlers Cove Blvd<br>Apt 328','Naples','FL','UNITED STATES','34113-7815','(239) 234-8181','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-25 15:09:07',0,NULL,0,0,0,0,NULL,'hermeshine'),(26652,862851051002,120841734145,'Promotion ! NEW Square Gradual Graduated Blue Color Filter for Cokin P Series',1,'AD1224',3.5,'hermeshine','prrrum','dunieskicorzo@yahoo.com','Dunieski Corzo','11400 Whistlers Cove Blvd<br>Apt 328','Naples','FL','UNITED STATES','34113-7815','(239) 234-8181','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-25 15:10:41',0,NULL,0,0,0,0,NULL,'hermeshine'),(26653,862873635002,120758265803,'Camera protector case bag f Nikon D5000 D5100 D90 D80 M',1,'AD1172',7.99,'hermeshine','mr.needy','bferguso@tampabay.rr.com','Robert B Ferguson','215 Bluebird Ave','Lakeland','FL','UNITED STATES','33809-3565','','NoPaymentFailure','CheckoutComplete','ePacketChina','2012-03-25 15:51:04',0,NULL,0,0,0,0,NULL,'hermeshine'),(26654,862879459002,120752214082,'43\" 110cm Black Silver Reflector Studio Light umbrella',1,'AD1126',12.5,'hermeshine','plefish','slirty8@hotmail.com','Maurice Aucoin','p.o. box 733','Cheticamp','NS','CANADA','b0e1h0','(902) 224-3542','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 16:02:36',0,NULL,0,0,0,0,NULL,'hermeshine'),(26655,818040495001,110846914387,'New 43\" Collapsible Silver/Black Reflective Studio Lighting Umbrella cover inclu',1,'AD1234',26,'hermeshine','marlon_gg','dadi25.bp@gmail.com','Dadi Azarzar','P.O BOX 88','Kibbutz Merchavia','ISRAEL','ISRAEL','19100','','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 16:04:18',0,NULL,0,0,0,0,NULL,'hermeshine'),(26656,973130465015,250636962495,'4-in-1 E27 Splitter Adapter Studio Light Lamp Socket ',1,'AE3301',7.8,'hutongstore','bradmc_1986','bmc_1986@hotmail.com','bradley cook','18 stour close','strood','Kent','UNITED KINGDOM','me2 3jx','07949020388','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 16:46:34',0,NULL,0,0,0,0,NULL,'hutongstore'),(26657,818094656001,110407881654,'58mm CPL Circular Polarizing Filter 58 CPL Green.L ',1,'AA3310',6,'hermeshine','dmitriych74','dmitriyach@gmail.com','Dmitriy Chernichenko','ul. Belyaeva, d.2-B, kv.85','Cherepovetc','Vologodskaya oblast','RUSSIAN FEDERATION','162616','+79646640505','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 17:23:17',0,NULL,0,0,0,0,NULL,'hermeshine'),(26658,952969246016,260660051619,'Medium size Neoprene Lens Pouch fit 17-85mm 18-70mm M',1,'AC1202',2.48,'hutongstore','supercali9090','darryl.sleet@btinternet.com','Darryl Sleet','20 Castlefields','Hartfield','East Sussex','UNITED KINGDOM','tn7 4ja','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 17:37:42',0,NULL,0,0,0,0,NULL,'hutongstore'),(26659,973184458015,250950973360,'Protect Soft Camera Bag Case Cover Canon EOS 60D 40D',1,'AD1115',6.5,'hutongstore','supercali9090','darryl.sleet@btinternet.com','Darryl Sleet','20 Castlefields','Hartfield','East Sussex','UNITED KINGDOM','tn7 4ja','','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 17:40:55',0,NULL,0,0,0,0,NULL,'hutongstore'),(26660,818113140001,110422379068,'Aluminium Lightweight 67\" Camera Monopod Free P&P New',1,'AE1602',16,'hermeshine','dinata71','dimdimi4ogre@inbox.lv','Dimitrijs Stepanovs','Rigas 18 - 18','Ogre','Latvia','LATVIA','LV-5001','+371 26516210','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 17:45:31',0,NULL,0,0,0,0,NULL,'hermeshine'),(26661,973214118015,250599954246,'Pro FANCIER FT-6662A Tripod with 6160H Pan head bag',1,'AE1503',45.99,'hutongstore','fereror','demoniustyper@hotmail.com','Jésus Dieguez','139 Avenue Jean Baptiste Clément','Boulogne Billancourt','Île-de-France','FRANCE','92100','06.32.17.77.68','NoPaymentFailure','CheckoutComplete','UK_OtherCourierOrDeliveryInternational','2012-03-25 18:06:51',0,NULL,0,0,0,0,NULL,'hutongstore'),(26662,863043147002,120816622324,'New Professional 80cm Octagon Umbrella Softbox soft box Reflector Speedlite',1,'AD1198',32.99,'hermeshine','vodibike','rsinapse@hotmail.com','RAPHAEL SOUZA DUARTE','RUA FREI CANECA 183<br>183 CURIANGO','CURVELO','MINAS GERAIS','BRAZIL','35790000','3197936561','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 19:11:32',0,NULL,0,0,0,0,NULL,'hermeshine'),(26663,973335367015,250631211096,'24\" 2-in-1 Light Mulit Collapsible disc Reflector 60cm',1,'AC3303',5.45,'hutongstore','zhord','didsburyalbion@yahoo.co.uk','Gary Carroll','59 Catterick Road, Didsbury','Manchester','Lancashire','UNITED KINGDOM','M20 6HF','01614482872','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 19:36:37',0,NULL,0,0,0,0,NULL,'hutongstore'),(26664,973337755015,251023188251,'New Soft Camera Bag Case Cover Canon 5D Mark II + 24-105mm XL',2,'AD1237',9.8,'hutongstore','lagrue123','michelle@scotwork.com','Michelle LaGrue','5 Maypark<br>Malahide Road','Dublin','Dublin','IRELAND','5','018316264','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 19:38:22',0,NULL,0,0,0,0,NULL,'hutongstore'),(26665,972525638015,250599985982,'Medium size Neoprene Lens Pouch Casefit 17-85mm 18-70mm',1,'AC1202',100.47,'hutongstore','zimsus','zimo@o2.pl','Stanislaw Zimoglad','20B Boghall Cottages','Bray','Wicklow','IRELAND','default','0851475059','NoPaymentFailure','CheckoutComplete','UK_SellersStandardInternationalRate','2012-03-25 20:13:10',0,NULL,0,0,0,0,NULL,'hutongstore'),(26666,973397314015,250845728892,'Portable 40cm 16\" Soft Box Softbox for Flash Speedlight',1,'AB3327',23.68,'hutongstore','visualgrammer','up4alarf@msn.com','Adrian Blake','Outwood, Whitecross','Wadebridge','Cornwall','UNITED KINGDOM','pl27 7jb','01208813929','NoPaymentFailure','CheckoutComplete','UK_EconomyShippingFromOutside','2012-03-25 20:29:11',0,NULL,0,0,0,0,NULL,'hutongstore'),(26667,863140675002,120451410660,'New Collapsible 4.6\' x 5.7\' 190x140 cm backdrop background light grey and black',1,'AA1218',58,'hermeshine','hittin48','chabaita.h@gmail.com','Hicham Chabaita','5 Yarhinai Shmouel App 14','Tel Aviv Yaffo','','ISRAEL','68083','972528429309','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 20:55:19',0,NULL,0,0,0,0,NULL,'hermeshine'),(26668,818305013001,110736978824,'New Studio Lighting Kit Stands Large Carry Carrying Bag',1,'AD1181',19.9,'hermeshine','hittin48','chabaita.h@gmail.com','Hicham Chabaita','5 Yarhinai Shmouel App 14','Tel Aviv Yaffo','','ISRAEL','68083','972528429309','NoPaymentFailure','CheckoutComplete','StandardInternational','2012-03-25 21:03:33',0,NULL,0,0,0,0,NULL,'hermeshine');
/*!40000 ALTER TABLE `hmsh_ebay_transaction` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2012-03-25 15:45:42
